% Auto-generated chapter 14 for nasai
% Hadiths in this chapter: 66

\hadithdefcmd{nasai}{1367}{أَخْبَرَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، وَابْنُ، طَاوُسٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَحْنُ الآخِرُونَ السَّابِقُونَ بَيْدَ أَنَّهُمْ أُوتُوا الْكِتَابَ مِنْ قَبْلِنَا وَأُوتِينَاهُ مِنْ بَعْدِهِمْ وَهَذَا الْيَوْمُ الَّذِي كَتَبَ اللَّهُ عَزَّ وَجَلَّ عَلَيْهِمْ فَاخْتَلَفُوا فِيهِ فَهَدَانَا اللَّهُ عَزَّ وَجَلَّ لَهُ - يَعْنِي يَوْمَ الْجُمُعَةِ - فَالنَّاسُ لَنَا فِيهِ تَبَعٌ الْيَهُودُ غَدًا وَالنَّصَارَى بَعْدَ غَدٍ ‏"‏ ‏.‏\hadithno{1367}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'We are the last (to come) but will be the foremost on the Day of Resurrection, but they were given the Book before us and we were given it after them. They differed concerning this day which Allah, the Mighty and Sublime, had prescribed for them and Allah, the Mighty and Sublime, guided us to"--meaning Friday--"so the people follow us, the Jews the next day and the Christians the day after that}}
\hadithdefcmd{nasai}{1368}{\hadithno{1368}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{1369}{\hadithno{1369}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{1370}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا حَبَّانُ، قَالَ حَدَّثَنَا أَبَانُ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنِ الْحَضْرَمِيِّ بْنِ لاَحِقٍ، عَنْ زَيْدٍ، عَنْ أَبِي سَلاَّمٍ، عَنِ الْحَكَمِ بْنِ مِينَاءَ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، وَابْنَ، عُمَرَ يُحَدِّثَانِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ وَهُوَ عَلَى أَعْوَادِ مِنْبَرِهِ ‏ "‏ لَيَنْتَهِيَنَّ أَقْوَامٌ عَنْ وَدْعِهِمُ الْجُمُعَاتِ أَوْ لَيَخْتِمَنَّ اللَّهُ عَلَى قُلُوبِهِمْ وَلَيَكُونَنَّ مِنَ الْغَافِلِينَ ‏"‏ ‏.‏\hadithno{1370}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Al-Hakam bin Mina' that:He heard Ibn Abbas and Ibn Umar narrate that while he was on the minbar, the Messenger of Allah (ﷺ) said: "People should stop neglecting Jumu'ah or Allah will place a seal on their hearts and they will be deemed as being among the negligent}}
\hadithdefcmd{nasai}{1371}{أَخْبَرَنِي مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنِي الْمُفَضَّلُ بْنُ فَضَالَةَ، عَنْ عَيَّاشِ بْنِ عَبَّاسٍ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ حَفْصَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ رَوَاحُ الْجُمُعَةِ وَاجِبٌ عَلَى كُلِّ مُحْتَلِمٍ ‏"‏ ‏.‏\hadithno{1371}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Hafsah, the wife of the Prophet (ﷺ) that:The Prophet (ﷺ) said: "Going to Jumu'ah is obligatory for everyone who has reached the age of puberty}}
\hadithdefcmd{nasai}{1372}{\hadithno{1372}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif}\hadithtrans{}}
\hadithdefcmd{nasai}{1373}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ الأَعْرَجُ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ يَوْمٍ طَلَعَتْ فِيهِ الشَّمْسُ يَوْمُ الْجُمُعَةِ فِيهِ خُلِقَ آدَمُ عَلَيْهِ السَّلاَمُ وَفِيهِ أُدْخِلَ الْجَنَّةَ وَفِيهِ أُخْرِجَ مِنْهَا ‏"‏ ‏.‏\hadithno{1373}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdur-Rahman Al-A'raj narrated that:He heard Abu Hurairah say: "The Messenger of Allah (ﷺ) said: 'The best day on which the sun rises is Friday. On this day, Adam, peace be upon him, was created, on this day he was admitted to Paradise, and on this day he was taken out of it}}
\hadithdefcmd{nasai}{1374}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا حُسَيْنٌ الْجُعْفِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ، عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، عَنْ أَوْسِ بْنِ أَوْسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ مِنْ أَفْضَلِ أَيَّامِكُمْ يَوْمَ الْجُمُعَةِ فِيهِ خُلِقَ آدَمُ عَلَيْهِ السَّلاَمُ وَفِيهِ قُبِضَ وَفِيهِ النَّفْخَةُ وَفِيهِ الصَّعْقَةُ فَأَكْثِرُوا عَلَىَّ مِنَ الصَّلاَةِ فَإِنَّ صَلاَتَكُمْ مَعْرُوضَةٌ عَلَىَّ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَكَيْفَ تُعْرَضُ صَلاَتُنَا عَلَيْكَ وَقَدْ أَرَمْتَ أَىْ يَقُولُونَ قَدْ بَلِيتَ ‏.‏ قَالَ ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ قَدْ حَرَّمَ عَلَى الأَرْضِ أَنْ تَأْكُلَ أَجْسَادَ الأَنْبِيَاءِ عَلَيْهِمُ السَّلاَمُ ‏"‏ ‏.‏\hadithno{1374}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Aws bin Aws that :The Prophet (ﷺ) said: "One of the best of your days is Friday. On this day, Adam was created and on this day he died, on this day the Trumpet will be blown, and on this day all creatures will swoon. So send a great deal of salah upon me on this day, for your salah will be presented to me." They said: "O Messenger of Allah (ﷺ), how will our salah be presented to you when you have decomposed (after death)?" He said: "Allah, the Mighty and Sublime, has forbidden the earth to consume the bodies of the prophets, peace be upon them}}
\hadithdefcmd{nasai}{1375}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، أَنَّ سَعِيدَ بْنَ أَبِي هِلاَلٍ، وَبُكَيْرَ بْنَ الأَشَجِّ، حَدَّثَاهُ عَنْ أَبِي بَكْرِ بْنِ الْمُنْكَدِرِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الْغُسْلُ يَوْمَ الْجُمُعَةِ وَاجِبٌ عَلَى كُلِّ مُحْتَلِمٍ وَالسِّوَاكُ وَيَمَسُّ مِنَ الطِّيبِ مَا قَدَرَ عَلَيْهِ ‏"‏ ‏.‏ إِلاَّ أَنَّ بُكَيْرًا لَمْ يَذْكُرْ عَبْدَ الرَّحْمَنِ وَقَالَ فِي الطِّيبِ ‏"‏ وَلَوْ مِنْ طِيبِ الْمَرْأَةِ ‏"‏ ‏.‏\hadithno{1375}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated (through two chains) from 'Abdur-Rahman bin Abi Sa'eed, from his father, that:The Messenger of Allah (ﷺ) said: "Ghusl and using siwak on Fridays are obligatory for everyone who has reached the age of puberty, and he should put on whatever he can find of perfume." Except that Bukair (one of the narrators in one chain) did not mention 'Abdur-Rahman, and about the perfume he said: "Even if it is women's perfume}}
\hadithdefcmd{nasai}{1376}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا جَاءَ أَحَدُكُمُ الْجُمُعَةَ فَلْيَغْتَسِلْ ‏"‏ ‏.‏\hadithno{1376}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah (ﷺ) said: "When any one of you wants to come to Jumu'ah prayer, let him perform ghusl}}
\hadithdefcmd{nasai}{1377}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ غُسْلُ يَوْمِ الْجُمُعَةِ وَاجِبٌ عَلَى كُلِّ مُحْتَلِمٍ ‏"‏ ‏.‏\hadithno{1377}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that:The Messenger of Allah (ﷺ) said: "Ghusl on Friday is obligatory for everyone who has reached the age of puberty}}
\hadithdefcmd{nasai}{1378}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا بِشْرٌ، قَالَ حَدَّثَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلَى كُلِّ رَجُلٍ مُسْلِمٍ فِي كُلِّ سَبْعَةِ أَيَّامٍ غُسْلُ يَوْمٍ وَهُوَ يَوْمُ الْجُمُعَةِ ‏"‏ ‏.‏\hadithno{1378}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah (ﷺ) said: 'Every Muslim man has to perform Ghusl one day in every seven, and that is on Friday}}
\hadithdefcmd{nasai}{1379}{أَخْبَرَنَا مَحْمُودُ بْنُ خَالِدٍ، عَنِ الْوَلِيدِ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْعَلاَءِ، أَنَّهُ سَمِعَ الْقَاسِمَ بْنَ مُحَمَّدِ بْنِ أَبِي بَكْرٍ، أَنَّهُمْ ذَكَرُوا غُسْلَ يَوْمِ الْجُمُعَةِ عِنْدَ عَائِشَةَ فَقَالَتْ إِنَّمَا كَانَ النَّاسُ يَسْكُنُونَ الْعَالِيَةَ فَيَحْضُرُونَ الْجُمُعَةَ وَبِهِمْ وَسَخٌ فَإِذَا أَصَابَهُمُ الرَّوْحُ سَطَعَتْ أَرْوَاحُهُمْ فَيَتَأَذَّى بِهَا النَّاسُ فَذُكِرَ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَوَلاَ يَغْتَسِلُونَ ‏"‏ ‏.‏\hadithno{1379}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin Al-'Ala narrated that:He heard Al-Qasim bin Muhammad bin Abi Bakr (say) that they mentioned Ghusl on Fridays in the presence of 'Aishah and she said: "Some people used to live in Al-'Aliyah and they would come to Jumu'ah with dirt on them (because of their work). When a breeze came it would carry their smell to the people which annoyed them. Mention of that was made to the Messenger of Allah (ﷺ) and he said: "Why don't you perform Ghusl?}}
\hadithdefcmd{nasai}{1380}{أَخْبَرَنَا أَبُو الأَشْعَثِ، عَنْ يَزِيدَ بْنِ زُرَيْعٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَوَضَّأَ يَوْمَ الْجُمُعَةِ فَبِهَا وَنِعْمَتْ وَمَنِ اغْتَسَلَ فَالْغُسْلُ أَفْضَلُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ الْحَسَنُ عَنْ سَمُرَةَ كِتَابًا وَلَمْ يَسْمَعِ الْحَسَنُ مِنْ سَمُرَةَ إِلاَّ حَدِيثَ الْعَقِيقَةِ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{1380}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Samurah said:"The Messenger of Allah (ﷺ) said: 'Whoever performs wudu' on Friday, that is all well and good, but whoever performs Ghusl, the Ghusl is better}}
\hadithdefcmd{nasai}{1381}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، وَهَارُونُ بْنُ مُحَمَّدِ بْنِ بَكَّارِ بْنِ بِلاَلٍ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا أَبُو مُسْهِرٍ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ يَحْيَى بْنِ الْحَارِثِ، عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، عَنْ أَوْسِ بْنِ أَوْسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ غَسَّلَ وَاغْتَسَلَ وَغَدَا وَابْتَكَرَ وَدَنَا مِنَ الإِمَامِ وَلَمْ يَلْغُ كَانَ لَهُ بِكُلِّ خُطْوَةٍ عَمَلُ سَنَةٍ صِيَامُهَا وَقِيَامُهَا ‏"‏ ‏.‏\hadithno{1381}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Aws bin Aws that:The Prophet (ﷺ) said: "Whoever washes (Ghassala) and performs Ghusl, comes early to the Masjid and sits near the Imam, and does not engage in idle talk, he will have for every step he takes (the reward of) a year's worth of good deeds, fasting it and praying Qiyam during it}}
\hadithdefcmd{nasai}{1382}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، رَأَى حُلَّةً فَقَالَ يَا رَسُولَ اللَّهِ لَوِ اشْتَرَيْتَ هَذِهِ فَلَبِسْتَهَا يَوْمَ الْجُمُعَةِ وَلِلْوَفْدِ إِذَا قَدِمُوا عَلَيْكَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا يَلْبَسُ هَذِهِ مَنْ لاَ خَلاَقَ لَهُ فِي الآخِرَةِ ‏"‏ ‏.‏ ثُمَّ جَاءَ رَسُولَ اللَّهِ صلى الله عليه وسلم مِثْلُهَا فَأَعْطَى عُمَرَ مِنْهَا حُلَّةً فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ كَسَوْتَنِيهَا وَقَدْ قُلْتَ فِي حُلَّةِ عُطَارِدٍ مَا قُلْتَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَمْ أَكْسُكَهَا لِتَلْبَسَهَا ‏"‏ ‏.‏ فَكَسَاهَا عُمَرُ أَخًا لَهُ مُشْرِكًا بِمَكَّةَ ‏.‏\hadithno{1382}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that :'Umar bin al-Khattab saw a Hullah and said: "O Messenger of Allah (ﷺ), why don't you buy this and wear it on Fridays and when meeting the delegations when they come to you?" The Messenger of Allah (ﷺ) said: "This is worn by one who has no share in the Hereafter." Then something similar was brought to the Messenger of Allah (ﷺ) and he gave a Hullah to 'Umar from it. 'Umar said: "O Messenger of Allah (ﷺ), have you given me this when you said what you said about the Hullah of 'Utarid?" The Messenger of Allah (ﷺ) said: "I have not given it to you to wear it." So 'Umar gave it to an idolator brother of his in Makkah}}
\hadithdefcmd{nasai}{1383}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ سَوَّارٍ، قَالَ حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ سَعِيدٍ، عَنْ أَبِي بَكْرِ بْنِ الْمُنْكَدِرِ، أَنَّ عَمْرَو بْنَ سُلَيْمٍ، أَخْبَرَهُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْغُسْلَ يَوْمَ الْجُمُعَةِ عَلَى كُلِّ مُحْتَلِمٍ وَالسِّوَاكَ وَأَنْ يَمَسَّ مِنَ الطِّيبِ مَا يَقْدِرُ عَلَيْهِ ‏"‏ ‏.‏\hadithno{1383}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdur-Rahman bin Abi Sa'eed, from his father, that:The Messenger of Allah (ﷺ) said: "Ghusl should be performed on Friday by everyone who has reached the age of puberty, and using the siwak, and he should put on whatever he is able of using perfume}}
\hadithdefcmd{nasai}{1384}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ، أَنَّهُ سَمِعَ أَبَا الأَشْعَثِ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَوْسَ بْنَ أَوْسٍ، صَاحِبَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اغْتَسَلَ يَوْمَ الْجُمُعَةِ وَغَسَّلَ وَغَدَا وَابْتَكَرَ وَمَشَى وَلَمْ يَرْكَبْ وَدَنَا مِنَ الإِمَامِ وَأَنْصَتَ وَلَمْ يَلْغُ كَانَ لَهُ بِكُلِّ خُطْوَةٍ عَمَلُ سَنَةٍ ‏"‏ ‏.‏\hadithno{1384}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Al-Ash'ath narrated that:He heard Aws bin Aws, the Companion of the Messenger of Allah (ﷺ) say: "The Messenger of Allah (ﷺ) said: 'Whoever performs Ghusl on Friday and washes (Ghassala), and comes early to the Masjid, walking not riding, and sits close to the Imam and listens attentively and does not engage in idle speech, for every step he takes he will have (the reward of) a year's worth of good deeds}}
\hadithdefcmd{nasai}{1385}{أَخْبَرَنَا نَصْرُ بْنُ عَلِيِّ بْنِ نَصْرٍ، عَنْ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ الأَغَرِّ أَبِي عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا كَانَ يَوْمُ الْجُمُعَةِ قَعَدَتِ الْمَلاَئِكَةُ عَلَى أَبْوَابِ الْمَسْجِدِ فَكَتَبُوا مَنْ جَاءَ إِلَى الْجُمُعَةِ فَإِذَا خَرَجَ الإِمَامُ طَوَتِ الْمَلاَئِكَةُ الصُّحُفَ ‏"‏ ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْمُهَجِّرُ إِلَى الْجُمُعَةِ كَالْمُهْدِي بَدَنَةً ثُمَّ كَالْمُهْدِي بَقَرَةً ثُمَّ كَالْمُهْدِي شَاةً ثُمَّ كَالْمُهْدِي بَطَّةً ثُمَّ كَالْمُهْدِي دَجَاجَةً ثُمَّ كَالْمُهْدِي بَيْضَةً ‏"‏ ‏.‏\hadithno{1385}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet (ﷺ) said: "When Friday comes, the angels sit at the doors of the Masjid and record who comes to Jumu'ah prayers. Then, when the Imam comes out, the angels roll up their scrolls." The Messenger of Allah (ﷺ) said: 'The one who comes early to Jumu'ah prayers is like one who sacrifices a camel, then like one who sacrifices a cow, then like one who sacrifices a sheep, then like one who sacrifices a duck, then like one who sacrifices a chicken, then like one who sacrifices an egg}}
\hadithdefcmd{nasai}{1386}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ يَوْمُ الْجُمُعَةِ كَانَ عَلَى كُلِّ بَابٍ مِنْ أَبْوَابِ الْمَسْجِدِ مَلاَئِكَةٌ يَكْتُبُونَ النَّاسَ عَلَى مَنَازِلِهِمُ الأَوَّلَ فَالأَوَّلَ فَإِذَا خَرَجَ الإِمَامُ طُوِيَتِ الصُّحُفُ وَاسْتَمَعُوا الْخُطْبَةَ فَالْمُهَجِّرُ إِلَى الصَّلاَةِ كَالْمُهْدِي بَدَنَةً ثُمَّ الَّذِي يَلِيهِ كَالْمُهْدِي بَقَرَةً ثُمَّ الَّذِي يَلِيهِ كَالْمُهْدِي كَبْشًا ‏"‏ ‏.‏ حَتَّى ذَكَرَ الدَّجَاجَةَ وَالْبَيْضَةَ ‏.‏\hadithno{1386}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah, who was attributing it to the Prophet (ﷺ):"When Friday comes, at every gate of the masjid there are angels who write down the people's names in the order in which they come, then when the Imam comes out, they roll up the scrolls and listen to the Khutbah. The one who comes early to the prayer is like the one who sacrifices a camel, then the one who comes after him is like the one who sacrifices a cow, then the one who comes after him is like the one who sacrifices a ram" until he mentioned a chicken and an egg}}
\hadithdefcmd{nasai}{1387}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ اللَّيْثِ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَقْعُدُ الْمَلاَئِكَةُ يَوْمَ الْجُمُعَةِ عَلَى أَبْوَابِ الْمَسْجِدِ يَكْتُبُونَ النَّاسَ عَلَى مَنَازِلِهِمْ فَالنَّاسُ فِيهِ كَرَجُلٍ قَدَّمَ بَدَنَةً وَكَرَجُلٍ قَدَّمَ بَقَرَةً وَكَرَجُلٍ قَدَّمَ شَاةً وَكَرَجُلٍ قَدَّمَ دَجَاجَةً وَكَرَجُلٍ قَدَّمَ عُصْفُورًا وَكَرَجُلٍ قَدَّمَ بَيْضَةً ‏"‏ ‏.‏\hadithno{1387}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) said: "On Fridays the angels sit at the gates of the Masjid writing down the peoples' names in the order in which they come. So the people are like a man who sacrifices a camel and like a man who sacrifices a camel, then like a man who sacrifices a cow and like a man who sacrifices a cow, then like a man who sacrifices a sheep and like a man who sacrifices a sheep, then like a man who sacrifices a chicken and like a man who sacrifices a chicken, then like a man who sacrifices a sparrow and like a man who sacrifices a sparrow, then like a man who sacrifices an egg and like a man who sacrifices an egg}}
\hadithdefcmd{nasai}{1388}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اغْتَسَلَ يَوْمَ الْجُمُعَةِ غُسْلَ الْجَنَابَةِ ثُمَّ رَاحَ فَكَأَنَّمَا قَرَّبَ بَدَنَةً وَمَنْ رَاحَ فِي السَّاعَةِ الثَّانِيَةِ فَكَأَنَّمَا قَرَّبَ بَقَرَةً وَمَنْ رَاحَ فِي السَّاعَةِ الثَّالِثَةِ فَكَأَنَّمَا قَرَّبَ كَبْشًا وَمَنْ رَاحَ فِي السَّاعَةِ الرَّابِعَةِ فَكَأَنَّمَا قَرَّبَ دَجَاجَةً وَمَنْ رَاحَ فِي السَّاعَةِ الْخَامِسَةِ فَكَأَنَّمَا قَرَّبَ بَيْضَةً فَإِذَا خَرَجَ الإِمَامُ حَضَرَتِ الْمَلاَئِكَةُ يَسْتَمِعُونَ الذِّكْرَ ‏"‏ ‏.‏\hadithno{1388}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) said: "Whoever performs Ghusl as from Janabah on Friday, then comes (to the Masjid), it is as if he sacrificed a camel. Then the one who comes in the second hour, it is as if he sacrificed a cow. Then the one who comes in the third hour, it is as if he sacrificed a ram. Then the one who comes in the fourth hour, it is as if he sacrificed a chicken. Then the one who comes in the fifth hour, it is as if he sacrificed an egg. Then when the Imam comes out, the angels attend to listen to the Khutbah}}
\hadithdefcmd{nasai}{1389}{أَخْبَرَنَا عَمْرُو بْنُ سَوَّادِ بْنِ الأَسْوَدِ بْنِ عَمْرٍو، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنِ الْجُلاَحِ، مَوْلَى عَبْدِ الْعَزِيزِ أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، حَدَّثَهُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَوْمُ الْجُمُعَةِ اثْنَتَا عَشْرَةَ سَاعَةً لاَ يُوجَدُ فِيهَا عَبْدٌ مُسْلِمٌ يَسْأَلُ اللَّهَ شَيْئًا إِلاَّ آتَاهُ إِيَّاهُ فَالْتَمِسُوهَا آخِرَ سَاعَةٍ بَعْدَ الْعَصْرِ ‏"‏ ‏.‏\hadithno{1389}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah that:The Messenger of Allah (ﷺ) said: "Friday is twelve hours in which there is no Muslim slave who asks Allah (SWT) for something but He will give it to him, so seek it in the last hour after 'Asr}}
\hadithdefcmd{nasai}{1390}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا حَسَنُ بْنُ عَيَّاشٍ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا نُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْجُمُعَةَ ثُمَّ نَرْجِعُ فَنُرِيحُ نَوَاضِحَنَا ‏.‏ قُلْتُ أَيَّةَ سَاعَةٍ قَالَ زَوَالُ الشَّمْسِ ‏.‏\hadithno{1390}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ja'far bin Muhammad from his father, from Jabir bin 'Abdullah who said:"We used to pray Jumu'ah with the Messenger of Allah (ﷺ) then we would go back and tend to our camels." I said: " At what time?" He said: "When the sun had passed its zenith}}
\hadithdefcmd{nasai}{1391}{أَخْبَرَنَا شُعَيْبُ بْنُ يُوسُفَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ، عَنْ يَعْلَى بْنِ الْحَارِثِ، قَالَ سَمِعْتُ إِيَاسَ بْنَ سَلَمَةَ بْنِ الأَكْوَعِ، يُحَدِّثُ عَنْ أَبِيهِ، قَالَ كُنَّا نُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْجُمُعَةَ ثُمَّ نَرْجِعُ وَلَيْسَ لِلْحِيطَانِ فَىْءٌ يُسْتَظَلُّ بِهِ ‏.‏\hadithno{1391}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Iyas bin Salamah bin Al-Akwa' narrated that his father said:"We used to pray Jumu'ah with the Messenger of Allah (ﷺ) then we would go back, and the walls had no shadow in which shade could be sought}}
\hadithdefcmd{nasai}{1392}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي السَّائِبُ بْنُ يَزِيدَ، أَنَّ الأَذَانَ، كَانَ أَوَّلُ حِينَ يَجْلِسُ الإِمَامُ عَلَى الْمِنْبَرِ يَوْمَ الْجُمُعَةَ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ فَلَمَّا كَانَ فِي خِلاَفَةِ عُثْمَانَ وَكَثُرَ النَّاسُ أَمَرَ عُثْمَانُ يَوْمَ الْجُمُعَةِ بِالأَذَانِ الثَّالِثِ فَأُذِّنَ بِهِ عَلَى الزَّوْرَاءِ فَثَبَتَ الأَمْرُ عَلَى ذَلِكَ ‏.‏\hadithno{1392}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{As-Sa'ib bin Yazid narrated that:The first Adhan used to be when the Imam sat on the Minbar on Friday, at the time of the Messenger of Allah (ﷺ) and Abu Bakr and 'Umar. During the caliphate of 'Uthman, when the number of people increased, 'Uthman commanded that a third Adhan be given on Friday, so that Adhan was given from the top of Az-Zawra, and that is how it remained}}
\hadithdefcmd{nasai}{1393}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا يَعْقُوبُ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ السَّائِبَ بْنَ يَزِيدَ، أَخْبَرَهُ قَالَ إِنَّمَا أَمَرَ بِالتَّأْذِينِ الثَّالِثِ عُثْمَانُ حِينَ كَثُرَ أَهْلُ الْمَدِينَةِ وَلَمْ يَكُنْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم غَيْرُ مُؤَذِّنٍ وَاحِدٍ وَكَانَ التَّأْذِينُ يَوْمَ الْجُمُعَةِ حِينَ يَجْلِسُ الإِمَامُ ‏.‏\hadithno{1393}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{As-Sa'ib bin Yazid said:"The third Adhan was ordered by 'Uthman when the number of people in Al-Madinah increased. The Messenger of Allah (ﷺ) only had one Adhan, and the Adhan on Friday was when the Imam sat down}}
\hadithdefcmd{nasai}{1394}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، عَنِ الزُّهْرِيِّ، عَنِ السَّائِبِ بْنِ يَزِيدَ، قَالَ كَانَ بِلاَلٌ يُؤَذِّنُ إِذَا جَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ يَوْمَ الْجُمُعَةِ فَإِذَا نَزَلَ أَقَامَ ثُمَّ كَانَ كَذَلِكَ فِي زَمَنِ أَبِي بَكْرٍ وَعُمَرَ رضى الله عنهما ‏.‏\hadithno{1394}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that As-Sa'ib bin Yazid said:"Bilal used to call the Adhan when the Messenger of Allah (ﷺ) sat on the Minbar on Friday, and when he came down he would say the Iqamah. It continued like that during the time of Abu Bakr and 'Umar, may Allah (SWT) be pleased with them}}
\hadithdefcmd{nasai}{1395}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا جَاءَ أَحَدُكُمْ وَقَدْ خَرَجَ الإِمَامُ فَلْيُصَلِّ رَكْعَتَيْنِ ‏"‏ ‏.‏ قَالَ شُعْبَةُ يَوْمَ الْجُمُعَةِ ‏.‏\hadithno{1395}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Amr bin Dinar said:"I heard Jabir bin 'Abdullah say: 'The Messenger of Allah (ﷺ) said: "If any one of you comes and the Imam has appeared, let him pray two Rak'ahs. Shu'bah (one of the narrators) said: "On Friday}}
\hadithdefcmd{nasai}{1396}{أَخْبَرَنَا عَمْرُو بْنُ سَوَّادِ بْنِ الأَسْوَدِ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، أَنَّ أَبَا الزُّبَيْرِ، أَخْبَرَهُ أَنَّهُ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا خَطَبَ يَسْتَنِدُ إِلَى جِذْعِ نَخْلَةٍ مِنْ سَوَارِي الْمَسْجِدِ فَلَمَّا صُنِعَ الْمِنْبَرُ وَاسْتَوَى عَلَيْهِ اضْطَرَبَتْ تِلْكَ السَّارِيَةُ كَحَنِينِ النَّاقَةِ حَتَّى سَمِعَهَا أَهْلُ الْمَسْجِدِ حَتَّى نَزَلَ إِلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَاعْتَنَقَهَا فَسَكَتَتْ ‏.‏\hadithno{1396}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir bin 'Abdullah said:"When the Messenger of Allah (ﷺ) delivered the khutbah, he used to lean against a palm tree trunk that formed one of the pillars of the Masjid. When the Minbar was made and he sat down on it, that pillar made a sound like the groaning of a camel, which the people of the Masjid heard, until the Messenger of Allah (ﷺ) came down and embraced it, then it fell silent}}
\hadithdefcmd{nasai}{1397}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ كَعْبِ بْنِ عُجْرَةَ، قَالَ دَخَلَ الْمَسْجِدَ وَعَبْدُ الرَّحْمَنِ بْنُ أُمِّ الْحَكَمِ يَخْطُبُ قَاعِدًا فَقَالَ انْظُرُوا إِلَى هَذَا يَخْطُبُ قَاعِدًا وَقَدْ قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَإِذَا رَأَوْا تِجَارَةً أَوْ لَهْوًا انْفَضُّوا إِلَيْهَا وَتَرَكُوكَ قَائِمًا ‏\}‏ ‏.‏\hadithno{1397}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ka'b bin 'Ujrah said that:He entered the masjid and 'Abdur-Rahman bin Umm Al-Hakam was delivering the Khutbah while seated. "He said: 'Look at this man who is delivering the khutbah while seated when Allah (SWT) says: And when they see some merchandise or some amusement they disperse headlong to it, and leave you standing}}
\hadithdefcmd{nasai}{1398}{أَخْبَرَنَا مَحْمُودُ بْنُ خَالِدٍ، قَالَ حَدَّثَنِي عُمَرُ بْنُ عَبْدِ الْوَاحِدِ، قَالَ سَمِعْتُ يَحْيَى بْنَ الْحَارِثِ، يُحَدِّثُ عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، عَنْ أَوْسِ بْنِ أَوْسٍ الثَّقَفِيِّ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ غَسَّلَ وَاغْتَسَلَ وَابْتَكَرَ وَغَدَا وَدَنَا مِنَ الإِمَامِ وَأَنْصَتَ ثُمَّ لَمْ يَلْغُ كَانَ لَهُ بِكُلِّ خُطْوَةٍ كَأَجْرِ سَنَةٍ صِيَامِهَا وَقِيَامِهَا ‏"‏ ‏.‏\hadithno{1398}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Aws bin Aws Ath-Thaqafi that :The Messenger of Allah (ﷺ) said: "Whoever washes (ghassala) and performs ghusl, and comes early to the masjid and sits near the imam, is attentive and does not engage in idle talk, for every step he takes he will have (the reward of) a year's worth of good deeds, its fasting and Qiyam prayer}}
\hadithdefcmd{nasai}{1399}{أَخْبَرَنَا وَهْبُ بْنُ بَيَانٍ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ سَمِعْتُ مُعَاوِيَةَ بْنَ صَالِحٍ، عَنْ أَبِي الزَّاهِرِيَّةِ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ، قَالَ كُنْتُ جَالِسًا إِلَى جَانِبِهِ يَوْمَ الْجُمُعَةِ فَقَالَ جَاءَ رَجُلٌ يَتَخَطَّى رِقَابَ النَّاسِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَىِ اجْلِسْ فَقَدْ آذَيْتَ ‏"‏ ‏.‏\hadithno{1399}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Az-Zahiriyah about 'Abdullah bin Busr, he said:"I was sitting beside him on Friday and he said: 'A man came, stepping over people's necks, and the Messenger of Allah (ﷺ) said: 'Sit down, you are disturbing people}}
\hadithdefcmd{nasai}{1400}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ، وَيُوسُفُ بْنُ سَعِيدٍ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ جَاءَ رَجُلٌ وَالنَّبِيُّ صلى الله عليه وسلم عَلَى الْمِنْبَرِ يَوْمَ الْجُمُعَةِ فَقَالَ لَهُ ‏"‏ أَرَكَعْتَ رَكْعَتَيْنِ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَارْكَعْ ‏"‏ ‏.‏\hadithno{1400}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Amr bin Dinar narrated that:He heard Jabir bin 'Abdullah say: "A man came when the Prophet (ﷺ) was on the minbar on a Friday. He said to him: 'Have you prayed two rak'ahs?' He said: 'No.' He said: 'Pray}}
\hadithdefcmd{nasai}{1401}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ لِصَاحِبِهِ يَوْمَ الْجُمُعَةِ وَالإِمَامُ يَخْطُبُ أَنْصِتْ فَقَدْ لَغَا ‏"‏ ‏.‏\hadithno{1401}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) said: "Whoever says to his companion on Friday, when the imam is delivering the khutbah: 'Listen attentively,' has engaged in idle talk}}
\hadithdefcmd{nasai}{1402}{أَخْبَرَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ بْنِ سَعْدٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ عَبْدِ اللَّهِ بْنِ إِبْرَاهِيمَ بْنِ قَارِظٍ، وَعَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُمَا حَدَّثَاهُ أَنَّ أَبَا هُرَيْرَةَ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا قُلْتَ لِصَاحِبِكَ أَنْصِتْ يَوْمَ الْجُمُعَةِ وَالإِمَامُ يَخْطُبُ فَقَدْ لَغَوْتَ ‏"‏ ‏.‏\hadithno{1402}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin Ibrahim bin Qariz and Sa'eed bin Al-Musayyab that:Abu Hurairah said: "I heard the Messenger of Allah (ﷺ) say: 'If you say to your companion: Listen attentively on a Friday when the Imam is delivering the khutbah, then you have engaged in idle talk}}
\hadithdefcmd{nasai}{1403}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي مَعْشَرٍ، زِيَادِ بْنِ كُلَيْبٍ عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنِ الْقَرْثَعِ الضَّبِّيِّ، - وَكَانَ مِنَ الْقُرَّاءِ الأَوَّلِينَ - عَنْ سَلْمَانَ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ رَجُلٍ يَتَطَهَّرُ يَوْمَ الْجُمُعَةِ كَمَا أُمِرَ ثُمَّ يَخْرُجُ مِنْ بَيْتِهِ حَتَّى يَأْتِيَ الْجُمُعَةَ وَيُنْصِتُ حَتَّى يَقْضِيَ صَلاَتَهُ إِلاَّ كَانَ كَفَّارَةً لِمَا قَبْلَهُ مِنَ الْجُمُعَةِ ‏"‏ ‏.‏\hadithno{1403}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Salman said:"The Messenger of Allah (ﷺ) said to me: 'There is no man who purifies himself on Friday as he is commanded, then comes out of his house to the Friday prayer, and listens attentively until he finishes his prayer, but it will be an expiation for what came before it the week before}}
\hadithdefcmd{nasai}{1404}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ أَبَا إِسْحَاقَ، يُحَدِّثُ عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ عَلَّمَنَا خُطْبَةَ الْحَاجَةِ الْحَمْدُ لِلَّهِ نَسْتَعِينُهُ وَنَسْتَغْفِرُهُ وَنَعُوذُ بِاللَّهِ مِنْ شُرُورِ أَنْفُسِنَا وَسَيِّئَاتِ أَعْمَالِنَا مَنْ يَهْدِهِ اللَّهُ فَلاَ مُضِلَّ لَهُ وَمَنْ يُضْلِلْ فَلاَ هَادِيَ لَهُ وَأَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ثُمَّ يَقْرَأُ ثَلاَثَ آيَاتٍ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا اتَّقُوا اللَّهَ حَقَّ تُقَاتِهِ وَلاَ تَمُوتُنَّ إِلاَّ وَأَنْتُمْ مُسْلِمُونَ ‏\}‏ ‏\{‏ يَا أَيُّهَا النَّاسُ اتَّقُوا رَبَّكُمُ الَّذِي خَلَقَكُمْ مِنْ نَفْسٍ وَاحِدَةٍ وَخَلَقَ مِنْهَا زَوْجَهَا وَبَثَّ مِنْهُمَا رِجَالاً كَثِيرًا وَنِسَاءً وَاتَّقُوا اللَّهَ الَّذِي تَسَاءَلُونَ بِهِ وَالأَرْحَامَ إِنَّ اللَّهَ كَانَ عَلَيْكُمْ رَقِيبًا ‏\}‏ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا اتَّقُوا اللَّهَ وَقُولُوا قَوْلاً سَدِيدًا ‏\}‏ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ أَبُو عُبَيْدَةَ لَمْ يَسْمَعْ مِنْ أَبِيهِ شَيْئًا وَلاَ عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَلاَ عَبْدُ الْجَبَّارِ بْنُ وَائِلِ بْنِ حُجْرٍ ‏.‏\hadithno{1404}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah:"The Prophet (ﷺ) taught us Khutbat Al-Hajah: Alhamduu lillahi nasta'inuhu wa nastagfiruhu, wa na'udhu billahi min shururi anfusina wa sayi'ati a'malina. Man yahdihillahu fala mudilla lahu wa man yudlil fala hadiya lahu. Wa ashhadu an la ilaha illallahu wa ashhadu anna Muhammadan 'abduhu wa rasuluhu. (Praise be to Allah, we seek His help and His forgiveness. We seek refuge in Allah from the evil of our own souls and from our bad deeds. Whomsoever Allah guides will never be led astray,and whomsoever Allah leaves astray, no one can guide. I bear witness that there is none worthy of worship except Allah, and I bear witness that Muhammad is His slave and Messenger.) Then he recited the following three verses: O you who believe! Fear Allah as He should be feared, and die not except as Muslims; O Mankind! Be dutiful to your Lord, Who created you from a single person, and from him he created his wife, and from them he created many men and women, and fear Allah through Whom you demand your mutual (rights), and (do not cut the relations of) the wombs (kinship). Surely, Allah is Ever an All-Watcher over you); O you who believe! Keep your duty to Allah and fear Him, and speak (always) the truth}}
\hadithdefcmd{nasai}{1405}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِذَا رَاحَ أَحَدُكُمْ إِلَى الْجُمُعَةِ فَلْيَغْتَسِلْ ‏"‏ ‏.‏\hadithno{1405}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah (ﷺ) delivered a khutbah and said: 'When any one of you wants to go to Jumu'ah, let him perform ghusl}}
\hadithdefcmd{nasai}{1406}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ إِبْرَاهِيمَ بْنِ نَشِيطٍ، أَنَّهُ سَأَلَ ابْنَ شِهَابٍ عَنِ الْغُسْلِ، يَوْمَ الْجُمُعَةِ فَقَالَ سُنَّةٌ وَقَدْ حَدَّثَنِي بِهِ، سَالِمُ بْنُ عَبْدِ اللَّهِ عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَكَلَّمَ بِهَا عَلَى الْمِنْبَرِ ‏.‏\hadithno{1406}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibrahim bin Nashit that:He asked Ibn Shihab about ghusl on Friday. He said: "It is a sunnah; Salim bin 'Abdullah told me, narrating from his father, that the Messenger of Allah (ﷺ) spoke about it from the minbar}}
\hadithdefcmd{nasai}{1407}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ وَهُوَ قَائِمٌ عَلَى الْمِنْبَرِ ‏ "‏ مَنْ جَاءَ مِنْكُمُ الْجُمُعَةَ فَلْيَغْتَسِلْ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ مَا أَعْلَمُ أَحَدًا تَابَعَ اللَّيْثَ عَلَى هَذَا الإِسْنَادِ غَيْرَ ابْنِ جُرَيْجٍ وَأَصْحَابُ الزُّهْرِيِّ يَقُولُونَ عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ عَنْ أَبِيهِ بَدَلَ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ ‏.‏\hadithno{1407}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin 'Abdullah (from 'Abdullah) Ibn 'Umar that:While he was standing on the minbar, the Messenger of Allah (ﷺ) said: "Whoever among you comes (to prayer) on a Friday, let him perform ghusl}}
\hadithdefcmd{nasai}{1408}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ جَاءَ رَجُلٌ يَوْمَ الْجُمُعَةِ وَالنَّبِيُّ صلى الله عليه وسلم يَخْطُبُ بِهَيْئَةٍ بَذَّةٍ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَصَلَّيْتَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ صَلِّ رَكْعَتَيْنِ ‏"‏ ‏.‏ وَحَثَّ النَّاسَ عَلَى الصَّدَقَةِ فَأَلْقُوا ثِيَابًا فَأَعْطَاهُ مِنْهَا ثَوْبَيْنِ فَلَمَّا كَانَتِ الْجُمُعَةُ الثَّانِيَةُ جَاءَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ فَحَثَّ النَّاسَ عَلَى الصَّدَقَةِ - قَالَ - فَأَلْقَى أَحَدَ ثَوْبَيْهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ جَاءَ هَذَا يَوْمَ الْجُمُعَةِ بِهَيْئَةٍ بَذَّةٍ فَأَمَرْتُ النَّاسَ بِالصَّدَقَةِ فَأَلْقَوا ثِيَابًا فَأَمَرْتُ لَهُ مِنْهَا بِثَوْبَيْنِ ثُمَّ جَاءَ الآنَ فَأَمَرْتُ النَّاسَ بِالصَّدَقَةِ فَأَلْقَى أَحَدَهُمَا ‏"‏ ‏.‏ فَانَتْهَرَهُ وَقَالَ ‏"‏ خُذْ ثَوْبَكَ ‏"‏ ‏.‏\hadithno{1408}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Iyad bin 'Abdullah said:"I heard Abu Sa'eed Al-Khudri say: 'A man who appeared shabbily came on a Friday, while the Prophet (ﷺ) was delivering the Khutbah. The Messenger of Allah (ﷺ) said to him: 'Have you prayed?" He said: 'No." He said: 'Pray two rak'ahs.' And he urged the people to give in charity. They gave clothes, and he gave him two garments. The following Friday, he came when the Messenger of Allah (ﷺ) was delivering the khutbah, and he urged the people to give charity. (That man) gave one of his two garments and the Messenger of Allah (ﷺ) said: 'This man came last Friday looking shabby, and I commanded the people to give charity and they gave clothes, and I said that he should be given two garments, and now he came and I commanded the people to give charity and he gave one of them. So he chided him and said: Take your garment}}
\hadithdefcmd{nasai}{1409}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ بَيْنَا النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ يَوْمَ الْجُمُعَةِ إِذْ جَاءَ رَجُلٌ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ صَلَّيْتَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ قُمْ فَارْكَعْ ‏"‏ ‏.‏\hadithno{1409}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah who said:"While the Prophet (ﷺ) was delivering the khutbah on Friday, a man came and the Prophet (ﷺ) said: 'Have you prayed?' He said: 'No.' He said: Stand up and pray}}
\hadithdefcmd{nasai}{1410}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا أَبُو مُوسَى، إِسْرَائِيلُ بْنُ مُوسَى قَالَ سَمِعْتُ الْحَسَنَ، يَقُولُ سَمِعْتُ أَبَا بَكْرَةَ، يَقُولُ لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ وَالْحَسَنُ مَعَهُ وَهُوَ يُقْبِلُ عَلَى النَّاسِ مَرَّةً وَعَلَيْهِ مَرَّةً وَيَقُولُ ‏ "‏ إِنَّ ابْنِي هَذَا سَيِّدٌ وَلَعَلَّ اللَّهَ أَنْ يُصْلِحَ بِهِ بَيْنَ فِئَتَيْنِ مِنَ الْمُسْلِمِينَ عَظِيمَتَيْنِ ‏"‏ ‏.‏\hadithno{1410}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Bakrah said:"I saw the Messenger of Allah (ﷺ) on the Minbar, and Al-Hasan was with him. He would turn to the people sometimes and turn to him (Al-Hasan) sometimes, and he said: 'This son of mine is a leader (Sayyid) and Allah may make peace between two large groups of Muslims through him}}
\hadithdefcmd{nasai}{1411}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا هَارُونُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا عَلِيٌّ، - وَهُوَ ابْنُ الْمُبَارَكِ - عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنِ ابْنَةِ حَارِثَةَ بْنِ النُّعْمَانِ، قَالَتْ حَفِظْتُ ‏\{‏ ق وَالْقُرْآنِ الْمَجِيدِ ‏\}‏ مِنْ فِي رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى الْمِنْبَرِ يَوْمَ الْجُمُعَةِ ‏.‏\hadithno{1411}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Muhammad bin 'Abdur-Rahman that:The daughter of Harithah bin An-Nu'man said: "I memorized 'Qaf. By the Glorious Qur'an,'" from the mouth of the Messenger of Allah (ﷺ) when he was on the minbar on Friday}}
\hadithdefcmd{nasai}{1412}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ حُصَيْنٍ، أَنَّ بِشْرَ بْنَ مَرْوَانَ، رَفَعَ يَدَيْهِ يَوْمَ الْجُمُعَةِ عَلَى الْمِنْبَرِ فَسَبَّهُ عُمَارَةُ بْنُ رُوَيْبَةَ الثَّقَفِيُّ وَقَالَ مَا زَادَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى هَذَا وَأَشَارَ بِأُصْبُعِهِ السَّبَّابَةِ ‏.‏\hadithno{1412}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Sufyan bin Husain that :Bishr bin Marwan raised his hands on Friday on the minbar, and 'Umarah bin Ruwaibah condemned him and said: "The Messenger of Allah (ﷺ) did no more than this,' and he pointed with his forefinger}}
\hadithdefcmd{nasai}{1413}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ حُسَيْنِ بْنِ وَاقِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ فَجَاءَ الْحَسَنُ وَالْحُسَيْنُ - رضى الله عنهما - وَعَلَيْهِمَا قَمِيصَانِ أَحْمَرَانِ يَعْثُرَانِ فِيهِمَا فَنَزَلَ النَّبِيُّ صلى الله عليه وسلم فَقَطَعَ كَلاَمَهُ فَحَمَلَهُمَا ثُمَّ عَادَ إِلَى الْمِنْبَرِ ثُمَّ قَالَ ‏"‏ صَدَقَ اللَّهُ ‏\{‏ إِنَّمَا أَمْوَالُكُمْ وَأَوْلاَدُكُمْ فِتْنَةٌ ‏\}‏ رَأَيْتُ هَذَيْنِ يَعْثُرَانِ فِي قَمِيصَيْهِمَا فَلَمْ أَصْبِرْ حَتَّى قَطَعْتُ كَلاَمِي فَحَمَلْتُهُمَا ‏"‏ ‏.‏\hadithno{1413}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin Buraidah that his father said:"The Prophet (ﷺ) was preaching, then Al-Hasan and Al-Husain came, wearing red shirts and stumbling in them. The Prophet (ﷺ) came down, interrupting himself, and picked them up, then he went back to the minbar and said: 'Allah has spoken the truth: Your wealth and your children are only a trial (At-Taghabun 64:15). I saw these two stumbling in their shirts and I could not continue until I had interrupted myself and picked them up}}
\hadithdefcmd{nasai}{1414}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ بْنِ غَزْوَانَ، قَالَ أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الْحُسَيْنِ بْنِ وَاقِدٍ، قَالَ حَدَّثَنِي يَحْيَى بْنُ عُقَيْلٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكْثِرُ الذِّكْرَ وَيُقِلُّ اللَّغْوَ وَيُطِيلُ الصَّلاَةَ وَيُقَصِّرُ الْخُطْبَةَ وَلاَ يَأْنَفُ أَنْ يَمْشِيَ مَعَ الأَرْمَلَةِ وَالْمِسْكِينِ فَيَقْضِيَ لَهُ الْحَاجَةَ ‏.‏\hadithno{1414}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Abi Awfa said:"The Messenger of Allah (ﷺ) used to recite a great deal of remembrance, engage little in idle talk, make the prayer long and keep the khutbah short, and he would not refrain from walking with a widow or poor person and tending to their needs}}
\hadithdefcmd{nasai}{1415}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ جَالَسْتُ النَّبِيَّ صلى الله عليه وسلم فَمَا رَأَيْتُهُ يَخْطُبُ إِلاَّ قَائِمًا وَيَجْلِسُ ثُمَّ يَقُومُ فَيَخْطُبُ الْخُطْبَةَ الآخِرَةَ ‏.‏\hadithno{1415}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin Samurah said:"I sat with the Prophet (ﷺ) and I did not see him deliver the khutbah except standing, and he sat, then he stood up and delivered the second khutbah}}
\hadithdefcmd{nasai}{1416}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَخْطُبُ الْخُطْبَتَيْنِ وَهُوَ قَائِمٌ وَكَانَ يَفْصِلُ بَيْنَهُمَا بِجُلُوسٍ ‏.‏\hadithno{1416}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah that:The Messenger of Allah (ﷺ) used to deliver two khutbahs standing, and he would separate them by sitting}}
\hadithdefcmd{nasai}{1417}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - قَالَ حَدَّثَنَا إِسْرَائِيلُ، قَالَ حَدَّثَنَا سِمَاكٌ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَخْطُبُ يَوْمَ الْجُمُعَةِ قَائِمًا ثُمَّ يَقْعُدُ قِعْدَةً لاَ يَتَكَلَّمُ ثُمَّ يَقُومُ فَيَخْطُبُ خُطْبَةً أُخْرَى فَمَنْ حَدَّثَكُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَخْطُبُ قَاعِدًا فَقَدْ كَذَبَ ‏.‏\hadithno{1417}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir bin Samurah said:"I saw the Messenger of Allah (ﷺ) delivering the khutbah on Friday standing, then he sat briefly and did not speak, then he stood up and delivered a second khutbah. So whoever tells you that the Messenger of Allah (ﷺ) used to deliver the khutbah seated, he has lied}}
\hadithdefcmd{nasai}{1418}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ قَائِمًا ثُمَّ يَجْلِسُ ثُمَّ يَقُومُ وَيَقْرَأُ آيَاتٍ وَيَذْكُرُ اللَّهَ عَزَّ وَجَلَّ وَكَانَتْ خُطْبَتُهُ قَصْدًا وَصَلاَتُهُ قَصْدًا ‏.‏\hadithno{1418}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir bin Samurah said:"The Prophet (ﷺ) used to deliver the khutbah standing, then he would sit, then he would stand up and recite some Verses and remember Allah, the Mighty and Sublime. His khutbah was moderate in length and his prayer was moderate in length}}
\hadithdefcmd{nasai}{1419}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَلِيِّ بْنِ مَيْمُونٍ، قَالَ حَدَّثَنَا الْفِرْيَابِيُّ، قَالَ حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْزِلُ عَنِ الْمِنْبَرِ فَيَعْرِضُ لَهُ الرَّجُلُ فَيُكَلِّمُهُ فَيَقُومُ مَعَهُ النَّبِيُّ صلى الله عليه وسلم حَتَّى يَقْضِيَ حَاجَتَهُ ثُمَّ يَتَقَدَّمُ إِلَى مُصَلاَّهُ فَيُصَلِّي ‏.‏\hadithno{1419}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah (ﷺ) would come down from the minbar and a man would come to him and speak to him, then the Prophet (ﷺ) would listen to him until he gave him an answer, then he would go to his place of prayer and pray}}
\hadithdefcmd{nasai}{1420}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ زُبَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، قَالَ قَالَ عُمَرُ صَلاَةُ الْجُمُعَةِ رَكْعَتَانِ وَصَلاَةُ الْفِطْرِ رَكْعَتَانِ وَصَلاَةُ الأَضْحَى رَكْعَتَانِ وَصَلاَةُ السَّفَرِ رَكْعَتَانِ تَمَامٌ غَيْرُ قَصْرٍ عَلَى لِسَانِ مُحَمَّدٍ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ عَبْدُ الرَّحْمَنِ بْنُ أَبِي لَيْلَى لَمْ يَسْمَعْ مِنْ عُمَرَ ‏.‏\hadithno{1420}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdur-Rahman bin Abi Laila that 'Umar said:"Jumu'ah prayer is two rak'ahs, and the prayer of Al-Fitr is two rak'ahs, and the prayer of Al-Adha is two rak'ahs, and the prayer when traveling is two rak'ahs, complete and not shortened, on the tongue of Muhammad (ﷺ)}}
\hadithdefcmd{nasai}{1421}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي مُخَوَّلٌ، قَالَ سَمِعْتُ مُسْلِمًا الْبَطِينَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقْرَأُ يَوْمَ الْجُمُعَةِ فِي صَلاَةِ الصُّبْحِ ‏\{‏ الم * تَنْزِيلُ ‏\}‏ وَ‏\{‏ هَلْ أَتَى عَلَى الإِنْسَانِ ‏\}‏ وَفِي صَلاَةِ الْجُمُعَةِ بِسُورَةِ الْجُمُعَةِ وَالْمُنَافِقِينَ ‏.‏\hadithno{1421}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Abbas that :During the Subh prayer on Friday, the Messenger of Allah (ﷺ) used to recite: "Alif-Lam-Mim. The Revelation"(As-Sajdah 32) and: "Has there not been over man,"(Al-Insan 76) and in Jumu'ah prayer he would recite Al-Jumu'ah (62) and Al-Munafiqin}}
\hadithdefcmd{nasai}{1422}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، قَالَ أَخْبَرَنِي مَعْبَدُ بْنُ خَالِدٍ، عَنْ زَيْدِ بْنِ عُقْبَةَ، عَنْ سَمُرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي صَلاَةِ الْجُمُعَةِ بِـ ‏\{‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏\}‏ وَ\{‏ هَلْ أَتَاكَ حَدِيثُ الْغَاشِيَةِ ‏\}‏ ‏.‏\hadithno{1422}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Samurah said:"The Messenger of Allah (ﷺ) used to recite in Jumu'ah prayer: 'Glorify the Name of your Lord, the Most High'(Al-A'la 87) and: 'Has there come to you the narration of the overwhelming (i.e. the Day of Resurrection)?"(Al-Ghashiyah)}}
\hadithdefcmd{nasai}{1423}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ ضَمْرَةَ بْنِ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، أَنَّ الضَّحَّاكَ بْنَ قَيْسٍ، سَأَلَ النُّعْمَانَ بْنَ بَشِيرٍ مَاذَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ يَوْمَ الْجُمُعَةِ عَلَى إِثْرِ سُورَةِ الْجُمُعَةِ قَالَ كَانَ يَقْرَأُ ‏\{‏ هَلْ أَتَاكَ حَدِيثُ الْغَاشِيَةِ ‏\}‏ ‏.‏\hadithno{1423}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ad-Dahhak bin Qais asked An-Nu'man bin Bashir:"What did the Messenger of Allah (ﷺ) use to recite on Friday after Surat Al-Jumu'ah?" He said: "He used to recite: 'Has there come to you the narration of the overwhelming (i.e. the Day of Resurrection)?'" (Al-Ghashiyah)}}
\hadithdefcmd{nasai}{1424}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، أَنَّ إِبْرَاهِيمَ بْنَ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، أَخْبَرَهُ قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ حَبِيبِ بْنِ سَالِمٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي الْجُمُعَةِ بِـ ‏\{‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏\}‏ وَ‏\{‏ هَلْ أَتَاكَ حَدِيثُ الْغَاشِيَةِ ‏\}‏ وَرُبَّمَا اجْتَمَعَ الْعِيدُ وَالْجُمُعَةُ فَيَقْرَأُ بِهِمَا فِيهِمَا جَمِيعًا ‏.‏\hadithno{1424}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that An-Nu'man bin Bashir said:"The Messenger of Allah (ﷺ) used to recite 'Glorify the name of your Lord, the Most High'(Al-A'la 87) and 'Has there come to you the narration of the overwhelming (i.e. the Day of Resurrection)?' (Al-Ghashiyah 88) in the Jumu'ah prayer, and sometimes 'Eid and Jumu'ah would fall on the same day, and he would recite them in both 'Eid and Jumu'ah prayer}}
\hadithdefcmd{nasai}{1425}{أَخْبَرَنَا قُتَيْبَةُ، وَمُحَمَّدُ بْنُ مَنْصُورٍ، - وَاللَّفْظُ لَهُ - عَنْ سُفْيَانَ، عَنِ الْزُّهْرِيِّ عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ مِنْ صَلاَةِ الْجُمُعَةِ رَكْعَةً فَقَدْ أَدْرَكَ ‏"‏ ‏.‏\hadithno{1425}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet (ﷺ) said: "Whoever catches up with a rak'ah of Jumu'ah prayer has caught up with it}}
\hadithdefcmd{nasai}{1426}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا صَلَّى أَحَدُكُمُ الْجُمُعَةَ فَلْيُصَلِّ بَعْدَهَا أَرْبَعًا ‏"‏ ‏.‏\hadithno{1426}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'When any one of you prays Jumu'ah let him pray four (rak'ahs) after that}}
\hadithdefcmd{nasai}{1427}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ لاَ يُصَلِّي بَعْدَ الْجُمُعَةِ حَتَّى يَنْصَرِفَ فَيُصَلِّيَ رَكْعَتَيْنِ ‏.‏\hadithno{1427}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah (ﷺ) would not pray after Jumu'ah until he had left, then he would pray two rak'ahs. (Sahih)}}
\hadithdefcmd{nasai}{1428}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بَعْدَ الْجُمُعَةِ رَكْعَتَيْنِ فِي بَيْتِهِ ‏.‏\hadithno{1428}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Salim that his father said:"The Messenger of Allah (ﷺ) used to pray two rak'ahs in his house after Jumu'ah}}
\hadithdefcmd{nasai}{1429}{أَخْبَرَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، عَنْ يَزِيدَ، - وَهُوَ ابْنُ هَارُونَ - قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَانَ يُصَلِّي بَعْدَ الْجُمُعَةِ رَكْعَتَيْنِ يُطِيلُ فِيهِمَا وَيَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَفْعَلُهُ ‏.‏\hadithno{1429}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that he used to pray two rak'ahs after Jumu'ah, making them lengthy, and he said:"The Messenger of Allah (ﷺ) used to do this}}
\hadithdefcmd{nasai}{1430}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا بَكْرٌ، - يَعْنِي ابْنَ مُضَرَ - عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَتَيْتُ الطُّورَ فَوَجَدْتُ ثَمَّ كَعْبًا فَمَكَثْتُ أَنَا وَهُوَ يَوْمًا أُحَدِّثُهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَيُحَدِّثُنِي عَنِ التَّوْرَاةِ فَقُلْتُ لَهُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَيْرُ يَوْمٍ طَلَعَتْ فِيهِ الشَّمْسُ يَوْمُ الْجُمُعَةِ فِيهِ خُلِقَ آدَمُ وَفِيهِ أُهْبِطَ وَفِيهِ تِيبَ عَلَيْهِ وَفِيهِ قُبِضَ وَفِيهِ تَقُومُ السَّاعَةُ مَا عَلَى الأَرْضِ مِنْ دَابَّةٍ إِلاَّ وَهِيَ تُصْبِحُ يَوْمَ الْجُمُعَةِ مُصِيخَةً حَتَّى تَطْلُعَ الشَّمْسُ شَفَقًا مِنَ السَّاعَةِ إِلاَّ ابْنَ آدَمَ وَفِيهِ سَاعَةٌ لاَ يُصَادِفُهَا مُؤْمِنٌ وَهُوَ فِي الصَّلاَةِ يَسْأَلُ اللَّهَ فِيهَا شَيْئًا إِلاَّ أَعْطَاهُ إِيَّاهُ ‏"‏ ‏.‏ فَقَالَ كَعْبٌ ذَلِكَ يَوْمٌ فِي كُلِّ سَنَةٍ ‏.‏ فَقُلْتُ بَلْ هِيَ فِي كُلِّ جُمُعَةٍ ‏.‏ فَقَرَأَ كَعْبٌ التَّوْرَاةَ ثُمَّ قَالَ صَدَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم هُوَ فِي كُلِّ جُمُعَةٍ ‏.‏ فَخَرَجْتُ فَلَقِيتُ بَصْرَةَ بْنَ أَبِي بَصْرَةَ الْغِفَارِيَّ فَقَالَ مِنْ أَيْنَ جِئْتَ قُلْتُ مِنَ الطُّورِ ‏.‏ قَالَ لَوْ لَقِيتُكَ مِنْ قَبْلِ أَنْ تَأْتِيَهُ لَمْ تَأْتِهِ ‏.‏ قُلْتُ لَهُ وَلِمَ قَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ تُعْمَلُ الْمَطِيُّ إِلاَّ إِلَى ثَلاَثَةِ مَسَاجِدَ الْمَسْجِدِ الْحَرَامِ وَمَسْجِدِي وَمَسْجِدِ بَيْتِ الْمَقْدِسِ ‏"‏ ‏.‏ فَلَقِيتُ عَبْدَ اللَّهِ بْنَ سَلاَمٍ فَقُلْتُ لَوْ رَأَيْتَنِي خَرَجْتُ إِلَى الطُّورِ فَلَقِيتُ كَعْبًا فَمَكَثْتُ أَنَا وَهُوَ يَوْمًا أُحَدِّثُهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَيُحَدِّثُنِي عَنِ التَّوْرَاةِ فَقُلْتُ لَهُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَيْرُ يَوْمٍ طَلَعَتْ فِيهِ الشَّمْسُ يَوْمُ الْجُمُعَةِ فِيهِ خُلِقَ آدَمُ وَفِيهِ أُهْبِطَ وَفِيهِ تِيبَ عَلَيْهِ وَفِيهِ قُبِضَ وَفِيهِ تَقُومُ السَّاعَةُ مَا عَلَى الأَرْضِ مِنْ دَابَّةٍ إِلاَّ وَهِيَ تُصْبِحُ يَوْمَ الْجُمُعَةِ مُصِيخَةً حَتَّى تَطْلُعَ الشَّمْسُ شَفَقًا مِنَ السَّاعَةِ إِلاَّ ابْنَ آدَمَ وَفِيهِ سَاعَةٌ لاَ يُصَادِفُهَا عَبْدٌ مُؤْمِنٌ وَهُوَ فِي الصَّلاَةِ يَسْأَلُ اللَّهَ شَيْئًا إِلاَّ أَعْطَاهُ إِيَّاهُ ‏"‏ ‏.‏ قَالَ كَعْبٌ ذَلِكَ يَوْمٌ فِي كُلِّ سَنَةٍ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ كَذَبَ كَعْبٌ ‏.‏ قُلْتُ ثُمَّ قَرَأَ كَعْبٌ فَقَالَ صَدَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم هُوَ فِي كُلِّ جُمُعَةٍ ‏.‏ فَقَالَ عَبْدُ اللَّهِ صَدَقَ كَعْبٌ إِنِّي لأَعْلَمُ تِلْكَ السَّاعَةَ فَقُلْتُ يَا أَخِي حَدِّثْنِي بِهَا ‏.‏ قَالَ هِيَ آخِرُ سَاعَةٍ مِنْ يَوْمِ الْجُمُعَةِ قَبْلَ أَنْ تَغِيبَ الشَّمْسُ فَقُلْتُ أَلَيْسَ قَدْ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يُصَادِفُهَا مُؤْمِنٌ وَهُوَ فِي الصَّلاَةِ ‏"‏ ‏.‏ وَلَيْسَتْ تِلْكَ السَّاعَةَ صَلاَةٌ قَالَ أَلَيْسَ قَدْ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ صَلَّى وَجَلَسَ يَنْتَظِرُ الصَّلاَةَ لَمْ يَزَلْ فِي صَلاَتِهِ حَتَّى تَأْتِيَهُ الصَّلاَةُ الَّتِي تُلاَقِيهَا ‏"‏ ‏.‏ قُلْتُ بَلَى ‏.‏ قَالَ فَهُوَ كَذَلِكَ ‏.‏\hadithno{1430}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"I went out to At-Tur and met Ka'b. He and I spent a day together, when I narrated things to him from the Messenger of Allah (ﷺ) and he narrated things to me from the Tawrah. I said to him: The Messenger of Allah (ﷺ) said: The best day on which the sun rises is Friday. On this day, Adam was created, on this day he was sent down, on it his repentance was accepted, on this day he died, and on this day the Hour will begin. There is no living creature on Earth that does not listen out from Friday morning until the sun rises, fearing the onset of the Hour, except the son of Adam. On (Friday) there is an hour in which, if a believer prays and asks Allah for something, He will give it to him. Ka'b said: Is that one day in every year? I said: No, it is every Friday.' Then Ka'b read in the Tawrah and said: The Messenger of Allah (ﷺ) spoke the truth; it is every Friday. Then I went out and met Basrah bin Abi Basrah Al-Ghifari. He said: From where have you come? I said: From At-Tur. He said: If I had met you before you went there, you would not have gone. I said to him: Why? He said: I heard the Messenger of Allah (ﷺ) say: Do not travel especially to visit any masjid except three: Al Masjid Al-Haram (in Makkah), my masjid (in Al-Madinah) and the Masjid of Bait Al-Maqdis (in Jerusalem). Then I met 'Abdullah bin Salam and said: 'If you had only seen me, I went to At-Tur and met Ka'b, and he and I spent the day together, when I narrated things to him from the Messenger of Allah (ﷺ) and he narrated things to me from the Tawrah. I said to him: The Messenger of Allah (ﷺ) said: The best day on which the sun rises is Friday. On this day, Adam was created, on this day he was sent down, on this day his repentance was accepted, on this day he died, and on this day the Hour will begin. There is no living creature on Earth that does not listen out from Friday morning until the sun rises, fearing the onset of the Hour, except the son of Adam. On (Friday) there is an hour in which, if a believer prays and asks Allah for something, He will give it to him. Ka'b said: That is one day in every year. 'Abdullah bin Salam said: Ka'b is not telling the truth. I said: Then Ka'b read (in the Tawrah) and said: The Messenger of Allah (ﷺ) spoke the truth; it is every Friday. 'Abdullah said: Ka'b spoke the truth; I know when that time is. I said: O my brother, tell me about it. He said: It is the last hour of Friday, before the sun sets. I said: Did you not hear the Messenger of Allah (ﷺ) say: If a believer prays, but that is not a time for prayer. He said: Did you not hear the Messenger of Allah (ﷺ) say: Whoever prays and sits waiting for the (next) prayer, is in a state of prayer until the next prayer comes? I said: Of course. He said: That is what it is}}
\hadithdefcmd{nasai}{1431}{أَخْبَرَنِي مُحَمَّدُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ خَالِدٍ، عَنْ رَبَاحٍ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سَعِيدٌ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ فِي الْجُمُعَةِ سَاعَةً لاَ يُوَافِقُهَا عَبْدٌ مُسْلِمٌ يَسْأَلُ اللَّهَ فِيهَا شَيْئًا إِلاَّ أَعْطَاهُ إِيَّاهُ ‏"‏ ‏.‏\hadithno{1431}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) said: "On Friday, there is an hour when, if a Muslim slave asks Allah for something at that time, He will give it to him}}
\hadithdefcmd{nasai}{1432}{أَخْبَرَنَا عَمْرُو بْنُ زُرَارَةَ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ عَنْ مُحَمَّدٍ ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ إِنَّ فِي الْجُمُعَةِ سَاعَةً لاَ يُوَافِقُهَا عَبْدٌ مُسْلِمٌ قَائِمٌ يُصَلِّي يَسْأَلُ اللَّهَ عَزَّ وَجَلَّ شَيْئًا إِلاَّ أَعْطَاهُ إِيَّاهُ ‏"‏ ‏.‏ قُلْنَا يُقَلِّلُهَا يُزَهِّدُهَا ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ لاَ نَعْلَمُ أَحَدًا حَدَّثَ بِهَذَا الْحَدِيثِ غَيْرَ رَبَاحٍ عَنْ مَعْمَرٍ عَنِ الزُّهْرِيِّ إِلاَّ أَيُّوبَ بْنَ سُوَيْدٍ فَإِنَّهُ حَدَّثَ بِهِ عَنْ يُونُسَ عَنِ الزُّهْرِيِّ عَنْ سَعِيدٍ وَأَبِي سَلَمَةَ وَأَيُّوبُ بْنُ سُوَيْدٍ مَتْرُوكُ الْحَدِيثِ ‏.‏\hadithno{1432}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"Abu Al-Qasim (ﷺ) said: 'On Friday, there is an hour when, if a Muslim slave stands in prayer and asks Allah for something at that time, He will give it to him.'" He was reducing it: lessening it}}
