% Auto-generated chapter 20 for bukhari
% Hadiths in this chapter: 9

\hadithdefcmd{bukhari}{1188}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ، عَنْ قَزَعَةَ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ ـ رضى الله عنه ـ أَرْبَعًا قَالَ سَمِعْتُ مِنَ النَّبِيِّ، صلى الله عليه وسلم وَكَانَ غَزَا مَعَ النَّبِيِّ صلى الله عليه وسلم ثِنْتَىْ عَشْرَةَ غَزْوَةً ح‏.‏\hadithno{1188}\hadithtrans{Narrated Quza'a: I heard Abu Said saying four words. He said, "I heard the Prophet (ﷺ) (saying the following narrative)." He had participated in twelve holy battles with the Prophet}}
\hadithdefcmd{bukhari}{1189}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُشَدُّ الرِّحَالُ إِلاَّ إِلَى ثَلاَثَةِ مَسَاجِدَ الْمَسْجِدِ الْحَرَامِ، وَمَسْجِدِ الرَّسُولِ صلى الله عليه وسلم وَمَسْجِدِ الأَقْصَى ‏"‏‏.‏\hadithno{1189}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Do not set out on a journey except for three Mosques i.e. Al-Masjid-Al-Haram, the Mosque of Allah's Messenger (ﷺ) , and the Mosque of Al-Aqsa, (Mosque of Jerusalem)}}
\hadithdefcmd{bukhari}{1190}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ زَيْدِ بْنِ رَبَاحٍ، وَعُبَيْدِ اللَّهِ بْنِ أَبِي عَبْدِ اللَّهِ الأَغَرِّ، عَنْ أَبِي عَبْدِ اللَّهِ الأَغَرِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةٌ فِي مَسْجِدِي هَذَا خَيْرٌ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ إِلاَّ الْمَسْجِدَ الْحَرَامَ ‏"‏‏.‏\hadithno{1190}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "One prayer in my Mosque is better than one thousand prayers in any other mosque excepting Al-Masjid-Al-Haram}}
\hadithdefcmd{bukhari}{1192}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ ـ هُوَ الدَّوْرَقِيُّ ـ حَدَّثَنَا ابْنُ عُلَيَّةَ، أَخْبَرَنَا أَيُّوبُ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ كَانَ لاَ يُصَلِّي مِنَ الضُّحَى إِلاَّ فِي يَوْمَيْنِ يَوْمَ يَقْدَمُ بِمَكَّةَ، فَإِنَّهُ كَانَ يَقْدَمُهَا ضُحًى، فَيَطُوفُ بِالْبَيْتِ، ثُمَّ يُصَلِّي رَكْعَتَيْنِ خَلْفَ الْمَقَامِ، وَيَوْمَ يَأْتِي مَسْجِدَ قُبَاءٍ، فَإِنَّهُ كَانَ يَأْتِيهِ كُلَّ سَبْتٍ، فَإِذَا دَخَلَ الْمَسْجِدَ كَرِهَ أَنْ يَخْرُجَ مِنْهُ حَتَّى يُصَلِّيَ فِيهِ‏.‏ قَالَ وَكَانَ يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَزُورُهُ رَاكِبًا وَمَاشِيًا‏.‏ قَالَ وَكَانَ يَقُولُ إِنَّمَا أَصْنَعُ كَمَا رَأَيْتُ أَصْحَابِي يَصْنَعُونَ، وَلاَ أَمْنَعُ أَحَدًا أَنْ يُصَلِّيَ فِي أَىِّ سَاعَةٍ شَاءَ مِنْ لَيْلٍ أَوْ نَهَارٍ، غَيْرَ أَنْ لاَ تَتَحَرَّوْا طُلُوعَ الشَّمْسِ وَلاَ غُرُوبَهَا‏.‏\hadithno{1192}\hadithtrans{Narrated Nafi`:Ibn `Umar never offered the Duha prayer except on two occasions: (1) Whenever he reached Mecca; and he always used to reach Mecca in the forenoon. He would perform Tawaf round the Ka`ba and then offer two rak`at at the rear of Maqam Ibrahim. (2) Whenever he visited Quba, for he used to visit it every Saturday. When he entered the Mosque, he disliked to leave it without offering a prayer. Ibn `Umar narrated that Allah's Messenger (ﷺ) used to visit the Mosque of Quba (sometime) walking and (sometime) riding. And he (i.e. Ibn `Umar) used to say, "I do only what my companions used to do and I don't forbid anybody to pray at any time during the day or night except that one should not intend to pray at sunrise or sunset}}
\hadithdefcmd{bukhari}{1193}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَأْتِي مَسْجِدَ قُبَاءٍ كُلَّ سَبْتٍ مَاشِيًا وَرَاكِبًا‏.‏ وَكَانَ عَبْدُ اللَّهِ ـ رضى الله عنهما ـ يَفْعَلُهُ‏.‏\hadithno{1193}\hadithtrans{Narrated `Abdullah bin Dinar:Ibn `Umar said, "The Prophet (ﷺ) used to go to the Mosque of Quba every Saturday (sometimes) walking and (sometimes) riding." `Abdullah (Ibn `Umar) used to do the same}}
\hadithdefcmd{bukhari}{1194}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَأْتِي قُبَاءً رَاكِبًا وَمَاشِيًا‏.‏ زَادَ ابْنُ نُمَيْرٍ حَدَّثَنَا عُبَيْدُ اللَّهِ عَنْ نَافِعٍ فَيُصَلِّي فِيهِ رَكْعَتَيْنِ‏.‏\hadithno{1194}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) used to go to the Mosque of Quba (sometimes) walking and sometimes riding. Added Nafi` (in another narration), "He then would offer two rak`at (in the Mosque of Quba)}}
\hadithdefcmd{bukhari}{1195}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ الْمَازِنِيِّ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا بَيْنَ بَيْتِي وَمِنْبَرِي رَوْضَةٌ مِنْ رِيَاضِ الْجَنَّةِ ‏"‏‏.‏\hadithno{1195}\hadithtrans{Narrated `Abdullah bin Zaid Al-Mazini:Allah's Messenger (ﷺ) said, "Between my house and the pulpit there is a garden of the gardens of Paradise}}
\hadithdefcmd{bukhari}{1196}{حَدَّثَنَا مُسَدَّدٌ، عَنْ يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي خُبَيْبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا بَيْنَ بَيْتِي وَمِنْبَرِي رَوْضَةٌ مِنْ رِيَاضِ الْجَنَّةِ، وَمِنْبَرِي عَلَى حَوْضِي ‏"‏‏.‏\hadithno{1196}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Between my house and my pulpit there is a garden of the gardens of Paradise, and my pulpit is on my fountain tank (i.e. Al-Kauthar)}}
\hadithdefcmd{bukhari}{1197}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ، سَمِعْتُ قَزَعَةَ، مَوْلَى زِيَادٍ قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ يُحَدِّثُ بِأَرْبَعٍ عَنِ النَّبِيِّ صلى الله عليه وسلم فَأَعْجَبْنَنِي وَآنَقْنَنِي قَالَ ‏ "‏ لاَ تُسَافِرِ الْمَرْأَةُ يَوْمَيْنِ إِلاَّ مَعَهَا زَوْجُهَا أَوْ ذُو مَحْرَمٍ‏.‏ وَلاَ صَوْمَ فِي يَوْمَيْنِ الْفِطْرِ وَالأَضْحَى، وَلاَ صَلاَةَ بَعْدَ صَلاَتَيْنِ بَعْدَ الصُّبْحِ حَتَّى تَطْلُعَ الشَّمْسُ، وَبَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ، وَلاَ تُشَدُّ الرِّحَالُ إِلاَّ إِلَى ثَلاَثَةِ مَسَاجِدَ مَسْجِدِ الْحَرَامِ وَمَسْجِدِ الأَقْصَى وَمَسْجِدِي ‏"‏‏.‏\hadithno{1197}\hadithtrans{Narrated Qaza'a Maula:(freed slave of) Ziyad: I heard Abu Sa`id Al-khudri narrating four things from the Prophet (ﷺ) and I appreciated them very much. He said, conveying the words of the Prophet. (1) "A woman should not go on a two day journey except with her husband or a Dhi-Mahram. (2) No fasting is permissible on two days: `Id-ul-Fitr and `Id-ul-Adha. (3) No prayer after two prayers, i.e. after the Fajr prayer till the sunrises and after the `Asr prayer till the sun sets. (4) Do not prepare yourself for a journey except to three Mosques, i.e. Al-Masjid-Al-Haram, the Mosque of Aqsa (Jerusalem) and my Mosque}}
