% Auto-generated chapter 40 for muslim
% Hadiths in this chapter: 23

\hadithdefcmd{muslim}{5862}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ وَحَرْمَلَةُ بْنُ يَحْيَى قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ قَالَ أَبُو هُرَيْرَةَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ يَسُبُّ ابْنُ آدَمَ الدَّهْرَ وَأَنَا الدَّهْرُ بِيَدِيَ اللَّيْلُ وَالنَّهَارُ ‏"‏ ‏.‏\hadithno{5862}\hadithtrans{Abu Huraira reported:I heard Allah's Messenger (ﷺ) as saying: Allah, the Exalted and Glorious, said: The son of Adam abuses Dahr (the time), whereas I am Dahr since in My hand are the day and the night}}
\hadithdefcmd{muslim}{5863}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لاِبْنِ أَبِي عُمَرَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي، هُرَيْرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ يُؤْذِينِي ابْنُ آدَمَ يَسُبُّ الدَّهْرَ وَأَنَا الدَّهْرُ أُقَلِّبُ اللَّيْلَ وَالنَّهَارَ ‏"‏ ‏.‏\hadithno{5863}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Allah, the Exalted and Glorious, said: The son of Adam displeases Me by abusing Dahr (time), whereas I am Dahr--I alternate the night and the day}}
\hadithdefcmd{muslim}{5864}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ، الْمُسَيَّبِ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ يُؤْذِينِي ابْنُ آدَمَ يَقُولُ يَا خَيْبَةَ الدَّهْرِ ‏.‏ فَلاَ يَقُولَنَّ أَحَدُكُمْ يَا خَيْبَةَ الدَّهْرِ ‏.‏ فَإِنِّي أَنَا الدَّهْرُ أُقَلِّبُ لَيْلَهُ وَنَهَارَهُ فَإِذَا شِئْتُ قَبَضْتُهُمَا ‏"‏ ‏.‏\hadithno{5864}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Allah, the Exalted and Glorious, said: The son of Adam causes Me pain as he says: Woe be upon the Time. None of you should say this: Woe be upon the Time, as I am the Time (because) I alternate the day and the night, and when I wish I can finish them up}}
\hadithdefcmd{muslim}{5865}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقُولَنَّ أَحَدُكُمْ يَا خَيْبَةَ الدَّهْرِ ‏.‏ فَإِنَّ اللَّهَ هُوَ الدَّهْرُ ‏"‏ ‏.‏\hadithno{5865}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:None of you should say: Woe be upon the Time, for verily Allah is the Time}}
\hadithdefcmd{muslim}{5866}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَسُبُّوا الدَّهْرَ فَإِنَّ اللَّهَ هُوَ الدَّهْرُ ‏"‏ ‏.‏\hadithno{5866}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:Do not curse Time, for it is Allah Who is Time}}
\hadithdefcmd{muslim}{5867}{حَدَّثَنَا حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنِ ابْنِ، سِيرِينَ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَسُبُّ أَحَدُكُمُ الدَّهْرَ فَإِنَّ اللَّهَ هُوَ الدَّهْرُ وَلاَ يَقُولَنَّ أَحَدُكُمْ لِلْعِنَبِ الْكَرْمَ ‏.‏ فَإِنَّ الْكَرْمَ الرَّجُلُ الْمُسْلِمُ ‏"‏ ‏.‏\hadithno{5867}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:None of you should abuse Time for it is Allah Who is the Time, and none of you should call 'Inab (grape) as al-karm, for karm is a Muslim person}}
\hadithdefcmd{muslim}{5868}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُولُوا كَرْمٌ ‏.‏ فَإِنَّ الْكَرْمَ قَلْبُ الْمُؤْمِنِ ‏"‏ ‏.‏\hadithno{5868}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Do not use the word karm (for wine) for worthy of respect is the heart of a believer}}
\hadithdefcmd{muslim}{5869}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُسَمُّوا الْعِنَبَ الْكَرْمَ فَإِنَّ الْكَرْمَ الرَّجُلُ الْمُسْلِمُ ‏"‏ ‏.‏\hadithno{5869}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Do not name grape as karm, for worthy of respect is a Muslim}}
\hadithdefcmd{muslim}{5870}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَلِيُّ بْنُ حَفْصٍ، حَدَّثَنَا وَرْقَاءُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَقُولَنَّ أَحَدُكُمُ الْكَرْمُ ‏.‏ فَإِنَّمَا الْكَرْمُ قَلْبُ الْمُؤْمِنِ ‏"‏ ‏.‏\hadithno{5870}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:None of you should use the word al-harin (for grape) for the heart of a believer is karm (worthy of respect)}}
\hadithdefcmd{muslim}{5871}{وَحَدَّثَنَا ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَقُولَنَّ أَحَدُكُمْ لِلْعِنَبِ الْكَرْمَ ‏.‏ إِنَّمَا الْكَرْمُ الرَّجُلُ الْمُسْلِمُ ‏"‏ ‏.‏\hadithno{5871}\hadithtrans{Abu Huraira reported from Allah's Messenger (ﷺ) various ahadith, one of which is this that he said:None of you should use the word al-karm for 'Inab, for karm (worthy of respect) is a Muslim person}}
\hadithdefcmd{muslim}{5872}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى، - يَعْنِي ابْنَ يُونُسَ - عَنْ شُعْبَةَ، عَنْ سِمَاكِ، بْنِ حَرْبٍ عَنْ عَلْقَمَةَ بْنِ وَائِلٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُولُوا الْكَرْمُ ‏.‏ وَلَكِنْ قُولُوا الْحَبَلَةُ ‏"‏ ‏.‏ يَعْنِي الْعِنَبَ ‏.‏\hadithno{5872}\hadithtrans{Alqama b. Wa'il reported, from his father, Allah's Apostle (ﷺ) having said:Do not say al-karm (for the word vine) but say al-habala (that is grape)}}
\hadithdefcmd{muslim}{5873}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكٍ، قَالَ سَمِعْتُ عَلْقَمَةَ بْنَ وَائِلٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُولُوا الْكَرْمُ ‏.‏ وَلَكِنْ قُولُوا الْعِنَبُ وَالْحَبَلَةُ ‏"‏ ‏.‏\hadithno{5873}\hadithtrans{This hadith has been reported by Alqama b. Wa'il on the authority of his father with a different chain of transmitters and with a slight variation of wording}}
\hadithdefcmd{muslim}{5874}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقُولَنَّ أَحَدُكُمْ عَبْدِي وَأَمَتِي ‏.‏ كُلُّكُمْ عَبِيدُ اللَّهِ وَكُلُّ نِسَائِكُمْ إِمَاءُ اللَّهِ وَلَكِنْ لِيَقُلْ غُلاَمِي وَجَارِيَتِي وَفَتَاىَ وَفَتَاتِي ‏"‏ ‏.‏\hadithno{5874}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:None of you should say: My bondman and my slave-girl, for all of you are the bondmen of Allah, and all your women are the slave-girls of Allah; but say: My servant, my girl, and my young man and my young girl}}
\hadithdefcmd{muslim}{5875}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي، هُرَيْرَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَقُولَنَّ أَحَدُكُمْ عَبْدِي ‏.‏ فَكُلُّكُمْ عَبِيدُ اللَّهِ وَلَكِنْ لِيَقُلْ فَتَاىَ ‏.‏ وَلاَ يَقُلِ الْعَبْدُ رَبِّي ‏.‏ وَلَكِنْ لِيَقُلْ سَيِّدِي ‏"‏ ‏.‏\hadithno{5875}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:None of you should say: My bondman, for all of you are the bondmen of Allah, but say: My young man, and the servant should not say: My Lord, but should say: My chief}}
\hadithdefcmd{muslim}{5876}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا وَكِيعٌ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِهِمَا ‏"‏ وَلاَ يَقُلِ الْعَبْدُ لِسَيِّدِهِ مَوْلاَىَ ‏"‏ ‏.‏ وَزَادَ فِي حَدِيثِ أَبِي مُعَاوِيَةَ ‏"‏ فَإِنَّ مَوْلاَكُمُ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{5876}\hadithtrans{This hadith has been reported on the authority of al-A'mash with the same chain of transmitters, and the words are that the servant should not say to his chief:My Lord, and Abu Mu'awiya made an addition:" For it is Allah, the Exalted and Glorious, Who is your Lord}}
\hadithdefcmd{muslim}{5877}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَقُلْ أَحَدُكُمُ اسْقِ رَبَّكَ أَطْعِمْ رَبَّكَ وَضِّئْ رَبَّكَ ‏.‏ وَلاَ يَقُلْ أَحَدُكُمْ رَبِّي ‏.‏ وَلْيَقُلْ سَيِّدِي مَوْلاَىَ وَلاَ يَقُلْ أَحَدُكُمْ عَبْدِي أَمَتِي ‏.‏ وَلْيَقُلْ فَتَاىَ فَتَاتِي غُلاَمِي ‏"‏ ‏.‏\hadithno{5877}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) so many ahadith and one of them is this that Allah's Messenger (ﷺ) said:None of you should say: Supply drink to your lord, feed your lord, help your lord in performing ablution, and none of you should say: My Lord. He should say: My chief, my patron; and none of you should say: My bondman, my slave-girl, but simply say: My boy, my girl, my servant}}
\hadithdefcmd{muslim}{5878}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، كِلاَهُمَا عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَقُولَنَّ أَحَدُكُمْ خَبُثَتْ نَفْسِي ‏.‏ وَلَكِنْ لِيَقُلْ لَقِسَتْ نَفْسِي ‏"‏ ‏.‏ هَذَا حَدِيثُ أَبِي كُرَيْبٍ وَقَالَ أَبُو بَكْرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَلَمْ يَذْكُرْ ‏"‏ لَكِنْ ‏"‏ ‏.‏\hadithno{5878}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) having said:None of you should say: "My soul has become evil," but he should say: "My soul has become remorseless." This hadith has been transmitted on the authority of Abu Bakr with a slight variation of wording}}
\hadithdefcmd{muslim}{5879}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5879}\hadithtrans{This hadith has been narrated on the authority of Abia Mu'iwiya with the same chain of transmitters}}
\hadithdefcmd{muslim}{5880}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ، شِهَابٍ عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقُلْ أَحَدُكُمْ خَبُثَتْ نَفْسِي ‏.‏ وَلْيَقُلْ لَقِسَتْ نَفْسِي ‏"‏ ‏.‏\hadithno{5880}\hadithtrans{Abu Umama b. Sahl b. Hunaif, on the authority of his father, reported Allah's Messenger (ﷺ) as saying:None of you should say:" My soul has become evil," but he should say:" My soul has become remorseless}}
\hadithdefcmd{muslim}{5881}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ شُعْبَةَ، حَدَّثَنِي خُلَيْدُ بْنُ جَعْفَرٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كَانَتِ امْرَأَةٌ مِنْ بَنِي إِسْرَائِيلَ قَصِيرَةٌ تَمْشِي مَعَ امْرَأَتَيْنِ طَوِيلَتَيْنِ فَاتَّخَذَتْ رِجْلَيْنِ مِنْ خَشَبٍ وَخَاتَمًا مِنْ ذَهَبٍ مُغْلَقٍ مُطْبَقٍ ثُمَّ حَشَتْهُ مِسْكًا وَهُوَ أَطْيَبُ الطِّيبِ فَمَرَّتْ بَيْنَ الْمَرْأَتَيْنِ فَلَمْ يَعْرِفُوهَا فَقَالَتْ بِيَدِهَا هَكَذَا ‏"‏ ‏.‏ وَنَفَضَ شُعْبَةُ يَدَهُ ‏.‏\hadithno{5881}\hadithtrans{Abd Sa'id Khudri reported Allah's Apostle (ﷺ) as saying:There was a woman from Bani Isra'il who was short-statured and she walked in the company of two tall women with wooden sandals in her feet and a ring of gold made of plates with musk filled in them and then looked up, and musk is the best of scents; then she walked between two women and they (the people) did not recognise her, and she made a gesture with her hand like this, and Shu'ba shook his hand in order to give an indication how she shook her hand}}
\hadithdefcmd{muslim}{5882}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ شُعْبَةَ، عَنْ خُلَيْدِ بْنِ جَعْفَرٍ، وَالْمُسْتَمِرِّ، قَالاَ سَمِعْنَا أَبَا نَضْرَةَ، يُحَدِّثُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ امْرَأَةً مِنْ بَنِي إِسْرَائِيلَ حَشَتْ خَاتَمَهَا مِسْكًا وَالْمِسْكُ أَطْيَبُ الطِّيبِ ‏.‏\hadithno{5882}\hadithtrans{Abu Sa'id Khudri reported that Allah's Messenger (ﷺ) made a mention of a woman of Bana Isra'il who had filled her ring with musk and musk is the most fragrant of the scents}}
\hadithdefcmd{muslim}{5883}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، كِلاَهُمَا عَنِ الْمُقْرِئِ، قَالَ أَبُو بَكْرٍ حَدَّثَنَا أَبُو عَبْدِ الرَّحْمَنِ الْمُقْرِئُ، عَنْ سَعِيدِ بْنِ أَبِي أَيُّوبَ، حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ أَبِي جَعْفَرٍ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ عُرِضَ عَلَيْهِ رَيْحَانٌ فَلاَ يَرُدُّهُ فَإِنَّهُ خَفِيفُ الْمَحْمِلِ طَيِّبُ الرِّيحِ ‏"‏ ‏.‏\hadithno{5883}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who is presented with a flower should not reject it, for it is light to carry and pleasant in odour}}
\hadithdefcmd{muslim}{5884}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَبُو طَاهِرٍ وَأَحْمَدُ بْنُ عِيسَى قَالَ أَحْمَدُ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَخْرَمَةُ، عَنْ أَبِيهِ، عَنْ نَافِعٍ، قَالَ كَانَ ابْنُ عُمَرَ إِذَا اسْتَجْمَرَ اسْتَجْمَرَ بِالأَلُوَّةِ غَيْرِ مُطَرَّاةٍ وَبِكَافُورٍ يَطْرَحُهُ مَعَ الأَلُوَّةِ ثُمَّ قَالَ هَكَذَا كَانَ يَسْتَجْمِرُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5884}\hadithtrans{Nafi' reported that when Ibn Umar wanted fumigation he got it from aloeswood without mixing anything with it, or he put camphor along with aloeswood and then said:This is how Allah's Messenger (ﷺ) fumigated}}
