% Auto-generated chapter 27 for ibnmajah
% Hadiths in this chapter: 38

\hadithdefcmd{ibnmajah}{3162}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، عَنْ أَبِيهِ، عَنْ سِبَاعِ بْنِ ثَابِتٍ، عَنْ أُمِّ كُرْزٍ، قَالَتْ سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ عَنِ الْغُلاَمِ، شَاتَانِ مُكَافِئَتَانِ وَعَنِ الْجَارِيَةِ، شَاةٌ ‏"‏ ‏.‏\hadithno{3162}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Umm Kurz said:“I heard the Prophet (ﷺ) say: ‘On behalf of a boy, two sheep of equal age and on behalf of a girl one sheep.’”}}
\hadithdefcmd{ibnmajah}{3163}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ حَفْصَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ أَمَرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ نَعُقَّ عَنِ الْغُلاَمِ شَاتَيْنِ وَعَنِ الْجَارِيَةِ شَاةً ‏.‏\hadithno{3163}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) commanded us to sacrifice two sheep for a boy’s ‘Aqiqah and one sheep for a girl.”}}
\hadithdefcmd{ibnmajah}{3164}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ سَلْمَانَ بْنِ عَامِرٍ، أَنَّهُ سَمِعَ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّ مَعَ الْغُلاَمِ عَقِيقَةً فَأَهْرِيقُوا عَنْهُ دَمًا وَأَمِيطُوا عَنْهُ الأَذَى ‏"‏ ‏.‏\hadithno{3164}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Salman bin ‘Amir that he heard the Prophet (ﷺ) say:“For a boy there should be an ‘Aqiqah, so shed blood for him and remove the harm from him.”}}
\hadithdefcmd{ibnmajah}{3165}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا شُعَيْبُ بْنُ إِسْحَاقَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كُلُّ غُلاَمٍ مُرْتَهَنٌ بِعَقِيقَتِهِ تُذْبَحُ عَنْهُ يَوْمَ السَّابِعِ وَيُحْلَقُ رَأْسُهُ وَيُسَمَّى ‏"‏ ‏.‏\hadithno{3165}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Samurah that the Prophet (ﷺ) said:“Every boy is mortgaged by his ‘Aqiqah, so slaughter for him on the seventh day, and shave his head, and name him.”}}
\hadithdefcmd{ibnmajah}{3166}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ أَيُّوبَ بْنِ مُوسَى، أَنَّهُ حَدَّثَهُ أَنَّ يَزِيدَ بْنَ عَبْدٍ الْمُزَنِيَّ حَدَّثَهُ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ يُعَقُّ عَنِ الْغُلاَمِ وَلاَ يُمَسُّ رَأْسُهُ بِدَمٍ ‏"‏ ‏.‏\hadithno{3166}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Yazid bin ‘Abdul-Muzani narrated that the Prophet (ﷺ) said:“Offer an ‘Aqiqah for the boy, but do not smear his head with blood.”}}
\hadithdefcmd{ibnmajah}{3167}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي الْمَلِيحِ، عَنْ نُبَيْشَةَ، قَالَ نَادَى رَجُلٌ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّا كُنَّا نَعْتِرُ عَتِيرَةً فِي الْجَاهِلِيَّةِ فِي رَجَبٍ فَمَا تَأْمُرُنَا قَالَ ‏"‏ اذْبَحُوا لِلَّهِ عَزَّ وَجَلَّ فِي أَىِّ شَهْرٍ مَا كَانَ وَبَرُّوا اللَّهَ وَأَطْعِمُوا ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ إِنَّا كُنَّا نُفْرِعُ فَرَعًا فِي الْجَاهِلِيَّةِ فَمَا تَأْمُرُنَا قَالَ ‏"‏ فِي كُلِّ سَائِمَةٍ فَرَعٌ تَغْذُوهُ مَاشِيَتُكَ حَتَّى إِذَا اسْتَحْمَلَ ذَبَحْتَهُ فَتَصَدَّقْتَ بِلَحْمِهِ - أُرَاهُ قَالَ - عَلَى ابْنِ السَّبِيلِ فَإِنَّ ذَلِكَ هُوَ خَيْرٌ ‏"‏ ‏.‏\hadithno{3167}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Nubaishah said:“A man called the Messenger of Allah (ﷺ) and said: ‘O Messenger of Allah, we used to sacrifice the ‘Atirah during the Ignorance days in Rajab,; what do you command us to do?’ He said: “Sacrifice to Allah whatever month it is, do good for the sake of Allah and feed (the poor).’ They said: ‘O Messenger of Allah, we used to sacrifice the Far’ah during the Ignorance days; what do you command us to do?’ He said: ‘For every Sa’imah* (flock of grazing animals), feed the firstborn as you feed the rest of your flock until it reaches an age where it could be used to carry loads, then sacrifice it, and give its meat in charity’ – I** think he said – ‘to the wayfarer, for that is good.’”}}
\hadithdefcmd{ibnmajah}{3168}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ فَرَعَةَ وَلاَ عَتِيرَةَ ‏"‏ ‏.‏ قَالَ هِشَامٌ فِي حَدِيثِهِ وَالْفَرَعَةُ أَوَّلُ النَّتَاجِ ‏.‏ وَالْعَتِيرَةُ الشَّاةُ يَذْبَحُهَا أَهْلُ الْبَيْتِ فِي رَجَبٍ ‏.‏\hadithno{3168}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“There is no Far’ah and no ‘Atirah.”}}
\hadithdefcmd{ibnmajah}{3169}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ فَرَعَةَ وَلاَ عَتِيرَةَ ‏"‏ ‏.‏ قَالَ ابْنُ مَاجَهْ هَذَا مِنْ فَرَائِدِ الْعَدَنِيِّ ‏.‏\hadithno{3169}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Muhammad bin Abu (‘Umar) ‘Adani that the Prophet (ﷺ) said:“There is no Far’ah and no ‘Atirah.”}}
\hadithdefcmd{ibnmajah}{3170}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ، عَنْ شَدَّادِ بْنِ أَوْسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ كَتَبَ الإِحْسَانَ عَلَى كُلِّ شَىْءٍ فَإِذَا قَتَلْتُمْ فَأَحْسِنُوا الْقِتْلَةَ وَإِذَا ذَبَحْتُمْ فَأَحْسِنُوا الذَّبْحَ وَلْيُحِدَّ أَحَدُكُمْ شَفْرَتَهُ وَلْيُرِحْ ذَبِيحَتَهُ ‏"‏ ‏.‏\hadithno{3170}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Shaddad bin Aws that the Messenger of Allah (ﷺ) said:“Allah has prescribed Al-Ihsan (proficiency) in all things. So if you kill, then kill well, and if you slaughter, then slaughter well. Let one of you sharpen his blade and spare suffering to the animal he slaughters.”}}
\hadithdefcmd{ibnmajah}{3171}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، عَنْ مُوسَى بْنِ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، أَخْبَرَنِي أَبِي، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ مَرَّ النَّبِيُّ ـ صلى الله عليه وسلم ـ بِرَجُلٍ وَهُوَ يَجُرُّ شَاةً بِأُذُنِهَا فَقَالَ ‏ "‏ دَعْ أُذُنَهَا وَخُذْ بِسَالِفَتِهَا ‏"‏ ‏.‏\hadithno{3171}\hadithgrade{Al-Albani: Very Daif Isnaad; Muhammad Fouad Abd al-Baqi: Very Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“The Prophet (ﷺ) passed by a man who was dragging a sheep by its ear. He said: ‘Leave its ear alone and hold it by the sides of its neck.’”}}
\hadithdefcmd{ibnmajah}{3172}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ ابْنُ أَخِي، حُسَيْنٍ الْجُعْفِيِّ حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ لَهِيعَةَ، حَدَّثَنِي قُرَّةُ بْنُ حَيْوَئِيلَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ أَمَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِحَدِّ الشِّفَارِ وَأَنْ تُوَارَى عَنِ الْبَهَائِمِ وَقَالَ ‏ "‏ إِذَا ذَبَحَ أَحَدُكُمْ فَلْيُجْهِزْ ‏"‏ ‏.‏ حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، حَدَّثَنَا أَبُو الأَسْوَدِ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ مِثْلَهُ ‏.‏\hadithno{3172}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah bin ‘Umar said:“The Messenger of Allah (ﷺ) commanded that the blade should be sharpened, and hidden from the animals, and he said: ‘When one of you slaughters, let him do it quickly.’” Another chain reports the same}}
\hadithdefcmd{ibnmajah}{3173}{حَدَّثَنَا عَمْرُو بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، ‏\{إِنَّ الشَّيَاطِينَ لَيُوحُونَ إِلَى أَوْلِيَائِهِمْ\}‏ قَالَ كَانُوا يَقُولُونَ مَا ذُكِرَ عَلَيْهِ اسْمُ اللَّهِ فَلاَ تَأْكُلُوا وَمَا لَمْ يُذْكَرِ اسْمُ اللَّهِ عَلَيْهِ فَكُلُوهُ ‏.‏ فَقَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{وَلاَ تَأْكُلُوا مِمَّا لَمْ يُذْكَرِ اسْمُ اللَّهِ عَلَيْهِ\}‏ ‏.‏\hadithno{3173}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas:“And certainly, the Shayatin (devils) do inspire their friends (from mankind).” [6:121] He said: “They used to say: ‘Whatever the Name of Allah has been mentioned over, do not eat it, and whatever the Name of Allah has not been mentioned over, eat it.’ Then Allah said: “Eat not of that over which Allah’s Name has not been pronounced.’” [6:]}}
\hadithdefcmd{ibnmajah}{3174}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّ قَوْمًا، قَالُوا يَا رَسُولَ اللَّهِ إِنَّ قَوْمًا يَأْتُونَا بِلَحْمٍ لاَ نَدْرِي ذُكِرَ اسْمُ اللَّهِ عَلَيْهِ أَمْ لاَ قَالَ ‏ "‏ سَمُّوا أَنْتُمْ وَكُلُوا ‏"‏ ‏.‏ وَكَانُوا حَدِيثَ عَهْدٍ بِالْكُفْرِ ‏.‏\hadithno{3174}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from ‘Aishah, the Mother of the Believers, that some people said:“O Messenger of Allah, some people bring us meat, and we do not know whether the Name of Allah has been mentioned over it or not.” He said: “Say: Bismillah and eat.’ They were new in Islam}}
\hadithdefcmd{ibnmajah}{3175}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، عَنْ مُحَمَّدِ بْنِ صَيْفِيٍّ، قَالَ ذَبَحْتُ أَرْنَبَيْنِ بِمَرْوَةٍ فَأَتَيْتُ بِهِمَا النَّبِيَّ ـ صلى الله عليه وسلم ـ فَأَمَرَنِي بِأَكْلِهِمَا ‏.‏\hadithno{3175}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Muhammad bin Saifi said:“I slaughtered two rabbits with a sharp-edges stone and brought them to the Prophet (ﷺ), and he told me to eat them.”}}
\hadithdefcmd{ibnmajah}{3176}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ حَاضِرَ بْنَ مُهَاجِرٍ، يُحَدِّثُ عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ ذِئْبًا، نَيَّبَ فِي شَاةٍ فَذَبَحُوهَا بِمَرْوَةٍ فَرَخَّصَ لَهُمْ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي أَكْلِهَا ‏.‏\hadithno{3176}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Zaid bin Thabit that a wolf bit a sheep, and they slaughtered it with a sharp-edged stone, and the Messenger of Allah (ﷺ) allowed them to eat it}}
\hadithdefcmd{ibnmajah}{3177}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ مُرِّيِّ بْنِ قَطَرِيٍّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا نَصِيدُ الصَّيْدَ فَلاَ نَجِدُ سِكِّينًا إِلاَّ الظِّرَارَ وَشِقَّةَ الْعَصَا ‏.‏ قَالَ ‏ "‏ أَمْرِرِ الدَّمَ بِمَا شِئْتَ وَاذْكُرِ اسْمَ اللَّهِ عَلَيْهِ ‏"‏ ‏.‏\hadithno{3177}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Adi bin Hatim said:“I said: ‘O Messenger of Allah, we hunt game but we cannot find anything but the sharp edge of a stone or stick (with which to slaughter it).’ He said: ‘Cause the blood to flow with whatever you want, and mention the Name of Allah over it.’”}}
\hadithdefcmd{ibnmajah}{3178}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عُمَرُ بْنُ عُبَيْدٍ الطَّنَافِسِيُّ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ جَدِّهِ، رَافِعِ بْنِ خَدِيجٍ قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي سَفَرٍ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّا نَكُونُ فِي الْمَغَازِي فَلاَ يَكُونُ مَعَنَا مُدًى فَقَالَ ‏ "‏ مَا أَنْهَرَ الدَّمَ وَذُكِرَ اسْمُ اللَّهِ عَلَيْهِ فَكُلْ غَيْرَ السِّنِّ وَالظُّفْرِ فَإِنَّ السِّنَّ عَظْمٌ وَالظُّفْرَ مُدَى الْحَبَشَةِ ‏"‏ ‏.‏\hadithno{3178}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Rafi’ bin Khadij said:“We were with the Prophet (ﷺ) on a journey, and I said: ‘O Messenger of Allah, we are (sometimes) on military campaigns, and we have no knife with us.’ He said: ‘(Use) whatever causes the blood to flow, mention the Name of Allah and eat, but (do not use) teeth or nails, for the tooth is a bone and the nail is the knife of the Ethiopians.”}}
\hadithdefcmd{ibnmajah}{3179}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا هِلاَلُ بْنُ مَيْمُونٍ الْجُهَنِيُّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، - قَالَ عَطَاءٌ لاَ أَعْلَمُهُ إِلاَّ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ - أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَرَّ بِغُلاَمٍ يَسْلُخُ شَاةً فَقَالَ لَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ تَنَحَّ حَتَّى أُرِيَكَ ‏"‏ ‏.‏ فَأَدْخَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَدَهُ بَيْنَ الْجِلْدِ وَاللَّحْمِ فَدَحَسَ بِهَا حَتَّى تَوَارَتْ إِلَى الإِبْطِ وَقَالَ ‏"‏ يَا غُلاَمُ هَكَذَا فَاسْلُخْ ‏"‏ ‏.‏ ثُمَّ مَضَى وَصَلَّى لِلنَّاسِ وَلَمْ يَتَوَضَّأْ ‏.‏\hadithno{3179}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Messenger of Allah (ﷺ) passed by a boy who was skinning a sheep. The Messenger of Allah (ﷺ) said to him:“Step aside and I will show you how.” The Messenger of Allah (ﷺ) put his hand between the skin and the flesh, and thrust his arm in until it disappeared up to the armpit, and said: “O boy, this is how you skin it.” Then he went and led the people in prayer and did not perform Wudu’}}
\hadithdefcmd{ibnmajah}{3180}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَلَفُ بْنُ خَلِيفَةَ، ح وَحَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، أَنْبَأَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، جَمِيعًا عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَتَى رَجُلاً مِنَ الأَنْصَارِ فَأَخَذَ الشَّفْرَةَ لِيَذْبَحَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ لَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِيَّاكَ وَالْحَلُوبَ ‏"‏ ‏.‏\hadithno{3180}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) came to a man from among the Ansar who had picked up a knife to slaughter an animal for the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) said to him:“Avoid those that are lactating.” (i.e. those from which milk is received)}}
\hadithdefcmd{ibnmajah}{3181}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ الْمُحَارِبِيُّ، عَنْ يَحْيَى بْنِ عُبَيْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ حَدَّثَنِي أَبُو بَكْرِ بْنُ أَبِي قُحَافَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ لَهُ وَلِعُمَرَ ‏"‏ انْطَلِقُوا بِنَا إِلَى الْوَاقِفِيِّ ‏"‏ ‏.‏ قَالَ فَانْطَلَقْنَا فِي الْقَمَرِ حَتَّى أَتَيْنَا الْحَائِطَ فَقَالَ مَرْحَبًا وَأَهْلاً ‏.‏ ثُمَّ أَخَذَ الشَّفْرَةَ ثُمَّ جَالَ فِي الْغَنَمِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِيَّاكَ وَالْحَلُوبَ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ ذَاتَ الدَّرِّ ‏"‏ ‏.‏\hadithno{3181}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that Abu Bakr bin Abu Quhafah narrated that the Messenger of Allah (ﷺ) said to him and to ‘Umar:“Let us go out to Waqifi.” He said: “So we went out in the moonlight until we came to the garden and he (the owner of the garden) said: ‘Welcome.’ Then he took up the knife and went among the sheep (to choose one for slaughter), and the Messenger of Allah (ﷺ) said: ‘Avoid those that are lactating.’”}}
\hadithdefcmd{ibnmajah}{3182}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنٍ لِكَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّ امْرَأَةً، ذَبَحَتْ شَاةً بِحَجَرٍ فَذُكِرَ ذَلِكَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَلَمْ يَرَ بِهِ بَأْسًا ‏.‏\hadithno{3182}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from a son of Ka’b bin Malik, from his father, that a woman slaughtered a sheep with a stone, and that was mentioned to the Messenger of Allah (ﷺ), but he did not see anything wrong with that}}
\hadithdefcmd{ibnmajah}{3183}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عُمَرُ بْنُ عُبَيْدٍ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ جَدِّهِ، رَافِعِ بْنِ خَدِيجٍ قَالَ كُنَّا مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي سَفَرٍ فَنَدَّ بَعِيرٌ فَرَمَاهُ رَجُلٌ بِسَهْمٍ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ لَهَا أَوَابِدَ - أَحْسَبُهُ قَالَ - كَأَوَابِدِ الْوَحْشِ فَمَا غَلَبَكُمْ مِنْهَا فَاصْنَعُوا بِهِ هَكَذَا ‏"‏ ‏.‏\hadithno{3183}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Rafi’ bin Khadij said:“We were with the Prophet (ﷺ) on a journey, and a camel ran away. A man shot an arrow at it and the Prophet (ﷺ) said: ‘It has the inclination to run away like a wild animal. If this happens to any of you, do likewise.’”}}
\hadithdefcmd{ibnmajah}{3184}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ أَبِي الْعُشَرَاءِ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَا تَكُونُ الذَّكَاةُ إِلاَّ فِي الْحَلْقِ وَاللَّبَّةِ قَالَ ‏ "‏ لَوْ طَعَنْتَ فِي فَخِذِهَا لأَجْزَأَكَ ‏"‏ ‏.‏\hadithno{3184}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu ‘Ushara’ that his father said:“I said: ‘O Messenger of Allah, should slaughtering only be done in the throat or upper chest?’ He said: ‘If you stab it in the thigh that will suffice you.’”}}
\hadithdefcmd{ibnmajah}{3185}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَبْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، عَنْ مُوسَى بْنِ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يُمَثَّلَ بِالْبَهَائِمِ ‏.‏\hadithno{3185}\hadithgrade{Al-Albani: Very Daif Isnaad; Muhammad Fouad Abd al-Baqi: Very Daif Isnaad; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“The Messenger of Allah (ﷺ) forbade mutilating animals.”}}
\hadithdefcmd{ibnmajah}{3186}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ هِشَامِ بْنِ زَيْدِ بْنِ أَنَسِ بْنِ مَالِكٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ صَبْرِ الْبَهَائِمِ ‏.‏\hadithno{3186}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:“The Messenger of Allah (ﷺ) forbade tying up animals.”}}
\hadithdefcmd{ibnmajah}{3187}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَتَّخِذُوا شَيْئًا فِيهِ الرُّوحُ غَرَضًا ‏"‏ ‏.‏\hadithno{3187}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:‘Do not take anything with a soul as a target.”}}
\hadithdefcmd{ibnmajah}{3188}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، أَنْبَأَنَا ابْنُ جُرَيْجٍ، حَدَّثَنَا أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يُقْتَلَ شَىْءٌ مِنَ الدَّوَابِّ صَبْرًا ‏.‏\hadithno{3188}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) forbade killing any animal when it is tied up (for use as a target).”}}
\hadithdefcmd{ibnmajah}{3189}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ لُحُومِ الْجَلاَّلَةِ وَأَلْبَانِهَا ‏.‏\hadithno{3189}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) forbade the meat and milk of Al-Jallalah.”}}
\hadithdefcmd{ibnmajah}{3190}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ نَحَرْنَا فَرَسًا فَأَكَلْنَا مِنْ لَحْمِهِ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{3190}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Asm’a bint Abu Bakr said:“We slaughtered a horse and ate its meat during the time of the Messenger of Allah (ﷺ).”}}
\hadithdefcmd{ibnmajah}{3191}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ أَكَلْنَا زَمَنَ خَيْبَرَ الْخَيْلَ وَحُمُرَ الْوَحْشِ ‏.‏\hadithno{3191}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Zubair that he heard Jabir bin ‘Abdullah say:“At the time of Khaibar we ate horses and wild donkeys.”}}
\hadithdefcmd{ibnmajah}{3192}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ أَبِي إِسْحَاقَ الشَّيْبَانِيِّ، قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى عَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ، فَقَالَ أَصَابَتْنَا مَجَاعَةٌ يَوْمَ خَيْبَرَ وَنَحْنُ مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ وَقَدْ أَصَابَ الْقَوْمُ حُمُرًا خَارِجًا مِنَ الْمَدِينَةِ فَنَحَرْنَاهَا وَإِنَّ قُدُورَنَا لَتَغْلِي إِذْ نَادَى مُنَادِي النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنِ اكْفَئُوا الْقُدُورَ وَلاَ تَطْعَمُوا مِنْ لُحُومِ الْحُمُرِ شَيْئًا ‏.‏ فَأَكْفَأْنَاهَا ‏.‏ فَقُلْتُ لِعَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى حَرَّمَهَا تَحْرِيمًا قَالَ تَحَدَّثْنَا أَنَّمَا حَرَّمَهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَلْبَتَّةَ مِنْ أَجْلِ أَنَّهَا تَأْكُلُ الْعَذِرَةَ ‏.‏\hadithno{3192}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Ishaq Shaibani said:“I asked ‘Abdullah bin Abu Awfa about the flesh of domesticated donkeys and he said: ‘We were starving on the Day of Khaibar, when we were with the Prophet (ﷺ). The people had gotten some donkeys as spoils of war on the way out from Al-Madinah, so we slaughtered them and our cooking pots were boiling when the caller of the Messenger of Allah (ﷺ) cried out, telling us to overturn out pots and not to eat anything of the flesh of donkeys. So we overturned them.’ I said to ‘Abdullah bin Abu Awfa: ‘Was it made unlawful?’ He said: ‘We think that the Messenger of Allah (ﷺ) forbade it altogether because it eats excrement.’”}}
\hadithdefcmd{ibnmajah}{3193}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، حَدَّثَنِي الْحَسَنُ بْنُ جَابِرٍ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ الْكِنْدِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ حَرَّمَ أَشْيَاءَ حَتَّى ذَكَرَ الْحُمُرَ الإِنْسِيَّةَ ‏.‏\hadithno{3193}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Miqdam bin Ma’dikarib Al-Kindi that the Messenger of Allah (ﷺ) forbade several things, until he mentioned (the meat of) domesticated donkeys}}
\hadithdefcmd{ibnmajah}{3194}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ نُلْقِيَ لُحُومَ الْحُمُرِ الأَهْلِيَّةِ نِيئَةً وَنَضِيجَةً ثُمَّ لَمْ يَأْمُرْنَا بِهِ بَعْدُ ‏.‏\hadithno{3194}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Bara’ bin ‘Azib said:“The Messenger of Allah (ﷺ) commanded us to throw away the meat of domesticated donkeys, raw or cooked, then he did not say anything to us about it after that.”}}
\hadithdefcmd{ibnmajah}{3195}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، قَالَ غَزَوْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ غَزْوَةَ خَيْبَرَ فَأَمْسَى النَّاسُ قَدْ أَوْقَدُوا النِّيرَانَ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ عَلاَمَ تُوقِدُونَ ‏"‏ ‏.‏ قَالُوا عَلَى لُحُومِ الْحُمُرِ الإِنْسِيَّةِ فَقَالَ ‏"‏ أَهْرِيقُوا مَا فِيهَا وَاكْسِرُوهَا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ أَوْ نُهَرِيقُ مَا فِيهَا وَنَغْسِلُهَا فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ أَوْ ذَاكَ ‏"‏ ‏.‏\hadithno{3195}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Salamah bin Akwa’ said:“We went out with the Messenger of Allah (ﷺ) on the campaign of Khaibar, and in the evening the people lit their fires. The Prophet (ﷺ) said: ‘What are you cooking?’ They said: ‘The meat of domesticated donkeys.’ He said: ‘Throw out what is in them (the pots) and break them.’ A man said: ‘Or can we throw out what is in them and wash them?’ The Prophet (ﷺ) said: ‘Or (do) that.’”}}
\hadithdefcmd{ibnmajah}{3196}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ مُنَادِيَ النَّبِيِّ، ـ صلى الله عليه وسلم ـ نَادَى إِنَّ اللَّهَ وَرَسُولَهُ يَنْهَيَانِكُمْ عَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ فَإِنَّهَا رِجْسٌ ‏.‏\hadithno{3196}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas bin Malik that the caller of the Prophet (ﷺ) cried out:“Allah and His Messenger forbid you to eat the flesh of domesticated donkeys, for it is filthy.”}}
\hadithdefcmd{ibnmajah}{3197}{حَدَّثَنَا عَمْرُو بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا الثَّوْرِيُّ، وَمَعْمَرٌ، جَمِيعًا عَنْ عَبْدِ الْكَرِيمِ الْجَزَرِيِّ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا نَأْكُلُ لُحُومَ الْخَيْلِ ‏.‏ قُلْتُ فَالْبِغَالُ قَالَ لاَ ‏.‏\hadithno{3197}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Fouad Abd al-Baqi: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that ‘Ata’ narrated that Jabir bin ‘Abdullah said:“We used to eat the meat of horses.” I said: “And mules?” He said: “No.”}}
\hadithdefcmd{ibnmajah}{3198}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنِي ثَوْرُ بْنُ يَزِيدَ، عَنْ صَالِحِ بْنِ يَحْيَى بْنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ خَالِدِ بْنِ الْوَلِيدِ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ لُحُومِ الْخَيْلِ وَالْبِغَالِ وَالْحَمِيرِ ‏.‏\hadithno{3198}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Khalid bin Walid said:“The Messenger of Allah (ﷺ) forbade the flesh of horses, mules and donkeys.”}}
\hadithdefcmd{ibnmajah}{3199}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، وَأَبُو خَالِدٍ الأَحْمَرُ وَعَبْدَةُ بْنُ سُلَيْمَانَ عَنْ مُجَالِدٍ، عَنْ أَبِي الْوَدَّاكِ، عَنْ أَبِي سَعِيدٍ، قَالَ سَأَلْنَا رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْجَنِينِ فَقَالَ ‏ "‏ كُلُوهُ إِنْ شِئْتُمْ فَإِنَّ ذَكَاةَ الْجَنِينِ ذَكَاةُ أُمِّهِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْد اللَّهِ سَمِعْتُ الْكَوْسَجَ إِسْحَقَ بْنَ مَنْصُورٍ يَقُولُ فِي قَوْلِهِمْ فِي الذَّكَاةِ لَا يُقْضَى بِهَا مَذِمَّةٌ قَالَ مَذِمَّةٌ بِكَسْرِ الذَّالِ مِنْ الذِّمَامِ وَبِفَتْحِ الذَّالِ مِنْ الذَّمِّ\hadithno{3199}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa’eed said:“We asked the Messenger of Allah (ﷺ) about the fetus. He said: ‘Eat it if you wish, for it is considered legally slaughtered with the slaughtering of its mother.’”}}
