% Auto-generated chapter 2 for nasai
% Hadiths in this chapter: 23

\hadithdefcmd{nasai}{325}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ سُفْيَانَ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ بَعْضَ، أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم اغْتَسَلَتْ مِنَ الْجَنَابَةِ فَتَوَضَّأَ النَّبِيُّ صلى الله عليه وسلم بِفَضْلِهَا فَذَكَرَتْ ذَلِكَ لَهُ فَقَالَ ‏ "‏ إِنَّ الْمَاءَ لاَ يُنَجِّسُهُ شَىْءٌ ‏"‏ ‏.‏\hadithno{325}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that one of the wives of the Prophet (ﷺ) performed Ghusl from Janabah, and the Prophet (ﷺ) performed Wudu' with her leftover water. She mentioned that to him and he said:"Water is not made impure by anything." [1] [1] See the following versions}}
\hadithdefcmd{nasai}{326}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ كَثِيرٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ كَعْبٍ الْقُرَظِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ رَافِعٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ أَتَتَوَضَّأُ مِنْ بِئْرِ بُضَاعَةَ وَهِيَ بِئْرٌ يُطْرَحُ فِيهَا لُحُومُ الْكِلاَبِ وَالْحِيَضُ وَالنَّتَنُ فَقَالَ ‏ "‏ الْمَاءُ طَهُورٌ لاَ يُنَجِّسُهُ شَىْءٌ ‏"‏ ‏.‏\hadithno{326}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"It was said: 'O Messenger of Allah, you perform Wudu' from the well into which the bodies of dogs, menstrual rags and garbage are thrown?' He said: 'Water is pure and it is not made impure by anything}}
\hadithdefcmd{nasai}{327}{أَخْبَرَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، قَالَ حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، - وَكَانَ مِنَ الْعَابِدِينَ - عَنْ مُطَرِّفِ بْنِ طَرِيفٍ، عَنْ خَالِدِ بْنِ أَبِي نَوْفٍ، عَنْ سَلِيطٍ، عَنِ ابْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ، قَالَ مَرَرْتُ بِالنَّبِيِّ صلى الله عليه وسلم وَهُوَ يَتَوَضَّأُ مِنْ بِئْرِ بُضَاعَةَ فَقُلْتُ أَتَتَوَضَّأُ مِنْهَا وَهِيَ يُطْرَحُ فِيهَا مَا يُكْرَهُ مِنَ النَّتْنِ فَقَالَ ‏ "‏ الْمَاءُ لاَ يُنَجِّسُهُ شَىْءٌ ‏"‏ ‏.‏\hadithno{327}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Abi Sa'eed Al-Khudri that his father said:"I passed by the Prophet (ﷺ) when he was performing Wudu' from the well of Buda'ah. I said: 'Are you performing Wudu' from it when garbage is thrown into it?' He said: 'Water is not made impure by anything}}
\hadithdefcmd{nasai}{328}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ الْمَرْوَزِيُّ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمَاءِ وَمَا يَنُوبُهُ مِنَ الدَّوَابِّ وَالسِّبَاعِ فَقَالَ ‏ "‏ إِذَا كَانَ الْمَاءُ قُلَّتَيْنِ لَمْ يَحْمِلِ الْخَبَثَ ‏"‏ ‏.‏\hadithno{328}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Ubaidullah bin 'Abdullah bin 'Umar that his father said:"The Messenger of Allah (ﷺ) was asked about water and how some animals and carnivorous beasts might drink from it. He said: 'If the water is more than two Qullahs, it will not become filthy}}
\hadithdefcmd{nasai}{329}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ أَعْرَابِيًّا، بَالَ فِي الْمَسْجِدِ فَقَامَ إِلَيْهِ بَعْضُ الْقَوْمِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُزْرِمُوهُ ‏"‏ ‏.‏ فَلَمَّا فَرَغَ دَعَا بِدَلْوٍ مِنْ مَاءٍ فَصَبَّهُ عَلَيْهِ ‏.‏\hadithno{329}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that a Bedouin urinated in the Masjid, and some of the people went after him, but the Messenger of Allah (ﷺ) said:"Do not restrain him." When he had finished he called from a bucket (of water) and poured over it}}
\hadithdefcmd{nasai}{330}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، عَنْ عُمَرَ بْنِ عَبْدِ الْوَاحِدِ، عَنِ الأَوْزَاعِيِّ، عَنْ مُحَمَّدِ بْنِ الْوَلِيدِ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَامَ أَعْرَابِيٌّ فَبَالَ فِي الْمَسْجِدِ فَتَنَاوَلَهُ النَّاسُ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دَعُوهُ وَأَهْرِيقُوا عَلَى بَوْلِهِ دَلْوًا مِنْ مَاءٍ فَإِنَّمَا بُعِثْتُمْ مُيَسِّرِينَ وَلَمْ تُبْعَثُوا مُعَسِّرِينَ ‏"‏ ‏.‏\hadithno{330}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"A Bedouin stood up and urinated in the Masjid, so the people grabbed him. The Messenger of Allah (ﷺ) said to them: 'Leave him alone, and pour a bucket of water over his urine. For you have been sent to make things easy for people, you have not been sent to make things difficult}}
\hadithdefcmd{nasai}{331}{أَخْبَرَنَا الْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، عَنْ عَمْرٍو، - وَهُوَ ابْنُ الْحَارِثِ - عَنْ بُكَيْرٍ، أَنَّ أَبَا السَّائِبِ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَغْتَسِلْ أَحَدُكُمْ فِي الْمَاءِ الدَّائِمِ وَهُوَ جُنُبٌ ‏"‏ ‏.‏\hadithno{331}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'None of you should perform Ghusl in standing water while he is Junub}}
\hadithdefcmd{nasai}{332}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ سَعِيدِ بْنِ سَلَمَةَ، أَنَّ الْمُغِيرَةَ بْنَ أَبِي بُرْدَةَ، أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ سَأَلَ رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّا نَرْكَبُ الْبَحْرَ وَنَحْمِلُ مَعَنَا الْقَلِيلَ مِنَ الْمَاءِ فَإِنْ تَوَضَّأْنَا بِهِ عَطِشْنَا أَفَنَتَوَضَّأُ مِنْ مَاءِ الْبَحْرِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هُوَ الطَّهُورُ مَاؤُهُ الْحِلُّ مَيْتَتُهُ ‏"‏ ‏.‏\hadithno{332}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah said:"A man asked the prophet (ﷺ): 'O Messenger of Allah, we travel by sea and we take a little water with us, but if we use it for Wudu', we will go thirsty. Can we perform Wudu' with seawater?' The Messenger of Allah (ﷺ) said: 'Its water is a means of purification and its dead meat is permissible}}
\hadithdefcmd{nasai}{333}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ اغْسِلْ خَطَايَاىَ بِمَاءِ الثَّلْجِ وَالْبَرَدِ وَنَقِّ قَلْبِي مِنَ الْخَطَايَا كَمَا نَقَّيْتَ الثَّوْبَ الأَبْيَضَ مِنَ الدَّنَسِ ‏"‏ ‏.‏\hadithno{333}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Prophet (ﷺ) used to say: 'Allahummaghsil khatayaya bi-ma'ith-thalj wal-barad was naqqi qalbi min al-khataya kama naqayta ath-thawb al-abyad min ad-danas (O Allah, wash away my sins with the water of snow and hail, and cleanse my heart of snow and hail, and cleanse my heart of sin as a white garment is cleansed of filth)}}
\hadithdefcmd{nasai}{334}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ اغْسِلْنِي مِنْ خَطَايَاىَ بِالثَّلْجِ وَالْمَاءِ وَالْبَرَدِ ‏"‏ ‏.‏\hadithno{334}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) would say: [1] 'Allahummaghsil khatayaya bi-ma'ith-thalj wal-barad (O Allah, wash away my sins with the water of snow and hail).'" [1] That is at the beginning of Salah as is clear from the remainder of the narration which preceded under No}}
\hadithdefcmd{nasai}{335}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي رَزِينٍ، وَأَبِي، صَالِحٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وَلَغَ الْكَلْبُ فِي إِنَاءِ أَحَدِكُمْ فَلْيُرِقْهُ ثُمَّ لْيَغْسِلْهُ سَبْعَ مَرَّاتٍ ‏"‏ ‏.‏\hadithno{335}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'If a dog licks the vessel of any one of you, let him throw (the contents) away and wash it seven times}}
\hadithdefcmd{nasai}{336}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - عَنْ شُعْبَةَ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ مُطَرِّفًا، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِقَتْلِ الْكِلاَبِ وَرَخَّصَ فِي كَلْبِ الصَّيْدِ وَالْغَنَمِ وَقَالَ ‏ "‏ إِذَا وَلَغَ الْكَلْبُ فِي الإِنَاءِ فَاغْسِلُوهُ سَبْعَ مَرَّاتٍ وَعَفِّرُوهُ الثَّامِنَةَ بِالتُّرَابِ ‏"‏ ‏.‏\hadithno{336}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah bin Mughaffal that the Messenger of Allah (ﷺ) commanded that dogs be killed, but he made an exception for hunting dogs and sheepdogs and said:"If a dog licks a vessel then wash it seven times and rub it the eighth time with dust}}
\hadithdefcmd{nasai}{337}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، قَالَ حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، يَزِيدَ بْنِ حُمَيْدٍ قَالَ سَمِعْتُ مُطَرِّفًا، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَتْلِ الْكِلاَبِ قَالَ ‏"‏ مَا بَالُهُمْ وَبَالُ الْكِلاَبِ ‏"‏ ‏.‏ قَالَ وَرَخَّصَ فِي كَلْبِ الصَّيْدِ وَكَلْبِ الْغَنَمِ وَقَالَ ‏"‏ إِذَا وَلَغَ الْكَلْبُ فِي الإِنَاءِ فَاغْسِلُوهُ سَبْعَ مَرَّاتٍ وَعَفِّرُوا الثَّامِنَةَ بِالتُّرَابِ ‏"‏ ‏.‏ خَالَفَهُ أَبُو هُرَيْرَةَ فَقَالَ إِحْدَاهُنَّ بِالتُّرَابِ ‏.‏\hadithno{337}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin Mughaffal said:"The Messenger of Allah (ﷺ) commanded that dogs be killed. He said: 'What do they have to do with dogs?' And he granted a concession regarding hunting dogs and sheepdogs. And he said: 'If a dog licks a vessel, wash it seven times, and rub it the eighth time with dust.' Abu Hurairah differed from him and said: 'Rub it one time with dust}}
\hadithdefcmd{nasai}{338}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ خِلاَسٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا وَلَغَ الْكَلْبُ فِي إِنَاءِ أَحَدِكُمْ فَلْيَغْسِلْهُ سَبْعَ مَرَّاتٍ أُولاَهُنَّ بِالتُّرَابِ ‏"‏ ‏.‏\hadithno{338}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"If a dog licks the vessel of any one of you, let him wash it seven times, the first time with dust}}
\hadithdefcmd{nasai}{339}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا وَلَغَ الْكَلْبُ فِي إِنَاءِ أَحَدِكُمْ فَلْيَغْسِلْهُ سَبْعَ مَرَّاتٍ أُولاَهُنَّ بِالتُّرَابِ ‏"‏ ‏.‏\hadithno{339}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"If a dog licks the vessel of any one of you, let him wash it seven times, the first time with dust}}
\hadithdefcmd{nasai}{340}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ حُمَيْدَةَ بِنْتِ عُبَيْدِ بْنِ رِفَاعَةَ، عَنْ كَبْشَةَ بِنْتِ كَعْبِ بْنِ مَالِكٍ، أَنَّ أَبَا قَتَادَةَ، دَخَلَ عَلَيْهَا ثُمَّ ذَكَرَ كَلِمَةً مَعْنَاهَا فَسَكَبْتُ لَهُ وَضُوءًا فَجَاءَتْ هِرَّةٌ فَشَرِبَتْ مِنْهُ فَأَصْغَى لَهَا الإِنَاءَ حَتَّى شَرِبَتْ قَالَتْ كَبْشَةُ فَرَآنِي أَنْظُرُ إِلَيْهِ فَقَالَ أَتَعْجَبِينَ يَا ابْنَةَ أَخِي قُلْتُ نَعَمْ ‏.‏ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّهَا لَيْسَتْ بِنَجَسٍ إِنَّمَا هِيَ مِنَ الطَّوَّافِينَ عَلَيْكُمْ وَالطَّوَّافَاتِ ‏"‏ ‏.‏\hadithno{340}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Kabshah bint Ka'ab bin Malik that Abu Qatadah entered upon her, then she narrated the following:"I poured some water for him for Wudu', and a cat came and drank from it, so he tilted the vessel for it to drink." Kabshah said: "He saw me looking at him and said: 'Are you surprised, O daughter of my brother?' I said: 'Yes.' He said: 'The Messenger of Allah (ﷺ) said: 'They are not impure, rather they are among the males and females (animals) who go around among you}}
\hadithdefcmd{nasai}{341}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كُنْتُ أَتَعَرَّقُ الْعَرْقَ فَيَضَعُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاهُ حَيْثُ وَضَعْتُهُ وَأَنَا حَائِضٌ وَكُنْتُ أَشْرَبُ مِنَ الإِنَاءِ فَيَضَعُ فَاهُ حَيْثُ وَضَعْتُ وَأَنَا حَائِضٌ ‏.‏\hadithno{341}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah, may Allah be pleased with her, said:"While I was menstruating, I would nibble meat from a bone and the Messenger of Allah (ﷺ) would put his mouth where mine has been. And while I was menstruating, I would drink from a vessel and he would put his mouth where mine had been}}
\hadithdefcmd{nasai}{342}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ الرِّجَالُ وَالنِّسَاءُ يَتَوَضَّئُونَ فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم جَمِيعًا ‏.‏\hadithno{342}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"Men and women used to perform Wudu' together during the time of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{343}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ الأَحْوَلِ، قَالَ سَمِعْتُ أَبَا حَاجِبٍ، - قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَاسْمُهُ سَوَادَةُ بْنُ عَاصِمٍ - عَنِ الْحَكَمِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يَتَوَضَّأَ الرَّجُلُ بِفَضْلِ وَضُوءِ الْمَرْأَةِ ‏.‏\hadithno{343}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Al-Hakam bin 'Amr that the Messenger of Allah (ﷺ) forbade a man from performing Wudu' with the leftovers of a woman's (water for) Wudu}}
\hadithdefcmd{nasai}{344}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا كَانَتْ تَغْتَسِلُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الإِنَاءِ الْوَاحِدِ ‏.‏\hadithno{344}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that she used to perform Ghusl with the Messenger of Allah (ﷺ) from a single vessel}}
\hadithdefcmd{nasai}{345}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ جَبْرٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ بِمَكُّوكٍ وَيَغْتَسِلُ بِخَمْسَةِ مَكَاكِيَّ ‏.‏\hadithno{345}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin Jabr said:"I heard Anas bin Malik say: 'The Messenger of Allah (ﷺ) used to perform Wudu' with a Makkuk (cup) and Ghusl with five Makkuks (cups)}}
\hadithdefcmd{nasai}{346}{أَخْبَرَنَا هَارُونُ بْنُ إِسْحَاقَ الْكُوفِيُّ، قَالَ حَدَّثَنَا عَبْدَةُ، - يَعْنِي ابْنَ سُلَيْمَانَ - عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَتَوَضَّأُ بِمُدٍّ وَيَغْتَسِلُ بِنَحْوِ الصَّاعِ ‏.‏\hadithno{346}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah (ﷺ) used to perform Ghusl with a Mudd and Ghusl with approximately a Sa}}
\hadithdefcmd{nasai}{347}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَوَضَّأُ بِالْمُدِّ وَيَغْتَسِلُ بِالصَّاعِ ‏.‏\hadithno{347}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) used to perform Ghusl with a Mudd and Ghusl with a Sa}}
