% Auto-generated chapter 32 for tirmidhi
% Hadiths in this chapter: 26

\hadithdefcmd{tirmidhi}{2133}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ الْبَصْرِيُّ، قَالَ حَدَّثَنَا صَالِحٌ الْمُرِّيُّ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ نَتَنَازَعُ فِي الْقَدَرِ فَغَضِبَ حَتَّى احْمَرَّ وَجْهُهُ حَتَّى كَأَنَّمَا فُقِئَ فِي وَجْنَتَيْهِ الرُّمَّانُ فَقَالَ ‏ "‏ أَبِهَذَا أُمِرْتُمْ أَمْ بِهَذَا أُرْسِلْتُ إِلَيْكُمْ إِنَّمَا هَلَكَ مَنْ كَانَ قَبْلَكُمْ حِينَ تَنَازَعُوا فِي هَذَا الأَمْرِ عَزَمْتُ عَلَيْكُمْ أَلاَّ تَتَنَازَعُوا فِيهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُمَرَ وَعَائِشَةَ وَأَنَسٍ ‏.‏ وَهَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ صَالِحٍ الْمُرِّيِّ ‏.‏ وَصَالِحٌ الْمُرِّيُّ لَهُ غَرَائِبُ يَنْفَرِدُ بِهَا لاَ يُتَابَعُ عَلَيْهَا ‏.‏\hadithno{2133}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated:"The Messenger of Allah(s.a.w) came out to us while we were discussing about Al-Qadar. He became angry such that his face became red, as if a pomegranate was bursting through his cheeks. He said: 'Is this what I ordered you to do?' - or: 'Is this what I have been sent to you with? The people before you were only ruined when they differed about this matter. I order you [I order you] to not debate about it.'". (Daif)}}
\hadithdefcmd{tirmidhi}{2134}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبِي، عَنْ سُلَيْمَانَ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ احْتَجَّ آدَمُ وَمُوسَى فَقَالَ مُوسَى يَا آدَمُ أَنْتَ الَّذِي خَلَقَكَ اللَّهُ بِيَدِهِ وَنَفَخَ فِيكَ مِنْ رُوحِهِ أَغْوَيْتَ النَّاسَ وَأَخْرَجْتَهُمْ مِنَ الْجَنَّةِ ‏.‏ قَالَ فَقَالَ آدَمُ وَأَنْتَ مُوسَى الَّذِي اصْطَفَاكَ اللَّهُ بِكَلاَمِهِ أَتَلُومُنِي عَلَى عَمَلٍ عَمِلْتُهُ كَتَبَهُ اللَّهُ عَلَىَّ قَبْلَ أَنْ يَخْلُقَ السَّمَوَاتِ وَالأَرْضَ قَالَ فَحَجَّ آدَمُ مُوسَى ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُمَرَ وَجُنْدَبٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ سُلَيْمَانَ التَّيْمِيِّ عَنِ الأَعْمَشِ ‏.‏ وَقَدْ رَوَى بَعْضُ أَصْحَابِ الأَعْمَشِ عَنِ الأَعْمَشِ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ وَقَالَ بَعْضُهُمْ عَنِ الأَعْمَشِ عَنْ أَبِي صَالِحٍ عَنْ أَبِي سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2134}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Prophet(S.A.W) said:"Adam and Musa argued, Musa said: "O Adam! You are the one that Allah created with His Hand, and blew into you of His Spirit, and you misled the people and caused them to be expelled from Paradise.' So Adam said: 'You are Musa, the one Allah selected with His Speech! Are you blaming me for something I did which Allah had decreed for me, before creating the heavens and the earth?'" He said: " So Adam confuted Musa}}
\hadithdefcmd{tirmidhi}{2135}{حَدَّثَنَا بُنْدَارٌ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، قَالَ سَمِعْتُ سَالِمَ بْنَ عَبْدِ اللَّهِ، يُحَدِّثُ عَنْ أَبِيهِ، قَالَ قَالَ عُمَرُ يَا رَسُولَ اللَّهِ أَرَأَيْتَ مَا نَعْمَلُ فِيهِ أَمْرٌ مُبْتَدَعٌ أَوْ مُبْتَدَأٌ أَوْ فِيمَا قَدْ فُرِغَ مِنْهُ فَقَالَ ‏ "‏ فِيمَا قَدْ فُرِغَ مِنْهُ يَا ابْنَ الْخَطَّابِ وَكُلٌّ مُيَسَّرٌ أَمَّا مَنْ كَانَ مِنْ أَهْلِ السَّعَادَةِ فَإِنَّهُ يَعْمَلُ لِلسَّعَادَةِ وَأَمَّا مَنْ كَانَ مِنْ أَهْلِ الشَّقَاءِ فَإِنَّهُ يَعْمَلُ لِلشَّقَاءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ وَحُذَيْفَةَ بْنِ أَسِيدٍ وَأَنَسٍ وَعِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2135}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Asim bin 'Ubaidullah said:' I heard Salim bin 'Abdullah narrating a Hadith from his father who said: "'Umar said : "O Messenger of Allah! Do you see that what we do is a new matter- or a matter initiated – or it is a matter already concluded?” He (s.a.w) said: “ O Ibn Al-Khattab! It is a matter already concluded. For everyone is suited (for that for which he is created). As for one who is among the people of happiness, then he works for happiness, and as for the one who is among the people of misery, then he works for his misery.” (Hasan)}}
\hadithdefcmd{tirmidhi}{2136}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ،قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ، قَالَ بَيْنَمَا نَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يَنْكُتُ فِي الأَرْضِ إِذْ رَفَعَ رَأْسَهُ إِلَى السَّمَاءِ ثُمَّ قَالَ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ إِلاَّ قَدْ عُلِمَ وَقَالَ وَكِيعٌ إِلاَّ قَدْ كُتِبَ مَقْعَدُهُ مِنَ النَّارِ وَمَقْعَدُهُ مِنَ الْجَنَّةِ ‏"‏ ‏.‏ قَالُوا أَفَلاَ نَتَّكِلُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لاَ اعْمَلُوا فَكُلٌّ مُيَسَّرٌ لِمَا خُلِقَ لَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2136}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ali narrated:"We were with the Messenger of Allah (s.a.w) and he was scraping the ground, when he raised his head to the heavens, then said: 'There is not one of you but (his place) is known' – Waki said: 'His place has been decreed (be it) in the Fire, and (or) his place in Paradise.' They said: 'Shall we not rely upon this O Messenger of Allah?' He said: 'No. Work, for everyone is facilitated for what he was created.'”(Sahih)}}
\hadithdefcmd{tirmidhi}{2137}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالَ عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ الصَّادِقُ الْمَصْدُوقُ ‏ "‏ إِنَّ أَحَدَكُمْ يُجْمَعُ خَلْقُهُ فِي بَطْنِ أُمِّهِ فِي أَرْبَعِينَ يَوْمًا ثُمَّ يَكُونُ عَلَقَةً مِثْلَ ذَلِكَ ثُمَّ يَكُونُ مُضْغَةً مِثْلَ ذَلِكَ ثُمَّ يُرْسِلُ اللَّهُ إِلَيْهِ الْمَلَكَ فَيَنْفُخُ فِيهِ وَيُؤْمَرُ بِأَرْبَعٍ يَكْتُبُ رِزْقَهُ وَأَجَلَهُ وَعَمَلَهُ وَشَقِيٌّ أَوْ سَعِيدٌ فَوَالَّذِي لاَ إِلَهَ غَيْرُهُ إِنَّ أَحَدَكُمْ لَيَعْمَلُ بِعَمَلِ أَهْلِ الْجَنَّةِ حَتَّى مَا يَكُونُ بَيْنَهُ وَبَيْنَهَا إِلاَّ ذِرَاعٌ ثُمَّ يَسْبِقُ عَلَيْهِ الْكِتَابُ فَيُخْتَمُ لَهُ بِعَمَلِ أَهْلِ النَّارِ فَيَدْخُلُهَا وَإِنَّ أَحَدَكُمْ لَيَعْمَلُ بِعَمَلِ أَهْلِ النَّارِ حَتَّى مَا يَكُونُ بَيْنَهُ وَبَيْنَهَا إِلاَّ ذِرَاعٌ ثُمَّ يَسْبِقُ عَلَيْهِ الْكِتَابُ فَيُخْتَمُ لَهُ بِعَمَلِ أَهْلِ الْجَنَّةِ فَيَدْخُلُهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا زَيْدُ بْنُ وَهْبٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ مِثْلَهُ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى شُعْبَةُ وَالثَّوْرِيُّ عَنِ الأَعْمَشِ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَنَسٍ ‏.‏ وَسَمِعْتُ أَحْمَدَ بْنَ الْحَسَنِ قَالَ سَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ يَقُولُ مَا رَأَيْتُ بِعَيْنِي مِثْلَ يَحْيَى بْنِ سَعِيدٍ الْقَطَّانِ و هذا حديث حسن صحيح. وقد روى شعبة والثوري عن عن الأعمش نحوه. حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ زَيْدٍ، نَحْوَهُ ‏.‏\hadithno{2137}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Mas'ud said:The Messenger of Allah (s.a.w) narrated to us - and he is the truthful and entrusted one: 'Indeed the creation of one of you is gathered inside his mother in forty days. Then, for a similar period, he is a clot. Then, for a similar period, he is a piece of flesh. Then Allah sends the angel to him to blow the soul into him, and he is ordered to write four (things): To write his provision, his life-span, his works, and whether he will be wretched or happy. By the One besides Whom there is none other worthy of worship! One of you will do deeds of the people of Paradise, until there is between him and it but a forearm span, then he is overcome by what is written for him, and he is sealed off with the deeds of the people of the Fire, so that he enters it. And indeed one of you will do deeds of the people of the Fire, until there is between him and it but a forearm span, then he is overcome by what is written for him, and he is sealed off with the deeds of the people of Paradise, so that he enters it.'" Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2138}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الْقُطَعِيُّ الْبَصْرِيُّ، قال: حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ رَبِيعَةَ الْبُنَانِيُّ، قال: حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُلُّ مَوْلُودٍ يُولَدُ عَلَى الْمِلَّةِ فَأَبَوَاهُ يُهَوِّدَانِهِ أَوْ يُنَصِّرَانِهِ أَوْ يُشَرِّكَانِهِ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ فَمَنْ هَلَكَ قَبْلَ ذَلِكَ قَالَ ‏"‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ بِهِ ‏"‏ ‏.‏ حَدَّثَنَا أَبُو كُرَيْبٍ، وَالْحُسَيْنُ بْنُ حُرَيْثٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِمَعْنَاهُ وَقَالَ ‏"‏ يُولَدُ عَلَى الْفِطْرَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ شُعْبَةُ وَغَيْرُهُ عَنِ الأَعْمَشِ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏ وَفِي الْبَابِ عَنِ الأَسْوَدِ بْنِ سَرِيعٍ ‏.‏\hadithno{2138}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"Every child is born upon the Millah, then his parents make him a Jew, a Christian, or an idolater." It was said: "O Messenger of Allah! What about those who die before that?" He said: "Allah knows best what they would have done." [Another chain) with similar in meaning, and he said: "Born upon the Fiirah}}
\hadithdefcmd{tirmidhi}{2139}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، وَسَعِيدُ بْنُ يَعْقُوبَ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ الضُّرَيْسِ، عَنْ أَبِي مَوْدُودٍ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ سَلْمَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَرُدُّ الْقَضَاءَ إِلاَّ الدُّعَاءُ وَلاَ يَزِيدُ فِي الْعُمُرِ إِلاَّ الْبِرُّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي أُسَيْدٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ سَلْمَانَ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ يَحْيَى بْنِ الضُّرَيْسِ ‏.‏ وَأَبُو مَوْدُودٍ اثْنَانِ أَحَدُهُمَا يُقَالُ لَهُ فِضَّةٌ وَهُوَ الَّذِي رَوَى هَذَا الْحَدِيثَ اسْمُهُ فِضَّةٌ بَصْرِيٌّ وَالآخَرُ عَبْدُ الْعَزِيزِ بْنُ أَبِي سُلَيْمَانَ أَحَدُهُمَا بَصْرِيٌّ وَالآخَرُ مَدَنِيٌّ وَكَانَا فِي عَصْرٍ وَاحِدٍ وابو مودود الذي روى هذا الحديث أسمه فضة بصري. ‏\hadithno{2139}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Salman narrated that the Messenger of Allah (s.a.w) said:"Nothing turns back the Decree except supplication, and nothing increases the life-span except righteousness}}
\hadithdefcmd{tirmidhi}{2140}{حَدَّثَنَا هَنَّادٌ، قال حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكْثِرُ أَنْ يَقُولَ ‏"‏ يَا مُقَلِّبَ الْقُلُوبِ ثَبِّتْ قَلْبِي عَلَى دِينِكَ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ آمَنَّا بِكَ وَبِمَا جِئْتَ بِهِ فَهَلْ تَخَافُ عَلَيْنَا قَالَ ‏"‏ نَعَمْ إِنَّ الْقُلُوبَ بَيْنَ أَصْبُعَيْنِ مِنْ أَصَابِعِ اللَّهِ يُقَلِّبُهَا كَيْفَ يَشَاءُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ النَّوَّاسِ بْنِ سَمْعَانَ وَأُمِّ سَلَمَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَائِشَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ وَهَكَذَا رَوَى غَيْرُ وَاحِدٍ عَنِ الأَعْمَشِ عَنْ أَبِي سُفْيَانَ عَنْ أَنَسٍ ‏.‏ وَرَوَى بَعْضُهُمْ عَنِ الأَعْمَشِ عَنْ أَبِي سُفْيَانَ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَحَدِيثُ أَبِي سُفْيَانَ عَنْ أَنَسٍ أَصَحُّ ‏.‏\hadithno{2140}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Anas narrated:"The Messenger of Allah (s.a.w) would often say: Ya Muqallibal-qulub, thabbit qalbi 'ala dinik('O Changer of the Hearts! Strengthen my heart upon Your Religion.)' So I said: 'O Prophet of Allah! We believe in you and what you have come with, but do you fear for us?' He said: 'Yes. Indeed the hearts are between two Fingers of Allah's Fingers, He changes them as He wills}}
\hadithdefcmd{tirmidhi}{2141}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قال: حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي قَبِيلٍ، عَنْ شُفَىِّ بْنِ مَاتِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِي، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَفِي يَدِهِ كِتَابَانِ فَقَالَ ‏"‏ أَتَدْرُونَ مَا هَذَانِ الْكِتَابَانِ ‏"‏ ‏.‏ فَقُلْنَا لاَ يَا رَسُولَ اللَّهِ إِلاَّ أَنْ تُخْبِرَنَا ‏.‏ فَقَالَ لِلَّذِي فِي يَدِهِ الْيُمْنَى ‏"‏ هَذَا كِتَابٌ مِنْ رَبِّ الْعَالَمِينَ فِيهِ أَسْمَاءُ أَهْلِ الْجَنَّةِ وَأَسْمَاءُ آبَائِهِمْ وَقَبَائِلِهِمْ ثُمَّ أُجْمِلَ عَلَى آخِرِهِمْ فَلاَ يُزَادُ فِيهِمْ وَلاَ يُنْقَصُ مِنْهُمْ أَبَدًا ‏"‏ ‏.‏ ثُمَّ قَالَ لِلَّذِي فِي شِمَالِهِ ‏"‏ هَذَا كِتَابٌ مِنْ رَبِّ الْعَالَمِينَ فِيهِ أَسْمَاءُ أَهْلِ النَّارِ وَأَسْمَاءُ آبَائِهِمْ وَقَبَائِلِهِمْ ثُمَّ أُجْمِلَ عَلَى آخِرِهِمْ فَلاَ يُزَادُ فِيهِمْ وَلاَ يُنْقَصُ مِنْهُمْ أَبَدًا ‏"‏ ‏.‏ فَقَالَ أَصْحَابُهُ فَفِيمَ الْعَمَلُ يَا رَسُولَ اللَّهِ إِنْ كَانَ أَمْرٌ قَدْ فُرِغَ مِنْهُ فَقَالَ ‏"‏ سَدِّدُوا وَقَارِبُوا فَإِنَّ صَاحِبَ الْجَنَّةِ يُخْتَمُ لَهُ بِعَمَلِ أَهْلِ الْجَنَّةِ وَإِنْ عَمِلَ أَىَّ عَمَلٍ وَإِنَّ صَاحِبَ النَّارِ يُخْتَمُ لَهُ بِعَمَلِ أَهْلِ النَّارِ وَإِنْ عَمِلَ أَىَّ عَمَلٍ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدَيْهِ فَنَبَذَهُمَا ثُمَّ قَالَ ‏"‏ فَرَغَ رَبُّكُمْ مِنَ الْعِبَادِ فَرِيقٌ فِي الْجَنَّةِ وَفَرِيقٌ فِي السَّعِيرِ ‏"‏ ‏.‏ حَدَّثَنَا قُتَيْبَةُ حَدَّثَنَا بَكْرُ بْنُ مُضَرَ عَنْ أَبِي قَبِيلٍ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏ وَأَبُو قَبِيلٍ اسْمُهُ حُيَىُّ بْنُ هَانِئٍ ‏.‏\hadithno{2141}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin 'Amr narrated:"The Messenger of Allah (s.a.w) came out to us with two books in hand. And he said: 'Do you know what these two books are?' We said: 'No, O Messenger of Allah ! Unless you inform us.' He said about the one that was in his right hand: 'This is a book from the Lord of the worlds, in it are the names of the people of Paradise, and the name of their fathers and their tribes. Then there is a summary at the end of them, there being no addition to them nor deduction from them forever.' Then he said about the one that was in his left: 'This is a book from the Lord of the worlds, in it are the names of the people of Fire, and the name of their fathers and their tribes. Then there is a summary at the end of them, there being no addition to them nor deduction from them forever.' The companions said: 'So why work O Messenger of Allah! Since the matter is already decided (and over)?' He said: 'Seek to do what is right and draw nearer, for indeed the inhabitant of Paradise, shall have his work sealed off with the deeds of the people of Paradise, whichever deeds he did. And indeed the inhabitant of Fire, shall have his work sealed off with the deeds of the people of Fire, whichever deeds he did.' Then the Messenger of Allah motioned with his hands, casting them down and said: 'Your Lord finished with the slaves, a group in Paradise, and a group in the Blazing Fire.'" Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2142}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قال: حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا أَرَادَ اللَّهُ بِعَبْدٍ خَيْرًا اسْتَعْمَلَهُ ‏"‏ ‏.‏ فَقِيلَ كَيْفَ يَسْتَعْمِلُهُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ يُوَفِّقُهُ لِعَمَلٍ صَالِحٍ قَبْلَ الْمَوْتِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2142}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas narrated that the Messenger of Allah (s.a.w) said:"When Allah wants good for a slave, He puts him in action." It was said: "How does he put him in action O Messenger Of Allah?" He said: "By making him meet up with the righteous deeds before death}}
\hadithdefcmd{tirmidhi}{2143}{حَدَّثَنَا بُنْدَارٌ، قال: حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، حَدَّثَنَا أَبُو زُرْعَةَ بْنُ عَمْرِو بْنِ جَرِيرٍ، قَالَ حَدَّثَنَا صَاحِبٌ، لَنَا عَنِ ابْنِ مَسْعُودٍ، قَالَ قَامَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ لاَ يُعْدِي شَيْءٌ شَيْئًا ‏"‏ ‏.‏ فَقَالَ أَعْرَابِيٌّ يَا رَسُولَ اللَّهِ الْبَعِيرُ الْجَرِبُ الْحَشَفَةُ نُدْبِنُهُ فَيُجْرِبُ الإِبِلَ كُلَّهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَمَنْ أَجْرَبَ الأَوَّلَ لاَ عَدْوَى وَلاَ صَفَرَ خَلَقَ اللَّهُ كُلَّ نَفْسٍ وَكَتَبَ حَيَاتَهَا وَرِزْقَهَا وَمَصَائِبَهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ وَأَنَسٍ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدَ بْنَ عَمْرِو بْنِ صَفْوَانَ الثَّقَفِيَّ الْبَصْرِيَّ قَالَ سَمِعْتُ عَلِيَّ بْنَ الْمَدِينِيِّ يَقُولُ لَوْ حَلَفْتُ بَيْنَ الرُّكْنِ وَالْمَقَامِ لَحَلفْتُ أَنِّي لَمْ أَرَ أَحَدًا أَعْلَمَ مِنْ عَبْدِ الرَّحْمَنِ بْنِ مَهْدِيٍّ ‏.‏\hadithno{2143}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Mas'ud narrated:"The Messenger of Allah (s.a.w) stood among us and said: 'One thing does not infect another.' So a Bedouin said: 'O Messenger of Allah! If a camel gets mangy glands and we leave it at the resting place of camels, then all of the camels get mange?' The Messenger of Allah (s.a.w) said: 'Who caused the first to get mange? There is no 'Adwa nor safar. Allah created every soul, so he wrote its life, its provision, and its afflictions.'" Note: The majority of scholars interpret this to mean that these things in and of themselves do not transmit or cause harm through supernatural or hidden means but that Allah is ultimately in control and any fearful superstition around these is false}}
\hadithdefcmd{tirmidhi}{2144}{حَدَّثَنَا أَبُو الْخَطَّابِ، زِيَادُ بْنُ يَحْيَى الْبَصْرِيُّ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَيْمُونٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُؤْمِنُ عَبْدٌ حَتَّى يُؤْمِنَ بِالْقَدَرِ خَيْرِهِ وَشَرِّهِ حَتَّى يَعْلَمَ أَنَّ مَا أَصَابَهُ لَمْ يَكُنْ لِيُخْطِئَهُ وَأَنَّ مَا أَخْطَأَهُ لَمْ يَكُنْ لِيُصِيبَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُبَادَةَ وَجَابِرٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ وَهَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ مَيْمُونٍ ‏.‏ وَعَبْدُ اللَّهِ بْنُ مَيْمُونٍ مُنْكَرُ الْحَدِيثِ ‏.‏\hadithno{2144}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Jabir bin 'Abdullah narrated that the Messenger of Allah (s.a.w) said:'A slave (of Allah) shall not believe until he believes in Al-Qadar, its good and its bad, such that he knows that what struck him would not have missed him, and that what missed him would not have struck him}}
\hadithdefcmd{tirmidhi}{2145}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قال: حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُؤْمِنُ عَبْدٌ حَتَّى يُؤْمِنَ بِأَرْبَعٍ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي مُحَمَّدٌ رَسُولُ اللَّهِ بَعَثَنِي بِالْحَقِّ وَيُؤْمِنُ بِالْمَوْتِ وَبِالْبَعْثِ بَعْدَ الْمَوْتِ وَيُؤْمِنُ بِالْقَدَرِ ‏"‏ ‏.‏ حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، عَنْ شُعْبَةَ، نَحْوَهُ إِلاَّ أَنَّهُ قَالَ رِبْعِيٌّ عَنْ رَجُلٍ، عَنْ عَلِيٍّ، ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي دَاوُدَ عَنْ شُعْبَةَ، عِنْدِي أَصَحُّ مِنْ حَدِيثِ النَّضْرِ وَهَكَذَا رَوَى غَيْرُ وَاحِدٍ عَنْ مَنْصُورٍ عَنْ رِبْعِيٍّ عَنْ عَلِيٍّ ‏.‏ حَدَّثَنَا الْجَارُودُ قَالَ سَمِعْتُ وَكِيعًا يَقُولُ بَلَغَنَا أَنَّ رِبْعِيًّا لَمْ يَكْذِبْ فِي الإِسْلاَمِ كِذْبَةً ‏.‏\hadithno{2145}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ali narrated that the Messenger of Allah (s.a.w) said:'A slave (of Allah) shall not believe until he believes in four: The testimony of La Ilaha Illallah, and that I am the Messenger of Allah whom He sent with the Truth, and he believes in the death, and he believes in the Resurrection after death, and he believes in Al-Qadar." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2146}{حَدَّثَنَا بُنْدَارٌ, قَالَ: حَدَّثَنَا مُؤَمَّلٌ، قَالَ: حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ مَطَرِ بْنِ عُكَامِسٍ، قَالَ: قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا قَضَى اللَّهُ لِعَبْدٍ أَنْ يَمُوتَ بِأَرْضٍ جَعَلَ لَهُ إِلَيْهَا حَاجَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي عَزَّةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَلاَ يُعْرَفُ لِمَطَرِ بْنِ عُكَامِسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم غَيْرُ هَذَا الْحَدِيثِ. حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا مُؤَمَّلٌ، وَأَبُو دَاوُدَ الْحَفَرِيُّ عَنْ سُفْيَانَ، نَحْوَهُ ‏.‏\hadithno{2146}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Matar bin 'Ukamis narrated that the Messenger of Allah (s.a.w) said:"When Allah decrees that a slave (of His) is to die in a land, He makes him have some need from it." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2147}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَعَلِيُّ بْنُ حُجْرٍ، - الْمَعْنَى وَاحِدٌ قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ أَبِي الْمَلِيحِ بْنِ أُسَامَةَ، عَنْ أَبِي عَزَّةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا قَضَى اللَّهُ لِعَبْدٍ أَنْ يَمُوتَ بِأَرْضٍ جَعَلَ لَهُ إِلَيْهَا حَاجَةً أَوْ قَالَ بِهَا حَاجَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَأَبُو عَزَّةَ لَهُ صُحْبَةٌ وَاسْمُهُ يَسَارُ بْنُ عَبْدٍ وَأَبُو الْمَلِيحِ اسْمُهُ عَامِرُ بْنُ أُسَامَةَ بْنِ عُمَيْرٍ الْهُذَلِيُّ وَيُقَالُ زَيْدُ بْنُ أُسَامَةَ ‏.‏\hadithno{2147}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu 'Azzah narrated that the Messenger of Allah (s.a.w) said:"When Allah decrees that a slave (of His) is to die in a land, He makes him have some need from it." Or, he said: "In it}}
\hadithdefcmd{tirmidhi}{2148}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، قال: حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ أَبِي خُزَامَةَ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ رُقًى نَسْتَرْقِيهَا وَدَوَاءً نَتَدَاوَى بِهِ وَتُقَاةً نَتَّقِيهَا هَلْ تَرُدُّ مِنْ قَدَرِ اللَّهِ شَيْئًا فَقَالَ ‏ "‏ هِيَ مِنْ قَدَرِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الزُّهْرِيِّ وَقَدْ رَوَى غَيْرُ وَاحِدٍ هَذَا عَنْ سُفْيَانَ عَنِ الزُّهْرِيِّ عَنْ أَبِي خُزَامَةَ عَنْ أَبِيهِ وَهَذَا أَصَحُّ هَكَذَا قَالَ غَيْرُ وَاحِدٍ عَنِ الزُّهْرِيِّ عَنْ أَبِي خُزَامَةَ عَنْ أَبِيهِ ‏.‏\hadithno{2148}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abi Khizamah narrated from his father,that a man came to the Prophet(s.a.w) and said:"O Messenger of Allah! Do you think that the Ruqyah we use, the treatments we use, and what we seek to protect ourselves with prevent anything from Allah's Decree?' He said: 'They are from Allah's Decree}}
\hadithdefcmd{tirmidhi}{2149}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى الْكُوفِيُّ، قال: حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنِ الْقَاسِمِ بْنِ حَبِيبٍ، وَعَلِيِّ بْنِ نِزَارٍ، عَنْ نِزَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صِنْفَانِ مِنْ أُمَّتِي لَيْسَ لَهُمَا فِي الإِسْلاَمِ نَصِيبٌ الْمُرْجِئَةُ وَالْقَدَرِيَّةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُمَرَ وَابْنِ عُمَرَ وَرَافِعِ بْنِ خَدِيجٍ ‏.‏ وَهَذَا حَدِيثٌ غَرِيبٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، قال: حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، قال: حَدَّثَنَا سَلاَّمُ بْنُ أَبِي عَمْرَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ مُحَمَّدُ بْنُ رَافِعٍ وَأَخْبَرَنَا مُحَمَّدُ بْنُ بِشْرٍ أَخْبَرَنَا عَلِيُّ بْنُ نِزَارٍ عَنْ نِزَارٍ عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2149}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn 'Abbas narrated that the Messenger of Allah (s.a.w) said:"There are two groups in my Ummah for whom there is no share in Islam: The Murji'ah and the Qadariyyah." Another chain reports a similar narration}}
\hadithdefcmd{tirmidhi}{2150}{حَدَّثَنَا أَبُو هُرَيْرَةَ، مُحَمَّدُ بْنُ فِرَاسٍ الْبَصْرِيُّ, قال: حَدَّثَنَا أَبُو قُتَيْبَةَ، سَلْمُ بْنُ قُتَيْبَةَ حَدَّثَنَا أَبُو الْعَوَّامِ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ ابْنِ آدَمَ وَإِلَى جَنْبِهِ تِسْعٌ وَتِسْعُونَ مَنِيَّةً إِنْ أَخْطَأَتْهُ الْمَنَايَا وَقَعَ فِي الْهَرَمِ حَتَّى يَمُوتَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأَبُو الْعَوَّامِ هُوَ عِمْرَانُ وَهُوَ ابْنُ دَاوَرَ الْقَطَّانُ ‏.‏\hadithno{2150}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Mutarrif bin 'Abdullah bin Ash-Shikh-khir narrated from his father, from the Prophet (s.a.w), who said:'Ibn Adam was fashioned with ninety-nine calamities surrounding him, if the calamities miss him, he is stricken by decrepitude until he dies}}
\hadithdefcmd{tirmidhi}{2151}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قال: حَدَّثَنَا أَبُو عَامِرٍ، عَنْ مُحَمَّدِ بْنِ أَبِي حُمَيْدٍ، عَنْ إِسْمَاعِيلَ بْنِ مُحَمَّدِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، عَنْ سَعْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مِنْ سَعَادَةِ ابْنِ آدَمَ رِضَاهُ بِمَا قَضَى اللَّهُ لَهُ وَمِنْ شَقَاوَةِ ابْنِ آدَمَ تَرْكُهُ اسْتِخَارَةَ اللَّهِ وَمِنْ شَقَاوَةِ ابْنِ آدَمَ سَخَطُهُ بِمَا قَضَى اللَّهُ لَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ أَبِي حُمَيْدٍ ‏.‏ وَيُقَالُ لَهُ أَيْضًا حَمَّادُ بْنُ أَبِي حُمَيْدٍ وَهُوَ أَبُو إِبْرَاهِيمَ الْمَدَنِيُّ وَلَيْسَ هُوَ بِالْقَوِيِّ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏\hadithno{2151}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Sa'd narrated that the Messenger of Allah (s.a.w) said:'From (the signs of) the son of Adam's prosperity, is his satisfaction with what Allah decreed for him, and from the son of Adam's misery is his avoiding to request guidance from Allah, and from the son of Adam's misery is his anger with what Allah decreed for him}}
\hadithdefcmd{tirmidhi}{2152}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قال: حَدَّثَنَا أَبُو عَاصِمٍ، قال: حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، أَخْبَرَنِي أَبُو صَخْرٍ، قَالَ حَدَّثَنِي نَافِعٌ، أَنَّ ابْنَ عُمَرَ، جَاءَهُ رَجُلٌ فَقَالَ إِنَّ فُلاَنًا يَقْرَأُ عَلَيْكَ السَّلاَمَ ‏.‏ فَقَالَ لَهُ إِنَّهُ بَلَغَنِي أَنَّهُ قَدْ أَحْدَثَ فَإِنْ كَانَ قَدْ أَحْدَثَ فَلاَ تُقْرِئْهُ مِنِّي السَّلاَمَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَكُونُ فِي هَذِهِ الأُمَّةِ أَوْ فِي أُمَّتِي الشَّكُّ مِنْهُ خَسْفٌ أَوْ مَسْخٌ أَوْ قَذْفٌ فِي أَهْلِ الْقَدَرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَأَبُو صَخْرٍ اسْمُهُ حُمَيْدُ بْنُ زِيَادٍ ‏.‏\hadithno{2152}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Nafi' narrated that a man came to Ibn 'Umar and said:"So-and-so conveys his Salam to you." So he said: "It has been conveyed to me that he has innovated, so if he has indeed innovated, then do not convey my Salam to him, for I heard the Messenger of Allah (s.a.w) saying: 'In this Ummah' or: 'In my Ummah'" - the doubt was his - "a collapse of the earth, or a transformation, or stones shall rain upon the people of Al-Qadr}}
\hadithdefcmd{tirmidhi}{2153}{حَدَّثَنَا قُتَيْبَةُ، قال: حَدَّثَنَا رِشْدِينُ بْنُ سَعْدٍ، عَنْ أَبِي صَخْرٍ، حُمَيْدِ بْنِ زِيَادٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ يَكُونُ فِي أُمَّتِي خَسْفٌ وَمَسْخٌ وَذَلِكَ فِي الْمُكَذِّبِينَ بِالْقَدَرِ ‏"‏ ‏.‏\hadithno{2153}\hadithgrade{Zubair Ali Zai: Hasan}\hadithtrans{Ibn 'Umar narrated from the Prophet (s.a.w):"There will be a collapse of the earth and transformation in my Ummah, and that is for those who deny Al-Qadar}}
\hadithdefcmd{tirmidhi}{2154}{حَدَّثَنَا قُتَيْبَةُ، قال: حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَبِي الْمَوَالِي الْمُزَنِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ مَوْهَبٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سِتَّةٌ لَعَنْتُهُمْ لَعَنَهُمُ اللَّهُ وَكُلُّ نَبِيٍّ كَانَ الزَّائِدُ فِي كِتَابِ اللَّهِ وَالْمُكَذِّبُ بِقَدَرِ اللَّهِ وَالْمُتَسَلِّطُ بِالْجَبَرُوتِ لِيُعِزَّ بِذَلِكَ مَنْ أَذَلَّ اللَّهُ وَيُذِلَّ مَنْ أَعَزَّ اللَّهُ وَالْمُسْتَحِلُّ لِحَرَمِ اللَّهِ وَالْمُسْتَحِلُّ مِنْ عِتْرَتِي مَا حَرَّمَ اللَّهُ وَالتَّارِكُ لِسُنَّتِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رَوَى عَبْدُ الرَّحْمَنِ بْنُ أَبِي الْمَوَالِي هَذَا الْحَدِيثَ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ مَوْهَبٍ عَنْ عَمْرَةَ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَاهُ سُفْيَانُ الثَّوْرِيُّ وَحَفْصُ بْنُ غِيَاثٍ وَغَيْرُ وَاحِدٍ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ مَوْهَبٍ عَنْ عَلِيِّ بْنِ حُسَيْنٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً وَهَذَا أَصَحُّ ‏.‏\hadithno{2154}\hadithgrade{Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Aishah narrated that the Messenger of Allah (s.a.w) said:" Six are cursed, being cursed by Allah and by every Prophet that came: The one who adds to Allah's Book, the one who denies Allah's Qadar, the one who rules with tyranny by which he honors whom Allah has debased, and he dishonors whom Allah has honored, and the one who legalizes what Allah forbade, and the one from my family who legalizes what Allah forbade, and the abandoner of my Sunnah}}
\hadithdefcmd{tirmidhi}{2155}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، قال: حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، قال: حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ سُلَيْمٍ، قَالَ قَدِمْتُ مَكَّةَ فَلَقِيتُ عَطَاءَ بْنَ أَبِي رَبَاحٍ فَقُلْتُ لَهُ يَا أَبَا مُحَمَّدٍ إِنَّ أَهْلَ الْبَصْرَةِ يَقُولُونَ فِي الْقَدَرِ ‏.‏ قَالَ يَا بُنَىَّ أَتَقْرَأُ الْقُرْآنَ قُلْتُ نَعَمْ ‏.‏ قَالَ فَاقْرَإِ الزُّخْرُفَ ‏.‏ قَالَ فَقَرَأْتُ ‏:‏ ‏(‏حم* وَالْكِتَابِ الْمُبِينِ * إِنَّا جَعَلْنَاهُ قُرْآنًا عَرَبِيًّا لَعَلَّكُمْ تَعْقِلُونَ * وَإِنَّهُ فِي أُمِّ الْكِتَابِ لَدَيْنَا لَعَلِيٌّ حَكِيمٌ ‏)‏ فَقَالَ أَتَدْرِي مَا أُمُّ الْكِتَابِ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ فَإِنَّهُ كِتَابٌ كَتَبَهُ اللَّهُ قَبْلَ أَنْ يَخْلُقَ السَّمَوَاتِ وَقَبْلَ أَنْ يَخْلُقَ الأَرْضَ فِيهِ إِنَّ فِرْعَوْنَ مِنْ أَهْلِ النَّارِ وَفِيهِ ‏:‏ ‏(‏تَبَّتْ يَدَا أَبِي لَهَبٍ وَتَبَّ ‏)‏ قَالَ عَطَاءٌ فَلَقِيتُ الْوَلِيدَ بْنَ عُبَادَةَ بْنِ الصَّامِتِ صَاحِبِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلْتُهُ مَا كَانَ وَصِيَّةُ أَبِيكَ عِنْدَ الْمَوْتِ قَالَ دَعَانِي أَبِي فَقَالَ لِي يَا بُنَىَّ اتَّقِ اللَّهَ وَاعْلَمْ أَنَّكَ لَنْ تَتَّقِيَ اللَّهَ حَتَّى تُؤْمِنَ بِاللَّهِ وَتُؤْمِنَ بِالْقَدَرِ كُلِّهِ خَيْرِهِ وَشَرِّهِ فَإِنْ مُتَّ عَلَى غَيْرِ هَذَا دَخَلْتَ النَّارَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ أَوَّلَ مَا خَلَقَ اللَّهُ الْقَلَمَ فَقَالَ اكْتُبْ ‏.‏ فَقَالَ مَا أَكْتُبُ قَالَ اكْتُبِ الْقَدَرَ مَا كَانَ وَمَا هُوَ كَائِنٌ إِلَى الأَبَدِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2155}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abdul-Wahid bin Sulaim narrated:"I arrived in Makkah and met 'Ata bin Abi Rabah. I said to him: 'O Abu Muhammad! The people of Al-Basrah speak about Al-Qadar.' He said: 'O my son! Do you recite the Quran?' I said: 'Yes.' He said: 'Then recite Az-Zukhruf to me.'" He said: 'So I recited: Ha Mim. By the manifest Book. Verily, We have made it a Qur'an in Arabic that you may be able to understand. And verily, it is in the Mother of Book with Us, indeed exalted, full of wisdom. Then he said: 'Do you know what Mother of Books is?' I said: 'Allah and His Messenger know better.' He said:'It is a book that Allah wrote before He created the Heavens, and before He created the earth. In it, it is (written): Fir'awn is among the inhabitants of the Fire, and in it is: Perish the two hands of Abu Lahab, and perish he!'Ata said: 'I met Al-Walid the son of 'Ubadah bin As-Samit the Companion of the Messenger of Allah (s.a.w) and asked him:'What was your father's admonition when he died?" He said:"He called me and said: 'O my son ! Have Taqwa of Allah, and know that you will never have Taqwa of Allah until you believe in Allah, and you believe in Al-Qadar- all of it-its good and its bad. If you die upon other than this you shall enter the Fire. Indeed I heard the Messenger of Allah (s.a.w) saying: "Verily the first of what Allah created was the Pen. So He said: 'Write.' It said : 'What shall I write?' He said : 'Write Al-Qadar, what it is , and what shall be, until the end}}
\hadithdefcmd{tirmidhi}{2156}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُنْذِرِ الْبَاهِلِيُّ الصَّنْعَانِيُّ، قال: حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، قال: حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، قال: حَدَّثَنِي أَبُو هَانِئٍ الْخَوْلاَنِيُّ، أَنَّهُ سَمِعَ أَبَا عَبْدِ الرَّحْمَنِ الْحُبُلِيَّ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ قَدَّرَ اللَّهُ الْمَقَادِيرَ قَبْلَ أَنْ يَخْلُقَ السَّمَوَاتِ وَالأَرْضَ بِخَمْسِينَ أَلْفَ سَنَةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{2156}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin 'Amr narrated that the Messenger of Allah (s.a.w) said:"Allah decreed the measures fifty-thousand years before He created the Heavens and the earth}}
\hadithdefcmd{tirmidhi}{2157}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ وَمُحَمَّدُ بْنُ بَشَّارٍ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ زِيَادِ بْنِ إِسْمَاعِيلَ، عَنْ مُحَمَّدِ بْنِ عَبَّادِ بْنِ جَعْفَرٍ الْمَخْزُومِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ مُشْرِكُو قُرَيْشٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يُخَاصِمُونَ فِي الْقَدَرِ فَنَزَلَتْ هَذِهِ الآيَةُ ‏:‏ ‏(‏يَوْمَ يُسْحَبُونَ فِي النَّارِ عَلَى وُجُوهِهِمْ ذُوقُوا مَسَّ سَقَرَ * إِنَّا كُلَّ شَيْءٍ خَلَقْنَاهُ بِقَدَرٍ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2157}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah said:"Idolaters from the Quraish came to the Messenger of Allah (s.a.w) quarreling about Al-Qadar. So this Ayah was revealed: "The day they will be dragged on their faces into the Fire (it will be said to them): "Taste you the touch of Hell." Verily we have created all things with Qadar}}
\hadithdefcmd{tirmidhi}{2298}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، عَنْ يَزِيدَ بْنِ زِيَادٍ الدِّمَشْقِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَجُوزُ شَهَادَةُ خَائِنٍ وَلاَ خَائِنَةٍ وَلاَ مَجْلُودٍ حَدًّا وَلاَ مَجْلُودَةٍ وَلاَ ذِي غِمْرٍ لأَخِيهِ وَلاَ مُجَرَّبِ شَهَادَةٍ وَلاَ الْقَانِعِ أَهْلَ الْبَيْتِ لَهُمْ وَلاَ ظَنِينٍ فِي وَلاَءٍ وَلاَ قَرَابَةٍ ‏"‏ ‏.‏ قَالَ الْفَزَارِيُّ الْقَانِعُ التَّابِعُ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ يَزِيدَ بْنِ زِيَادٍ الدِّمَشْقِيِّ ‏.‏ وَيَزِيدُ يُضَعَّفُ فِي الْحَدِيثِ وَلاَ يُعْرَفُ هَذَا الْحَدِيِثُ مِنْ حَدِيثِ الزُّهْرِيِّ إِلاَّ مِنْ حَدِيثِهِ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ وَلاَ نَعْرِفُ مَعْنَى هَذَا الْحَدِيثِ وَلاَ يَصِحُّ عِنْدِي مِنْ قِبَلِ إِسْنَادِهِ ‏.‏ وَالْعَمَلُ عِنْدَ أَهْلِ الْعِلْمِ فِي هَذَا أَنَّ شَهَادَةَ الْقَرِيبِ جَائِزَةٌ لِقَرَابَتِهِ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي شَهَادَةِ الْوَالِدِ لِلْوَلَدِ وَالْوَلَدِ لِوَالِدِهِ وَلَمْ يُجِزْ أَكْثَرُ أَهْلِ الْعِلْمِ شَهَادَةَ الْوَالِدِ لِلْوَلَدِ وَلاَ الْوَلَدِ لِلْوَالِدِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا كَانَ عَدْلاً فَشَهَادَةُ الْوَالِدِ لِلْوَلَدِ جَائِزَةٌ وَكَذَلِكَ شَهَادَةُ الْوَلَدِ لِلْوَالِدِ ‏.‏ وَلَمْ يَخْتَلِفُوا فِي شَهَادَةِ الأَخِ لأَخِيهِ أَنَّهَا جَائِزَةٌ وَكَذَلِكَ شَهَادَةُ كُلِّ قَرِيبٍ لِقَرِيبِهِ ‏.‏ وَقَالَ الشَّافِعِيُّ لاَ تَجُوزُ شَهَادَةٌ لِرَجُلٍ عَلَى الآخَرِ وَإِنْ كَانَ عَدْلاً إِذَا كَانَتْ بَيْنَهُمَا عَدَاوَةٌ ‏.‏ وَذَهَبَ إِلَى حَدِيثِ عَبْدِ الرَّحْمَنِ الأَعْرَجِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏"‏ لاَ تَجُوزُ شَهَادَةُ صَاحِبِ إِحْنَةٍ ‏"‏ ‏.‏ يَعْنِي صَاحِبَ عَدَاوَةٍ وَكَذَلِكَ مَعْنَى هَذَا الْحَدِيثِ حَيْثُ قَالَ ‏"‏ لاَ تَجُوزُ شَهَادَةُ صَاحِبِ غِمْرٍ لأَخِيهِ ‏"‏ يَعْنِي صَاحِبَ عَدَاوَةٍ ‏.‏\hadithno{2298}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated that the Messenger of Allah (s.a.w) said:The testimony of a treacherous man is not acceptable nor a treacherous woman nor a man lashed for the Hadd nor a woman lashed nor one possessing malice of enmity nor a rehearsed witness nor the Qani of (one contracted by)the family on their behalf nor the one associating himself to other than his Wala or to other than his relatives}}
