% Auto-generated chapter 30 for abudawud
% Hadiths in this chapter: 22

\hadithdefcmd{abudawud}{3904}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ حَكِيمٍ الأَثْرَمِ، عَنْ أَبِي تَمِيمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَتَى كَاهِنًا ‏"‏ ‏.‏ قَالَ مُوسَى فِي حَدِيثِهِ ‏"‏ فَصَدَّقَهُ بِمَا يَقُولُ ‏"‏ ‏.‏ ثُمَّ اتَّفَقَا ‏"‏ أَوْ أَتَى امْرَأَةً ‏"‏ ‏.‏ قَالَ مُسَدَّدٌ ‏"‏ امْرَأَتَهُ حَائِضًا أَوْ أَتَى امْرَأَةً ‏"‏ ‏.‏ قَالَ مُسَدَّدٌ ‏"‏ امْرَأَتَهُ فِي دُبُرِهَا فَقَدْ بَرِئَ مِمَّا أَنْزَلَ اللَّهُ عَلَى مُحَمَّدٍ ‏"‏ ‏.‏\hadithno{3904}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone resorts to a diviner and believes in what he says (according) to the version of Musa), or has intercourse with his wife (according to the agreed version) when she is menstruating, or has intercourse with his wife through her anus, he has nothing to do with what has been sent down to Muhammad (ﷺ) - according to the version of Musaddad}}
\hadithdefcmd{abudawud}{3905}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُسَدَّدٌ، - الْمَعْنَى - قَالاَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ بْنِ الأَخْنَسِ، عَنِ الْوَلِيدِ بْنِ عَبْدِ اللَّهِ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اقْتَبَسَ عِلْمًا مِنَ النُّجُومِ اقْتَبَسَ شُعْبَةً مِنَ السِّحْرِ زَادَ مَا زَادَ ‏"‏ ‏.‏\hadithno{3905}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: If anyone acquires any knowledge of astrology, he acquires a branch of magic of which he gets more as long as he continues to do so}}
\hadithdefcmd{abudawud}{3906}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّهُ قَالَ صَلَّى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الصُّبْحِ بِالْحُدَيْبِيَةِ فِي إِثْرِ سَمَاءٍ كَانَتْ مِنَ اللَّيْلِ فَلَمَّا انْصَرَفَ أَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏"‏ هَلْ تَدْرُونَ مَاذَا قَالَ رَبُّكُمْ ‏"‏ ‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ قَالَ أَصْبَحَ مِنْ عِبَادِي مُؤْمِنٌ بِي وَكَافِرٌ فَأَمَّا مَنْ قَالَ مُطِرْنَا بِفَضْلِ اللَّهِ وَبِرَحْمَتِهِ فَذَلِكَ مُؤْمِنٌ بِي كَافِرٌ بِالْكَوْكَبِ وَأَمَّا مَنْ قَالَ مُطِرْنَا بِنَوْءِ كَذَا وَكَذَا فَذَلِكَ كَافِرٌ بِي مُؤْمِنٌ بِالْكَوْكَبِ ‏"‏ ‏.‏\hadithno{3906}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (846) Sahih Muslim (71)}\hadithtrans{Narrated Zaid bin Khalid Al-Juhani:The Messenger of Allah (ﷺ) led us in the morning prayer at al-Hudaibiyyah after rain which has fallen during the night, and when he finished, he turned to the people and said: Do you know what your Lord has said ? They said: Allah and His Apostle know best. He said: This morning there were among mt servants one who believes in me and one who disbelieves. The one who said: "We have been given rain by Allah's grace and mercy" is the one who believes in me and disbelieves in the star ; but the one who said: "We have been given rain by such and such a rain star," is the one who disbelieves in me and believes in the star}}
\hadithdefcmd{abudawud}{3907}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا عَوْفٌ، حَدَّثَنَا حَيَّانُ، - قَالَ غَيْرُ مُسَدَّدٍ حَيَّانُ بْنُ الْعَلاَءِ - حَدَّثَنَا قَطَنُ بْنُ قَبِيصَةَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْعِيَافَةُ وَالطِّيَرَةُ وَالطَّرْقُ مِنَ الْجِبْتِ ‏"‏ ‏.‏ الطَّرْقُ الزَّجْرُ وَالْعِيَافَةُ الْخَطُّ ‏.‏\hadithno{3907}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qabisah: I heard the Messenger of Allah (ﷺ) say: Augury from the flight of birds, taking evil omens and the practice of pressomancy pertain to divination. Tarq: It is used in the sense of divination in which women threw stones. 'Iyafah: It means geomancy by drawing lines}}
\hadithdefcmd{abudawud}{3908}{حَدَّثَنَا ابْنُ بَشَّارٍ، قَالَ قَالَ مُحَمَّدُ بْنُ جَعْفَرٍ قَالَ عَوْفٌ الْعِيَافَةُ زَجْرُ الطَّيْرِ وَالطَّرْقُ الْخَطُّ يُخَطُّ فِي الأَرْضِ ‏.‏\hadithno{3908}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Muhammed b. Ja'far:On the authority of 'Awf: 'Iyafah means to makes the birds fly by threatening them. Tarq means lines drawn on the earth}}
\hadithdefcmd{abudawud}{3909}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ الْحَجَّاجِ الصَّوَّافِ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ هِلاَلِ بْنِ أَبِي مَيْمُونَةَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ مُعَاوِيَةَ بْنِ الْحَكَمِ السُّلَمِيِّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ وَمِنَّا رِجَالٌ يَخُطُّونَ ‏.‏ قَالَ ‏ "‏ كَانَ نَبِيٌّ مِنَ الأَنْبِيَاءِ يَخُطُّ فَمَنْ وَافَقَ خَطَّهُ فَذَاكَ ‏"‏ ‏.‏\hadithno{3909}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (537)}\hadithtrans{Narrated Mu'awiyah b. al-Hakam al-Sulami:I said: Messenger of Allah! among us there are men who practice divination by drawing lines. He said: There was a Prophet who drew lines, so if anyone does it as he drew lines, that is right}}
\hadithdefcmd{abudawud}{3910}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ عِيسَى بْنِ عَاَصِمٍ، عَنْ زِرِّ بْنِ حُبَيْشٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الطِّيَرَةُ شِرْكٌ الطِّيَرَةُ شِرْكٌ ‏"‏ ‏.‏ ثَلاَثًا ‏"‏ وَمَا مِنَّا إِلاَّ وَلَكِنَّ اللَّهَ يُذْهِبُهُ بِالتَّوَكُّلِ ‏"‏ ‏.‏\hadithno{3910}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Prophet (ﷺ) said: Taking omens is polytheism; taking omens is polytheism. He said it three times. Every one of us has some, but Allah removes it by trust (in Him)}}
\hadithdefcmd{abudawud}{3911}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُتَوَكِّلِ الْعَسْقَلاَنِيُّ، وَالْحَسَنُ بْنُ عَلِيٍّ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ عَدْوَى وَلاَ طِيَرَةَ وَلاَ صَفَرَ وَلاَ هَامَةَ ‏"‏ ‏.‏ فَقَالَ أَعْرَابِيٌّ مَا بَالُ الإِبِلِ تَكُونُ فِي الرَّمْلِ كَأَنَّهَا الظِّبَاءُ فَيُخَالِطُهَا الْبَعِيرُ الأَجْرَبُ فَيُجْرِبُهَا قَالَ ‏"‏ فَمَنْ أَعْدَى الأَوَّلَ ‏"‏ ‏.‏ قَالَ مَعْمَرٌ قَالَ الزُّهْرِيُّ فَحَدَّثَنِي رَجُلٌ عَنْ أَبِي هُرَيْرَةَ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يُورِدَنَّ مُمْرِضٌ عَلَى مُصِحٍّ ‏"‏ ‏.‏ قَالَ فَرَاجَعَهُ الرَّجُلُ فَقَالَ أَلَيْسَ قَدْ حَدَّثْتَنَا أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ عَدْوَى وَلاَ صَفَرَ وَلاَ هَامَةَ ‏"‏ ‏.‏ قَالَ لَمْ أُحَدِّثْكُمُوهُ ‏.‏ قَالَ الزُّهْرِيُّ قَالَ أَبُو سَلَمَةَ قَدْ حَدَّثَ بِهِ وَمَا سَمِعْتُ أَبَا هُرَيْرَةَ نَسِيَ حَدِيثًا قَطُّ غَيْرَهُ ‏.‏\hadithno{3911}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5770) Sahih Muslim (2220)}\hadithtrans{Narrated Abu Hurairah: The Messenger of Allah (ﷺ) as saying : There is no infection, no evil, omen or serpent, in a hungry belly and no hamah. A nomadic Arab asked: How is it that when camels are in the sand as if they were gazelles and a mangy camel comes among them and it gives them mange ? He replied: Who infected the first one ? Ma'mar, quoting al-Zuhri said: A man told me that Abu Hurairah narrated to him saying that he heard the Prophet (ﷺ) say: A diseased camel should not be brought with a healthy camel to drink water. He said: The man then consulted him and said: Did you not tell us that Prophet (ﷺ) had said: There is no infection, no serpent in a hungry belly and no hamah? He replied: I did not transmit it to you. Al-Zuhri said: Abu Salamah said: He had narrated it and I did not hear that Abu Hurairah had ever forgotten any tradition except this one. Note: The majority of scholars interpret this to mean that these things in and of themselves do not transmit or cause harm through supernatural or hidden means but that Allah is ultimately in control and any fearful superstition around these is false}}
\hadithdefcmd{abudawud}{3912}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ عَدْوَى وَلاَ هَامَةَ وَلاَ نَوْءَ وَلاَ صَفَرَ ‏"‏ ‏.‏\hadithno{3912}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2220 After  2221)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: There is no infection, no hamah, no other promising rain, and no serpent in a hungry belly}}
\hadithdefcmd{abudawud}{3913}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ بْنِ الْبَرْقِيِّ، أَنَّ سَعِيدَ بْنَ الْحَكَمِ، حَدَّثَهُمْ قَالَ أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنِي ابْنُ عَجْلاَنَ، حَدَّثَنِي الْقَعْقَاعُ بْنُ حَكِيمٍ، وَعُبَيْدُ اللَّهِ بْنُ مِقْسَمٍ، وَزَيْدُ بْنُ أَسْلَمَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ غُولَ ‏"‏ ‏.‏\hadithno{3913}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: There is no ghoul}}
\hadithdefcmd{abudawud}{3914}{قَالَ أَبُو دَاوُدَ قُرِئَ عَلَى الْحَارِثِ بْنِ مِسْكِينٍ وَأَنَا شَاهِدٌ، أَخْبَرَكُمْ أَشْهَبُ، قَالَ سُئِلَ مَالِكٌ عَنْ قَوْلِهِ ‏"‏ لاَ صَفَرَ ‏"‏ ‏.‏ قَالَ إِنَّ أَهْلَ الْجَاهِلِيَّةِ كَانُوا يُحِلُّونَ صَفَرَ يُحِلُّونَهُ عَامًا وَيُحَرِّمُونَهُ عَامًا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ صَفَرَ ‏"‏ ‏.‏\hadithno{3914}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Dawud said:Malik was asked about the meaning of his saying: There is no safar. He replied: The people of pre-Islamic Arabia used to make the month of safar lawful (for war). They made it lawful in one year and unlawful in another year. The Prophet (ﷺ) said: There is no safar}}
\hadithdefcmd{abudawud}{3915}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى، حَدَّثَنَا بَقِيَّةُ، قَالَ قُلْتُ لِمُحَمَّدٍ - يَعْنِي ابْنَ رَاشِدٍ - قَوْلُهُ ‏"‏ هَامَ ‏"‏ ‏.‏ قَالَ كَانَتِ الْجَاهِلِيَّةُ تَقُولُ لَيْسَ أَحَدٌ يَمُوتُ فَيُدْفَنُ إِلاَّ خَرَجَ مِنْ قَبْرِهِ هَامَةٌ ‏.‏ قُلْتُ فَقَوْلُهُ صَفَرَ ‏.‏ قَالَ سَمِعْتُ أَنَّ أَهْلَ الْجَاهِلِيَّةِ يَسْتَشْئِمُونَ بِصَفَرَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ صَفَرَ ‏"‏ ‏.‏ قَالَ مُحَمَّدٌ وَقَدْ سَمِعْنَا مَنْ يَقُولُ هُوَ وَجَعٌ يَأْخُذُ فِي الْبَطْنِ فَكَانُوا يَقُولُونَ هُوَ يُعْدِي فَقَالَ ‏"‏ لاَ صَفَرَ ‏"‏ ‏.‏\hadithno{3915}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Sahih Bukhari (5756) Sahih Muslim (2224)}\hadithtrans{Muhammad b. al-Musaffa said to us on the authority of Baqiyyah. He said:I asked Muhammad b. Rashid about the meaning of the word hamah. He replied: The pre-Islamic Arabs used to say: When anyone dies and is buried, a bird comes forth from his grave. I asked: What did he mean by safar ? He said: I heard that the pre-Islamic Arabs used to take evil omen from safar. So the Prophet (ﷺ) said: There is no safar. Muhammad (b. Rashid) said: We heard someone say: It is a pain in the stomach. They said that it was infection. Hence he said: There is no safar}}
\hadithdefcmd{abudawud}{3916}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ عَدْوَى وَلاَ طِيَرَةَ وَيُعْجِبُنِي الْفَأْلُ الصَّالِحُ وَالْفَأْلُ الصَّالِحُ الْكَلِمَةُ الْحَسَنَةُ ‏"‏ ‏.‏\hadithno{3916}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas:The Prophet (ﷺ) as saying: There is no infection* and no evil omen, and I like a good omen. Good omen means a good word. * The majority of scholars interpret this to mean that these things in and of themselves do not transmit or cause harm through supernatural or hidden means but that Allah is ultimately in control and any fearful superstition around these is false}}
\hadithdefcmd{abudawud}{3917}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، عَنْ سُهَيْلٍ، عَنْ رَجُلٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَمِعَ كَلِمَةً فَأَعْجَبَتْهُ فَقَالَ ‏ "‏ أَخَذْنَا فَأْلَكَ مِنْ فِيكَ ‏"‏ ‏.‏\hadithno{3917}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: When the Messenger of Allah (ﷺ) heard a word, and he liked it, he said: We took your omen from your mouth}}
\hadithdefcmd{abudawud}{3918}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، قَالَ يَقُولُ النَّاسُ الصَّفَرُ وَجَعٌ يَأْخُذُ فِي الْبَطْنِ ‏.‏ قُلْتُ فَمَا الْهَامَةُ قَالَ يَقُولُ النَّاسُ الْهَامَةُ الَّتِي تَصْرُخُ هَامَةُ النَّاسِ وَلَيْسَتْ بِهَامَةِ الإِنْسَانِ إِنَّمَا هِيَ دَابَّةٌ ‏.‏\hadithno{3918}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Ata:People said: safar is a pain within the belly. I asked: What is hamah ? He said: People said (believed) that hamah which is an owl or a nightbird and which shrieks is the spirit of men. It is not the spirit of men. It is an animal}}
\hadithdefcmd{abudawud}{3919}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ الْمَعْنَى قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عُرْوَةَ بْنِ عَامِرٍ، - قَالَ أَحْمَدُ الْقُرَشِيُّ - قَالَ ذُكِرَتِ الطِّيَرَةُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَحْسَنُهَا الْفَأْلُ وَلاَ تَرُدُّ مُسْلِمًا فَإِذَا رَأَى أَحَدُكُمْ مَا يَكْرَهُ فَلْيَقُلِ اللَّهُمَّ لاَ يَأْتِي بِالْحَسَنَاتِ إِلاَّ أَنْتَ وَلاَ يَدْفَعُ السَّيِّئَاتِ إِلاَّ أَنْتَ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِكَ ‏"‏ ‏.‏\hadithno{3919}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Urwah ibn Amir al-Qurashi: When taking omens was mentioned in the presence of the Prophet (ﷺ), he said: The best type is the good omen, and it does not turn back a Muslim. If one of you sees anything he dislikes, he should say: O Allah, no one brings good things except Thee, and no one averts evil things except Thee and there is no might and power but in Allah}}
\hadithdefcmd{abudawud}{3920}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لاَ يَتَطَيَّرُ مِنْ شَىْءٍ وَكَانَ إِذَا بَعَثَ عَامِلاً سَأَلَ عَنِ اسْمِهِ فَإِذَا أَعْجَبَهُ اسْمُهُ فَرِحَ بِهِ وَرُئِيَ بِشْرُ ذَلِكَ فِي وَجْهِهِ وَإِنْ كَرِهَ اسْمَهُ رُئِيَ كَرَاهِيَةُ ذَلِكَ فِي وَجْهِهِ وَإِذَا دَخَلَ قَرْيَةً سَأَلَ عَنِ اسْمِهَا فَإِنْ أَعْجَبَهُ اسْمُهَا فَرِحَ بِهَا وَرُئِيَ بِشْرُ ذَلِكَ فِي وَجْهِهِ وَإِنْ كَرِهَ اسْمَهَا رُئِيَ كَرَاهِيَةُ ذَلِكَ فِي وَجْهِهِ ‏.‏\hadithno{3920}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Buraydah ibn al-Hasib: The Prophet (ﷺ) did not take omens from anything, but when he sent out an agent he asked about his name. If it pleased him, he was glad about it, and his cheerfulness on that account was visible in his face. If he disliked his name, his displeasure on that account was visible in his face. When he entered a village, he asked about its name, and if it pleased him, he was glad about it, and his cheerfulness on that account was visible in his face. But if he disliked its name, his displeasure on that account was visible in his face}}
\hadithdefcmd{abudawud}{3921}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، حَدَّثَنِي يَحْيَى، أَنَّ الْحَضْرَمِيَّ بْنَ لاَحِقٍ، حَدَّثَهُ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ سَعْدِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ لاَ هَامَةَ وَلاَ عَدْوَى وَلاَ طِيَرَةَ وَإِنْ تَكُنِ الطِّيَرَةُ فِي شَىْءٍ فَفِي الْفَرَسِ وَالْمَرْأَةِ وَالدَّارِ ‏"‏ ‏.‏\hadithno{3921}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Sa'd ibn Malik: The Prophet (ﷺ) said: There is no hamah, no infection and no evil omen; if there is in anything an evil omen, it is a house, a horse, and a woman}}
\hadithdefcmd{abudawud}{3922}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ حَمْزَةَ، وَسَالِمِ، ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الشُّؤْمُ فِي الدَّارِ وَالْمَرْأَةِ وَالْفَرَسِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قُرِئَ عَلَى الْحَارِثِ بْنِ مِسْكِينٍ وَأَنَا شَاهِدٌ أَخْبَرَكَ ابْنُ الْقَاسِمِ قَالَ سُئِلَ مَالِكٌ عَنِ الشُّؤْمِ فِي الْفَرَسِ وَالدَّارِ قَالَ كَمْ مِنْ دَارٍ سَكَنَهَا نَاسٌ فَهَلَكُوا ثُمَّ سَكَنَهَا آخَرُونَ فَهَلَكُوا فَهَذَا تَفْسِيرُهُ فِيمَا نَرَى وَاللَّهُ أَعْلَمُ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ عُمَرُ رضى الله عنه حَصِيرٌ فِي الْبَيْتِ خَيْرٌ مِنَ امْرَأَةٍ لاَ تَلِدُ ‏.‏\hadithno{3922}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Sahih Bukhari (5093) Sahih Muslim (2225)}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that the Messenger of Allah (ﷺ) said:"An omen is in a dwelling, a woman or a horse." Abu Dawud said: This tradition was read out to al-Harith b. Miskin and I was witness. It was said to him that Ibn Qasim told him that Malik was asked about evil omen in a horse and in a house. He replied: There are many houses in which people lived and perished and again others lived therein and they also perished. This is its explanation so far as we know. Allah knows best. Abu Dawud said: 'Umar (ra) said: A mat in a house better than a woman who does not give birth to a child}}
\hadithdefcmd{abudawud}{3923}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، وَعَبَّاسٌ الْعَنْبَرِيُّ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ بَحِيرٍ، قَالَ أَخْبَرَنِي مَنْ، سَمِعَ فَرْوَةَ بْنَ مُسَيْكٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَرْضٌ عِنْدَنَا يُقَالُ لَهَا أَرْضُ أَبْيَنَ هِيَ أَرْضُ رِيفِنَا وَمِيرَتِنَا وَإِنَّهَا وَبِئَةٌ أَوْ قَالَ وَبَاؤُهَا شَدِيدٌ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ دَعْهَا عَنْكَ فَإِنَّ مِنَ الْقَرَفِ التَّلَفَ ‏"‏ ‏.‏\hadithno{3923}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Yahya ibn Abdullah ibn Buhayr said that he was informed by one who had heard Farwah ibn Musayk tell that he said:Messenger of Allah! we have land called Abyan, which is the land where we have our fields and grow our crops, but it is very unhealthy. The Prophet (ﷺ) said: Leave it, for destruction comes from being near disease}}
\hadithdefcmd{abudawud}{3924}{حَدَّثَنَا الْحَسَنُ بْنُ يَحْيَى، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ إِنَّا كُنَّا فِي دَارٍ كَثِيرٌ فِيهَا عَدَدُنَا وَكَثِيرٌ فِيهَا أَمْوَالُنَا فَتَحَوَّلْنَا إِلَى دَارٍ أُخْرَى فَقَلَّ فِيهَا عَدَدُنَا وَقَلَّتْ فِيهَا أَمْوَالُنَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ذَرُوهَا ذَمِيمَةً ‏"‏ ‏.‏\hadithno{3924}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: A man said: Messenger of Allah! we were in an abode in which our numbers and our goods were many and changed to an abode in which our numbers and our goods became few. The Messenger of Allah (ﷺ) said: Leave it, for it is reprehensible}}
\hadithdefcmd{abudawud}{3925}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُفَضَّلُ بْنُ فَضَالَةَ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَخَذَ بِيَدِ مَجْذُومٍ فَوَضَعَهَا مَعَهُ فِي الْقَصْعَةِ وَقَالَ ‏ "‏ كُلْ ثِقَةً بِاللَّهِ وَتَوَكُّلاً عَلَيْهِ ‏"‏ ‏.‏\hadithno{3925}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) took a man who was suffering from tubercular leprosy by the hand; he then put it along with his own hand in the dish and said: Eat with confidence in Allah and trust in Him}}
