% Auto-generated chapter 61 for malik
% Hadiths in this chapter: 1

\hadithdefcmd{malik}{1858}{حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لِي خَمْسَةُ أَسْمَاءٍ أَنَا مُحَمَّدٌ وَأَنَا أَحْمَدُ وَأَنَا الْمَاحِي الَّذِي يَمْحُو اللَّهُ بِيَ الْكُفْرَ وَأَنَا الْحَاشِرُ الَّذِي يُحْشَرُ النَّاسُ عَلَى قَدَمِي وَأَنَا الْعَاقِبُ ‏"‏ ‏.‏\hadithno{1858}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Ibn Shihab from Muhammad ibn Jubayr ibn Mutim that the Prophet, may Allah bless him and grant him peace, said, "I have five names. I am Muhammad. I am Ahmad. I am al-Mahi (the effacer), by whom Allah effaces kufr. I am al-Hashir (the gatherer), before whom people are gathered. I am al-Aqib (the last)}}
