% Auto-generated chapter index for tirmidhi
% Source: ara-tirmidhi.json
% Total hadiths: 3998
% Chapters: 49

\hadithcollectionname{tirmidhi}{Jami At Tirmidhi}

\hadithsectionname{tirmidhi}{1}{The Book on Purification}
\hadithsectionname{tirmidhi}{2}{The Book on Salat (Prayer)}
\hadithsectionname{tirmidhi}{3}{The Book on Al-Witr}
\hadithsectionname{tirmidhi}{4}{The Book on the Day of Friday}
\hadithsectionname{tirmidhi}{5}{The Book on the Two Eids}
\hadithsectionname{tirmidhi}{6}{The Book on Traveling}
\hadithsectionname{tirmidhi}{7}{The Book on Zakat}
\hadithsectionname{tirmidhi}{8}{The Book on Fasting}
\hadithsectionname{tirmidhi}{9}{The Book on Hajj}
\hadithsectionname{tirmidhi}{10}{The Book on Jana''iz (Funerals)}
\hadithsectionname{tirmidhi}{11}{The Book on Marriage}
\hadithsectionname{tirmidhi}{12}{The Book on Suckling}
\hadithsectionname{tirmidhi}{13}{The Book on Divorce and Li'an}
\hadithsectionname{tirmidhi}{14}{The Book on Business}
\hadithsectionname{tirmidhi}{15}{The Chapters On Judgements From The Messenger of Allah}
\hadithsectionname{tirmidhi}{16}{The Book on Blood Money}
\hadithsectionname{tirmidhi}{17}{The Book on Legal Punishments (Al-Hudud)}
\hadithsectionname{tirmidhi}{18}{The Book on Hunting}
\hadithsectionname{tirmidhi}{19}{The Book on Sacrifices}
\hadithsectionname{tirmidhi}{20}{The Book on Vows and Oaths}
\hadithsectionname{tirmidhi}{21}{The Book on Military Expeditions}
\hadithsectionname{tirmidhi}{22}{The Book on Virtues of Jihad}
\hadithsectionname{tirmidhi}{23}{The Book on Jihad}
\hadithsectionname{tirmidhi}{24}{The Book on Clothing}
\hadithsectionname{tirmidhi}{25}{The Book on Food}
\hadithsectionname{tirmidhi}{26}{The Book on Drinks}
\hadithsectionname{tirmidhi}{27}{Chapters on Righteousness And Maintaining Good Relations With Relatives}
\hadithsectionname{tirmidhi}{28}{Chapters on Medicine}
\hadithsectionname{tirmidhi}{29}{Chapters On Inheritance}
\hadithsectionname{tirmidhi}{30}{Chapters On Wasaya (Wills and Testament)}
\hadithsectionname{tirmidhi}{31}{Chapters On Wala' And Gifts}
\hadithsectionname{tirmidhi}{32}{Chapters On Al-Qadar}
\hadithsectionname{tirmidhi}{33}{Chapters On Al-Fitan}
\hadithsectionname{tirmidhi}{34}{Chapters On Dreams}
\hadithsectionname{tirmidhi}{35}{Chapters On Witnesses}
\hadithsectionname{tirmidhi}{36}{Chapters On Zuhd}
\hadithsectionname{tirmidhi}{37}{Chapters on the description of the Day of Judgement, Ar-Riqaq, and Al-Wara'}
\hadithsectionname{tirmidhi}{38}{Chapters on the description of Paradise}
\hadithsectionname{tirmidhi}{39}{The Book on the Description of Hellfire}
\hadithsectionname{tirmidhi}{40}{The Book on Faith}
\hadithsectionname{tirmidhi}{41}{Chapters on Knowledge}
\hadithsectionname{tirmidhi}{42}{Chapters on Seeking Permission}
\hadithsectionname{tirmidhi}{43}{Chapters on Manners}
\hadithsectionname{tirmidhi}{44}{Chapters on Parables}
\hadithsectionname{tirmidhi}{45}{Chapters on The Virtues of the Qur'an}
\hadithsectionname{tirmidhi}{46}{Chapters on Recitation}
\hadithsectionname{tirmidhi}{47}{Chapters on Tafsir}
\hadithsectionname{tirmidhi}{48}{Chapters on Supplication}
\hadithsectionname{tirmidhi}{49}{Chapters on Virtues}

\hadithsectionrange{tirmidhi}{1}{1}{148}
\hadithsectionrange{tirmidhi}{2}{149}{451}
\hadithsectionrange{tirmidhi}{3}{452}{487}
\hadithsectionrange{tirmidhi}{4}{488}{529}
\hadithsectionrange{tirmidhi}{5}{530}{543}
\hadithsectionrange{tirmidhi}{6}{544}{616}
\hadithsectionrange{tirmidhi}{7}{617}{681}
\hadithsectionrange{tirmidhi}{8}{682}{808}
\hadithsectionrange{tirmidhi}{9}{809}{964}
\hadithsectionrange{tirmidhi}{10}{965}{1079}
\hadithsectionrange{tirmidhi}{11}{1080}{1145}
\hadithsectionrange{tirmidhi}{12}{1146}{1174}
\hadithsectionrange{tirmidhi}{13}{1175}{1204}
\hadithsectionrange{tirmidhi}{14}{1205}{1321}
\hadithsectionrange{tirmidhi}{15}{1322}{1385}
\hadithsectionrange{tirmidhi}{16}{1386}{1422}
\hadithsectionrange{tirmidhi}{17}{1423}{1463}
\hadithsectionrange{tirmidhi}{18}{1464}{1492}
\hadithsectionrange{tirmidhi}{19}{1493}{1523}
\hadithsectionrange{tirmidhi}{20}{1524}{1547}
\hadithsectionrange{tirmidhi}{21}{1548}{1618}
\hadithsectionrange{tirmidhi}{22}{1619}{1669}
\hadithsectionrange{tirmidhi}{23}{1670}{1719}
\hadithsectionrange{tirmidhi}{24}{1720}{1787}
\hadithsectionrange{tirmidhi}{25}{1788}{1860}
\hadithsectionrange{tirmidhi}{26}{1861}{1896}
\hadithsectionrange{tirmidhi}{27}{1897}{2035}
\hadithsectionrange{tirmidhi}{28}{2036}{2089}
\hadithsectionrange{tirmidhi}{29}{2090}{2115}
\hadithsectionrange{tirmidhi}{30}{2116}{2124}
\hadithsectionrange{tirmidhi}{31}{2125}{2132}
\hadithsectionrange{tirmidhi}{32}{2133}{2298}
\hadithsectionrange{tirmidhi}{33}{2158}{2269}
\hadithsectionrange{tirmidhi}{34}{2270}{2294}
\hadithsectionrange{tirmidhi}{35}{2295}{2303}
\hadithsectionrange{tirmidhi}{36}{2304}{2414}
\hadithsectionrange{tirmidhi}{37}{2415}{2522}
\hadithsectionrange{tirmidhi}{38}{2523}{2735}
\hadithsectionrange{tirmidhi}{39}{2573}{2795}
\hadithsectionrange{tirmidhi}{40}{2606}{2644}
\hadithsectionrange{tirmidhi}{41}{2645}{2687}
\hadithsectionrange{tirmidhi}{42}{2688}{2734}
\hadithsectionrange{tirmidhi}{43}{2736}{2858}
\hadithsectionrange{tirmidhi}{44}{2859}{2874}
\hadithsectionrange{tirmidhi}{45}{2875}{2926}
\hadithsectionrange{tirmidhi}{46}{2927}{2949}
\hadithsectionrange{tirmidhi}{47}{2950}{3723}
\hadithsectionrange{tirmidhi}{48}{3370}{3604.1}
\hadithsectionrange{tirmidhi}{49}{3605}{3956}

% Chapter index — which .def file to load for each chapter

\hadithchapterfile{tirmidhi}{1}{hadithtext-tirmidhi-ch01.def}{1}{148}
\hadithchapterfile{tirmidhi}{2}{hadithtext-tirmidhi-ch02.def}{149}{451}
\hadithchapterfile{tirmidhi}{3}{hadithtext-tirmidhi-ch03.def}{452}{487}
\hadithchapterfile{tirmidhi}{4}{hadithtext-tirmidhi-ch04.def}{488}{529}
\hadithchapterfile{tirmidhi}{5}{hadithtext-tirmidhi-ch05.def}{530}{543}
\hadithchapterfile{tirmidhi}{6}{hadithtext-tirmidhi-ch06.def}{544}{616}
\hadithchapterfile{tirmidhi}{7}{hadithtext-tirmidhi-ch07.def}{617}{681}
\hadithchapterfile{tirmidhi}{8}{hadithtext-tirmidhi-ch08.def}{682}{808}
\hadithchapterfile{tirmidhi}{9}{hadithtext-tirmidhi-ch09.def}{809}{964}
\hadithchapterfile{tirmidhi}{10}{hadithtext-tirmidhi-ch10.def}{965}{1079}
\hadithchapterfile{tirmidhi}{11}{hadithtext-tirmidhi-ch11.def}{1080}{1145}
\hadithchapterfile{tirmidhi}{12}{hadithtext-tirmidhi-ch12.def}{1146}{1174}
\hadithchapterfile{tirmidhi}{13}{hadithtext-tirmidhi-ch13.def}{1175}{1204}
\hadithchapterfile{tirmidhi}{14}{hadithtext-tirmidhi-ch14.def}{1205}{1321}
\hadithchapterfile{tirmidhi}{15}{hadithtext-tirmidhi-ch15.def}{1322}{1385}
\hadithchapterfile{tirmidhi}{16}{hadithtext-tirmidhi-ch16.def}{1386}{1422}
\hadithchapterfile{tirmidhi}{17}{hadithtext-tirmidhi-ch17.def}{1423}{1463}
\hadithchapterfile{tirmidhi}{18}{hadithtext-tirmidhi-ch18.def}{1464}{1492}
\hadithchapterfile{tirmidhi}{19}{hadithtext-tirmidhi-ch19.def}{1493}{1523}
\hadithchapterfile{tirmidhi}{20}{hadithtext-tirmidhi-ch20.def}{1524}{1547}
\hadithchapterfile{tirmidhi}{21}{hadithtext-tirmidhi-ch21.def}{1548}{1618}
\hadithchapterfile{tirmidhi}{22}{hadithtext-tirmidhi-ch22.def}{1619}{1669}
\hadithchapterfile{tirmidhi}{23}{hadithtext-tirmidhi-ch23.def}{1670}{1719}
\hadithchapterfile{tirmidhi}{24}{hadithtext-tirmidhi-ch24.def}{1720}{1787}
\hadithchapterfile{tirmidhi}{25}{hadithtext-tirmidhi-ch25.def}{1788}{1860}
\hadithchapterfile{tirmidhi}{26}{hadithtext-tirmidhi-ch26.def}{1861}{1896}
\hadithchapterfile{tirmidhi}{27}{hadithtext-tirmidhi-ch27.def}{1897}{2035}
\hadithchapterfile{tirmidhi}{28}{hadithtext-tirmidhi-ch28.def}{2036}{2089}
\hadithchapterfile{tirmidhi}{29}{hadithtext-tirmidhi-ch29.def}{2090}{2115}
\hadithchapterfile{tirmidhi}{30}{hadithtext-tirmidhi-ch30.def}{2116}{2124}
\hadithchapterfile{tirmidhi}{31}{hadithtext-tirmidhi-ch31.def}{2125}{2132}
\hadithchapterfile{tirmidhi}{32}{hadithtext-tirmidhi-ch32.def}{2133}{2298}
\hadithchapterfile{tirmidhi}{33}{hadithtext-tirmidhi-ch33.def}{2158}{2269}
\hadithchapterfile{tirmidhi}{34}{hadithtext-tirmidhi-ch34.def}{2270}{2294}
\hadithchapterfile{tirmidhi}{35}{hadithtext-tirmidhi-ch35.def}{2295}{2303}
\hadithchapterfile{tirmidhi}{36}{hadithtext-tirmidhi-ch36.def}{2304}{2414}
\hadithchapterfile{tirmidhi}{37}{hadithtext-tirmidhi-ch37.def}{2415}{2522}
\hadithchapterfile{tirmidhi}{38}{hadithtext-tirmidhi-ch38.def}{2523}{2735}
\hadithchapterfile{tirmidhi}{39}{hadithtext-tirmidhi-ch39.def}{2573}{2795}
\hadithchapterfile{tirmidhi}{40}{hadithtext-tirmidhi-ch40.def}{2606}{2644}
\hadithchapterfile{tirmidhi}{41}{hadithtext-tirmidhi-ch41.def}{2645}{2687}
\hadithchapterfile{tirmidhi}{42}{hadithtext-tirmidhi-ch42.def}{2688}{2734}
\hadithchapterfile{tirmidhi}{43}{hadithtext-tirmidhi-ch43.def}{2736}{2858}
\hadithchapterfile{tirmidhi}{44}{hadithtext-tirmidhi-ch44.def}{2859}{2874}
\hadithchapterfile{tirmidhi}{45}{hadithtext-tirmidhi-ch45.def}{2875}{2926}
\hadithchapterfile{tirmidhi}{46}{hadithtext-tirmidhi-ch46.def}{2927}{2949}
\hadithchapterfile{tirmidhi}{47}{hadithtext-tirmidhi-ch47.def}{2950}{3723}
\hadithchapterfile{tirmidhi}{48}{hadithtext-tirmidhi-ch48.def}{3370}{3604.1}
\hadithchapterfile{tirmidhi}{49}{hadithtext-tirmidhi-ch49.def}{3605}{3956}
