% Auto-generated chapter 52 for bukhari
% Hadiths in this chapter: 50

\hadithdefcmd{bukhari}{2637}{حَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ النُّمَيْرِيُّ، حَدَّثَنَا يُونُسُ،‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ، وَابْنُ الْمُسَيَّبِ، وَعَلْقَمَةُ بْنُ وَقَّاصٍ، وَعُبَيْدُ اللَّهِ، عَنْ حَدِيثِ، عَائِشَةَ ـ رضى الله عنها ـ وَبَعْضُ حَدِيثِهِمْ يُصَدِّقُ بَعْضًا، حِينَ قَالَ لَهَا أَهْلُ الإِفْكِ، فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلِيًّا وَأُسَامَةَ حِينَ اسْتَلْبَثَ الْوَحْىُ يَسْتَأْمِرُهُمَا فِي فِرَاقِ أَهْلِهِ، فَأَمَّا أُسَامَةُ فَقَالَ أَهْلُكَ وَلاَ نَعْلَمُ إِلاَّ خَيْرًا‏.‏ وَقَالَتْ بَرِيرَةُ إِنْ رَأَيْتُ عَلَيْهَا أَمْرًا أَغْمِصُهُ أَكْثَرَ مِنْ أَنَّهَا جَارِيَةٌ حَدِيثَةُ السِّنِّ تَنَامُ عَنْ عَجِينِ أَهْلِهَا، فَتَأْتِي الدَّاجِنُ فَتَأْكُلُهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يَعْذِرُنَا مِنْ رَجُلٍ بَلَغَنِي أَذَاهُ فِي أَهْلِ بَيْتِي فَوَاللَّهِ مَا عَلِمْتُ مِنْ أَهْلِي إِلاَّ خَيْرًا، وَلَقَدْ ذَكَرُوا رَجُلاً مَا عَلِمْتُ عَلَيْهِ إِلاَّ خَيْرًا ‏"‏‏.‏\hadithno{2637}\hadithtrans{Narrated `Urwa bin Al-Musaiyab Alqama bin Waqqas and Ubaidullah bin `Abdullah:About the story of `Aisha and their narrations were similar attesting each other, when the liars said what they invented about `Aisha, and the Divine Inspiration was delayed, Allah's Messenger (ﷺ) sent for `Ali and Usama to consult them in divorcing his wife (i.e. `Aisha). Usama said, "Keep your wife, as we know nothing about her except good." Barirah said, "I cannot accuse her of any defect except that she is still a young girl who sleeps, neglecting her family's dough which the domestic goats come to eat (i.e. she was too simple-minded to deceive her husband)." Allah's Messenger (ﷺ) said, "Who can help me to take revenge over the man who has harmed me by defaming the reputation of my family? By Allah, I have not known about my family anything except good, and they mentioned (i.e. accused) a man about whom I did not know anything except good}}
\hadithdefcmd{bukhari}{2638}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ سَالِمٌ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ انْطَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأُبَىُّ بْنُ كَعْبٍ الأَنْصَارِيُّ يَؤُمَّانِ النَّخْلَ الَّتِي فِيهَا ابْنُ صَيَّادٍ حَتَّى إِذَا دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم طَفِقَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَّقِي بِجُذُوعِ النَّخْلِ، وَهْوَ يَخْتِلُ أَنْ يَسْمَعَ مِنِ ابْنِ صَيَّادٍ شَيْئًا قَبْلَ أَنْ يَرَاهُ، وَابْنُ صَيَّادٍ مُضْطَجِعٌ عَلَى فِرَاشِهِ فِي قَطِيفَةٍ لَهُ فِيهَا رَمْرَمَةٌ ـ أَوْ زَمْزَمَةٌ ـ فَرَأَتْ أُمُّ ابْنِ صَيَّادٍ النَّبِيَّ صلى الله عليه وسلم وَهْوَ يَتَّقِي بِجُذُوعِ النَّخْلِ، فَقَالَتْ لاِبْنِ صَيَّادِ أَىْ صَافِ، هَذَا مُحَمَّدٌ‏.‏ فَتَنَاهَى ابْنُ صَيَّادٍ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ تَرَكَتْهُ بَيَّنَ ‏"‏‏.‏\hadithno{2638}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) and Ubai bin Ka`b Al-Ansari went to the garden where Ibn Saiyad used to live. When Allah's Messenger (ﷺ) entered (the garden), he (i.e. Allah's Messenger (ﷺ) ) started hiding himself behind the date-palms as he wanted to hear secretly the talk of Ibn Saiyad before the latter saw him. Ibn Saiyad wrapped with a soft decorated sheet was lying on his bed murmuring. Ibn Saiyad's mother saw the Prophet hiding behind the stems of the date-palms. She addressed Ibn Saiyad saying, "O Saf, this is Muhammad." Hearing that Ibn Saiyad stopped murmuring (or got cautious), the Prophet (ﷺ) said, "If she had left him undisturbed, he would have revealed his reality." (See Hadith No. 290, Vol 4 for details)}}
\hadithdefcmd{bukhari}{2639}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ جَاءَتِ امْرَأَةُ رِفَاعَةَ الْقُرَظِيِّ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ كُنْتُ عِنْدَ رِفَاعَةَ فَطَلَّقَنِي فَأَبَتَّ طَلاَقِي، فَتَزَوَّجْتُ عَبْدَ الرَّحْمَنِ بْنَ الزَّبِيرِ، إِنَّمَا مَعَهُ مِثْلُ هُدْبَةِ الثَّوْبِ‏.‏ فَقَالَ ‏ "‏ أَتُرِيدِينَ أَنْ تَرْجِعِي إِلَى رِفَاعَةَ لاَ حَتَّى تَذُوقِي عُسَيْلَتَهُ وَيَذُوقَ عُسَيْلَتَكِ ‏"‏‏.‏ وَأَبُو بَكْرٍ جَالِسٌ عِنْدَهُ وَخَالِدُ بْنُ سَعِيدِ بْنِ الْعَاصِ بِالْبَابِ يَنْتَظِرُ أَنْ يُؤْذَنَ لَهُ، فَقَالَ يَا أَبَا بَكْرٍ، أَلاَ تَسْمَعُ إِلَى هَذِهِ مَا تَجْهَرُ بِهِ عِنْدَ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2639}\hadithtrans{Narrated Aisha:The wife of Rifa`a Al-Qurazi came to the Prophet (ﷺ) and said, "I was Rifa`a's wife, but he divorced me and it was a final irrevocable divorce. Then I married `Abdur-Rahman bin Az-Zubair but he is impotent." The Prophet (ﷺ) asked her 'Do you want to remarry Rifa`a? You cannot unless you had a complete sexual relation with your present husband." Abu Bakr was sitting with Allah's Messenger (ﷺ) and Khalid bin Sa`id bin Al-`As was at the door waiting to be admitted. He said, "O Abu Bakr! Do you hear what this (woman) is revealing frankly before the Prophet (ﷺ) ?}}
\hadithdefcmd{bukhari}{2640}{حَدَّثَنَا حِبَّانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا عُمَرُ بْنُ سَعِيدِ بْنِ أَبِي حُسَيْنٍ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ أَبِي مُلَيْكَةَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ، أَنَّهُ تَزَوَّجَ ابْنَةً لأَبِي إِهَابِ بْنِ عَزِيزٍ، فَأَتَتْهُ امْرَأَةٌ فَقَالَتْ قَدْ أَرْضَعْتُ عُقْبَةَ وَالَّتِي تَزَوَّجَ‏.‏ فَقَالَ لَهَا عُقْبَةُ مَا أَعْلَمُ أَنَّكِ أَرْضَعْتِنِي وَلاَ أَخْبَرْتِنِي‏.‏ فَأَرْسَلَ إِلَى آلِ أَبِي إِهَابٍ يَسْأَلُهُمْ فَقَالُوا مَا عَلِمْنَا أَرْضَعَتْ صَاحِبَتَنَا‏.‏ فَرَكِبَ إِلَى النَّبِيِّ صلى الله عليه وسلم بِالْمَدِينَةِ فَسَأَلَهُ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَيْفَ وَقَدْ قِيلَ ‏"‏‏.‏ فَفَارَقَهَا، وَنَكَحَتْ زَوْجًا غَيْرَهُ‏.‏\hadithno{2640}\hadithtrans{Narrated `Abdullah bin Abu Mulaika from `Uqba bin Al-Harith:`Uqba married the daughter of Abu Ihab bin `Aziz, and then a woman came and said, "I suckled `Uqba and his wife." `Uqba said to her, "I do not know that you have suckled me, and you did not inform me." He then sent someone to the house of Abu Ihab to inquire about that but they did not know that she had suckled their daughter. Then `Uqba went to the Prophet (ﷺ) in Medina and asked him about it. The Prophet (ﷺ) said to him, "How (can you keep your wife) after it has been said (that both of you were suckled by the same woman)?" So, he divorced her and she was married to another (husband)}}
\hadithdefcmd{bukhari}{2641}{حَدَّثَنَا الْحَكَمُ بْنُ نَافِعٍ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُتْبَةَ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ يَقُولُ إِنَّ أُنَاسًا كَانُوا يُؤْخَذُونَ بِالْوَحْىِ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم، وَإِنَّ الْوَحْىَ قَدِ انْقَطَعَ، وَإِنَّمَا نَأْخُذُكُمُ الآنَ بِمَا ظَهَرَ لَنَا مِنْ أَعْمَالِكُمْ، فَمَنْ أَظْهَرَ لَنَا خَيْرًا أَمِنَّاهُ وَقَرَّبْنَاهُ، وَلَيْسَ إِلَيْنَا مِنْ سَرِيرَتِهِ شَىْءٌ، اللَّهُ يُحَاسِبُهُ فِي سَرِيرَتِهِ، وَمَنْ أَظْهَرَ لَنَا سُوءًا لَمْ نَأْمَنْهُ وَلَمْ نُصَدِّقْهُ، وَإِنْ قَالَ إِنَّ سَرِيرَتَهُ حَسَنَةٌ‏.‏\hadithno{2641}\hadithtrans{Narrated `Umar bin Al-Khattab:People were (sometimes) judged by the revealing of a Divine Inspiration during the lifetime of Allah's Apostle but now there is no longer any more (new revelation). Now we judge you by the deeds you practice publicly, so we will trust and favor the one who does good deeds in front of us, and we will not call him to account about what he is really doing in secret, for Allah will judge him for that; but we will not trust or believe the one who presents to us with an evil deed even if he claims that his intentions were good}}
\hadithdefcmd{bukhari}{2642}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ مُرَّ عَلَى النَّبِيِّ صلى الله عليه وسلم بِجَنَازَةٍ، فَأَثْنَوْا عَلَيْهَا خَيْرًا فَقَالَ ‏"‏ وَجَبَتْ ‏"‏‏.‏ ثُمَّ مُرَّ بِأُخْرَى فَأَثْنَوْا عَلَيْهَا شَرًّا ـ أَوْ قَالَ غَيْرَ ذَلِكَ ـ فَقَالَ ‏"‏ وَجَبَتْ ‏"‏‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ، قُلْتَ لِهَذَا وَجَبَتْ، وَلِهَذَا وَجَبَتْ، قَالَ ‏"‏ شَهَادَةُ الْقَوْمِ، الْمُؤْمِنُونَ شُهَدَاءُ اللَّهِ فِي الأَرْضِ ‏"‏‏.‏\hadithno{2642}\hadithtrans{Narrated Anas:A funeral procession passed in front of the Prophet (ﷺ) and the people praised the deceased. The Prophet (ﷺ) said, "It has been affirmed (Paradise)." Then another funeral procession passed by and the people talked badly of the deceased. The Prophet (ﷺ) said, "It has been affirmed (Hell)." Allah's Messenger (ﷺ) was asked, "O Allah's Messenger (ﷺ)! You said it has been affirmed for both?" The Prophet (ﷺ) said, "The testimony of the people (is accepted), (for) the believers are Allah's witnesses on the earth}}
\hadithdefcmd{bukhari}{2643}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا دَاوُدُ بْنُ أَبِي الْفُرَاتِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ أَبِي الأَسْوَدِ، قَالَ أَتَيْتُ الْمَدِينَةَ وَقَدْ وَقَعَ بِهَا مَرَضٌ، وَهُمْ يَمُوتُونَ مَوْتًا ذَرِيعًا، فَجَلَسْتُ إِلَى عُمَرَ ـ رضى الله عنه ـ فَمَرَّتْ جِنَازَةٌ فَأُثْنِيَ خَيْرٌ فَقَالَ عُمَرُ وَجَبَتْ‏.‏ ثُمَّ مُرَّ بِأُخْرَى فَأُثْنِيَ خَيْرًا فَقَالَ وَجَبَتْ‏.‏ ثُمَّ مُرَّ بِالثَّالِثَةِ فَأُثْنِيَ شَرًّا، فَقَالَ وَجَبَتْ‏.‏ فَقُلْتُ مَا وَجَبَتْ يَا أَمِيرَ الْمُؤْمِنِينَ قَالَ قُلْتُ كَمَا قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَيُّمَا مُسْلِمٍ شَهِدَ لَهُ أَرْبَعَةٌ بِخَيْرٍ أَدْخَلَهُ اللَّهُ الْجَنَّةَ ‏"‏‏.‏ قُلْنَا وَثَلاَثَةٌ قَالَ ‏"‏ وَثَلاَثَةٌ ‏"‏‏.‏ قُلْتُ وَاثْنَانِ قَالَ ‏"‏ وَاثْنَانِ ‏"‏‏.‏ ثُمَّ لَمْ نَسْأَلْهُ عَنِ الْوَاحِدِ‏.‏\hadithno{2643}\hadithtrans{Narrated Abu Al-Aswad:Once I went to Medina where there was an outbreak of disease and the people were dying rapidly. I was sitting with `Umar and a funeral procession passed by. The people praised the deceased. `Umar said, "It has been affirmed" (Paradise). Then another funeral procession passed by. The people praised the deceased. `Umar said, "It has been affirmed." (Paradise). Then another funeral procession passed by. The people praised the deceased. `Umar said, "It has been affirmed (Paradise)." Then a third funeral procession passed by and the people talked badly of the deceased. `Umar said, "It has been affirmed (Hell)." I asked `Umar, "O chief of the believers! What has been affirmed?" He said, "I have said what the Prophet (ﷺ) said. He said, 'Allah will admit into paradise any Muslim whose good character is attested by four persons.' We asked the Prophet, 'If there were three witnesses only?' He said, 'Even three.' We asked, 'If there were two only?' He said, 'Even two.' But we did not ask him about one witness}}
\hadithdefcmd{bukhari}{2644}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنَا الْحَكَمُ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتِ اسْتَأْذَنَ عَلَىَّ أَفْلَحُ فَلَمْ آذَنْ لَهُ، فَقَالَ أَتَحْتَجِبِينَ مِنِّي وَأَنَا عَمُّكِ فَقُلْتُ وَكَيْفَ ذَلِكَ قَالَ أَرْضَعَتْكِ امْرَأَةُ أَخِي بِلَبَنِ أَخِي‏.‏ فَقَالَتْ سَأَلْتُ عَنْ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ صَدَقَ أَفْلَحُ، ائْذَنِي لَهُ ‏"‏‏.‏\hadithno{2644}\hadithtrans{Narrated Aisha:Aflah asked the permission to visit me but I did not allow him. He said, "Do you veil yourself before me although I am your uncle?" `Aisha said, "How is that?" Aflah replied, "You were suckled by my brother's wife with my brother's milk." I asked Allah's Messenger (ﷺ) about it, and he said, "Aflah is right, so permit him to visit you}}
\hadithdefcmd{bukhari}{2645}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم فِي بِنْتِ حَمْزَةَ ‏ "‏ لاَ تَحِلُّ لِي، يَحْرُمُ مِنَ الرَّضَاعِ مَا يَحْرُمُ مِنَ النَّسَبِ، هِيَ بِنْتُ أَخِي مِنَ الرَّضَاعَةِ ‏"‏‏.‏\hadithno{2645}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said about Hamza's daughter, "I am not legally permitted to marry her, as foster relations are treated like blood relations (in marital affairs). She is the daughter of my foster brother}}
\hadithdefcmd{bukhari}{2646}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عِنْدَهَا، وَأَنَّهَا سَمِعَتْ صَوْتَ رَجُلٍ يَسْتَأْذِنُ فِي بَيْتِ حَفْصَةَ‏.‏ قَالَتْ عَائِشَةُ فَقُلْتُ يَا رَسُولَ اللَّهِ أُرَاهُ فُلاَنًا‏.‏ لِعَمِّ حَفْصَةَ مِنَ الرَّضَاعَةِ‏.‏ فَقَالَتْ عَائِشَةُ يَا رَسُولَ اللَّهِ، هَذَا رَجُلٌ يَسْتَأْذِنُ فِي بَيْتِكَ‏.‏ قَالَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أُرَاهُ فُلاَنًا ‏"‏‏.‏ لِعَمِّ حَفْصَةَ مِنَ الرَّضَاعَةِ‏.‏ فَقَالَتْ عَائِشَةُ لَوْ كَانَ فُلاَنٌ حَيًّا ـ لِعَمِّهَا مِنَ الرَّضَاعَةِ ـ دَخَلَ عَلَىَّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ، إِنَّ الرَّضَاعَةَ تُحَرِّمُ مَا يَحْرُمُ مِنَ الْوِلاَدَةِ ‏"‏‏.‏\hadithno{2646}\hadithtrans{Narrated `Amra bint `Abdur-Rahman:That `Aisha the wife of the Prophet (ﷺ) told her uncle that once, while the Prophet (ﷺ) was in her house, she heard a man asking Hafsa's permission to enter her house. `Aisha said, "I said, 'O Allah's Messenger (ﷺ)! I think the man is Hafsa's foster uncle.' " `Aisha added, "O Allah's Messenger (ﷺ)! There is a man asking the permission to enter your house." Allah's Messenger (ﷺ) replied, "I think the man is Hafsa's foster uncle." `Aisha said, "If so-and-so were living (i.e. her foster uncle) would he be allowed to visit me?" Allah's Apostle said, "Yes, he would, as the foster relations are treated like blood relations (in marital affairs)}}
\hadithdefcmd{bukhari}{2647}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَشْعَثَ بْنِ أَبِي الشَّعْثَاءِ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ دَخَلَ عَلَىَّ النَّبِيُّ صلى الله عليه وسلم وَعِنْدِي رَجُلٌ، قَالَ ‏"‏ يَا عَائِشَةُ مَنْ هَذَا ‏"‏‏.‏ قُلْتُ أَخِي مِنَ الرَّضَاعَةِ‏.‏ قَالَ ‏"‏ يَا عَائِشَةُ، انْظُرْنَ مَنْ إِخْوَانُكُنَّ، فَإِنَّمَا الرَّضَاعَةُ مِنَ الْمَجَاعَةِ ‏"‏‏.‏ تَابَعَهُ ابْنُ مَهْدِيٍّ عَنْ سُفْيَانَ‏.‏\hadithno{2647}\hadithtrans{Narrated Aisha:Once the Prophet (ﷺ) came to me while a man was in my house. He said, "O `Aisha! Who is this (man)?" I replied, "My foster brothers" He said, "O `Aisha! Be sure about your foster brothers, as fostership is only valid if it takes place in the suckling period (before two years of age)}}
\hadithdefcmd{bukhari}{2648}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، عَنْ يُونُسَ،‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ امْرَأَةً، سَرَقَتْ فِي غَزْوَةِ الْفَتْحِ، فَأُتِيَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ أَمَرَ فَقُطِعَتْ يَدُهَا‏.‏ قَالَتْ عَائِشَةُ فَحَسُنَتْ تَوْبَتُهَا وَتَزَوَّجَتْ، وَكَانَتْ تَأْتِي بَعْدَ ذَلِكَ فَأَرْفَعُ حَاجَتَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{2648}\hadithtrans{Narrated `Urwa bin Az-Zubair:A woman committed theft in the Ghazwa of the Conquest (of Mecca) and she was taken to the Prophet who ordered her hand to be cut off. `Aisha said, "Her repentance was perfect and she was married (later) and used to come to me (after that) and I would present her needs to Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{2649}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ زَيْدِ بْنِ خَالِدٍ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ أَمَرَ فِيمَنْ زَنَى وَلَمْ يُحْصِنْ بِجَلْدِ مِائَةٍ وَتَغْرِيبِ عَامٍ‏.‏\hadithno{2649}\hadithtrans{Narrated Zaid bin Khalid:Allah's Messenger (ﷺ) ordered that an unmarried man who committed illegal sexual intercourse be scourged one hundred lashes and sent into exile for one year}}
\hadithdefcmd{bukhari}{2650}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا أَبُو حَيَّانَ التَّيْمِيُّ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ ـ رضى الله عنهما ـ قَالَ سَأَلَتْ أُمِّي أَبِي بَعْضَ الْمَوْهِبَةِ لِي مِنْ مَالِهِ، ثُمَّ بَدَا لَهُ فَوَهَبَهَا لِي فَقَالَتْ لاَ أَرْضَى حَتَّى تُشْهِدَ النَّبِيَّ صلى الله عليه وسلم‏.‏ فَأَخَذَ بِيَدِي وَأَنَا غُلاَمٌ، فَأَتَى بِيَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنَّ أُمَّهُ بِنْتَ رَوَاحَةَ سَأَلَتْنِي بَعْضَ الْمَوْهِبَةِ لِهَذَا، قَالَ ‏"‏ أَلَكَ وَلَدٌ سِوَاهُ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ فَأُرَاهُ قَالَ ‏"‏ لاَ تُشْهِدْنِي عَلَى جَوْرٍ ‏"‏‏.‏ وَقَالَ أَبُو حَرِيزٍ عَنِ الشَّعْبِيِّ ‏"‏ لاَ أَشْهَدُ عَلَى جَوْرٍ ‏"‏‏.‏\hadithno{2650}\hadithtrans{Narrated An-Nu`man bin Bashir:My mother asked my father to present me a gift from his property; and he gave it to me after some hesitation. My mother said that she would not be satisfied unless the Prophet (ﷺ) was made a witness to it. I being a young boy, my father held me by the hand and took me to the Prophet (ﷺ) . He said to the Prophet, "His mother, bint Rawaha, requested me to give this boy a gift." The Prophet (ﷺ) said, "Do you have other sons besides him?" He said, "Yes." The Prophet (ﷺ) said, "Do not make me a witness for injustice." Narrated Ash-Shu`bi that the Prophet (ﷺ) said, "I will not become a witness for injustice}}
\hadithdefcmd{bukhari}{2651}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا أَبُو جَمْرَةَ، قَالَ سَمِعْتُ زَهْدَمَ بْنَ مُضَرِّبٍ، قَالَ سَمِعْتُ عِمْرَانَ بْنَ حُصَيْنٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ خَيْرُكُمْ قَرْنِي، ثُمَّ الَّذِينَ يَلُونَهُمْ، ثُمَّ الَّذِينَ يَلُونَهُمْ ‏"‏‏.‏ قَالَ عِمْرَانُ لاَ أَدْرِي أَذَكَرَ النَّبِيُّ صلى الله عليه وسلم بَعْدُ قَرْنَيْنِ أَوْ ثَلاَثَةً‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ بَعْدَكُمْ قَوْمًا يَخُونُونَ وَلاَ يُؤْتَمَنُونَ، وَيَشْهَدُونَ، وَلاَ يُسْتَشْهَدُونَ وَيَنْذِرُونَ وَلاَ يَفُونَ، وَيَظْهَرُ فِيهِمُ السِّمَنُ ‏"‏‏.‏\hadithno{2651}\hadithtrans{Narrated Zahdam bin Mudarrib:I heard `Imran bin Husain saying, "The Prophet (ﷺ) said, 'The best people are those living in my generation, then those coming after them, and then those coming after (the second generation)." `Imran said "I do not know whether the Prophet (ﷺ) mentioned two or three generations after your present generation. The Prophet (ﷺ) added, 'There will be some people after you, who will be dishonest and will not be trustworthy and will give witness (evidences) without being asked to give witness, and will vow but will not fulfill their vows, and obesity will appear among them}}
\hadithdefcmd{bukhari}{2652}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ النَّاسِ قَرْنِي، ثُمَّ الَّذِينَ يَلُونَهُمْ، ثُمَّ الَّذِينَ يَلُونَهُمْ، ثُمَّ يَجِيءُ أَقْوَامٌ تَسْبِقُ شَهَادَةُ أَحَدِهِمْ يَمِينَهُ، وَيَمِينُهُ شَهَادَتَهُ ‏"‏‏.‏ قَالَ إِبْرَاهِيمُ وَكَانُوا يَضْرِبُونَنَا عَلَى الشَّهَادَةِ وَالْعَهْدِ‏.‏\hadithno{2652}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "The people of my generation are the best, then those who follow them, and then those who follow the latter. After that there will come some people whose witness will go ahead of their oaths, and their oaths will go ahead of their witness." Ibrahim (a sub-narrator) said, "We used to be beaten for taking oaths by saying, 'I bear witness by the Name of Allah or by the Covenant of Allah}}
\hadithdefcmd{bukhari}{2653}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُنِيرٍ، سَمِعَ وَهْبَ بْنَ جَرِيرٍ، وَعَبْدَ الْمَلِكِ بْنَ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ أَنَسٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنِ الْكَبَائِرِ قَالَ ‏ "‏ الإِشْرَاكُ بِاللَّهِ، وَعُقُوقُ الْوَالِدَيْنِ، وَقَتْلُ النَّفْسِ، وَشَهَادَةُ الزُّورِ ‏"‏‏.‏ تَابَعَهُ غُنْدَرٌ وَأَبُو عَامِرٍ وَبَهْزٌ وَعَبْدُ الصَّمَدِ عَنْ شُعْبَةَ‏.‏\hadithno{2653}\hadithtrans{Narrated Anas:The Prophet (ﷺ) was asked about the great sins He said, "They are:-- (1 ) To join others in worship with Allah, (2) To be undutiful to one's parents. (3) To kill a person (which Allah has forbidden to kill) (i.e. to commit the crime of murdering). (4) And to give a false witness}}
\hadithdefcmd{bukhari}{2654}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَلاَ أُنَبِّئُكُمْ بِأَكْبَرِ الْكَبَائِرِ ‏"‏‏.‏ ثَلاَثًا‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ الإِشْرَاكُ بِاللَّهِ، وَعُقُوقُ الْوَالِدَيْنِ ‏"‏‏.‏ وَجَلَسَ وَكَانَ مُتَّكِئًا فَقَالَ ‏"‏ أَلاَ وَقَوْلُ الزُّورِ ‏"‏‏.‏ قَالَ فَمَا زَالَ يُكَرِّرُهَا حَتَّى قُلْنَا لَيْتَهُ سَكَتَ‏.‏ وَقَالَ إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ حَدَّثَنَا الْجُرَيْرِيُّ حَدَّثَنَا عَبْدُ الرَّحْمَنِ‏.‏\hadithno{2654}\hadithtrans{Narrated Abu Bakra:The Prophet (ﷺ) said thrice, "Should I inform you about the greatest of the great sins?" They said, "Yes, O Allah's Messenger (ﷺ)!" He said, "To join others in worship with Allah and to be undutiful to one's parents." The Prophet (ﷺ) then sat up after he had been reclining (on a pillow) and said, "And I warn you against giving a false witness, and he kept on saying that warning till we thought he would not stop. (See Hadith No. 7, Vol)}}
\hadithdefcmd{bukhari}{2655}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ مَيْمُونٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سَمِعَ النَّبِيُّ صلى الله عليه وسلم رَجُلاً يَقْرَأُ فِي الْمَسْجِدِ فَقَالَ ‏"‏ رَحِمَهُ اللَّهُ، لَقَدْ أَذْكَرَنِي كَذَا وَكَذَا آيَةً، أَسْقَطْتُهُنَّ مِنْ سُورَةِ كَذَا وَكَذَا ‏"‏‏.‏ وَزَادَ عَبَّادُ بْنُ عَبْدِ اللَّهِ عَنْ عَائِشَةَ تَهَجَّدَ النَّبِيُّ صلى الله عليه وسلم فِي بَيْتِي فَسَمِعَ صَوْتَ عَبَّادٍ يُصَلِّي فِي الْمَسْجِدِ فَقَالَ ‏"‏ يَا عَائِشَةُ، أَصَوْتُ عَبَّادٍ هَذَا ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ اللَّهُمَّ ارْحَمْ عَبَّادًا ‏"‏‏.‏\hadithno{2655}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) heard a man (reciting Qur'an) in the Mosque, and he said, "May Allah bestow His Mercy upon him. No doubt, he made me remember such-and such Verses of such-and-such Sura which I dropped (from my memory). Narrated Aisha: The Prophet (ﷺ) performed the Tahajjud prayer in my house, and then he heard the voice of `Abbad who was praying in the Mosque, and said, "O `Aisha! Is this `Abbad's voice?" I said, "Yes." He said, "O Allah! Be merciful to `Abbad}}
\hadithdefcmd{bukhari}{2656}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، أَخْبَرَنَا ابْنُ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ بِلاَلاً يُؤَذِّنُ بِلَيْلٍ فَكُلُوا وَاشْرَبُوا حَتَّى يُؤَذِّنَ ـ أَوْ قَالَ حَتَّى تَسْمَعُوا ـ أَذَانَ ابْنِ أُمِّ مَكْتُومٍ ‏"‏‏.‏ وَكَانَ ابْنُ أُمِّ مَكْتُومٍ رَجُلاً أَعْمَى، لاَ يُؤَذِّنُ حَتَّى يَقُولَ لَهُ النَّاسُ أَصْبَحْتَ‏.‏\hadithno{2656}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "Bilal pronounces the Adhan when it is still night (before dawn), so eat and drink till the next Adhan is pronounced (or till you hear Ibn Um Maktum's Adhan)." Ibn Um Maktum was a blind man who would not pronounce the Adhan till he was told that it was dawn}}
\hadithdefcmd{bukhari}{2657}{حَدَّثَنَا زِيَادُ بْنُ يَحْيَى، حَدَّثَنَا حَاتِمُ بْنُ وَرْدَانَ، حَدَّثَنَا أَيُّوبُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ ـ رضى الله عنهما ـ قَالَ قَدِمَتْ عَلَى النَّبِيِّ صلى الله عليه وسلم أَقْبِيَةٌ فَقَالَ لِي أَبِي مَخْرَمَةُ انْطَلِقْ بِنَا إِلَيْهِ عَسَى أَنْ يُعْطِيَنَا مِنْهَا شَيْئًا‏.‏ فَقَامَ أَبِي عَلَى الْبَابِ فَتَكَلَّمَ، فَعَرَفَ النَّبِيُّ صلى الله عليه وسلم صَوْتَهُ فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم وَمَعَهُ قَبَاءٌ وَهُوَ يُرِيهِ مَحَاسِنَهُ وَهُوَ يَقُولَ ‏ "‏ خَبَأْتُ هَذَا لَكَ، خَبَأْتُ هَذَا لَكَ ‏"‏‏.‏\hadithno{2657}\hadithtrans{Narrated Al-Miswar bin Makhrama:Some outer garments were received by the Prophet (ﷺ) and my father (Makhrama) said to me, "Let us go to the Prophet (ﷺ) so that he may give us something from the garments." So, my father stood at the door and spoke. The Prophet (ﷺ) recognized his voice and came out carrying a garment and telling Makhrama the good qualities of that garment, adding, "I have kept this for you, I have sent this for you}}
\hadithdefcmd{bukhari}{2658}{حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ أَخْبَرَنِي زَيْدٌ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أَلَيْسَ شَهَادَةُ الْمَرْأَةِ مِثْلَ نِصْفِ شَهَادَةِ الرَّجُلِ ‏"‏‏.‏ قُلْنَا بَلَى‏.‏ قَالَ ‏"‏ فَذَلِكَ مِنْ نُقْصَانِ عَقْلِهَا ‏"‏‏.‏\hadithno{2658}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "Isn't the witness of a woman equal to half of that of a man?" The women said, "Yes." He said, "This is because of the deficiency of a woman's mind}}
\hadithdefcmd{bukhari}{2659}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ،‏.‏ وَحَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ سَمِعْتُ ابْنَ أَبِي مُلَيْكَةَ، قَالَ حَدَّثَنِي عُقْبَةُ بْنُ الْحَارِثِ، أَوْ سَمِعْتُهُ مِنْهُ، أَنَّهُ تَزَوَّجَ أُمَّ يَحْيَى بِنْتَ أَبِي إِهَابٍ قَالَ فَجَاءَتْ أَمَةٌ سَوْدَاءُ فَقَالَتْ قَدْ أَرْضَعْتُكُمَا‏.‏ فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَأَعْرَضَ عَنِّي، قَالَ فَتَنَحَّيْتُ فَذَكَرْتُ ذَلِكَ لَهُ قَالَ ‏ "‏ وَكَيْفَ وَقَدْ زَعَمَتْ أَنْ قَدْ أَرْضَعَتْكُمَا ‏"‏‏.‏ فَنَهَاهُ عَنْهَا‏.‏\hadithno{2659}\hadithtrans{Narrated `Uqba bin Al-Harith:That he had married Um Yahya bint Abu Ihab. He said. "A black slave-lady came and said, 'I suckled you both.' I then mentioned that to the Prophet (ﷺ) who turned his face aside." `Uqba further said, "I went to the other side and told the Prophet (ﷺ) about it. He said, 'How can you (keep her as your wife) when the lady has said that she suckled both of you (i.e. you and your wife?)" So, the Prophet (ﷺ) ordered him to divorce her}}
\hadithdefcmd{bukhari}{2660}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ عُمَرَ بْنِ سَعِيدٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ، قَالَ تَزَوَّجْتُ امْرَأَةً فَجَاءَتِ امْرَأَةٌ فَقَالَتْ إِنِّي قَدْ أَرْضَعْتُكُمَا‏.‏ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ وَكَيْفَ وَقَدْ قِيلَ دَعْهَا عَنْكَ ‏"‏ أَوْ نَحْوَهُ‏.‏\hadithno{2660}\hadithtrans{Narrated `Uqba bin Al-Harith:I married a woman and later on a woman came and said, "I suckled you both." So, I went to the Prophet (to ask him about it). He said, "How can you (keep her as a wife) when it has been said (that you were foster brother and sister)? Leave (divorce) her}}
\hadithdefcmd{bukhari}{2661}{حَدَّثَنَا أَبُو الرَّبِيعِ، سُلَيْمَانُ بْنُ دَاوُدَ وَأَفْهَمَنِي بَعْضَهُ أَحْمَدُ حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنِ ابْنِ شِهَابٍ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، وَسَعِيدِ بْنِ الْمُسَيَّبِ، وَعَلْقَمَةَ بْنِ وَقَّاصٍ اللَّيْثِيِّ، وَعُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ قَالَ لَهَا أَهْلُ الإِفْكِ مَا قَالُوا، فَبَرَّأَهَا اللَّهُ مِنْهُ، قَالَ الزُّهْرِيُّ، وَكُلُّهُمْ حَدَّثَنِي طَائِفَةً مِنْ حَدِيثِهَا وَبَعْضُهُمْ أَوْعَى مِنْ بَعْضٍ، وَأَثْبَتُ لَهُ اقْتِصَاصًا، وَقَدْ وَعَيْتُ عَنْ كُلِّ وَاحِدٍ مِنْهُمُ الْحَدِيثَ الَّذِي حَدَّثَنِي عَنْ عَائِشَةَ، وَبَعْضُ حَدِيثِهِمْ يُصَدِّقُ بَعْضًا‏.‏ زَعَمُوا أَنَّ عَائِشَةَ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَخْرُجَ سَفَرًا أَقْرَعَ بَيْنَ أَزْوَاجِهِ، فَأَيَّتُهُنَّ خَرَجَ سَهْمُهَا خَرَجَ بِهَا مَعَهُ، فَأَقْرَعَ بَيْنَنَا فِي غَزَاةٍ غَزَاهَا فَخَرَجَ سَهْمِي، فَخَرَجْتُ مَعَهُ بَعْدَ مَا أُنْزِلَ الْحِجَابُ، فَأَنَا أُحْمَلُ فِي هَوْدَجٍ وَأُنْزَلُ فِيهِ، فَسِرْنَا حَتَّى إِذَا فَرَغَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ غَزْوَتِهِ تِلْكَ، وَقَفَلَ وَدَنَوْنَا مِنَ الْمَدِينَةِ، آذَنَ لَيْلَةً بِالرَّحِيلِ، فَقُمْتُ حِينَ آذَنُوا بِالرَّحِيلِ، فَمَشَيْتُ حَتَّى جَاوَزْتُ الْجَيْشَ، فَلَمَّا قَضَيْتُ شَأْنِي أَقْبَلْتُ إِلَى الرَّحْلِ، فَلَمَسْتُ صَدْرِي، فَإِذَا عِقْدٌ لِي مِنْ جَزْعِ أَظْفَارٍ قَدِ انْقَطَعَ، فَرَجَعْتُ فَالْتَمَسْتُ عِقْدِي، فَحَبَسَنِي ابْتِغَاؤُهُ، فَأَقْبَلَ الَّذِينَ يَرْحَلُونَ لِي، فَاحْتَمَلُوا هَوْدَجِي فَرَحَلُوهُ عَلَى بَعِيرِي الَّذِي كُنْتُ أَرْكَبُ، وَهُمْ يَحْسِبُونَ أَنِّي فِيهِ، وَكَانَ النِّسَاءُ إِذْ ذَاكَ خِفَافًا لَمْ يَثْقُلْنَ وَلَمْ يَغْشَهُنَّ اللَّحْمُ، وَإِنَّمَا يَأْكُلْنَ الْعُلْقَةَ مِنَ الطَّعَامِ، فَلَمْ يَسْتَنْكِرِ الْقَوْمُ حِينَ رَفَعُوهُ ثِقَلَ الْهَوْدَجِ فَاحْتَمَلُوهُ وَكُنْتُ جَارِيَةً حَدِيثَةَ السِّنِّ، فَبَعَثُوا الْجَمَلَ وَسَارُوا، فَوَجَدْتُ عِقْدِي بَعْدَ مَا اسْتَمَرَّ الْجَيْشُ، فَجِئْتُ مَنْزِلَهُمْ وَلَيْسَ فِيهِ أَحَدٌ، فَأَمَمْتُ مَنْزِلِي الَّذِي كُنْتُ بِهِ فَظَنَنْتُ أَنَّهُمْ سَيَفْقِدُونِي فَيَرْجِعُونَ إِلَىَّ، فَبَيْنَا أَنَا جَالِسَةٌ غَلَبَتْنِي عَيْنَاىَ فَنِمْتُ، وَكَانَ صَفْوَانُ بْنُ الْمُعَطَّلِ السُّلَمِيُّ ثُمَّ الذَّكْوَانِيُّ مِنْ وَرَاءِ الْجَيْشِ، فَأَصْبَحَ عِنْدَ مَنْزِلِي فَرَأَى سَوَادَ إِنْسَانٍ نَائِمٍ فَأَتَانِي، وَكَانَ يَرَانِي قَبْلَ الْحِجَابِ فَاسْتَيْقَظْتُ بِاسْتِرْجَاعِهِ حِينَ أَنَاخَ رَاحِلَتَهُ، فَوَطِئَ يَدَهَا فَرَكِبْتُهَا فَانْطَلَقَ يَقُودُ بِي الرَّاحِلَةَ، حَتَّى أَتَيْنَا الْجَيْشَ بَعْدَ مَا نَزَلُوا مُعَرِّسِينَ فِي نَحْرِ الظَّهِيرَةِ، فَهَلَكَ مَنْ هَلَكَ، وَكَانَ الَّذِي تَوَلَّى الإِفْكَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ ابْنُ سَلُولَ، فَقَدِمْنَا الْمَدِينَةَ فَاشْتَكَيْتُ بِهَا شَهْرًا، يُفِيضُونَ مِنْ قَوْلِ أَصْحَابِ الإِفْكِ، وَيَرِيبُنِي فِي وَجَعِي أَنِّي لاَ أَرَى مِنَ النَّبِيِّ صلى الله عليه وسلم اللُّطْفَ الَّذِي كُنْتُ أَرَى مِنْهُ حِينَ أَمْرَضُ، إِنَّمَا يَدْخُلُ فَيُسَلِّمُ ثُمَّ يَقُولُ ‏"‏ كَيْفَ تِيكُمْ ‏"‏‏.‏ لاَ أَشْعُرُ بِشَىْءٍ مِنْ ذَلِكَ حَتَّى نَقَهْتُ، فَخَرَجْتُ أَنَا وَأُمُّ مِسْطَحٍ قِبَلَ الْمَنَاصِعِ مُتَبَرَّزُنَا، لاَ نَخْرُجُ إِلاَّ لَيْلاً إِلَى لَيْلٍ، وَذَلِكَ قَبْلَ أَنْ نَتَّخِذَ الْكُنُفَ قَرِيبًا مِنْ بُيُوتِنَا، وَأَمْرُنَا أَمْرُ الْعَرَبِ الأُوَلِ فِي الْبَرِّيَّةِ أَوْ فِي التَّنَزُّهِ، فَأَقْبَلْتُ أَنَا وَأُمُّ مِسْطَحٍ بِنْتُ أَبِي رُهْمٍ نَمْشِي، فَعَثُرَتْ فِي مِرْطِهَا فَقَالَتْ تَعِسَ مِسْطَحٌ، فَقُلْتُ لَهَا بِئْسَ مَا قُلْتِ، أَتَسُبِّينَ رَجُلاً شَهِدَ بَدْرًا فَقَالَتْ يَا هَنْتَاهْ أَلَمْ تَسْمَعِي مَا قَالُوا فَأَخْبَرَتْنِي بِقَوْلِ أَهْلِ الإِفْكِ، فَازْدَدْتُ مَرَضًا إِلَى مَرَضِي، فَلَمَّا رَجَعْتُ إِلَى بَيْتِي دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَلَّمَ فَقَالَ ‏"‏ كَيْفَ تِيكُمْ ‏"‏‏.‏ فَقُلْتُ ائْذَنْ لِي إِلَى أَبَوَىَّ‏.‏ قَالَتْ وَأَنَا حِينَئِذٍ أُرِيدُ أَنْ أَسْتَيْقِنَ الْخَبَرَ مِنْ قِبَلِهِمَا، فَأَذِنَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَتَيْتُ أَبَوَىَّ فَقُلْتُ لأُمِّي مَا يَتَحَدَّثُ بِهِ النَّاسُ فَقَالَتْ يَا بُنَيَّةُ هَوِّنِي عَلَى نَفْسِكِ الشَّأْنَ، فَوَاللَّهِ لَقَلَّمَا كَانَتِ امْرَأَةٌ قَطُّ وَضِيئَةٌ عِنْدَ رَجُلٍ يُحِبُّهَا وَلَهَا ضَرَائِرُ إِلاَّ أَكْثَرْنَ عَلَيْهَا‏.‏ فَقُلْتُ سُبْحَانَ اللَّهِ وَلَقَدْ يَتَحَدَّثُ النَّاسُ بِهَذَا قَالَتْ فَبِتُّ تِلْكَ اللَّيْلَةَ حَتَّى أَصْبَحْتُ لاَ يَرْقَأُ لِي دَمْعٌ وَلاَ أَكْتَحِلُ بِنَوْمٍ، ثُمَّ أَصْبَحْتُ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلِيَّ بْنَ أَبِي طَالِبٍ وَأُسَامَةَ بْنَ زَيْدٍ حِينَ اسْتَلْبَثَ الْوَحْىُ، يَسْتَشِيرُهُمَا فِي فِرَاقِ أَهْلِهِ، فَأَمَّا أُسَامَةُ فَأَشَارَ عَلَيْهِ بِالَّذِي يَعْلَمُ فِي نَفْسِهِ مِنَ الْوُدِّ لَهُمْ، فَقَالَ أُسَامَةُ أَهْلُكَ يَا رَسُولَ اللَّهِ وَلاَ نَعْلَمُ وَاللَّهِ إِلاَّ خَيْرًا، وَأَمَّا عَلِيُّ بْنُ أَبِي طَالِبٍ فَقَالَ يَا رَسُولَ اللَّهِ لَمْ يُضَيِّقِ اللَّهُ عَلَيْكَ وَالنِّسَاءُ سِوَاهَا كَثِيرٌ، وَسَلِ الْجَارِيَةَ تَصْدُقْكَ‏.‏ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بَرِيرَةَ فَقَالَ ‏"‏ يَا بَرِيرَةُ هَلْ رَأَيْتِ فِيهَا شَيْئًا يَرِيبُكِ ‏"‏‏.‏ فَقَالَتْ بَرِيرَةُ لاَ وَالَّذِي بَعَثَكَ بِالْحَقِّ، إِنْ رَأَيْتُ مِنْهَا أَمْرًا أَغْمِصُهُ عَلَيْهَا أَكْثَرَ مِنْ أَنَّهَا جَارِيَةٌ حَدِيثَةُ السِّنِّ تَنَامُ عَنِ الْعَجِينَ فَتَأْتِي الدَّاجِنُ فَتَأْكُلُهُ‏.‏ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ يَوْمِهِ، فَاسْتَعْذَرَ مِنْ عَبْدِ اللَّهِ بْنِ أُبَىٍّ ابْنِ سَلُولَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ يَعْذِرُنِي مِنْ رَجُلٍ بَلَغَنِي أَذَاهُ فِي أَهْلِي، فَوَاللَّهِ مَا عَلِمْتُ عَلَى أَهْلِي إِلاَّ خَيْرًا، وَقَدْ ذَكَرُوا رَجُلاً مَا عَلِمْتُ عَلَيْهِ إِلاَّ خَيْرًا، وَمَا كَانَ يَدْخُلُ عَلَى أَهْلِي إِلاَّ مَعِي ‏"‏‏.‏ فَقَامَ سَعْدُ بْنُ مُعَاذٍ فَقَالَ يَا رَسُولَ اللَّهِ أَنَا وَاللَّهِ أَعْذِرُكَ مِنْهُ، إِنْ كَانَ مِنَ الأَوْسِ ضَرَبْنَا عُنُقَهُ، وَإِنْ كَانَ مِنْ إِخْوَانِنَا مِنَ الْخَزْرَجِ أَمَرْتَنَا فَفَعَلْنَا فِيهِ أَمْرَكَ‏.‏ فَقَامَ سَعْدُ بْنُ عُبَادَةَ وَهُوَ سَيِّدُ الْخَزْرَجِ، وَكَانَ قَبْلَ ذَلِكَ رَجُلاً صَالِحًا وَلَكِنِ احْتَمَلَتْهُ الْحَمِيَّةُ فَقَالَ كَذَبْتَ لَعَمْرُ اللَّهِ، لاَ تَقْتُلُهُ وَلاَ تَقْدِرُ عَلَى ذَلِكَ، فَقَامَ أُسَيْدُ بْنُ الْحُضَيْرِ فَقَالَ كَذَبْتَ لَعَمْرُ اللَّهِ، وَاللَّهِ لَنَقْتُلَنَّهُ، فَإِنَّكَ مُنَافِقٌ تُجَادِلُ عَنِ الْمُنَافِقِينَ‏.‏ فَثَارَ الْحَيَّانِ الأَوْسُ وَالْخَزْرَجُ حَتَّى هَمُّوا، وَرَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ فَنَزَلَ فَخَفَّضَهُمْ حَتَّى سَكَتُوا وَسَكَتَ، وَبَكَيْتُ يَوْمِي لاَ يَرْقَأُ لِي دَمْعٌ وَلاَ أَكْتَحِلُ بِنَوْمٍ، فَأَصْبَحَ عِنْدِي أَبَوَاىَ، قَدْ بَكَيْتُ لَيْلَتَيْنِ وَيَوْمًا حَتَّى أَظُنُّ أَنَّ الْبُكَاءَ فَالِقٌ كَبِدِي ـ قَالَتْ ـ فَبَيْنَا هُمَا جَالِسَانِ عِنْدِي وَأَنَا أَبْكِي إِذِ اسْتَأْذَنَتِ امْرَأَةٌ مِنَ الأَنْصَارِ فَأَذِنْتُ لَهَا، فَجَلَسَتْ تَبْكِي مَعِي، فَبَيْنَا نَحْنُ كَذَلِكَ إِذْ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَلَسَ، وَلَمْ يَجْلِسْ عِنْدِي مِنْ يَوْمِ قِيلَ فِيَّ مَا قِيلَ قَبْلَهَا، وَقَدْ مَكُثَ شَهْرًا لاَ يُوحَى إِلَيْهِ فِي شَأْنِي شَىْءٌ ـ قَالَتْ ـ فَتَشَهَّدَ ثُمَّ قَالَ ‏"‏ يَا عَائِشَةُ فَإِنَّهُ بَلَغَنِي عَنْكِ كَذَا وَكَذَا، فَإِنْ كُنْتِ بَرِيئَةً فَسَيُبَرِّئُكِ اللَّهُ، وَإِنْ كُنْتِ أَلْمَمْتِ فَاسْتَغْفِرِي اللَّهَ وَتُوبِي إِلَيْهِ، فَإِنَّ الْعَبْدَ إِذَا اعْتَرَفَ بِذَنْبِهِ ثُمَّ تَابَ تَابَ اللَّهُ عَلَيْهِ ‏"‏‏.‏ فَلَمَّا قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم مَقَالَتَهُ قَلَصَ دَمْعِي حَتَّى مَا أُحِسُّ مِنْهُ قَطْرَةً وَقُلْتُ لأَبِي أَجِبْ عَنِّي رَسُولَ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَ وَاللَّهِ مَا أَدْرِي مَا أَقُولُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَقُلْتُ لأُمِّي أَجِيبِي عَنِّي رَسُولَ اللَّهِ صلى الله عليه وسلم فِيمَا قَالَ‏.‏ قَالَتْ وَاللَّهِ مَا أَدْرِي مَا أَقُولُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَتْ وَأَنَا جَارِيَةٌ حَدِيثَةُ السِّنِّ لاَ أَقْرَأُ كَثِيرًا مِنَ الْقُرْآنِ فَقُلْتُ إِنِّي وَاللَّهِ لَقَدْ عَلِمْتُ أَنَّكُمْ سَمِعْتُمْ مَا يَتَحَدَّثُ بِهِ النَّاسُ، وَوَقَرَ فِي أَنْفُسِكُمْ وَصَدَّقْتُمْ بِهِ، وَلَئِنْ قُلْتُ لَكُمْ إِنِّي بَرِيئَةٌ‏.‏ وَاللَّهُ يَعْلَمُ إِنِّي لَبَرِيئَةٌ لاَ تُصَدِّقُونِي بِذَلِكَ، وَلَئِنِ اعْتَرَفْتُ لَكُمْ بِأَمْرٍ، وَاللَّهُ يَعْلَمُ أَنِّي بَرِيئَةٌ لَتُصَدِّقُنِّي وَاللَّهِ مَا أَجِدُ لِي وَلَكُمْ مَثَلاً إِلاَّ أَبَا يُوسُفَ إِذْ قَالَ ‏\{‏فَصَبْرٌ جَمِيلٌ وَاللَّهُ الْمُسْتَعَانُ عَلَى مَا تَصِفُونَ‏\}‏ ثُمَّ تَحَوَّلْتُ عَلَى فِرَاشِي، وَأَنَا أَرْجُو أَنْ يُبَرِّئَنِي اللَّهُ، وَلَكِنْ وَاللَّهِ مَا ظَنَنْتُ أَنْ يُنْزِلَ فِي شَأْنِي وَحْيًا، وَلأَنَا أَحْقَرُ فِي نَفْسِي مِنْ أَنْ يُتَكَلَّمَ بِالْقُرْآنِ فِي أَمْرِي، وَلَكِنِّي كُنْتُ أَرْجُو أَنْ يَرَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّوْمِ رُؤْيَا يُبَرِّئُنِي اللَّهُ، فَوَاللَّهِ مَا رَامَ مَجْلِسَهُ وَلاَ خَرَجَ أَحَدٌ مِنْ أَهْلِ الْبَيْتِ حَتَّى أُنْزِلَ عَلَيْهِ، فَأَخَذَهُ مَا كَانَ يَأْخُذُهُ مِنَ الْبُرَحَاءِ، حَتَّى إِنَّهُ لَيَتَحَدَّرُ مِنْهُ مِثْلُ الْجُمَانِ مِنَ الْعَرَقِ فِي يَوْمٍ شَاتٍ، فَلَمَّا سُرِّيَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يَضْحَكُ، فَكَانَ أَوَّلَ كَلِمَةٍ تَكَلَّمَ بِهَا أَنْ قَالَ لِي ‏"‏ يَا عَائِشَةُ، احْمَدِي اللَّهَ فَقَدْ بَرَّأَكِ اللَّهُ ‏"‏‏.‏ فَقَالَتْ لِي أُمِّي قُومِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَقُلْتُ لاَ وَاللَّهِ، لاَ أَقُومُ إِلَيْهِ، وَلاَ أَحْمَدُ إِلاَّ اللَّهَ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِنَّ الَّذِينَ جَاءُوا بِالإِفْكِ عُصْبَةٌ مِنْكُمْ‏\}‏ الآيَاتِ، فَلَمَّا أَنْزَلَ اللَّهُ هَذَا فِي بَرَاءَتِي قَالَ أَبُو بَكْرٍ الصِّدِّيقُ ـ رضى الله عنه ـ وَكَانَ يُنْفِقُ عَلَى مِسْطَحِ بْنِ أُثَاثَةَ لِقَرَابَتِهِ مِنْهُ وَاللَّهِ لاَ أُنْفِقُ عَلَى مِسْطَحٍ شَيْئًا أَبَدًا بَعْدَ مَا قَالَ لِعَائِشَةَ‏.‏ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏وَلاَ يَأْتَلِ أُولُو الْفَضْلِ مِنْكُمْ وَالسَّعَةِ‏\}‏ إِلَى قَوْلِهِ ‏\{‏غَفُورٌ رَحِيمٌ‏\}‏ فَقَالَ أَبُو بَكْرٍ بَلَى، وَاللَّهِ إِنِّي لأُحِبُّ أَنْ يَغْفِرَ اللَّهُ لِي، فَرَجَعَ إِلَى مِسْطَحٍ الَّذِي كَانَ يُجْرِي عَلَيْهِ‏.‏ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْأَلُ زَيْنَبَ بِنْتَ جَحْشٍ عَنْ أَمْرِي، فَقَالَ ‏"‏ يَا زَيْنَبُ، مَا عَلِمْتِ مَا رَأَيْتِ ‏"‏‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ، أَحْمِي سَمْعِي وَبَصَرِي، وَاللَّهِ مَا عَلِمْتُ عَلَيْهَا إِلاَّ خَيْرًا، قَالَتْ وَهْىَ الَّتِي كَانَتْ تُسَامِينِي، فَعَصَمَهَا اللَّهُ بِالْوَرَعِ‏.‏ قَالَ وَحَدَّثَنَا فُلَيْحٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، وَعَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، مِثْلَهُ‏.‏ قَالَ وَحَدَّثَنَا فُلَيْحٌ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، وَيَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدِ بْنِ أَبِي بَكْرٍ، مِثْلَهُ‏.‏\hadithno{2661}\hadithtrans{Narrated Aisha:(the wife of the Prophet) "Whenever Allah's Messenger (ﷺ) intended to go on a journey, he would draw lots amongst his wives and would take with him the one upon whom the lot fell. During a Ghazwa of his, he drew lots amongst us and the lot fell upon me, and I proceeded with him after Allah had decreed the use of the veil by women. I was carried in a Howdah (on the camel) and dismounted while still in it. When Allah's Messenger (ﷺ) was through with his Ghazwa and returned home, and we approached the city of Medina, Allah's Messenger (ﷺ) ordered us to proceed at night. When the order of setting off was given, I walked till I was past the army to answer the call of nature. After finishing I returned (to the camp) to depart (with the others) and suddenly realized that my necklace over my chest was missing. So, I returned to look for it and was delayed because of that. The people who used to carry me on the camel, came to my Howdah and put it on the back of the camel, thinking that I was in it, as, at that time, women were light in weight, and thin and lean, and did not use to eat much. So, those people did not feel the difference in the heaviness of the Howdah while lifting it, and they put it over the camel. At that time I was a young lady. They set the camel moving and proceeded on. I found my necklace after the army had gone, and came to their camp to find nobody. So, I went to the place where I used to stay, thinking that they would discover my absence and come back in my search. While in that state, I felt sleepy and slept. Safwan bin Mu'attal As-Sulami Adh-Dhakwani was behind the army and reached my abode in the morning. When he saw a sleeping person, he came to me, and he used to see me before veiling. So, I got up when I heard him saying, "Inna lil-lah-wa inn a ilaihi rajiun (We are for Allah, and we will return to Him)." He made his camel kneel down. He got down from his camel, and put his leg on the front legs of the camel and then I rode and sat over it. Safwan set out walking, leading the camel by the rope till we reached the army who had halted to take rest at midday. Then whoever was meant for destruction, fell into destruction, (some people accused me falsely) and the leader of the false accusers was `Abdullah bin Ubai bin Salul. After that we returned to Medina, and I became ill for one month while the people were spreading the forged statements of the false accusers. I was feeling during my ailment as if I were not receiving the usual kindness from the Prophet (ﷺ) which I used to receive from him when I got sick. But he would come, greet and say, 'How is that (girl)?' I did not know anything of what was going on till I recovered from my ailment and went out with Um Mistah to the Manasi where we used to answer the call of nature, and we used not to go to answer the call of nature except from night to night and that was before we had lavatories near to our houses. And this habit of ours was similar to the habit of the old 'Arabs in the open country (or away from houses). So. I and Um Mistah bint Ruhm went out walking. Um Mistah stumbled because of her long dress and on that she said, 'Let Mistah be ruined.' I said, 'You are saying a bad word. Why are you abusing a man who took part in (the battle of) Badr?' She said, 'O Hanata (you there) didn't you hear what they said?' Then she told me the rumors of the false accusers. My sickness was aggravated, and when I returned home, Allah's Messenger (ﷺ) came to me, and after greeting he said, 'How is that (girl)?' I requested him to allow me to go to my parents. I wanted then to be sure of the news through them. Allah's Messenger (ﷺ) allowed me, and I went to my parents and asked my mother, 'What are the people talking about?' She said, 'O my daughter! Don't worry much about this matter. By Allah, never is there a charming woman loved by her husband who has other wives, but the women would forge false news about her.' I said, 'Glorified be Allah! Are the people really talking of this matter?' That night I kept on weeping and could not sleep till morning. In the morning Allah's Messenger (ﷺ) called `Ali bin Abu Talib and Usama bin Zaid when he saw the Divine Inspiration delayed, to consul them about divorcing his wife (i.e. `Aisha). Usama bin Zaid said what he knew of the good reputation of his wives and added, 'O Allah's Messenger (ﷺ)! Keep your wife, for, by Allah, we know nothing about her but good.' `Ali bin Abu Talib said, 'O Allah's Messenger (ﷺ)! Allah has not imposed restrictions on you, and there are many women other than she, yet you may ask the woman-servant who will tell you the truth.' On that Allah's Messenger (ﷺ) called Barirah and said, 'O Barirah. Did you ever see anything which roused your suspicions about her?' Barirah said, 'No, by Allah Who has sent you with the Truth, I have never seen in her anything faulty except that she is a girl of immature age, who sometimes sleeps and leaves the dough for the goats to eat.' On that day Allah's Messenger (ﷺ) ascended the pulpit and requested that somebody support him in punishing `Abdullah bin Ubai bin Salul. Allah's Apostle said, 'Who will support me to punish that person (`Abdullah bin Ubai bin Salul) who has hurt me by slandering the reputation of my family? By Allah, I know nothing about my family but good, and they have accused a person about whom I know nothing except good, and he never entered my house except in my company.' Sa`d bin Mu`adh got up and said, 'O Allah's Messenger (ﷺ)! by Allah, I will relieve you from him. If that man is from the tribe of the Aus, then we will chop his head off, and if he is from our brothers, the Khazraj, then order us, and we will fulfill your order.' On that Sa`d bin 'Ubada, the chief of the Khazraj and before this incident, he had been a pious man, got up, motivated by his zeal for his tribe and said, 'By Allah, you have told a lie; you cannot kill him, and you will never be able to kill him.' On that Usaid bin Al-Hudair got up and said (to Sa`d bin 'Ubada), 'By Allah! you are a liar. By Allah, we will kill him; and you are a hypocrite, defending the hypocrites.' On this the two tribes of Aus and Khazraj got excited and were about to fight each other, while Allah's Messenger (ﷺ) was standing on the pulpit. He got down and quieted them till they became silent and he kept quiet. On that day I kept on weeping so much so that neither did my tears stop, nor could I sleep. In the morning my parents were with me and I had wept for two nights and a day, till I thought my liver would burst from weeping. While they were sitting with me and I was weeping, an Ansari woman asked my permission to enter, and I allowed her to come in. She sat down and started weeping with me. While we were in this state, Allah's Messenger (ﷺ) came and sat down and he had never sat with me since the day they forged the accusation. No revelation regarding my case came to him for a month. He recited Tashah-hud (i.e. None has the right to be worshipped but Allah and Muhammad is His Apostle) and then said, 'O `Aisha! I have been informed such-and-such about you; if you are innocent, then Allah will soon reveal your innocence, and if you have committed a sin, then repent to Allah and ask Him to forgive you, for when a person confesses his sin and asks Allah for forgiveness, Allah accepts his repentance.' When Allah's Messenger (ﷺ) finished his speech my tears ceased completely and there remained not even a single drop of it. I requested my father to reply to Allah's Messenger (ﷺ) on my behalf. My father said, By Allah, I do not know what to say to Allah's Messenger (ﷺ).' I said to my mother, 'Talk to Allah's Messenger (ﷺ) on my behalf.' She said, 'By Allah, I do not know what to say to Allah's Apostle. I was a young girl and did not have much knowledge of the Qur'an. I said, 'I know, by Allah, that you have listened to what people are saying and that has been planted in your minds and you have taken it as a truth. Now, if I told you that I am innocent and Allah knows that I am innocent, you would not believe me and if I confessed to you falsely that I am guilty, and Allah knows that I am innocent you would believe me. By Allah, I don't compare my situation with you except to the situation of Joseph's father (i.e. Jacob) who said, 'So (for me) patience is most fitting against that which you assert and it is Allah (Alone) whose help can be sought.' Then I turned to the other side of my bed hoping that Allah would prove my innocence. By Allah I never thought that Allah would reveal Divine Inspiration in my case, as I considered myself too inferior to be talked of in the Holy Qur'an. I had hoped that Allah's Messenger (ﷺ) might have a dream in which Allah would prove my innocence. By Allah, Allah's Apostle had not got up and nobody had left the house before the Divine Inspiration came to Allah's Apostle. So, there overtook him the same state which used to overtake him, (which he used to have on being inspired divinely). He was sweating so much so that the drops of the sweat were dropping like pearls though it was a (cold) wintry day. When that state of Allah's Messenger (ﷺ) was over, he was smiling and the first word he said, `Aisha! Thank Allah, for Allah has declared your innocence.' My mother told me to go to Allah's Messenger (ﷺ) . I replied, 'By Allah I will not go to him and will not thank but Allah.' So Allah revealed: "Verily! They who spread the slander are a gang among you . . ." (24.11) When Allah gave the declaration of my Innocence, Abu Bakr, who used to provide for Mistah bin Uthatha for he was his relative, said, 'By Allah, I will never provide Mistah with anything because of what he said about Aisha.' But Allah later revealed: -- "And let not those who are good and wealthy among you swear not to help their kinsmen, those in need and those who left their homes in Allah's Cause. Let them forgive and overlook. Do you not wish that Allah should forgive you? Verily! Allah is Oft-forgiving, Most Merciful." (24.22) After that Abu Bakr said, 'Yes ! By Allah! I like that Allah should forgive me,' and resumed helping Mistah whom he used to help before. Allah's Messenger (ﷺ) also asked Zainab bint Jahsh (i.e. the Prophet's wife about me saying, 'What do you know and what did you see?' She replied, 'O Allah's Messenger (ﷺ)! I refrain to claim hearing or seeing what I have not heard or seen. By Allah, I know nothing except goodness about Aisha." Aisha further added "Zainab was competing with me (in her beauty and the Prophet's love), yet Allah protected her (from being malicious), for she had piety}}
\hadithdefcmd{bukhari}{2662}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلَامٍ أَخْبَرَنَا عَبْدُ الْوَهَّابِ حَدَّثَنَا خَالِدٌ الْحَذَّاءُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ عَنْ أَبِيهِ قَالَ أَثْنَى رَجُلٌ عَلَى رَجُلٍ عِنْدَ النَّبِيِّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ فَقَالَ وَيْلَكَ قَطَعْتَ عُنُقَ صَاحِبِكَ قَطَعْتَ عُنُقَ صَاحِبِكَ مِرَارًا ثُمَّ قَالَ مَنْ كَانَ مِنْكُمْ مَادِحًا أَخَاهُ لَا مَحَالَةَ فَلْيَقُلْ أَحْسِبُ فُلَانًا وَاللَّهُ حَسِيبُهُ وَلَا أُزَكِّي عَلَى اللَّهِ أَحَدًا أَحْسِبُهُ كَذَا وَكَذَا إِنْ كَانَ يَعْلَمُ ذَلِكَ مِنْهُ\hadithno{2662}\hadithtrans{Narrated Abu Bakra:A man praised another man in front of the Prophet (ﷺ) . The Prophet (ﷺ) said to him, "Woe to you, you have cut off your companion's neck, you have cut off your companion's neck," repeating it several times and then added, "Whoever amongst you has to praise his brother should say, 'I think that he is so and so, and Allah knows exactly the truth, and I do not confirm anybody's good conduct before Allah, but I think him so and so,' if he really knows what he says about him}}
\hadithdefcmd{bukhari}{2663}{حَدَّثَنَا مُحَمَّدُ بْنُ صَبَّاحٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا بُرَيْدُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ سَمِعَ النَّبِيُّ صلى الله عليه وسلم رَجُلاً يُثْنِي عَلَى رَجُلٍ، وَيُطْرِيهِ فِي مَدْحِهِ فَقَالَ ‏ "‏ أَهْلَكْتُمْ ـ أَوْ قَطَعْتُمْ ـ ظَهْرَ الرَّجُلِ ‏"‏‏.‏\hadithno{2663}\hadithtrans{Narrated Abu Musa Al-Ash`ari:The Prophet (ﷺ) heard someone praising another and exaggerating in his praise. The Prophet (ﷺ) said, "You have ruined or cut the man's back (by praising him so much)}}
\hadithdefcmd{bukhari}{2664}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنِي عُبَيْدُ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، قَالَ حَدَّثَنِي ابْنُ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَرَضَهُ يَوْمَ أُحُدٍ وَهْوَ ابْنُ أَرْبَعَ عَشْرَةَ سَنَةً، فَلَمْ يُجِزْنِي، ثُمَّ عَرَضَنِي يَوْمَ الْخَنْدَقِ وَأَنَا ابْنُ خَمْسَ عَشْرَةَ فَأَجَازَنِي‏.‏ قَالَ نَافِعٌ فَقَدِمْتُ عَلَى عُمَرَ بْنِ عَبْدِ الْعَزِيزِ وَهْوَ خَلِيفَةٌ، فَحَدَّثْتُهُ هَذَا الْحَدِيثَ، فَقَالَ إِنَّ هَذَا لَحَدٌّ بَيْنَ الصَّغِيرِ وَالْكَبِيرِ‏.‏ وَكَتَبَ إِلَى عُمَّالِهِ أَنْ يَفْرِضُوا لِمَنْ بَلَغَ خَمْسَ عَشْرَةَ‏.‏\hadithno{2664}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) called me to present myself in front of him on the eve of the battle of Uhud, while I was fourteen years of age at that time, and he did not allow me to take part in that battle, but he called me in front of him on the eve of the battle of the Trench when I was fifteen years old, and he allowed me (to join the battle)." Nafi` said, "I went to `Umar bin `Abdul `Aziz who was Caliph at that time and related the above narration to him, He said, "This age (fifteen) is the limit between childhood and manhood," and wrote to his governors to give salaries to those who reached the age of fifteen}}
\hadithdefcmd{bukhari}{2665}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا صَفْوَانُ بْنُ سُلَيْمٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ غُسْلُ يَوْمِ الْجُمُعَةِ وَاجِبٌ عَلَى كُلِّ مُحْتَلِمٍ ‏"‏‏.‏\hadithno{2665}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "Bath on Friday is compulsory for those who have attained the age of puberty}}
\hadithdefcmd{bukhari}{2666}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ وَهْوَ فِيهَا فَاجِرٌ، لِيَقْتَطِعَ بِهَا مَالَ امْرِئٍ مُسْلِمٍ، لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ قَالَ فَقَالَ الأَشْعَثُ بْنُ قَيْسٍ فِيَّ وَاللَّهِ كَانَ ذَلِكَ، كَانَ بَيْنِي وَبَيْنَ رَجُلٍ مِنَ الْيَهُودِ أَرْضٌ فَجَحَدَنِي، فَقَدَّمْتُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلَكَ بَيِّنَةٌ ‏"‏‏.‏ قَالَ قُلْتُ لاَ‏.‏ قَالَ فَقَالَ لِلْيَهُودِيِّ ‏"‏ احْلِفْ ‏"‏‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِذًا يَحْلِفَ وَيَذْهَبَ بِمَالِي‏.‏ قَالَ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ إِلَى آخِرِ الآيَةِ‏.‏\hadithno{2666}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said, "If somebody takes a false oath in order to get the property of a Muslim (unjustly) by that oath, then Allah will be angry with him when he will meet Him." Al-Ash'ath informed me, "By Allah! This was said regarding me. There was a dispute about a piece of land between me and a man from the Jews who denied my right. I took him to the Prophet. Allah's Messenger (ﷺ) asked me, 'Do you have an evidence?' I replied in the negative. He said to the Jew, 'Take an oath.' I said, 'O Allah's Messenger (ﷺ)! He will surely take an oath and take my property unjustly." So, Allah revealed: "Verily! Those who purchase a little gain at the cost of Allah's covenant and their oaths}}
\hadithdefcmd{bukhari}{2668}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا نَافِعُ بْنُ عُمَرَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ كَتَبَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى بِالْيَمِينِ عَلَى الْمُدَّعَى عَلَيْهِ‏.‏\hadithno{2668}\hadithtrans{Narrated Ibn Abu Mulaika:Ibn `Abbas wrote that the Prophet (ﷺ) gave his verdict on the basis of the defendant's oath}}
\hadithdefcmd{bukhari}{2669}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ عَبْدُ اللَّهِ مَنْ حَلَفَ عَلَى يَمِينٍ يَسْتَحِقُّ بِهَا مَالاً لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ، ثُمَّ أَنْزَلَ اللَّهُ تَصْدِيقَ ذَلِكَ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ‏\}‏ إِلَى ‏\{‏عَذَابٌ أَلِيمٌ‏\}‏‏.‏ ثُمَّ إِنَّ الأَشْعَثَ بْنَ قَيْسٍ خَرَجَ إِلَيْنَا فَقَالَ مَا يُحَدِّثُكُمْ أَبُو عَبْدِ الرَّحْمَنِ فَحَدَّثْنَاهُ بِمَا، قَالَ، فَقَالَ صَدَقَ لَفِيَّ أُنْزِلَتْ، كَانَ بَيْنِي وَبَيْنَ رَجُلٍ خُصُومَةٌ فِي شَىْءٍ، فَاخْتَصَمْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ شَاهِدَاكَ أَوْ يَمِينُهُ ‏"‏‏.‏ فَقُلْتُ لَهُ إِنَّهُ إِذًا يَحْلِفُ وَلاَ يُبَالِي‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ يَسْتَحِقُّ بِهَا مَالاً وَهْوَ فِيهَا فَاجِرٌ لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ تَصْدِيقَ ذَلِكَ، ثُمَّ اقْتَرَأَ هَذِهِ الآيَةَ‏.‏\hadithno{2669}\hadithtrans{Narrated Abu Wail:`Abdullah (bin Mas`ud) said, "Whoever takes a (false) oath in order to grab some property (unjustly), Allah will be angry with him when he will meet Him. Allah confirmed that through His Divine Revelation: "Verily! Those who purchase a little gain at the cost of Allah's covenant and their oaths . . . they will have a painful punishment." (3.77) Al-Ash'ath bin Qais came to us and asked, 'What is Abu `Abdur-Rahman (i.e. `Abdullah) telling you? 'We told him what he was narrating to us. He said, 'He was telling the truth; this Divine Verse was revealed in connection with me. There was a dispute between me and another man about something and the case was filed before Allah's Messenger (ﷺ) who said, 'Produce your two witnesses or else the defendant is to take an oath.' I said, The defendant will surely take a (false) oath caring for nothing.' The Prophet (ﷺ) said, 'Whoever takes a false oath in order to grab (other's) property, then Allah will be angry with him when he will meet Him.' Then Allah revealed its confirmation. Al-Ashath then recited the above Divine Verse}}
\hadithdefcmd{bukhari}{2671}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ هِشَامٍ، حَدَّثَنَا عِكْرِمَةُ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ هِلاَلَ بْنَ أُمَيَّةَ، قَذَفَ امْرَأَتَهُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم بِشَرِيكِ بْنِ سَحْمَاءَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الْبَيِّنَةُ أَوْ حَدٌّ فِي ظَهْرِكَ ‏"‏‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِذَا رَأَى أَحَدُنَا عَلَى امْرَأَتِهِ رَجُلاً يَنْطَلِقُ يَلْتَمِسُ الْبَيِّنَةَ فَجَعَلَ يَقُولُ ‏"‏ الْبَيِّنَةَ وَإِلاَّ حَدٌّ فِي ظَهْرِكَ ‏"‏‏.‏ فَذَكَرَ حَدِيثَ اللِّعَانِ‏.‏\hadithno{2671}\hadithtrans{Narrated Ibn `Abbas:Hilal bin Umaiya accused his wife before the Prophet (ﷺ) of committing illegal sexual intercourse with Sharik bin Sahma.' The Prophet (ﷺ) said, "Produce a proof, or else you would get the legal punishment (by being lashed) on your back." Hilal said, "O Allah's Messenger (ﷺ)! If anyone of us saw another man over his wife, would he go to search for a proof." The Prophet (ﷺ) went on saying, "Produce a proof or else you would get the legal punishment (by being lashed) on your back." The Prophet (ﷺ) then mentioned the narration of Lian (as in the Holy Book). (Surat-al-Nur:)}}
\hadithdefcmd{bukhari}{2672}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ، وَلاَ يَنْظُرُ إِلَيْهِمْ وَلاَ يُزَكِّيهِمْ، وَلَهُمْ عَذَابٌ أَلِيمٌ رَجُلٌ عَلَى فَضْلِ مَاءٍ بِطَرِيقٍ يَمْنَعُ مِنْهُ ابْنَ السَّبِيلِ، وَرَجُلٌ بَايَعَ رَجُلاً لاَ يُبَايِعُهُ إِلاَّ لِلدُّنْيَا، فَإِنْ أَعْطَاهُ مَا يُرِيدُ وَفَى لَهُ، وَإِلاَّ لَمْ يَفِ لَهُ، وَرَجُلٌ سَاوَمَ رَجُلاً بِسِلْعَةٍ بَعْدَ الْعَصْرِ، فَحَلَفَ بِاللَّهِ لَقَدْ أُعْطِيَ بِهِ كَذَا وَكَذَا، فَأَخَذَهَا ‏"‏‏.‏\hadithno{2672}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There are three persons whom Allah will neither talk to nor look at, nor purify from (the sins), and they will have a painful punishment. (They are): (1) A man who possessed superfluous water on a way and he withheld it from the travelers. (2) a man who gives a pledge of allegiance to a Muslim ruler and gives it only for worldly gains. If the ruler gives him what he wants, he remains obedient to It, otherwise he does not abide by it, and (3) a man bargains with another man after the `Asr prayer and the latter takes a false oath in the Name of Allah claiming that he has been offered so much for the thing and the former (believes him and) buys it}}
\hadithdefcmd{bukhari}{2673}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنِ ابْنِ مَسْعُودٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ لِيَقْتَطِعَ بِهَا مَالاً لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏\hadithno{2673}\hadithtrans{Narrated Ibn Mas`ud:The Prophet (ﷺ) said, "Whoever takes a (false) oath in order to grab (other's) property, then Allah will be angry with him when he will meet Him}}
\hadithdefcmd{bukhari}{2674}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم عَرَضَ عَلَى قَوْمٍ الْيَمِينَ فَأَسْرَعُوا، فَأَمَرَ أَنْ يُسْهَمَ بَيْنَهُمْ فِي الْيَمِينِ أَيُّهُمْ يَحْلِفُ‏.‏\hadithno{2674}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) asked some people to take an oath, and they hurried for it. The Prophet (ﷺ) ordered that lots should be drawn amongst them as to who would take an oath first}}
\hadithdefcmd{bukhari}{2675}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا الْعَوَّامُ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ أَبُو إِسْمَاعِيلَ السَّكْسَكِيُّ، سَمِعَ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى ـ رضى الله عنهما ـ يَقُولُ أَقَامَ رَجُلٌ سِلْعَتَهُ فَحَلَفَ بِاللَّهِ لَقَدْ أُعْطِيَ بِهَا مَا لَمْ يُعْطَهَا فَنَزَلَتْ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ وَقَالَ ابْنُ أَبِي أَوْفَى النَّاجِشُ آكِلُ رِبًا خَائِنٌ‏.‏\hadithno{2675}\hadithtrans{Narrated `Abdullah bin Abu `Aufa:A man displayed some goods in the market and took a false oath that he had been offered so much for them though he was not offered that amount Then the following Divine Verse was revealed:-- "Verily! Those who purchase a little gain at the cost of Allah's covenant and their oaths . . . Will get painful punishment." (3.77) Ibn Abu `Aufa added, "Such person as described above is a treacherous Riba eater (i.e. eater of usury)}}
\hadithdefcmd{bukhari}{2676}{حَدَّثَنَا بِشْرُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ كَاذِبًا لِيَقْتَطِعَ مَالَ رَجُلٍ ـ أَوْ قَالَ أَخِيهِ ـ لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ وَأَنْزَلَ اللَّهُ تَصْدِيقَ ذَلِكَ فِي الْقُرْآنِ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ الآيَةَ‏.‏ فَلَقِيَنِي الأَشْعَثُ فَقَالَ مَا حَدَّثَكُمْ عَبْدُ اللَّهِ الْيَوْمَ، قُلْتُ كَذَا وَكَذَا‏.‏ قَالَ فِيَّ أُنْزِلَتْ‏.‏\hadithno{2676}\hadithtrans{Narrated Abu Wail from `Abdullah:The Prophet (ﷺ) said, "Whoever takes a false oath in order to grab another man's (or his brother's) property, then Allah will be angry with him when he will meet him." Then Allah confirmed this by revealing the Divine Verse: "Verily! Those who purchase a little gain at the cost of Allah's Covenant and their oaths . . . Will get painful punishment." (3.77) Al-Ash'ath met me and asked, "What did `Abdullah tell you today?" I said, "So and so." He said, "The Verse was revealed regarding my case}}
\hadithdefcmd{bukhari}{2678}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَمِّهِ أَبِي سُهَيْلٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ طَلْحَةَ بْنَ عُبَيْدِ اللَّهِ، يَقُولُ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِذَا هُوَ يَسْأَلُهُ عَنِ الإِسْلاَمِ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَمْسُ صَلَوَاتٍ فِي الْيَوْمِ وَاللَّيْلَةِ ‏"‏‏.‏ فَقَالَ هَلْ عَلَىَّ غَيْرُهَا قَالَ ‏"‏ لاَ، إِلاَّ أَنْ تَطَّوَّعَ ‏"‏‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَصِيَامُ رَمَضَانَ ‏"‏‏.‏ قَالَ هَلْ عَلَىَّ غَيْرُهُ قَالَ ‏"‏ لاَ، إِلاَّ أَنْ تَطَّوَّعَ ‏"‏‏.‏ قَالَ وَذَكَرَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم الزَّكَاةَ‏.‏ قَالَ هَلْ عَلَىَّ غَيْرُهَا قَالَ ‏"‏ لاَ، إِلاَّ أَنْ تَطَّوَّعَ ‏"‏‏.‏ فَأَدْبَرَ الرَّجُلُ وَهْوَ يَقُولُ وَاللَّهِ لاَ أَزِيدُ عَلَى هَذَا وَلاَ أَنْقُصُ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَفْلَحَ إِنْ صَدَقَ ‏"‏‏.‏\hadithno{2678}\hadithtrans{Narrated Talha bin 'Ubaidullah:A man came to Allah's Messenger (ﷺ) asking him about Islam, Allah's Messenger (ﷺ) said, "You have to offer five compulsory prayers in a day and a night (24 hours)." The man asked, "Is there any more compulsory prayers for me?" Allah's Messenger (ﷺ) said, "No, unless you like to offer Nawafil (i.e. optional prayers)." Allah's Messenger (ﷺ) then added, "You have to observe fasts during the month of Ramadan." The man said, "Am I to fast any other days?' Allah's Messenger (ﷺ) said, "No, unless you wish to observe the optional fast voluntarily." Then Allah's Messenger (ﷺ) told him about the compulsory Zakat. The man asked, "Do I have to give anything besides?" Allah's Messenger (ﷺ) said, "No, unless you wish to give in charity voluntarily." So, the man departed saying, "By Allah I will neither do more nor less than that." Allah's Messenger (ﷺ) said, "If he has said the truth he will be successful}}
\hadithdefcmd{bukhari}{2679}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ، قَالَ ذَكَرَ نَافِعٌ عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ حَالِفًا فَلْيَحْلِفْ بِاللَّهِ أَوْ لِيَصْمُتْ ‏"‏‏.‏\hadithno{2679}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "Whoever has to take an oath should swear by Allah or remain silent." (i.e. He should not swear by other than Allah)}}
\hadithdefcmd{bukhari}{2680}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ، عَنْ أُمِّ سَلَمَةَ ـ رضى الله عنها ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّكُمْ تَخْتَصِمُونَ إِلَىَّ، وَلَعَلَّ بَعْضَكُمْ أَلْحَنُ بِحُجَّتِهِ مِنْ بَعْضٍ، فَمَنْ قَضَيْتُ لَهُ بِحَقِّ أَخِيهِ شَيْئًا بِقَوْلِهِ، فَإِنَّمَا أَقْطَعُ لَهُ قِطْعَةً مِنَ النَّارِ فَلاَ يَأْخُذْهَا ‏"‏‏.‏\hadithno{2680}\hadithtrans{Narrated Um Salama:Once Allah's Messenger (ﷺ) said, "You people present your cases to me and some of you may be more eloquent and persuasive in presenting their argument. So, if I give some one's right to another (wrongly) because of the latter's (tricky) presentation of the case, I am really giving him a piece of fire; so he should not take it}}
\hadithdefcmd{bukhari}{2681}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ ـ رضى الله عنهما ـ أَخْبَرَهُ قَالَ أَخْبَرَنِي أَبُو سُفْيَانَ، أَنَّ هِرَقْلَ، قَالَ لَهُ سَأَلْتُكَ مَاذَا يَأْمُرُكُمْ فَزَعَمْتَ أَنَّهُ أَمَرَكُمْ بِالصَّلاَةِ وَالصِّدْقِ وَالْعَفَافِ وَالْوَفَاءِ بِالْعَهْدِ وَأَدَاءِ الأَمَانَةِ‏.‏ قَالَ وَهَذِهِ صِفَةُ نَبِيٍّ‏.‏\hadithno{2681}\hadithtrans{Narrated `Abdullah bin `Abbas:Abu Sufyan told me that Heraclius said to him, "When I inquired you what he (i.e. Muhammad) ordered you, you replied that he ordered you to establish the prayer, to speak the truth, to be chaste, to keep promises and to pay back trusts." Then Heraclius added, "These are really the qualities of a prophet}}
\hadithdefcmd{bukhari}{2682}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ أَبِي سُهَيْلٍ، نَافِعِ بْنِ مَالِكِ بْنِ أَبِي عَامِرٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ آيَةُ الْمُنَافِقِ ثَلاَثٌ إِذَا حَدَّثَ كَذَبَ، وَإِذَا اؤْتُمِنَ خَانَ، وَإِذَا وَعَدَ أَخَلَفَ ‏"‏‏.‏\hadithno{2682}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The signs of a hypocrite are three: (1) whenever he speaks, he tells a lie, (2) whenever he is entrusted, he proves to be dishonest, (3) whenever he promises, he breaks his promise}}
\hadithdefcmd{bukhari}{2683}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، عَنْ مُحَمَّدِ بْنِ عَلِيٍّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، رضى الله عنهم قَالَ لَمَّا مَاتَ النَّبِيُّ صلى الله عليه وسلم جَاءَ أَبَا بَكْرٍ مَالٌ مِنْ قِبَلِ الْعَلاَءِ بْنِ الْحَضْرَمِيِّ، فَقَالَ أَبُو بَكْرٍ مَنْ كَانَ لَهُ عَلَى النَّبِيِّ صلى الله عليه وسلم دَيْنٌ، أَوْ كَانَتْ لَهُ قِبَلَهُ عِدَةٌ، فَلْيَأْتِنَا‏.‏ قَالَ جَابِرٌ فَقُلْتُ وَعَدَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُعْطِيَنِي هَكَذَا وَهَكَذَا وَهَكَذَا، فَبَسَطَ يَدَيْهِ ثَلاَثَ مَرَّاتٍ، قَالَ جَابِرٌ فَعَدَّ فِي يَدِي خَمْسَمِائَةٍ، ثُمَّ خَمْسَمِائَةٍ، ثُمَّ خَمْسَمِائَةٍ‏.‏\hadithno{2683}\hadithtrans{Narrated Muhammad bin `Ali:Jabir bin `Abdullah said, "When the Prophet (ﷺ) died, Abu Bakr received some property from Al-`Ala bin Al-Hadrami. Abu Bakr said to the people, "Whoever has a money claim on the Prophet, or was promised something by him, should come to us (so that we may pay him his right)." Jabir added, "I said (to Abu Bakr), Allah's Messenger (ﷺ) promised me that he would give me this much, and this much, and this much (spreading his hands three times)." Jabir added, "Abu Bakr counted for me and handed me five-hundred (gold pieces), and then five-hundred, and then five-hundred}}
\hadithdefcmd{bukhari}{2684}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، أَخْبَرَنَا سَعِيدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مَرْوَانُ بْنُ شُجَاعٍ، عَنْ سَالِمٍ الأَفْطَسِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ سَأَلَنِي يَهُودِيٌّ مِنْ أَهْلِ الْحِيرَةِ أَىَّ الأَجَلَيْنِ قَضَى مُوسَى قُلْتُ لاَ أَدْرِي حَتَّى أَقْدَمَ عَلَى حَبْرِ الْعَرَبِ فَأَسْأَلَهُ‏.‏ فَقَدِمْتُ، فَسَأَلْتُ ابْنَ عَبَّاسٍ فَقَالَ قَضَى أَكْثَرَهُمَا وَأَطْيَبَهُمَا، إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا قَالَ فَعَلَ‏.‏\hadithno{2684}\hadithtrans{Narrated Sa`id bin Jubair:A Jew from Hira asked me which one of the two periods Musa (i.e. Prophet Moses) completed. I said, "I don't know, (but wait) till I see the most learned 'Arab and inquire him about it." So, I went to Ibn `Abbas and asked him. He replied, "Moses completed the longer and better period." Ibn `Abbas added, "No doubt, an apostle of Allah always does what he says}}
\hadithdefcmd{bukhari}{2685}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ يَا مَعْشَرَ الْمُسْلِمِينَ، كَيْفَ تَسْأَلُونَ أَهْلَ الْكِتَابِ، وَكِتَابُكُمُ الَّذِي أُنْزِلَ عَلَى نَبِيِّهِ صلى الله عليه وسلم أَحْدَثُ الأَخْبَارِ بِاللَّهِ، تَقْرَءُونَهُ لَمْ يُشَبْ، وَقَدْ حَدَّثَكُمُ اللَّهُ أَنَّ أَهْلَ الْكِتَابِ بَدَّلُوا مَا كَتَبَ اللَّهُ وَغَيَّرُوا بِأَيْدِيهِمُ الْكِتَابَ، فَقَالُوا هُوَ مِنْ عِنْدِ اللَّهِ، لِيَشْتَرُوا بِهِ ثَمَنًا قَلِيلاً أَفَلاَ يَنْهَاكُمْ مَا جَاءَكُمْ مِنَ الْعِلْمِ عَنْ مُسَاءَلَتِهِمْ، وَلاَ وَاللَّهِ مَا رَأَيْنَا مِنْهُمْ رَجُلاً قَطُّ يَسْأَلُكُمْ عَنِ الَّذِي أُنْزِلَ عَلَيْكُمْ‏.‏\hadithno{2685}\hadithtrans{Narrated Ubaidullah bin `Abdullah bin `Utba:Ibn `Abbas said, "O Muslims? How do you ask the people of the Scriptures, though your Book (i.e. the Qur'an) which was revealed to His Prophet is the most recent information from Allah and you recite it, the Book that has not been distorted? Allah has revealed to you that the people of the scriptures have changed with their own hands what was revealed to them and they have said (as regards their changed Scriptures): This is from Allah, in order to get some worldly benefit thereby." Ibn `Abbas added: "Isn't the knowledge revealed to you sufficient to prevent you from asking them? By Allah I have never seen any one of them asking (Muslims) about what has been revealed to you}}
\hadithdefcmd{bukhari}{2686}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي الشَّعْبِيُّ، أَنَّهُ سَمِعَ النُّعْمَانَ بْنَ بَشِيرٍ ـ رضى الله عنهما ـ يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَثَلُ الْمُدْهِنِ فِي حُدُودِ اللَّهِ وَالْوَاقِعِ فِيهَا مَثَلُ قَوْمٍ اسْتَهَمُوا سَفِينَةً، فَصَارَ بَعْضُهُمْ فِي أَسْفَلِهَا وَصَارَ بَعْضُهُمْ فِي أَعْلاَهَا، فَكَانَ الَّذِي فِي أَسْفَلِهَا يَمُرُّونَ بِالْمَاءِ عَلَى الَّذِينَ فِي أَعْلاَهَا، فَتَأَذَّوْا بِهِ، فَأَخَذَ فَأْسًا، فَجَعَلَ يَنْقُرُ أَسْفَلَ السَّفِينَةِ، فَأَتَوْهُ فَقَالُوا مَا لَكَ قَالَ تَأَذَّيْتُمْ بِي، وَلاَ بُدَّ لِي مِنَ الْمَاءِ، فَإِنْ أَخَذُوا عَلَى يَدَيْهِ أَنْجَوْهُ وَنَجَّوْا أَنْفُسَهُمْ، وَإِنْ تَرَكُوهُ أَهْلَكُوهُ وَأَهْلَكُوا أَنْفُسَهُمْ ‏"‏‏.‏\hadithno{2686}\hadithtrans{Narrated An-Nu`man bin Bashir:The Prophet (ﷺ) said, "The example of the person abiding by Allah's orders and limits (or the one who abides by the limits and regulations prescribed by Allah) in comparison to the one who does wrong and violates Allah's limits and orders is like the example of people drawing lots for seats in a boat. Some of them got seats in the upper part while the others in the lower part; those in the lower part have to pass by those in the upper one to get water, and that troubled the latter. One of them (i.e. the people in the lower part) took an axe and started making a hole in the bottom of the boat. The people of the upper part came and asked him, (saying), 'What is wrong with you?' He replied, "You have been troubled much by my (coming up to you), and I have to get water.' Now if they prevent him from doing that they will save him and themselves, but if they leave him (to do what he wants), they will destroy him and themselves}}
\hadithdefcmd{bukhari}{2687}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي خَارِجَةُ بْنُ زَيْدٍ الأَنْصَارِيُّ، أَنَّ أُمَّ الْعَلاَءِ، امْرَأَةً مِنْ نِسَائِهِمْ قَدْ بَايَعَتِ النَّبِيَّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ عُثْمَانَ بْنَ مَظْعُونٍ طَارَ لَهُ سَهْمُهُ فِي السُّكْنَى حِينَ أَقْرَعَتِ الأَنْصَارُ سُكْنَى الْمُهَاجِرِينَ‏.‏ قَالَتْ أُمُّ الْعَلاَءِ فَسَكَنَ عِنْدَنَا عُثْمَانُ بْنُ مَظْعُونٍ، فَاشْتَكَى، فَمَرَّضْنَاهُ حَتَّى إِذَا تُوُفِّيَ وَجَعَلْنَاهُ فِي ثِيَابِهِ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ رَحْمَةُ اللَّهِ عَلَيْكَ أَبَا السَّائِبِ، فَشَهَادَتِي عَلَيْكَ لَقَدْ أَكْرَمَكَ اللَّهُ‏.‏ فَقَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَمَا يُدْرِيكِ أَنَّ اللَّهَ أَكْرَمَهُ ‏"‏‏.‏ فَقُلْتُ لاَ أَدْرِي بِأَبِي أَنْتَ وَأُمِّي يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَّا عُثْمَانُ فَقَدْ جَاءَهُ ـ وَاللَّهِ ـ الْيَقِينُ وَإِنِّي لأَرْجُو لَهُ الْخَيْرَ، وَاللَّهِ مَا أَدْرِي وَأَنَا رَسُولُ اللَّهِ مَا يُفْعَلُ بِي ‏"‏‏.‏ قَالَتْ فَوَاللَّهِ لاَ أُزَكِّي أَحَدًا بَعْدَهُ أَبَدًا، وَأَحْزَنَنِي ذَلِكَ قَالَتْ فَنِمْتُ فَأُرِيتُ لِعُثْمَانَ عَيْنًا تَجْرِي، فَجِئْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَقَالَ ‏"‏ ذَلِكَ عَمَلُهُ ‏"‏‏.‏\hadithno{2687}\hadithtrans{Narrated Um Al-Ala:That when the Ansar drew lots as to which of the emigrants should dwell with which of the Ansar, the name of `Uthman bin Mazun came out (to be in their lot). Um Al-Ala further said, "Uthman stayed with us, and we nursed him when he got sick, but he died. We shrouded him in his clothes, and Allah's Apostle came to our house and I said, (addressing the dead `Uthman), 'O Abu As-Sa'ib! May Allah be merciful to you. I testify that Allah has blessed you.' The Prophet (ﷺ) said to me, "How do you know that Allah has blessed him?" I replied, 'I do not know O Allah's Messenger (ﷺ)! May my parents be sacrificed for you.' Allah's Messenger (ﷺ) said, 'As regards `Uthman, by Allah he has died and I really wish him every good, yet, by Allah, although I am Allah's Messenger (ﷺ), I do not know what will be done to him.' Um Al- Ala added, 'By Allah I shall never attest the piety of anybody after him. And what Allah's Messenger (ﷺ) said made me sad." Um Al-Ala further said, "Once I slept and saw in a dream, a flowing stream for `Uthman. So I went to Allah's Messenger (ﷺ) and told him about it, he said, 'That is (the symbol of) his deeds}}
\hadithdefcmd{bukhari}{2688}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ سَفَرًا أَقْرَعَ بَيْنَ نِسَائِهِ، فَأَيَّتُهُنَّ خَرَجَ سَهْمُهَا خَرَجَ بِهَا مَعَهُ، وَكَانَ يَقْسِمُ لِكُلِّ امْرَأَةٍ مِنْهُنَّ يَوْمَهَا وَلَيْلَتَهَا، غَيْرَ أَنَّ سَوْدَةَ بِنْتَ زَمْعَةَ وَهَبَتْ يَوْمَهَا وَلَيْلَتَهَا لِعَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم، تَبْتَغِي بِذَلِكَ رِضَا رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{2688}\hadithtrans{Narrated Aisha:Whenever Allah's Messenger (ﷺ) intended to go on a journey, he used to draw lots among his wives and would take with him the one on whom the lot fell. He also used to fix for everyone of his wives a day and a night, but Sauda bint Zam`a gave her day and night to `Aisha, the wife of the Prophet (ﷺ) intending thereby to please Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{2689}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ يَعْلَمُ النَّاسُ مَا فِي النِّدَاءِ وَالصَّفِّ الأَوَّلِ، ثُمَّ لَمْ يَجِدُوا إِلاَّ أَنْ يَسْتَهِمُوا عَلَيْهِ لاَسْتَهَمُوا، وَلَوْ يَعْلَمُونَ مَا فِي التَّهْجِيرِ لاَسْتَبَقُوا إِلَيْهِ، وَلَوْ يَعْلَمُونَ مَا فِي الْعَتَمَةِ وَالصُّبْحِ لأَتَوْهُمَا وَلَوْ حَبْوًا ‏"‏‏.‏\hadithno{2689}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If the people knew what is the reward of making the call (for the prayer) and (of being in) the first row (in the prayer), and if they found no other way to get this privilege except by casting lots, they would certainly cast lots for it. If they knew the reward of the noon prayer, they would race for it, and if they knew the reward of the morning (i.e. Fajr) and `Isha prayers, they would present themselves for the prayer even if they had to crawl to reach there}}
