% Auto-generated chapter 3 for tirmidhi
% Hadiths in this chapter: 36

\hadithdefcmd{tirmidhi}{452}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَبْدِ اللَّهِ بْنِ رَاشِدٍ الزَّوْفِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُرَّةَ الزَّوْفِيِّ، عَنْ خَارِجَةَ بْنِ حُذَافَةَ، أَنَّهُ قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّ اللَّهَ أَمَدَّكُمْ بِصَلاَةٍ هِيَ خَيْرٌ لَكُمْ مِنْ حُمْرِ النَّعَمِ الْوِتْرُ جَعَلَهُ اللَّهُ لَكُمْ فِيمَا بَيْنَ صَلاَةِ الْعِشَاءِ إِلَى أَنْ يَطْلُعَ الْفَجْرُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَبُرَيْدَةَ وَأَبِي بَصْرَةَ الْغِفَارِيِّ صَاحِبِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ خَارِجَةَ بْنِ حُذَافَةَ حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ يَزِيدَ بْنِ أَبِي حَبِيبٍ ‏.‏ وَقَدْ وَهِمَ بَعْضُ الْمُحَدِّثِينَ فِي هَذَا الْحَدِيثِ فَقَالَ عَنْ عَبْدِ اللَّهِ بْنِ رَاشِدٍ الزُّرَقِيِّ وَهُوَ وَهَمٌ فِي هَذَا ‏.‏ وَأَبُو بَصْرَةَ الْغِفَارِيُّ اسْمُهُ حُمَيْلُ بْنُ بَصْرَةَ وَقَالَ بَعْضُهُمْ جَمِيلُ بْنُ بَصْرَةَ وَلاَ يَصِحُّ ‏.‏ وَأَبُو بَصْرَةَ الْغِفَارِيُّ رَجُلٌ آخَرُ يَرْوِي عَنْ أَبِي ذَرٍّ وَهُوَ ابْنُ أَخِي أَبِي ذَرٍّ ‏.‏\hadithno{452}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Kharijab bin Hudhafah narrated:"Allah's Messenger came out to us and he said: 'Indeed Allah has assisted you with a Salat that is better for you than red camels: Al-Witr which Allah made for you between the Isha prayer till Al-Fajr has begun}}
\hadithdefcmd{tirmidhi}{453}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، قَالَ الْوِتْرُ لَيْسَ بِحَتْمٍ كَصَلاَتِكُمُ الْمَكْتُوبَةِ وَلَكِنْ سَنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏ "‏ إِنَّ اللَّهَ وِتْرٌ يُحِبُّ الْوِتْرَ فَأَوْتِرُوا يَا أَهْلَ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَابْنِ مَسْعُودٍ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ ‏.‏\hadithno{453}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ali said:"Al-Witr is not incumbent like your obligatory prayers, but it is a Sunnah of Allah's Messenger who said: "Indeed Allah is Witr (One), and He loves Al-Witr, so perform Al-Witr O people of the Qur'an}}
\hadithdefcmd{tirmidhi}{454}{وَرَوَى سُفْيَانُ الثَّوْرِيُّ، وَغَيْرُهُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، قَالَ الْوِتْرُ لَيْسَ بِحَتْمٍ كَهَيْئَةِ الصَّلاَةِ الْمَكْتُوبَةِ وَلَكِنْ سُنَّةٌ سَنَّهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ حَدَّثَنَا بِذَلِكَ مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ عَنْ سُفْيَانَ عَنْ أَبِي إِسْحَاقَ ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ أَبِي بَكْرِ بْنِ عَيَّاشٍ ‏.‏ وَقَدْ رَوَاهُ مَنْصُورُ بْنُ الْمُعْتَمِرِ عَنْ أَبِي إِسْحَاقَ نَحْوَ رِوَايَةِ أَبِي بَكْرِ بْنِ عَيَّاشٍ ‏.‏\hadithno{454}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Sufyan Ath-Thawri and others reported from Abu Ishaq, from Asim bin Damrah, that :Ali said: "Al-Witr is not incumbent like the status of the obligatory prayers, but it is a Sunnah which Allah's Messenger practiced}}
\hadithdefcmd{tirmidhi}{455}{\hadithno{455}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{456}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، حَدَّثَنَا أَبُو حَصِينٍ، عَنْ يَحْيَى بْنِ وَثَّابٍ، عَنْ مَسْرُوقٍ، أَنَّهُ سَأَلَ عَائِشَةَ عَنْ وِتْرِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ مِنْ كُلِّ اللَّيْلِ قَدْ أَوْتَرَ أَوَّلِهِ وَأَوْسَطِهِ وَآخِرِهِ فَانْتَهَى وِتْرُهُ حِينَ مَاتَ إِلَى السَّحَرِ ‏.‏ قَالَ أَبُو عِيسَى أَبُو حَصِينٍ اسْمُهُ عُثْمَانُ بْنُ عَاصِمٍ الأَسَدِيُّ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَجَابِرٍ وَأَبِي مَسْعُودٍ الأَنْصَارِيِّ وَأَبِي قَتَادَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ الَّذِي اخْتَارَهُ بَعْضُ أَهْلِ الْعِلْمِ الْوِتْرُ مِنْ آخِرِ اللَّيْلِ ‏.‏\hadithno{456}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Masruq narrated that :he asked Aishah about the Witr of the Prophet. She said: "He would perform Witr during all of the night; (either) its beginning, its middle, or its end. So when he died, his Witr ended, during the approachof As-Sahar}}
\hadithdefcmd{tirmidhi}{457}{\hadithno{457}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{458}{\hadithno{458}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{459}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ الْكَوْسَجُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ صَلاَةُ النَّبِيِّ صلى الله عليه وسلم مِنَ اللَّيْلِ ثَلاَثَ عَشْرَةَ رَكْعَةً يُوتِرُ مِنْ ذَلِكَ بِخَمْسٍ لاَ يَجْلِسُ فِي شَيْءٍ مِنْهُنَّ إِلاَّ فِي آخِرِهِنَّ فَإِذَا أَذَّنَ الْمُؤَذِّنُ قَامَ فَصَلَّى رَكْعَتَيْنِ خَفِيفَتَيْنِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي أَيُّوبَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَأَى بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمُ الْوِتْرَ بِخَمْسٍ وَقَالُوا لاَ يَجْلِسُ فِي شَيْءٍ مِنْهُنَّ إِلاَّ فِي آخِرِهِنَّ ‏.‏ قَالَ أَبُو عِيسَى وَسَأَلْتُ أَبَا مُصْعَبٍ الْمَدِينِيَّ عَنْ هَذَا الْحَدِيثِ كَانَ النَّبِيُّ صلى الله عليه وسلم يُوتِرُ بِالتِّسْعِ وَالسَّبْعِ قُلْتُ كَيْفَ يُوتِرُ بِالتِّسْعِ وَالسَّبْعِ قَالَ يُصَلِّي مَثْنَى مَثْنَى وَيُسَلِّمُ وَيُوتِرُ بِوَاحِدَةٍ ‏.‏\hadithno{459}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"The night prayer of Allah's Messenger was thirteen Rak'ah, five of which were his Witr, not sitting in any of them except at the end of them. When the Mu'adh-dhin called the Adhan he would stand to perform two light (Rak'ah)}}
\hadithdefcmd{tirmidhi}{460}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُوتِرُ بِثَلاَثٍ يَقْرَأُ فِيهِنَّ بِتِسْعِ سُوَرٍ مِنَ الْمُفَصَّلِ يَقْرَأُ فِي كُلِّ رَكْعَةٍ بِثَلاَثِ سُوَرٍ آخِرُهُنَّْ ‏(‏قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ وَعَائِشَةَ وَابْنِ عَبَّاسٍ وَأَبِي أَيُّوبَ ‏.‏ وَعَبْدُ الرَّحْمَنِ بْنُ أَبْزَى عَنْ أُبَىِّ بْنِ كَعْبٍ وَيُرْوَى أَيْضًا عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ هَكَذَا رَوَى بَعْضُهُمْ فَلَمْ يَذْكُرُوا فِيهِ عَنْ أُبَىٍّ وَذَكَرَ بَعْضُهُمْ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى عَنْ أُبَىٍّ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ ذَهَبَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِلَى هَذَا وَرَأَوْا أَنْ يُوتِرَ الرَّجُلُ بِثَلاَثٍ ‏.‏ قَالَ سُفْيَانُ إِنْ شِئْتَ أَوْتَرْتَ بِخَمْسٍ وَإِنْ شِئْتَ أَوْتَرْتَ بِثَلاَثٍ وَإِنْ شِئْتَ أَوْتَرْتَ بِرَكْعَةٍ ‏.‏ قَالَ سُفْيَانُ وَالَّذِي أَسْتَحِبُّ أَنْ أُوتِرَ بِثَلاَثِ رَكَعَاتٍ ‏.‏ وَهُوَ قَوْلُ ابْنِ الْمُبَارَكِ وَأَهْلِ الْكُوفَةِ ‏.‏ حَدَّثَنَا سَعِيدُ بْنُ يَعْقُوبَ الطَّالْقَانِيُّ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ عَنْ هِشَامٍ عَنْ مُحَمَّدِ بْنِ سِيرِينَ قَالَ كَانُوا يُوتِرُونَ بِخَمْسٍ وَبِثَلاَثٍ وَبِرَكْعَةٍ وَيَرَوْنَ كُلَّ ذَلِكَ حَسَنًا ‏.‏\hadithno{460}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Ali narrated:"Allah's Messenger would perform Al-Witr with three, reciting nine Surah from the Mufassal in them, reciting three Surah in each Rak'ah with Say: "Allah is One." At the end of them."Muhammad bin Sirin said: "They would perform Al-Witr with five, with three, and with one Rak'ah, and they considered all of that to be good}}
\hadithdefcmd{tirmidhi}{461}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَنَسِ بْنِ سِيرِينَ، قَالَ سَأَلْتُ ابْنَ عُمَرَ فَقُلْتُ أُطِيلُ فِي رَكْعَتَىِ الْفَجْرِ فَقَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ مَثْنَى مَثْنَى وَيُوتِرُ بِرَكْعَةٍ وَكَانَ يُصَلِّي الرَّكْعَتَيْنِ وَالأَذَانُ فِي أُذُنِهِ ‏.‏ يَعَنِي يُخَفِّفُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَجَابِرٍ وَالْفَضْلِ بْنِ عَبَّاسٍ وَأَبِي أَيُّوبَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ رَأَوْا أَنْ يَفْصِلَ الرَّجُلُ بَيْنَ الرَّكْعَتَيْنِ وَالثَّالِثَةِ يُوتِرُ بِرَكْعَةٍ ‏.‏ وَبِهِ يَقُولُ مَالِكٌ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{461}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Sirin narrated that :he asked Ibn Umar about the length of the two Rak'ah (before) Al-Fajr. He said: "The Prophet would pray two and two during the night, and he would perform Al-Witr with one Rak'ah. And he would pray two Rak'ah while he was hearing the Adhan [meaning that they were light]}}
\hadithdefcmd{tirmidhi}{462}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ فِي الْوِتْرِ بِـ ‏(‏سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏)‏ وَ ‏(‏قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏)‏ وَ ‏(‏قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ فِي رَكْعَةٍ رَكْعَةٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَائِشَةَ وَعَبْدِ الرَّحْمَنِ بْنِ أَبْزَى عَنْ أُبَىِّ بْنِ كَعْبٍ وَيُرْوَى عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَرَأَ فِي الْوِتْرِ فِي الرَّكْعَةِ الثَّالِثَةِ بِالْمُعَوِّذَتَيْنِ وَ ‏(‏قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ ‏.‏ وَالَّذِي اخْتَارَهُ أَكْثَرُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ أَنْ يُقْرَأَ بِـ ‏(‏سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏)‏ وَ ‏(‏قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏)‏ وَ ‏(‏قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ ‏.‏ يُقْرَأُ فِي كُلِّ رَكْعَةٍ مِنْ ذَلِكَ بِسُورَةٍ ‏.‏\hadithno{462}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated:"Allah's Messenger would recite during Al-Witr: "Glorify the Name of your Lord the Most High' and, 'Say: O you disbelievers!' and, 'Say: Allah is One,' in each Rak'ah}}
\hadithdefcmd{tirmidhi}{463}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبِ بْنِ الشَّهِيدِ الْبَصْرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْحَرَّانِيُّ، عَنْ خُصَيْفٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ جُرَيْجٍ، قَالَ سَأَلْنَا عَائِشَةَ بِأَىِّ شَيْءٍ كَانَ يُوتِرُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ كَانَ يَقْرَأُ فِي الأُولَى بِـ ‏(‏سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏)‏ وَفِي الثَّانِيَةِ بِـ‏(‏قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏)‏ وَفِي الثَّالِثَةِ بِـ ‏(‏قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ وَالْمُعَوِّذَتَيْنِ ‏.‏ قَالَ أَبُو عِيسَى ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ قَالَ وَعَبْدُ الْعَزِيزِ هَذَا هُوَ وَالِدُ ابْنِ جُرَيْجٍ صَاحِبِ عَطَاءٍ وَابْنُ جُرَيْجٍ اسْمُهُ عَبْدُ الْمَلِكِ بْنُ عَبْدِ الْعَزِيزِ بْنِ جُرَيْجٍ ‏.‏ وَقَدْ رَوَى يَحْيَى بْنُ سَعِيدٍ الأَنْصَارِيُّ هَذَا الْحَدِيثَ عَنْ عَمْرَةَ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{463}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abdul-Aziz bin Juraij said:"I asked Aishah about what (recitation) Allah's Messenger would perform Al-Witr with. She said: 'In the first he would recite: Glorify the Name of your Lord the Most High, in the second: Say: O you disbelievers!, and in the third: Say: Allah is One" and, Al-Mu'awwidhatain}}
\hadithdefcmd{tirmidhi}{464}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ، عَنْ أَبِي الْحَوْرَاءِ السَّعْدِيِّ، قَالَ قَالَ الْحَسَنُ بْنُ عَلِيٍّ رضى الله عَنْهُمَا عَلَّمَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم كَلِمَاتٍ أَقُولُهُنَّ فِي الْوِتْرِ ‏ "‏ اللَّهُمَّ اهْدِنِي فِيمَنْ هَدَيْتَ وَعَافِنِي فِيمَنْ عَافَيْتَ وَتَوَلَّنِي فِيمَنْ تَوَلَّيْتَ وَبَارِكْ لِي فِيمَا أَعْطَيْتَ وَقِنِي شَرَّ مَا قَضَيْتَ فَإِنَّكَ تَقْضِي وَلاَ يُقْضَى عَلَيْكَ وَإِنَّهُ لاَ يَذِلُّ مَنْ وَالَيْتَ تَبَارَكْتَ رَبَّنَا وَتَعَالَيْتَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ أَبِي الْحَوْرَاءِ السَّعْدِيِّ وَاسْمُهُ رَبِيعَةُ بْنُ شَيْبَانَ ‏.‏ وَلاَ نَعْرِفُ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الْقُنُوتِ فِي الْوِتْرِ شَيْئًا أَحْسَنَ مِنْ هَذَا ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي الْقُنُوتِ فِي الْوِتْرِ فَرَأَى عَبْدُ اللَّهِ بْنُ مَسْعُودٍ الْقُنُوتَ فِي الْوِتْرِ فِي السَّنَةِ كُلِّهَا وَاخْتَارَ الْقُنُوتَ قَبْلَ الرُّكُوعِ ‏.‏ وَهُوَ قَوْلُ بَعْضِ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَإِسْحَاقُ وَأَهْلُ الْكُوفَةِ ‏.‏ وَقَدْ رُوِيَ عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ أَنَّهُ كَانَ لاَ يَقْنُتُ إِلاَّ فِي النِّصْفِ الآخِرِ مِنْ رَمَضَانَ وَكَانَ يَقْنُتُ بَعْدَ الرُّكُوعِ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ ‏.‏\hadithno{464}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{Al-Hasan bin Ali [may Allah be pleased with him] said:"Allah's Messenger taught me some phrases to say during Al-Witr (Allahummahdini fiman hadait, wa a'fini fiman afait, wa tawallani fiman tawallait, wa barik Li fima atait, wa qini sharra ma qadait, fa Innaka taqdi wa la yuqda Alaik, wa innahu la yadhillu man walait, tabarakta Rabbana wa ta'alait.) 'O Allah guide me among those You have guided, pardon me among those You have pardoned, befriend me among those You have befriended, bless me in what You have granted, and save me from the evil that You decreed. Indeed You decree, and none can pass decree, and none can pass decree upon You, indeed he is not humiliated whom You have befriended, blessed are You our Lord and Exalted}}
\hadithdefcmd{tirmidhi}{465}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ نَامَ عَنِ الْوِتْرِ أَوْ نَسِيَهُ فَلْيُصَلِّ إِذَا ذَكَرَ وَإِذَا اسْتَيْقَظَ ‏"‏ ‏.‏\hadithno{465}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed Al-Khudri narrated that :Allah's Messenger said: "Whoever sleeps past Al-Witr or forgets it, then let him pray it when he remembers it or when he awakens}}
\hadithdefcmd{tirmidhi}{466}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ نَامَ عَنْ وِتْرِهِ فَلْيُصَلِّ إِذَا أَصْبَحَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ مِنَ الْحَدِيثِ الأَوَّلِ ‏.‏ قَالَ أَبُو عِيسَى سَمِعْتُ أَبَا دَاوُدَ السِّجْزِيَّ يَعْنِي سُلَيْمَانَ بْنَ الأَشْعَثِ يَقُولُ سَأَلْتُ أَحْمَدَ بْنَ حَنْبَلٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ زَيْدِ بْنِ أَسْلَمَ فَقَالَ أَخُوهُ عَبْدُ اللَّهِ لاَ بَأْسَ بِهِ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدًا يَذْكُرُ عَنْ عَلِيِّ بْنِ عَبْدِ اللَّهِ أَنَّهُ ضَعَّفَ عَبْدَ الرَّحْمَنِ بْنَ زَيْدِ بْنِ أَسْلَمَ وَقَالَ عَبْدُ اللَّهِ بْنُ زَيْدِ بْنِ أَسْلَمَ ثِقَةٌ ‏.‏ قَالَ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ بِالْكُوفَةِ إِلَى هَذَا الْحَدِيثِ فَقَالُوا يُوتِرُ الرَّجُلُ إِذَا ذَكَرَ وَإِنْ كَانَ بَعْدَ مَا طَلَعَتِ الشَّمْسُ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ ‏.‏\hadithno{466}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{Zaid bin Aslam narrated from his father that:the Prophet said: "Whoever sleeps past his Al-Witr then let him pray it in the morning}}
\hadithdefcmd{tirmidhi}{467}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ بَادِرُوا الصُّبْحَ بِالْوِتْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{467}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Umar narrated that :the Prophet said: "Precede the morning with Al-Witr}}
\hadithdefcmd{tirmidhi}{468}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوْتِرُوا قَبْلَ أَنْ تُصْبِحُوا ‏"‏ ‏.‏\hadithno{468}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Sa'eed Al-Khudri narrated that :Allah's Messenger said: "Perform Witr before the morning comes upon you}}
\hadithdefcmd{tirmidhi}{469}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا طَلَعَ الْفَجْرُ فَقَدْ ذَهَبَ كُلُّ صَلاَةِ اللَّيْلِ وَالْوِتْرُ فَأَوْتِرُوا قَبْلَ طُلُوعِ الْفَجْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَسُلَيْمَانُ بْنُ مُوسَى قَدْ تَفَرَّدَ بِهِ عَلَى هَذَا اللَّفْظِ ‏.‏ وَرُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لاَ وِتْرَ بَعْدَ صَلاَةِ الصُّبْحِ ‏"‏ ‏.‏ وَهُوَ قَوْلُ غَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ لاَ يَرَوْنَ الْوِتْرَ بَعْدَ صَلاَةِ الصُّبْحِ ‏.‏\hadithno{469}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Umar narrated that :Allah's Messenger said: "When Fajr begins, then every Salat of the night and Al-Witr have gone, so perform Al-Witr before Fajr begins}}
\hadithdefcmd{tirmidhi}{470}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا مُلاَزِمُ بْنُ عَمْرٍو، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بَدْرٍ، عَنْ قَيْسِ بْنِ طَلْقِ بْنِ عَلِيٍّ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ وِتْرَانِ فِي لَيْلَةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي الَّذِي يُوتِرُ مِنْ أَوَّلِ اللَّيْلِ ثُمَّ يَقُومُ مِنْ آخِرِهِ فَرَأَى بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ نَقْضَ الْوِتْرِ وَقَالُوا يُضِيفُ إِلَيْهَا رَكْعَةً وَيُصَلِّي مَا بَدَا لَهُ ثُمَّ يُوتِرُ فِي آخِرِ صَلاَتِهِ لأَنَّهُ ‏"‏ لاَ وِتْرَانِ فِي لَيْلَةٍ ‏"‏ ‏.‏ وَهُوَ الَّذِي ذَهَبَ إِلَيْهِ إِسْحَاقُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِذَا أَوْتَرَ مِنْ أَوَّلِ اللَّيْلِ ثُمَّ نَامَ ثُمَّ قَامَ مِنْ آخِرِ اللَّيْلِ فَإِنَّهُ يُصَلِّي مَا بَدَا لَهُ وَلاَ يَنْقُضُ وِتْرَهُ وَيَدَعُ وِتْرَهُ عَلَى مَا كَانَ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكِ بْنِ أَنَسٍ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَهْلِ الْكُوفَةِ وَأَحْمَدَ ‏.‏ وَهَذَا أَصَحُّ لأَنَّهُ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَدْ صَلَّى بَعْدَ الْوِتْرِ ‏.‏\hadithno{470}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Qais bin Talq bin Ali narrated that :his father said: I heard Allah's Messenger saying: "There are no two Witr in one night}}
\hadithdefcmd{tirmidhi}{471}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، عَنْ مَيْمُونِ بْنِ مُوسَى الْمَرَئِيِّ، عَنِ الْحَسَنِ، عَنْ أُمِّهِ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي بَعْدَ الْوِتْرِ رَكْعَتَيْنِ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ نَحْوُ هَذَا عَنْ أَبِي أُمَامَةَ وَعَائِشَةَ وَغَيْرِ وَاحِدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{471}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umm Salamah narrated:"The Prophet would pray two Rak'ah after Al-Witr}}
\hadithdefcmd{tirmidhi}{472}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ أَبِي بَكْرِ بْنِ عُمَرَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَعِيدِ بْنِ يَسَارٍ، قَالَ كُنْتُ أَمْشِي مَعَ ابْنِ عُمَرَ فِي سَفَرٍ فَتَخَلَّفْتُ عَنْهُ فَقَالَ أَيْنَ كُنْتَ فَقُلْتُ أَوْتَرْتُ ‏.‏ فَقَالَ أَلَيْسَ لَكَ فِي رَسُولِ اللَّهِ أُسْوَةٌ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُوتِرُ عَلَى رَاحِلَتِهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِلَى هَذَا وَرَأَوْا أَنْ يُوتِرَ الرَّجُلُ عَلَى رَاحِلَتِهِ ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لاَ يُوتِرُ الرَّجُلُ عَلَى الرَّاحِلَةِ وَإِذَا أَرَادَ أَنْ يُوتِرَ نَزَلَ فَأَوْتَرَ عَلَى الأَرْضِ ‏.‏ وَهُوَ قَوْلُ بَعْضِ أَهْلِ الْكُوفَةِ ‏.‏ آخِرُ أَبْوَابِ الْوِتْرِ\hadithno{472}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sa'eed bin Yasar narrated:"I was with Ibn Umar on a journey and I fell behind him. He said: 'Where were you?' I said: 'I prayed Al-Witr.' He said: 'Is there not a good exampled for you in Allah's Messenger? I saw Allah's Messenger performing Al-Witr on his mount}}
\hadithdefcmd{tirmidhi}{473}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، قَالَ حَدَّثَنِي مُوسَى بْنُ فُلاَنِ بْنِ أَنَسٍ، عَنْ عَمِّهِ، ثُمَامَةَ بْنِ أَنَسِ بْنِ مَالِكٍ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى الضُّحَى ثِنْتَىْ عَشْرَةَ رَكْعَةً بَنَى اللَّهُ لَهُ قَصْرًا مِنْ ذَهَبٍ فِي الْجَنَّةِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ هَانِئٍ وَأَبِي هُرَيْرَةَ وَنُعَيْمِ بْنِ هَمَّارٍ وَأَبِي ذَرٍّ وَعَائِشَةَ وَأَبِي أُمَامَةَ وَعُتْبَةَ بْنِ عَبْدٍ السُّلَمِيِّ وَابْنِ أَبِي أَوْفَى وَأَبِي سَعِيدٍ وَزَيْدِ بْنِ أَرْقَمَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{473}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that :Allah's Messenger said: "Whoever prays twelve Rak'ah of Ad-Duha, Allah will build a castle made of gold for him in Paradise}}
\hadithdefcmd{tirmidhi}{474}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، قَالَ مَا أَخْبَرَنِي أَحَدٌ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم يُصَلِّي الضُّحَى إِلاَّ أُمُّ هَانِئٍ فَإِنَّهَا حَدَّثَتْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ بَيْتَهَا يَوْمَ فَتْحِ مَكَّةَ فَاغْتَسَلَ فَسَبَّحَ ثَمَانَ رَكَعَاتٍ مَا رَأَيْتُهُ صَلَّى صَلاَةً قَطُّ أَخَفَّ مِنْهَا غَيْرَ أَنَّهُ كَانَ يُتِمُّ الرُّكُوعَ وَالسُّجُودَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَكَأَنَّ أَحْمَدَ رَأَى أَصَحَّ شَيْءٍ فِي هَذَا الْبَابِ حَدِيثَ أُمِّ هَانِئٍ ‏.‏ وَاخْتَلَفُوا فِي نُعَيْمٍ فَقَالَ بَعْضُهُمْ نُعَيْمُ بْنُ خَمَّارٍ وَقَالَ بَعْضُهُمُ ابْنُ هَمَّارٍ وَيُقَالُ ابْنُ هَبَّارٍ وَيُقَالُ ابْنُ هَمَّامٍ وَالصَّحِيحُ ابْنُ هَمَّارٍ ‏.‏ وَأَبُو نُعَيْمٍ وَهِمَ فِيهِ فَقَالَ ابْنُ حِمَازٍ وَأَخْطَأَ فِيهِ ثُمَّ تَرَكَ فَقَالَ نُعَيْمٌ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى وَأَخْبَرَنِي بِذَلِكَ عَبْدُ بْنُ حُمَيْدٍ عَنْ أَبِي نُعَيْمٍ ‏.‏\hadithno{474}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdur-Rahman bin Abi Laila narrated:"No one informed that they saw Allah's Messenger praying Ad-Duha except Umm Hani. She narrated that Allah's Messenger entered her house on the Day of the Conquest of Makkah. He performed Ghusl and performed eight voluntary Rak'ah such that she had not ever seen him pray any Salat lighter than them, but that he completed the bowing and prostrations}}
\hadithdefcmd{tirmidhi}{475}{حَدَّثَنَا أَبُو جَعْفَرٍ السِّمْنَانِيُّ، حَدَّثَنَا أَبُو مُسْهِرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِي الدَّرْدَاءِ، وَأَبِي، ذَرٍّ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَنِ اللَّهِ، عَزَّ وَجَلَّ أَنَّهُ قَالَ ابْنَ آدَمَ ارْكَعْ لِي مِنْ أَوَّلِ النَّهَارِ أَرْبَعَ رَكَعَاتٍ أَكْفِكَ آخِرَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{475}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jubair narrated from Abu Ad-Darda, or Abu Dharr, that :Allah's Messenger narrated that Allah, Blessed and Most High said: "Son of Adam: Perform four Rak'ah for Me in the beginning of the day it will suffice you for the latter part of it}}
\hadithdefcmd{tirmidhi}{476}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الْبَصْرِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ نَهَّاسِ بْنِ قَهْمٍ، عَنْ شَدَّادٍ أَبِي عَمَّارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَافَظَ عَلَى شُفْعَةِ الضُّحَى غُفِرَ لَهُ ذُنُوبُهُ وَإِنْ كَانَتْ مِثْلَ زَبَدِ الْبَحْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى وَكِيعٌ وَالنَّضْرُ بْنُ شُمَيْلٍ وَغَيْرُ وَاحِدٍ مِنَ الأَئِمَّةِ هَذَا الْحَدِيثَ عَنْ نَهَّاسِ بْنِ قَهْمٍ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِهِ ‏.‏\hadithno{476}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "Whoever continuously performs the two Rak'ah of Ad-Duha his sins will be forgiven, even if they be like the foam of the sea}}
\hadithdefcmd{tirmidhi}{477}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ الْبَغْدَادِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ رَبِيعَةَ، عَنْ فُضَيْلِ بْنِ مَرْزُوقٍ، عَنْ عَطِيَّةَ الْعَوْفِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم يُصَلِّي الضُّحَى حَتَّى نَقُولَ لاَ يَدَعُ وَيَدَعُهَا حَتَّى نَقُولَ لاَ يُصَلِّي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{477}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed Al-Khudri narrated:"The Prophet would pray Ad-Duha until we would say: 'He will not leave it.' And he would leave it until we would say: 'He will not pray it}}
\hadithdefcmd{tirmidhi}{478}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ مُسْلِمِ بْنِ أَبِي الْوَضَّاحِ، هُوَ أَبُو سَعِيدٍ الْمُؤَدِّبُ عَنْ عَبْدِ الْكَرِيمِ الْجَزَرِيِّ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ السَّائِبِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي أَرْبَعًا بَعْدَ أَنْ تَزُولَ الشَّمْسُ قَبْلَ الظُّهْرِ وَقَالَ ‏ "‏ إِنَّهَا سَاعَةٌ تُفْتَحُ فِيهَا أَبْوَابُ السَّمَاءِ وَأُحِبُّ أَنْ يَصْعَدَ لِي فِيهَا عَمَلٌ صَالِحٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي أَيُّوبَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ السَّائِبِ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يُصَلِّي أَرْبَعَ رَكَعَاتٍ بَعْدَ الزَّوَالِ لاَ يُسَلِّمُ إِلاَّ فِي آخِرِهِنَّ ‏.‏\hadithno{478}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin As-Sa'ib narrated:"Allah's Messenger would pray four (Rak'ah) after the Zawal of the sun before Az-Zuhr. He said: 'It is an hour in which the gates of the heavens are opened, and I love that a righteous deed should be raised up for me in it}}
\hadithdefcmd{tirmidhi}{479}{حَدَّثَنَا عَلِيُّ بْنُ عِيسَى بْنِ يَزِيدَ الْبَغْدَادِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَكْرٍ السَّهْمِيُّ، ‏.‏ وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُنِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ بَكْرٍ، عَنْ فَائِدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ إِلَى اللَّهِ حَاجَةٌ أَوْ إِلَى أَحَدٍ مِنْ بَنِي آدَمَ فَلْيَتَوَضَّأْ وَلْيُحْسِنِ الْوُضُوءَ ثُمَّ لْيُصَلِّ رَكْعَتَيْنِ ثُمَّ لْيُثْنِ عَلَى اللَّهِ وَلْيُصَلِّ عَلَى النَّبِيِّ صلى الله عليه وسلم ثُمَّ لْيَقُلْ لاَ إِلَهَ إِلاَّ اللَّهُ الْحَلِيمُ الْكَرِيمُ سُبْحَانَ اللَّهِ رَبِّ الْعَرْشِ الْعَظِيمِ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ أَسْأَلُكَ مُوجِبَاتِ رَحْمَتِكَ وَعَزَائِمَ مَغْفِرَتِكَ وَالْغَنِيمَةَ مِنْ كُلِّ بِرٍّ وَالسَّلاَمَةَ مِنْ كُلِّ إِثْمٍ لاَ تَدَعْ لِي ذَنْبًا إِلاَّ غَفَرْتَهُ وَلاَ هَمًّا إِلاَّ فَرَّجْتَهُ وَلاَ حَاجَةً هِيَ لَكَ رِضًا إِلاَّ قَضَيْتَهَا يَا أَرْحَمَ الرَّاحِمِينَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَفِي إِسْنَادِهِ مَقَالٌ ‏.‏ فَائِدُ بْنُ عَبْدِ الرَّحْمَنِ يُضَعَّفُ فِي الْحَدِيثِ وَفَائِدٌ هُوَ أَبُو الْوَرْقَاءِ ‏.‏\hadithno{479}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Abi Awfa narrated that :Allah's Messenger (ﷺ) said: "Whoever has a need from Allah, or from one of the sons of Adam, then let him perform Wudu', performing it well, then pray two Rak`ah, then praise Allah and say Salat upon the Prophet (ﷺ). Then let him say: (La ilaha illallah Al-Halimul-Karim. Subhan Allah Rabbil-`Arshil-`Azim. Al-Hamdulillahi Rabbil-`Alamin. As'aluka mujibati rahmatika wa `aza'im maghfiratika, wal-ghanimata min kulli birrin, was-salamata min kulli ithmin, la tada` li dhanban illa ghafartahu, wa la hamman illa farrajtahu, wa la Hajatan hiya laka ridan Illa Qadaitaha, ya arham ar-rahimin) 'None has the right to be worshiped but Allah. Al-Halim (the Forbearing) Al-Karim (the Generous). Glorious is Allah, Lord of the Magnificent Throne. All praise is due to Allah, Lord of the worlds. I ask You for that which warrants Your mercy, and that which will determine Your forgiveness, and the spoils (fruits) of every righteous deed, and safety from every sin; do not leave a sin for me without forgiving it, nor a worry without relieving it. Or a need that pleases you without granting it. O Most-Merciful of those who have mercy}}
\hadithdefcmd{tirmidhi}{480}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الْمَوَالِي، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُنَا الاِسْتِخَارَةَ فِي الأُمُورِ كُلِّهَا كَمَا يُعَلِّمُنَا السُّورَةَ مِنَ الْقُرْآنِ يَقُولُ ‏ "‏ إِذَا هَمَّ أَحَدُكُمْ بِالأَمْرِ فَلْيَرْكَعْ رَكْعَتَيْنِ مِنْ غَيْرِ الْفَرِيضَةِ ثُمَّ لْيَقُلِ اللَّهُمَّ إِنِّي أَسْتَخِيرُكَ بِعِلْمِكَ وَأَسْتَقْدِرُكَ بِقُدْرَتِكَ وَأَسْأَلُكَ مِنْ فَضْلِكَ الْعَظِيمِ فَإِنَّكَ تَقْدِرُ وَلاَ أَقْدِرُ وَتَعْلَمُ وَلاَ أَعْلَمُ وَأَنْتَ عَلاَّمُ الْغُيُوبِ اللَّهُمَّ إِنْ كُنْتَ تَعْلَمُ أَنَّ هَذَا الأَمْرَ خَيْرٌ لِي فِي دِينِي وَمَعِيشَتِي وَعَاقِبَةِ أَمْرِي أَوْ قَالَ فِي عَاجِلِ أَمْرِي وَآجِلِهِ فَيَسِّرْهُ لِي ثُمَّ بَارِكْ لِي فِيهِ وَإِنْ كُنْتَ تَعْلَمُ أَنَّ هَذَا الأَمْرَ شَرٌّ لِي فِي دِينِي وَمَعِيشَتِي وَعَاقِبَةِ أَمْرِي أَوْ قَالَ فِي عَاجِلِ أَمْرِي وَآجِلِهِ فَاصْرِفْهُ عَنِّي وَاصْرِفْنِي عَنْهُ وَاقْدُرْ لِيَ الْخَيْرَ حَيْثُ كَانَ ثُمَّ أَرْضِنِي بِهِ قَالَ وَيُسَمِّي حَاجَتَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَأَبِي أَيُّوبَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي الْمَوَالِي ‏.‏ وَهُوَ شَيْخٌ مَدِينِيٌّ ثِقَةٌ رَوَى عَنْهُ سُفْيَانُ حَدِيثًا وَقَدْ رَوَى عَنْ عَبْدِ الرَّحْمَنِ غَيْرُ وَاحِدٍ مِنَ الأَئِمَّةِ وَهُوَ عَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَبِي الْمَوَالِي ‏.‏\hadithno{480}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Jabir bin Abdullah narrated:"Allah's Messenger would teach us Al-Isthikhara for all of our affairs just as he would teach us a Surah of the Qur'an, saying: 'When one of you is worried about a matter, then let him perform two Rak'ah other than the obligatory (prayer), then let him say: (Allahumma inni astakhiruka bi'ilmika, wa astaqdiruka biqudratika, wa as'aluka min falikal-azim, fa innaka taqdiru wa la qadiru, wa ta'lami wa la a'lamu, wa anta allamul-ghayub. Allahumma in kunta ta'lamu anna hadhal-amra khairun li fi dini wa ma'ishati wa aqibati amri, or said: Fi ajili amri wa ajilihi fayassirhu li,thumma barik li fihi, wa in kunta ta'lamu anna hadhal-amra sharrun li fi dini wa ma'ishati wa aqibati amri, or said: Fi ajili amri wa ajilihi fasrifhu anni wasrifni anhu waqdur Lil-khaira haithu kana, thumma ardini bih.)" 'O Allah! I consult Your knowledge, and seek ability from Your power, and I ask You from Your magnificent bounty, for indeed You have power and I do not have power, and You know while I do not know, and You know the unseen. O Allah! If you know that this matter is good for me in my religion or my livelihood, and for my life in the Hereafter - or he said: for my present and future - then make it easy for me, then bless me in it. If You know that this matter is bad for me in my religion and my livelihood and my life in the Hereafter - or he said: for my present and future - then divert it from me and divert me from it, enable me to find the good wherever it is, then make me pleased with it."He said: "And he mentions his need}}
\hadithdefcmd{tirmidhi}{481}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ مُوسَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنِي إِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ أُمَّ سُلَيْمٍ، غَدَتْ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ عَلِّمْنِي كَلِمَاتٍ أَقُولُهُنَّ فِي صَلاَتِي ‏.‏ فَقَالَ ‏"‏ كَبِّرِي اللَّهَ عَشْرًا وَسَبِّحِي اللَّهَ عَشْرًا وَاحْمَدِيهِ عَشْرًا ثُمَّ سَلِي مَا شِئْتِ يَقُولُ نَعَمْ نَعَمْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَالْفَضْلِ بْنِ عَبَّاسٍ وَأَبِي رَافِعٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم غَيْرُ حَدِيثٍ فِي صَلاَةِ التَّسْبِيحِ وَلاَ يَصِحُّ مِنْهُ كَبِيرُ شَيْءٍ ‏.‏ وَقَدْ رَأَى ابْنُ الْمُبَارَكِ وَغَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ صَلاَةَ التَّسْبِيحِ وَذَكَرُوا الْفَضْلَ فِيهِ ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ حَدَّثَنَا أَبُو وَهْبٍ قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ الْمُبَارَكِ عَنِ الصَّلاَةِ الَّتِي يُسَبَّحُ فِيهَا فَقَالَ يُكَبِّرُ ثُمَّ يَقُولُ سُبْحَانَكَ اللَّهُمَّ وَبِحَمْدِكَ وَتَبَارَكَ اسْمُكَ وَتَعَالَى جَدُّكَ وَلاَ إِلَهَ غَيْرُكَ ثُمَّ يَقُولُ خَمْسَ عَشْرَةَ مَرَّةً سُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ ثُمَّ يَتَعَوَّذُ وَيَقْرَأُ ‏(‏بِسمِ الله الرَّحْمَنِ الرَّحِيمِ‏)‏ وَفَاتِحَةَ الْكِتَابِ وَسُورَةً ثُمَّ يَقُولُ عَشْرَ مَرَّاتٍ سُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ ثُمَّ يَرْكَعُ فَيَقُولُهَا عَشْرًا ‏.‏ ثُمَّ يَرْفَعُ رَأْسَهُ مِنَ الرُّكُوعِ فَيَقُولُهَا عَشْرًا ثُمَّ يَسْجُدُ فَيَقُولُهَا عَشْرًا ثُمَّ يَرْفَعُ رَأْسَهُ فَيَقُولُهَا عَشْرًا ثُمَّ يَسْجُدُ الثَّانِيَةَ فَيَقُولُهَا عَشْرًا يُصَلِّي أَرْبَعَ رَكَعَاتٍ عَلَى هَذَا فَذَلِكَ خَمْسٌ وَسَبْعُونَ تَسْبِيحَةً فِي كُلِّ رَكْعَةٍ يَبْدَأُ فِي كُلِّ رَكْعَةٍ بِخَمْسَ عَشْرَةَ تَسْبِيحَةً ثُمَّ يَقْرَأُ ثُمَّ يُسَبِّحُ عَشْرًا فَإِنْ صَلَّى لَيْلاً فَأَحَبُّ إِلَىَّ أَنْ يُسَلِّمَ فِي الرَّكْعَتَيْنِ وَإِنْ صَلَّى نَهَارًا فَإِنْ شَاءَ سَلَّمَ وَإِنْ شَاءَ لَمْ يُسَلِّمْ ‏.‏ قَالَ أَبُو وَهْبٍ وَأَخْبَرَنِي عَبْدُ الْعَزِيزِ بْنُ أَبِي رِزْمَةَ عَنْ عَبْدِ اللَّهِ أَنَّهُ قَالَ يَبْدَأُ فِي الرُّكُوعِ بِسُبْحَانَ رَبِّيَ الْعَظِيمِ وَفِي السُّجُودِ بِسُبْحَانَ رَبِّيَ الأَعْلَى ثَلاَثًا ثُمَّ يُسَبِّحُ التَّسْبِيحَاتِ ‏.‏ قَالَ أَحْمَدُ بْنُ عَبْدَةَ وَحَدَّثَنَا وَهْبُ بْنُ زَمْعَةَ قَالَ أَخْبَرَنِي عَبْدُ الْعَزِيزِ وَهُوَ ابْنُ أَبِي رِزْمَةَ قَالَ قُلْتُ لِعَبْدِ اللَّهِ بْنِ الْمُبَارَكِ إِنْ سَهَا فِيهَا يُسَبِّحُ فِي سَجْدَتَىِ السَّهْوِ عَشْرًا عَشْرًا قَالَ لاَ إِنَّمَا هِيَ ثَلاَثُمِائَةِ تَسْبِيحَةٍ ‏.‏\hadithno{481}\hadithgrade{Ahmad Muhammad Shakir: Hasan Isnaad; Al-Albani: Hasan Isnaad; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated that :Umm Sulaim came upon the Prophet and said: "Teach me some words that I can say in my Salat." So he said: "Mention Allah's Greatness (saying: Allahu Akbar) ten times, mention Allah's Glory (saying: Subhan Allah) ten times, and mention Allah's praise (saying: Al-Hamdulilah) ten times. Then ask as you like, (for which) He says: 'Yes. Yes}}
\hadithdefcmd{tirmidhi}{482}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ الْعُكْلِيُّ، حَدَّثَنَا مُوسَى بْنُ عُبَيْدَةَ، حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، مَوْلَى أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ عَنْ أَبِي رَافِعٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلْعَبَّاسِ ‏"‏ يَا عَمِّ أَلاَ أَصِلُكَ أَلاَ أَحْبُوكَ أَلاَ أَنْفَعُكَ ‏"‏ ‏.‏ قَالَ بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ يَا عَمِّ صَلِّ أَرْبَعَ رَكَعَاتٍ تَقْرَأُ فِي كُلِّ رَكْعَةٍ بِفَاتِحَةِ الْكِتَابِ وَسُورَةٍ فَإِذَا انْقَضَتِ الْقِرَاءَةُ فَقُلِ اللَّهُ أَكْبَرُ وَالْحَمْدُ لِلَّهِ وَسُبْحَانَ اللَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ خَمْسَ عَشْرَةَ مَرَّةً قَبْلَ أَنْ تَرْكَعَ ثُمَّ ارْكَعْ فَقُلْهَا عَشْرًا ثُمَّ ارْفَعْ رَأْسَكَ فَقُلْهَا عَشْرًا ثُمَّ اسْجُدْ فَقُلْهَا عَشْرًا ثُمَّ ارْفَعْ رَأْسَكَ فَقُلْهَا عَشْرًا ثُمَّ اسْجُدِ الثَّانِيَةَ فَقُلْهَا عَشْرًا ثُمَّ ارْفَعْ رَأْسَكَ فَقُلْهَا عَشْرًا قَبْلَ أَنْ تَقُومَ فَتِلْكَ خَمْسٌ وَسَبْعُونَ فِي كُلِّ رَكْعَةٍ وَهِيَ ثَلاَثُمِائَةٍ فِي أَرْبَعِ رَكَعَاتٍ فَلَوْ كَانَتْ ذُنُوبُكَ مِثْلَ رَمْلِ عَالِجٍ لَغَفَرَهَا اللَّهُ لَكَ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ وَمَنْ يَسْتَطِيعُ أَنْ يَقُولَهَا فِي كُلِّ يَوْمٍ قَالَ ‏"‏ فَإِنْ لَمْ تَسْتَطِعْ أَنْ تَقُولَهَا فِي كُلِّ يَوْمٍ فَقُلْهَا فِي جُمُعَةٍ فَإِنْ لَمْ تَسْتَطِعْ أَنْ تَقُولَهَا فِي جُمُعَةٍ فَقُلْهَا فِي شَهْرٍ ‏"‏ ‏.‏ فَلَمْ يَزَلْ يَقُولُ لَهُ حَتَّى قَالَ ‏"‏ فَقُلْهَا فِي سَنَةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ أَبِي رَافِعٍ ‏.‏\hadithno{482}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Rafi narrated that :Allah's Messenger said to Al-Abbas: "O uncle! Shall I not give to you, shall I not present to you, shall I not benefit you?" He said: "Of course, O Messenger of Allah!" He said: "O uncle! Pray four Rak'ah, reciting in each Rak'ah Fatihatil-Kitab and a Surah. When you are finished your recitation then say: Allahu Akbar, wal-hamdulilah, wa Subhan-Allah, [Wa La Ilaha illallah] 'Allah is Greatest, and all praise is due to Allah, and Glorious is Allah, [and there is none worthy of worship except Allah].' fifteen times before you bow. Then bow and say it ten times, then raise your head and say it ten times. Then prostrate [the second time] and say it ten times. Then raise your head and say it ten times before standing. That is seventy-five in every Rak'ah, which is three-hundred in four Rak'ah. If your sins were like a heap of sand then Allah would forgive you." He said: "O Messenger if Allah! Who is able to say that every day?" He said: "If you can not say it every day then say it every Friday, and if you are not able to say it every Friday then say it every month." And he did not stop saying that until he said: "Then say it every year}}
\hadithdefcmd{tirmidhi}{483}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ مِسْعَرٍ، وَالأَجْلَحِ، وَمَالِكِ بْنِ مِغْوَلٍ، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، قَالَ قُلْنَا يَا رَسُولَ اللَّهِ هَذَا السَّلاَمُ عَلَيْكَ قَدْ عَلِمْنَا فَكَيْفَ الصَّلاَةُ عَلَيْكَ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا صَلَّيْتَ عَلَى إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ وَبَارِكْ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى إِبْرَاهِيمَ إِنَّكَ حَمِيِدٌ مَجِيدٌ ‏"‏ ‏.‏ قَالَ مَحْمُودٌ قَالَ أَبُو أُسَامَةَ وَزَادَنِي زَائِدَةُ عَنِ الأَعْمَشِ عَنِ الْحَكَمِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى قَالَ وَنَحْنُ نَقُولُ وَعَلَيْنَا مَعَهُمْ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي حُمَيْدٍ وَأَبِي مَسْعُودٍ وَطَلْحَةَ وَأَبِي سَعِيدٍ وَبُرَيْدَةَ وَزَيْدِ بْنِ خَارِجَةَ وَيُقَالُ ابْنُ جَارِيَةَ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ كَعْبِ بْنِ عُجْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعَبْدُ الرَّحْمَنِ بْنُ أَبِي لَيْلَى كُنْيَتُهُ أَبُو عِيسَى وَأَبُو لَيْلَى اسْمُهُ يَسَارٌ ‏.‏\hadithno{483}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ka'b bin Ujrah narrated:"We said: 'O Messenger of Allah! We have learned about saying the Salam to you, but how about As-Salat upon you?' He said: 'Say: (Allahumma salli ala Muhammadin Wa Ala ali Muhammadin kama sallaita Ala Ibrahim, Innaka hamidan MAjid, Wa barik Ala Muhammadin wa Ala ali Muhammadin kamma barakta Ala Ibrahim Innaka Hamidan Majid)" O Allah! Send Salat upon Muhammad and upon Muhammad's family just as You have sent Salat upon Ibrahim, indeed You are the Praise and Majestic. And send blessings upon Muhammad and Muhammad's family just as You have sent blessing upon Ibrahim, indeed You are the Praised and Majestic.'Mahmud said: "Abu Usamah said: Za'idah added something for me, from Al-Amash, from Al-Hakam, from Abdur-Rahman bin Abi Laila, that he said: "We would say 'And upon us along with them}}
\hadithdefcmd{tirmidhi}{484}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، بُنْدَارٌ حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدِ ابْنُ عَثْمَةَ، حَدَّثَنِي مُوسَى بْنُ يَعْقُوبَ الزَّمْعِيُّ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ كَيْسَانَ، أَنَّ عَبْدَ اللَّهِ بْنَ شَدَّادٍ، أَخْبَرَهُ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَوْلَى النَّاسِ بِي يَوْمَ الْقِيَامَةِ أَكْثَرُهُمْ عَلَىَّ صَلاَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَرُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ مَنْ صَلَّى عَلَىَّ صَلاَةً صَلَّى اللَّهُ عَلَيْهِ بِهَا عَشْرًا وَكَتَبَ لَهُ بِهَا عَشْرَ حَسَنَاتٍ ‏"‏ ‏.‏\hadithno{484}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Mas'ud narrated that :Allah's Messenger said: "The person closest to me on the Day of Judgement is the one who sent the most Salat upon me}}
\hadithdefcmd{tirmidhi}{485}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى عَلَىَّ صَلاَةً صَلَّى اللَّهُ عَلَيْهِ بِهَا عَشْرًا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَعَامِرِ بْنِ رَبِيعَةَ وَعَمَّارٍ وَأَبِي طَلْحَةَ وَأَنَسٍ وَأُبَىِّ بْنِ كَعْبٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرُوِيَ عَنْ سُفْيَانَ الثَّوْرِيِّ وَغَيْرِ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ قَالُوا صَلاَةُ الرَّبِّ الرَّحْمَةُ وَصَلاَةُ الْمَلاَئِكَةِ الاِسْتِغْفَارُ ‏.‏\hadithno{485}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that :Allah's Messenger said: "Whoever sends Salat upon me, Allah sends Salat upon him ten times}}
\hadithdefcmd{tirmidhi}{486}{حَدَّثَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ سَلْمٍ الْمَصَاحِفِيُّ الْبَلْخِيُّ أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، عَنْ أَبِي قُرَّةَ الأَسَدِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ إِنَّ الدُّعَاءَ مَوْقُوفٌ بَيْنَ السَّمَاءِ وَالأَرْضِ لاَ يَصْعَدُ مِنْهُ شَيْءٌ حَتَّى تُصَلِّيَ عَلَى نَبِيِّكَ صلى الله عليه وسلم ‏.‏\hadithno{486}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Umar bin Al-Khattab narrated:"Indeed the supplication stops between the heavens and the earth. Nothing of it is raised up until you send Salat upon your Prophet}}
\hadithdefcmd{tirmidhi}{487}{حَدَّثَنَا عَبَّاسٌ الْعَنْبَرِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَعْقُوبَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ لاَ يَبِعْ فِي سُوقِنَا إِلاَّ مَنْ قَدْ تَفَقَّهَ فِي الدِّينِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ عَبَّاسٌ هُوَ ابْنُ عَبْدِ الْعَظِيمِ ‏.‏ قَالَ أَبُو عِيسَى وَالْعَلاَءُ بْنُ عَبْدِ الرَّحْمَنِ هُوَ ابْنُ يَعْقُوبَ وَهُوَ مَوْلَى الْحُرَقَةِ وَالْعَلاَءُ هُوَ مِنَ التَّابِعِينَ سَمِعَ مِنْ أَنَسِ بْنِ مَالِكٍ وَغَيْرِهِ ‏.‏ وَعَبْدُ الرَّحْمَنِ بْنُ يَعْقُوبَ وَالِدُ الْعَلاَءِ هُوَ أَيْضًا مِنَ التَّابِعِينَ سَمِعَ مِنْ أَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ الْخُدْرِيِّ وَابْنِ عُمَرَ ‏.‏ وَيَعْقُوبُ جَدُّ الْعَلاَءِ هُوَ مِنْ كِبَارِ التَّابِعِينَ أَيْضًا قَدْ أَدْرَكَ عُمَرَ بْنَ الْخَطَّابِ وَرَوَى عَنْهُ ‏.‏ أبواب الجمعة عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{487}\hadithgrade{Ahmad Muhammad Shakir: Hasan Isnaad; Al-Albani: Hasan Isnaad; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Umar bin Al-Khattab [may Allah be pleased with him] said:"No one should sell in our markets except one who has understanding in the religion}}
