% Auto-generated chapter 43 for bukhari
% Hadiths in this chapter: 24

\hadithdefcmd{bukhari}{2385}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا جَرِيرٌ، عَنِ الْمُغِيرَةِ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ غَزَوْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كَيْفَ تَرَى بَعِيرَكَ أَتَبِيعُنِيهِ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ فَبِعْتُهُ إِيَّاهُ، فَلَمَّا قَدِمَ الْمَدِينَةَ غَدَوْتُ إِلَيْهِ بِالْبَعِيرِ، فَأَعْطَانِي ثَمَنَهُ‏.‏\hadithno{2385}\hadithtrans{Narrated Jabir bin `Abdullah:While I was in the company of the Prophet (ﷺ) in one of his Ghazawat, he asked, "What is wrong with your camel? Will you sell it?" I replied in the affirmative and sold it to him. When he reached Medina, I took the camel to him in the morning and he paid me its price}}
\hadithdefcmd{bukhari}{2386}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، قَالَ تَذَاكَرْنَا عِنْدَ إِبْرَاهِيمَ الرَّهْنَ فِي السَّلَمِ فَقَالَ حَدَّثَنِي الأَسْوَدُ عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم اشْتَرَى طَعَامًا مِنْ يَهُودِيٍّ إِلَى أَجَلٍ، وَرَهَنَهُ دِرْعًا مِنْ حَدِيدٍ‏.‏\hadithno{2386}\hadithtrans{Narrated Al-A`mash:When we were with Ibrahim, we talked about mortgaging in deals of Salam. Ibrahim narrated from Aswad that `Aisha had said, "The Prophet (ﷺ) bought some foodstuff on credit from a Jew and mortgaged an iron armor to him}}
\hadithdefcmd{bukhari}{2387}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ الأُوَيْسِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَخَذَ أَمْوَالَ النَّاسِ يُرِيدُ أَدَاءَهَا أَدَّى اللَّهُ عَنْهُ، وَمَنْ أَخَذَ يُرِيدُ إِتْلاَفَهَا أَتْلَفَهُ اللَّهُ ‏"‏‏.‏\hadithno{2387}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever takes the money of the people with the intention of repaying it, Allah will repay it on his behalf, and whoever takes it in order to spoil it, then Allah will spoil him}}
\hadithdefcmd{bukhari}{2388}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو شِهَابٍ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ أَبِي ذَرٍّ ـ رضى الله عنه ـ قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَلَمَّا أَبْصَرَ ـ يَعْنِي أُحُدًا ـ قَالَ ‏"‏ مَا أُحِبُّ أَنَّهُ يُحَوَّلُ لِي ذَهَبًا يَمْكُثُ عِنْدِي مِنْهُ دِينَارٌ فَوْقَ ثَلاَثٍ، إِلاَّ دِينَارًا أُرْصِدُهُ لِدَيْنٍ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ الأَكْثَرِينَ هُمُ الأَقَلُّونَ، إِلاَّ مَنْ قَالَ بِالْمَالِ هَكَذَا وَهَكَذَا ‏"‏‏.‏ وَأَشَارَ أَبُو شِهَابٍ بَيْنَ يَدَيْهِ وَعَنْ يَمِينِهِ وَعَنْ شِمَالِهِ ـ وَقَلِيلٌ مَا هُمْ ـ وَقَالَ مَكَانَكَ‏.‏ وَتَقَدَّمَ غَيْرَ بَعِيدٍ، فَسَمِعْتُ صَوْتًا، فَأَرَدْتُ أَنْ آتِيَهُ، ثُمَّ ذَكَرْتُ قَوْلَهُ مَكَانَكَ حَتَّى آتِيَكَ، فَلَمَّا جَاءَ قُلْتُ يَا رَسُولَ اللَّهِ، الَّذِي سَمِعْتُ أَوْ قَالَ الصَّوْتُ الَّذِي سَمِعْتُ قَالَ ‏"‏ وَهَلْ سَمِعْتَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ أَتَانِي جِبْرِيلُ ـ عَلَيْهِ السَّلاَمُ ـ فَقَالَ مَنْ مَاتَ مِنْ أُمَّتِكَ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا دَخَلَ الْجَنَّةَ ‏"‏‏.‏ قُلْتُ وَإِنْ فَعَلَ كَذَا وَكَذَا قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏\hadithno{2388}\hadithtrans{Narrated Abu Dhar:Once, while I was in the company of the Prophet, he saw the mountain of Uhud and said, "I would not like to have this mountain turned into gold for me unless nothing of it, not even a single Dinar remains of it with me for more than three days (i.e. I will spend all of it in Allah's Cause), except that Dinar which I will keep for repaying debts." Then he said, "Those who are rich in this world would have little reward in the Hereafter except those who spend their money here and there (in Allah's Cause), and they are few in number." Then he ordered me to stay at my place and went not far away. I heard a voice and intended to go to him but I remembered his order, "Stay at your place till I return." On his return I said, "O Allah's Messenger (ﷺ)! (What was) that noise which I heard?" He said, "Did you hear anything?" I said, "Yes." He said, "Gabriel came and said to me, 'Whoever amongst your followers dies, worshipping none along with Allah, will enter Paradise.' " I said, "Even if he did such-and-such things (i.e. even if he stole or committed illegal sexual intercourse)" He said, "Yes}}
\hadithdefcmd{bukhari}{2389}{حَدَّثَنَا أَحْمَدُ بْنُ شَبِيبِ بْنِ سَعِيدٍ، حَدَّثَنَا أَبِي، عَنْ يُونُسَ، قَالَ ابْنُ شِهَابٍ حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، قَالَ قَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كَانَ لِي مِثْلُ أُحُدٍ ذَهَبًا، مَا يَسُرُّنِي أَنْ لاَ يَمُرَّ عَلَىَّ ثَلاَثٌ وَعِنْدِي مِنْهُ شَىْءٌ، إِلاَّ شَىْءٌ أُرْصِدُهُ لِدَيْنٍ ‏"‏‏.‏ رَوَاهُ صَالِحٌ وَعُقَيْلٌ عَنِ الزُّهْرِيِّ‏.‏\hadithno{2389}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If I had gold equal to the mountain of Uhud, it would not please me that it should remain with me for more than three days, except an amount which I would keep for repaying debts}}
\hadithdefcmd{bukhari}{2390}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنَا سَلَمَةُ بْنُ كُهَيْلٍ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ، بِبَيْتِنَا يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَجُلاً، تَقَاضَى رَسُولَ اللَّهِ صلى الله عليه وسلم، فَأَغْلَظَ لَهُ، فَهَمَّ أَصْحَابُهُ، فَقَالَ ‏"‏ دَعُوهُ، فَإِنَّ لِصَاحِبِ الْحَقِّ مَقَالاً‏.‏ وَاشْتَرُوا لَهُ بَعِيرًا، فَأَعْطُوهُ إِيَّاهُ ‏"‏‏.‏ وَقَالُوا لاَ نَجِدُ إِلاَّ أَفْضَلَ مِنْ سِنِّهِ‏.‏ قَالَ ‏"‏ اشْتَرُوهُ فَأَعْطُوهُ إِيَّاهُ، فَإِنَّ خَيْرَكُمْ أَحْسَنُكُمْ قَضَاءً ‏"‏‏.‏\hadithno{2390}\hadithtrans{Narrated Abu Huraira:A man demanded his debts from Allah's Messenger (ﷺ) in such a rude manner that the companions of the Prophet intended to harm him, but the Prophet (ﷺ) said, "Leave him, no doubt, for he (the creditor) has the right to demand it (harshly). Buy a camel and give it to him." They said, "The camel that is available is older than the camel he demands. "The Prophet (ﷺ) said, "Buy it and give it to him, for the best among you are those who repay their debts handsomely}}
\hadithdefcmd{bukhari}{2391}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ، عَنْ رِبْعِيٍّ، عَنْ حُذَيْفَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَاتَ رَجُلٌ، فَقِيلَ لَهُ قَالَ كُنْتُ أُبَايِعُ النَّاسَ، فَأَتَجَوَّزُ عَنِ الْمُوسِرِ، وَأُخَفِّفُ عَنِ الْمُعْسِرِ، فَغُفِرَ لَهُ ‏"‏‏.‏ قَالَ أَبُو مَسْعُودٍ سَمِعْتُهُ مِنَ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2391}\hadithtrans{Narrated Hudhaifa:I heard the Prophet (ﷺ) saying, "Once a man died and was asked, 'What did you use to say (or do) (in your life time)?' He replied, 'I was a businessman and used to give time to the rich to repay his debt and (used to) deduct part of the debt of the poor.' So he was forgiven (his sins.)" Abu Mas`ud said, "I heard the same (Hadith) from the Prophet}}
\hadithdefcmd{bukhari}{2392}{حَدَّثَنَا مُسَدَّدٌ، عَنْ يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي سَلَمَةُ بْنُ كُهَيْلٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم يَتَقَاضَاهُ بَعِيرًا، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعْطُوهُ ‏"‏‏.‏ فَقَالُوا مَا نَجِدُ إِلاَّ سِنًّا أَفْضَلَ مِنْ سِنِّهِ‏.‏ فَقَالَ الرَّجُلُ أَوْفَيْتَنِي أَوْفَاكَ اللَّهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعْطُوهُ فَإِنَّ مِنْ خِيَارِ النَّاسِ أَحْسَنَهُمْ قَضَاءً ‏"‏‏.‏\hadithno{2392}\hadithtrans{Narrated Abu Huraira:A man came to the Prophet (ﷺ) and demanded a camel (the Prophet (ﷺ) owed him). Allah's Messenger (ﷺ) told his companions to give him (a camel). They said, "We do not find except an older camel (than what he demands). (The Prophet (ﷺ) ordered them to give him that camel). The man said, "You have paid me in full and may Allah also pay you in full." Allah's Messenger (ﷺ) said, "Give him, for the best amongst the people is he who repays his debts in the most handsome manner}}
\hadithdefcmd{bukhari}{2393}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ كَانَ لِرَجُلٍ عَلَى النَّبِيِّ صلى الله عليه وسلم سِنٌّ مِنَ الإِبِلِ فَجَاءَهُ يَتَقَاضَاهُ فَقَالَ صلى الله عليه وسلم ‏"‏ أَعْطُوهُ ‏"‏‏.‏ فَطَلَبُوا سِنَّهُ، فَلَمْ يَجِدُوا لَهُ إِلاَّ سِنًّا فَوْقَهَا‏.‏ فَقَالَ ‏"‏ أَعْطُوهُ ‏"‏‏.‏ فَقَالَ أَوْفَيْتَنِي، وَفَّى اللَّهُ بِكَ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ خِيَارَكُمْ أَحْسَنُكُمْ قَضَاءً ‏"‏‏.‏\hadithno{2393}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) owed a camel of a certain age to a man who came to demand it back. The Prophet (ﷺ) ordered his companions to give him. They looked for a camel of the same age but found nothing but a camel one year older. The Prophet (ﷺ) told them to give it to him. The man said, "You have paid me in full, and may Allah pay you in full." The Prophet (ﷺ) said, "The best amongst you is he who pays his debts in the most handsome manner}}
\hadithdefcmd{bukhari}{2394}{حَدَّثَنَا خَلاَّدٌ، حَدَّثَنَا مِسْعَرٌ، حَدَّثَنَا مُحَارِبُ بْنُ دِثَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَهْوَ فِي الْمَسْجِدِ ـ قَالَ مِسْعَرٌ أُرَاهُ قَالَ ضُحًى ـ فَقَالَ ‏ "‏ صَلِّ رَكْعَتَيْنِ ‏"‏‏.‏ وَكَانَ لِي عَلَيْهِ دَيْنٌ فَقَضَانِي وَزَادَنِي‏.‏\hadithno{2394}\hadithtrans{Narrated Jabir bin `Abdullah:I went to the Prophet (ﷺ) while he was in the Mosque. (Mis`ar thinks that Jabir went in the forenoon.) After the Prophet (ﷺ) told me to pray two rak`at, he repaid me the debt he owed me and gave me an extra amount}}
\hadithdefcmd{bukhari}{2395}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي ابْنُ كَعْبِ بْنِ مَالِكٍ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ أَبَاهُ قُتِلَ يَوْمَ أُحُدٍ شَهِيدًا، وَعَلَيْهِ دَيْنٌ فَاشْتَدَّ الْغُرَمَاءُ فِي حُقُوقِهِمْ، فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَسَأَلَهُمْ أَنْ يَقْبَلُوا تَمْرَ حَائِطِي وَيُحَلِّلُوا أَبِي فَأَبَوْا، فَلَمْ يُعْطِهِمِ النَّبِيُّ صلى الله عليه وسلم حَائِطِي، وَقَالَ ‏ "‏ سَنَغْدُو عَلَيْكَ ‏"‏‏.‏ فَغَدَا عَلَيْنَا حِينَ أَصْبَحَ، فَطَافَ فِي النَّخْلِ، وَدَعَا فِي ثَمَرِهَا بِالْبَرَكَةِ، فَجَدَدْتُهَا فَقَضَيْتُهُمْ، وَبَقِيَ لَنَا مِنْ تَمْرِهَا‏.‏\hadithno{2395}\hadithtrans{Narrated Jabir bin `Abdullah:My father was martyred on the day (of the battle) of Uhud, and he was in debt. His creditors demanded their rights persistently. I went to the Prophet (and informed him about it). He told them to take the fruits of my garden and exempt my father from the debts but they refused to do so. So, the Prophet did not give them my garden and told me that he would come to me the next morning. He came to us early in the morning and wandered among the date-palms and invoked Allah to bless their fruits. I then plucked the dates and paid the creditors, and there remained some of the dates for us}}
\hadithdefcmd{bukhari}{2396}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَنَسٌ، عَنْ هِشَامٍ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّهُ أَخْبَرَهُ أَنَّ أَبَاهُ تُوُفِّيَ، وَتَرَكَ عَلَيْهِ ثَلاَثِينَ وَسْقًا لِرَجُلٍ مِنَ الْيَهُودِ، فَاسْتَنْظَرَهُ جَابِرٌ، فَأَبَى أَنْ يُنْظِرَهُ، فَكَلَّمَ جَابِرٌ رَسُولَ اللَّهِ صلى الله عليه وسلم لِيَشْفَعَ لَهُ إِلَيْهِ، فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَلَّمَ الْيَهُودِيَّ لِيَأْخُذَ ثَمَرَ نَخْلِهِ بِالَّذِي لَهُ فَأَبَى، فَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّخْلَ، فَمَشَى فِيهَا ثُمَّ قَالَ لِجَابِرٍ ‏"‏ جُدَّ لَهُ فَأَوْفِ لَهُ الَّذِي لَهُ ‏"‏‏.‏ فَجَدَّهُ بَعْدَ مَا رَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَوْفَاهُ ثَلاَثِينَ وَسْقًا، وَفَضَلَتْ لَهُ سَبْعَةَ عَشَرَ وَسْقًا، فَجَاءَ جَابِرٌ رَسُولَ اللَّهِ صلى الله عليه وسلم لِيُخْبِرَهُ بِالَّذِي كَانَ، فَوَجَدَهُ يُصَلِّي الْعَصْرَ، فَلَمَّا انْصَرَفَ أَخْبَرَهُ بِالْفَضْلِ، فَقَالَ ‏"‏ أَخْبِرْ ذَلِكَ ابْنَ الْخَطَّابِ ‏"‏‏.‏ فَذَهَبَ جَابِرٌ إِلَى عُمَرَ، فَأَخْبَرَهُ‏.‏ فَقَالَ لَهُ عُمَرُ لَقَدْ عَلِمْتُ حِينَ مَشَى فِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُبَارَكَنَّ فِيهَا‏.‏\hadithno{2396}\hadithtrans{Narrated Jabir bin `Abdullah:When my father died he owed a Jew thirty Awsuq (of dates). I requested him to give me respite for repaying but he refused. I requested Allah's Messenger (ﷺ) to intercede with the Jew. Allah's Messenger (ﷺ) went to the Jew and asked him to accept the fruits of my trees in place of the debt but the Jew refused. Allah's Apostle entered the garden of the date-palms, wandering among the trees and ordered me (saying), "Pluck (the fruits) and give him his due." So, I plucked the fruits for him after the departure of Allah's Apostle and gave his thirty Awsuq, and still had seventeen Awsuq extra for myself. Jabir said: I went to Allah's Messenger (ﷺ) to inform of what had happened, but found him praying the `Asr prayer. After the prayer I told him about the extra fruits which remained. Allah's Messenger (ﷺ) told me to inform (`Umar) Ibn Al-Khattab about it. When I went to `Umar and told him about it, `Umar said, "When Allah's Messenger (ﷺ) walked in your garden, I was sure that Allah would definitely bless it}}
\hadithdefcmd{bukhari}{2397}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، ح وَحَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ أَبِي عَتِيقٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو فِي الصَّلاَةِ وَيَقُولُ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْمَأْثَمِ وَالْمَغْرَمِ ‏"‏‏.‏ فَقَالَ لَهُ قَائِلٌ مَا أَكْثَرَ مَا تَسْتَعِيذُ يَا رَسُولَ اللَّهِ مِنَ الْمَغْرَمِ قَالَ ‏"‏ إِنَّ الرَّجُلَ إِذَا غَرِمَ حَدَّثَ فَكَذَبَ وَوَعَدَ فَأَخْلَفَ ‏"‏‏.‏\hadithno{2397}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to invoke Allah in the prayer saying, "O Allah, I seek refuge with you from all sins, and from being in debt." Someone said, O Allah's Messenger (ﷺ)! (I see) very often you seek refuge with Allah from being in debt. He replied, "If a person is in debt, he tells lies when he speaks, and breaks his promises when he promises}}
\hadithdefcmd{bukhari}{2398}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَرَكَ مَالاً فَلِوَرَثَتِهِ، وَمَنْ تَرَكَ كَلاًّ فَإِلَيْنَا ‏"‏‏.‏\hadithno{2398}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If someone leaves some property, it will be for the inheritors, and if he leaves some weak offspring, it will be for us to support them}}
\hadithdefcmd{bukhari}{2399}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا فُلَيْحٌ، عَنْ هِلاَلِ بْنِ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ مَا مِنْ مُؤْمِنٍ إِلاَّ وَأَنَا أَوْلَى بِهِ فِي الدُّنْيَا وَالآخِرَةِ اقْرَءُوا إِنْ شِئْتُمْ ‏\{‏النَّبِيُّ أَوْلَى بِالْمُؤْمِنِينَ مِنْ أَنْفُسِهِمْ‏\}‏ فَأَيُّمَا مُؤْمِنٍ مَاتَ وَتَرَكَ مَالاً فَلْيَرِثْهُ عَصَبَتُهُ مَنْ كَانُوا، وَمَنْ تَرَكَ دَيْنًا أَوْ ضَيَاعًا فَلْيَأْتِنِي فَأَنَا مَوْلاَهُ ‏"‏‏.‏\hadithno{2399}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "I am closer to the believers than their selves in this world and in the Hereafter, and if you like, you can read Allah's Statement: "The Prophet (ﷺ) is closer to the believers than their own selves." (33.6) So, if a true believer dies and leaves behind some property, it will be for his inheritors (from the father's side), and if he leaves behind some debt to be paid or needy offspring, then they should come to me as I am the guardian of the deceased}}
\hadithdefcmd{bukhari}{2400}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مَعْمَرٍ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، أَخِي وَهْبِ بْنِ مُنَبِّهٍ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَطْلُ الْغَنِيِّ ظُلْمٌ ‏"‏‏.‏\hadithno{2400}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Procrastination (delay) in repaying debts by a wealthy person is injustice}}
\hadithdefcmd{bukhari}{2401}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ سَلَمَةَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَتَى النَّبِيَّ صلى الله عليه وسلم رَجُلٌ يَتَقَاضَاهُ فَأَغْلَظَ لَهُ فَهَمَّ بِهِ أَصْحَابُهُ‏.‏ فَقَالَ ‏ "‏ دَعُوهُ فَإِنَّ لِصَاحِبِ الْحَقِّ مَقَالاً ‏"‏‏.‏\hadithno{2401}\hadithtrans{Narrated Abu Huraira:A man came to the Prophet (ﷺ) and demanded his debts and used harsh words. The companions of the Prophet wanted to harm him, but the Prophet (ﷺ) said, "Leave him, as the creditor (owner of the right) has the right to speak}}
\hadithdefcmd{bukhari}{2402}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ أَخْبَرَنِي أَبُو بَكْرِ بْنُ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، أَخْبَرَهُ أَنَّ أَبَا بَكْرِ بْنَ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَوْ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَدْرَكَ مَالَهُ بِعَيْنِهِ عِنْدَ رَجُلٍ أَوْ إِنْسَانٍ قَدْ أَفْلَسَ، فَهْوَ أَحَقُّ بِهِ مِنْ غَيْرِهِ ‏"‏‏.‏\hadithno{2402}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If a man finds his very things with a bankrupt, he has more right to take them back than anyone else}}
\hadithdefcmd{bukhari}{2403}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، حَدَّثَنَا عَطَاءُ بْنُ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ أَعْتَقَ رَجُلٌ غُلاَمًا لَهُ عَنْ دُبُرٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ يَشْتَرِيهِ مِنِّي ‏"‏‏.‏ فَاشْتَرَاهُ نُعَيْمُ بْنُ عَبْدِ اللَّهِ، فَأَخَذَ ثَمَنَهُ، فَدَفَعَهُ إِلَيْهِ‏.‏\hadithno{2403}\hadithtrans{Narrated Jabir bin `Abdullah:A man pledged that his slave would be manumitted after his death. The Prophet (ﷺ) asked, "Who will buy the slave from me?" Nu'aim bin `Abdullah bought the slave and the Prophet (ﷺ) took its price and gave it to the owner}}
\hadithdefcmd{bukhari}{2404}{وَقَالَ اللَّيْثُ حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ ذَكَرَ رَجُلاً مِنْ بَنِي إِسْرَائِيلَ، سَأَلَ بَعْضَ بَنِي إِسْرَائِيلَ أَنْ يُسْلِفَهُ، فَدَفَعَهَا إِلَيْهِ إِلَى أَجَلٍ مُسَمًّى‏.‏ فَذَكَرَ الْحَدِيثَ‏.‏\hadithno{2404}\hadithtrans{Narrated Abu Hurairah (ra):Allah's Messenger (ﷺ) mentioned an Israeli man who asked another Israeli to lend him money, and the latter gave it to him for a fixed period. (Abu Hurairah mentioned the rest of narration) [See chapter: Kafala in loans and debts. Hadith]}}
\hadithdefcmd{bukhari}{2406}{حَدَّثَنَا مُوسَى، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مُغِيرَةَ، عَنْ عَامِرٍ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ أُصِيبَ عَبْدُ اللَّهِ وَتَرَكَ عِيَالاً وَدَيْنًا، فَطَلَبْتُ إِلَى أَصْحَابِ الدَّيْنِ أَنْ يَضَعُوا بَعْضًا مِنْ دَيْنِهِ فَأَبَوْا، فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَاسْتَشْفَعْتُ بِهِ عَلَيْهِمْ فَأَبَوْا، فَقَالَ ‏"‏ صَنِّفْ تَمْرَكَ كُلَّ شَىْءٍ مِنْهُ عَلَى حِدَتِهِ، عِذْقَ ابْنِ زَيْدٍ عَلَى حِدَةٍ، وَاللِّينَ عَلَى حِدَةٍ، وَالْعَجْوَةَ عَلَى حِدَةٍ، ثُمَّ أَحْضِرْهُمْ حَتَّى آتِيَكَ ‏"‏‏.‏ فَفَعَلْتُ، ثُمَّ جَاءَ صلى الله عليه وسلم فَقَعَدَ عَلَيْهِ، وَكَالَ لِكُلِّ رَجُلٍ حَتَّى اسْتَوْفَى، وَبَقِيَ التَّمْرُ كَمَا هُوَ كَأَنَّهُ لَمْ يُمَسَّ‏.‏ وَغَزَوْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم عَلَى نَاضِحٍ لَنَا، فَأَزْحَفَ الْجَمَلُ فَتَخَلَّفَ عَلَىَّ فَوَكَزَهُ النَّبِيُّ صلى الله عليه وسلم مِنْ خَلْفِهِ، قَالَ ‏"‏ بِعْنِيهِ وَلَكَ ظَهْرُهُ إِلَى الْمَدِينَةِ ‏"‏‏.‏ فَلَمَّا دَنَوْنَا اسْتَأْذَنْتُ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي حَدِيثُ عَهْدٍ بِعُرْسٍ‏.‏ قَالَ صلى الله عليه وسلم ‏"‏ فَمَا تَزَوَّجْتَ بِكْرًا أَمْ ثَيِّبًا ‏"‏‏.‏ قُلْتُ ثَيِّبًا، أُصِيبَ عَبْدُ اللَّهِ وَتَرَكَ جَوَارِيَ صِغَارًا، فَتَزَوَّجْتُ ثَيِّبًا تُعَلِّمُهُنَّ وَتُؤَدِّبُهُنَّ، ثُمَّ قَالَ ‏"‏ ائْتِ أَهْلَكَ ‏"‏‏.‏ فَقَدِمْتُ فَأَخْبَرْتُ خَالِي بِبَيْعِ الْجَمَلِ فَلاَمَنِي، فَأَخْبَرْتُهُ بِإِعْيَاءِ الْجَمَلِ، وَبِالَّذِي كَانَ مِنَ النَّبِيِّ صلى الله عليه وسلم وَوَكْزِهِ إِيَّاهُ، فَلَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم غَدَوْتُ إِلَيْهِ بِالْجَمَلِ، فَأَعْطَانِي ثَمَنَ الْجَمَلِ وَالْجَمَلَ وَسَهْمِي مَعَ الْقَوْمِ‏.‏\hadithno{2406}\hadithtrans{Narrated Jabir:When `Abdullah (my father) died, he left behind children and debts. I asked the lenders to put down some of his debt, but they refused, so I went to the Prophet (ﷺ) to intercede with them, yet they refused. The Prophet (ﷺ) said (to me), "Classify your dates into their different kinds: 'Adha bin Zaid, Lean and 'Ajwa, each kind alone and call all the creditors and wait till I come to you." I did so and the Prophet (ﷺ) came and sat beside the dates and started measuring to each his due till he paid them fully, and the amount of dates remained as it was before, as if he had not touched them. (On another occasion) I took part in one of Ghazawat along with the Prophet (ﷺ) and I was riding one of our camels. The camel got tired and was lagging behind the others. The Prophet (ﷺ) hit it on its back. He said, "Sell it to me, and you have the right to ride it till Medina.'' When we approached Medina, I took the permission from the Prophet (ﷺ) to go to my house, saying, "O Allah's Messenger (ﷺ)! I have newly married." The Prophet (ﷺ) asked, "Have you married a virgin or a matron (a widow or divorcee)?" I said, "I have married a matron, as `Abdullah (my father) died and left behind daughters small in their ages, so I married a matron who may teach them and bring them up with good manners." The Prophet (ﷺ) then said (to me), "Go to your family." When I went there and told my maternal uncle about the selling of the camel, he admonished me for it. On that I told him about its slowness and exhaustion and about what the Prophet (ﷺ) had done to the camel and his hitting it. When the Prophet (ﷺ) arrived, I went to him with the camel in the morning and he gave me its price, the camel itself, and my share from the war booty as he gave the other people}}
\hadithdefcmd{bukhari}{2407}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ رَجُلٌ لِلنَّبِيِّ صلى الله عليه وسلم إِنِّي أُخْدَعُ فِي الْبُيُوعِ‏.‏ فَقَالَ ‏ "‏ إِذَا بَايَعْتَ فَقُلْ لاَ خِلاَبَةَ ‏"‏‏.‏ فَكَانَ الرَّجُلُ يَقُولُهُ‏.‏\hadithno{2407}\hadithtrans{Narrated Ibn `Umar:A man came to the Prophet (ﷺ) and said, "I am often betrayed in bargaining." The Prophet (ﷺ) advised him, "When you buy something, say (to the seller), 'No deception." The man used to say so afterwards}}
\hadithdefcmd{bukhari}{2408}{حَدَّثَنَا عُثْمَانُ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الشَّعْبِيِّ، عَنْ وَرَّادٍ، مَوْلَى الْمُغِيرَةِ بْنِ شُعْبَةَ عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ حَرَّمَ عَلَيْكُمْ عُقُوقَ الأُمَّهَاتِ، وَوَأْدَ الْبَنَاتِ، وَمَنَعَ وَهَاتِ، وَكَرِهَ لَكُمْ قِيلَ وَقَالَ، وَكَثْرَةَ السُّؤَالِ، وَإِضَاعَةَ الْمَالِ ‏"‏‏.‏\hadithno{2408}\hadithtrans{Narrated Al-Mughira bin Shu`ba:The Prophet (ﷺ) said, "Allah has forbidden for you, (1) to be undutiful to your mothers, (2) to bury your daughters alive, (3) to not to pay the rights of the others (e.g. charity, etc.) and (4) to beg of men (begging). And Allah has hated for you (1) vain, useless talk, or that you talk too much about others, (2) to ask too many questions, (in disputed religious matters) and (3) to waste the wealth (by extravagance)}}
\hadithdefcmd{bukhari}{2409}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ كُلُّكُمْ رَاعٍ وَمَسْئُولٌ عَنْ رَعِيَّتِهِ، فَالإِمَامُ رَاعٍ، وَهْوَ مَسْئُولٌ عَنْ رَعِيَّتِهِ، وَالرَّجُلُ فِي أَهْلِهِ رَاعٍ، وَهْوَ مَسْئُولٌ عَنْ رَعِيَّتِهِ، وَالْمَرْأَةُ فِي بَيْتِ زَوْجِهَا رَاعِيَةٌ وَهْىَ مَسْئُولَةٌ عَنْ رَعِيَّتِهَا، وَالْخَادِمُ فِي مَالِ سَيِّدِهِ رَاعٍ، وَهْوَ مَسْئُولٌ عَنْ رَعِيَّتِهِ ‏"‏‏.‏ قَالَ فَسَمِعْتُ هَؤُلاَءِ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَحْسِبُ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ وَالرَّجُلُ فِي مَالِ أَبِيهِ رَاعٍ، وَهْوَ مَسْئُولٌ عَنْ رَعِيَّتِهِ، فَكُلُّكُمْ رَاعٍ، وَكُلُّكُمْ مَسْئُولٌ عَنْ رَعِيَّتِهِ ‏"‏‏.‏\hadithno{2409}\hadithtrans{Narrated `Abdullah bin `Umar:I heard Allah's Messenger (ﷺ) saying, "Everyone of you is a guardian, and responsible for what is in his custody. The ruler is a guardian of his subjects and responsible for them; a husband is a guardian of his family and is responsible for it; a lady is a guardian of her husband's house and is responsible for it, and a servant is a guardian of his master's property and is responsible for it." I heard that from Allah's Messenger (ﷺ) and I think that the Prophet (ﷺ) also said, "A man is a guardian of his father's property and is responsible for it, so all of you are guardians and responsible for your wards and things under your care}}
