% Auto-generated chapter 16 for malik
% Hadiths in this chapter: 58

\hadithdefcmd{malik}{520}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غُسِّلَ فِي قَمِيصٍ ‏.‏\hadithno{520}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Jafar ibn Muhammad from his father that the Messenger of Allah, may Allah bless him and grant him peace, was washed in a long shirt}}
\hadithdefcmd{malik}{521}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَيُّوبَ بْنِ أَبِي تَمِيمَةَ السَّخْتِيَانِيِّ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ الأَنْصَارِيَّةِ، قَالَتْ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ تُوُفِّيَتِ ابْنَتُهُ فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكَ إِنْ رَأَيْتُنَّ ذَلِكَ بِمَاءٍ وَسِدْرٍ وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏ ‏.‏ قَالَتْ فَلَمَّا فَرَغْنَا آذَنَّاهُ فَأَعْطَانَا حِقْوَهُ فَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏ ‏.‏ تَعْنِي بِحِقْوِهِ إِزَارَهُ ‏.‏\hadithno{521}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ayyub ibn Abi Tamima as- Sakhtayani from Muhammad ibn Sirin that Umm Atiyya al-Ansariyya said, "The Messenger of Allah, may Allah bless him and grant him peace, came to us when his daughter died and said, 'Wash her three times, or five, or more than that if you think it necessary, with water and lotus leaves, and at the end put on some camphor, or a little camphor, and when you have finished let me know.' When we finished we told him, and he gave us his waist-wrapper and said, 'Shroud her with this}}
\hadithdefcmd{malik}{522}{\hadithno{522}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{}}
\hadithdefcmd{malik}{523}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كُفِّنَ فِي ثَلاَثَةِ أَثْوَابٍ بِيضٍ سَحُولِيَّةٍ لَيْسَ فِيهَا قَمِيصٌ وَلاَ عِمَامَةٌ ‏.‏\hadithno{523}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{}}
\hadithdefcmd{malik}{524}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كُفِّنَ فِي ثَلاَثَةِ أَثْوَابٍ بِيضٍ سَحُولِيَّةٍ ‏.‏\hadithno{524}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Hadith Translation Not Available}}
\hadithdefcmd{malik}{525}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ بَلَغَنِي أَنَّ أَبَا بَكْرٍ الصِّدِّيقَ، قَالَ لِعَائِشَةَ وَهُوَ مَرِيضٌ فِي كَمْ كُفِّنَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَتْ فِي ثَلاَثَةِ أَثْوَابٍ بِيضٍ سَحُولِيَّةٍ ‏.‏ فَقَالَ أَبُو بَكْرٍ خُذُوا هَذَا الثَّوْبَ - لِثَوْبٍ عَلَيْهِ قَدْ أَصَابَهُ مِشْقٌ أَوْ زَعْفَرَانٌ - فَاغْسِلُوهُ ثُمَّ كَفِّنُونِي فِيهِ مَعَ ثَوْبَيْنِ آخَرَيْنِ ‏.‏ فَقَالَتْ عَائِشَةُ وَمَا هَذَا فَقَالَ أَبُو بَكْرٍ الْحَىُّ أَحْوَجُ إِلَى الْجَدِيدِ مِنَ الْمَيِّتِ وَإِنَّمَا هَذَا لِلْمُهْلَةِ ‏.‏\hadithno{525}\hadithgrade{Salim al-Hilali: Mauquf Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said that he had heard that when Abu Bakr as-Siddiq was ill he asked A'isha, "How many shrouds did the Messenger of Allah, may Allah bless him and grant him peace, have?" and she replied, "Three pure white cotton garments." Abu Bakr said, "Take this garment (a garment he was wearing on which red clay or saffron had fallen) and wash it. Then shroud me in it with two other garments." A'isha said, "Why's that?", and Abu Bakr replied, "The living have greater need of the new than the dead. This is only for the body fluids that come out as the body decays}}
\hadithdefcmd{malik}{526}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّهُ قَالَ الْمَيِّتُ يُقَمَّصُ وَيُؤَزَّرُ وَيُلَفُّ فِي الثَّوْبِ الثَّالِثِ فَإِنْ لَمْ يَكُنْ إِلاَّ ثَوْبٌ وَاحِدٌ كُفِّنَ فِيهِ ‏.‏\hadithno{526}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Humayd ibn Abdar-Rahman ibn Awf that Abdullah ibn Amr ibn al-As said, "A dead man is clothed in a shirt and a waist-wrapper and then wrapped in a third, and if he only has one garment he is shrouded in that}}
\hadithdefcmd{malik}{527}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ كَانُوا يَمْشُونَ أَمَامَ الْجَنَازَةِ وَالْخُلَفَاءُ هَلُمَّ جَرًّا وَعَبْدُ اللَّهِ بْنُ عُمَرَ ‏.‏\hadithno{527}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that the Messenger of Allah, may Allah bless him and grant him peace, and Abu Bakr and Umar as well as the khalifas up until this time and Abdullah ibn Umar, would walk in front of the bier}}
\hadithdefcmd{malik}{528}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ رِبِيعَةَ بْنِ عَبْدِ اللَّهِ بْنِ الْهَدِيرِ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، رَأَى عُمَرَ بْنَ الْخَطَّابِ يَقْدُمُ النَّاسَ أَمَامَ الْجَنَازَةِ فِي جَنَازَةِ زَيْنَبَ بِنْتِ جَحْشٍ ‏.‏\hadithno{528}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Muhammad ibn alMunkadir that Rabia ibn Abdullah ibn alHadir told him that he had seen Umar ibn al-Khattab leading people in front of the bier at the funeral of Zaynab bint Jahsh}}
\hadithdefcmd{malik}{529}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، قَالَ مَا رَأَيْتُ أَبِي قَطُّ فِي جَنَازَةٍ إِلاَّ أَمَامَهَا - قَالَ - ثُمَّ يَأْتِي الْبَقِيعَ فَيَجْلِسُ حَتَّى يَمُرُّوا عَلَيْهِ ‏.‏\hadithno{529}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Hisham ibn Urwa said, "I only ever saw my father in front of a funeral procession." He added, "Then he would come to al-Baqi and sit down until the procession passed him}}
\hadithdefcmd{malik}{530}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ الْمَشْىُ خَلْفَ الْجَنَازَةِ مِنْ خَطَإِ السُّنَّةِ ‏.‏\hadithno{530}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Ibn Shihab said, "Walking behind the bier is in contradiction to the sunna}}
\hadithdefcmd{malik}{531}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّهَا قَالَتْ لأَهْلِهَا أَجْمِرُوا ثِيَابِي إِذَا مِتُّ ثُمَّ حَنِّطُونِي وَلاَ تَذُرُّوا عَلَى كَفَنِي حِنَاطًا وَلاَ تَتْبَعُونِي بِنَارٍ ‏.‏\hadithno{531}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that Asma bint Abi Bakr said to her family, "Perfume my clothes with incense when I die and then embalm me. Do not put any of the embalming substance on my shroud, and do not follow me with a burning torch}}
\hadithdefcmd{malik}{532}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ نَهَى أَنْ يُتْبَعَ، بَعْدَ مَوْتِهِ بِنَارٍ ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَكْرَهُ ذَلِكَ ‏.‏\hadithno{532}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Said ibn Abi Said al-Maqburi that Abu Hurayra forbade anyone to follow him with a burning torch after his death. Yahya said, "I heard Malik disapprove of that}}
\hadithdefcmd{malik}{533}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَعَى النَّجَاشِيَّ لِلنَّاسِ فِي الْيَوْمِ الَّذِي مَاتَ فِيهِ وَخَرَجَ بِهِمْ إِلَى الْمُصَلَّى فَصَفَّ بِهِمْ وَكَبَّرَ أَرْبَعَ تَكْبِيرَاتٍ ‏.‏\hadithno{533}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Said ibn al- Musayyab from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, announced the death of an Najashi to everyone on the day that he died, and went out with them to the place of prayer, and then formed them into rows and said "Allah is greater" four times}}
\hadithdefcmd{malik}{534}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، أَنَّهُ أَخْبَرَهُ أَنَّ مِسْكِينَةً مَرِضَتْ فَأُخْبِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم - بِمَرَضِهَا وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُ الْمَسَاكِينَ وَيَسْأَلُ عَنْهُمْ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا مَاتَتْ فَآذِنُونِي بِهَا ‏"‏ ‏.‏ فَخُرِجَ بِجَنَازَتِهَا لَيْلاً فَكَرِهُوا أَنْ يُوقِظُوا رَسُولَ اللَّهِ صلى الله عليه وسلم فَلَمَّا أَصْبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم أُخْبِرَ بِالَّذِي كَانَ مِنْ شَأْنِهَا فَقَالَ ‏"‏ أَلَمْ آمُرْكُمْ أَنْ تُؤْذِنُونِي بِهَا ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ كَرِهْنَا أَنْ نُخْرِجَكَ لَيْلاً وَنُوقِظَكَ ‏.‏ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى صَفَّ بِالنَّاسِ عَلَى قَبْرِهَا وَكَبَّرَ أَرْبَعَ تَكْبِيرَاتٍ ‏.‏\hadithno{534}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Abu Umama ibn Sahl ibn Hunayf told him that once a poor woman fell ill and the Messenger of Allah, may Allah bless him and grant him peace, was told of her illness, and the Messenger of Allah, may Allah bless him and grant him peace, used to visit poor people frequently and ask after them. The Messenger of Allah, may Allah bless him and grant him peace, said, "Let me know if she dies." Her bier was brought out at night- time and they did not want to wake up the Messenger of Allah, may Allah bless him and grant him peace. In the morning the Messenger of Allah, may Allah bless him and grant him peace, was told what had happened to her and he said, "Didn't I tell you to let me know if she died?" They replied, "Messenger of Allah, we did not want to wake you up and make you come out in the night." Then the Messenger of Allah, may Allah bless him and grant him peace, went out and formed everyone into rows by her grave and said "Allah is greater" four times}}
\hadithdefcmd{malik}{535}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَأَلَ ابْنَ شِهَابٍ عَنِ الرَّجُلِ، يُدْرِكُ بَعْضَ التَّكْبِيرِ عَلَى الْجَنَازَةِ وَيَفُوتُهُ بَعْضُهُ فَقَالَ يَقْضِي مَا فَاتَهُ مِنْ ذَلِكَ ‏.‏\hadithno{535}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me that Malik asked Ibn Shihab about a man who caught some of the takbirs said over the corpse and missed the rest, and Ibn Shihab said, "He completes what he has missed}}
\hadithdefcmd{malik}{536}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، أَنَّهُ سَأَلَ أَبَا هُرَيْرَةَ كَيْفَ تُصَلِّي عَلَى الْجَنَازَةِ فَقَالَ أَبُو هُرَيْرَةَ أَنَا لَعَمْرُ اللَّهِ، أُخْبِرُكَ أَتَّبِعُهَا، مِنْ أَهْلِهَا فَإِذَا وُضِعَتْ كَبَّرْتُ وَحَمِدْتُ اللَّهَ وَصَلَّيْتُ عَلَى نَبِيِّهِ ثُمَّ أَقُولُ اللَّهُمَّ إِنَّهُ عَبْدُكَ وَابْنُ عَبْدِكَ وَابْنُ أَمَتِكَ كَانَ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ أَنْتَ وَأَنَّ مُحَمَّدًا عَبْدُكَ وَرَسُولُكَ وَأَنْتَ أَعْلَمُ بِهِ اللَّهُمَّ إِنْ كَانَ مُحْسِنًا فَزِدْ فِي إِحْسَانِهِ وَإِنْ كَانَ مُسِيئًا فَتَجَاوَزْ عَنْ سَيِّئَاتِهِ اللَّهُمَّ لاَ تَحْرِمْنَا أَجْرَهُ وَلاَ تَفْتِنَّا بَعْدَهُ ‏.‏\hadithno{536}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Said ibn Abi Said al-Maqburi from his father that he had asked Abu Hurayra, "How do you pray over the dead?" and Abu Hurayra replied, "By the Life of Allah, I will tell you! I follow with the family and when the corpse is put down I say 'Allah is greater' and praise Allah and ask for blessings on His Prophet. Then I say, 'O Allah, he is Your slave and the son of Your male slave and Your female slave. He used to testify that there is no god but You and that Muhammad is Your slave and Your Messenger, and You know that best. O Allah, if he acted well, then increase for him his good action, and if he acted wrongly, then overlook his wrong actions. O Allah, do not deprive us of his reward, and do not try us after him.'" Allahumma inna huwa abduka wa'bnu abdika wa'bnu amatika. Kana yash-hadu an la ilaha illa ant wa anna Muhammadan abduka wa rasooluka, wa anta alamu bihi. Allahumma in kana muhsinan zid fi ihsanihi, wa in kana musiyan fa tajawaz an sayatihi. Allahumma la tahrimna ajrahu wa lataftina badahu}}
\hadithdefcmd{malik}{537}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ صَلَّيْتُ وَرَاءَ أَبِي هُرَيْرَةَ عَلَى صَبِيٍّ لَمْ يَعْمَلْ خَطِيئَةً قَطُّ فَسَمِعْتُهُ يَقُولُ اللَّهُمَّ أَعِذْهُ مِنْ عَذَابِ الْقَبْرِ ‏.‏\hadithno{537}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said that he heard Said ibn al-Musayyab say, "I once prayed behind Abu Hurayra over a child who had never done a wrong action and I heard him say, 'O Allah, give him protection from the torment of the grave}}
\hadithdefcmd{malik}{538}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ لاَ يَقْرَأُ فِي الصَّلاَةِ عَلَى الْجَنَازَةِ ‏.‏\hadithno{538}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used not to recite when praying over a dead person}}
\hadithdefcmd{malik}{539}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ أَبِي حَرْمَلَةَ، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ أَبِي سُفْيَانَ بْنِ حُوَيْطِبٍ أَنَّ زَيْنَبَ بِنْتَ أَبِي سَلَمَةَ، تُوُفِّيَتْ - وَطَارِقٌ أَمِيرُ الْمَدِينَةِ - فَأُتِيَ بِجَنَازَتِهَا بَعْدَ صَلاَةِ الصُّبْحِ فَوُضِعَتْ بِالْبَقِيعِ ‏.‏ قَالَ وَكَانَ طَارِقٌ يُغَلِّسُ بِالصُّبْحِ ‏.‏ قَالَ ابْنُ أَبِي حَرْمَلَةَ فَسَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ يَقُولُ لأَهْلِهَا إِمَّا أَنْ تُصَلُّوا عَلَى جَنَازَتِكُمُ الآنَ وَإِمَّا أَنْ تَتْرُكُوهَا حَتَّى تَرْتَفِعَ الشَّمْسُ ‏.‏\hadithno{539}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Muhammad ibn Abi Harmala, the mawla of Abd ar-Rahman ibn Abi Sufyan ibn Huwaytib, that Zaynab bint Abi Salama died during the time that Tariq was amir of Madina and her bier was brought out after subh and put in al-Baqi. He said that Tariq used to pray subh right at the beginning of its time. He added, "I heard Abdullah ibn Umar say to the family, 'You can either pray over your dead now or you can wait until the sun comes up}}
\hadithdefcmd{malik}{540}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ يُصَلَّى عَلَى الْجَنَازَةِ بَعْدَ الْعَصْرِ وَبَعْدَ الصُّبْحِ إِذَا صُلِّيَتَا لِوَقْتِهِمَا ‏.‏\hadithno{540}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "The prayer for a dead person can be done after asr and subh if these have been prayed at their times}}
\hadithdefcmd{malik}{541}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا أَمَرَتْ أَنْ يُمَرَّ عَلَيْهَا بِسَعْدِ بْنِ أَبِي وَقَّاصٍ فِي الْمَسْجِدِ حِينَ مَاتَ لِتَدْعُوَ لَهُ فَأَنْكَرَ ذَلِكَ النَّاسُ عَلَيْهَا فَقَالَتْ عَائِشَةُ مَا أَسْرَعَ النَّاسَ مَا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى سُهَيْلِ ابْنِ بَيْضَاءَ إِلاَّ فِي الْمَسْجِدِ ‏.‏\hadithno{541}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'n Nadr, the mawla of Umar ibn Ubaydullah that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, ordered that the body of Sad ibn Abi Waqqas be brought past her in the mosque so that she could make dua for him. Some people disapproved of her doing that, and she said, "How hasty people are! The Messenger of Allah, may Allah bless him and grant him peace, only prayed over Suhayl ibn Bayda in the mosque}}
\hadithdefcmd{malik}{542}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ صُلِّيَ عَلَى عُمَرَ بْنِ الْخَطَّابِ فِي الْمَسْجِدِ ‏.‏\hadithno{542}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "The prayer over Umar ibn al-Khattab was done in the mosque}}
\hadithdefcmd{malik}{543}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُثْمَانَ بْنَ عَفَّانَ، وَعَبْدَ اللَّهِ بْنَ عُمَرَ، وَأَبَا، هُرَيْرَةَ كَانُوا يُصَلُّونَ عَلَى الْجَنَائِزِ بِالْمَدِينَةِ الرِّجَالِ وَالنِّسَاءِ فَيَجْعَلُونَ الرِّجَالَ مِمَّا يَلِي الإِمَامَ وَالنِّسَاءَ مِمَّا يَلِي الْقِبْلَةَ ‏.‏\hadithno{543}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Uthman ibn Affan and Abdullah ibn Umar and Abu Hurayra used to pray over the dead, both men and women, in Madina. They would put the men nearer to the imam and the women nearer to the qibla}}
\hadithdefcmd{malik}{544}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا صَلَّى عَلَى الْجَنَائِزِ يُسَلِّمُ حَتَّى يُسْمِعَ مَنْ يَلِيهِ ‏.‏\hadithno{544}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar, when he prayed over the dead, would say, "Peace be upon you" loud enough for whoever was near to him to hear}}
\hadithdefcmd{malik}{545}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ لاَ يُصَلِّي الرَّجُلُ عَلَى الْجَنَازَةِ إِلاَّ وَهُوَ طَاهِرٌ ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ لَمْ أَرَ أَحَدًا مِنْ أَهْلِ الْعِلْمِ يَكْرَهُ أَنْ يُصَلَّى عَلَى وَلَدِ الزِّنَا وَأُمِّهِ ‏.‏\hadithno{545}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "No-one should pray over a dead person unless he is in wudu." Yahya said that he heard Malik say, "I have not seen any person of knowledge disapproving of praying over either a child born of adultery or its mother}}
\hadithdefcmd{malik}{546}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تُوُفِّيَ يَوْمَ الاِثْنَيْنِ وَدُفِنَ يَوْمَ الثُّلاَثَاءِ وَصَلَّى النَّاسُ عَلَيْهِ أَفْذَاذًا لاَ يَؤُمُّهُمْ أَحَدٌ ‏.‏ فَقَالَ نَاسٌ يُدْفَنُ عِنْدَ الْمِنْبَرِ ‏.‏ وَقَالَ آخَرُونَ يُدْفَنُ بِالْبَقِيعِ ‏.‏ فَجَاءَ أَبُو بَكْرٍ الصِّدِّيقُ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا دُفِنَ نَبِيٌّ قَطُّ إِلاَّ فِي مَكَانِهِ الَّذِي تُوُفِّيَ فِيهِ ‏"‏ ‏.‏ فَحُفِرَ لَهُ فِيهِ فَلَمَّا كَانَ عِنْدَ غُسْلِهِ أَرَادُوا نَزْعَ قَمِيصِهِ فَسَمِعُوا صَوْتًا يَقُولُ لاَ تَنْزِعُوا الْقَمِيصَ فَلَمْ يُنْزَعِ الْقَمِيصُ وَغُسِّلَ وَهُوَ عَلَيْهِ صلى الله عليه وسلم ‏.‏\hadithno{546}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, died on Monday and was buried on Tuesday and people prayed over him individually with no one leading them. Some people said that he would be buried near the mimbar, and others said that he would be buried in al-Baqi. Abu Bakr as-Siddiq came and said, "I heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'No prophet was ever buried except in the place where he died.' "So a grave was dug for him there. When he was about to be washed they wished to take off his shirt but they heard a voice saying "Don't take off his shirt," so they did not take off his shirt and he was washed with it on, may Allah bless him and grant him peace}}
\hadithdefcmd{malik}{547}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ كَانَ بِالْمَدِينَةِ رَجُلاَنِ أَحَدُهُمَا يَلْحَدُ وَالآخَرُ لاَ يَلْحَدُ فَقَالُوا أَيُّهُمَا جَاءَ أَوَّلُ عَمِلَ عَمَلَهُ ‏.‏ فَجَاءَ الَّذِي يَلْحَدُ فَلَحَدَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{547}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said, "There were two men in Madina, one of whom dug graves with a niche in the side wall for the body, and the other who did not, and they said, 'Whichever one comes first can do the job,' and the one who dug graves with a niche came first and dug the Messenger of Allah's grave, may Allah bless him and grant him peace}}
\hadithdefcmd{malik}{548}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ أُمَّ سَلَمَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَانَتْ تَقُولُ مَا صَدَّقْتُ بِمَوْتِ النَّبِيِّ صلى الله عليه وسلم حَتَّى سَمِعْتُ وَقْعَ الْكَرَازِينِ ‏.‏\hadithno{548}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, used to say, "I did not believe that the Messenger of Allah, may Allah bless him and grant him peace, had died until I heard the pickaxes fall}}
\hadithdefcmd{malik}{549}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ رَأَيْتُ ثَلاَثَةَ أَقْمَارٍ سَقَطْنَ فِي حُجْرَتِي فَقَصَصْتُ رُؤْيَاىَ عَلَى أَبِي بَكْرٍ الصِّدِّيقِ قَالَتْ فَلَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَدُفِنَ فِي بَيْتِهَا قَالَ لَهَا أَبُو بَكْرٍ هَذَا أَحَدُ أَقْمَارِكِ وَهُوَ خَيْرُهَا ‏.‏\hadithno{549}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "I saw three moons fall into my room, and I related my vision to Abu Bakr as-Siddiq. Then, when the Messenger of Allah died, may Allah bless him and grant him peace, and was buried in my house, Abu Bakr said to me, 'This is one of your moons, and he is the best of them}}
\hadithdefcmd{malik}{550}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ غَيْرِ، وَاحِدٍ، مِمَّنْ يَثِقُ بِهِ أَنَّ سَعْدَ بْنَ أَبِي وَقَّاصٍ وَسَعِيدَ بْنَ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ تُوُفِّيَا بِالْعَقِيقِ وَحُمِلاَ إِلَى الْمَدِينَةِ وَدُفِنَا بِهَا ‏.‏\hadithno{550}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from more than one reliable source that Sad ibn Abi Waqqas and Said ibn Zayd ibn Amr ibn Nufayl died at al-Aqiq and were carried to Madina and buried there}}
\hadithdefcmd{malik}{551}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ مَا أُحِبُّ أَنْ أُدْفَنَ، بِالْبَقِيعِ لأَنْ أُدْفَنَ بِغَيْرِهِ أَحَبُّ إِلَىَّ مِنْ أَنْ أُدْفَنَ بِهِ إِنَّمَا هُوَ أَحَدُ رَجُلَيْنِ إِمَّا ظَالِمٌ فَلاَ أُحِبُّ أَنْ أُدْفَنَ مَعَهُ وَإِمَّا صَالِحٌ فَلاَ أُحِبُّ أَنْ تُنْبَشَ لِي عِظَامُهُ ‏.‏\hadithno{551}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said, "I would not want to be buried in al-Baqi. I would prefer to be buried elsewhere. The one who is buried in al-Baqi is one of two people. Either he is unjust (dhalim), and I would not like to be buried with him, or he is salih, and I would not like his bones to be disturbed for me}}
\hadithdefcmd{malik}{552}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ وَاقِدِ بْنِ عَمْرِو بْنِ سَعْدِ بْنِ مُعَاذٍ، عَنْ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ مَسْعُودِ بْنِ الْحَكَمِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُومُ فِي الْجَنَائِزِ ثُمَّ جَلَسَ بَعْدُ ‏.‏\hadithno{552}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Wafid ibn Amr ibn Said ibn Muadh from Nafi ibn Jubayr ibn Mutim from Masud ibn al-Hakam from AIi ibn Abi Talib that the Messenger of Allah, may Allah bless him and grant him peace, used to stand up when a funeral procession passed by, and then sit down again afterwards}}
\hadithdefcmd{malik}{553}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ، كَانَ يَتَوَسَّدُ الْقُبُورَ وَيَضْطَجِعُ عَلَيْهَا ‏.‏ قَالَ مَالِكٌ وَإِنَّمَا نُهِيَ عَنِ الْقُعُودِ عَلَى الْقُبُورِ فِيمَا نُرَى لِلْمَذَاهِبِ ‏.‏\hadithno{553}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{ahya related to me from Malik that he had heard that AIi ibn Abi Talib used to rest his head on graves and lie on them. Malik said, "As far as we can see ,it is only forbidden to sit on graves to relieve oneself}}
\hadithdefcmd{malik}{554}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي بَكْرِ بْنِ عُثْمَانَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، أَنَّهُ سَمِعَ أَبَا أُمَامَةَ بْنَ سَهْلِ بْنِ حُنَيْفٍ، يَقُولُ كُنَّا نَشْهَدُ الْجَنَائِزَ فَمَا يَجْلِسُ آخِرُ النَّاسِ حَتَّى يُؤْذَنُوا ‏.‏\hadithno{554}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu Bakr ibn Uthman ibn Sahl ibn Hunayf that he had heard Abu Umama ibn Sahl ibn Hunayf say, "We used to attend funeral processions, and the last of the people would not sit until they had been given permission}}
\hadithdefcmd{malik}{555}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ جَابِرِ بْنِ عَتِيكٍ، عَنْ عَتِيكِ بْنِ الْحَارِثِ، - وَهُوَ جَدُّ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ جَابِرٍ أَبُو أُمِّهِ - أَنَّهُ أَخْبَرَهُ أَنَّ جَابِرَ بْنَ عَتِيكٍ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَاءَ يَعُودُ عَبْدَ اللَّهِ بْنَ ثَابِتٍ فَوَجَدَهُ قَدْ غُلِبَ عَلَيْهِ فَصَاحَ بِهِ فَلَمْ يُجِبْهُ فَاسْتَرْجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ غُلِبْنَا عَلَيْكَ يَا أَبَا الرَّبِيعِ ‏"‏ ‏.‏ فَصَاحَ النِّسْوَةُ وَبَكَيْنَ فَجَعَلَ جَابِرٌ يُسَكِّتُهُنَّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ دَعْهُنَّ فَإِذَا وَجَبَ فَلاَ تَبْكِيَنَّ بَاكِيَةٌ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَا الْوُجُوبُ قَالَ ‏"‏ إِذَا مَاتَ ‏"‏ ‏.‏ فَقَالَتِ ابْنَتُهُ وَاللَّهِ إِنْ كُنْتُ لأَرْجُو أَنْ تَكُونَ شَهِيدًا فَإِنَّكَ كُنْتَ قَدْ قَضَيْتَ جِهَازَكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ قَدْ أَوْقَعَ أَجْرَهُ عَلَى قَدْرِ نِيَّتِهِ وَمَا تَعُدُّونَ الشَّهَادَةَ ‏"‏ ‏.‏ قَالُوا الْقَتْلُ فِي سَبِيلِ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الشُّهَدَاءُ سَبْعَةٌ سِوَى الْقَتْلِ فِي سَبِيلِ اللَّهِ الْمَطْعُونُ شَهِيدٌ وَالْغَرِقُ شَهِيدٌ وَصَاحِبُ ذَاتِ الْجَنْبِ شَهِيدٌ وَالْمَبْطُونُ شَهِيدٌ وَالْحَرِقُ شَهِيدٌ وَالَّذِي يَمُوتُ تَحْتَ الْهَدْمِ شَهِيدٌ وَالْمَرْأَةُ تَمُوتُ بِجُمْعٍ شَهِيدٌ ‏"‏ ‏.‏\hadithno{555}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abdullah ibn Jabir ibn Atik that Atik ibn al-Harith, the grandfather of Abdullah ibn Abdullah ibn Jabir on his mother's side, told him that Jabir ibn Atik had told him that the Messenger of Allah, may Allah bless him and grant him peace, came to visit Abdullah ibn Thabit and found him in his death-throes. He called to him but he did not reply. The Messenger of Allah, may Allah bless him and grant him peace, said, "We belong to Allah, and to Him we are returning," and added, "You are being taken from us, Abur-Rabi`." The women cried out and wept, and Jabir began to silence them. The Messenger of Allah, may Allah bless him and grant him peace, said, "Leave them, and when the necessary time comes, none of the women should cry." They said, "Messenger of Allah, what is the necessary time?" and he replied, "When he dies." The dying man's daughter said, "By Allah, I hope that you will be a martyr, for you have completed your preparations for battle," and the Messenger of Allah, may Allah bless him and grant him peace, said, "Allah has made his reward fall according to his intention. What do you consider dying a martyr to be?" They said, "Death in the way of Allah." The Messenger of Allah, may Allah bless him and grant him peace, said, "There are seven kinds of martyr other than those killed in the way of Allah. Someone who is killed by the plague is a martyr, someone who drowns is a martyr, someone who dies of pleurisy is a martyr, someone who dies of a disease of the belly is a martyr, someone who dies by fire is a martyr, someone who dies under a falling building is a martyr and a woman who dies in childbirth is a martyr}}
\hadithdefcmd{malik}{556}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّهَا أَخْبَرَتْهُ أَنَّهَا، سَمِعَتْ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ، تَقُولُ وَذُكِرَ لَهَا أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ يَقُولُ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبُكَاءِ الْحَىِّ ‏.‏ فَقَالَتْ عَائِشَةُ يَغْفِرُ اللَّهُ لأَبِي عَبْدِ الرَّحْمَنِ أَمَا إِنَّهُ لَمْ يَكْذِبْ وَلَكِنَّهُ نَسِيَ أَوْ أَخْطَأَ إِنَّمَا مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَهُودِيَّةٍ يَبْكِي عَلَيْهَا أَهْلُهَا فَقَالَ ‏ "‏ إِنَّكُمْ لَتَبْكُونَ عَلَيْهَا وَإِنَّهَا لَتُعَذَّبُ فِي قَبْرِهَا ‏"‏ ‏.‏\hadithno{556}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr from his father that Amra bint Abd ar-Rahman told him that she had heard A'isha, the umm al-muminin, say (when it was mentioned to her that Abdullah ibn Umar used to say, "The dead are tormented by the weeping of the living"), "May Allah forgive Abu Abd ar-Rahman. Of course he has not lied, but he has forgotten, or made a mistake. The Messenger of Allah, may Allah bless him and grant him peace, passed by a jewish woman whose family were crying over her and he said, 'You are crying over her, and she is being tormented in her grave}}
\hadithdefcmd{malik}{557}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمُوتُ لأَحَدٍ مِنَ الْمُسْلِمِينَ ثَلاَثَةٌ مِنَ الْوَلَدِ فَتَمَسَّهُ النَّارُ إِلاَّ تَحِلَّةَ الْقَسَمِ ‏"‏ ‏.‏\hadithno{557}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Said ibn al- Musayyab from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "No muslim who has three children die will be touched by the Fire except to fulfil Allah's oath}}
\hadithdefcmd{malik}{558}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ أَبِي بَكْرِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ أَبِيهِ، عَنْ أَبِي النَّضْرِ السَّلَمِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَمُوتُ لأَحَدٍ مِنَ الْمُسْلِمِينَ ثَلاَثَةٌ مِنَ الْوَلَدِ فَيَحْتَسِبُهُمْ إِلاَّ كَانُوا جُنَّةً مِنَ النَّارِ ‏"‏ ‏.‏ فَقَالَتِ امْرَأَةٌ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ أَوِ اثْنَانِ قَالَ ‏"‏ أَوِ اثْنَانِ ‏"‏ ‏.‏\hadithno{558}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Muhammad ibn Abi Bakr ibn Amr ibn Hazm from his father from Abu'n-Nadr as-Salami that the Messenger of Allah, may Allah bless him and grant him peace, said, "If three of a muslim's children die, and he remains content with that, they will be a protection for him from the Fire." A woman who was with the Messenger of Allah, may Allah bless him and grant him peace, said, "Or two, Messengerof Allah?", and he said, "Or two}}
\hadithdefcmd{malik}{559}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ أَبِي الْحُبَابِ، سَعِيدِ بْنِ يَسَارٍ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا يَزَالُ الْمُؤْمِنُ يُصَابُ فِي وَلَدِهِ وَحَامَّتِهِ حَتَّى يَلْقَى اللَّهَ وَلَيْسَتْ لَهُ خَطِيئَةٌ ‏"‏ ‏.‏\hadithno{559}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he had heard from Abu'l-Hubab Said ibn Yasar from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "The mumin continues to be struck by misfortune in his children and close friends until he meets Allah with no wrong actions}}
\hadithdefcmd{malik}{560}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ بْنِ مُحَمَّدِ بْنِ أَبِي بَكْرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لِيُعَزِّ الْمُسْلِمِينَ فِي مَصَائِبِهِمُ الْمُصِيبَةُ بِي ‏"‏ ‏.‏\hadithno{560}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim ibn Muhammad ibn Abi Bakr that the Messenger of Allah, may Allah bless him and grant him peace, said, "Let the misfortune that befalls me be a comfort to the Muslims in their misfortunes}}
\hadithdefcmd{malik}{561}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ، أَنَّ رَسُولَ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ قَالَ مَنْ أَصَابَتْهُ مُصِيبَةٌ فَقَالَ كَمَا أَمَرَ اللَّهُ (إِنَّا لِلَّهِ وَإِنَّا إِلَيْهِ رَاجِعُونَ) اللَّهُمَّ أْجُرْنِي فِي مُصِيبَتِي وَأَعْقِبْنِي خَيْرًا مِنْهَا إِلَّا فَعَلَ اللَّهُ ذَلِكَ بِهِ قَالَتْ أُمُّ سَلَمَةَ فَلَمَّا تُوُفِّيَ أَبُو سَلَمَةَ قُلْتُ ذَلِكَ ثُمَّ قُلْتُ وَمَنْ خَيْرٌ مِنْ أَبِي سَلَمَةَ فَأَعْقَبَهَا اللَّهُ رَسُولَهُ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ فَتَزَوَّجَهَا\hadithno{561}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Rabia ibn Abi Abd ar-Rahman from Umm Salama, the wife of the Prophet may Allah bless him and grant him peace, that the Messenger of Allah, may Allah bless him and grant him peace, said, "If a misfortune befalls some one and he says, as Allah has ordered, 'We belong to Allah and to Him we are returning. O Allah, reward me in my misfortune and give me better than it afterwards,' Allah will do that for him" (Inna lillahi wa inna ilayhi rajiun. Allahumma' jurniy fi musiybatiy, wa a qibhiy khayran minha, illa faala 'llahu dhalika bihi.). Umm Salama said, "When Abu Salama died I said that, and then I said, 'Who is better than Abu Salama?' " And then Allah left her the Messenger of Allah, may Allah bless him and grant him peace, and he married her}}
\hadithdefcmd{malik}{562}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، أَنَّهُ قَالَ هَلَكَتِ امْرَأَةٌ لِي فَأَتَانِي مُحَمَّدُ بْنُ كَعْبٍ الْقُرَظِيُّ يُعَزِّينِي بِهَا فَقَالَ إِنَّهُ كَانَ فِي بَنِي إِسْرَائِيلَ رَجُلٌ فَقِيهٌ عَالِمٌ عَابِدٌ مُجْتَهِدٌ وَكَانَتْ لَهُ امْرَأَةٌ - وَكَانَ بِهَا مُعْجَبًا وَلَهَا مُحِبًّا - فَمَاتَتْ فَوَجَدَ عَلَيْهَا وَجْدًا شَدِيدًا وَلَقِيَ عَلَيْهَا أَسَفًا حَتَّى خَلاَ فِي بَيْتٍ وَغَلَّقَ عَلَى نَفْسِهِ وَاحْتَجَبَ مِنَ النَّاسِ فَلَمْ يَكُنْ يَدْخُلُ عَلَيْهِ أَحَدٌ وَإِنَّ امْرَأَةً سَمِعَتْ بِهِ فَجَاءَتْهُ فَقَالَتْ إِنَّ لِي إِلَيْهِ حَاجَةً أَسْتَفْتِيهِ فِيهَا لَيْسَ يُجْزِينِي فِيهَا إِلاَّ مُشَافَهَتُهُ فَذَهَبَ النَّاسُ وَلَزِمَتْ بَابَهُ وَقَالَتْ مَا لِي مِنْهُ بُدٌّ ‏.‏ فَقَالَ لَهُ قَائِلٌ إِنَّ هَا هُنَا امْرَأَةً أَرَادَتْ أَنْ تَسْتَفْتِيَكَ وَقَالَتْ إِنْ أَرَدْتُ إِلاَّ مُشَافَهَتَهُ وَقَدْ ذَهَبَ النَّاسُ وَهِيَ لاَ تُفَارِقُ الْبَابَ ‏.‏ فَقَالَ ائْذَنُوا لَهَا ‏.‏ فَدَخَلَتْ عَلَيْهِ فَقَالَتْ إِنِّي جِئْتُكَ أَسْتَفْتِيكَ فِي أَمْرٍ ‏.‏ قَالَ وَمَا هُوَ قَالَتْ إِنِّي اسْتَعَرْتُ مِنْ جَارَةٍ لِي حَلْيًا فَكُنْتُ أَلْبَسُهُ وَأُعِيرُهُ زَمَانًا ثُمَّ إِنَّهُمْ أَرْسَلُوا إِلَىَّ فِيهِ أَفَأُؤَدِّيهِ إِلَيْهِمْ فَقَالَ نَعَمْ وَاللَّهِ ‏.‏ فَقَالَتْ إِنَّهُ قَدْ مَكَثَ عِنْدِي زَمَانًا ‏.‏ فَقَالَ ذَلِكَ أَحَقُّ لِرَدِّكِ إِيَّاهُ إِلَيْهِمْ حِينَ أَعَارُوكِيهِ زَمَانًا ‏.‏ فَقَالَتْ أَىْ يَرْحَمُكَ اللَّهُ أَفَتَأْسَفُ عَلَى مَا أَعَارَكَ اللَّهُ ثُمَّ أَخَذَهُ مِنْكَ وَهُوَ أَحَقُّ بِهِ مِنْكَ فَأَبْصَرَ مَا كَانَ فِيهِ وَنَفَعَهُ اللَّهُ بِقَوْلِهَا ‏.‏\hadithno{562}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that al-Qasim ibn Muhammad said, "One of my wives died and Muhammad ibn Kab al Quradhi came to console me about her. He told me of one among the Bani Israil who was a diligent, worshipping, knowing and understanding man who had a wife that he admired and loved, and she died. He grieved over her intensely and lamented her until he withdrew into a house and locked himself in, hidden from everyone, and no-one visited him. A woman heard about him and went to him, saying, 'I need him to give me an opinion. Nothing will satisfy me except what he says about it.' Everyone went away, but she stuck to his door and said, 'I must see him.' Someone said to him, 'There is a woman who wishes to ask your opinion about something,' and she insisted, 'I will only talk to him about it.' When everyone had gone away, and she still had not left his door, he said, 'Let her in.' So she went in and saw him and said, 'I have come to ask your opinion about something.' He said, 'What is it?' She said, 'I borrowed a piece of jewellery from a neighbour of mine, and I have worn it and used it for a long time. Then they sent to me for it. Should I let them have it back?' He said, 'Yes, by Allah.' She said, 'I have had it for a long time.' He said, 'It is more correct for you to return it to them, since they have lent it to you for such a long time.' She said, 'Yes. May Allah have mercy on you. Do you then grieve over what Allah has lent you and then taken from you, when He has a greater right to it than you?' Then he saw the situation he was in, and Allah helped him by her words}}
\hadithdefcmd{malik}{563}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الرِّجَالِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أُمِّهِ، عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ أَنَّهُ سَمِعَهَا تَقُولُ، لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمُخْتَفِيَ وَالْمُخْتَفِيَةَ يَعْنِي نَبَّاشَ الْقُبُورِ ‏.‏\hadithno{563}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik that Abu'r-Rijal Muhammad ibn Abd ar-Rahman heard his mother Amra bint Abd ar-Rahman say, "The Messenger of Allah, may Allah bless him and grant him peace, cursed both men and women who dug up," meaning those who dug up graves}}
\hadithdefcmd{malik}{564}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَانَتْ تَقُولُ كَسْرُ عَظْمِ الْمُسْلِمِ مَيْتًا كَكَسْرِهِ وَهُوَ حَىٌّ ‏.‏ تَعْنِي فِي الإِثْمِ ‏.‏\hadithno{564}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, used to say, "Breaking the bone of a muslim when he is dead is like breaking it when he is alive." She meant if done in wrong action}}
\hadithdefcmd{malik}{565}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم قَبْلَ أَنْ يَمُوتَ وَهُوَ مُسْتَنِدٌ إِلَى صَدْرِهَا وَأَصْغَتْ إِلَيْهِ يَقُولُ ‏ "‏ اللَّهُمَّ اغْفِرْ لِي وَارْحَمْنِي وَأَلْحِقْنِي بِالرَّفِيقِ الأَعْلَى ‏"‏ ‏.‏\hadithno{565}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from Abbad ibn Abdullah ibn az-Zubayr that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, told him that she had heard the Messenger of Allah, may Allah bless him and grant him peace, say before he died, while he was leaning on her breast and she was listening to him, "O Allah, forgive me and have mercy on me and join me with the highest company}}
\hadithdefcmd{malik}{566}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ نَبِيٍّ يَمُوتُ حَتَّى يُخَيَّرَ ‏"‏ ‏.‏ قَالَتْ فَسَمِعْتُهُ يَقُولُ ‏"‏ اللَّهُمَّ الرَّفِيقَ الأَعْلَى ‏"‏ ‏.‏ فَعَرَفْتُ أَنَّهُ ذَاهِبٌ ‏.‏\hadithno{566}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he heard that A'isha said, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'No prophet dies until he is given the choice.' " She continued, "I heard him say ,'O Allah, the highest company,' and I knew that he was going}}
\hadithdefcmd{malik}{567}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَحَدَكُمْ إِذَا مَاتَ عُرِضَ عَلَيْهِ مَقْعَدُهُ بِالْغَدَاةِ وَالْعَشِيِّ إِنْ كَانَ مِنْ أَهْلِ الْجَنَّةِ فَمِنْ أَهْلِ الْجَنَّةِ وَإِنْ كَانَ مِنْ أَهْلِ النَّارِ فَمِنْ أَهْلِ النَّارِ يُقَالُ لَهُ هَذَا مَقْعَدُكَ حَتَّى يَبْعَثَكَ اللَّهُ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{567}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said that the Messenger of Allah, may Allah bless him and grant him peace, said, "When you die, your place will be shown to you in the morning and the evening. If you are one of the people of the Garden, then you will be with the people of the Garden, and if you are one of the people of the Fire, then you will be with the people of the Fire. You will be told, 'This is your place of waiting until Allah raises you on the day of rising}}
\hadithdefcmd{malik}{568}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ ابْنِ آدَمَ تَأْكُلُهُ الأَرْضُ إِلاَّ عَجْبَ الذَّنَبِ مِنْهُ خُلِقَ وَفِيهِ يُرَكَّبُ ‏"‏ ‏.‏\hadithno{568}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "The earth eats all of the son of Adam except the coccyx. He was created from it, and on it he is built}}
\hadithdefcmd{malik}{569}{وَحَدَّثَنِي عَنْ مَالِك عَنْ ابْنِ شِهَابٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ الْأَنْصَارِيِّ أَنَّهُ أَخْبَرَهُ أَنَّ أَبَاهُ كَعْبَ بْنَ مَالِكٍ كَانَ يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ قَالَ إِنَّمَا نَسَمَةُ الْمُؤْمِنِ طَيْرٌ يَعْلَقُ فِي شَجَرِ الْجَنَّةِ حَتَّى يَرْجِعَهُ اللَّهُ إِلَى جَسَدِهِ يَوْمَ يَبْعَثُهُ\hadithno{569}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Abd ar-Rahman ibn Kab ibn Malik al-Ansari told him that his father, Kab ibn Malik, used to relate that the Messenger of Allah, may Allah bless him and grant him peace, said, "The ruh of the mumin is a bird that sits in the trees of the Garden until Allah returns it to his body on the day He raises him}}
\hadithdefcmd{malik}{570}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ اللَّهُ تَبَارَكَ وَتَعَالَى إِذَا أَحَبَّ عَبْدِي لِقَائِي أَحْبَبْتُ لِقَاءَهُ وَإِذَا كَرِهَ لِقَائِي كَرِهْتُ لِقَاءَهُ ‏"‏ ‏.‏\hadithno{570}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Allah, the Blessed and Exalted, said, 'If My slave longs to meet Me, I long to meet him, and if he is averse to meeting Me, I am averse to meeting him}}
\hadithdefcmd{malik}{571}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ رَجُلٌ لَمْ يَعْمَلْ حَسَنَةً قَطُّ لأَهْلِهِ إِذَا مَاتَ فَحَرِّقُوهُ ثُمَّ اذْرُوا نِصْفَهُ فِي الْبَرِّ وَنِصْفَهُ فِي الْبَحْرِ فَوَاللَّهِ لَئِنْ قَدَرَ اللَّهُ عَلَيْهِ لَيُعَذِّبَنَّهُ عَذَابًا لاَ يُعَذِّبُهُ أَحَدًا مِنَ الْعَالَمِينَ ‏.‏ فَلَمَّا مَاتَ الرَّجُلُ فَعَلُوا مَا أَمَرَهُمْ بِهِ فَأَمَرَ اللَّهُ الْبَرَّ فَجَمَعَ مَا فِيهِ وَأَمَرَ الْبَحْرَ فَجَمَعَ مَا فِيهِ ثُمَّ قَالَ لِمَ فَعَلْتَ هَذَا قَالَ مِنْ خَشْيَتِكَ يَا رَبِّ وَأَنْتَ أَعْلَمُ ‏.‏ قَالَ فَغَفَرَ لَهُ ‏"‏ ‏.‏\hadithno{571}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "A man said to his family that he had never done a good action, and that when he died they were to burn him and then scatter half of him on the land and half of him on the sea, and by Allah, if Allah destined it for him He would punish him with a punishment which He had not punished anyone else with in all the worlds. When the man died, they did as he had told them. Then Allah told the land to collect everything that was in it, and told the sea to collect everything that was in it, and then He said to the man, 'Why did you do this?' and he said, 'From fear of You, Lord, and You know best.' " Abu Hurayra added, "And He forgave him}}
\hadithdefcmd{malik}{572}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنِ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏"‏ كُلُّ مَوْلُودٍ يُولَدُ عَلَى الْفِطْرَةِ فَأَبَوَاهُ يُهَوِّدَانِهِ أَوْ يُنَصِّرَانِهِ، كَمَا تُنَاتَجُ الإِبِلُ مِنْ بَهِيمَةٍ جَمْعَاءَ هَلْ تُحِسُّ فِيهَا مِنْ جَدْعَاءَ ‏"‏ ‏.‏ قَالُوا ‏:‏ يَا رَسُولَ اللَّهِ أَرَأَيْتَ الَّذِي يَمُوتُ وَهُوَ صَغِيرٌ قَالَ ‏:‏ ‏"‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏ ‏.‏\hadithno{572}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Every child is born on the fitra and it is his parents who make him a jew or a christian. Just as a camel is born whole - do you perceive any defect?" They said, "Messenger of Allah, what happens to people who die when they are (very) young?" He said, "Allah knows best what they used to do}}
\hadithdefcmd{malik}{573}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏:‏ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَمُرَّ الرَّجُلُ بِقَبْرِ الرَّجُلِ فَيَقُولُ يَا لَيْتَنِي مَكَانَهُ ‏"‏ ‏.‏\hadithno{573}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "The Hour will not come until a man passes by the grave of another and says, 'If only I were in his place}}
\hadithdefcmd{malik}{574}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَلْحَلَةَ الدِّيلِيِّ، عَنْ مَعْبَدِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِي قَتَادَةَ بْنِ رِبْعِيٍّ، أَنَّهُ كَانَ يُحَدِّثُ ‏:‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مُرَّ عَلَيْهِ بِجَنَازَةٍ فَقَالَ ‏:‏ ‏"‏ مُسْتَرِيحٌ وَمُسْتَرَاحٌ مِنْهُ ‏"‏ ‏.‏ قَالُوا ‏:‏ يَا رَسُولَ اللَّهِ مَا الْمُسْتَرِيحُ وَالْمُسْتَرَاحُ مِنْهُ قَالَ ‏:‏ ‏"‏ الْعَبْدُ الْمُؤْمِنُ يَسْتَرِيحُ مِنْ نَصَبِ الدُّنْيَا وَأَذَاهَا إِلَى رَحْمَةِ اللَّهِ، وَالْعَبْدُ الْفَاجِرُ يَسْتَرِيحُ مِنْهُ الْعِبَادُ وَالْبِلاَدُ وَالشَّجَرُ وَالدَّوَابُّ ‏"‏ ‏.‏\hadithno{574}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Muhammad ibn Amr ibn Halhalaad-Dili from Mabad ibn Kab ibn Malik that Abu Qatada ibn Ribi used to relate that a funeral procession passed by the Messenger of Allah, may Allah bless him and grant him peace, and he said, "One is relieved and another others are relieved from." They said, "Who is the one relieved and the one from whom others are relieved?" He said, "A slave who is mumin is the one who is relieved from the exhaustion and suffering of this world to the mercy of Allah, and a wrong-acting slave is the one from whom people, towns, trees and animals are relieved}}
\hadithdefcmd{malik}{575}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ أَنَّهُ قَالَ ‏:‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَمَّا مَاتَ عُثْمَانُ بْنُ مَظْعُونٍ وَمُرَّ بِجَنَازَتِهِ ‏:‏ ‏ "‏ ذَهَبْتَ وَلَمْ تَلَبَّسْ مِنْهَا بِشَىْءٍ ‏"‏ ‏.‏\hadithno{575}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik that Abu'n Nadr, the mawla of Umar ibn Ubaydullah, said that the Messenger of Allah, may Allah bless him and grant him peace, said, when Uthman ibn Madhun's funeral procession passed by him, "You have gone and you were not involved in any of it}}
\hadithdefcmd{malik}{576}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَلْقَمَةَ بْنِ أَبِي عَلْقَمَةَ، عَنْ أُمِّهِ، أَنَّهَا قَالَتْ سَمِعْتُ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ ‏:‏ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَلَبِسَ ثِيَابَهُ ثُمَّ خَرَجَ - قَالَتْ - فَأَمَرْتُ جَارِيَتِي بَرِيرَةَ تَتْبَعُهُ، فَتَبِعَتْهُ حَتَّى جَاءَ الْبَقِيعَ، فَوَقَفَ فِي أَدْنَاهُ مَا شَاءَ اللَّهُ أَنْ يَقِفَ، ثُمَّ انْصَرَفَ فَسَبَقَتْهُ بَرِيرَةُ فَأَخْبَرَتْنِي، فَلَمْ أَذْكُرْ لَهُ شَيْئًا حَتَّى أَصْبَحَ ثُمَّ ذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏:‏ ‏ "‏ إِنِّي بُعِثْتُ إِلَى أَهْلِ الْبَقِيعِ لأُصَلِّيَ عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{576}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Malik related to me from AIqama ibn Abi Alqama that his mother said that she had heard A'isha, the wife of the Prophet, may Allah bless him and grant him peace, say, "The Messenger of Allah, may Allah bless him and grant him peace, rose one night and put on his clothes and then went out. I ordered my slave-girl, Barira, to follow him, and she followed him until he got to al-Baqi. He stood near it as long as Allah willed and then he left. Barira arrived back before him and told me and I did not say anything to him until morning, and then I mentioned it to him and he explained, 'I was sent out to the people of al-Baqi to pray for them}}
\hadithdefcmd{malik}{577}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ ‏:‏ أَسْرِعُوا بِجَنَائِزِكُمْ، فَإِنَّمَا هُوَ خَيْرٌ تُقَدِّمُونَهُ إِلَيْهِ أَوْ شَرٌّ تَضَعُونَهُ عَنْ رِقَابِكُمْ ‏.‏\hadithno{577}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abu Hurayra said, "Make your funerals speedy, for it is only good that you are advancing him towards, or evil that you are taking off your necks}}
