% Auto-generated chapter 38 for malik
% Hadiths in this chapter: 25

\hadithdefcmd{malik}{1464}{حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ شِرْكًا لَهُ فِي عَبْدٍ فَكَانَ لَهُ مَالٌ يَبْلُغُ ثَمَنَ الْعَبْدِ قُوِّمَ عَلَيْهِ قِيمَةَ الْعَدْلِ فَأَعْطَى شُرَكَاءَهُ حِصَصَهُمْ وَعَتَقَ عَلَيْهِ الْعَبْدُ وَإِلاَّ فَقَدْ عَتَقَ مِنْهُ مَا عَتَقَ ‏"‏ ‏.‏\hadithno{1464}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace,said, "If a man frees his share of a slave and has enough money to cover the full price of the slave justly evaluated for him, he must buy out his partners so that the slave is completely freed. If he doesn't have the money, he partially frees him}}
\hadithdefcmd{malik}{1465}{حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، وَعَنْ غَيْرِ، وَاحِدٍ، عَنِ الْحَسَنِ بْنِ أَبِي الْحَسَنِ الْبَصْرِيِّ، وَعَنْ مُحَمَّدِ بْنِ سِيرِينَ، أَنَّ رَجُلاً، فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَعْتَقَ عَبِيدًا لَهُ سِتَّةً عِنْدَ مَوْتِهِ فَأَسْهَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَهُمْ فَأَعْتَقَ ثُلُثَ تِلْكَ الْعَبِيدِ ‏.‏ قَالَ مَالِكٌ وَبَلَغَنِي أَنَّهُ لَمْ يَكُنْ لِذَلِكَ الرَّجُلِ مَالٌ غَيْرُهُمْ ‏.‏\hadithno{1465}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik said, "The generally agreed-on way of doing things among us in the case of slave whose master makes a bequest to free part of him - a third, a fourth, a half, or any share after his death, is that only the portion of him is freed that his master has named. This is because the freeing of that portion is only obliged to take place after the death of the master because the master has the option to withdraw the bequest as long as he lives. When the slave is freed from his master, the master is a testator and the testator only has access to free what he can take from his property, being the third of the property he is allowed to bequeath, and the rest of the slave is not free because the man's property has gone out of his hands. How can the rest of the slave which belongs to other people be free when they did not initiate the setting free and did not confirm it and they do not have the wala' established for them? Only the deceased could do that. He was the one who freed him and the one for whom the wala' was confirmed. That is not to be borne by another's property unless he bequeaths within the third of his property what remains of a lave to be freed. That is a request against his partners and inheritors and the partners must not refuse the slave that when it is within the third of the dead man's property because there is no harm in that to the inheritors." Malik said, "If a man frees a third of his slave while he is critically ill, he must complete the emancipation so all of him is free from him, if it is within the third of his property that he has access to, because he is not treated in the same way as a man who frees a third of a slave after his death, because had the one who freed a third of his slave after his death lived, he could have cancelled it and the slave's being set free would be of no effect. The master who made the freeing of the third of the slave irrevocable in his illness, would still have to free all of him if he lived. If he died, the slave would be set free within the third of the bequest. That is because the command of the deceased is permissible in his third as the command of the healthy is permissible in all his property." Malik said, "A master who frees a slave of his and settles his emancipation so that his testimony is permitted, his inviolability complete, and his right to inherit confirmed, cannot impose stipulations on him like what he imposes on a slave about property or service, nor get him to do anything of slavery, because the Messenger of Allah, may Allah bless him and grant him peace, said, "If a man frees his share of a slave and has enough money to cover the full price of the slave justly evaluated for him, he must give his partners their shares so the slave is completely free." Malik commented, "If he owns the slave completely, it is more proper to free him completely and not mingle any slavery with it." Malik related to me from Yahya ibn Said and somebody else from al-Hasan ibn Abi al-Hasan al-Basri and from Muhammad ibn Sirin that a man in the time of the Messenger of Allah, may Allah bless him and grant him peace, freed six of his slaves while he was dying. The Messenger of Allah, may Allah bless him and grant him peace, drew lots between them and freed a third of those slaves. Malik added that he had heard that the man did not have any property other than them}}
\hadithdefcmd{malik}{1466}{وَحَدَّثَنِي مَالِكٌ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّ رَجُلاً، فِي إِمَارَةِ أَبَانَ بْنِ عُثْمَانَ أَعْتَقَ رَقِيقًا لَهُ كُلَّهُمْ جَمِيعًا وَلَمْ يَكُنْ لَهُ مَالٌ غَيْرُهُمْ فَأَمَرَ أَبَانُ بْنُ عُثْمَانَ بِتِلْكَ الرَّقِيقِ فَقُسِمَتْ أَثْلاَثًا ثُمَّ أَسْهَمَ عَلَى أَيِّهِمْ يَخْرُجُ سَهْمُ الْمَيِّتِ فَيَعْتِقُونَ فَوَقَعَ السَّهْمُ عَلَى أَحَدِ الأَثْلاَثِ فَعَتَقَ الثُّلُثُ الَّذِي وَقَعَ عَلَيْهِ السَّهْمُ ‏.‏\hadithno{1466}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me from Rabia ibn Abi Abd ar-Rahman that a man in the time of Aban ibn Uthman's amirate freed all of his slaves and did not have other property than them. Aban ibn Uthman took charge of the slaves and they were divided into three groups. Then he drew lots on the basis that which ever group drew the dead man's arrow would be free. The arrow fell to one of the thirds, and that third was freed}}
\hadithdefcmd{malik}{1467}{حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ سَمِعَهُ يَقُولُ مَضَتِ السُّنَّةُ أَنَّ الْعَبْدَ إِذَا عَتَقَ تَبِعَهُ مَالُهُ ‏.‏ قَالَ مَالِكٌ وَمِمَّا يُبَيِّنُ ذَلِكَ أَنَّ الْعَبْدَ إِذَا عَتَقَ تَبِعَهُ مَالُهُ أَنَّ الْمُكَاتَبَ إِذَا كُوتِبَ تَبِعَهُ مَالُهُ وَإِنْ لَمْ يَشْتَرِطْهُ وَذَلِكَ أَنَّ عَقْدَ الْكِتَابَةِ هُوَ عَقْدُ الْوَلاَءِ إِذَا تَمَّ ذَلِكَ وَلَيْسَ مَالُ الْعَبْدِ وَالْمُكَاتَبِ بِمَنْزِلَةِ مَا كَانَ لَهُمَا مِنْ وَلَدٍ إِنَّمَا أَوْلاَدُهُمَا بِمَنْزِلَةِ رِقَابِهِمَا لَيْسُوا بِمَنْزِلَةِ أَمْوَالِهِمَا لأَنَّ السُّنَّةَ الَّتِي لاَ اخْتِلاَفَ فِيهَا أَنَّ الْعَبْدَ إِذَا عَتَقَ تَبِعَهُ مَالُهُ وَلَمْ يَتْبَعْهُ وَلَدُهُ وَأَنَّ الْمُكَاتَبَ إِذَا كُوتِبَ تَبِعَهُ مَالُهُ وَلَمْ يَتْبَعْهُ وَلَدُهُ ‏.‏ قَالَ مَالِكٌ وَمِمَّا يُبَيِّنُ ذَلِكَ أَيْضًا أَنَّ الْعَبْدَ وَالْمُكَاتَبَ إِذَا أَفْلَسَا أُخِذَتْ أَمْوَالُهُمَا وَأُمَّهَاتُ أَوْلاَدِهِمَا وَلَمْ تُؤْخَذْ أَوْلاَدُهُمَا لأَنَّهُمْ لَيْسُوا بِأَمْوَالٍ لَهُمَا ‏.‏ قَالَ مَالِكٌ وَمِمَّا يُبَيِّنُ ذَلِكَ أَيْضًا أَنَّ الْعَبْدَ إِذَا بِيعَ وَاشْتَرَطَ الَّذِي ابْتَاعَهُ مَالَهُ لَمْ يَدْخُلْ وَلَدُهُ فِي مَالِهِ ‏.‏ قَالَ مَالِكٌ وَمِمَّا يُبَيِّنُ ذَلِكَ أَيْضًا أَنَّ الْعَبْدَ إِذَا جَرَحَ أُخِذَ هُوَ وَمَالُهُ وَلَمْ يُؤْخَذْ وَلَدُهُ ‏.‏\hadithno{1467}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me that he heard Ibn Shihab say, "The precedent of the sunna is that when a slave is freed, his property follows him." Malik said, "One thing which makes clear that the property of a slave follows him when he is freed is that when the contract (mukatab) is written for his freedom, his property follows him even if he did not stipulate it. That is because the bond of kitaba is the bond of wala' when it is complete. The property of a slave and a mukatab is not treated in the same way as any children they may have. Their children are only treated in the same way as their own slaves, not in the same way as their property. This is because the sunna, in which there is no dispute, is that when a slave is freed, his property follows him and his children do not follow him, and when a mukatab writes the contract for his freedom, his property follows him and his children do not follow him." Malik said, "One thing which makes that clear is that when a slave or a mukatab are bankrupt, their property is taken but the mothers of their children and their children are not taken because they are not their property." Malik said, "Another thing which makes it clear is that when a slave is sold and the person who buys him stipulates the inclusions of his property, his children are not included in his property." Malik said, "Another thing which makes it clear is that when a slave does injure some one, he and his property are taken, and his children are not taken}}
\hadithdefcmd{malik}{1468}{حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ أَيُّمَا وَلِيدَةٍ وَلَدَتْ مِنْ سَيِّدِهَا فَإِنَّهُ لاَ يَبِيعُهَا وَلاَ يَهَبُهَا وَلاَ يُوَرِّثُهَا وَهُوَ يَسْتَمْتِعُ بِهَا فَإِذَا مَاتَ فَهِيَ حُرَّةٌ ‏.‏\hadithno{1468}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Nafi from Abdullah ibn Umar that Umar ibn al-Khattab said, "If a slave-girl gives birth to a child by her master, he must not sell her, give her away, or bequeath her. He enjoys her and when he dies she is free}}
\hadithdefcmd{malik}{1469}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، أَتَتْهُ وَلِيدَةٌ قَدْ ضَرَبَهَا سَيِّدُهَا بِنَارٍ أَوْ أَصَابَهَا بِهَا فَأَعْتَقَهَا ‏.‏ قَالَ مَالِكٌ الأَمْرُ الْمُجْتَمَعُ عَلَيْهِ عِنْدَنَا أَنَّهُ لاَ تَجُوزُ عَتَاقَةُ رَجُلٍ وَعَلَيْهِ دَيْنٌ يُحِيطُ بِمَالِهِ وَأَنَّهُ لاَ تَجُوزُ عَتَاقَةُ الْغُلاَمِ حَتَّى يَحْتَلِمَ أَوْ يَبْلُغَ مَبْلَغَ الْمُحْتَلِمِ وَأَنَّهُ لاَ تَجُوزُ عَتَاقَةُ الْمُوَلَّى عَلَيْهِ فِي مَالِهِ وَإِنْ بَلَغَ الْحُلُمَ حَتَّى يَلِيَ مَالَهُ ‏.‏\hadithno{1469}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me that he had heard that a slave-girl came to Umar ibn al-Khattab (who had been beaten by her master with a red hot iron) and he set her free. Malik said, "The generally agreed- on way of doing things among us is that a man is not permitted to be freed while he has a debt against him which exceeds his property. A boy is not allowed to be set free until he has reached puberty. The young person whose affairs are managed cannot set free in his property, even when he reaches puberty, until he manages his property}}
\hadithdefcmd{malik}{1470}{حَدَّثَنِي مَالِكٌ، عَنْ هِلاَلِ بْنِ أُسَامَةَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عُمَرَ بْنِ الْحَكَمِ، أَنَّهُ قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ جَارِيَةً لِي كَانَتْ تَرْعَى غَنَمًا لِي فَجِئْتُهَا وَقَدْ فُقِدَتْ شَاةٌ مِنَ الْغَنَمِ فَسَأَلْتُهَا عَنْهَا فَقَالَتْ أَكَلَهَا الذِّئْبُ فَأَسِفْتُ عَلَيْهَا وَكُنْتُ مِنْ بَنِي آدَمَ فَلَطَمْتُ وَجْهَهَا وَعَلَىَّ رَقَبَةٌ أَفَأُعْتِقُهَا فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيْنَ اللَّهُ ‏"‏ ‏.‏ فَقَالَتْ فِي السَّمَاءِ ‏.‏ فَقَالَ ‏"‏ مَنْ أَنَا ‏"‏ ‏.‏ فَقَالَتْ أَنْتَ رَسُولُ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعْتِقْهَا ‏"‏ ‏.‏\hadithno{1470}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Hilal ibn Usama from Ata ibn Yasar that Umar ibn al-Hakam said, "I went to the Messenger of Allah, may Allah bless him and grant him peace, and said, 'Messenger of Allah, a slave girl of mine was tending my sheep. I came to her and one of the sheep was lost. I asked her about it and she said that a wolf had eaten it, so I became angry and I am one of the children of Adam, so I struck her on the face. As it happens, I have to set a slave free, shall I free her?' The Messenger of Allah, may Allah bless him and grant him peace, questioned her, 'Where is Allah?' She said, 'In heaven.' He said, 'Who am I?' She said, 'You are the Messenger of Allah.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'Free her}}
\hadithdefcmd{malik}{1471}{وَحَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِجَارِيَةٍ لَهُ سَوْدَاءَ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ عَلَىَّ رَقَبَةً مُؤْمِنَةً فَإِنْ كُنْتَ تَرَاهَا مُؤْمِنَةً أُعْتِقُهَا ‏.‏ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَشْهَدِينَ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ أَتَشْهَدِينَ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ قَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ أَتُوقِنِينَ بِالْبَعْثِ بَعْدَ الْمَوْتِ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعْتِقْهَا ‏"‏ ‏.‏\hadithno{1471}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Ibn Shihab from Ubaydullah ibn Abdullah ibn Utba ibn Masud that one of the Ansar came to the Messenger of Allah, may Allah bless him and grant him peace, with a black slave- girl of his. He said, "Messenger of Allah, I must set a slave free who is a mumina. If you think that she is mumina, I will free her." The Messenger of Allah, may Allah bless him and grant him peace, questioned her, "Do you testify that there is no god but Allah?" She said, "Yes." "Do you testify that Muhammad is the Messenger of Allah?" She said, "Yes." "Are you certain about the rising after death?" She said, "Yes." The Messenger of Allah, may Allah bless him and grant him peace, said, "Free her}}
\hadithdefcmd{malik}{1472}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ عَنِ الْمَقْبُرِيِّ، أَنَّهُ قَالَ سُئِلَ أَبُو هُرَيْرَةَ عَنِ الرَّجُلِ، تَكُونُ عَلَيْهِ رَقَبَةٌ هَلْ يُعْتِقُ فِيهَا ابْنَ زِنًا فَقَالَ أَبُو هُرَيْرَةَ نَعَمْ ذَلِكَ يُجْزِئُ عَنْهُ ‏.‏\hadithno{1472}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me that he had heard that al-Maqburi said that Abu Hurayra was asked whether a man who had to free a slave, could free an illegitimate child to fulfil that obligation. Abu Hurayra said, "Yes. That will give satisfaction for him}}
\hadithdefcmd{malik}{1473}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ عَنْ فَضَالَةَ بْنِ عُبَيْدٍ الأَنْصَارِيِّ، وَكَانَ، مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ سُئِلَ عَنِ الرَّجُلِ تَكُونُ عَلَيْهِ رَقَبَةٌ هَلْ يَجُوزُ لَهُ أَنْ يُعْتِقَ وَلَدَ زِنًا قَالَ نَعَمْ ذَلِكَ يُجْزِئُ عَنْهُ ‏.‏\hadithno{1473}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me that he had heard that Fadala ibn Ubayd al- Ansari who was one of the companions of the Messenger of Allah, may Allah bless him and grant him peace, was asked whether it was permissible for a man who had to free a slave to free an illegitimate child. He said, "Yes, That will give satisfaction for him}}
\hadithdefcmd{malik}{1474}{حَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، سُئِلَ عَنِ الرَّقَبَةِ الْوَاجِبَةِ، هَلْ تُشْتَرَى بِشَرْطٍ فَقَالَ لاَ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ أَحْسَنُ مَا سَمِعْتُ فِي الرِّقَابِ الْوَاجِبَةِ أَنَّهُ لاَ يَشْتَرِيهَا الَّذِي يُعْتِقُهَا فِيمَا وَجَبَ عَلَيْهِ بِشَرْطٍ عَلَى أَنْ يُعْتِقَهَا لأَنَّهُ إِذَا فَعَلَ ذَلِكَ فَلَيْسَتْ بِرَقَبَةٍ تَامَّةٍ لأَنَّهُ يَضَعُ مِنْ ثَمَنِهَا لِلَّذِي يَشْتَرِطُ مِنْ عِتْقِهَا ‏.‏ قَالَ مَالِكٌ وَلاَ بَأْسَ أَنْ يَشْتَرِيَ الرَّقَبَةَ فِي التَّطَوُّعِ وَيَشْتَرِطَ أَنْ يُعْتِقَهَا ‏.‏ قَالَ مَالِكٌ إِنَّ أَحْسَنَ مَا سُمِعَ فِي الرِّقَابِ الْوَاجِبَةِ أَنَّهُ لاَ يَجُوزُ أَنْ يُعْتَقَ فِيهَا نَصْرَانِيٌّ وَلاَ يَهُودِيٌّ وَلاَ يُعْتَقُ فِيهَا مُكَاتَبٌ وَلاَ مُدَبَّرٌ وَلاَ أُمُّ وَلَدٍ وَلاَ مُعْتَقٌ إِلَى سِنِينَ وَلاَ أَعْمَى وَلاَ بَأْسَ أَنْ يُعْتَقَ النَّصْرَانِيُّ وَالْيَهُودِيُّ وَالْمَجُوسِيُّ تَطَوُّعًا لأَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى قَالَ فِي كِتَابِهِ ‏\{‏فَإِمَّا مَنًّا بَعْدُ وَإِمَّا فِدَاءً‏\}‏ فَالْمَنُّ الْعَتَاقَةُ ‏.‏ قَالَ مَالِكٌ فَأَمَّا الرِّقَابُ الْوَاجِبَةُ الَّتِي ذَكَرَ اللَّهُ فِي الْكِتَابِ فَإِنَّهُ لاَ يُعْتَقُ فِيهَا إِلاَّ رَقَبَةٌ مُؤْمِنَةٌ ‏.‏ قَالَ مَالِكٌ وَكَذَلِكَ فِي إِطْعَامِ الْمَسَاكِينِ فِي الْكَفَّارَاتِ لاَ يَنْبَغِي أَنْ يُطْعَمَ فِيهَا إِلاَّ الْمُسْلِمُونَ وَلاَ يُطْعَمُ فِيهَا أَحَدٌ عَلَى غَيْرِ دِينِ الإِسْلاَمِ ‏.‏\hadithno{1474}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Malik related to me that he had heard that Abdullah ibn Umar was asked whether a slave could be bought on the specific condition that it was to be used to fulfil the obligation of freeing a slave, and he said, "No." Malik said, "That is the best of what I have heard on the obligation of freeing slaves. Someone who has to set a slave free because of an obligation on him, may not buy one on the condition that he sets it free because if he does that, whatever he buys is not completely a slave because he has reduced its price by the condition he has made of setting it free." Malik added, "There is no harm, however, in someone buying a person expressly to set him free." Malik said, "The best of what I have heard on the obligation of freeing slaves is that it is not permitted to free a christian or a jew to fulfil it, and one does not free a mukatab or a mudabbar or an umm walad or a slave to be freed after a certain number of years, or a blind person. There is no harm in freeing a christian, jew, or magian voluntarily, because Allah, the Blessed, the Exalted, said in His Book, 'either as a favour then or by ransom,' (Sura 47 ayat 4) The favour is setting free." Malik said, "As for obligations of freeing slaves which Allah has mentioned in the Book, one only frees a mumin slave for them." Malik said, "It is like that in feeding poor people for kaffara. One must only feed muslims and one does not feed anyone outside of the deen of Islam}}
\hadithdefcmd{malik}{1475}{حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ الأَنْصَارِيِّ، أَنَّ أُمَّهُ، أَرَادَتْ أَنْ تُوصِيَ ثُمَّ أَخَّرَتْ ذَلِكَ إِلَى أَنْ تُصْبِحَ فَهَلَكَتْ وَقَدْ كَانَتْ هَمَّتْ بِأَنْ تُعْتِقَ فَقَالَ عَبْدُ الرَّحْمَنِ فَقُلْتُ لِلْقَاسِمِ بْنِ مُحَمَّدٍ أَيَنْفَعُهَا أَنْ أُعْتِقَ عَنْهَا فَقَالَ الْقَاسِمُ إِنَّ سَعْدَ بْنَ عُبَادَةَ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّ أُمِّي هَلَكَتْ فَهَلْ يَنْفَعُهَا أَنْ أُعْتِقَ عَنْهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَعَمْ ‏"‏ ‏.‏\hadithno{1475}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Malik related to me from Abd ar-Rahman ibn Abi Amra al-Ansari that his mother had wanted to make a bequest, but she delayed until morning and died. She had intended to set someone free, so Abd ar- Rahman said, 'I said to al-Qasim ibn Muhammad, 'Will it help her if I free a slave for her?' Al-Qasim replied, 'Sad ibn Ubada said to the Messenger of Allah, may Allah bless him and grant him peace, 'My mother died, will it help her if I set a slave free for her?' The Messenger of Allah, may Allah bless him and grant him peace, said "Yes}}
\hadithdefcmd{malik}{1476}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ تُوُفِّيَ عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرٍ فِي نَوْمٍ نَامَهُ فَأَعْتَقَتْ عَنْهُ عَائِشَةُ زَوْجُ النَّبِيِّ صلى الله عليه وسلم رِقَابًا كَثِيرَةً ‏.‏ قَالَ مَالِكٌ وَهَذَا أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي ذَلِكَ ‏.‏\hadithno{1476}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me that Yahya ibn Said said, ''Abd ar-Rahman ibn Abi Bakr died in his sleep, and A'isha, the wife of the Prophet, may Allah bless him and grant him peace, set free many slaves for him." Malik said, "This is what I like best of what I have heard on the subject}}
\hadithdefcmd{malik}{1477}{حَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الرِّقَابِ أَيُّهَا أَفْضَلُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَغْلاَهَا ثَمَنًا وَأَنْفَسُهَا عِنْدَ أَهْلِهَا ‏"‏ ‏.‏\hadithno{1477}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Hisham ibn Urwa from his father from A'isha, the wife of the Prophet, may Allah bless him and grant him peace, that the Messenger of Allah, may Allah bless him and grant him peace, was asked what was the most excellent kind of slave to free. The Messenger of Allah, May Allah bless him and grant him peace, answered, "The most expensive and the most valuable to his master}}
\hadithdefcmd{malik}{1478}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ أَعْتَقَ وَلَدَ زِنًا وَأُمَّهُ ‏.‏\hadithno{1478}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Nafi that Abdullah ibn Umar freed an illegitimate child and its mother}}
\hadithdefcmd{malik}{1479}{حَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ جَاءَتْ بَرِيرَةُ فَقَالَتْ إِنِّي كَاتَبْتُ أَهْلِي عَلَى تِسْعِ أَوَاقٍ فِي كُلِّ عَامٍ أُوْقِيَّةٌ فَأَعِينِينِي ‏.‏ فَقَالَتْ عَائِشَةُ إِنْ أَحَبَّ أَهْلُكِ أَنْ أَعُدَّهَا لَهُمْ عَنْكِ عَدَدْتُهَا وَيَكُونَ لِي وَلاَؤُكِ فَعَلْتُ ‏.‏ فَذَهَبَتْ بَرِيرَةُ إِلَى أَهْلِهَا فَقَالَتْ لَهُمْ ذَلِكَ فَأَبَوْا عَلَيْهَا فَجَاءَتْ مِنْ عِنْدِ أَهْلِهَا وَرَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ فَقَالَتْ لِعَائِشَةَ إِنِّي قَدْ عَرَضْتُ عَلَيْهِمْ ذَلِكَ فَأَبَوْا عَلَىَّ إِلاَّ أَنْ يَكُونَ الْوَلاَءُ لَهُمْ ‏.‏ فَسَمِعَ ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَأَلَهَا فَأَخْبَرَتْهُ عَائِشَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خُذِيهَا وَاشْتَرِطِي لَهُمُ الْوَلاَءَ فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ فَفَعَلَتْ عَائِشَةُ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّاسِ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَمَا بَالُ رِجَالٍ يَشْتَرِطُونَ شُرُوطًا لَيْسَتْ فِي كِتَابِ اللَّهِ مَا كَانَ مِنْ شَرْطٍ لَيْسَ فِي كِتَابِ اللَّهِ فَهُوَ بَاطِلٌ وَإِنْ كَانَ مِائَةَ شَرْطٍ قَضَاءُ اللَّهِ أَحَقُّ وَشَرْطُ اللَّهِ أَوْثَقُ وَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏\hadithno{1479}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Hisham ibn Urwa from his father that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "Barira came to me and said, 'I have written myself as mukatab for my people for nine uqiyas, one uqiya per year, so help me.' A'isha said, 'If your people agree that I pay it all to them for you, and that if I pay it, your wala' is mine, then I will do it.' Barira went to her masters and told them that and they didn't agree. She came back from her masters while the Messenger of Allah, may Allah bless him and grant him peace, was sitting. She said to A'isha, 'I offered that to them and they refused me unless they had the wala'.' The Messenger of Allah, may Allah bless him and grant him peace, heard that and asked her about it A'isha told him and the Messenger of Allah, may Allah bless him and grant him peace, said, 'Take her and stipulate that the wala' is yours, for the wala' is for the one who sets free.' So A'isha did that and then the Messenger of Allah, may Allah bless him and grant him peace, stood up in front of the people, and praised Allah and gave thanks to Him. Then he said, 'What is wrong with the people who make conditions which are not in the Book of Allah? Any condition which is not in the Book of Allah is invalid even if it is a hundred conditions. The decree of Allah is truer and the conditions of Allah are firmer, and the wala' only belongs to the one who sets free}}
\hadithdefcmd{malik}{1480}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ، أَرَادَتْ أَنْ تَشْتَرِيَ جَارِيَةً تُعْتِقُهَا فَقَالَ أَهْلُهَا نَبِيعُكِهَا عَلَى أَنَّ وَلاَءَهَا لَنَا فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ يَمْنَعَنَّكِ ذَلِكَ فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏\hadithno{1480}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Nafi from Abdullah ibn Umar that A'isha umm al-muminin wanted to buy a slave-girl and set her free. Her people said, "We will sell her to you provided that her wala' is ours." She mentioned that to the Messenger of Allah, may Allah bless him and grant him peace, and he said, "Don't let that hinder you, for the wala' only belongs to the one who sets free}}
\hadithdefcmd{malik}{1481}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّ بَرِيرَةَ، جَاءَتْ تَسْتَعِينُ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ فَقَالَتْ عَائِشَةُ إِنْ أَحَبَّ أَهْلُكِ أَنْ أَصُبَّ لَهُمْ ثَمَنَكِ صَبَّةً وَاحِدَةً وَأُعْتِقَكِ فَعَلْتُ ‏.‏ فَذَكَرَتْ ذَلِكَ بَرِيرَةُ لأَهْلِهَا فَقَالُوا لاَ إِلاَّ أَنْ يَكُونَ لَنَا وَلاَؤُكِ ‏.‏ قَالَ يَحْيَى بْنُ سَعِيدٍ فَزَعَمَتْ عَمْرَةُ أَنَّ عَائِشَةَ ذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اشْتَرِيهَا وَأَعْتِقِيهَا فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏\hadithno{1481}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Yahya ibn Said from Amra bint Abd ar- Rahman that Barira came asking the help of A'isha, umm al-muminin. A'isha said, "If your masters agree that I pay them your price in one lump sum and set you free I will do it." Barira mentioned that to her masters and they said, "No, not unless your wala' is ours." Yahya ibn Said added that Amra bint Abd ar-Rahman claimed that A'isha mentioned that to the Messenger of Allah, may Allah bless him and grant him peace, and the Messenger of Allah, may Allah bless him and grant him peace said, "Buy her and set her free. The wala' only belongs to the one who sets free}}
\hadithdefcmd{malik}{1482}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْوَلاَءِ وَعَنْ هِبَتِهِ ‏.‏\hadithno{1482}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abdullah ibn Dinar from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, forbade selling or giving away the wala}}
\hadithdefcmd{malik}{1483}{حَدَّثَنِي مَالِكٌ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، ‏.‏ أَنَّ الزُّبَيْرَ بْنَ الْعَوَّامِ، اشْتَرَى عَبْدًا فَأَعْتَقَهُ وَلِذَلِكَ الْعَبْدِ بَنُونَ مِنِ امْرَأَةٍ حُرَّةٍ فَلَمَّا أَعْتَقَهُ الزُّبَيْرُ قَالَ هُمْ مَوَالِيَّ ‏.‏ وَقَالَ مَوَالِي أُمِّهِمْ بَلْ هُمْ مَوَالِينَا ‏.‏ فَاخْتَصَمُوا إِلَى عُثْمَانَ بْنِ عَفَّانَ فَقَضَى عُثْمَانُ لِلزُّبَيْرِ بِوَلاَئِهِمْ ‏.‏\hadithno{1483}\hadithgrade{Salim al-Hilali: Mauquf Sahih Lighairihi}\hadithtrans{Malik said that it was not permissible for a slave to buy himself from his master on the provision that he could give the wala' to whomever he wished as the wala' was for the one who set him free, and that had a man given permission to his mawla to give the wala' to whomever he wished, that would not have been permitted, because the Messenger of Allah, may Allah bless him and grant him peace, had said, "The wala' is for the one who sets free. " The Messenger of Allah, may Allah bless him and grant him peace, forbade selling or giving away the wala'. For if it was permitted to the master to stipulate that for him and to give him permission to give the wala' to whomever he liked, that would be a gift. Malik related to me from Rabia ibn Abd ar-Rahman that az-Zubayr ibn al-Awwam bought a slave and set him free. The slave had children by a free woman. When az-Zubayr freed him, he said, "They are my mawali." The man argued, "They are the mawali of their mother. Rather, they are our mawali." They took the dispute to Uthman ibn Affan, and Uthman gave a judgement that az-Zubayr had their wala}}
\hadithdefcmd{malik}{1484}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، سُئِلَ عَنْ عَبْدٍ لَهُ، وَلَدٌ مِنِ امْرَأَةٍ حُرَّةٍ لِمَنْ وَلاَؤُهُمْ فَقَالَ سَعِيدٌ إِنْ مَاتَ أَبُوهُمْ وَهُوَ عَبْدٌ لَمْ يُعْتَقْ فَوَلاَؤُهُمْ لِمَوَالِي أُمِّهِمْ ‏.‏ قَالَ مَالِكٌ وَمَثَلُ ذَلِكَ وَلَدُ الْمُلاَعَنَةِ مِنَ الْمَوَالِي يُنْسَبُ إِلَى مَوَالِي أُمِّهِ فَيَكُونُونَ هُمْ مَوَالِيَهُ إِنْ مَاتَ وَرِثُوهُ وَإِنْ جَرَّ جَرِيرَةً عَقَلُوا عَنْهُ فَإِنِ اعْتَرَفَ بِهِ أَبُوهُ أُلْحِقَ بِهِ وَصَارَ وَلاَؤُهُ إِلَى مَوَالِي أَبِيهِ وَكَانَ مِيرَاثُهُ لَهُمْ وَعَقْلُهُ عَلَيْهِمْ وَيُجْلَدُ أَبُوهُ الْحَدَّ ‏.‏ قَالَ مَالِكٌ وَكَذَلِكَ الْمَرْأَةُ الْمُلاَعِنَةُ مِنَ الْعَرَبِ إِذَا اعْتَرَفَ زَوْجُهَا الَّذِي لاَعَنَهَا بِوَلَدِهَا صَارَ بِمِثْلِ هَذِهِ الْمَنْزِلَةِ إِلاَّ أَنَّ بَقِيَّةَ مِيرَاثِهِ بَعْدَ مِيرَاثِ أُمِّهِ وَإِخْوَتِهِ لأُمِّهِ لِعَامَّةِ الْمُسْلِمِينَ مَا لَمْ يُلْحَقْ بِأَبِيهِ وَإِنَّمَا وَرَّثَ وَلَدُ الْمُلاَعَنَةِ الْمُوَالاَةَ مَوَالِيَ أُمِّهِ قَبْلَ أَنْ يَعْتَرِفَ بِهِ أَبُوهُ لأَنَّهُ لَمْ يَكُنْ لَهُ نَسَبٌ وَلاَ عَصَبَةٌ فَلَمَّا ثَبَتَ نَسَبُهُ صَارَ إِلَى عَصَبَتِهِ ‏.‏ قَالَ مَالِكٌ الأَمْرُ الْمُجْتَمَعُ عَلَيْهِ عِنْدَنَا فِي وَلَدِ الْعَبْدِ مِنِ امْرَأَةٍ حُرَّةٍ وَأَبُو الْعَبْدِ حُرٌّ أَنَّ الْجَدَّ أَبَا الْعَبْدِ يَجُرُّ وَلاَءَ وَلَدِ ابْنِهِ الأَحْرَارِ مِنِ امْرَأَةٍ حُرَّةٍ يَرِثُهُمْ مَا دَامَ أَبُوهُمْ عَبْدًا فَإِنْ عَتَقَ أَبُوهُمْ رَجَعَ الْوَلاَءُ إِلَى مَوَالِيهِ وَإِنْ مَاتَ وَهُوَ عَبْدٌ كَانَ الْمِيرَاثُ وَالْوَلاَءُ لِلْجَدِّ وَإِنِ الْعَبْدُ كَانَ لَهُ ابْنَانِ حُرَّانِ فَمَاتَ أَحَدُهُمَا وَأَبُوهُ عَبْدٌ جَرَّ الْجَدُّ أَبُو الأَبِ الْوَلاَءَ وَالْمِيرَاثَ ‏.‏ قَالَ مَالِكٌ فِي الأَمَةِ تُعْتَقُ وَهِيَ حَامِلٌ وَزَوْجُهَا مَمْلُوكٌ ثُمَّ يَعْتِقُ زَوْجُهَا قَبْلَ أَنْ تَضَعَ حَمْلَهَا أَوْ بَعْدَ مَا تَضَعُ إِنَّ وَلاَءَ مَا كَانَ فِي بَطْنِهَا لِلَّذِي أَعْتَقَ أُمَّهُ لأَنَّ ذَلِكَ الْوَلَدَ قَدْ كَانَ أَصَابَهُ الرِّقُّ قَبْلَ أَنْ تُعْتَقَ أُمُّهُ وَلَيْسَ هُوَ بِمَنْزِلَةِ الَّذِي تَحْمِلُ بِهِ أُمُّهُ بَعْدَ الْعَتَاقَةِ لأَنَّ الَّذِي تَحْمِلُ بِهِ أُمُّهُ بَعْدَ الْعَتَاقَةِ إِذَا أُعْتِقَ أَبُوهُ جَرَّ وَلاَءَهُ ‏.‏ قَالَ مَالِكٌ فِي الْعَبْدِ يَسْتَأْذِنُ سَيِّدَهُ أَنْ يُعْتِقَ عَبْدًا لَهُ فَيَأْذَنَ لَهُ سَيِّدُهُ إِنَّ وَلاَءَ الْعَبْدِ الْمُعْتَقِ\hadithno{1484}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Malik related to me that he had heard that Said ibn al-Musayyab was asked who had the wala' of the children whom a slave had by a free woman. Said said, "If their father dies and he is a slave who was not set free, their wala' belongs to the mawali of their mother." Malik said, "That is like the child of a woman who is a mawla who has been divorced by lian; the child is attached to the mawali of his mother and they are his mawali. If he dies, they inherit from him. If he commits a crime, they pay the blood-money for him. If his father acknowledges him, he is given a kinship to him and his wala' goes to the mawali of his father. They are his heirs, they pay his blood-money and his father is punished with the hadd-punishment." Malik said, "It is like that with a free-born woman divorced by lian. If her husband who curses her by lian does not acknowledge her child, the child is dealt with in the same way except that the rest of his inheritance after the inheritance of his mother and his brothers from his mother goes to all the muslims as long as he was not given kinship to his father. The child of the lian is attached to the patronage of the mawali of his mother until his father acknowledges him because he does not have a lineage or paternal relations. If his lineage is confirmed, it goes to his paternal relations." Malik said, "The generally agreed-on way of doing things among us about a child of a slave by a free woman, while the father of the slave is free, is that the grandfather (the father of the slave), attracts the wala' of his son's free children by a free woman. They leave their inheritance to him as long as their father is a slave. If the father becomes free, the wala' returns to his mawali. If he dies and he is still a slave, the inheritance and the wala' go to the grandfather. If the slave has two free sons, and one of them dies while the father is still a slave, the grandfather, the father of the father, attracts the wala' and the inheritance." Malik spoke about a slave-girl who was set free while she was pregnant and her husband was a slave and then her husband became free before she gave birth, or after she gave birth. He said, "The wala' of what is in her womb goes to the person who set the mother free because slavery touched the child before the mother was set free. It is not treated in the same way as a child conceived by its mother after she has been set free because the wala' of such a child, is attracted by the father when he is set free." Malik said that if a slave asked his master's permission to free a slave of his and his master gave permission, the wala' of the freed slave went to the master of his master, and his wala' did not return to the master who had set him free, even if he were to become free himself}}
\hadithdefcmd{malik}{1485}{حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ أَبِيهِ، أَنَّهُ أَخْبَرَهُ أَنَّ الْعَاصِيَ بْنَ هِشَامٍ هَلَكَ وَتَرَكَ بَنِينَ لَهُ ثَلاَثَةً اثْنَانِ لأُمٍّ وَرَجُلٌ لِعَلَّةٍ فَهَلَكَ أَحَدُ اللَّذَيْنِ لأُمٍّ وَتَرَكَ مَالاً وَمَوَالِيَ فَوَرِثَهُ أَخُوهُ لأَبِيهِ وَأُمِّهِ مَالَهُ وَوَلاَءَهُ مَوَالِيهِ ثُمَّ هَلَكَ الَّذِي وَرِثَ الْمَالَ وَوَلاَءَ الْمَوَالِي وَتَرَكَ ابْنَهُ وَأَخَاهُ لأَبِيهِ فَقَالَ ابْنُهُ قَدْ أَحْرَزْتُ مَا كَانَ أَبِي أَحْرَزَ مِنَ الْمَالِ وَوَلاَءِ الْمَوَالِي وَقَالَ أَخُوهُ لَيْسَ كَذَلِكَ إِنَّمَا أَحْرَزْتَ الْمَالَ وَأَمَّا وَلاَءُ الْمَوَالِي فَلاَ أَرَأَيْتَ لَوْ هَلَكَ أَخِي الْيَوْمَ أَلَسْتُ أَرِثُهُ أَنَا فَاخْتَصَمَا إِلَى عُثْمَانَ بْنِ عَفَّانَ فَقَضَى لأَخِيهِ بِوَلاَءِ الْمَوَالِي ‏.‏\hadithno{1485}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me from Abdullah ibn Abi Bakr ibn Muhammad ibn Amr ibn Hazm from Abd al-Malik ibn Abi Bakr ibn Abd ar-Rahman ibn al- Harith ibn Hisham that his father told him that al-Asi ibn Hisham had died and left three sons, two by one wife and one by another wife. One of the two with the same mother died and left property and mawali. His full brother inherited his property and the wala' of his mawali. Then he also died, and left as heirs his son and his paternal half brother. His son said, "I obtain what my father inherited of property and the wala' of the mawali." His brother said, "It is not like that. You obtain the property. As for the wala' of the mawali, it is not so. Do you think that had it been my first brother who died today, I would not have inherited from him?" They argued and went to Uthman ibn Affan. He gave a judgement that the brother had the wala' of the mawali}}
\hadithdefcmd{malik}{1486}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ حَزْمٍ، أَنَّهُ أَخْبَرَهُ أَبُوهُ، أَنَّهُ كَانَ جَالِسًا عِنْدَ أَبَانَ بْنِ عُثْمَانَ فَاخْتَصَمَ إِلَيْهِ نَفَرٌ مِنْ جُهَيْنَةَ وَنَفَرٌ مِنْ بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ وَكَانَتِ امْرَأَةٌ مِنْ جُهَيْنَةَ عِنْدَ رَجُلٍ مِنْ بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ يُقَالُ لَهُ إِبْرَاهِيمُ بْنُ كُلَيْبٍ فَمَاتَتِ الْمَرْأَةُ وَتَرَكَتْ مَالاً وَمَوَالِيَ فَوَرِثَهَا ابْنُهَا وَزَوْجُهَا ثُمَّ مَاتَ ابْنُهَا فَقَالَ وَرَثَتُهُ لَنَا وَلاَءُ الْمَوَالِي قَدْ كَانَ ابْنُهَا أَحْرَزَهُ فَقَالَ الْجُهَنِيُّونَ لَيْسَ كَذَلِكَ إِنَّمَا هُمْ مَوَالِي صَاحِبَتِنَا فَإِذَا مَاتَ وَلَدُهَا فَلَنَا وَلاَؤُهُمْ وَنَحْنُ نَرِثُهُمْ فَقَضَى أَبَانُ بْنُ عُثْمَانَ لِلْجُهَنِيِّينَ بِوَلاَءِ الْمَوَالِي ‏.‏\hadithno{1486}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me from Abdullah ibn Abi Bakr ibn Hazm that his father told him that he was sitting with Aban ibn Uthman, and an argument was brought to him between some people from the Juhayna tribe and some people from the Banu al-Harith ibn al-Khazraj. A woman of the Juhayna tribe was married to a man from the Banu al-Harith ibn al- Khazraj, called Ibrahim ibn Kulayb. She died and left property and mawali, and her son and husband inherited them from her. Then her son died and his heirs said, "We have the wala' of the mawali. Her son obtained them." Those of the Juhayna said, "It is not like that. They are the mawali of our female associate. When her child died, we have their wala' and we inherit them." Aban ibn Uthman gave a judgement that the people from the Juhayna tribe did indeed have the wala' of the mawali}}
\hadithdefcmd{malik}{1487}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، قَالَ فِي رَجُلٍ هَلَكَ وَتَرَكَ بَنِينَ لَهُ ثَلاَثَةً وَتَرَكَ مَوَالِيَ أَعْتَقَهُمْ هُوَ عَتَاقَةً ثُمَّ إِنَّ الرَّجُلَيْنِ مِنْ بَنِيهِ هَلَكَا وَتَرَكَا أَوْلاَدًا ‏.‏ فَقَالَ سَعِيدُ بْنُ الْمُسَيَّبِ يَرِثُ الْمَوَالِيَ الْبَاقِي مِنَ الثَّلاَثَةِ فَإِذَا هَلَكَ هُوَ فَوَلَدُهُ وَوَلَدُ إِخْوَتِهِ فِي وَلاَءِ الْمَوَالِي شَرَعٌ سَوَاءٌ ‏.‏\hadithno{1487}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Malik related to me that he had heard that Said ibn al-Musayyab spoke about a man who died and left three sons and left mawali whom he had freed. Then two of his sons died and left children. He said, "The third remaining son inherits the mawali. When he dies, his children and the children of his brothers share equally in the wala' of the mawali}}
\hadithdefcmd{malik}{1488}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ سَأَلَ ابْنَ شِهَابٍ عَنِ السَّائِبَةِ، قَالَ يُوَالِي مَنْ شَاءَ فَإِنْ مَاتَ وَلَمْ يُوَالِ أَحَدًا فَمِيرَاثُهُ لِلْمُسْلِمِينَ وَعَقْلُهُ عَلَيْهِمْ ‏.‏ قَالَ مَالِكٌ إِنَّ أَحْسَنَ مَا سُمِعَ فِي السَّائِبَةِ أَنَّهُ لاَ يُوَالِي أَحَدًا وَأَنَّ مِيرَاثَهُ لِلْمُسْلِمِينَ وَعَقْلَهُ عَلَيْهِمْ ‏.‏ قَالَ مَالِكٌ فِي الْيَهُودِيِّ وَالنَّصْرَانِيِّ يُسْلِمُ عَبْدُ أَحَدِهِمَا فَيُعْتِقُهُ قَبْلَ أَنْ يُبَاعَ عَلَيْهِ إِنَّ وَلاَءَ الْعَبْدِ الْمُعْتَقِ لِلْمُسْلِمِينَ وَإِنْ أَسْلَمَ الْيَهُودِيُّ أَوِ النَّصْرَانِيُّ بَعْدَ ذَلِكَ لَمْ يَرْجِعْ إِلَيْهِ الْوَلاَءُ أَبَدًا ‏.‏ قَالَ وَلَكِنْ إِذَا أَعْتَقَ الْيَهُودِيُّ أَوِ النَّصْرَانِيُّ عَبْدًا عَلَى دِينِهِمَا ثُمَّ أَسْلَمَ الْمُعْتَقُ قَبْلَ أَنْ يُسْلِمَ الْيَهُودِيُّ أَوِ النَّصْرَانِيُّ الَّذِي أَعْتَقَهُ ثُمَّ أَسْلَمَ الَّذِي أَعْتَقَهُ رَجَعَ إِلَيْهِ الْوَلاَءُ لأَنَّهُ قَدْ كَانَ ثَبَتَ لَهُ الْوَلاَءُ يَوْمَ أَعْتَقَهُ ‏.‏ قَالَ مَالِكٌ وَإِنْ كَانَ لِلْيَهُودِيِّ أَوِ النَّصْرَانِيِّ وَلَدٌ مُسْلِمٌ وَرِثَ مَوَالِيَ أَبِيهِ الْيَهُودِيِّ أَوِ النَّصْرَانِيِّ إِذَا أَسْلَمَ الْمَوْلَى الْمُعْتَقُ قَبْلَ أَنْ يُسْلِمَ الَّذِي أَعْتَقَهُ وَإِنْ كَانَ الْمُعْتَقُ حِينَ أُعْتِقَ مُسْلِمًا لَمْ يَكُنْ لِوَلَدِ النَّصْرَانِيِّ أَوِ الْيَهُودِيِّ الْمُسْلِمَيْنِ مِنْ وَلاَءِ الْعَبْدِ الْمُسْلِمِ شَىْءٌ لأَنَّهُ لَيْسَ لِلْيَهُودِيِّ وَلاَ لِلنَّصْرَانِيِّ وَلاَءٌ فَوَلاَءُ الْعَبْدِ الْمُسْلِمِ لِجَمَاعَةِ الْمُسْلِمِينَ ‏.‏\hadithno{1488}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me that he had asked Ibn Shihab about a slave who was released. He said, "He gives his wala' to whomever he likes. If he dies and has not given his wala' to anyone, his inheritance goes to the muslims and his blood-money is paid by them." Malik said, "The best of what has been heard about a slave who is released is that no one gets his wala', and his inheritance goes to the muslims, and they pay his blood-money." Malik said that when the slave of a jew or christian became muslim and he was freed before being sold, the wala' of the freed slave went to the muslims. If the jew or christian became muslim afterwards, the wala' did not revert to him. " He said, "However, if a jew or christian frees a slave from their own deen, and then the freed one becomes muslim before the jew or christian who freed him becomes muslim and then the one who freed him has become muslim, his wala' reverts to him because the wala' was confirmed for him on the day he freed him." Malik said that the muslim child of a jew or christian inherited the mawali of his jewish or christian father when the freed mawla became muslim before the one who freed him became muslim. If the freed one was already muslim when he was freed, the muslim children of the christian or jew had nothing of the wala' of a muslim slave because the jew and the christian did not have the wala'. The wala' of a muslim slave went to the community of muslims}}
