% Auto-generated chapter 59 for malik
% Hadiths in this chapter: 1

\hadithdefcmd{malik}{1856}{باب مَا جَاءَ فِي طَلَبِ الْعِلْمِ حَدَّثَنِي عَنْ مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ لُقْمَانَ الْحَكِيمَ، أَوْصَى ابْنَهُ فَقَالَ يَا بُنَىَّ جَالِسِ الْعُلَمَاءَ وَزَاحِمْهُمْ بِرُكْبَتَيْكَ فَإِنَّ اللَّهَ يُحْيِي الْقُلُوبَ بِنُورِ الْحِكْمَةِ كَمَا يُحْيِي اللَّهُ الأَرْضَ الْمَيْتَةَ بِوَابِلِ السَّمَاءِ\hadithno{1856}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he heard that Luqman al-Hakim made his will and counselled his son, saying, "My son! Sit with the learned men and keep close to them. Allah gives life to the hearts with the light of wisdom as Allah gives life to the dead earth with the abundant rain of the sky}}
