% Auto-generated chapter 31 for nasai
% Hadiths in this chapter: 16

\hadithdefcmd{nasai}{3672}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدٍ، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، قَالَ سَمِعْنَاهُ مِنَ الزُّهْرِيِّ، أَخْبَرَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، وَمُحَمَّدُ بْنُ النُّعْمَانِ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ أَبَاهُ، نَحَلَهُ غُلاَمًا فَأَتَى النَّبِيَّ صلى الله عليه وسلم يُشْهِدُهُ فَقَالَ ‏"‏ أَكُلَّ وَلَدِكَ نَحَلْتَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَارْدُدْهُ ‏"‏ ‏.‏ وَاللَّفْظُ لِمُحَمَّدٍ ‏.‏\hadithno{3672}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from An-Nu'man bin Bashir that his father gave him a slave as a present, then he came to the Prophet to ask him to bear witness (to that). He said:"Have you given a present to all of your children?" He said: "No." He said: "Then take it back." This wording is that of (one of the narrators) Muhammad}}
\hadithdefcmd{nasai}{3673}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، وَمُحَمَّدِ بْنِ النُّعْمَانِ، يُحَدِّثَانِهِ عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ أَبَاهُ، أَتَى بِهِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنِّي نَحَلْتُ ابْنِي غُلاَمًا كَانَ لِي فَقَالَ رَسُولُ اللَّهِ ‏"‏ أَكُلَّ وَلَدِكَ نَحَلْتَهُ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَارْجِعْهُ ‏"‏ ‏.‏\hadithno{3673}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from An-Nu'man bin Bashir that his father brought him to the Messenger of Allah and said:"I have given my son a slave of mine as a present." The Messenger of Allah said: "Have you given a present to all of your children?" He said: "No." The Messenger of Allah said: "Then take (your present) back}}
\hadithdefcmd{nasai}{3674}{أَخْبَرَنَا مُحَمَّدُ بْنُ هَاشِمٍ، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، وَعَنْ مُحَمَّدِ بْنِ النُّعْمَانِ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ أَبَاهُ، بَشِيرَ بْنَ سَعْدٍ جَاءَ بِابْنِهِ النُّعْمَانِ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي نَحَلْتُ ابْنِي هَذَا غُلاَمًا كَانَ لِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَكُلَّ بَنِيكَ نَحَلْتَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَارْجِعْهُ ‏"‏ ‏.‏\hadithno{3674}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from An-Nu'man bin Bashir that his father Bashir bin Sa'd brought An-Nu'man with him and said:"O Messenger of Allah, I have given this son of mine a slave who belonged to me as a present." The Messenger of Allah said: "Have you given a present to all your children?" He said: "No." He said: "Then take (your present) back}}
\hadithdefcmd{nasai}{3675}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، أَنَّ مُحَمَّدَ بْنَ النُّعْمَانِ، وَحُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ، حَدَّثَاهُ عَنْ بَشِيرِ بْنِ سَعْدٍ، أَنَّهُ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم بِالنُّعْمَانِ بْنِ بَشِيرٍ فَقَالَ إِنِّي نَحَلْتُ ابْنِي هَذَا غُلاَمًا فَإِنْ رَأَيْتَ أَنْ تُنْفِذَهُ أَنْفَذْتُهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَكُلَّ بَنِيكَ نَحَلْتَهُ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَارْدُدْهُ ‏"‏ ‏.‏\hadithno{3675}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Bashir bin Sa'd that he brought An-Nu'man to the Prophet and said:"I want to give this son of mine a slave as a present, and if you think that I should go ahead with it, I will go ahead." The Messenger of Allah said: "Have you given a present to all your children?" He said: "No." He said: "Then take (your present) back}}
\hadithdefcmd{nasai}{3676}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ أَبَاهُ، نَحَلَهُ نُحْلاً فَقَالَتْ لَهُ أُمُّهُ أَشْهِدِ النَّبِيَّ صلى الله عليه وسلم عَلَى مَا نَحَلْتَ ابْنِي ‏.‏ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَكَرِهَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَشْهَدَ لَهُ ‏.‏\hadithno{3676}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from An-Nu'man bin Bashir that his father gave him a present, and his mother said:"Ask the Prophet to bear witness to what you have given to my son." So he came to the Prophet and told him about that, and the Prophet did not want to bear witness to it}}
\hadithdefcmd{nasai}{3677}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا أَبُو عَامِرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدٍ، - يَعْنِي ابْنَ إِبْرَاهِيمَ - عَنْ عُرْوَةَ، عَنْ بَشِيرٍ، أَنَّهُ نَحَلَ ابْنَهُ غُلاَمًا فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَأَرَادَ أَنْ يُشْهِدَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَكُلَّ وَلَدِكَ نَحَلْتَهُ مِثْلَ ذَا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَارْدُدْهُ ‏"‏ ‏.‏\hadithno{3677}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Bashir that he gave his son a slave as a present, then he came to the Prophet and he wanted the Prophet to bear witness to that. He said:"Have you given a similar present to all of your children?" He said: "No." He said: "Then take (your present) back}}
\hadithdefcmd{nasai}{3678}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ حَدَّثَنَا حِبَّانُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ بَشِيرًا، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا نَبِيَّ اللَّهِ نَحَلْتُ النُّعْمَانَ نِحْلَةً ‏.‏ قَالَ ‏"‏ أَعْطَيْتَ لإِخْوَتِهِ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَارْدُدْهُ ‏"‏ ‏.‏\hadithno{3678}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hisham bin 'Urwah, from his father, that Bashir came to the Prophet and said:"O Prophet of Allah, I have given An-Nu'man a present." He said: "Have you given something to his brothers?" He said: "No." He said: "Then take it back}}
\hadithdefcmd{nasai}{3679}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا دَاوُدُ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ، قَالَ انْطَلَقَ بِهِ أَبُوهُ يَحْمِلُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ اشْهَدْ أَنِّي قَدْ نَحَلْتُ النُّعْمَانَ مِنْ مَالِي كَذَا وَكَذَا ‏.‏ قَالَ ‏ "‏ كُلَّ بَنِيكَ نَحَلْتَ مِثْلَ الَّذِي نَحَلْتَ النُّعْمَانَ ‏"‏ ‏.‏\hadithno{3679}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that An-Nu'man said that his father took him to the Prophet and said:"Bear witness that I have given An-Nu'man such and such of my wealth as a gift." He said: "Have you given all your children a present like that which you have given to An-Nu'man?}}
\hadithdefcmd{nasai}{3680}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ عَبْدِ الْوَهَّابِ، قَالَ حَدَّثَنَا دَاوُدُ، عَنْ عَامِرٍ، عَنِ النُّعْمَانِ، أَنَّ أَبَاهُ، أَتَى بِهِ النَّبِيَّ صلى الله عليه وسلم يُشْهِدُ عَلَى نُحْلٍ نَحَلَهُ إِيَّاهُ ‏.‏ فَقَالَ ‏"‏ أَكُلَّ وَلَدِكَ نَحَلْتَ مِثْلَ مَا نَحَلْتَهُ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَلاَ أَشْهَدُ عَلَى شَىْءٍ أَلَيْسَ يَسُرُّكَ أَنْ يَكُونُوا إِلَيْكَ فِي الْبِرِّ سَوَاءً ‏"‏ ‏.‏ قَالَ بَلَى ‏.‏ قَالَ ‏"‏ فَلاَ إِذًا ‏"‏ ‏.‏\hadithno{3680}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from An-Nu'man that his father brought him to the Prophet to bear witness to a present that he gave to him. He said:"Have you given all your children a present like that which you have given to him?" He said: "No." He said: "I will not bear witness to anything. Will it not please you if they were all to treat you with equal respect?" He said: "Of course." He said: "Then no (I will not do it)}}
\hadithdefcmd{nasai}{3681}{أَخْبَرَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنَا أَبُو حَيَّانَ، عَنِ الشَّعْبِيِّ، قَالَ حَدَّثَنِي النُّعْمَانُ بْنُ بَشِيرٍ الأَنْصَارِيُّ، أَنَّ أُمَّهُ ابْنَةَ رَوَاحَةَ، سَأَلَتْ أَبَاهُ بَعْضَ الْمَوْهِبَةِ مِنْ مَالِهِ لاِبْنِهَا فَالْتَوَى بِهَا سَنَةً ثُمَّ بَدَا لَهُ فَوَهَبَهَا لَهُ فَقَالَتْ لاَ أَرْضَى حَتَّى تُشْهِدَ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمَّ هَذَا ابْنَةَ رَوَاحَةَ قَاتَلَتْنِي عَلَى الَّذِي وَهَبْتُ لَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا بَشِيرُ أَلَكَ وَلَدٌ سِوَى هَذَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَفَكُلُّهُمْ وَهَبْتَ لَهُمْ مِثْلَ الَّذِي وَهَبْتَ لاِبْنِكَ هَذَا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَلاَ تُشْهِدْنِي إِذًا فَإِنِّي لاَ أَشْهَدُ عَلَى جَوْرٍ ‏"‏ ‏.‏\hadithno{3681}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{An-Nu'man bin Bashir Al-Ansari narrated that his mother, the daughter of Rawahah, asked his father to give some of his wealth to her son. He deferred that for a year, then he decided to give it to him. She said:"I will not be pleased until you ask the Messenger of Allah to bear witness." He said: "O Messenger of Allah, the mother of this boy, the daughter of Rawahah, insisted that I give a gift to him." The Messenger of Allah said: "O Bashir, do you have any other children besides this one?" He said: "Yes." The Messenger of Allah said: "Have you given all of them a gift like that which you have given to this son of yours?" He said: "No." The Messenger of Allah said: "Then do not ask me to bear witness, for I will not bear witness to unfairness}}
\hadithdefcmd{nasai}{3682}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَعْلَى، قَالَ حَدَّثَنَا أَبُو حَيَّانَ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ، قَالَ سَأَلَتْ أُمِّي أَبِي بَعْضَ الْمَوْهِبَةِ فَوَهَبَهَا لِي فَقَالَتْ لاَ أَرْضَى حَتَّى أُشْهِدَ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ فَأَخَذَ أَبِي بِيَدِي وَأَنَا غُلاَمٌ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمَّ هَذَا ابْنَةَ رَوَاحَةَ طَلَبَتْ مِنِّي بَعْضَ الْمَوْهِبَةِ وَقَدْ أَعْجَبَهَا أَنْ أُشْهِدَكَ عَلَى ذَلِكَ ‏.‏ قَالَ ‏"‏ يَا بَشِيرُ أَلَكَ ابْنٌ غَيْرُ هَذَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَوَهَبْتَ لَهُ مِثْلَ مَا وَهَبْتَ لِهَذَا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَلاَ تُشْهِدْنِي إِذًا فَإِنِّي لاَ أَشْهَدُ عَلَى جَوْرٍ ‏"‏ ‏.‏\hadithno{3682}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that An-Nu'man said:"My mother asked my father for a gift and he gave it to me. She said: 'I will not be contented until you ask the Messenger of Allah to bear witness.' So my father took me by the hand, as I was still a boy, and went to the Messenger of Allah. He said: 'O Messenger of Allah, the mother of this boy, the daughter of Rawahah, asked me for a gift, and she wanted me to ask you to bear witness to that.' He said: 'O Bashir, do you have any other child apart from this one?' He said: 'Yes.' He said: 'Have you given him gifts like that which you have given to this one?' He said: 'No.' He said: 'Then do not ask me to bear witness, for I will not bear witness to unfairness}}
\hadithdefcmd{nasai}{3683}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ عَامِرٍ، قَالَ أُخْبِرْتُ أَنَّ بَشِيرَ بْنَ سَعْدٍ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ امْرَأَتِي عَمْرَةَ بِنْتَ رَوَاحَةَ أَمَرَتْنِي أَنْ أَتَصَدَّقَ عَلَى ابْنِهَا نُعْمَانَ بِصَدَقَةٍ وَأَمَرَتْنِي أَنْ أُشْهِدَكَ عَلَى ذَلِكَ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلْ لَكَ بَنُونَ سِوَاهُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَأَعْطَيْتَهُمْ مِثْلَ مَا أَعْطَيْتَ لِهَذَا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَلاَ تُشْهِدْنِي عَلَى جَوْرٍ ‏"‏ ‏.‏\hadithno{3683}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Amir said:"I was told that Bashir bin Sa'd came to the Messenger of Allah and said: 'O Messenger of Allah, my wife 'Amrah bint Rawahah told me to give a gift to her son Nu'man, and she told me to ask you to bear witness to that.' The Prophet said: 'Do you have any other children?' He said: 'Yes.' He said: 'Have you given them something like that which you have given to this one?' He said: 'No.' He said: 'Then do not ask me to bear witness to unfairness}}
\hadithdefcmd{nasai}{3684}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا زَكَرِيَّا، عَنْ عَامِرٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عُتْبَةَ بْنِ مَسْعُودٍ، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ أَنْبَأَنَا حِبَّانُ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ زَكَرِيَّا، عَنِ الشَّعْبِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ رَجُلاً، جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم - وَقَالَ مُحَمَّدٌ أَتَى النَّبِيَّ صلى الله عليه وسلم - فَقَالَ إِنِّي تَصَدَّقْتُ عَلَى ابْنِي بِصَدَقَةٍ فَاشْهَدْ فَقَالَ ‏"‏ هَلْ لَكَ وَلَدٌ غَيْرُهُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ أَعْطَيْتَهُمْ كَمَا أَعْطَيْتَهُ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ أَأَشْهَدُ عَلَى جَوْرٍ ‏"‏ ‏.‏\hadithno{3684}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah bin 'Utbah bin Mas'ud that a man came to the Prophet and said:"I have given a gift to my son, so bear witness." He said: "Do you have any other children?" He said: "Yes." He said: "Have you given them something like that which you have given him?" He said: "No." He said: "Shall I bear witness to unfairness?}}
\hadithdefcmd{nasai}{3685}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، عَنْ يَحْيَى، عَنْ فِطْرٍ، قَالَ حَدَّثَنِي مُسْلِمُ بْنُ صُبَيْحٍ، قَالَ سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ، يَقُولُ ذَهَبَ بِي أَبِي إِلَى النَّبِيِّ صلى الله عليه وسلم يُشْهِدُهُ عَلَى شَىْءٍ أَعْطَانِيهِ فَقَالَ ‏ "‏ أَلَكَ وَلَدٌ غَيْرُهُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ وَصَفَّ بِيَدِهِ بِكَفِّهِ أَجْمَعَ كَذَا أَلاَ سَوَّيْتَ بَيْنَهُمْ ‏.‏\hadithno{3685}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{An-Nu'man bin Bashir said:"My father took me to the Prophet to ask him to bear witness to something that he had given to me. He said: 'Do you have any other children?' He said: 'Yes.' He gestured with his hand held horizontally like this, (saying): 'Why don't you treat them all equally?}}
\hadithdefcmd{nasai}{3686}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ أَنْبَأَنَا حِبَّانُ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ فِطْرٍ، عَنْ مُسْلِمِ بْنِ صُبَيْحٍ، قَالَ سَمِعْتُ النُّعْمَانَ، يَقُولُ وَهُوَ يَخْطُبُ انْطَلَقَ بِي أَبِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يُشْهِدُهُ عَلَى عَطِيَّةٍ أَعْطَانِيهَا فَقَالَ ‏"‏ هَلْ لَكَ بَنُونَ سِوَاهُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ سَوِّ بَيْنَهُمْ ‏"‏ ‏.‏\hadithno{3686}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{An-Nu'man said, when he was delivering a Khutbah:"My father took me to the Messenger of Allah to ask him to bear witness to a gift that he had given me. He said: 'Do you have any other children besides him?' He said: 'Yes.' He said: 'Treat them equally}}
\hadithdefcmd{nasai}{3687}{أَخْبَرَنَا يَعْقُوبُ بْنُ سُفْيَانَ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ حَاجِبِ بْنِ الْمُفَضَّلِ بْنِ الْمُهَلَّبِ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ، يَخْطُبُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اعْدِلُوا بَيْنَ أَبْنَائِكُمُ اعْدِلُوا بَيْنَ أَبْنَائِكُمْ ‏"‏ ‏.‏\hadithno{3687}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{An-Nu'man bin Bashir delivered a Khutbah and said:"The Messenger of Allah said: 'Treat your children fairly, treat your children fairly}}
