% Auto-generated chapter 21 for bukhari
% Hadiths in this chapter: 27

\hadithdefcmd{bukhari}{1198}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ أَنَّهُ أَخْبَرَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّهُ بَاتَ عِنْدَ مَيْمُونَةَ أُمِّ الْمُؤْمِنِينَ ـ رضى الله عنها ـ وَهْىَ خَالَتُهُ ـ قَالَ فَاضْطَجَعْتُ عَلَى عَرْضِ الْوِسَادَةِ، وَاضْطَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَهْلُهُ فِي طُولِهَا، فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى انْتَصَفَ اللَّيْلُ أَوْ قَبْلَهُ بِقَلِيلٍ أَوْ بَعْدَهُ بِقَلِيلٍ، ثُمَّ اسْتَيْقَظَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَلَسَ، فَمَسَحَ النَّوْمَ عَنْ وَجْهِهِ بِيَدِهِ، ثُمَّ قَرَأَ الْعَشْرَ آيَاتٍ خَوَاتِيمَ سُورَةِ آلِ عِمْرَانَ، ثُمَّ قَامَ إِلَى شَنٍّ مُعَلَّقَةٍ فَتَوَضَّأَ مِنْهَا، فَأَحْسَنَ وُضُوءَهُ، ثُمَّ قَامَ يُصَلِّي‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ ـ رضى الله عنهما ـ فَقُمْتُ فَصَنَعْتُ مِثْلَ مَا صَنَعَ، ثُمَّ ذَهَبْتُ فَقُمْتُ إِلَى جَنْبِهِ، فَوَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ الْيُمْنَى عَلَى رَأْسِي، وَأَخَذَ بِأُذُنِي الْيُمْنَى يَفْتِلُهَا بِيَدِهِ، فَصَلَّى رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ أَوْتَرَ، ثُمَّ اضْطَجَعَ حَتَّى جَاءَهُ الْمُؤَذِّنُ، فَقَامَ فَصَلَّى رَكْعَتَيْنِ خَفِيفَتَيْنِ، ثُمَّ خَرَجَ فَصَلَّى الصُّبْحَ‏.‏\hadithno{1198}\hadithtrans{Narrated Kuraib Maula Ibn `Abbas:`Abdullah bin `Abbas said that he had passed a night in the house of Maimuna the mother of the faithful believers , who was his aunt. He said, "I slept across the bed, and Allah's Messenger (ﷺ) along with his wife slept lengthwise. Allah's Messenger (ﷺ) slept till midnight or slightly before or after it. Then Allah's Apostle woke up, sat, and removed the traces of sleep by rubbing his hands over his face. Then he recited the last ten verses of Surat-Al `Imran (2). Then he went towards a hanging leather watercontainer and performed a perfect ablution and then stood up for prayer." `Abdullah bin `Abbas added, "I got up and did the same as Allah's Messenger (ﷺ) had done and then went and stood by his side. Allah's Messenger (ﷺ) then put his right hand over my head and caught my right ear and twisted it. He offered two rak`at, then two rak`at, then two rak`at, then two rak`at, then two rak`at, then two rak`at and then offered one rak`a witr. Then he lay down till the Mu'adh-dhin came and then he prayed two light rak`at and went out and offered the early morning (Fajr) prayer}}
\hadithdefcmd{bukhari}{1199}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا ابْنُ فُضَيْلٍ، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ كُنَّا نُسَلِّمُ عَلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ فِي الصَّلاَةِ فَيَرُدُّ عَلَيْنَا، فَلَمَّا رَجَعْنَا مِنْ عِنْدِ النَّجَاشِيِّ سَلَّمْنَا عَلَيْهِ فَلَمْ يَرُدَّ عَلَيْنَا وَقَالَ ‏ "‏ إِنَّ فِي الصَّلاَةِ شُغْلاً ‏"‏‏.‏\hadithno{1199}\hadithtrans{Narrated `Abdullah:We used to greet the Prophet (ﷺ) while he was praying and he used to answer our greetings. When we returned from An-Najashi (the ruler of Ethiopia), we greeted him, but he did not answer us (during the prayer) and (after finishing the prayer) he said, "In the prayer one is occupied (with a more serious matter)}}
\hadithdefcmd{bukhari}{1199p2}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا هُرَيْمُ بْنُ سُفْيَانَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ‏.‏\hadithno{1199.2}\hadithtrans{Narrated `Abdullah:The same as No. 290. from the Prophet}}
\hadithdefcmd{bukhari}{1200}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عِيسَى ـ هُوَ ابْنُ يُونُسَ ـ عَنْ إِسْمَاعِيلَ، عَنِ الْحَارِثِ بْنِ شُبَيْلٍ، عَنْ أَبِي عَمْرٍو الشَّيْبَانِيِّ، قَالَ قَالَ لِي زَيْدُ بْنُ أَرْقَمَ إِنْ كُنَّا لَنَتَكَلَّمُ فِي الصَّلاَةِ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم، يُكَلِّمُ أَحَدُنَا صَاحِبَهُ بِحَاجَتِهِ حَتَّى نَزَلَتْ ‏\{‏حَافِظُوا عَلَى الصَّلَوَاتِ‏\}‏ الآيَةَ، فَأُمِرْنَا بِالسُّكُوتِ‏.‏\hadithno{1200}\hadithtrans{Narrated Zaid bin Arqam:In the lifetime of the Prophet (ﷺ) we used to speak while praying, and one of us would tell his needs to his companions, till the verse, 'Guard strictly your prayers (2.238) was revealed. After that we were ordered to remain silent while praying}}
\hadithdefcmd{bukhari}{1201}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلٍ ـ رضى الله عنه ـ قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم يُصْلِحُ بَيْنَ بَنِي عَمْرِو بْنِ عَوْفٍ، وَحَانَتِ الصَّلاَةُ، فَجَاءَ بِلاَلٌ أَبَا بَكْرٍ ـ رضى الله عنهما ـ فَقَالَ حُبِسَ النَّبِيُّ صلى الله عليه وسلم فَتَؤُمُّ النَّاسَ قَالَ نَعَمْ إِنْ شِئْتُمْ‏.‏ فَأَقَامَ بِلاَلٌ الصَّلاَةَ، فَتَقَدَّمَ أَبُو بَكْرٍ ـ رضى الله عنه ـ فَصَلَّى، فَجَاءَ النَّبِيُّ صلى الله عليه وسلم يَمْشِي فِي الصُّفُوفِ يَشُقُّهَا شَقًّا حَتَّى قَامَ فِي الصَّفِّ الأَوَّلِ، فَأَخَذَ النَّاسُ بِالتَّصْفِيحِ‏.‏ قَالَ سَهْلٌ هَلْ تَدْرُونَ مَا التَّصْفِيحُ هُوَ التَّصْفِيقُ‏.‏ وَكَانَ أَبُو بَكْرٍ ـ رضى الله عنه ـ لاَ يَلْتَفِتُ فِي صَلاَتِهِ، فَلَمَّا أَكْثَرُوا الْتَفَتَ فَإِذَا النَّبِيُّ صلى الله عليه وسلم فِي الصَّفِّ، فَأَشَارَ إِلَيْهِ مَكَانَكَ‏.‏ فَرَفَعَ أَبُو بَكْرٍ يَدَيْهِ، فَحَمِدَ اللَّهَ، ثُمَّ رَجَعَ الْقَهْقَرَى وَرَاءَهُ وَتَقَدَّمَ النَّبِيُّ صلى الله عليه وسلم فَصَلَّى‏.‏\hadithno{1201}\hadithtrans{Narrated Sahl bin Sa`d:The Prophet (ﷺ) went out to affect a reconciliation between the tribes of Bani `Amr bin `Auf and the time of the prayer became due; Bilal went to Abu Bakr and said, "The Prophet (ﷺ) is detained. Will you lead the people in the prayer?" Abu Bakr replied, "Yes, if you wish." So Bilal pronounced the Iqama and Abu Bakr led the prayer. In the meantime the Prophet (ﷺ) came crossing the rows (of the praying people) till he stood in the first row and the people started clapping. Abu Bakr never looked hither and thither during the prayer but when the people clapped too much, he looked back and saw the Prophet (ﷺ) in the (first) row. The Prophet (ﷺ) waved him to remain at his place, but Abu Bakr raised both his hands and sent praises to Allah and then retreated and the Prophet (ﷺ) went forward and led the prayer. (See Hadith No)}}
\hadithdefcmd{bukhari}{1202}{حَدَّثَنَا عَمْرُو بْنُ عِيسَى، حَدَّثَنَا أَبُو عَبْدِ الصَّمَدِ عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنَا حُصَيْنُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ كُنَّا نَقُولُ التَّحِيَّةُ فِي الصَّلاَةِ وَنُسَمِّي، وَيُسَلِّمُ بَعْضُنَا عَلَى بَعْضٍ، فَسَمِعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ قُولُوا التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ، السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ، السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ، أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ، فَإِنَّكُمْ إِذَا فَعَلْتُمْ ذَلِكَ فَقَدْ سَلَّمْتُمْ عَلَى كُلِّ عَبْدٍ لِلَّهِ صَالِحٍ فِي السَّمَاءِ وَالأَرْضِ ‏"‏‏.‏\hadithno{1202}\hadithtrans{Narrated `Abdullah bin Mas`ud:We used to say the greeting, name and greet each other in the prayer. Allah's Messenger (ﷺ) heard it and said:--"Say, 'at-tahiyyatu lil-lahi was-salawatu wat-taiyibatu . Assalamu 'Alaika aiyuha-n-Nabiyu warahmatu- l-lahi wa-barakatuhu. \_ Assalamu alaina wa-'ala 'ibadi-l-lahi as-salihin.. Ashhadu an la ilaha illa-l-lah wa ashhadu anna Muhammadan `Abdu hu wa Rasuluh. (All the compliments are for Allah and all the prayers and all the good things (are for Allah). Peace be on you, O Prophet, and Allah's mercy and blessings (are on you). And peace be on us and on the good (pious) worshipers of Allah. I testify that none has the right to be worshipped but Allah and that Muhammad is His slave and Apostle.) So, when you have said this, then you have surely sent the greetings to every good (pious) worshipper of Allah, whether he be in the Heaven or on the Earth}}
\hadithdefcmd{bukhari}{1203}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ التَّسْبِيحُ لِلرِّجَالِ وَالتَّصْفِيقُ لِلنِّسَاءِ ‏"‏‏.‏\hadithno{1203}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The saying 'Subhan Allah' is for men and clapping is for women." (If something happens in the prayer, the men can invite the attention of the Imam by saying "Subhan Allah". And women, by clapping their hands)}}
\hadithdefcmd{bukhari}{1204}{حَدَّثَنَا يَحْيَى، أَخْبَرَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ التَّسْبِيحُ لِلرِّجَالِ وَالتَّصْفِيحُ لِلنِّسَاءِ ‏"‏‏.‏\hadithno{1204}\hadithtrans{Narrated Sahl bin Sa`d:The Prophet (ﷺ) said, "The saying 'Subhan Allah' is for men and clapping is for women}}
\hadithdefcmd{bukhari}{1205}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ يُونُسُ قَالَ الزُّهْرِيُّ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ الْمُسْلِمِينَ، بَيْنَا هُمْ فِي الْفَجْرِ يَوْمَ الاِثْنَيْنِ، وَأَبُو بَكْرٍ ـ رضى الله عنه ـ يُصَلِّي بِهِمْ فَفَجَأَهُمُ النَّبِيُّ صلى الله عليه وسلم قَدْ كَشَفَ سِتْرَ حُجْرَةِ عَائِشَةَ ـ رضى الله عنها ـ فَنَظَرَ إِلَيْهِمْ، وَهُمْ صُفُوفٌ، فَتَبَسَّمَ يَضْحَكُ، فَنَكَصَ أَبُو بَكْرٍ ـ رضى الله عنه ـ عَلَى عَقِبَيْهِ، وَظَنَّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يُرِيدُ أَنْ يَخْرُجَ إِلَى الصَّلاَةِ، وَهَمَّ الْمُسْلِمُونَ أَنْ يَفْتَتِنُوا فِي صَلاَتِهِمْ فَرَحًا بِالنَّبِيِّ صلى الله عليه وسلم حِينَ رَأَوْهُ، فَأَشَارَ بِيَدِهِ أَنْ أَتِمُّوا، ثُمَّ دَخَلَ الْحُجْرَةَ وَأَرْخَى السِّتْرَ، وَتُوُفِّيَ ذَلِكَ الْيَوْمَ‏.‏\hadithno{1205}\hadithtrans{Narrated Anas bin Malik: While Abu Bakr was leading the people in the morning prayer on a Monday, the Prophet (ﷺ) came towards them suddenly having lifted the curtain of 'Aisha's house, and looked at them as they were standing in rows and smiled. Abu Bakr tried to come back thinking that Allah's Apostle wanted to come out for the prayer. The attention of the Muslims was diverted from the prayer because they were delighted to see the Prophet. The Prophet (ﷺ) waved his hand to them to complete their prayer, then he went back into the room and let down the curtain. The Prophet expired on that very day}}
\hadithdefcmd{bukhari}{1206}{وَقَالَ اللَّيْثُ حَدَّثَنِي جَعْفَرٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، قَالَ قَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَادَتِ امْرَأَةٌ ابْنَهَا، وَهْوَ فِي صَوْمَعَةٍ قَالَتْ يَا جُرَيْجُ‏.‏ قَالَ اللَّهُمَّ أُمِّي وَصَلاَتِي‏.‏ قَالَتْ يَا جُرَيْجُ‏.‏ قَالَ اللَّهُمَّ أُمِّي وَصَلاَتِي‏.‏ قَالَتْ يَا جُرَيْجُ‏.‏ قَالَ اللَّهُمَّ أُمِّي وَصَلاَتِي‏.‏ قَالَتِ اللَّهُمَّ لاَ يَمُوتُ جُرَيْجٌ حَتَّى يَنْظُرَ فِي وَجْهِ الْمَيَامِيسِ‏.‏ وَكَانَتْ تَأْوِي إِلَى صَوْمَعَتِهِ رَاعِيَةٌ تَرْعَى الْغَنَمَ فَوَلَدَتْ فَقِيلَ لَهَا مِمَّنْ هَذَا الْوَلَدُ قَالَتْ مِنْ جُرَيْجٍ نَزَلَ مِنْ صَوْمَعَتِهِ‏.‏ قَالَ جُرَيْجٌ أَيْنَ هَذِهِ الَّتِي تَزْعُمُ أَنَّ وَلَدَهَا لِي قَالَ يَا بَابُوسُ مَنْ أَبُوكَ قَالَ رَاعِي الْغَنَمِ ‏"‏‏.‏\hadithno{1206}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) said, "A woman called her son while he was in his hermitage and said, 'O Juraij' He said, 'O Allah, my mother (is calling me) and (I am offering) my prayer (what shall I do)?' She again said, 'O Juraij!' He said again, 'O Allah ! My mother (is calling me) and (I am offering) my prayer (what shall I do)?' She again said, 'O Juraij' He again said, 'O Allah! My mother (is calling me) and (I am offering) my prayer. (What shall I do?)' She said, 'O Allah! Do not let Juraij die till he sees the faces of prostitutes.' A shepherdess used to come by his hermitage for grazing her sheep and she gave birth to a child. She was asked whose child that was, and she replied that it was from Juraij and that he had come out from his hermitage. Juraij said, 'Where is that woman who claims that her child is from me?' (When she was brought to him along with the child), Juraij asked the child, 'O Babus, who is your father?' The child replied, 'The shepherd.' " (See Hadith No 662. Vol)}}
\hadithdefcmd{bukhari}{1207}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، قَالَ حَدَّثَنِي مُعَيْقِيبٌ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ فِي الرَّجُلِ يُسَوِّي التُّرَابَ حَيْثُ يَسْجُدُ قَالَ ‏ "‏ إِنْ كُنْتَ فَاعِلاً فَوَاحِدَةً ‏"‏‏.‏\hadithno{1207}\hadithtrans{Narrated Mu'aiqib:The Prophet (ﷺ) talked about a man leveling the earth on prostrating, and said, "If you have to do so, then do it once}}
\hadithdefcmd{bukhari}{1208}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ، حَدَّثَنَا غَالِبٌ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ كُنَّا نُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم فِي شِدَّةِ الْحَرِّ، فَإِذَا لَمْ يَسْتَطِعْ أَحَدُنَا أَنْ يُمَكِّنَ وَجْهَهُ مِنَ الأَرْضِ بَسَطَ ثَوْبَهُ فَسَجَدَ عَلَيْهِ‏.‏\hadithno{1208}\hadithtrans{Narrated Anas bin Malik:We used to pray with the Prophet (ﷺ) in scorching heat, and if someone of us could not put his face on the earth (because of the heat) then he would spread his clothes and prostrate over them}}
\hadithdefcmd{bukhari}{1209}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي النَّضْرِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كُنْتُ أَمُدُّ رِجْلِي فِي قِبْلَةِ النَّبِيِّ صلى الله عليه وسلم وَهُوَ يُصَلِّي، فَإِذَا سَجَدَ غَمَزَنِي فَرَفَعْتُهَا، فَإِذَا قَامَ مَدَدْتُهَا‏.‏\hadithno{1209}\hadithtrans{Narrated Aisha:I used to stretch my legs towards the Qibla of the Prophet (ﷺ) while he was praying; whenever he prostrated he touched me, and I would withdraw my legs, and whenever he stood up, I would restretch my legs}}
\hadithdefcmd{bukhari}{1210}{حَدَّثَنَا مَحْمُودٌ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى صَلاَةً قَالَ ‏"‏ إِنَّ الشَّيْطَانَ عَرَضَ لِي، فَشَدَّ عَلَىَّ لِيَقْطَعَ الصَّلاَةَ عَلَىَّ، فَأَمْكَنَنِي اللَّهُ مِنْهُ، فَذَعَتُّهُ، وَلَقَدْ هَمَمْتُ أَنْ أُوثِقَهُ إِلَى سَارِيَةٍ حَتَّى تُصْبِحُوا فَتَنْظُرُوا إِلَيْهِ فَذَكَرْتُ قَوْلَ سُلَيْمَانَ ـ عَلَيْهِ السَّلاَمُ ـ رَبِّ هَبْ لِي مُلْكًا لاَ يَنْبَغِي لأَحَدٍ مِنْ بَعْدِي‏.‏ فَرَدَّهُ اللَّهُ خَاسِيًا ‏"‏‏.‏ ثُمَّ قَالَ النَّضْرُ بْنُ شُمَيْلٍ فَذَعَتُّهُ بِالذَّالِ أَىْ خَنَقْتُهُ وَفَدَعَّتُّهُ مِنْ قَوْلِ اللَّهِ ‏\{‏يَوْمَ يُدَعُّونَ‏\}‏ أَىْ يُدْفَعُونَ وَالصَّوَابُ، فَدَعَتُّهُ إِلاَّ أَنَّهُ كَذَا قَالَ بِتَشْدِيدِ الْعَيْنِ وَالتَّاءِ‏.‏\hadithno{1210}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) once offered the prayer and said, "Satan came in front of me and tried to interrupt my prayer, but Allah gave me an upper hand on him and I choked him. No doubt, I thought of tying him to one of the pillars of the mosque till you get up in the morning and see him. Then I remembered the statement of Prophet Solomon, 'My Lord ! Bestow on me a kingdom such as shall not belong to any other after me.' Then Allah made him (Satan) return with his head down (humiliated)}}
\hadithdefcmd{bukhari}{1211}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا الأَزْرَقُ بْنُ قَيْسٍ، قَالَ كُنَّا بِالأَهْوَازِ نُقَاتِلُ الْحَرُورِيَّةَ، فَبَيْنَا أَنَا عَلَى جُرُفِ نَهَرٍ إِذَا رَجُلٌ يُصَلِّي، وَإِذَا لِجَامُ دَابَّتِهِ بِيَدِهِ فَجَعَلَتِ الدَّابَّةُ تُنَازِعُهُ، وَجَعَلَ يَتْبَعُهَا ـ قَالَ شُعْبَةُ ـ هُوَ أَبُو بَرْزَةَ الأَسْلَمِيُّ ـ فَجَعَلَ رَجُلٌ مِنَ الْخَوَارِجِ يَقُولُ اللَّهُمَّ افْعَلْ بِهَذَا الشَّيْخِ‏.‏ فَلَمَّا انْصَرَفَ الشَّيْخُ قَالَ إِنِّي سَمِعْتُ قَوْلَكُمْ، وَإِنِّي غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم سِتَّ غَزَوَاتٍ أَوْ سَبْعَ غَزَوَاتٍ وَثَمَانِيًا، وَشَهِدْتُ تَيْسِيرَهُ، وَإِنِّي أَنْ كُنْتُ أَنْ أُرَاجِعَ مَعَ دَابَّتِي أَحَبُّ إِلَىَّ مِنْ أَنْ أَدَعَهَا تَرْجِعُ إِلَى مَأْلَفِهَا فَيَشُقَّ عَلَىَّ‏.‏\hadithno{1211}\hadithtrans{Narrated Al-Azraq bin Qais:We were at Al-Ahwaz fighting the Al-Haruriya (tribe). While I was at the bank of a river a man was praying and the reins of his animal were in his hands and the animal was struggling and he was following the animal. (Shu`ba, a sub-narrator, said that man was Abu Barza Al-Aslami). A man from the Khawarij said, "O Allah! Be harsh to this sheik." And when the sheik (Abu Barza) finished his prayer, he said, "I heard your remark. No doubt, I participated with Allah's Messenger (ﷺ) in six or seven or eight holy battles and saw his leniency, and no doubt, I would rather retain my animal than let it return to its stable, as it would cause me much trouble}}
\hadithdefcmd{bukhari}{1212}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، قَالَ قَالَتْ عَائِشَةُ خَسَفَتِ الشَّمْسُ، فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَقَرَأَ سُورَةً طَوِيلَةً، ثُمَّ رَكَعَ فَأَطَالَ، ثُمَّ رَفَعَ رَأْسَهُ، ثُمَّ اسْتَفْتَحَ بِسُورَةٍ أُخْرَى، ثُمَّ رَكَعَ حَتَّى قَضَاهَا وَسَجَدَ، ثُمَّ فَعَلَ ذَلِكَ فِي الثَّانِيَةِ، ثُمَّ قَالَ ‏ "‏ إِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ، فَإِذَا رَأَيْتُمْ ذَلِكَ فَصَلُّوا حَتَّى يُفْرَجَ عَنْكُمْ، لَقَدْ رَأَيْتُ فِي مَقَامِي هَذَا كُلَّ شَىْءٍ وُعِدْتُهُ، حَتَّى لَقَدْ رَأَيْتُنِي أُرِيدُ أَنْ آخُذَ قِطْفًا مِنَ الْجَنَّةِ حِينَ رَأَيْتُمُونِي جَعَلْتُ أَتَقَدَّمُ، وَلَقَدْ رَأَيْتُ جَهَنَّمَ يَحْطِمُ بَعْضُهَا بَعْضًا حِينَ رَأَيْتُمُونِي تَأَخَّرْتُ، وَرَأَيْتُ فِيهَا عَمْرَو بْنَ لُحَىٍّ وَهُوَ الَّذِي سَيَّبَ السَّوَائِبَ ‏"‏‏.‏\hadithno{1212}\hadithtrans{Narrated `Aisha:Once the sun eclipsed and Allah's Messenger (ﷺ) stood up for the prayer and recited a very long Sura and then bowed for a long while and then raised his head and started reciting another Sura. Then he bowed, and after finishing, he prostrated and did the same in the second rak`a and then said, "These (lunar and solar eclipses) are two of the signs of Allah and if you see them, pray till the eclipse is over. No doubt, while standing at this place I saw everything promised to me by Allah and I saw (Paradise) and I wanted to pluck a bunch (of grapes) therefrom, at the time when you saw me stepping forward. No doubt, I saw Hell with its different parts destroying each other when you saw me retreating and in it I saw `Amr bin Luhai who started the tradition of freeing animals (set them free) in the name of idols}}
\hadithdefcmd{bukhari}{1213}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى نُخَامَةً فِي قِبْلَةِ الْمَسْجِدِ، فَتَغَيَّظَ عَلَى أَهْلِ الْمَسْجِدِ وَقَالَ ‏ "‏ إِنَّ اللَّهَ قِبَلَ أَحَدِكُمْ، فَإِذَا كَانَ فِي صَلاَتِهِ، فَلاَ يَبْزُقَنَّ ـ أَوْ قَالَ ـ لاَ يَتَنَخَّمَنَّ ‏"‏‏.‏ ثُمَّ نَزَلَ فَحَتَّهَا بِيَدِهِ‏.‏ وَقَالَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ إِذَا بَزَقَ أَحَدُكُمْ فَلْيَبْزُقْ عَلَى يَسَارِهِ‏.‏\hadithno{1213}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) saw some sputum on the wall facing the Qibla of the mosque and became furious with the people of the mosque and said, "During the prayer, Allah is in front of everyone of you and so he should not spit (or said, 'He should not expectorate')." Then he got down and scratched the sputum with his hand. Ibn `Umar said (after narrating), "If anyone of you has to spit during the prayer, he should spit to his left}}
\hadithdefcmd{bukhari}{1214}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانَ فِي الصَّلاَةِ فَإِنَّهُ يُنَاجِي رَبَّهُ، فَلاَ يَبْزُقَنَّ بَيْنَ يَدَيْهِ وَلاَ عَنْ يَمِينِهِ، وَلَكِنْ عَنْ شِمَالِهِ تَحْتَ قَدَمِهِ الْيُسْرَى ‏"‏‏.‏\hadithno{1214}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "Whenever anyone of you is in prayer, he is speaking in private to his Lord and so he should neither spit in front of him nor on his right side but to his left side under his left foot}}
\hadithdefcmd{bukhari}{1215}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه ـ قَالَ كَانَ النَّاسُ يُصَلُّونَ مَعَ النَّبِيِّ صلى الله عليه وسلم وَهُمْ عَاقِدُو أُزْرِهِمْ مِنَ الصِّغَرِ عَلَى رِقَابِهِمْ، فَقِيلَ لِلنِّسَاءِ ‏ "‏ لاَ تَرْفَعْنَ رُءُوسَكُنَّ حَتَّى يَسْتَوِيَ الرِّجَالُ جُلُوسًا ‏"‏‏.‏\hadithno{1215}\hadithtrans{Narrated Sahl bin Sa`d:The people used to offer the prayer with the Prophet (ﷺ) with their waist-sheets tied round their necks because of the shortness of the sheets and the women were ordered not to lift their heads till the men had sat straight}}
\hadithdefcmd{bukhari}{1216}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنْتُ أُسَلِّمُ عَلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ فِي الصَّلاَةِ فَيَرُدُّ عَلَىَّ، فَلَمَّا رَجَعْنَا سَلَّمْتُ عَلَيْهِ فَلَمْ يَرُدَّ عَلَىَّ وَقَالَ ‏ "‏ إِنَّ فِي الصَّلاَةِ شُغْلاً ‏"‏‏.‏\hadithno{1216}\hadithtrans{Narrated `Abdullah:I used to greet the Prophet (ﷺ) while he was in prayer and he would return my greeting, but when we returned (from Ethiopia) I greeted the Prophet (while he was praying) but he did not return the greeting, and (after finishing the prayer) he said, "In the prayer one is occupied (with a more serious matter)}}
\hadithdefcmd{bukhari}{1217}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا كَثِيرُ بْنُ شِنْظِيرٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَاجَةٍ لَهُ فَانْطَلَقْتُ، ثُمَّ رَجَعْتُ وَقَدْ قَضَيْتُهَا، فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَسَلَّمْتُ عَلَيْهِ، فَلَمْ يَرُدَّ عَلَىَّ، فَوَقَعَ فِي قَلْبِي مَا اللَّهُ أَعْلَمُ بِهِ فَقُلْتُ فِي نَفْسِي لَعَلَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَجَدَ عَلَىَّ أَنِّي أَبْطَأْتُ عَلَيْهِ، ثُمَّ سَلَّمْتُ عَلَيْهِ فَلَمْ يَرُدَّ عَلَىَّ، فَوَقَعَ فِي قَلْبِي أَشَدُّ مِنَ الْمَرَّةِ الأُولَى، ثُمَّ سَلَّمْتُ عَلَيْهِ فَرَدَّ عَلَىَّ فَقَالَ ‏ "‏ إِنَّمَا مَنَعَنِي أَنْ أَرُدَّ عَلَيْكَ أَنِّي كُنْتُ أُصَلِّي ‏"‏‏.‏ وَكَانَ عَلَى رَاحِلَتِهِ مُتَوَجِّهًا إِلَى غَيْرِ الْقِبْلَةِ‏.‏\hadithno{1217}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) sent me for some job and when I had finished it I returned and came to the Prophet (ﷺ) and greeted him but he did not return my greeting. So I felt so sorry that only Allah knows it and I said to myself,, 'Perhaps Allah's Messenger (ﷺ) is angry because I did not come quickly, then again I greeted him but he did not reply. I felt even more sorry than I did the first time. Again I greeted him and he returned the greeting and said, "The thing which prevented me from returning the greeting was that I was praying." And at that time he was on his Rahila and his face was not towards the Qibla}}
\hadithdefcmd{bukhari}{1218}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه ـ قَالَ بَلَغَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَّ بَنِي عَمْرِو بْنِ عَوْفٍ بِقُبَاءٍ كَانَ بَيْنَهُمْ شَىْءٌ، فَخَرَجَ يُصْلِحُ بَيْنَهُمْ فِي أُنَاسٍ مِنْ أَصْحَابِهِ، فَحُبِسَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَحَانَتِ الصَّلاَةُ، فَجَاءَ بِلاَلٌ إِلَى أَبِي بَكْرٍ ـ رضى الله عنهما ـ فَقَالَ يَا أَبَا بَكْرٍ، إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ حُبِسَ وَقَدْ حَانَتِ الصَّلاَةُ، فَهَلْ لَكَ أَنْ تَؤُمَّ النَّاسَ قَالَ نَعَمْ إِنْ شِئْتَ‏.‏ فَأَقَامَ بِلاَلٌ الصَّلاَةَ، وَتَقَدَّمَ أَبُو بَكْرٍ ـ رضى الله عنه ـ فَكَبَّرَ لِلنَّاسِ، وَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْشِي فِي الصُّفُوفِ يَشُقُّهَا شَقًّا، حَتَّى قَامَ فِي الصَّفِّ، فَأَخَذَ النَّاسُ فِي التَّصْفِيحِ‏.‏ قَالَ سَهْلٌ التَّصْفِيحُ هُوَ التَّصْفِيقُ‏.‏ قَالَ وَكَانَ أَبُو بَكْرٍ ـ رضى الله عنه ـ لاَ يَلْتَفِتُ فِي صَلاَتِهِ، فَلَمَّا أَكْثَرَ النَّاسُ الْتَفَتَ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَشَارَ إِلَيْهِ، يَأْمُرُهُ أَنْ يُصَلِّيَ، فَرَفَعَ أَبُو بَكْرٍ ـ رضى الله عنه ـ يَدَهُ، فَحَمِدَ اللَّهَ، ثُمَّ رَجَعَ الْقَهْقَرَى وَرَاءَهُ حَتَّى قَامَ فِي الصَّفِّ، وَتَقَدَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى لِلنَّاسِ، فَلَمَّا فَرَغَ أَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏"‏ يَا أَيُّهَا النَّاسُ مَا لَكُمْ حِينَ نَابَكُمْ شَىْءٌ فِي الصَّلاَةِ أَخَذْتُمْ بِالتَّصْفِيحِ إِنَّمَا التَّصْفِيحُ لِلنِّسَاءِ، مَنْ نَابَهُ شَىْءٌ فِي صَلاَتِهِ فَلْيَقُلْ سُبْحَانَ اللَّهِ ‏"‏‏.‏ ثُمَّ الْتَفَتَ إِلَى أَبِي بَكْرٍ ـ رضى الله عنه ـ فَقَالَ ‏"‏ يَا أَبَا بَكْرٍ، مَا مَنَعَكَ أَنْ تُصَلِّيَ لِلنَّاسِ حِينَ أَشَرْتُ إِلَيْكَ ‏"‏‏.‏ قَالَ أَبُو بَكْرٍ مَا كَانَ يَنْبَغِي لاِبْنِ أَبِي قُحَافَةَ أَنْ يُصَلِّيَ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{1218}\hadithtrans{Narrated Sahl bin Sa`d:The news about the differences amongst the people of Bani `Amr bin `Auf at Quba reached Allah's Apostle and so he went to them along with some of his companions to affect a reconciliation. Allah's Apostle was delayed there and the time for the prayer became due. Bilal came to Abu Bakr and said, "O Abu Bakr! Allah's Messenger (ﷺ) is detained (there) and the time for the prayer is due. Will you lead the people in prayer?" Abu Bakr replied, "Yes, if you wish." So Bilal pronounced the Iqama and Abu Bakr went forward and the people said Takbir. In the meantime, Allah's Messenger (ﷺ) came piercing through the rows till he stood in the (first) row and the people started clapping. Abu Bakr, would never look hither and thither during the prayer but when the people clapped much he looked back and saw Allah's Messenger (ﷺ). The Prophet (ﷺ) beckoned him to carry on. Abu Bakr raised both his hands, praised Allah and retreated till he stood in the row and Allah's Messenger (ﷺ) went forward and led the people in the prayer. When he had finished the prayer, he addressed the people and said, "O people! Why did you start clapping when something happened to you in the prayer? Clapping is for women. Whenever one is confronted with something unusual in the prayer one should say, 'Subhan Allah'." Then the Prophet looked towards Abu Bakr and asked, "What prevented you from leading the prayer when I beckoned you to carry on?" Abu Bakr replied, "It does not befit the son of Al Quhafa to lead the prayer in the presence of Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{1219}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ نُهِيَ عَنِ الْخَصْرِ، فِي الصَّلاَةِ‏.‏ وَقَالَ هِشَامٌ وَأَبُو هِلاَلٍ عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1219}\hadithtrans{Narrated Abu Huraira:It was forbidden to keep the hands on the hips during the prayer. (This is narrated by Abu Huraira from the Prophet)}}
\hadithdefcmd{bukhari}{1220}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا مُحَمَّدٌ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ نُهِيَ أَنْ يُصَلِّيَ الرَّجُلُ مُخْتَصِرًا‏.‏\hadithno{1220}\hadithtrans{Narrated Abu Huraira:It was forbidden to pray with the hands over one's hips}}
\hadithdefcmd{bukhari}{1221}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا عُمَرُ ـ هُوَ ابْنُ سَعِيدٍ ـ قَالَ أَخْبَرَنِي ابْنُ أَبِي مُلَيْكَةَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ ـ رضى الله عنه ـ قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم الْعَصْرَ، فَلَمَّا سَلَّمَ قَامَ سَرِيعًا دَخَلَ عَلَى بَعْضِ نِسَائِهِ، ثُمَّ خَرَجَ وَرَأَى مَا فِي وُجُوهِ الْقَوْمِ مِنْ تَعَجُّبِهِمْ لِسُرْعَتِهِ فَقَالَ ‏ "‏ ذَكَرْتُ وَأَنَا فِي الصَّلاَةِ تِبْرًا عِنْدَنَا، فَكَرِهْتُ أَنْ يُمْسِيَ أَوْ يَبِيتَ عِنْدَنَا فَأَمَرْتُ بِقِسْمَتِهِ ‏"‏‏.‏\hadithno{1221}\hadithtrans{Narrated `Uqba bin Al-Harith:I offered the `Asr prayer with the Prophet (ﷺ) and after finishing the prayer with Taslim he got up quickly and went to some of his wives and then came out. He noticed the signs of astonishment on the faces of the people caused by his speed. He then said, "I remembered while I was in my prayer that a piece of gold was Lying in my house and I disliked that it should remain with us throughout the night, and so I have ordered it to be distributed}}
\hadithdefcmd{bukhari}{1222}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ جَعْفَرٍ، عَنِ الأَعْرَجِ، قَالَ قَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أُذِّنَ بِالصَّلاَةِ أَدْبَرَ الشَّيْطَانُ لَهُ ضُرَاطٌ حَتَّى لاَ يَسْمَعَ التَّأْذِينَ، فَإِذَا سَكَتَ الْمُؤَذِّنُ أَقْبَلَ، فَإِذَا ثُوِّبَ أَدْبَرَ فَإِذَا سَكَتَ أَقْبَلَ، فَلاَ يَزَالُ بِالْمَرْءِ يَقُولُ لَهُ اذْكُرْ مَا لَمْ يَكُنْ يَذْكُرُ حَتَّى لاَ يَدْرِي كَمْ صَلَّى ‏"‏‏.‏ قَالَ أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ إِذَا فَعَلَ أَحَدُكُمْ ذَلِكَ فَلْيَسْجُدْ سَجْدَتَيْنِ وَهُوَ قَاعِدٌ‏.‏ وَسَمِعَهُ أَبُو سَلَمَةَ مِنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه‏.‏\hadithno{1222}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When the Adhan for the prayer is pronounced, then Satan takes to his heels passing wind so that he may not hear the Adhan and when the Mu'adh-dhin finishes, he comes back; and when the Iqama is pronounced he again takes to his heels and when it is finished, he again comes back and continues reminding the praying person of things that he used not to remember when not in prayer till he forgets how much he has prayed." Abu Salama bin `Abdur-Rahman said, "If anyone of you has such a thing (forgetting the number of rak`at he has prayed) he should perform two prostrations of Sahu (i.e. forgetfulness) while sitting." Abu Salama narrates this from Abu Huraira}}
\hadithdefcmd{bukhari}{1223}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، قَالَ أَخْبَرَنِي ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، قَالَ قَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ النَّاسُ أَكْثَرَ أَبُو هُرَيْرَةَ، فَلَقِيتُ رَجُلاً فَقُلْتُ بِمَ قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْبَارِحَةَ فِي الْعَتَمَةِ فَقَالَ لاَ أَدْرِي‏.‏ فَقُلْتُ لَمْ تَشْهَدْهَا قَالَ بَلَى‏.‏ قُلْتُ لَكِنْ أَنَا أَدْرِي، قَرَأَ سُورَةَ كَذَا وَكَذَا‏.‏\hadithno{1223}\hadithtrans{Narrated Abu Huraira:People say that I narrate too many narrations of the Prophet; once I met a man (during the lifetime of the Prophet) and asked him, "Which Sura did Allah's Messenger (ﷺ) recite yesterday in the `Isha' prayer?" He said, "I do not know." I said, "Did you not attend the prayer?" He said, "Yes, (I did)." I said, "I know. He recited such and such Sura}}
