% Auto-generated chapter 26 for tirmidhi
% Hadiths in this chapter: 37

\hadithdefcmd{tirmidhi}{1861}{حَدَّثَنَا أَبُو زَكَرِيَّا، يَحْيَى بْنُ دُرُسْتَ الْبَصْرِيُّ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ مُسْكِرٍ خَمْرٌ وَكُلُّ مُسْكِرٍ حَرَامٌ وَمَنْ شَرِبَ الْخَمْرَ فِي الدُّنْيَا فَمَاتَ وَهُوَ يُدْمِنُهَا لَمْ يَشْرَبْهَا فِي الآخِرَةِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَابْنِ عَبَّاسٍ وَعُبَادَةَ وَأَبِي مَالِكٍ الأَشْعَرِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَاهُ مَالِكُ بْنُ أَنَسٍ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ مَوْقُوفًا فَلَمْ يَرْفَعْهُ ‏.‏\hadithno{1861}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar: That the Messenger of Allah (ﷺ) said: "Every intoxicant is Khamr, and every intoxicant is unlawful. Whoever drinks Khamr in this world, and dies continuing it, he will not drink it in the Hereafter. He said: There are narrations on this topic from Abu Hurairah, Abu Sa'eed, 'Abdullah bin 'Amr, 'Ubadah, Abu Malik Al-Ash'ari, and Ibn 'Abbas. [Abu 'Eisa said:] The Hadith of Ibn 'Umar is a Hasan Sahih Hadith. It has been reported through other routes from Nafi', from Ibn 'Umar, from the Prophet (ﷺ). Malik bin Anas reported it from Nafi' from Ibn 'Umar in Mawquf - not Marfu' form}}
\hadithdefcmd{tirmidhi}{1862}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ أَبِيهِ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ شَرِبَ الْخَمْرَ لَمْ يَقْبَلِ اللَّهُ لَهُ صَلاَةً أَرْبَعِينَ صَبَاحًا فَإِنْ تَابَ تَابَ اللَّهُ عَلَيْهِ فَإِنْ عَادَ لَمْ يَقْبَلِ اللَّهُ لَهُ صَلاَةً أَرْبَعِينَ صَبَاحًا فَإِنْ تَابَ تَابَ اللَّهُ عَلَيْهِ فَإِنْ عَادَ لَمْ يَقْبَلِ اللَّهُ لَهُ صَلاَةً أَرْبَعِينَ صَبَاحًا فَإِنْ تَابَ تَابَ اللَّهُ عَلَيْهِ فَإِنْ عَادَ الرَّابِعَةَ لَمْ يَقْبَلِ اللَّهُ لَهُ صَلاَةً أَرْبَعِينَ صَبَاحًا فَإِنْ تَابَ لَمْ يَتُبِ اللَّهُ عَلَيْهِ وَسَقَاهُ مِنْ نَهْرِ الْخَبَالِ ‏"‏ ‏.‏ قِيلَ يَا أَبَا عَبْدِ الرَّحْمَنِ وَمَا نَهْرُ الْخَبَالِ قَالَ نَهْرٌ مِنْ صَدِيدِ أَهْلِ النَّارِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَقَدْ رُوِيَ نَحْوُ هَذَا عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1862}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdullah bin 'Umar: That the Messenger of Allah (ﷺ) said: "Whoever drinks Khamr, Salat is not accepted from him for forty days. If he repents, then Allah will accept his repentance. It he returns to it, then Allah will not accept his Salat for forty days. If he repents, then Allah will accept his repentance. If he returns to it, then Allah will not accepts his Salat for forty days. If he repents, then Allah will accept his repentance. If he returns to it a fourth time, Allah will not accept his Salat for forty days, and if he were to repent, Allah would not accept his repentance, and he will be given to drink from the river of Al-Khabal." They said: "O Aby 'Abdur-Rahman! What is the river of Al-Khabal?" He said: "A river of the pus from the inhabitants of the Fire." [Abu 'Eisa said:] This Hadith is Hasan. Similar to this has been reported from 'Abdullah bin 'Amr and Ibn 'Abbas from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1863}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ عَنِ الْبِتْعِ فَقَالَ ‏ "‏ كُلُّ شَرَابٍ أَسْكَرَ فَهُوَ حَرَامٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1863}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Aishah: That the Prophet (ﷺ) was asked about Bit' so he said: "All drinks that intoxicate are unlawful." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1864}{حَدَّثَنَا عُبَيْدُ بْنُ أَسْبَاطِ بْنِ مُحَمَّدٍ الْقُرَشِيُّ الْكُوفِيُّ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَعَلِيٍّ وَابْنِ مَسْعُودٍ وَأَنَسٍ وَأَبِي سَعِيدٍ وَأَبِي مُوسَى وَالأَشَجِّ الْعَصَرِيِّ وَدَيْلَمَ وَمَيْمُونَةَ وَابْنِ عَبَّاسٍ وَقَيْسِ بْنِ سَعْدٍ وَالنُّعْمَانِ بْنِ بَشِيرٍ وَمُعَاوِيَةَ وَوَائِلِ بْنِ حُجْرٍ وَقُرَّةَ الْمُزَنِيِّ وَعَبْدِ اللَّهِ بْنِ مُغَفَّلٍ وَأُمِّ سَلَمَةَ وَبُرَيْدَةَ وَأَبِي هُرَيْرَةَ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَكِلاَهُمَا صَحِيحٌ رَوَاهُ غَيْرُ وَاحِدٍ عَنْ مُحَمَّدِ بْنِ عَمْرٍو عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَعَنْ أَبِي سَلَمَةَ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1864}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn 'Umar: That the Prophet (ﷺ) "Every intoxicant is unlawful." He said: There are narrations on this topic from 'Umar, 'Ali, Ibn Mas'ud, Anas, Abu Sa'eed, Abu Musa, Al-Ashajj, Al-Asri', Dailam, Maimunah, 'Aishah, Ibn 'Abbas, Qais bin Sa'd, An-Nu'man bin Bashir, Mu'awiyah, 'Abdullah bin Mughaffal, Umm Salamah, Buraidah, Abu Hurairah, Wa'il bin Hujr, and Qurrah Al-Muzani. [Abu 'Eisa said:] This Hadith is Hasan. Similar was reported from Abu Salamah, from Abu Hurairah, from the Prophet (ﷺ). Both of these are Sahih. More than one narrator reported similarly from Muhammad bin 'Amr, from Abu Salamah, from Abu Hurairah, from the Prophet (ﷺ), and from Abu Salamah, from Ibn 'Umar, from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1865}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، وَحَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ دَاوُدَ بْنِ بَكْرِ بْنِ أَبِي الْفُرَاتِ، عَنِ ابْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا أَسْكَرَ كَثِيرُهُ فَقَلِيلُهُ حَرَامٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَعْدٍ وَعَائِشَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَابْنِ عُمَرَ وَخَوَّاتِ بْنِ جُبَيْرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ جَابِرٍ ‏.‏\hadithno{1865}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir bin ‘Abdullah : That the Messenger of Allah (ﷺ) said: "Whatever a lot of it intoxicates, a little of it is unlawful." He said: There are narrations on this topic from Sa'd, 'Aishah, 'Abdullah bin 'Amr, Ibn 'Umar, and Khawwat bin Jubair. [Abu 'Eisa said:] This Hadith is Hasan Gharib as a narration of Jabir}}
\hadithdefcmd{tirmidhi}{1866}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ مَهْدِيِّ بْنِ مَيْمُونٍ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ الْمَعْنَى، وَاحِدٌ، عَنْ أَبِي عُثْمَانَ الأَنْصَارِيِّ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُلُّ مُسْكِرٍ حَرَامٌ مَا أَسْكَرَ الْفَرَقُ مِنْهُ فَمِلْءُ الْكَفِّ مِنْهُ حَرَامٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى قَالَ أَحَدُهُمَا فِي حَدِيثِهِ ‏"‏ الْحُسْوَةُ مِنْهُ حَرَامٌ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَاهُ لَيْثُ بْنُ أَبِي سُلَيْمٍ وَالرَّبِيعُ بْنُ صَبِيحٍ عَنْ أَبِي عُثْمَانَ الأَنْصَارِيِّ نَحْوَ رِوَايَةِ مَهْدِيِّ بْنِ مَيْمُونٍ ‏.‏ وَأَبُو عُثْمَانَ الأَنْصَارِيُّ اسْمُهُ عَمْرُو بْنُ سَالِمٍ وَيُقَالُ عُمَرُ بْنُ سَالِمٍ أَيْضًا ‏.‏\hadithno{1866}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Aishah: That the Messenger of Allah (ﷺ) said: "Every intoxicant is unlawful. Whatever a Faraq of it intoxicates, then a handful of it is unlawful." [Abu 'Eisa said:] One of them said in his Hadith: "A sip of it is unlawful." He said: This Hadith is Hasan. Al-Laith bin Abi Sulaim and Ar-Rabi' bin Sabih reported similar to the narration of Mahdi bin Maimun from Abu 'Uthman Al-Ansari. Abu 'Uthman Al-Ansari's (a narrator in this chain) name is 'Amr bin Salim, and they say: "Umar bin Salim" (as well)}}
\hadithdefcmd{tirmidhi}{1867}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا ابْنُ عُلَيَّةَ، وَيَزِيدُ بْنُ هَارُونَ، قَالاَ أَخْبَرَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ طَاوُسٍ، أَنَّ رَجُلاً، أَتَى ابْنَ عُمَرَ فَقَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ نَبِيذِ الْجَرِّ فَقَالَ نَعَمْ ‏.‏ فَقَالَ طَاوُسٌ وَاللَّهِ إِنِّي سَمِعْتُهُ مِنْهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ أَبِي أَوْفَى وَأَبِي سَعِيدٍ وَسُوَيْدٍ وَعَائِشَةَ وَابْنِ الزُّبَيْرِ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1867}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Sulaiman At-Taimi: From Tawus, that a man came to Ibn 'Umar and said: "Did the Messenger of Allah (ﷺ) prohibit Nabidh prepared in eartherware vessels?" He said: "Yes" So Tawus said: "I heard that from him, by Allah." He said: There are narrations on this topic from Ibn Abu Awfa, Abu Sa'eed, Suwaid, 'Aishah, Ibn Az-Zubair, and Ibn 'Abbas. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1868}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ زَاذَانَ، يَقُولُ سَأَلْتُ ابْنَ عُمَرَ عَمَّا نَهَى عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الأَوْعِيَةِ أَخْبِرْنَاهُ بِلُغَتِكُمْ وَفَسِّرْهُ لَنَا بِلُغَتِنَا ‏.‏ فَقَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْحَنْتَمَةِ وَهِيَ الْجَرَّةُ وَنَهَى عَنِ الدُّبَّاءِ وَهِيَ الْقَرْعَةُ وَنَهَى عَنِ النَّقِيرِ وَهُوَ أَصْلُ النَّخْلِ يُنْقَرُ نَقْرًا أَوْ يُنْسَحُ نَسْحًا وَنَهَى عَنِ الْمُزَفَّتِ وَهِيَ الْمُقَيَّرُ وَأَمَرَ أَنْ يُنْبَذَ فِي الأَسْقِيَةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَعَلِيٍّ وَابْنِ عَبَّاسٍ وَأَبِي سَعِيدٍ وَأَبِي هُرَيْرَةَ وَعَبْدِ الرَّحْمَنِ بْنِ يَعْمُرَ وَسَمُرَةَ وَأَنَسٍ وَعَائِشَةَ وَعِمْرَانَ بْنِ حُصَيْنٍ وَعَائِذِ بْنِ عَمْرٍو وَالْحَكَمِ الْغِفَارِيِّ وَمَيْمُونَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1868}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Zadhan: "I asked Ibn 'Umar about what containers the Messenger of Allah (ﷺ) prohibited. He informed us in your language, and he explained it to us in our language. He said: "The Messenger of Allah (ﷺ) prohibited Al-Hantamah, and it is an earthenware container, and he prohibited Ad-Dubba', and it is gourd, and he prohibited An-Naqir, and it is the trunk of a date-palm that is hollowed out or carved, and he prohibited Al-Muzaffat, and it is coated with pitch. And he ordered that Nabidh be prepared in water-skins." He said: There are narrations on this topic from 'Umar, 'Ali, Ibn 'Abbas, Abu Sa'eed, Abu Hurairah, 'Abdur-Rahman bin Ya'mur, Samurah, Anas, 'Aishah, 'Imran bin Husain, 'A'idh bin 'Amr, Al-Hakam Al-Ghifari, and Maimunah. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1869}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَالْحَسَنُ بْنُ عَلِيٍّ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالُوا حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي كُنْتُ نَهَيْتُكُمْ عَنِ الظُّرُوفِ وَإِنَّ ظَرْفًا لاَ يُحِلُّ شَيْئًا وَلاَ يُحَرِّمُهُ وَكُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1869}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Sulaiman bin Buraidah: From his father, that the Messenger of Allah (ﷺ) said: "I had indeed forbidden you from using containers, but the container does not make anything lawful nor unlawful, rather every intoxicant is unlawful." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1870}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الظُّرُوفِ فَشَكَتْ إِلَيْهِ الأَنْصَارُ فَقَالُوا لَيْسَ لَنَا وِعَاءٌ ‏.‏ قَالَ ‏ "‏ فَلاَ إِذًا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَأَبِي سَعِيدٍ وَأَبِي هُرَيْرَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1870}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir bin ‘Abdullah : "The Messenger of Allah (ﷺ) prohibited using (certain) containers. So the Ansar complained about that to him. They said: 'We will have no vessels!' so he said: 'If so then use them.'" He said: There are narrations on this topic from Ibn Mas'ud, Abu Hurairah, Abu Sa'eed, and 'Abdullah bin 'Amr. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1871}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنِ الْحَسَنِ الْبَصْرِيِّ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتْ كُنَّا نَنْبِذُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فِي سِقَاءٍ يُوكَأُ فِي أَعْلاَهُ لَهُ عَزْلاَءُ نَنْبِذُهُ غُدْوَةً وَيَشْرَبُهُ عِشَاءً وَنَنْبِذُهُ عِشَاءً وَيَشْرَبُهُ غُدْوَةً ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَأَبِي سَعِيدٍ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ يُونُسَ بْنِ عُبَيْدٍ إِلاَّ مِنْ هَذَا الْوَجْهِ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ عَائِشَةَ أَيْضًا ‏.‏\hadithno{1871}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Aishah: "We would prepare Nabidh for the Messenger of Allah (ﷺ) in a water-skin which was fastened at the top and it has a small hole. We would prepare Nabidh in it during the morning, and drink it during the evening. And we would prepare Nabidh in it during the evening and drink it during the morning." He said: There are narrations on this topic from Jabir, Abu Sa'eed, and Ibn 'Abbas. [Abu 'Eisa said:] This Hadith is Gharib, we do not know of it as a narration of Yunus bin 'Ubaid except through this route. This Hadith has also been reported through routes other than this from 'Aishah}}
\hadithdefcmd{tirmidhi}{1872}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا إِسْرَائِيلُ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُهَاجِرٍ، عَنْ عَامِرٍ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنَ الْحِنْطَةِ خَمْرًا وَمِنَ الشَّعِيرِ خَمْرًا وَمِنَ التَّمْرِ خَمْرًا وَمِنَ الزَّبِيبِ خَمْرًا وَمِنَ الْعَسَلِ خَمْرًا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{1872}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated An-Nu'man bin Bashir: That the Messenger of Allah (ﷺ) said: "Indeed Khamr comes from wheat, Khamr comes from barely, Khamr comes from dates, Khamr comes from rasins, and Khamr comes from honey." He said: There are narrations on this topic from Abu Hurairah. [Abu 'Eisa said:] This Hadith is Gharib}}
\hadithdefcmd{tirmidhi}{1873}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ إِسْرَائِيلَ، نَحْوَهُ ‏.‏ وَرَوَى أَبُو حَيَّانَ التَّيْمِيُّ، هَذَا الْحَدِيثَ عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، قَالَ إِنَّ مِنَ الْحِنْطَةِ خَمْرًا فَذَكَرَ هَذَا الْحَدِيثَ ‏.‏\hadithno{1873}\hadithgrade{Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Umar: "Indeed Khamr comes from wheat." And he mentioned this Hadith}}
\hadithdefcmd{tirmidhi}{1874}{حَدَّثَنَا بِذَلِكَ، أَحْمَدُ بْنُ مَنِيعٍ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ أَبِي حَيَّانَ التَّيْمِيِّ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، إِنَّ مِنَ الْحِنْطَةِ خَمْرًا بِهَذَا ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ ‏.‏ وَقَالَ عَلِيُّ بْنُ الْمَدِينِيِّ قَالَ يَحْيَى بْنُ سَعِيدٍ لَمْ يَكُنْ إِبْرَاهِيمُ بْنُ مُهَاجِرٍ بِالْقَوِيِّ فِي الْحَدِيثِ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ أَيْضًا عَنِ الشَّعْبِيِّ عَنِ النُّعْمَانِ بْنِ بَشِيرٍ ‏.‏\hadithno{1874}\hadithgrade{Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Umar bin Al-Khattab: "Indeed Khamr comes from wheat." [After mentioning this, he said:] and this is more correct than the narration of Ibrahim bin Muhajir (no. 1872). 'Ali bin Al-Madini said: "Yahya bin Sa'eed said: 'Ibrahim bin Al-Muhajir is not strong [in Hadith].'" And it has also been reported through other rotes from Ash-Sha'bi, from An-Nu'man bin Bashir}}
\hadithdefcmd{tirmidhi}{1875}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، حَدَّثَنَا الأَوْزَاعِيُّ، وَعِكْرِمَةُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا أَبُو كَثِيرٍ السُّحَيْمِيُّ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْخَمْرُ مِنْ هَاتَيْنِ الشَّجَرَتَيْنِ النَّخْلَةُ وَالْعِنَبَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو كَثِيرٍ السُّحَيْمِيُّ هُوَ الْغُبَرِيُّ وَاسْمُهُ يَزِيدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ غُفَيْلَةَ ‏.‏ وَرَوَى شُعْبَةُ عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ هَذَا الْحَدِيثَ ‏.‏\hadithno{1875}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Kathir As-Suhaimi: That he heard Abu Hurairah saying that the Messenger of Allah (ﷺ) said: "Khamr comes from these two trees (plants): The datepalm and the grape (vine)." [Abu 'Eisa said:] This Hadith is Hasan Sahih. Abu Kathir As-Suhaimi is Al-Ghubari, and his name is Yazid bin 'Abdur-Rahman bin Ghufailah and Shu'bah reported this Hadith from 'Ikrimah bin 'Ammar}}
\hadithdefcmd{tirmidhi}{1876}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يُنْبَذَ الْبُسْرُ وَالرُّطَبُ جَمِيعًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1876}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jabir bin ‘Abdullah : "The Messenger of Allah (ﷺ) prohibited making Nabidh from unripend dates and fresh dates together. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1877}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْبُسْرِ وَالتَّمْرِ أَنْ يُخْلَطَ بَيْنَهُمَا وَنَهَى عَنِ الزَّبِيبِ وَالتَّمْرِ أَنْ يُخْلَطَ بَيْنَهُمَا وَنَهَى عَنِ الْجِرَارِ أَنْ يُنْبَذَ فِيهَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَأَنَسٍ وَأَبِي قَتَادَةَ وَابْنِ عَبَّاسٍ وَأُمِّ سَلَمَةَ وَمَعْبَدِ بْنِ كَعْبٍ عَنْ أُمِّهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1877}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Sa'eed: "The Prophet (ﷺ) prohibited mixing of unripe dates and dates, and mixing of raisins and dates (for making Nabidh), and he prohibited the jars that Nabidh is made in." He said: There are narrations on this topic from Anas, Jabir, Abu Qatadah, Ibn 'Abbas, Umm Salamah, and Ma'bad bin Ka'b from his mother. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1878}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ سَمِعْتُ ابْنَ أَبِي لَيْلَى، يُحَدِّثُ أَنَّ حُذَيْفَةَ، اسْتَسْقَى فَأَتَاهُ إِنْسَانٌ بِإِنَاءٍ مِنْ فِضَّةٍ فَرَمَاهُ بِهِ وَقَالَ إِنِّي كُنْتُ قَدْ نَهَيْتُهُ فَأَبَى أَنْ يَنْتَهِيَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الشُّرْبِ فِي آنِيَةِ الْفِضَّةِ وَالذَّهَبِ وَلُبْسِ الْحَرِيرِ وَالدِّيبَاجِ وَقَالَ ‏ "‏ هِيَ لَهُمْ فِي الدُّنْيَا وَلَكُمْ فِي الآخِرَةِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ سَلَمَةَ وَالْبَرَاءِ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1878}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Shu'bah bin Al-Hakam: "I heard Ibn Abi Laila narrating that Hudhaifah asked for water, so someone brought him a vessel made from silver. He threw it, and said: 'I have indeed forbade him, but he refused to stop! Indeed the Messenger of Allah (ﷺ) prohibited drinking from silver and gold vessels, and from wearing silk and Dibaj, and he (ﷺ) said: "If is for them in this world, and for you in the Hereafter." He said: There are narrations on this topic from Umm Salamah, Al-Bara', and 'Aishah. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1879}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يَشْرَبَ الرَّجُلُ قَائِمًا ‏.‏ فَقِيلَ الأَكْلُ قَالَ ذَاكَ أَشَدُّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1879}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Qatadah: From Anas: "The Prophet (ﷺ) prohibited that a man should drink while standing." (Qatadah said:) So it was said: "And eating ?" He (Anas) said: "That is worse." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1880}{حَدَّثَنَا أَبُو السَّائِبِ، سَلْمُ بْنُ جُنَادَةَ الْكُوفِيُّ حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنَّا نَأْكُلُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَنَحْنُ نَمْشِي وَنَشْرَبُ وَنَحْنُ قِيَامٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ عُبَيْدِ اللَّهِ بْنِ عُمَرَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ ‏.‏ وَرَوَى عِمْرَانُ بْنُ حُدَيْرٍ هَذَا الْحَدِيثَ عَنْ أَبِي الْبَزَرِيِّ عَنِ ابْنِ عُمَرَ ‏.‏ وَأَبُو الْبُزَرِيُّ اسْمُهُ يَزِيدُ بْنُ عُطَارِدٍ ‏.‏\hadithno{1880}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn 'Umar: "We would eat during the time of the Messenger of Allah (ﷺ) while we were walking, and we would drink while we were standing." [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib as a narration of 'Ubaidullah bin 'Umar, from Nafi', from Ibn 'Umar. 'Imran bin Hudair reported this Hadith from Abu Al-Bazari, from Ibn 'Umar. Abu Al-Bazari's name is Yazid bin 'Utarid}}
\hadithdefcmd{tirmidhi}{1881}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَبِي مُسْلِمٍ الْجَذْمِيِّ، عَنِ الْجَارُودِ بْنِ الْمُعَلَّى، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الشُّرْبِ قَائِمًا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَأَبِي هُرَيْرَةَ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ حَسَنٌ ‏.‏ وَهَكَذَا رَوَى غَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ سَعِيدٍ عَنْ قَتَادَةَ عَنْ أَبِي مُسْلِمٍ عَنِ الْجَارُودِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرُوِيَ عَنْ قَتَادَةَ عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ عَنْ أَبِي مُسْلِمٍ عَنِ الْجَارُودِ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ ضَالَّةُ الْمُسْلِمِ حَرْقُ النَّارِ ‏"‏ ‏.‏ وَالْجَارُودُ هُوَ ابْنُ الْمُعَلَّى الْعَبْدِيُّ صَاحِبُ النَّبِيِّ صلى الله عليه وسلم وَيُقَالُ الْجَارُودُ بْنُ الْعَلاَءِ أَيْضًا وَالصَّحِيحُ ابْنُ الْمُعَلَّى ‏.‏\hadithno{1881}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Al-Jarud bin Al-'Ala': "The Prophet (ﷺ) prohibited drinking while standing." And there are narrations on this topic from Abu Sa'eed, Abu Hurairah, and Anas. And this Hadith is Hasan Gharib. This Hadith was reported from other narrators, from Sa'eed, from Qatadah, from Abu Muslim, from Al-Jarud, that the Prophet (ﷺ) said: "The Muslim's wandering (animal) stirs the Fire." Al-Jarud bin Al-Mu'alla is called Ibn Al-'Al' but what is correct is Al-Mu'alla}}
\hadithdefcmd{tirmidhi}{1882}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، وَمُغِيرَةُ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم شَرِبَ مِنْ زَمْزَمَ وَهُوَ قَائِمٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَسَعْدٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1882}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Abbas: "The Prophet (ﷺ) drank from Zamzam while he was standing." He said: There are narrations on this topic from 'Ali, Sa'd, 'Abdullah bin 'Amr and 'Aishah. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1883}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَشْرَبُ قَائِمًا وَقَاعِدًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1883}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr bin Shu'aib: From his father, from his grandfather who said: "I saw the Messenger of Allah (ﷺ) drinking while standing and sitting." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1884}{\hadithno{1884}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1884p2}{\hadithno{1884.2}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1885}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ يَزِيدَ بْنِ سِنَانٍ الْجَزَرِيِّ، عَنِ ابْنٍ لِعَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَشْرَبُوا وَاحِدًا كَشُرْبِ الْبَعِيرِ وَلَكِنِ اشْرَبُوا مَثْنَى وَثُلاَثَ وَسَمُّوا إِذَا أَنْتُمْ شَرِبْتُمْ وَاحْمَدُوا إِذَا أَنْتُمْ رَفَعْتُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَيَزِيدُ بْنُ سِنَانٍ الْجَزَرِيُّ هُوَ أَبُو فَرْوَةَ الرُّهَاوِيُّ ‏.‏\hadithno{1885}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas: That the Messenger of Allah (ﷺ) said: "Let none of you drink all at once like the camel. But drink two or three times, mentioning Allah's Name when you drink, and praising Him when you (finish)." [Abu 'Eisa said:] This Hadith is Gharib. Yazid bin Sinan Al-Jazari is Abu Farwah Ar-Ruhawi}}
\hadithdefcmd{tirmidhi}{1886}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ رِشْدِينَ بْنِ كُرَيْبٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا شَرِبَ تَنَفَّسَ مَرَّتَيْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ رِشْدِينَ بْنِ كُرَيْبٍ ‏.‏ قَالَ وَسَأَلْتُ أَبَا مُحَمَّدٍ عَبْدَ اللَّهِ بْنَ عَبْدِ الرَّحْمَنِ عَنْ رِشْدِينَ بْنِ كُرَيْبٍ قُلْتُ هُوَ أَقْوَى أَوْ مُحَمَّدُ بْنُ كُرَيْبٍ فَقَالَ مَا أَقْرَبَهُمَا وَرِشْدِينُ بْنُ كُرَيْبٍ أَرْجَحُهُمَا عِنْدِي ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ عَنْ هَذَا فَقَالَ مُحَمَّدُ بْنُ كُرَيْبٍ أَرْجَحُ مِنْ رِشْدِينَ بْنِ كُرَيْبٍ ‏.‏ وَالْقَوْلُ عِنْدِي مَا قَالَ أَبُو مُحَمَّدٍ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ رِشْدِينُ بْنُ كُرَيْبٍ أَرْجَحُ وَأَكْبَرُ وَقَدْ أَدْرَكَ ابْنَ عَبَّاسٍ وَرَآهُ وَهُمَا أَخَوَانِ وَعِنْدَهُمَا مَنَاكِيرُ ‏.‏\hadithno{1886}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas: "When the Prophet (ﷺ) drank, he would breathe two times." [Abu 'Eisa said:] This Hadith is Hasan Gharib, we do not know of it except as a narration of Rishdin bin Kuraib. He said: I asked [Abu Muhammad] 'Abdullah bin 'Abdur-Rahman about Rishdin bin Kuraib: "Is he stronger (in narration), or Muhammad bin Kuraib?" He said: "Neither are better to me. Rishdin bin Kuraib is preferred over them to me." He said: I asked Muhammad bin Isma'il about this, so he said: "Muhammad bin Kuraib is preferred over Rishdin bin Kuraib." To me, the correct view is what Abu Muhammad 'Abdullah bin 'Abdur-Rahman said: Rishdin bin Kuraib is more preferred and he is elder. He lived to see Ibn 'Abbas, and they are brothers, and they both have Munkar narrations in their reports}}
\hadithdefcmd{tirmidhi}{1887}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ أَيُّوبَ، وَهُوَ ابْنُ حَبِيبٍ أَنَّهُ سَمِعَ أَبَا الْمُثَنَّى الْجُهَنِيَّ، يَذْكُرُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ النَّفْخِ فِي الشُّرْبِ ‏.‏ فَقَالَ رَجُلٌ الْقَذَاةُ أَرَاهَا فِي الإِنَاءِ قَالَ ‏"‏ أَهْرِقْهَا ‏"‏ ‏.‏ قَالَ فَإِنِّي لاَ أَرْوَى مِنْ نَفَسٍ وَاحِدٍ قَالَ ‏"‏ فَأَبِنِ الْقَدَحَ إِذًا عَنْ فِيكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1887}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Sa’id Al Khudri : That the Prophet (ﷺ) prohibited blowing into the drink. A man said: "What about if one sees something floating in the vessel?" He said: "Spill it out (removing that)." He said: "I can not drink in one breath." He said: "Then remove the cup away from your mouth." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1888}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْكَرِيمِ الْجَزَرِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يُتَنَفَّسَ فِي الإِنَاءِ أَوْ يُنْفَخَ فِيهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1888}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn 'Abbas: "The Messenger of Allah (ﷺ) prohibited breathing in the vessel, or blowing into it." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1889}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا هِشَامٌ الدَّسْتَوَائِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا شَرِبَ أَحَدُكُمْ فَلاَ يَتَنَفَّسْ فِي الإِنَاءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1889}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah bin Abi Qatadah: From his father, that the Messenger of Allah (ﷺ) said: "When one of you drinks, then do not breathe into the vessel." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1890}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، رِوَايَةً أَنَّهُ نَهَى عَنِ اخْتِنَاثِ الأَسْقِيَةِ، ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ، وَابْنِ، عَبَّاسٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1890}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ubaidullah bin 'Abdullah narrated a report (of the Messenger of Allah (ﷺ) from Abu Sa'eed, that he prohibited bending the mouths of the water-skins. He said:There are narrations on this topic from Jabir, Ibn 'Abbas, and Abu Hurairah. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1891}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ، عَنْ عِيسَى بْنِ عَبْدِ اللَّهِ بْنِ أُنَيْسٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم قَامَ إِلَى قِرْبَةٍ مُعَلَّقَةٍ فَخَنَثَهَا ثُمَّ شَرِبَ مِنْ فِيهَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ سُلَيْمٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لَيْسَ إِسْنَادُهُ بِصَحِيحٍ ‏.‏ وَعَبْدُ اللَّهِ بْنُ عُمَرَ الْعُمَرِيُّ يُضَعَّفُ فِي الْحَدِيثِ وَلاَ أَدْرِي سَمِعَ مِنْ عِيسَى أَمْ لاَ\hadithno{1891}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Eisa bin 'Abdullah bin Unais: From his father who said: "I saw the Prophet (ﷺ) standing at a hanging water-skin, so he bent it, then drank from it." He said: There is something on this topic from Umm Salamah. [Abu 'Eisa said:] The chain of this Hadith is not Sahih. 'Abdullah bin 'Umar Al-'Umari (a narrator in the chain) was graded weak due to his memory, and I do not know if he heard from 'Eisa or not}}
\hadithdefcmd{tirmidhi}{1892}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ يَزِيدَ بْنِ يَزِيدَ بْنِ جَابِرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ، عَنْ جَدَّتِهِ، كَبْشَةَ قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَشَرِبَ مِنْ فِي قِرْبَةٍ مُعَلَّقَةٍ قَائِمًا فَقُمْتُ إِلَى فِيهَا فَقَطَعْتُهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَيَزِيدُ بْنُ يَزِيدَ بْنِ جَابِرٍ هُوَ أَخُو عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ وَهُوَ أَقْدَمُ مِنْهُ مَوْتًا ‏.‏\hadithno{1892}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Abdur-Rahman bin Abi 'Amrah: From his grandmother Kabshah who said: "The Messenger of Allah (ﷺ) entered upon me. He drank from a hanging water-skin while standing. So I went to its mouth and cut it off." [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib. Yazid bin Yazid bin Jabir is the brother of 'Adbur-Rahman bin Yazid bin Jabir. He died earlier than him}}
\hadithdefcmd{tirmidhi}{1893}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، قَالَ وَحَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِلَبَنٍ قَدْ شِيبَ بِمَاءٍ وَعَنْ يَمِينِهِ أَعْرَابِيٌّ وَعَنْ يَسَارِهِ أَبُو بَكْرٍ فَشَرِبَ ثُمَّ أَعْطَى الأَعْرَابِيَّ وَقَالَ ‏ "‏ الأَيْمَنَ فَالأَيْمَنَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَسَهْلِ بْنِ سَعْدٍ وَابْنِ عُمَرَ وَعَبْدِ اللَّهِ بْنِ بُسْرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1893}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik: "The Messenger of Allah (ﷺ) was brought some milk which was mixed with some water. On his right was a Bedouin and on his left was Abu Bakr. So he drank, then he gave it to the Bedouin and said: 'The right, then the right.'" He said: There are narrations on this topic from Ibn 'Abbas, Sahl bin Sa'd, Ibn 'Umar, and 'Abdullah bin Busr. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1894}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ، عَنْ أَبِي قَتَادَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ سَاقِي الْقَوْمِ آخِرُهُمْ شُرْبًا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ أَبِي أَوْفَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1894}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Qatadah: That the Prophet (ﷺ) said: "The one providing water for people is the last of them to drink." He said: There is something on this topic from Ibn Abi Awfa. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1895}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ أَحَبَّ الشَّرَابِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الْحُلْوُ الْبَارِدُ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رَوَى غَيْرُ وَاحِدٍ عَنِ ابْنِ عُيَيْنَةَ مِثْلَ هَذَا عَنْ مَعْمَرٍ عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ وَالصَّحِيحُ مَا رُوِيَ عَنِ الزُّهْرِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏\hadithno{1895}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Aishah: "The drink most beloved to the Messenger of Allah (ﷺ) was the sweet, cool drink." [Abu 'Eisa said:] This was reported similarly by more than one narrator from Ibn 'Uyainah from Ma'mar, from Az-Zuhri, from 'Urwah from 'Aishah. What is correct what was reported by Az-Zuhri from the Prophet (ﷺ) in Mursal form}}
\hadithdefcmd{tirmidhi}{1896}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا مَعْمَرٌ، وَيُونُسُ، عَنِ الزُّهْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ أَىُّ الشَّرَابِ أَطْيَبُ قَالَ ‏ "‏ الْحُلْوُ الْبَارِدُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَكَذَا رَوَى عَبْدُ الرَّزَّاقِ عَنْ مَعْمَرٍ عَنِ الزُّهْرِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً وَهَذَا أَصَحُّ مِنْ حَدِيثِ ابْنِ عُيَيْنَةَ رَحِمَهُ اللَّهُ ‏.‏\hadithno{1896}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Az-Zuhri: "The Prophet (ﷺ) was asked: 'Which drink is the best ?' He said: 'The sweet, cool drink." [Abu 'Eisa said:] This is how 'Abdur-Razzaq reported it from Ma'mar, from Az-Zuhri, from the Prophet (ﷺ) in Mursal form. This is more correct that the narration of Ibn 'Uyainah (no)}}
