% Auto-generated chapter 90 for bukhari
% Hadiths in this chapter: 28

\hadithdefcmd{bukhari}{6953}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ بْنِ وَقَّاصٍ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ يَخْطُبُ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَا أَيُّهَا النَّاسُ إِنَّمَا الأَعْمَالُ بِالنِّيَّةِ وَإِنَّمَا لاِمْرِئٍ مَا نَوَى، فَمَنْ كَانَتْ هِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ، فَهِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ، وَمَنْ هَاجَرَ إِلَى دُنْيَا يُصِيبُهَا أَوِ امْرَأَةٍ يَتَزَوَّجُهَا، فَهِجْرَتُهُ إِلَى مَا هَاجَرَ إِلَيْهِ ‏"‏‏.‏\hadithno{6953}\hadithtrans{Narrated `Umar bin Al-Khattab:The Prophet (ﷺ) said, 'O people! The reward of deeds depends upon the intentions, and every person will get the reward according to what he has intended. So, whoever emigrated for Allah and His Apostle, then his emigration was for Allah and His Apostle, and whoever emigrated to take worldly benefit or for a woman to marry, then his emigration was for what he emigrated for}}
\hadithdefcmd{bukhari}{6954}{حَدَّثَنِي إِسْحَاقُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقْبَلُ اللَّهُ صَلاَةَ أَحَدِكُمْ إِذَا أَحْدَثَ حَتَّى يَتَوَضَّأَ ‏"‏‏.‏\hadithno{6954}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah does not accept prayer of anyone of you if he does Hadath (passes wind) till he performs the ablution (anew)}}
\hadithdefcmd{bukhari}{6955}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا ثُمَامَةُ بْنُ عَبْدِ اللَّهِ بْنِ أَنَسٍ، أَنَّ أَنَسًا، حَدَّثَهُ أَنَّ أَبَا بَكْرٍ كَتَبَ لَهُ فَرِيضَةَ الصَّدَقَةِ الَّتِي فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَلاَ يُجْمَعُ بَيْنَ مُتَفَرِّقٍ وَلاَ يُفَرَّقُ بَيْنَ مُجْتَمِعٍ خَشْيَةَ الصَّدَقَةِ ‏"‏‏.‏\hadithno{6955}\hadithtrans{Narrated Anas:That Abu Bakr wrote for him, Zakat regulations which Allah's Messenger (ﷺ) had made compulsory, and wrote that one should neither collect various portions (of the property) nor divide the property into various portions in order to avoid paying Zakat}}
\hadithdefcmd{bukhari}{6956}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ أَبِي سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ، أَنَّ أَعْرَابِيًّا، جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ثَائِرَ الرَّأْسِ فَقَالَ يَا رَسُولَ اللَّهِ أَخْبِرْنِي مَاذَا فَرَضَ اللَّهُ عَلَىَّ مِنَ الصَّلاَةِ فَقَالَ ‏"‏ الصَّلَوَاتِ الْخَمْسَ، إِلاَّ أَنْ تَطَوَّعَ شَيْئًا ‏"‏‏.‏ فَقَالَ أَخْبِرْنِي بِمَا فَرَضَ اللَّهُ عَلَىَّ مِنَ الصِّيَامِ قَالَ ‏"‏ شَهْرَ رَمَضَانَ، إِلاَّ أَنْ تَطَوَّعَ شَيْئًا ‏"‏‏.‏ قَالَ أَخْبِرْنِي بِمَا فَرَضَ اللَّهُ عَلَىَّ مِنَ الزَّكَاةِ قَالَ فَأَخْبَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم شَرَائِعَ الإِسْلاَمِ‏.‏ قَالَ وَالَّذِي أَكْرَمَكَ لاَ أَتَطَوَّعُ شَيْئًا وَلاَ أَنْقُصُ مِمَّا فَرَضَ اللَّهُ عَلَىَّ شَيْئًا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَفْلَحَ إِنْ صَدَقَ ‏"‏‏.‏ أَوْ ‏"‏ دَخَلَ الْجَنَّةَ إِنْ صَدَقَ ‏"‏‏.‏ وَقَالَ بَعْضُ النَّاسِ فِي عِشْرِينَ وَمِائَةِ بَعِيرٍ حِقَّتَانِ‏.‏ فَإِنْ أَهْلَكَهَا مُتَعَمِّدًا، أَوْ وَهَبَهَا أَوِ احْتَالَ فِيهَا فِرَارًا مِنَ الزَّكَاةِ، فَلاَ شَىْءَ عَلَيْهِ‏.‏\hadithno{6956}\hadithtrans{Narrated Talha bin 'Ubaidullah:A bedouin with unkempt hair came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Tell me what Allah has enjoined on me as regards prayers." The Prophet (ﷺ) said, "You have to offer perfectly the five (compulsory) prayers in a day and a night (24 hrs.), except if you want to perform some extra optional prayers." The bedouin said, "Tell me what Allah has enjoined on me as regards fasting." The Prophet (ﷺ) said, "You have to observe fast during the month of Ramadan except if you fast some extra optional fast." The bedouin said, "Tell me what Allah has enjoined on me as regard Zakat." The Prophet (ﷺ) then told him the Islamic laws and regulations whereupon the bedouin said, "By Him Who has honored you, I will not perform any optional deeds of worship and I will not leave anything of what Allah has enjoined on me." Allah's Messenger (ﷺ) said, "He will be successful if he has told the truth (or he will enter Paradise if he said the truth)." And some people said, "The Zakat for one-hundred and twenty camels is two Hiqqas, and if the Zakat payer slaughters the camels intentionally or gives them as a present or plays some other trick in order to avoid the Zakat, then there is no harm (in it) for him}}
\hadithdefcmd{bukhari}{6958}{حَدَّثَنِي إِسْحَاقُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَكُونُ كَنْزُ أَحَدِكُمْ يَوْمَ الْقِيَامَةِ شُجَاعًا أَقْرَعَ، يَفِرُّ مِنْهُ صَاحِبُهُ فَيَطْلُبُهُ وَيَقُولُ أَنَا كَنْزُكَ‏.‏ قَالَ وَاللَّهِ لَنْ يَزَالَ يَطْلُبُهُ حَتَّى يَبْسُطَ يَدَهُ فَيُلْقِمَهَا فَاهُ ‏"‏‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا مَا رَبُّ النَّعَمِ لَمْ يُعْطِ حَقَّهَا، تُسَلَّطُ عَلَيْهِ يَوْمَ الْقِيَامَةِ، تَخْبِطُ وَجْهَهُ بِأَخْفَافِهَا ‏"‏‏.‏ وَقَالَ بَعْضُ النَّاسِ فِي رَجُلٍ لَهُ إِبِلٌ، فَخَافَ أَنْ تَجِبَ عَلَيْهِ الصَّدَقَةُ، فَبَاعَهَا بِإِبِلٍ مِثْلِهَا، أَوْ بِغَنَمٍ، أَوْ بِبَقَرٍ، أَوْ بِدَرَاهِمَ، فِرَارًا مِنَ الصَّدَقَةِ بِيَوْمٍ، احْتِيَالاً فَلاَ بَأْسَ عَلَيْهِ، وَهْوَ يَقُولُ إِنْ زَكَّى إِبِلَهُ قَبْلَ أَنْ يَحُولَ الْحَوْلُ بِيَوْمٍ أَوْ بِسَنَةٍ، جَازَتْ عَنْهُ‏.‏\hadithno{6958}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "On the Day of Resurrection the Kanz (Treasure or wealth of which, Zakat has not been paid) of anyone of you will appear in the shape of a huge bald headed poisonous male snake and its owner will run away from it, but it will follow him and say, 'I am your Kanz.'" The Prophet (ﷺ) added, "By Allah, that snake will keep on following him until he stretches out his hand and let the snake swallow it." Allah's Messenger (ﷺ) added, "If the owner of camels does not pay their Zakat, then, on the Day of Resurrection those camels will come to him and will strike his face with their hooves." Some people said: Concerning a man who has camels, and is afraid that Zakat will be due so he sells those camels for similar camels or for sheep or cows or money one day before Zakat becomes due in order to avoid payment of their Zakat cunningly! "He has not to pay anything." The same scholar said, "If one pays Zakat of his camels one day or one year prior to the end of the year (by the end of which Zakat becomes due), his Zakat will be valid}}
\hadithdefcmd{bukhari}{6959}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ اسْتَفْتَى سَعْدُ بْنُ عُبَادَةَ الأَنْصَارِيُّ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي نَذْرٍ كَانَ عَلَى أُمِّهِ، تُوُفِّيَتْ قَبْلَ أَنْ تَقْضِيَهُ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْضِهِ عَنْهَا ‏"‏‏.‏ وَقَالَ بَعْضُ النَّاسِ إِذَا بَلَغَتِ الإِبِلُ عِشْرِينَ، فَفِيهَا أَرْبَعُ شِيَاهٍ، فَإِنْ وَهَبَهَا قَبْلَ الْحَوْلِ أَوْ بَاعَهَا، فِرَارًا وَاحْتِيَالاً لإِسْقَاطِ الزَّكَاةِ، فَلاَ شَىْءَ عَلَيْهِ، وَكَذَلِكَ إِنْ أَتْلَفَهَا فَمَاتَ، فَلاَ شَىْءَ فِي مَالِهِ‏.‏\hadithno{6959}\hadithtrans{Narrated Ibn Abbas: Sa'd bin 'Ubada Al-Ansari sought the verdict of Allah's Messenger (ﷺ) regarding a vow made by his mother who had died before fulfilling it. Allah's Messenger (ﷺ) said, "Fulfill it on her behalf." Some people said, "If the number of camels reaches twenty, then their owner has to pay four sheep as Zakat; and if their owner gives them as a gift or sells them in order to escape the payment of Zakat cunningly before the completion of a year, then he is not to pay anything, and if he slaughters them and then dies, then no Zakat is to be taken from his property}}
\hadithdefcmd{bukhari}{6960}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الشِّغَارِ‏.‏ قُلْتُ لِنَافِعٍ مَا الشِّغَارُ قَالَ يَنْكِحُ ابْنَةَ الرَّجُلِ وَيُنْكِحُهُ ابْنَتَهُ بِغَيْرِ صَدَاقٍ، وَيَنْكِحُ أُخْتَ الرَّجُلِ وَيُنْكِحُهُ أُخْتَهُ بِغَيْرِ صَدَاقٍ‏.‏ وَقَالَ بَعْضُ النَّاسِ إِنِ احْتَالَ حَتَّى تَزَوَّجَ عَلَى الشِّغَارِ، فَهْوَ جَائِزٌ، وَالشَّرْطُ بَاطِلٌ‏.‏ وَقَالَ فِي الْمُتْعَةِ النِّكَاحُ فَاسِدٌ، وَالشَّرْطُ بَاطِلٌ‏.‏ وَقَالَ بَعْضُهُمُ الْمُتْعَةُ وَالشِّغَارُ جَائِزٌ، وَالشَّرْطُ بَاطِلٌ‏.‏\hadithno{6960}\hadithtrans{Narrated 'Abdullah: Nafi narrated to me that 'Abdullah said that Allah's Messenger (ﷺ) forbade the Shighar. I asked Nafi', "What is the Shighar?" He said, "It is to marry the daughter of a man and marry one's daughter to that man (at the same time) without Mahr (in both cases); or to marry the sister of a man and marry one's own sister to that man without Mahr." Some people said, "If one, by a trick, marries on the basis of Shighar, the marriage is valid but its condition is illegal." The same scholar said regarding Al-Mut'a, "The marriage is invalid and its condition is illegal." Some others said, "The Mut'a and the Shighar are permissible but the condition is illegal}}
\hadithdefcmd{bukhari}{6961}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، حَدَّثَنَا الزُّهْرِيُّ، عَنِ الْحَسَنِ، وَعَبْدِ اللَّهِ، ابْنَىْ مُحَمَّدِ بْنِ عَلِيٍّ عَنْ أَبِيهِمَا، أَنَّ عَلِيًّا ـ رضى الله عنه ـ قِيلَ لَهُ إِنَّ ابْنَ عَبَّاسٍ لاَ يَرَى بِمُتْعَةِ النِّسَاءِ بَأْسًا‏.‏ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْهَا يَوْمَ خَيْبَرَ، وَعَنْ لُحُومِ الْحُمُرِ الإِنْسِيَّةِ‏.‏ وَقَالَ بَعْضُ النَّاسِ إِنِ احْتَالَ حَتَّى تَمَتَّعَ، فَالنِّكَاحُ فَاسِدٌ‏.‏ وَقَالَ بَعْضُهُمُ النِّكَاحُ جَائِزٌ وَالشَّرْطُ بَاطِلٌ‏.‏\hadithno{6961}\hadithtrans{Narrated Muhammad bin `Ali:`Ali was told that Ibn `Abbas did not see any harm in the Mut'a marriage. `Ali said, "Allah's Messenger (ﷺ) forbade the Mut'a marriage on the Day of the battle of Khaibar and he forbade the eating of donkey's meat." Some people said, "If one, by a tricky way, marries temporarily, his marriage is illegal." Others said, "The marriage is valid but its condition is illegal}}
\hadithdefcmd{bukhari}{6962}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُمْنَعُ فَضْلُ الْمَاءِ لِيُمْنَعَ بِهِ فَضْلُ الْكَلإِ ‏"‏‏.‏\hadithno{6962}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "One should not prevent others from watering their animals with the surplus of his water in order to prevent them from benefiting by the surplus of grass}}
\hadithdefcmd{bukhari}{6963}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ النَّجْشِ‏.‏\hadithno{6963}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) forbade the practice of An-Najsh}}
\hadithdefcmd{bukhari}{6964}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَجُلاً، ذَكَرَ لِلنَّبِيِّ صلى الله عليه وسلم أَنَّهُ يُخْدَعُ فِي الْبُيُوعِ فَقَالَ ‏ "‏ إِذَا بَايَعْتَ فَقُلْ لاَ خِلاَبَةَ ‏"‏‏.‏\hadithno{6964}\hadithtrans{Narrated `Abdullah bin `Umar:A man mentioned to the Prophet (ﷺ) that he had always been cheated in bargains. The Prophet (ﷺ) said, "Whenever you do bargain, say, 'No cheating}}
\hadithdefcmd{bukhari}{6965}{حَدَّثَنَا أَبُو الْيَمَانِ، حَدَّثَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ كَانَ عُرْوَةُ يُحَدِّثُ أَنَّهُ سَأَلَ عَائِشَةَ ‏\{‏وَإِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى فَانْكِحُوا مَا طَابَ لَكُمْ مِنَ النِّسَاءِ‏\}‏‏.‏ قَالَتْ هِيَ الْيَتِيمَةُ فِي حَجْرِ وَلِيِّهَا، فَيَرْغَبُ فِي مَالِهَا وَجَمَالِهَا، فَيُرِيدُ أَنْ يَتَزَوَّجَهَا بِأَدْنَى مِنْ سُنَّةِ نِسَائِهَا، فَنُهُوا عَنْ نِكَاحِهِنَّ، إِلاَّ أَنْ يُقْسِطُوا لَهُنَّ فِي إِكْمَالِ الصَّدَاقِ، ثُمَّ اسْتَفْتَى النَّاسُ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدُ فَأَنْزَلَ اللَّهُ ‏\{‏وَيَسْتَفْتُونَكَ فِي النِّسَاءِ‏\}‏ فَذَكَرَ الْحَدِيثَ‏.‏\hadithno{6965}\hadithtrans{Narrated `Urwa:That he asked `Aisha regarding the Verse: 'If you fear that you shall not be able to deal justly with the orphan girls, marry (other) women of your choice.' (4.3) `Aisha said, "It is about an orphan girl under the custody of her guardian who being attracted by her wealth and beauty wants to marry her with Mahr less than other women of her status. So such guardians were forbidden to marry them unless they treat them justly by giving them their full Mahr. Then the people sought the verdict of Allah's Apostle for such cases, whereupon Allah revealed: 'They ask your instruction concerning women..' (4.127) (The sub-narrator then mentioned the Hadith)}}
\hadithdefcmd{bukhari}{6966}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ لِكُلِّ غَادِرٍ لِوَاءٌ يَوْمَ الْقِيَامَةِ يُعْرَفُ بِهِ ‏"‏‏.‏\hadithno{6966}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "For every betrayer there will be a flag by which he will be recognized on the Day of Resurrection}}
\hadithdefcmd{bukhari}{6967}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، عَنْ سُفْيَانَ، عَنْ هِشَامٍ، عَنْ عُرْوَةَ، عَنْ زَيْنَبَ ابْنَةِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا أَنَا بَشَرٌ، وَإِنَّكُمْ تَخْتَصِمُونَ، وَلَعَلَّ بَعْضَكُمْ أَنْ يَكُونَ أَلْحَنَ بِحُجَّتِهِ مِنْ بَعْضٍ، وَأَقْضِيَ لَهُ عَلَى نَحْوِ مَا أَسْمَعُ، فَمَنْ قَضَيْتُ لَهُ مِنْ حَقِّ أَخِيهِ شَيْئًا، فَلاَ يَأْخُذْ، فَإِنَّمَا أَقْطَعُ لَهُ قِطْعَةً مِنَ النَّارِ ‏"‏‏.‏\hadithno{6967}\hadithtrans{Narrated Um Salama:The Prophet (ﷺ) said, "I am only a human being, and you people have disputes. May be some one amongst you can present his case in a more eloquent and convincing manner than the other, and I give my judgment in his favor according to what I hear. Beware! If ever I give (by error) somebody something of his brother's right then he should not take it as I have only, given him a piece of Fire." (See Hadith No. 638. Vol)}}
\hadithdefcmd{bukhari}{6968}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تُنْكَحُ الْبِكْرُ حَتَّى تُسْتَأْذَنَ، وَلاَ الثَّيِّبُ حَتَّى تُسْتَأْمَرَ ‏"‏‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ كَيْفَ إِذْنُهَا قَالَ ‏"‏ إِذَا سَكَتَتْ ‏"‏‏.‏ وَقَالَ بَعْضُ النَّاسِ إِنْ لَمْ تُسْتَأْذَنِ الْبِكْرُ وَلَمْ تَزَوَّجْ‏.‏ فَاحْتَالَ رَجُلٌ فَأَقَامَ شَاهِدَىْ زُورٍ أَنَّهُ تَزَوَّجَهَا بِرِضَاهَا، فَأَثْبَتَ الْقَاضِي نِكَاحَهَا، وَالزَّوْجُ يَعْلَمُ أَنَّ الشَّهَادَةَ بَاطِلَةٌ، فَلاَ بَأْسَ أَنْ يَطَأَهَا، وَهْوَ تَزْوِيجٌ صَحِيحٌ‏.‏\hadithno{6968}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "A virgin should not be married till she is asked for her consent; and the matron should not be married till she is asked whether she agrees to marry or not." It was asked, "O Allah's Apostle! How will she (the virgin) express her consent?" He said, "By keeping silent." Some people said that if a virgin is not asked for her consent and she is not married, and then a man, by playing a trick presents two false witnesses that he has married her with her consent and the judge confirms his marriage as a true one, and the husband knows that the witnesses were false ones, then there is no harm for him to consummate his marriage with her and the marriage is regarded as valid}}
\hadithdefcmd{bukhari}{6969}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ الْقَاسِمِ، أَنَّ امْرَأَةً، مِنْ وَلَدِ جَعْفَرٍ تَخَوَّفَتْ أَنْ يُزَوِّجَهَا وَلِيُّهَا وَهْىَ كَارِهَةٌ فَأَرْسَلَتْ إِلَى شَيْخَيْنِ مِنَ الأَنْصَارِ عَبْدِ الرَّحْمَنِ وَمُجَمِّعٍ ابْنَىْ جَارِيَةَ قَالاَ فَلاَ تَخْشَيْنَ، فَإِنَّ خَنْسَاءَ بِنْتَ خِذَامٍ أَنْكَحَهَا أَبُوهَا وَهْىَ كَارِهَةٌ، فَرَدَّ النَّبِيُّ صلى الله عليه وسلم ذَلِكَ‏.‏ قَالَ سُفْيَانُ وَأَمَّا عَبْدُ الرَّحْمَنِ فَسَمِعْتُهُ يَقُولُ عَنْ أَبِيهِ إِنَّ خَنْسَاءَ‏.‏\hadithno{6969}\hadithtrans{Narrated Al-Qasim:A woman from the offspring of Ja`far was afraid lest her guardian marry her (to somebody) against her will. So she sent for two elderly men from the Ansar, `AbdurRahman and Mujammi', the two sons of Jariya, and they said to her, "Don't be afraid, for Khansa' bint Khidam was given by her father in marriage against her will, then the Prophet (ﷺ) cancelled that marriage." (See Hadith No)}}
\hadithdefcmd{bukhari}{6970}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تُنْكَحُ الأَيِّمُ حَتَّى تُسْتَأْمَرَ، وَلاَ تُنْكَحُ الْبِكْرُ حَتَّى تُسْتَأْذَنَ ‏"‏‏.‏ قَالُوا كَيْفَ إِذْنُهَا قَالَ ‏"‏ أَنْ تَسْكُتَ ‏"‏‏.‏ وَقَالَ بَعْضُ النَّاسِ إِنِ احْتَالَ إِنْسَانٌ بِشَاهِدَىْ زُورٍ عَلَى تَزْوِيجِ امْرَأَةٍ ثَيِّبٍ بِأَمْرِهَا، فَأَثْبَتَ الْقَاضِي نِكَاحَهَا إِيَّاهُ، وَالزَّوْجُ يَعْلَمُ أَنَّهُ لَمْ يَتَزَوَّجْهَا قَطُّ، فَإِنَّهُ يَسَعُهُ هَذَا النِّكَاحُ، وَلاَ بَأْسَ بِالْمُقَامِ لَهُ مَعَهَا‏.‏\hadithno{6970}\hadithtrans{Narrated Abu Haraira:Allah's Messenger (ﷺ) said, "A lady slave should not be given in marriage until she is consulted, and a virgin should not be given in marriage until her permission is granted." The people said, "How will she express her permission?" The Prophet (ﷺ) said, "By keeping silent (when asked her consent)." Some people said, "If a man, by playing a trick, presents two false witnesses before the judge to testify that he has married a matron with her consent and the judge confirms his marriage, and the husband is sure that he has never married her (before), then such a marriage will be considered as a legal one and he may live with her as husband}}
\hadithdefcmd{bukhari}{6971}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ ذَكْوَانَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْبِكْرُ تُسْتَأْذَنُ ‏"‏‏.‏ قُلْتُ إِنَّ الْبِكْرَ تَسْتَحْيِي قَالَ ‏"‏ إِذْنُهَا صُمَاتُهَا ‏"‏‏.‏ وَقَالَ بَعْضُ النَّاسِ إِنْ هَوِيَ رَجُلٌ جَارِيَةً يَتِيمَةً أَوْ بِكْرًا، فَأَبَتْ فَاحْتَالَ فَجَاءَ بِشَاهِدَىْ زُورٍ عَلَى أَنَّهُ تَزَوَّجَهَا، فَأَدْرَكَتْ فَرَضِيَتِ الْيَتِيمَةُ، فَقَبِلَ الْقَاضِي شَهَادَةَ الزُّورِ، وَالزَّوْجُ يَعْلَمُ بِبُطْلاَنِ ذَلِكَ، حَلَّ لَهُ الْوَطْءُ‏.‏\hadithno{6971}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said, "It is essential to have the consent of a virgin (for the marriage). I said, "A virgin feels shy." The Prophet; said, "Her silence means her consent." Some people said, "If a man falls in love with an orphan slave girl or a virgin and she refuses (him) and then he makes a trick by bringing two false witnesses to testify that he has married her, and then she attains the age of puberty and agrees to marry him and the judge accepts the false witness and the husband knows that the witnesses were false ones, he may consummate his marriage}}
\hadithdefcmd{bukhari}{6972}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُحِبُّ الْحَلْوَاءَ، وَيُحِبُّ الْعَسَلَ، وَكَانَ إِذَا صَلَّى الْعَصْرَ أَجَازَ عَلَى نِسَائِهِ فَيَدْنُو مِنْهُنَّ، فَدَخَلَ عَلَى حَفْصَةَ، فَاحْتَبَسَ عِنْدَهَا أَكْثَرَ مِمَّا كَانَ يَحْتَبِسُ، فَسَأَلْتُ عَنْ ذَلِكَ فَقِيلَ لِي أَهْدَتِ امْرَأَةٌ مِنْ قَوْمِهَا عُكَّةَ عَسَلٍ، فَسَقَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْهُ شَرْبَةً‏.‏ فَقُلْتُ أَمَا وَاللَّهِ لَنَحْتَالَنَّ لَهُ‏.‏ فَذَكَرْتُ ذَلِكَ لِسَوْدَةَ قُلْتُ إِذَا دَخَلَ عَلَيْكِ فَإِنَّهُ سَيَدْنُو مِنْكِ فَقُولِي لَهُ يَا رَسُولَ اللَّهِ أَكَلْتَ مَغَافِيرَ فَإِنَّهُ سَيَقُولُ لاَ‏.‏ فَقُولِي لَهُ مَا هَذِهِ الرِّيحُ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَشْتَدُّ عَلَيْهِ أَنْ تُوجَدُ مِنْهُ الرِّيحُ، فَإِنَّهُ سَيَقُولُ سَقَتْنِي حَفْصَةُ شَرْبَةَ عَسَلٍ‏.‏ فَقُولِي لَهُ جَرَسَتْ نَحْلُهُ الْعُرْفُطَ‏.‏ وَسَأَقُولُ ذَلِكَ، وَقُولِيهِ أَنْتِ يَا صَفِيَّةُ‏.‏ فَلَمَّا دَخَلَ عَلَى سَوْدَةَ، قُلْتُ تَقُولُ سَوْدَةُ وَالَّذِي لاَ إِلَهَ إِلاَّ هُوَ لَقَدْ كِدْتُ أَنْ أُبَادِرَهُ بِالَّذِي قُلْتِ لِي، وَإِنَّهُ لَعَلَى الْبَابِ فَرَقًا مِنْكِ، فَلَمَّا دَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم قُلْتُ يَا رَسُولَ اللَّهِ أَكَلْتَ مَغَافِيرَ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ فَمَا هَذِهِ الرِّيحُ قَالَ ‏"‏ سَقَتْنِي حَفْصَةُ شَرْبَةَ عَسَلٍ ‏"‏‏.‏ قُلْتُ جَرَسَتْ نَحْلُهُ الْعُرْفُطَ‏.‏ فَلَمَّا دَخَلَ عَلَىَّ قُلْتُ لَهُ مِثْلَ ذَلِكَ‏.‏ وَدَخَلَ عَلَى صَفِيَّةَ فَقَالَتْ لَهُ مِثْلَ ذَلِكَ‏.‏ فَلَمَّا دَخَلَ عَلَى حَفْصَةَ قَالَتْ لَهُ يَا رَسُولَ اللَّهِ أَلاَ أَسْقِيكَ مِنْهُ قَالَ ‏"‏ لاَ حَاجَةَ لِي بِهِ ‏"‏‏.‏ قَالَتْ تَقُولُ سَوْدَةُ سُبْحَانَ اللَّهِ لَقَدْ حَرَمْنَاهُ‏.‏ قَالَتْ قُلْتُ لَهَا اسْكُتِي‏.‏\hadithno{6972}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to like sweets and also used to like honey, and whenever he finished the `Asr prayer, he used to visit his wives and stay with them. Once he visited Hafsa and remained with her longer than the period he used to stay, so I enquired about it. It was said to me, "A woman from her tribe gave her a leather skin containing honey as a present, and she gave some of it to Allah's Messenger (ﷺ) to drink." I said, "By Allah, we will play a trick on him." So I mentioned the story to Sauda (the wife of the Prophet) and said to her, "When he enters upon you, he will come near to you whereupon you should say to him, 'O Allah's Messenger (ﷺ)! Have you eaten Maghafir?' He will say, 'No.' Then you say to him, 'What is this bad smell? ' And it would be very hard on Allah's Messenger (ﷺ) that a bad smell should be found on his body. He will say, 'Hafsa has given me a drink of honey.' Then you should say to him, 'Its bees must have sucked from the Al-`Urfut (a foul smelling flower).' I too, will tell him the same. And you, O Saifya, say the same." So when the Prophet (ﷺ) entered upon Sauda (the following happened). Sauda said, "By Him except Whom none has the right to be worshipped, I was about to say to him what you had told me to say while he was still at the gate because of fear from you. But when Allah's Apostle came near to me, I said to him, 'O Allah's Messenger (ﷺ)! Have you eaten Maghafir?' He replied, 'No.' I said, 'What about this smell?' He said, 'Hafsa has given me a drink of honey.' I said, 'Its bees must have sucked Al-`Urfut.' " When he entered upon me, I told him the same as that, and when he entered upon Safiya, she too told him the same. So when he visited Hafsa again, she said to him, "O Allah's Messenger (ﷺ)! Shall I give you a drink of it (honey)?" He said, "I have no desire for it." Sauda said, Subhan Allah! We have deprived him of it (honey)." I said to her, "Be quiet}}
\hadithdefcmd{bukhari}{6973}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ خَرَجَ إِلَى الشَّأْمِ، فَلَمَّا جَاءَ بِسَرْغَ بَلَغَهُ أَنَّ الْوَبَاءَ وَقَعَ بِالشَّأْمِ فَأَخْبَرَهُ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَمِعْتُمْ بِأَرْضٍ فَلاَ تَقْدَمُوا عَلَيْهِ، وَإِذَا وَقَعَ بِأَرْضٍ وَأَنْتُمْ بِهَا فَلاَ تَخْرُجُوا فِرَارًا مِنْهُ ‏"‏‏.‏ فَرَجَعَ عُمَرُ مِنْ سَرْغَ‏.‏ وَعَنِ ابْنِ شِهَابٍ عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ أَنَّ عُمَرَ إِنَّمَا انْصَرَفَ مِنْ حَدِيثِ عَبْدِ الرَّحْمَنِ‏.‏\hadithno{6973}\hadithtrans{Narrated `Abdullah bin 'Amir bin Rabi`a:`Umar bin Al-Khattab left for Sham, and when he reached a placed called Sargh, he came to know that there was an outbreak of an epidemic (of plague) in Sham. Then `AbdurRahman bin `Auf told him that Allah's Messenger (ﷺ) said, "If you hear the news of an outbreak of an epidemic (plague) in a certain place, do not enter that place: and if the epidemic falls in a place while you are present in it, do not leave that place to escape from the epidemic." So `Umar returned from Sargh}}
\hadithdefcmd{bukhari}{6974}{حَدَّثَنَا أَبُو الْيَمَانِ، حَدَّثَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنَا عَامِرُ بْنُ سَعْدِ بْنِ أَبِي وَقَّاصٍ، أَنَّهُ سَمِعَ أُسَامَةَ بْنَ زَيْدٍ، يُحَدِّثُ سَعْدًا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ الْوَجَعَ فَقَالَ ‏ "‏ رِجْزٌ ـ أَوْ عَذَابٌ ـ عُذِّبَ بِهِ بَعْضُ الأُمَمِ، ثُمَّ بَقِيَ مِنْهُ بَقِيَّةٌ، فَيَذْهَبُ الْمَرَّةَ وَيَأْتِي الأُخْرَى، فَمَنْ سَمِعَ بِهِ بِأَرْضٍ فَلاَ يَقْدَمَنَّ عَلَيْهِ، وَمَنْ كَانَ بِأَرْضٍ وَقَعَ بِهَا فَلاَ يَخْرُجْ فِرَارًا مِنْهُ ‏"‏‏.‏\hadithno{6974}\hadithtrans{Narrated 'Amir bin Sa`d bin Abi Waqqas:That he heard Usama bin Zaid speaking to Sa`d, saying, "Allah's Messenger (ﷺ) mentioned the plague and said, 'It is a means of punishment with which some nations were punished and some of it has remained, and it appears now and then. So whoever hears that there is an outbreak of plague in some land, he should not go to that land, and if the plague breaks out in the land where one is already present, one should not run away from that land, escaping from the plague}}
\hadithdefcmd{bukhari}{6975}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْعَائِدُ فِي هِبَتِهِ كَالْكَلْبِ يَعُودُ فِي قَيْئِهِ، لَيْسَ لَنَا مَثَلُ السَّوْءِ ‏"‏‏.‏\hadithno{6975}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "The one who takes back his gift is like a dog swallowing its own vomit, and we (believers) should not act according to this bad example}}
\hadithdefcmd{bukhari}{6976}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ إِنَّمَا جَعَلَ النَّبِيُّ صلى الله عليه وسلم الشُّفْعَةَ فِي كُلِّ مَا لَمْ يُقْسَمْ، فَإِذَا وَقَعَتِ الْحُدُودُ وَصُرِّفَتِ الطُّرُقُ فَلاَ شُفْعَةَ‏.‏ وَقَالَ بَعْضُ النَّاسِ الشُّفْعَةُ لِلْجِوَارِ‏.‏ ثُمَّ عَمَدَ إِلَى مَا شَدَّدَهُ فَأَبْطَلَهُ، وَقَالَ إِنِ اشْتَرَى دَارًا فَخَافَ أَنْ يَأْخُذَ الْجَارُ بِالشُّفْعَةِ، فَاشْتَرَى سَهْمًا مِنْ مِائَةِ سَهْمٍ، ثُمَّ اشْتَرَى الْبَاقِيَ، وَكَانَ لِلْجَارِ الشُّفْعَةُ فِي السَّهْمِ الأَوَّلِ، وَلاَ شُفْعَةَ لَهُ فِي بَاقِي الدَّارِ، وَلَهُ أَنْ يَحْتَالَ فِي ذَلِكَ‏.‏\hadithno{6976}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) has decreed that preemption is valid in all cases where the real estate concerned has not been divided, but if the boundaries are established and the ways are made, then there is no preemption. A man said, "Preemption is only for the neighbor," and then he makes invalid what he has confirmed. He said, "If someone wants to buy a house and being afraid that the neighbor (of the house) may buy it through preemption, he buys one share out of one hundred shares of the house and then buys the rest of the house, then the neighbor can only have the right of preemption for the first share but not for the rest of the house; and the buyer may play such a trick in this case}}
\hadithdefcmd{bukhari}{6977}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ، سَمِعْتُ عَمْرَو بْنَ الشَّرِيدِ، قَالَ جَاءَ الْمِسْوَرُ بْنُ مَخْرَمَةَ فَوَضَعَ يَدَهُ عَلَى مَنْكِبِي، فَانْطَلَقْتُ مَعَهُ إِلَى سَعْدٍ فَقَالَ أَبُو رَافِعٍ لِلْمِسْوَرِ أَلاَ تَأْمُرُ هَذَا أَنْ يَشْتَرِيَ مِنِّي بَيْتِي الَّذِي فِي دَارِي‏.‏ فَقَالَ لاَ أَزِيدُهُ عَلَى أَرْبَعِمِائَةٍ، إِمَّا مُقَطَّعَةٍ وَإِمَّا مُنَجَّمَةٍ‏.‏ قَالَ أُعْطِيتُ خَمْسَمِائَةٍ نَقْدًا، فَمَنَعْتُهُ، وَلَوْلاَ أَنِّي سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْجَارُ أَحَقُّ بِصَقَبِهِ ‏"‏‏.‏ مَا بِعْتُكَهُ أَوْ قَالَ مَا أَعْطَيْتُكَهُ‏.‏ قُلْتُ لِسُفْيَانَ إِنَّ مَعْمَرًا لَمْ يَقُلْ هَكَذَا‏.‏ قَالَ لَكِنَّهُ قَالَ لِي هَكَذَا‏.‏ وَقَالَ بَعْضُ النَّاسِ إِذَا أَرَادَ أَنْ يَبِيعَ الشُّفْعَةَ فَلَهُ أَنْ يَحْتَالَ حَتَّى يُبْطِلَ الشُّفْعَةَ فَيَهَبُ الْبَائِعُ لِلْمُشْتَرِي الدَّارَ، وَيَحُدُّهَا وَيَدْفَعُهَا إِلَيْهِ، وَيُعَوِّضُهُ الْمُشْتَرِي أَلْفَ دِرْهَمٍ، فَلاَ يَكُونُ لِلشَّفِيعِ فِيهَا شُفْعَةٌ‏.‏\hadithno{6977}\hadithtrans{Narrated 'Amr bin Ash-Sharid: Al-Miswar bin Makhrama came and put his hand on my shoulder and I accompanied him to Sa'd. Abu Rafi' said to Al-Miswar, "Won't you order this (i.e. Sa'd) to buy my house which is in my yard?" Sa'd said, "I will not offer more than four hundred in installments over a fixed period." Abu Rafi said, "I was offered five hundred cash but I refused. Had I not heard the Prophet (ﷺ) saying, 'A neighbor is more entitled to receive the care of his neighbor,' I would not have sold it to you." The narrator said, to Sufyan: Ma'mar did not say so. Sufyan said, "But he did say so to me." Some people said, "If someone wants to sell a house and deprived somebody of the right of preemption, he has the right to play a trick to render the preemption invalid. And that is by giving the house to the buyer as a present and marking its boundaries and giving it to him. The buyer then gives the seller one-thousand Dirham as compensation in which case the preemptor loses his right of preemption}}
\hadithdefcmd{bukhari}{6978}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنْ أَبِي رَافِعٍ، أَنَّ سَعْدًا، سَاوَمَهُ بَيْتًا بِأَرْبَعِمِائَةِ مِثْقَالٍ فَقَالَ لَوْلاَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْجَارُ أَحَقُّ بِصَقَبِهِ ‏"‏‏.‏ لَمَا أَعْطَيْتُكَ‏.‏ وَقَالَ بَعْضُ النَّاسِ إِنِ اشْتَرَى نَصِيبَ دَارٍ، فَأَرَادَ أَنْ يُبْطِلَ الشُّفْعَةَ، وَهَبَ لاِبْنِهِ الصَّغِيرِ وَلاَ يَكُونُ عَلَيْهِ يَمِينٌ‏.‏\hadithno{6978}\hadithtrans{Narrated 'Amr bin Ash-Sharid: Abu Rafi' said that Sa'd offered him four hundred Mithqal of gold for a house. Abu Rafi ' said, "If I had not heard Allah's Messenger (ﷺ) saying, 'A neighbor has more right to be taken care of by his neighbor,' then I would not have given it to you." Some people said, "If one has bought a portion of a house and wants to cancel the right of preemption, he may give it as a present to his little son and he will not be obliged to take an oath}}
\hadithdefcmd{bukhari}{6979}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ اسْتَعْمَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً عَلَى صَدَقَاتِ بَنِي سُلَيْمٍ يُدْعَى ابْنَ اللُّتَبِيَّةِ، فَلَمَّا جَاءَ حَاسَبَهُ قَالَ هَذَا مَالُكُمْ وَهَذَا هَدِيَّةٌ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَهَلاَّ جَلَسْتَ فِي بَيْتِ أَبِيكَ وَأُمِّكَ، حَتَّى تَأْتِيَكَ هَدِيَّتُكَ إِنْ كُنْتَ صَادِقًا ‏"‏‏.‏ ثُمَّ خَطَبَنَا فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ، فَإِنِّي أَسْتَعْمِلُ الرَّجُلَ مِنْكُمْ عَلَى الْعَمَلِ مِمَّا وَلاَّنِي اللَّهُ، فَيَأْتِي فَيَقُولُ هَذَا مَالُكُمْ وَهَذَا هَدِيَّةٌ أُهْدِيَتْ لِي‏.‏ أَفَلاَ جَلَسَ فِي بَيْتِ أَبِيهِ وَأُمِّهِ حَتَّى تَأْتِيَهُ هَدِيَّتُهُ، وَاللَّهِ لاَ يَأْخُذُ أَحَدٌ مِنْكُمْ شَيْئًا بِغَيْرِ حَقِّهِ، إِلاَّ لَقِيَ اللَّهَ يَحْمِلُهُ يَوْمَ الْقِيَامَةِ، فَلأَعْرِفَنَّ أَحَدًا مِنْكُمْ لَقِيَ اللَّهَ يَحْمِلُ بَعِيرًا لَهُ رُغَاءٌ، أَوْ بَقَرَةً لَهَا خُوَارٌ، أَوْ شَاةً تَيْعَرُ ‏"‏‏.‏ ثُمَّ رَفَعَ يَدَهُ حَتَّى رُئِيَ بَيَاضُ إِبْطِهِ يَقُولُ ‏"‏ اللَّهُمَّ هَلْ بَلَّغْتُ ‏"‏‏.‏ بَصْرَ عَيْنِي وَسَمْعَ أُذُنِي‏.‏\hadithno{6979}\hadithtrans{Narrated Abu Humaid As-Sa`idi:Allah's Messenger (ﷺ) appointed a man called Ibn Al-Lutabiyya to collect the Zakat from Bani Sulaim's tribe. When he returned, the Prophet (ﷺ) called him to account. He said (to the Prophet, 'This is your money, and this has been given to me as a gift." On that, Allah's Messenger (ﷺ) said, "Why didn't you stay in your father's and mother's house to see whether you will be given gifts or not if you are telling the truth?" Then the Prophet (ﷺ) addressed us, and after praising and glorifying Allah, he said: "Amma Ba'du", I employ a man from among you to manage some affair of what Allah has put under my custody, and then he comes to me and says, 'This is your money and this has been given to me as a gift. Why didn't he stay in his father's and mother's home to see whether he will be given gifts or not? By Allah, not anyone of you takes a thing unlawfully but he will meet Allah on the Day of Resurrection, carrying that thing. I do not want to see any of you carrying a grunting camel or a mooing cow or a bleating sheep on meeting Allah." Then the Prophet (ﷺ) raised both his hands till the whiteness of his armpits became visible, and he said, "O Allah! Haven't I have conveyed (Your Message)?" The narrator added: My eyes witnessed and my ears heard (that Hadith)}}
\hadithdefcmd{bukhari}{6980}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنْ أَبِي رَافِعٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الْجَارُ أَحَقُّ بِصَقَبِهِ ‏"‏‏.‏ وَقَالَ بَعْضُ النَّاسِ إِنِ اشْتَرَى دَارًا بِعِشْرِينَ أَلْفَ دِرْهَمٍ، فَلاَ بَأْسَ أَنْ يَحْتَالَ حَتَّى يَشْتَرِيَ الدَّارَ بِعِشْرِينَ أَلْفَ دِرْهَمٍ، وَيَنْقُدَهُ تِسْعَةَ آلاَفِ دِرْهَمٍ وَتِسْعَمِائَةَ دِرْهَمٍ وَتِسْعَةً وَتِسْعِينَ، وَيَنْقُدَهُ دِينَارًا بِمَا بَقِيَ مِنَ الْعِشْرِينَ الأَلْفَ، فَإِنْ طَلَبَ الشَّفِيعُ أَخَذَهَا بِعِشْرِينَ أَلْفَ دِرْهَمٍ، وَإِلاَّ فَلاَ سَبِيلَ لَهُ عَلَى الدَّارِ، فَإِنِ اسْتُحِقَّتِ الدَّارُ، رَجَعَ الْمُشْتَرِي عَلَى الْبَائِعِ بِمَا دَفَعَ إِلَيْهِ، وَهْوَ تِسْعَةُ آلاَفِ دِرْهَمٍ وَتِسْعُمِائَةٍ وَتِسْعَةٌ وَتِسْعُونَ دِرْهَمًا وَدِينَارٌ، لأَنَّ الْبَيْعَ حِينَ اسْتُحِقَّ انْتَقَضَ الصَّرْفُ فِي الدِّينَارِ، فَإِنْ وَجَدَ بِهَذِهِ الدَّارِ عَيْبًا وَلَمْ تُسْتَحَقَّ، فَإِنَّهُ يَرُدُّهَا عَلَيْهِ بِعِشْرِينَ أَلْفَ دِرْهَمٍ‏.‏ قَالَ فَأَجَازَ هَذَا الْخِدَاعَ بَيْنَ الْمُسْلِمِينَ وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ دَاءَ وَلاَ خِبْثَةَ وَلاَ غَائِلَةَ ‏"‏‏.‏\hadithno{6980}\hadithtrans{Narrated Abu Rafi`:The Prophet (ﷺ) said, "The neighbor has more right to be taken care of by his neighbor (than anyone else)." Some men said, "If one wants to buy a house for 20,000 Dirhams then there is no harm to play a trick to deprive somebody of preemption by buying it (just on paper) with 20,000 Dirhams but paying to the seller only 9,999 Dirhams in cash and then agree with the seller to pay only one Dinar in cash for the rest of the price (i.e. 10,001 Dirhams). If the preemptor offers 20,000 Dirhams for the house, he can buy it otherwise he has no right to buy it (by this trick he got out of preemption). If the house proves to belong to somebody else other than the seller, the buyer should take back from the seller what he has paid, i.e., 9,999 Dirhams and one Dinar, because if the house proves to belong to somebody else, so the whole bargain (deal) is unlawful. If the buyer finds a defect in the house and it does not belong to somebody other than the seller, the buyer may return it and receive 20,000 Dirhams (instead of 9999 Dirham plus one Dinar) which he actually paid.' Abu `Abdullah said, "So that man allows (some people) the playing of tricks amongst the Muslims (although) the Prophet (ﷺ) said, 'In dealing with Muslims one should not sell them sick (animals) or bad things or stolen things}}
\hadithdefcmd{bukhari}{6981}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ مَيْسَرَةَ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، أَنَّ أَبَا رَافِعٍ، سَاوَمَ سَعْدَ بْنَ مَالِكٍ بَيْتًا بِأَرْبَعِمِائَةِ مِثْقَالٍ وَقَالَ لَوْلاَ أَنِّي سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْجَارُ أَحَقُّ بِصَقَبِهِ ‏"‏‏.‏ مَا أَعْطَيْتُكَ‏.‏\hadithno{6981}\hadithtrans{Narrated `Amr bin Ash-Sharid:Abu Rafi` sold a house to Sa`d bin Malik for four-hundred Mithqal of gold, and said, "If I had not heard the Prophet (ﷺ) saying, 'The neighbor has more right to be taken care of by his neighbor (than anyone else),' then I would not have sold it to you}}
