% Auto-generated chapter 29 for bukhari
% Hadiths in this chapter: 24

\hadithdefcmd{bukhari}{1867}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا ثَابِتُ بْنُ يَزِيدَ، حَدَّثَنَا عَاصِمٌ أَبُو عَبْدِ الرَّحْمَنِ الأَحْوَلُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَدِينَةُ حَرَمٌ، مِنْ كَذَا إِلَى كَذَا، لاَ يُقْطَعُ شَجَرُهَا، وَلاَ يُحْدَثُ فِيهَا حَدَثٌ، مَنْ أَحْدَثَ حَدَثًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ ‏"‏‏.‏\hadithno{1867}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "Medina is a sanctuary from that place to that. Its trees should not be cut and no heresy should be innovated nor any sin should be committed in it, and whoever innovates in it an heresy or commits sins (bad deeds), then he will incur the curse of Allah, the angels, and all the people." (See Hadith No. 409, Vol)}}
\hadithdefcmd{bukhari}{1868}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَدِمَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ فَأَمَرَ بِبِنَاءِ الْمَسْجِدِ فَقَالَ ‏ "‏ يَا بَنِي النَّجَّارِ ثَامِنُونِي ‏"‏‏.‏ فَقَالُوا لاَ نَطْلُبُ ثَمَنَهُ إِلاَّ إِلَى اللَّهِ‏.‏ فَأَمَرَ بِقُبُورِ الْمُشْرِكِينَ، فَنُبِشَتْ، ثُمَّ بِالْخِرَبِ فَسُوِّيَتْ، وَبِالنَّخْلِ فَقُطِعَ، فَصَفُّوا النَّخْلَ قِبْلَةَ الْمَسْجِدِ‏.‏\hadithno{1868}\hadithtrans{Narrated Anas:The Prophet (ﷺ) came to Medina and ordered a mosque to be built and said, "O Bani Najjar! Suggest to me the price (of your land)." They said, "We do not want its price except from Allah" (i.e. they wished for a reward from Allah for giving up their land freely). So, the Prophet (ﷺ) ordered the graves of the pagans to be dug out and the land to be leveled, and the date-palm trees to be cut down. The cut datepalms were fixed in the direction of the Qibla of the mosque}}
\hadithdefcmd{bukhari}{1869}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ حُرِّمَ مَا بَيْنَ لاَبَتَىِ الْمَدِينَةِ عَلَى لِسَانِي ‏"‏‏.‏ قَالَ وَأَتَى النَّبِيُّ صلى الله عليه وسلم بَنِي حَارِثَةَ فَقَالَ ‏"‏ أَرَاكُمْ يَا بَنِي حَارِثَةَ قَدْ خَرَجْتُمْ مِنَ الْحَرَمِ ‏"‏‏.‏ ثُمَّ الْتَفَتَ، فَقَالَ ‏"‏ بَلْ أَنْتُمْ فِيهِ ‏"‏‏.‏\hadithno{1869}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "I have made Medina a sanctuary between its two (Harrat) mountains." The Prophet (ﷺ) went to the tribe of Bani Haritha and said (to them), "I see that you have gone out of the sanctuary," but looking around, he added, "No, you are inside the sanctuary}}
\hadithdefcmd{bukhari}{1870}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ مَا عِنْدَنَا شَىْءٌ إِلاَّ كِتَابُ اللَّهِ، وَهَذِهِ الصَّحِيفَةُ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ الْمَدِينَةُ حَرَمٌ، مَا بَيْنَ عَائِرٍ إِلَى كَذَا، مَنْ أَحْدَثَ فِيهَا حَدَثًا، أَوْ آوَى مُحْدِثًا، فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ، لاَ يُقْبَلُ مِنْهُ صَرْفٌ وَلاَ عَدْلٌ ‏"‏‏.‏ وَقَالَ ‏"‏ ذِمَّةُ الْمُسْلِمِينَ وَاحِدَةٌ، فَمَنْ أَخْفَرَ مُسْلِمًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ، لاَ يُقْبَلُ مِنْهُ صَرْفٌ وَلاَ عَدْلٌ، وَمَنْ تَوَلَّى قَوْمًا بِغَيْرِ إِذْنِ مَوَالِيهِ، فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ، لاَ يُقْبَلُ مِنْهُ صَرْفٌ وَلاَ عَدْلٌ ‏"‏‏.‏\hadithno{1870}\hadithtrans{Narrated `Ali:We have nothing except the Book of Allah and this written paper from the Prophet (wherein is written:) Medina is a sanctuary from the 'Air Mountain to such and such a place, and whoever innovates in it an heresy or commits a sin, or gives shelter to such an innovator in it will incur the curse of Allah, the angels, and all the people, none of his compulsory or optional good deeds of worship will be accepted. And the asylum (of protection) granted by any Muslim is to be secured (respected) by all the other Muslims; and whoever betrays a Muslim in this respect incurs the curse of Allah, the angels, and all the people, and none of his compulsory or optional good deeds of worship will be accepted, and whoever (freed slave) befriends (take as masters) other than his manumitters without their permission incurs the curse of Allah, the angels, and all the people, and none of his compulsory or optional good deeds of worship will be accepted}}
\hadithdefcmd{bukhari}{1871}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ سَمِعْتُ أَبَا الْحُبَابِ، سَعِيدَ بْنَ يَسَارٍ يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ ‏ "‏ أُمِرْتُ بِقَرْيَةٍ تَأْكُلُ الْقُرَى يَقُولُونَ يَثْرِبُ‏.‏ وَهْىَ الْمَدِينَةُ، تَنْفِي النَّاسَ كَمَا يَنْفِي الْكِيرُ خَبَثَ الْحَدِيدِ ‏"‏‏.‏\hadithno{1871}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "I was ordered to migrate to a town which will swallow (conquer) other towns and is called Yathrib and that is Medina, and it turns out (bad) persons as a furnace removes the impurities of iron}}
\hadithdefcmd{bukhari}{1872}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ، قَالَ حَدَّثَنِي عَمْرُو بْنُ يَحْيَى، عَنْ عَبَّاسِ بْنِ سَهْلِ بْنِ سَعْدٍ، عَنْ أَبِي حُمَيْدٍ ـ رضى الله عنه ـ أَقْبَلْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم مِنْ تَبُوكَ حَتَّى أَشْرَفْنَا عَلَى الْمَدِينَةِ فَقَالَ ‏ "‏ هَذِهِ طَابَةُ ‏"‏‏.‏\hadithno{1872}\hadithtrans{Narrated Abu Humaid:We came with the Prophet (ﷺ) from Tabuk, and when we reached near Medina, the Prophet (ﷺ) said, "This is Tabah}}
\hadithdefcmd{bukhari}{1873}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ كَانَ يَقُولُ لَوْ رَأَيْتُ الظِّبَاءَ بِالْمَدِينَةِ تَرْتَعُ مَا ذَعَرْتُهَا، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا بَيْنَ لاَبَتَيْهَا حَرَامٌ ‏"‏‏.‏\hadithno{1873}\hadithtrans{Narrated Abu Huraira:If I saw deers grazing in Medina, I would not chase them, for Allah's Messenger (ﷺ) said, "(Medina) is a sanctuary between its two mountains}}
\hadithdefcmd{bukhari}{1874}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَتْرُكُونَ الْمَدِينَةَ عَلَى خَيْرِ مَا كَانَتْ، لاَ يَغْشَاهَا إِلاَّ الْعَوَافِ ـ يُرِيدُ عَوَافِيَ السِّبَاعِ وَالطَّيْرِ ـ وَآخِرُ مَنْ يُحْشَرُ رَاعِيَانِ مِنْ مُزَيْنَةَ، يُرِيدَانِ الْمَدِينَةَ يَنْعِقَانِ بِغَنَمِهِمَا، فَيَجِدَانِهَا وَحْشًا، حَتَّى إِذَا بَلَغَا ثَنِيَّةَ الْوَدَاعِ خَرَّا عَلَى وُجُوهِهِمَا ‏"‏‏.‏\hadithno{1874}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "The people will leave Medina in spite of the best state it will have, and none except the wild birds and the beasts of prey will live in it, and the last persons who will die will be two shepherds from the tribe of Muzaina, who will be driving their sheep towards Medina, but will find nobody in it, and when they reach the valley of Thaniyat-al-Wada`, they will fall down on their faces dead}}
\hadithdefcmd{bukhari}{1875}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ سُفْيَانَ بْنِ أَبِي زُهَيْرٍ ـ رضى الله عنه ـ أَنَّهُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تُفْتَحُ الْيَمَنُ فَيَأْتِي قَوْمٌ يُبِسُّونَ، فَيَتَحَمَّلُونَ بِأَهْلِيهِمْ وَمَنْ أَطَاعَهُمْ، وَالْمَدِينَةُ خَيْرٌ لَهُمْ لَوْ كَانُوا يَعْلَمُونَ، وَتُفْتَحُ الشَّأْمُ، فَيَأْتِي قَوْمٌ يُبِسُّونَ فَيَتَحَمَّلُونَ بِأَهْلِيهِمْ وَمَنْ أَطَاعَهُمْ، وَالْمَدِينَةُ خَيْرٌ لَهُمْ لَوْ كَانُوا يَعْلَمُونَ، وَتُفْتَحُ الْعِرَاقُ، فَيَأْتِي قَوْمٌ يُبِسُّونَ فَيَتَحَمَّلُونَ بِأَهْلِيهِمْ وَمَنْ أَطَاعَهُمْ‏.‏ وَالْمَدِينَةُ خَيْرٌ لَهُمْ لَوْ كَانُوا يَعْلَمُونَ ‏"‏‏.‏\hadithno{1875}\hadithtrans{Narrated Sufyan b. Abu Zuhair:I heard Allah's Messenger (ﷺ) saying, "Yemen will be conquered and some people will migrate (from Medina) and will urge their families, and those who will obey them to migrate (to Yemen) although Medina will be better for them; if they but knew. Sham will also be conquered and some people will migrate (from Medina) and will urge their families and those who will obey them, to migrate (to Sham) although Medina will be better for them; if they but knew. 'Iraq will be conquered and some people will migrate (from Medina) and will urge their families and those who will obey them to migrate (to 'Iraq) although Medina will be better for them; if they but knew}}
\hadithdefcmd{bukhari}{1876}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، قَالَ حَدَّثَنِي عُبَيْدُ اللَّهِ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الإِيمَانَ لَيَأْرِزُ إِلَى الْمَدِينَةِ كَمَا تَأْرِزُ الْحَيَّةُ إِلَى جُحْرِهَا ‏"‏‏.‏\hadithno{1876}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Verily, Belief returns and goes back to Medina as a snake returns and goes back to its hole (when in danger)}}
\hadithdefcmd{bukhari}{1877}{حَدَّثَنَا حُسَيْنُ بْنُ حُرَيْثٍ، أَخْبَرَنَا الْفَضْلُ، عَنْ جُعَيْدٍ، عَنْ عَائِشَةَ، قَالَتْ سَمِعْتُ سَعْدًا ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَكِيدُ أَهْلَ الْمَدِينَةِ أَحَدٌ إِلاَّ انْمَاعَ كَمَا يَنْمَاعُ الْمِلْحُ فِي الْمَاءِ ‏"‏‏.‏\hadithno{1877}\hadithtrans{Narrated Sa`d:I heard the Prophet (ﷺ) saying, "None plots against the people of Medina but that he will be dissolved (destroyed) like the salt is dissolved in water}}
\hadithdefcmd{bukhari}{1878}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا ابْنُ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ، سَمِعْتُ أُسَامَةَ ـ رضى الله عنه ـ قَالَ أَشْرَفَ النَّبِيُّ صلى الله عليه وسلم عَلَى أُطُمٍ مِنْ آطَامِ الْمَدِينَةِ فَقَالَ ‏ "‏ هَلْ تَرَوْنَ مَا أَرَى إِنِّي لأَرَى مَوَاقِعَ الْفِتَنِ خِلاَلَ بُيُوتِكُمْ كَمَوَاقِعِ الْقَطْرِ ‏"‏‏.‏ تَابَعَهُ مَعْمَرٌ وَسُلَيْمَانُ بْنُ كَثِيرٍ عَنِ الزُّهْرِيِّ‏.‏\hadithno{1878}\hadithtrans{Narrated Usama:Once the Prophet (ﷺ) stood at the top of a (looked out from upon one) castle amongst the castles (or the high buildings) of Medina and said, "Do you see what I see? (No doubt) I see the spots where afflictions will take place among your houses (and these afflictions will be) as numerous as the spots where raindrops fall}}
\hadithdefcmd{bukhari}{1879}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ أَبِي بَكْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَدْخُلُ الْمَدِينَةَ رُعْبُ الْمَسِيحِ الدَّجَّالِ، لَهَا يَوْمَئِذٍ سَبْعَةُ أَبْوَابٍ، عَلَى كُلِّ باب مَلَكَانِ ‏"‏‏.‏\hadithno{1879}\hadithtrans{Narrated Abu Bakra:The Prophet (ﷺ) said, "The terror caused by Al-Masih Ad-Dajjal will not enter Medina and at that time Medina will have seven gates and there will be two angels at each gate guarding them}}
\hadithdefcmd{bukhari}{1880}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نُعَيْمِ بْنِ عَبْدِ اللَّهِ الْمُجْمِرِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ ‏ "‏ عَلَى أَنْقَابِ الْمَدِينَةِ مَلاَئِكَةٌ، لاَ يَدْخُلُهَا الطَّاعُونُ وَلاَ الدَّجَّالُ ‏"‏‏.‏\hadithno{1880}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There are angels guarding the entrances (or roads) of Medina, neither plague nor Ad-Dajjal will be able to enter it}}
\hadithdefcmd{bukhari}{1881}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا أَبُو عَمْرٍو، حَدَّثَنَا إِسْحَاقُ، حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ مِنْ بَلَدٍ إِلاَّ سَيَطَؤُهُ الدَّجَّالُ، إِلاَّ مَكَّةَ وَالْمَدِينَةَ، لَيْسَ لَهُ مِنْ نِقَابِهَا نَقْبٌ إِلاَّ عَلَيْهِ الْمَلاَئِكَةُ صَافِّينَ، يَحْرُسُونَهَا، ثُمَّ تَرْجُفُ الْمَدِينَةُ بِأَهْلِهَا ثَلاَثَ رَجَفَاتٍ، فَيُخْرِجُ اللَّهُ كُلَّ كَافِرٍ وَمُنَافِقٍ ‏"‏‏.‏\hadithno{1881}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "There will be no town which Ad-Dajjal will not enter except Mecca and Medina, and there will be no entrance (road) (of both Mecca and Medina) but the angels will be standing in rows guarding it against him, and then Medina will shake with its inhabitants thrice (i.e. three earthquakes will take place) and Allah will expel all the non-believers and the hypocrites from it}}
\hadithdefcmd{bukhari}{1882}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ قَالَ حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم حَدِيثًا طَوِيلاً عَنِ الدَّجَّالِ، فَكَانَ فِيمَا حَدَّثَنَا بِهِ أَنْ قَالَ ‏ "‏ يَأْتِي الدَّجَّالُ ـ وَهُوَ مُحَرَّمٌ عَلَيْهِ أَنْ يَدْخُلَ نِقَابَ الْمَدِينَةِ ـ بَعْضَ السِّبَاخِ الَّتِي بِالْمَدِينَةِ، فَيَخْرُجُ إِلَيْهِ يَوْمَئِذٍ رَجُلٌ، هُوَ خَيْرُ النَّاسِ ـ أَوْ مِنْ خَيْرِ النَّاسِ ـ فَيَقُولُ أَشْهَدُ أَنَّكَ الدَّجَّالُ، الَّذِي حَدَّثَنَا عَنْكَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَدِيثَهُ، فَيَقُولُ الدَّجَّالُ أَرَأَيْتَ إِنْ قَتَلْتُ هَذَا ثُمَّ أَحْيَيْتُهُ، هَلْ تَشُكُّونَ فِي الأَمْرِ فَيَقُولُونَ لاَ‏.‏ فَيَقْتُلُهُ، ثُمَّ يُحْيِيهِ فَيَقُولُ حِينَ يُحْيِيهِ وَاللَّهِ مَا كُنْتُ قَطُّ أَشَدَّ بَصِيرَةً مِنِّي الْيَوْمَ، فَيَقُولُ الدَّجَّالُ أَقْتُلُهُ فَلاَ أُسَلَّطُ عَلَيْهِ ‏"‏‏.‏\hadithno{1882}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) told us a long narrative about Ad-Dajjal, and among the many things he mentioned, was his saying, "Ad-Dajjal will come and it will be forbidden for him to pass through the entrances of Medina. He will land in some of the salty barren areas (outside) Medina; on that day the best man or one of the best men will come up to him and say, 'I testify that you are the same Dajjal whose description was given to us by Allah's Messenger (ﷺ) .' Ad-Dajjal will say to the people, 'If I kill this man and bring him back to life again, will you doubt my claim?' They will say, 'No.' Then Ad-Dajjal will kill that man and bring him back to life. That man will say, 'Now I know your reality better than before.' Ad-Dajjal will say, 'I want to kill him but I cannot}}
\hadithdefcmd{bukhari}{1883}{حَدَّثَنَا عَمْرُو بْنُ عَبَّاسٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ ـ رضى الله عنه ـ جَاءَ أَعْرَابِيٌّ النَّبِيَّ صلى الله عليه وسلم فَبَايَعَهُ عَلَى الإِسْلاَمِ، فَجَاءَ مِنَ الْغَدِ مَحْمُومًا، فَقَالَ أَقِلْنِي، فَأَبَى ثَلاَثَ مِرَارٍ، فَقَالَ ‏ "‏ الْمَدِينَةُ كَالْكِيرِ، تَنْفِي خَبَثَهَا، وَيَنْصَعُ طَيِّبُهَا ‏"‏‏.‏\hadithno{1883}\hadithtrans{Narrated Jabir:A bedouin came to the Prophet (ﷺ) and gave a pledge of allegiance for embracing Islam. The next day he came with fever and said (to the Prophet (ﷺ) ), "Please cancel my pledge (of embracing Islam and of emigrating to Medina)." The Prophet (ﷺ) refused (that request) three times and said, "Medina is like a furnace, it expels out the impurities (bad persons) and selects the good ones and makes them perfect}}
\hadithdefcmd{bukhari}{1884}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ سَمِعْتُ زَيْدَ بْنَ ثَابِتٍ ـ رضى الله عنه ـ يَقُولُ لَمَّا خَرَجَ النَّبِيُّ صلى الله عليه وسلم إِلَى أُحُدٍ رَجَعَ نَاسٌ مِنْ أَصْحَابِهِ فَقَالَتْ فِرْقَةٌ نَقْتُلُهُمْ‏.‏ وَقَالَتْ فِرْقَةٌ لاَ نَقْتُلُهُمْ‏.‏ فَنَزَلَتْ ‏\{‏فَمَا لَكُمْ فِي الْمُنَافِقِينِ فِئَتَيْنِ‏\}‏ وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّهَا تَنْفِي الرِّجَالَ كَمَا تَنْفِي النَّارُ خَبَثَ الْحَدِيدِ ‏"‏‏.‏\hadithno{1884}\hadithtrans{Narrated Zaid bin Thabit:When the Prophet (ﷺ) went out for (the battle of) Uhud, some of his companions (hypocrites) returned (home). A party of the believers remarked that they would kill those (hypocrites) who had returned, but another party said that they would not kill them. So, this Divine Inspiration was revealed: "Then what is the matter with you that you are divided into two parties concerning the hypocrites." (4.88) The Prophet (ﷺ) said, "Medina expels the bad persons from it, as fire expels the impurities of iron}}
\hadithdefcmd{bukhari}{1885}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي، سَمِعْتُ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ اجْعَلْ بِالْمَدِينَةِ ضِعْفَىْ مَا جَعَلْتَ بِمَكَّةَ مِنَ الْبَرَكَةِ ‏"‏‏.‏ تَابَعَهُ عُثْمَانُ بْنُ عُمَرَ عَنْ يُونُسَ‏.‏\hadithno{1885}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "O Allah! Bestow on Medina twice the blessings You bestowed on Mecca}}
\hadithdefcmd{bukhari}{1886}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا قَدِمَ مِنْ سَفَرٍ، فَنَظَرَ إِلَى جُدُرَاتِ الْمَدِينَةِ أَوْضَعَ رَاحِلَتَهُ، وَإِنْ كَانَ عَلَى دَابَّةٍ، حَرَّكَهَا مِنْ حُبِّهَا‏.‏\hadithno{1886}\hadithtrans{Narrated Anas:Whenever the Prophet (ﷺ) returned from a journey and observed the walls of Medina, he would make his Mount go fast, and if he was on an animal (i.e. a horse), he would make it gallop because of his love for Medina}}
\hadithdefcmd{bukhari}{1887}{حَدَّثَنَا ابْنُ سَلاَمٍ، أَخْبَرَنَا الْفَزَارِيُّ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ أَرَادَ بَنُو سَلِمَةَ أَنْ يَتَحَوَّلُوا، إِلَى قُرْبِ الْمَسْجِدِ، فَكَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُعْرَى الْمَدِينَةُ، وَقَالَ ‏ "‏ يَا بَنِي سَلِمَةَ‏.‏ أَلاَ تَحْتَسِبُونَ آثَارَكُمْ ‏"‏‏.‏ فَأَقَامُوا‏.‏\hadithno{1887}\hadithtrans{Narrated Anas:(The people of) Bani Salama intended to shift near the mosque (of the Prophet) but Allah's Messenger (ﷺ) disliked to see Medina vacated and said, "O the people of Bani Salama! Don't you think that you will be rewarded for your footsteps which you take towards the mosque?" So, they stayed at their old places}}
\hadithdefcmd{bukhari}{1888}{حَدَّثَنَا مُسَدَّدٌ، عَنْ يَحْيَى، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، قَالَ حَدَّثَنِي خُبَيْبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا بَيْنَ بَيْتِي وَمِنْبَرِي رَوْضَةٌ مِنْ رِيَاضِ الْجَنَّةِ، وَمِنْبَرِي عَلَى حَوْضِي ‏"‏‏.‏\hadithno{1888}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "There is a garden from the gardens of Paradise between my house and my pulpit, and my pulpit is on my Lake Fount (Al-Kauthar)}}
\hadithdefcmd{bukhari}{1889}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ وُعِكَ أَبُو بَكْرٍ وَبِلاَلٌ، فَكَانَ أَبُو بَكْرٍ إِذَا أَخَذَتْهُ الْحُمَّى يَقُولُ كُلُّ امْرِئٍ مُصَبَّحٌ فِي أَهْلِهِ وَالْمَوْتُ أَدْنَى مِنْ شِرَاكِ نَعْلِهِ وَكَانَ بِلاَلٌ إِذَا أُقْلِعَ عَنْهُ الْحُمَّى يَرْفَعُ عَقِيرَتَهُ يَقُولُ أَلاَ لَيْتَ شِعْرِي هَلْ أَبِيتَنَّ لَيْلَةً بِوَادٍ وَحَوْلِي إِذْخِرٌ وَجَلِيلُ وَهَلْ أَرِدَنْ يَوْمًا مِيَاهَ مَجَنَّةٍ وَهَلْ يَبْدُوَنْ لِي شَامَةٌ وَطَفِيلُ قَالَ اللَّهُمَّ الْعَنْ شَيْبَةَ بْنَ رَبِيعَةَ، وَعُتْبَةَ بْنَ رَبِيعَةَ، وَأُمَيَّةَ بْنَ خَلَفٍ، كَمَا أَخْرَجُونَا مِنْ أَرْضِنَا إِلَى أَرْضِ الْوَبَاءِ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ حَبِّبْ إِلَيْنَا الْمَدِينَةَ كَحُبِّنَا مَكَّةَ أَوْ أَشَدَّ، اللَّهُمَّ بَارِكْ لَنَا فِي صَاعِنَا، وَفِي مُدِّنَا، وَصَحِّحْهَا لَنَا وَانْقُلْ حُمَّاهَا إِلَى الْجُحْفَةِ ‏"‏‏.‏ قَالَتْ وَقَدِمْنَا الْمَدِينَةَ، وَهْىَ أَوْبَأُ أَرْضِ اللَّهِ‏.‏ قَالَتْ فَكَانَ بُطْحَانُ يَجْرِي نَجْلاً‏.‏ تَعْنِي مَاءً آجِنًا‏.‏\hadithno{1889}\hadithtrans{Narrated `Aisha:When Allah's Messenger (ﷺ) reached Medina, Abu Bakr and Bilal became ill. When Abu Bakr's fever got worse, he would recite (this poetic verse): "Everybody is staying alive with his People, yet Death is nearer to him than His shoe laces." And Bilal, when his fever deserted him, would recite: "Would that I could stay overnight in A valley wherein I would be Surrounded by Idhkhir and Jalil (kinds of goodsmelling grass). Would that one day I could Drink the water of the Majanna, and Would that (The two mountains) Shama and Tafil would appear to me!" The Prophet (ﷺ) said, "O Allah! Curse Shaiba bin Rabi`a and `Utba bin Rabi`a and Umaiya bin Khalaf as they turned us out of our land to the land of epidemics." Allah's Messenger (ﷺ) then said, "O Allah! Make us love Medina as we love Mecca or even more than that. O Allah! Give blessings in our Sa and our Mudd (measures symbolizing food) and make the climate of Medina suitable for us, and divert its fever towards Al-juhfa." Aisha added: When we reached Medina, it was the most unhealthy of Allah's lands, and the valley of Buthan (the valley of Medina) used to flow with impure colored water}}
\hadithdefcmd{bukhari}{1890}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ خَالِدِ بْنِ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عُمَرَ ـ رضى الله عنه ـ قَالَ اللَّهُمَّ ارْزُقْنِي شَهَادَةً فِي سَبِيلِكَ، وَاجْعَلْ مَوْتِي فِي بَلَدِ رَسُولِكَ صلى الله عليه وسلم‏.‏ وَقَالَ ابْنُ زُرَيْعٍ عَنْ رَوْحِ بْنِ الْقَاسِمِ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أُمِّهِ، عَنْ حَفْصَةَ بِنْتِ عُمَرَ ـ رضى الله عنهما ـ قَالَتْ سَمِعْتُ عُمَرَ، نَحْوَهُ‏.‏ وَقَالَ هِشَامٌ عَنْ زَيْدٍ، عَنْ أَبِيهِ، عَنْ حَفْصَةَ، سَمِعْتُ عُمَرَ، رضى الله عنه‏.‏\hadithno{1890}\hadithtrans{Narrated Zaid bin Aslam from his father:`Umar said, O Allah! Grant me martyrdom in Your cause, and let my death be in the city of Your Apostle}}
