% Auto-generated chapter 37 for bukhari
% Hadiths in this chapter: 25

\hadithdefcmd{bukhari}{2260}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي بُرْدَةَ، قَالَ أَخْبَرَنِي جَدِّي أَبُو بُرْدَةَ، عَنْ أَبِيهِ أَبِي مُوسَى الأَشْعَرِيِّ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيَّ صلى الله عليه وسلم ‏ "‏ الْخَازِنُ الأَمِينُ الَّذِي يُؤَدِّي مَا أُمِرَ بِهِ طَيِّبَةً نَفْسُهُ أَحَدُ الْمُتَصَدِّقَيْنِ ‏"‏‏.‏\hadithno{2260}\hadithtrans{Narrated Abu Musa Al-Ash`ari:The Prophet (ﷺ) said, "The honest treasurer who gives willingly what he is ordered to give, is one of the two charitable persons, (the second being the owner)}}
\hadithdefcmd{bukhari}{2261}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ قُرَّةَ بْنِ خَالِدٍ، قَالَ حَدَّثَنِي حُمَيْدُ بْنُ هِلاَلٍ، حَدَّثَنَا أَبُو بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ أَقْبَلْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَمَعِي رَجُلاَنِ مِنَ الأَشْعَرِيِّينَ، فَقُلْتُ مَا عَلِمْتُ أَنَّهُمَا يَطْلُبَانِ الْعَمَلَ‏.‏ فَقَالَ ‏ "‏ لَنْ أَوْ لاَ نَسْتَعْمِلُ عَلَى عَمَلِنَا مَنْ أَرَادَهُ ‏"‏‏.‏\hadithno{2261}\hadithtrans{Narrated Abu Musa:I went to the Prophet (ﷺ) with two men from Ash`ari tribe. I said (to the Prophet), "I do not know that they want employment." The Prophet (ﷺ) said, "No, we do not appoint for our jobs anybody who demands it earnestly}}
\hadithdefcmd{bukhari}{2262}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَكِّيُّ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، عَنْ جَدِّهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَا بَعَثَ اللَّهُ نَبِيًّا إِلاَّ رَعَى الْغَنَمَ ‏"‏‏.‏ فَقَالَ أَصْحَابُهُ وَأَنْتَ فَقَالَ ‏"‏ نَعَمْ كُنْتُ أَرْعَاهَا عَلَى قَرَارِيطَ لأَهْلِ مَكَّةَ ‏"‏‏.‏\hadithno{2262}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah did not send any prophet but shepherded sheep." His companions asked him, "Did you do the same?" The Prophet (ﷺ) replied, "Yes, I used to shepherd the sheep of the people of Mecca for some Qirats}}
\hadithdefcmd{bukhari}{2263}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ وَاسْتَأْجَرَ النَّبِيُّ صلى الله عليه وسلم وَأَبُو بَكْرٍ رَجُلاً مِنْ بَنِي الدِّيلِ ثُمَّ مِنْ بَنِي عَبْدِ بْنِ عَدِيٍّ هَادِيًا خِرِّيتًا ـ الْخِرِّيتُ الْمَاهِرُ بِالْهِدَايَةِ ـ قَدْ غَمَسَ يَمِينَ حِلْفٍ فِي آلِ الْعَاصِ بْنِ وَائِلٍ، وَهْوَ عَلَى دِينِ كُفَّارِ قُرَيْشٍ، فَأَمِنَاهُ فَدَفَعَا إِلَيْهِ رَاحِلَتَيْهِمَا، وَوَعَدَاهُ غَارَ ثَوْرٍ بَعْدَ ثَلاَثِ لَيَالٍ، فَأَتَاهُمَا بِرَاحِلَتَيْهِمَا، صَبِيحَةَ لَيَالٍ ثَلاَثٍ، فَارْتَحَلاَ، وَانْطَلَقَ مَعَهُمَا عَامِرُ بْنُ فُهَيْرَةَ، وَالدَّلِيلُ الدِّيلِيُّ فَأَخَذَ بِهِمْ أَسْفَلَ مَكَّةَ وَهْوَ طَرِيقُ السَّاحِلِ‏.‏\hadithno{2263}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) and Abu Bakr employed a (pagan) man from the tribe of Bani Ad-Dail and the tribe of Bani 'Abu bin `Adi as a guide. He was an expert guide and he broke the oath contract which he had to abide by with the tribe of Al-`Asi bin Wail and he was on the religion of Quraish pagans. The Prophet (ﷺ) and Abu Bakr had confidence in him and gave him their riding camels and told him to bring them to the Cave of Thaur after three days. So, he brought them their two riding camels after three days and both of them (The Prophet (ﷺ) and Abu Bakr) set out accompanied by 'Amir bin Fuhaira and the Dili guide who guided them below Mecca along the road leading to the sea-shore}}
\hadithdefcmd{bukhari}{2264}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ وَاسْتَأْجَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ رَجُلاً مِنْ بَنِي الدِّيلِ، هَادِيًا خِرِّيتًا وَهْوَ عَلَى دِينِ كُفَّارِ قُرَيْشٍ، فَدَفَعَا إِلَيْهِ رَاحِلَتَيْهِمَا، وَوَاعَدَاهُ غَارَ ثَوْرٍ بَعْدَ ثَلاَثِ لَيَالٍ بِرَاحِلَتَيْهِمَا صُبْحَ ثَلاَثٍ‏.‏\hadithno{2264}\hadithtrans{Narrated Aisha:(the wife of the Prophet) Allah's Messenger (ﷺ) and Abu Bakr hired a man from the tribe of Bani-Ad-Dil as an expert guide who was a pagan (follower of the religion of the pagans of Quraish). The Prophet (ﷺ) and Abu Bakr gave him their two riding camels and took a promise from him to bring their riding camels in the morning of the third day to the Cave of Thaur}}
\hadithdefcmd{bukhari}{2266}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ صَفْوَانَ بْنِ يَعْلَى، عَنْ يَعْلَى بْنِ أُمَيَّةَ ـ رضى الله عنه ـ قَالَ غَزَوْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم جَيْشَ الْعُسْرَةِ فَكَانَ مِنْ أَوْثَقِ أَعْمَالِي فِي نَفْسِي، فَكَانَ لِي أَجِيرٌ، فَقَاتَلَ إِنْسَانًا، فَعَضَّ أَحَدُهُمَا إِصْبَعَ صَاحِبِهِ، فَانْتَزَعَ إِصْبَعَهُ، فَأَنْدَرَ ثَنِيَّتَهُ فَسَقَطَتْ، فَانْطَلَقَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَهْدَرَ ثَنِيَّتَهُ وَقَالَ ‏ "‏ أَفَيَدَعُ إِصْبَعَهُ فِي فِيكَ تَقْضَمُهَا ـ قَالَ أَحْسِبُهُ قَالَ ـ كَمَا يَقْضَمُ الْفَحْلُ ‏"‏‏.‏ قَالَ ابْنُ جُرَيْجٍ وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي مُلَيْكَةَ، عَنْ جَدِّهِ، بِمِثْلِ هَذِهِ الصِّفَةِ أَنَّ رَجُلاً، عَضَّ يَدَ رَجُلٍ، فَأَنْدَرَ ثَنِيَّتَهُ، فَأَهْدَرَهَا أَبُو بَكْرٍ رضى الله عنه‏.‏\hadithno{2266}\hadithtrans{Narrated Ya`la bin Umaiya:I fought in Jaish-al-Usra (Ghazwa of Tabuk) along with the Prophet (ﷺ) and in my opinion that was the best of my deeds. Then I had an employee, who quarrel led with someone and one of the them bit and cut the other's finger and caused his own tooth to fall out. He then went to the Prophet (with a complaint) but the Prophet (ﷺ) canceled the suit and said to the complainant, "Did you expect him to let his finger in your mouth so that you might snap and cut it (as does a stallion camel)?" Narrated Ibn Juraij from `Abdullah bin Abu Mulaika from his grandfather a similar story: A man bit the hand of another man and caused his own tooth to fall out, but Abu Bakr judged that he had no right for compensation (for the broken tooth)}}
\hadithdefcmd{bukhari}{2267}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي يَعْلَى بْنُ مُسْلِمٍ، وَعَمْرُو بْنُ دِينَارٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، يَزِيدُ أَحَدُهُمَا عَلَى صَاحِبِهِ، وَغَيْرُهُمَا قَالَ قَدْ سَمِعْتُهُ يُحَدِّثُهُ عَنْ سَعِيدٍ قَالَ قَالَ لِي ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ حَدَّثَنِي أُبَىُّ بْنُ كَعْبٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَانْطَلَقَا فَوَجَدَا جِدَارًا يُرِيدُ أَنْ يَنْقَضَّ ‏"‏‏.‏ قَالَ سَعِيدٌ بِيَدِهِ هَكَذَا، وَرَفَعَ يَدَيْهِ فَاسْتَقَامَ، قَالَ يَعْلَى حَسِبْتُ أَنَّ سَعِيدًا قَالَ‏.‏ فَمَسَحَهُ بِيَدِهِ فَاسْتَقَامَ ‏\{‏قَالَ‏\}‏ ‏"‏لَوْ شِئْتَ لاَتَّخَذْتَ عَلَيْهِ أَجْرًا ‏"‏‏.‏ قَالَ سَعِيدٌ أَجْرًا نَأْكُلُهُ‏.‏\hadithno{2267}\hadithtrans{Narrated Ubai bin Ka`b:Allah's Messenger (ﷺ) said, "Both of them (Moses and Al-Khadir) proceeded on till they reached a wall which was about to fall." Sa`d said [?? or Sa`id], "(Al-Khadir pointed) with his hands (towards the wall) and then raised his hands and the wall became straightened up." Ya`la said, "I think Sa`id [?? or Sa`d] said, 'He (Khadir) passed his hand over it and it was straightened up." (Moses said to him), "if you had wanted, you could have taken wages for it." Sa`id [?? or Sa`d] said, "Wages with which to buy food}}
\hadithdefcmd{bukhari}{2268}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُكُمْ وَمَثَلُ أَهْلِ الْكِتَابَيْنِ كَمَثَلِ رَجُلٍ اسْتَأْجَرَ أُجَرَاءَ فَقَالَ مَنْ يَعْمَلُ لِي مِنْ غُدْوَةَ إِلَى نِصْفِ النَّهَارِ عَلَى قِيرَاطٍ فَعَمِلَتِ الْيَهُودُ، ثُمَّ قَالَ مَنْ يَعْمَلُ لِي مِنْ نِصْفِ النَّهَارِ إِلَى صَلاَةِ الْعَصْرِ عَلَى قِيرَاطٍ فَعَمِلَتِ النَّصَارَى ثُمَّ، قَالَ مَنْ يَعْمَلُ لِي مِنَ الْعَصْرِ إِلَى أَنْ تَغِيبَ الشَّمْسُ عَلَى قِيرَاطَيْنِ فَأَنْتُمْ هُمْ، فَغَضِبَتِ الْيَهُودُ وَالنَّصَارَى، فَقَالُوا مَا لَنَا أَكْثَرَ عَمَلاً، وَأَقَلَّ عَطَاءً قَالَ هَلْ نَقَصْتُكُمْ مِنْ حَقِّكُمْ قَالُوا لاَ‏.‏ قَالَ فَذَلِكَ فَضْلِي أُوتِيهِ مَنْ أَشَاءُ ‏"‏‏.‏\hadithno{2268}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "Your example and the example of the people of the two Scriptures (i.e. Jews and Christians) is like the example of a man who employed some laborers and asked them, 'Who will work for me from morning till midday for one Qirat?' The Jews accepted and carried out the work. He then asked, Who will work for me from midday up to the `Asr prayer for one Qirat?' The Christians accepted and fulfilled the work. He then said, 'Who will work for me from the `Asr till sunset for two Qirats?' You, Muslims have accepted the offer. The Jews and the Christians got angry and said, 'Why should we work more and get lesser wages?' (Allah) said, 'Have I withheld part of your right?' They replied in the negative. He said, 'It is My Blessing, I bestow upon whomever I wish}}
\hadithdefcmd{bukhari}{2269}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا مَثَلُكُمْ وَالْيَهُودُ وَالنَّصَارَى كَرَجُلٍ اسْتَعْمَلَ عُمَّالاً فَقَالَ مَنْ يَعْمَلُ لِي إِلَى نِصْفِ النَّهَارِ عَلَى قِيرَاطٍ قِيرَاطٍ فَعَمِلَتِ الْيَهُودُ عَلَى قِيرَاطٍ قِيرَاطٍ، ثُمَّ عَمِلَتِ النَّصَارَى عَلَى قِيرَاطٍ قِيرَاطٍ، ثُمَّ أَنْتُمُ الَّذِينَ تَعْمَلُونَ مِنْ صَلاَةِ الْعَصْرِ إِلَى مَغَارِبِ الشَّمْسِ عَلَى قِيرَاطَيْنِ قِيرَاطَيْنِ، فَغَضِبَتِ الْيَهُودُ وَالنَّصَارَى وَقَالُوا نَحْنُ أَكْثَرُ عَمَلاً وَأَقَلُّ عَطَاءً، قَالَ هَلْ ظَلَمْتُكُمْ مِنْ حَقِّكُمْ شَيْئًا قَالُوا لاَ‏.‏ فَقَالَ فَذَلِكَ فَضْلِي أُوتِيهِ مَنْ أَشَاءُ ‏"‏‏.‏\hadithno{2269}\hadithtrans{Narrated `Abdullah bin `Umar bin Al-Khattab:Allah's Messenger (ﷺ) said, "Your example and the example of Jews and Christians is like the example of a man who employed some laborers to whom he said, 'Who will work for me up to midday for one Qirat each?' The Jews carried out the work for one Qirat each; and then the Christians carried out the work up to the `Asr prayer for one Qirat each; and now you Muslims are working from the `Asr prayer up to sunset for two Qirats each. The Jews and Christians got angry and said, 'We work more and are paid less.' The employer (Allah) asked them, 'Have I usurped some of your right?' They replied in the negative. He said, 'That is My Blessing, I bestow upon whomever I wish}}
\hadithdefcmd{bukhari}{2270}{حَدَّثَنَا يُوسُفُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي يَحْيَى بْنُ سُلَيْمٍ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ اللَّهُ تَعَالَى ثَلاَثَةٌ أَنَا خَصْمُهُمْ يَوْمَ الْقِيَامَةِ رَجُلٌ أَعْطَى بِي ثُمَّ غَدَرَ، وَرَجُلٌ بَاعَ حُرًّا فَأَكَلَ ثَمَنَهُ، وَرَجُلٌ اسْتَأْجَرَ أَجِيرًا فَاسْتَوْفَى مِنْهُ وَلَمْ يُعْطِهِ أَجْرَهُ ‏"‏‏.‏\hadithno{2270}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah said, 'I will be an opponent to three types of people on the Day of Resurrection: -1. One who makes a covenant in My Name, but proves treacherous; -2. One who sells a free person and eats his price; and -3. One who employs a laborer and takes full work from him but does not pay him for his lab our}}
\hadithdefcmd{bukhari}{2271}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الْمُسْلِمِينَ وَالْيَهُودِ وَالنَّصَارَى كَمَثَلِ رَجُلٍ اسْتَأْجَرَ قَوْمًا يَعْمَلُونَ لَهُ عَمَلاً يَوْمًا إِلَى اللَّيْلِ عَلَى أَجْرٍ مَعْلُومٍ، فَعَمِلُوا لَهُ إِلَى نِصْفِ النَّهَارِ فَقَالُوا لاَ حَاجَةَ لَنَا إِلَى أَجْرِكَ الَّذِي شَرَطْتَ لَنَا، وَمَا عَمِلْنَا بَاطِلٌ، فَقَالَ لَهُمْ لاَ تَفْعَلُوا أَكْمِلُوا بَقِيَّةَ عَمَلِكُمْ، وَخُذُوا أَجْرَكُمْ كَامِلاً، فَأَبَوْا وَتَرَكُوا، وَاسْتَأْجَرَ أَجِيرَيْنِ بَعْدَهُمْ فَقَالَ لَهُمَا أَكْمِلاَ بَقِيَّةَ يَوْمِكُمَا هَذَا، وَلَكُمَا الَّذِي شَرَطْتُ لَهُمْ مِنَ الأَجْرِ‏.‏ فَعَمِلُوا حَتَّى إِذَا كَانَ حِينُ صَلاَةِ الْعَصْرِ قَالاَ لَكَ مَا عَمِلْنَا بَاطِلٌ، وَلَكَ الأَجْرُ الَّذِي جَعَلْتَ لَنَا فِيهِ‏.‏ فَقَالَ لَهُمَا أَكْمِلاَ بَقِيَّةَ عَمَلِكُمَا، فَإِنَّ مَا بَقِيَ مِنَ النَّهَارِ شَىْءٌ يَسِيرٌ‏.‏ فَأَبَيَا، وَاسْتَأْجَرَ قَوْمًا أَنْ يَعْمَلُوا لَهُ بَقِيَّةَ يَوْمِهِمْ، فَعَمِلُوا بَقِيَّةَ يَوْمِهِمْ حَتَّى غَابَتِ الشَّمْسُ، وَاسْتَكْمَلُوا أَجْرَ الْفَرِيقَيْنِ كِلَيْهِمَا، فَذَلِكَ مَثَلُهُمْ وَمَثَلُ مَا قَبِلُوا مِنْ هَذَا النُّورِ ‏"‏‏.‏\hadithno{2271}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "The example of Muslims, Jews and Christians is like the example of a man who employed laborers to work for him from morning till night for specific wages. They worked till midday and then said, 'We do not need your money which you have fixed for us and let whatever we have done be annulled.' The man said to them, 'Don't quit the work, but complete the rest of it and take your full wages.' But they refused and went away. The man employed another batch after them and said to them, 'Complete the rest of the day and yours will be the wages I had fixed for the first batch.' So, they worked till the time of `Asr prayer. Then they said, "Let what we have done be annulled and keep the wages you have promised us for yourself.' The man said to them, 'Complete the rest of the work, as only a little of the day remains,' but they refused. Thereafter he employed another batch to work for the rest of the day and they worked for the rest of the day till the sunset, and they received the wages of the two former batches. So, that was the example of those people (Muslims) and the example of this light (guidance) which they have accepted willingly}}
\hadithdefcmd{bukhari}{2272}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ انْطَلَقَ ثَلاَثَةُ رَهْطٍ مِمَّنْ كَانَ قَبْلَكُمْ حَتَّى أَوَوُا الْمَبِيتَ إِلَى غَارٍ فَدَخَلُوهُ، فَانْحَدَرَتْ صَخْرَةٌ مِنَ الْجَبَلِ فَسَدَّتْ عَلَيْهِمُ الْغَارَ فَقَالُوا إِنَّهُ لاَ يُنْجِيكُمْ مِنْ هَذِهِ الصَّخْرَةِ إِلاَّ أَنْ تَدْعُوا اللَّهَ بِصَالِحِ أَعْمَالِكُمْ‏.‏ فَقَالَ رَجُلٌ مِنْهُمُ اللَّهُمَّ كَانَ لِي أَبَوَانِ شَيْخَانِ كَبِيرَانِ، وَكُنْتُ لاَ أَغْبِقُ قَبْلَهُمَا أَهْلاً وَلاَ مَالاً، فَنَأَى بِي فِي طَلَبِ شَىْءٍ يَوْمًا، فَلَمْ أُرِحْ عَلَيْهِمَا حَتَّى نَامَا، فَحَلَبْتُ لَهُمَا غَبُوقَهُمَا فَوَجَدْتُهُمَا نَائِمَيْنِ وَكَرِهْتُ أَنْ أَغْبِقَ قَبْلَهُمَا أَهْلاً أَوْ مَالاً، فَلَبِثْتُ وَالْقَدَحُ عَلَى يَدَىَّ أَنْتَظِرُ اسْتِيقَاظَهُمَا حَتَّى بَرَقَ الْفَجْرُ، فَاسْتَيْقَظَا فَشَرِبَا غَبُوقَهُمَا، اللَّهُمَّ إِنْ كُنْتُ فَعَلْتُ ذَلِكَ ابْتِغَاءَ وَجْهِكَ فَفَرِّجْ عَنَّا مَا نَحْنُ فِيهِ مِنْ هَذِهِ الصَّخْرَةِ، فَانْفَرَجَتْ شَيْئًا لاَ يَسْتَطِيعُونَ الْخُرُوجَ ‏"‏‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَقَالَ الآخَرُ اللَّهُمَّ كَانَتْ لِي بِنْتُ عَمٍّ كَانَتْ أَحَبَّ النَّاسِ إِلَىَّ، فَأَرَدْتُهَا عَنْ نَفْسِهَا، فَامْتَنَعَتْ مِنِّي حَتَّى أَلَمَّتْ بِهَا سَنَةٌ مِنَ السِّنِينَ، فَجَاءَتْنِي فَأَعْطَيْتُهَا عِشْرِينَ وَمِائَةَ دِينَارٍ عَلَى أَنْ تُخَلِّيَ بَيْنِي وَبَيْنَ نَفْسِهَا، فَفَعَلَتْ حَتَّى إِذَا قَدَرْتُ عَلَيْهَا قَالَتْ لاَ أُحِلُّ لَكَ أَنْ تَفُضَّ الْخَاتَمَ إِلاَّ بِحَقِّهِ‏.‏ فَتَحَرَّجْتُ مِنَ الْوُقُوعِ عَلَيْهَا، فَانْصَرَفْتُ عَنْهَا وَهْىَ أَحَبُّ النَّاسِ إِلَىَّ وَتَرَكْتُ الذَّهَبَ الَّذِي أَعْطَيْتُهَا، اللَّهُمَّ إِنْ كُنْتُ فَعَلْتُ ذَلِكَ ابْتِغَاءَ وَجْهِكَ فَافْرُجْ عَنَّا مَا نَحْنُ فِيهِ‏.‏ فَانْفَرَجَتِ الصَّخْرَةُ، غَيْرَ أَنَّهُمْ لاَ يَسْتَطِيعُونَ الْخُرُوجَ مِنْهَا‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم وَقَالَ الثَّالِثُ اللَّهُمَّ إِنِّي اسْتَأْجَرْتُ أُجَرَاءَ فَأَعْطَيْتُهُمْ أَجْرَهُمْ، غَيْرَ رَجُلٍ وَاحِدٍ تَرَكَ الَّذِي لَهُ وَذَهَبَ فَثَمَّرْتُ أَجْرَهُ حَتَّى كَثُرَتْ مِنْهُ الأَمْوَالُ، فَجَاءَنِي بَعْدَ حِينٍ فَقَالَ يَا عَبْدَ اللَّهِ أَدِّ إِلَىَّ أَجْرِي‏.‏ فَقُلْتُ لَهُ كُلُّ مَا تَرَى مِنْ أَجْرِكَ مِنَ الإِبِلِ وَالْبَقَرِ وَالْغَنَمِ وَالرَّقِيقِ‏.‏ فَقَالَ يَا عَبْدَ اللَّهِ لاَ تَسْتَهْزِئْ بِي‏.‏ فَقُلْتُ إِنِّي لاَ أَسْتَهْزِئُ بِكَ‏.‏ فَأَخَذَهُ كُلَّهُ فَاسْتَاقَهُ فَلَمْ يَتْرُكْ مِنْهُ شَيْئًا، اللَّهُمَّ فَإِنْ كُنْتُ فَعَلْتُ ذَلِكَ ابْتِغَاءَ وَجْهِكَ فَافْرُجْ عَنَّا مَا نَحْنُ فِيهِ‏.‏ فَانْفَرَجَتِ الصَّخْرَةُ فَخَرَجُوا يَمْشُونَ ‏"‏‏.‏\hadithno{2272}\hadithtrans{Narrated `Abdullah bin `Umar:I heard Allah's Messenger (ﷺ) saying, "Three men from among those who were before you, set out together till they reached a cave at night and entered it. A big rock rolled down the mountain and closed the mouth of the cave. They said (to each other), Nothing could save you from this rock but to invoke Allah by giving reference to the righteous deed which you have done (for Allah's sake only).' So, one of them said, 'O Allah! I had old parents and I never provided my family (wife, children etc.) with milk before them. One day, by chance I was delayed, and I came late (at night) while they had slept. I milked the sheep for them and took the milk to them, but I found them sleeping. I disliked to provide my family with the milk before them. I waited for them and the bowl of milk was in my hand and I kept on waiting for them to get up till the day dawned. Then they got up and drank the milk. O Allah! If I did that for Your Sake only, please relieve us from our critical situation caused by this rock.' So, the rock shifted a little but they could not get out." The Prophet (ﷺ) added, "The second man said, 'O Allah! I had a cousin who was the dearest of all people to me and I wanted to have sexual relations with her but she refused. Later she had a hard time in a famine year and she came to me and I gave her one-hundred-and-twenty Dinars on the condition that she would not resist my desire, and she agreed. When I was about to fulfill my desire, she said: It is illegal for you to outrage my chastity except by legitimate marriage. So, I thought it a sin to have sexual intercourse with her and left her though she was the dearest of all the people to me, and also I left the gold I had given her. O Allah! If I did that for Your Sake only, please relieve us from the present calamity.' So, the rock shifted a little more but still they could not get out from there." The Prophet (ﷺ) added, "Then the third man said, 'O Allah! I employed few laborers and I paid them their wages with the exception of one man who did not take his wages and went away. I invested his wages and I got much property thereby. (Then after some time) he came and said to me: O Allah's slave! Pay me my wages. I said to him: All the camels, cows, sheep and slaves you see, are yours. He said: O Allah's slave! Don't mock at me. I said: I am not mocking at you. So, he took all the herd and drove them away and left nothing. O Allah! If I did that for Your Sake only, please relieve us from the present suffering.' So, that rock shifted completely and they got out walking}}
\hadithdefcmd{bukhari}{2273}{حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى بْنِ سَعِيدٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ ـ رضى الله عنه ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَمَرَ بِالصَّدَقَةِ انْطَلَقَ أَحَدُنَا إِلَى السُّوقِ فَيُحَامِلُ فَيُصِيبُ الْمُدَّ، وَإِنَّ لِبَعْضِهِمْ لَمِائَةَ أَلْفٍ، قَالَ مَا نُرَاهُ إِلاَّ نَفْسَهُ‏.‏\hadithno{2273}\hadithtrans{Narrated Abu Mas'ud Al-Ansari:Whenever Allah's Messenger (ﷺ) ordered us to give in charity we would go to the market and work as porters to earn a Mudd (two handfuls) (of foodstuff) but now some of us have one-hundred thousand Dirhams or Dinars. (The sub-narrator) Shaqiq said, "I think Abu Mas`ud meant himself by saying (some of us)}}
\hadithdefcmd{bukhari}{2274}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُتَلَقَّى الرُّكْبَانُ، وَلاَ يَبِيعَ حَاضِرٌ لِبَادٍ‏.‏ قُلْتُ يَا ابْنَ عَبَّاسٍ مَا قَوْلُهُ لاَ يَبِيعُ حَاضِرٌ لِبَادٍ قَالَ لاَ يَكُونُ لَهُ سِمْسَارًا‏.‏\hadithno{2274}\hadithtrans{Narrated Tawus:Ibn `Abbas said, "The Prophet (ﷺ) forbade the meeting of caravans (on the way) and ordained that no townsman is permitted to sell things on behalf of a bedouin." I asked Ibn `Abbas, "What is the meaning of his saying, 'No townsman is permitted to sell things on behalf of a bedouin.' " He replied, "He should not work as a broker for him}}
\hadithdefcmd{bukhari}{2275}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، حَدَّثَنَا خَبَّابٌ، قَالَ كُنْتُ رَجُلاً قَيْنًا فَعَمِلْتُ لِلْعَاصِ بْنِ وَائِلٍ فَاجْتَمَعَ لِي عِنْدَهُ فَأَتَيْتُهُ أَتَقَاضَاهُ فَقَالَ لاَ وَاللَّهِ لاَ أَقْضِيكَ حَتَّى تَكْفُرَ بِمُحَمَّدٍ‏.‏ فَقُلْتُ أَمَا وَاللَّهِ حَتَّى تَمُوتَ ثُمَّ تُبْعَثَ فَلاَ‏.‏ قَالَ وَإِنِّي لَمَيِّتٌ ثُمَّ مَبْعُوثٌ قُلْتُ نَعَمْ‏.‏ قَالَ فَإِنَّهُ سَيَكُونُ لِي ثَمَّ مَالٌ وَوَلَدٌ فَأَقْضِيكَ‏.‏ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏أَفَرَأَيْتَ الَّذِي كَفَرَ بِآيَاتِنَا وَقَالَ لأُوتَيَنَّ مَالاً وَوَلَدًا‏\}‏\hadithno{2275}\hadithtrans{Narrated Khabbab:I was a blacksmith and did some work for Al-`As bin Wail. When he owed me some money for my work, I went to him to ask for that amount. He said, "I will not pay you unless you disbelieve in Muhammad." I said, "By Allah! I will never do that till you die and be resurrected." He said, "Will I be dead and then resurrected after my death?" I said, "Yes." He said, "There I will have property and offspring and then I will pay you your due." Then Allah revealed. 'Have you seen him who disbelieved in Our signs, and yet says: I will be given property and offspring?}}
\hadithdefcmd{bukhari}{2276}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ قَالَ انْطَلَقَ نَفَرٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فِي سَفْرَةٍ سَافَرُوهَا حَتَّى نَزَلُوا عَلَى حَىٍّ مِنْ أَحْيَاءِ الْعَرَبِ فَاسْتَضَافُوهُمْ، فَأَبَوْا أَنْ يُضَيِّفُوهُمْ، فَلُدِغَ سَيِّدُ ذَلِكَ الْحَىِّ، فَسَعَوْا لَهُ بِكُلِّ شَىْءٍ لاَ يَنْفَعُهُ شَىْءٌ، فَقَالَ بَعْضُهُمْ لَوْ أَتَيْتُمْ هَؤُلاَءِ الرَّهْطَ الَّذِينَ نَزَلُوا لَعَلَّهُ أَنْ يَكُونَ عِنْدَ بَعْضِهِمْ شَىْءٌ، فَأَتَوْهُمْ، فَقَالُوا يَا أَيُّهَا الرَّهْطُ، إِنَّ سَيِّدَنَا لُدِغَ، وَسَعَيْنَا لَهُ بِكُلِّ شَىْءٍ لاَ يَنْفَعُهُ، فَهَلْ عِنْدَ أَحَدٍ مِنْكُمْ مِنْ شَىْءٍ فَقَالَ بَعْضُهُمْ نَعَمْ وَاللَّهِ إِنِّي لأَرْقِي، وَلَكِنْ وَاللَّهِ لَقَدِ اسْتَضَفْنَاكُمْ فَلَمْ تُضِيِّفُونَا، فَمَا أَنَا بِرَاقٍ لَكُمْ حَتَّى تَجْعَلُوا لَنَا جُعْلاً‏.‏ فَصَالَحُوهُمْ عَلَى قَطِيعٍ مِنَ الْغَنَمِ، فَانْطَلَقَ يَتْفِلُ عَلَيْهِ وَيَقْرَأُ ‏\{‏الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ‏\}‏ فَكَأَنَّمَا نُشِطَ مِنْ عِقَالٍ، فَانْطَلَقَ يَمْشِي وَمَا بِهِ قَلَبَةٌ، قَالَ فَأَوْفَوْهُمْ جُعْلَهُمُ الَّذِي صَالَحُوهُمْ عَلَيْهِ، فَقَالَ بَعْضُهُمُ اقْسِمُوا‏.‏ فَقَالَ الَّذِي رَقَى لاَ تَفْعَلُوا، حَتَّى نَأْتِيَ النَّبِيَّ صلى الله عليه وسلم فَنَذْكُرَ لَهُ الَّذِي كَانَ، فَنَنْظُرَ مَا يَأْمُرُنَا‏.‏ فَقَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرُوا لَهُ، فَقَالَ ‏"‏ وَمَا يُدْرِيكَ أَنَّهَا رُقْيَةٌ ـ ثُمَّ قَالَ ـ قَدْ أَصَبْتُمُ اقْسِمُوا وَاضْرِبُوا لِي مَعَكُمْ سَهْمًا ‏"‏‏.‏ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ وَقَالَ شُعْبَةُ حَدَّثَنَا أَبُو بِشْرٍ سَمِعْتُ أَبَا الْمُتَوَكِّلِ بِهَذَا‏.‏\hadithno{2276}\hadithtrans{Narrated Abu Sa`id:Some of the companions of the Prophet (ﷺ) went on a journey till they reached some of the 'Arab tribes (at night). They asked the latter to treat them as their guests but they refused. The chief of that tribe was then bitten by a snake (or stung by a scorpion) and they tried their best to cure him but in vain. Some of them said (to the others), "Nothing has benefited him, will you go to the people who resided here at night, it may be that some of them might possess something (as treatment)," They went to the group of the companions (of the Prophet (ﷺ) ) and said, "Our chief has been bitten by a snake (or stung by a scorpion) and we have tried everything but he has not benefited. Have you got anything (useful)?" One of them replied, "Yes, by Allah! I can recite a Ruqya, but as you have refused to accept us as your guests, I will not recite the Ruqya for you unless you fix for us some wages for it." They agreed to pay them a flock of sheep. One of them then went and recited (Surat-ul-Fatiha): 'All the praises are for the Lord of the Worlds' and puffed over the chief who became all right as if he was released from a chain, and got up and started walking, showing no signs of sickness. They paid them what they agreed to pay. Some of them (i.e. the companions) then suggested to divide their earnings among themselves, but the one who performed the recitation said, "Do not divide them till we go to the Prophet (ﷺ) and narrate the whole story to him, and wait for his order." So, they went to Allah's Messenger (ﷺ) and narrated the story. Allah's Messenger (ﷺ) asked, "How did you come to know that Surat-ul-Fatiha was recited as Ruqya?" Then he added, "You have done the right thing. Divide (what you have earned) and assign a share for me as well." The Prophet (ﷺ) smiled thereupon}}
\hadithdefcmd{bukhari}{2277}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ حَجَمَ أَبُو طَيْبَةَ النَّبِيَّ صلى الله عليه وسلم، فَأَمَرَ لَهُ بِصَاعٍ أَوْ صَاعَيْنِ مِنْ طَعَامٍ، وَكَلَّمَ مَوَالِيَهُ فَخَفَّفَ عَنْ غَلَّتِهِ أَوْ ضَرِيبَتِهِ‏.‏\hadithno{2277}\hadithtrans{Narrated Anas bin Malik:When Abu Taiba cupped the Prophet (ﷺ) and the Prophet (ﷺ) ordered that he be paid one or two Sas of foodstuff and he interceded with his masters to reduce his taxes}}
\hadithdefcmd{bukhari}{2278}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ احْتَجَمَ النَّبِيُّ صلى الله عليه وسلم، وَأَعْطَى الْحَجَّامَ أَجْرَهُ‏.‏\hadithno{2278}\hadithtrans{Narrated Ibn `Abbas:When the Prophet (ﷺ) was cupped, he paid the man who cupped him his wages}}
\hadithdefcmd{bukhari}{2279}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ خَالِدٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ احْتَجَمَ النَّبِيُّ صلى الله عليه وسلم وَأَعْطَى الْحَجَّامَ أَجْرَهُ، وَلَوْ عَلِمَ كَرَاهِيَةً لَمْ يُعْطِهِ‏.‏\hadithno{2279}\hadithtrans{Narrated Ibn `Abbas:When the Prophet (ﷺ) was cupped, he paid the man who cupped him his wages. If it had been undesirable he would not have paid him}}
\hadithdefcmd{bukhari}{2280}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا مِسْعَرٌ، عَنْ عَمْرِو بْنِ عَامِرٍ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم يَحْتَجِمُ، وَلَمْ يَكُنْ يَظْلِمُ أَحَدًا أَجْرَهُ‏.‏\hadithno{2280}\hadithtrans{Narrated Anas:The Prophet (ﷺ) used to get cupped and would never withhold the wages of any person}}
\hadithdefcmd{bukhari}{2281}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ دَعَا النَّبِيُّ صلى الله عليه وسلم غُلاَمًا حَجَّامًا فَحَجَمَهُ، وَأَمَرَ لَهُ بِصَاعٍ أَوْ صَاعَيْنِ، أَوْ مُدٍّ أَوْ مُدَّيْنِ، وَكَلَّمَ فِيهِ فَخُفِّفَ مِنْ ضَرِيبَتِهِ‏.‏\hadithno{2281}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) sent for a slave who had the profession of cupping, and he cupped him. The Prophet (ﷺ) ordered that he be paid one or two Sas, or one or two Mudds of foodstuff, and appealed to his masters to reduce his taxes:}}
\hadithdefcmd{bukhari}{2282}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ ثَمَنِ الْكَلْبِ وَمَهْرِ الْبَغِيِّ وَحُلْوَانِ الْكَاهِنِ‏.‏\hadithno{2282}\hadithtrans{Narrated Abu Mas`ud Al-Ansari:Allah's Messenger (ﷺ) regarded illegal the price of a dog, the earnings of a prostitute, and the charges taken by a soothsayer}}
\hadithdefcmd{bukhari}{2283}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ جُحَادَةَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ كَسْبِ الإِمَاءِ‏.‏\hadithno{2283}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) prohibited the earnings of slave girls (through prostitution)}}
\hadithdefcmd{bukhari}{2284}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، وَإِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ عَلِيِّ بْنِ الْحَكَمِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ عَسْبِ الْفَحْلِ‏.‏\hadithno{2284}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) forbade taking a price for animal copulation}}
\hadithdefcmd{bukhari}{2286}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ بْنُ أَسْمَاءَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ أَعْطَى رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْبَرَ أَنْ يَعْمَلُوهَا وَيَزْرَعُوهَا وَلَهُمْ شَطْرُ مَا يَخْرُجُ مِنْهَا، وَأَنَّ ابْنَ عُمَرَ حَدَّثَهُ أَنَّ الْمَزَارِعَ كَانَتْ تُكْرَى عَلَى شَىْءٍ سَمَّاهُ نَافِعٌ لاَ أَحْفَظُهُ‏.‏ وَأَنَّ رَافِعَ بْنَ خَدِيجٍ حَدَّثَ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ كِرَاءِ الْمَزَارِعِ‏.‏ وَقَالَ عُبَيْدُ اللَّهِ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ حَتَّى أَجْلاَهُمْ عُمَرُ‏.‏\hadithno{2286}\hadithtrans{Narrated `Abdullah bin `Umar:"Allah's Messenger (ﷺ) gave the land of Khaibar to the Jews to work on and cultivate and take half of its yield. Ibn `Umar added, "The land used to be rented for a certain portion (of its yield)." Nafi` mentioned the amount of the portion but I forgot it. Rafi` bin Khadij said, "The Prophet (ﷺ) forbade renting farms." Narrated 'Ubaidullah Nafi` said: Ibn `Umar said: (The contract of Khaibar continued) till `Umar evacuated the Jews (from Khaibar)}}
