% Auto-generated chapter 42 for malik
% Hadiths in this chapter: 15

\hadithdefcmd{malik}{1537}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنِ السَّائِبِ بْنِ يَزِيدَ، أَنَّهُ أَخْبَرَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ خَرَجَ عَلَيْهِمْ فَقَالَ إِنِّي وَجَدْتُ مِنْ فُلاَنٍ رِيحَ شَرَابٍ فَزَعَمَ أَنَّهُ شَرَابُ الطِّلاَءِ وَأَنَا سَائِلٌ عَمَّا شَرِبَ فَإِنْ كَانَ يُسْكِرُ جَلَدْتُهُ ‏.‏ فَجَلَدَهُ عُمَرُ الْحَدَّ تَامًّا ‏.‏\hadithno{1537}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that as-Sa'ib ibn Yazid informed him that Umar ibn al-Khattab came out to them. He said, "I have found the smell of wine on so-and-so, and he claimed that it was the drink of boiled fruit juice, and I am inquiring about what he has drunk. If it intoxicates, I will flog him." Umar then flogged him with the complete hadd}}
\hadithdefcmd{malik}{1538}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، اسْتَشَارَ فِي الْخَمْرِ يَشْرَبُهَا الرَّجُلُ فَقَالَ لَهُ عَلِيُّ بْنُ أَبِي طَالِبٍ نَرَى أَنْ تَجْلِدَهُ ثَمَانِينَ فَإِنَّهُ إِذَا شَرِبَ سَكِرَ وَإِذَا سَكِرَ هَذَى وَإِذَا هَذَى افْتَرَى ‏.‏ أَوْ كَمَا قَالَ فَجَلَدَ عُمَرُ فِي الْخَمْرِ ثَمَانِينَ ‏.‏\hadithno{1538}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Thawr ibn Zayd ad-Dili that Umar ibn al-Khattab asked advice about a man drinking wine. Ali ibn Abi Talib said to him, "We think that you flog him for it with eighty lashes. Because when he drinks, he becomes intoxicated, and when he becomes intoxicated, he talks confusedly, and when he talks confusedly, he lies." (80 lashes is the same amount as for slandering) Umar gave eighty lashes for drinking wine}}
\hadithdefcmd{malik}{1539}{وَحَدَّثَنِي عَنِ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ سُئِلَ عَنْ حَدِّ الْعَبْدِ، فِي الْخَمْرِ فَقَالَ بَلَغَنِي أَنَّ عَلَيْهِ نِصْفَ حَدِّ الْحُرِّ فِي الْخَمْرِ وَأَنَّ عُمَرَ بْنَ الْخَطَّابِ وَعُثْمَانَ بْنَ عَفَّانَ وَعَبْدَ اللَّهِ بْنَ عُمَرَ قَدْ جَلَدُوا عَبِيدَهُمْ نِصْفَ حَدِّ الْحُرِّ فِي الْخَمْرِ ‏.‏\hadithno{1539}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that he was asked about the hadd of the slave for wine. He said, "I heard that he has half the hadd of a freeman for drinking wine. Umar ibn al-Khattab, Uthman ibn Affan, and Abdullah ibn Umar flogged their slaves with half of the hadd of a freeman when they drank wine}}
\hadithdefcmd{malik}{1540}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ مَا مِنْ شَىْءٍ إِلاَّ اللَّهُ يُحِبُّ أَنْ يُعْفَى عَنْهُ مَا لَمْ يَكُنْ حَدًّا ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ وَالسُّنَّةُ عِنْدَنَا أَنَّ كُلَّ مَنْ شَرِبَ شَرَابًا مُسْكِرًا فَسَكِرَ أَوْ لَمْ يَسْكَرْ فَقَدْ وَجَبَ عَلَيْهِ الْحَدُّ ‏.‏\hadithno{1540}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that he heard Said ibn al-Musayyab say, "There is nothing that Allah does not like to be pardoned as long as it is not a hadd." Yahya said that Malik said, "The sunna with us is that the hadd is obliged against anyone who drinks something intoxicating whether or not he becomes drunk}}
\hadithdefcmd{malik}{1541}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَطَبَ النَّاسَ فِي بَعْضِ مَغَازِيهِ - قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ - فَأَقْبَلْتُ نَحْوَهُ فَانْصَرَفَ قَبْلَ أَنْ أَبْلُغَهُ فَسَأَلْتُ مَاذَا قَالَ فَقِيلَ لِي نَهَى أَنْ يُنْبَذَ فِي الدُّبَّاءِ وَالْمُزَفَّتِ ‏.‏\hadithno{1541}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, addressed the people in one of his raids. Abdullah ibn Umar said, "I went towards him, but he finished before I reached him. I asked about what he had said. Someone said to me, 'He forbade preparing nabidh in a gourd or in a jug smeared with pitch}}
\hadithdefcmd{malik}{1542}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَعْقُوبَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يُنْبَذَ فِي الدُّبَّاءِ وَالْمُزَفَّتِ ‏.‏\hadithno{1542}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from al-Ala ibn Abd ar-Rahman ibn Yaqub from his father from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, forbade preparing nabidh in a gourd or in a jug smeared with pitch}}
\hadithdefcmd{malik}{1543}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يُنْبَذَ الْبُسْرُ وَالرُّطَبُ جَمِيعًا وَالتَّمْرُ وَالزَّبِيبُ جَمِيعًا ‏.‏\hadithno{1543}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar that the Messenger of Allah, may Allah bless him and grant him peace, forbade preparing nabidh from nearly ripe dates and fresh dates together, and from dates and raisins together}}
\hadithdefcmd{malik}{1544}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ الثِّقَةِ، عِنْدَهُ عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحُبَابِ الأَنْصَارِيِّ، عَنْ أَبِي قَتَادَةَ الأَنْصَارِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يُشْرَبَ التَّمْرُ وَالزَّبِيبُ جَمِيعًا وَالزَّهْوُ وَالرُّطَبُ جَمِيعًا ‏.‏\hadithno{1544}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from a reliable source from Bukayr ibn Abdullah ibn al-Ashajj from Abd ar-Rahman ibn al-Hubab al-Ansari from Abu Qatada al-Ansari that the Messenger of Allah, may Allah bless him and grant him peace, forbade making nabidh from dates and raisins together, and nearly ripe dates and fresh dates together. Malik said, "That is the way of doing things among us in which the people of knowledge in our city continue. It is disapproved of because the Messenger of Allah, may Allah bless him and grant him peace, forbade it}}
\hadithdefcmd{malik}{1545}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْبِتْعِ فَقَالَ ‏ "‏ كُلُّ شَرَابٍ أَسْكَرَ فَهُوَ حَرَامٌ ‏"‏ ‏.‏\hadithno{1545}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from ibn Shihab from Abu Salama ibn Abd ar-Rahman that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "The Messenger of Allah, may Allah bless him and grant him peace, was asked about mead, and he replied, 'Every drink which intoxicates is haram}}
\hadithdefcmd{malik}{1546}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الْغُبَيْرَاءِ فَقَالَ ‏ "‏ لاَ خَيْرَ فِيهَا ‏"‏ ‏.‏ وَنَهَى عَنْهَا ‏.‏ قَالَ مَالِكٌ فَسَأَلْتُ زَيْدَ بْنَ أَسْلَمَ مَا الْغُبَيْرَاءُ فَقَالَ هِيَ الأُسْكَرْكَةُ ‏.‏\hadithno{1546}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar that the Messenger of Allah, may Allah bless him and grant him peace, was asked about al-Ghubayra. He said, "There is no good in it," and forbade it. Malik said, "I asked Zayd ibn Aslam, 'What is al- Ghubayra?' He said, 'It is an intoxicant}}
\hadithdefcmd{malik}{1547}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ شَرِبَ الْخَمْرَ فِي الدُّنْيَا ثُمَّ لَمْ يَتُبْ مِنْهَا حُرِمَهَا فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{1547}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said "Whoever drinks wine in this world and does not turn from it in tawba, it is haram for him in the Next World}}
\hadithdefcmd{malik}{1548}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنِ ابْنِ وَعْلَةَ الْمِصْرِيِّ، ‏.‏ أَنَّهُ سَأَلَ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ عَمَّا يُعْصَرُ مِنَ الْعِنَبِ فَقَالَ ابْنُ عَبَّاسٍ أَهْدَى رَجُلٌ لِرَسُولِ اللَّهِ صلى الله عليه وسلم رَاوِيَةَ خَمْرٍ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا عَلِمْتَ أَنَّ اللَّهَ حَرَّمَهَا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ فَسَارَّهُ رَجُلٌ إِلَى جَنْبِهِ ‏.‏ فَقَالَ لَهُ صلى الله عليه وسلم ‏"‏ بِمَ سَارَرْتَهُ ‏"‏ ‏.‏ فَقَالَ أَمَرْتُهُ أَنْ يَبِيعَهَا ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الَّذِي حَرَّمَ شُرْبَهَا حَرَّمَ بَيْعَهَا ‏"‏ ‏.‏ فَفَتَحَ الرَّجُلُ الْمَزَادَتَيْنِ حَتَّى ذَهَبَ مَا فِيهِمَا ‏.‏\hadithno{1548}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that Ibn Wala al-Misri asked Abdullah ibn Abbas about what is squeezed from the grapes. Ibn Abbas replied, "A man gave the Messenger of Allah, may Allah bless him and grant him peace, a small water-skin of wine. The Messenger of Allah, may Allah bless him and grant him peace, said to him, 'Don't you know that Allah has made it haram?' He said, 'No.' Then a man at his side whispered to him. The Messenger of Allah, may Allah bless him and grant him peace, asked what he had whispered, and the man replied, 'I told him to sell it.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'The One who made drinking it haram has made selling it haram.' The man then opened the water- skins and poured out what was in them}}
\hadithdefcmd{malik}{1549}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ كُنْتُ أَسْقِي أَبَا عُبَيْدَةَ بْنَ الْجَرَّاحِ وَأَبَا طَلْحَةَ الأَنْصَارِيَّ وَأُبَىَّ بْنَ كَعْبٍ شَرَابًا مِنْ فَضِيخٍ وَتَمْرٍ - قَالَ - فَجَاءَهُمْ آتٍ فَقَالَ إِنَّ الْخَمْرَ قَدْ حُرِّمَتْ ‏.‏ فَقَالَ أَبُو طَلْحَةَ يَا أَنَسُ قُمْ إِلَى هَذِهِ الْجِرَارِ فَاكْسِرْهَا ‏.‏ قَالَ فَقُمْتُ إِلَى مِهْرَاسٍ لَنَا فَضَرَبْتُهَا بِأَسْفَلِهِ حَتَّى تَكَسَّرَتْ ‏.‏\hadithno{1549}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ishaq ibn Abdullah ibn Abi Talha that Anas ibn Malik said, "I was serving wine to Abu Ubayda ibn al-Jarrah and Abu Talha al-Ansari and Umayy ibn Kab. The wine had been prepared from crushed ripe dates and dried dates. Someone came to them and said, 'Wine has been made haram.' Abu Talha ordered me to go and take the jugs and break them. I stood up and went to a mortar of ours and I struck them with the bottom of it until they broke}}
\hadithdefcmd{malik}{1550}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ وَاقِدِ بْنِ عَمْرِو بْنِ سَعْدِ بْنِ مُعَاذٍ، أَنَّهُ أَخْبَرَهُ عَنْ مَحْمُودِ بْنِ لَبِيدٍ الأَنْصَارِيِّ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، حِينَ قَدِمَ الشَّامَ شَكَا إِلَيْهِ أَهْلُ الشَّامِ وَبَاءَ الأَرْضِ وَثِقَلَهَا وَقَالُوا لاَ يُصْلِحُنَا إِلاَّ هَذَا الشَّرَابُ ‏.‏ فَقَالَ عُمَرُ اشْرَبُوا هَذَا الْعَسَلَ ‏.‏ قَالُوا لاَ يُصْلِحُنَا الْعَسَلُ ‏.‏ فَقَالَ رَجُلٌ مِنْ أَهْلِ الأَرْضِ هَلْ لَكَ أَنْ نَجْعَلَ لَكَ مِنْ هَذَا الشَّرَابِ شَيْئًا لاَ يُسْكِرُ قَالَ نَعَمْ ‏.‏ فَطَبَخُوهُ حَتَّى ذَهَبَ مِنْهُ الثُّلُثَانِ وَبَقِيَ الثُّلُثُ فَأَتَوْا بِهِ عُمَرَ فَأَدْخَلَ فِيهِ عُمَرُ إِصْبَعَهُ ثُمَّ رَفَعَ يَدَهُ فَتَبِعَهَا يَتَمَطَّطُ فَقَالَ هَذَا الطِّلاَءُ هَذَا مِثْلُ طِلاَءِ الإِبِلِ ‏.‏ فَأَمَرَهُمْ عُمَرُ أَنْ يَشْرَبُوهُ فَقَالَ لَهُ عُبَادَةُ بْنُ الصَّامِتِ أَحْلَلْتَهَا وَاللَّهِ ‏.‏ فَقَالَ عُمَرُ كَلاَّ وَاللَّهِ اللَّهُمَّ إِنِّي لاَ أُحِلُّ لَهُمْ شَيْئًا حَرَّمْتَهُ عَلَيْهِمْ وَلاَ أُحَرِّمُ عَلَيْهِمْ شَيْئًا أَحْلَلْتَهُ لَهُمْ ‏.‏\hadithno{1550}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Da'ud ibn al-Husayn that Waqid ibn Amr ibn Sad ibn Muadh informed him from Mahmud ibn Labid al- Ansari that when Umar ibn al-Khattab went to ash-Sham, the people of ash-Sham complained to him about the bad air of their land and its heaviness. They said, "Only this drink helps." Umar said, "Drink this honey preparation." They said, "Honey does not help us." A man from the people of that land said, "Can we give you something of this drink which does not intoxicate?" He said, "Yes." They cooked it until two- thirds of it evaporated and one-third of it remained. Then they brought it to Umar. Umar put his finger in it and then lifted his head and extended it. He said, "This is fruit juice concentrated by boiling. This is like the distillation with which you smear the camel's scabs." Umar ordered them to drink it. Ubada ibn as-Samit said to him, "You have made it halal, by Allah!" Umar said, "No, by Allah! O Allah! I will not make anything halal for them which You have made haram for them! I will not make anything haram for them which You have made halal for them}}
\hadithdefcmd{malik}{1551}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رِجَالاً، مِنْ أَهْلِ الْعِرَاقِ قَالُوا لَهُ يَا أَبَا عَبْدِ الرَّحْمَنِ إِنَّا نَبْتَاعُ مِنْ ثَمَرِ النَّخْلِ وَالْعِنَبِ فَنَعْصِرُهُ خَمْرًا فَنَبِيعُهَا ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ إِنِّي أُشْهِدُ اللَّهَ عَلَيْكُمْ وَمَلاَئِكَتَهُ وَمَنْ سَمِعَ مِنَ الْجِنِّ وَالإِنْسِ أَنِّي لاَ آمُرُكُمْ أَنْ تَبِيعُوهَا وَلاَ تَبْتَاعُوهَا وَلاَ تَعْصِرُوهَا وَلاَ تَشْرَبُوهَا وَلاَ تَسْقُوهَا فَإِنَّهَا رِجْسٌ مِنْ عَمَلِ الشَّيْطَانِ ‏.‏\hadithno{1551}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that some men from Iraq said to him, "Abu Abd ar-Rahman, we buy the fruit of the palm and grapes and we squeeze them into wine and we sell it." Abdullah ibn Umar said, "I call on Allah and His angels and whoever hears of jinn and men to testify to you that I order you not to buy it nor sell it nor to press it nor to drink it nor to give it to people to drink. It is something impure from the work of Shaytan}}
