% Auto-generated chapter 40 for nasai
% Hadiths in this chapter: 10

\hadithdefcmd{nasai}{4212}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا دَاوُدُ بْنُ قَيْسٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْعَقِيقَةِ فَقَالَ ‏"‏ لاَ يُحِبُّ اللَّهُ عَزَّ وَجَلَّ الْعُقُوقَ ‏"‏ ‏.‏ وَكَأَنَّهُ كَرِهَ الاِسْمَ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّمَا نَسْأَلُكَ أَحَدُنَا يُولَدُ لَهُ ‏.‏ قَالَ ‏"‏ مَنْ أَحَبَّ أَنْ يَنْسُكَ عَنْ وَلَدِهِ فَلْيَنْسُكْ عَنْهُ عَنِ الْغُلاَمِ شَاتَانِ مُكَافَأَتَانِ وَعَنِ الْجَارِيَةِ شَاةٌ ‏"‏ ‏.‏ قَالَ دَاوُدُ سَأَلْتُ زَيْدَ بْنَ أَسْلَمَ عَنِ الْمُكَافَأَتَانِ قَالَ الشَّاتَانِ الْمُشَبَّهَتَانِ تُذْبَحَانِ جَمِيعًا ‏.‏\hadithno{4212}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Shuaib, from his fahther, that his grandfather said:"The messenger of Allah was asked about the 'Aqiqah and he said: "Allah, the mighty and sublime, does not like Al-Uquq' as if he disliked the word (Al-Aqiqah). He said to the Messenger of Allah: 'But one of us may offer a sacrifice when a child is born to him.' He said: 'Whoever wants to offer a sacrifice for his child, let him do so, for a boy; two sheep, Mukafaatan, (of equal age), and for a girl, one.' (One of the narrators) Dawud said: 'I asked Ziad bin Aslam about the word Mukafaatan and he said: 'Two similar sheep that are slaughtered together}}
\hadithdefcmd{nasai}{4213}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْفَضْلُ، عَنِ الْحُسَيْنِ بْنِ وَاقِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَقَّ عَنِ الْحَسَنِ وَالْحُسَيْنِ ‏.‏\hadithno{4213}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin Buraidah, from his father, that:the Messenger of Allah offered the 'Aqiqah for Al-Hasan and Al-Husain}}
\hadithdefcmd{nasai}{4214}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَفَّانُ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا أَيُّوبُ، وَحَبِيبٌ، وَيُونُسُ، وَقَتَادَةُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ سَلْمَانَ بْنِ عَامِرٍ الضَّبِّيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فِي الْغُلاَمِ عَقِيقَةٌ فَأَهْرِيقُوا عَنْهُ دَمًا وَأَمِيطُوا عَنْهُ الأَذَى ‏"‏ ‏.‏\hadithno{4214}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Salman bin 'Amir Ad-Dabbi that the Messenger of Allah said:"For a boy there shoud be an 'Aqiqah, so shed blood for him, and remove the harm from him}}
\hadithdefcmd{nasai}{4215}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عَفَّانُ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ قَيْسِ بْنِ سَعْدٍ، عَنْ عَطَاءٍ، وَطَاوُسٍ، وَمُجَاهِدٍ، عَنْ أُمِّ كُرْزٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فِي الْغُلاَمِ شَاتَانِ مُكَافَأَتَانِ وَفِي الْجَارِيَةِ شَاةٌ ‏"‏ ‏.‏\hadithno{4215}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{it was narrated from Um Kurz that the Messenger of Allah said:"for a boy two sheep, Mukafaatan (of equal age), and for a girl, one sheep}}
\hadithdefcmd{nasai}{4216}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ قَالَ عَمْرٌو عَنْ عَطَاءٍ، عَنْ حَبِيبَةَ بِنْتِ مَيْسَرَةَ، عَنْ أُمِّ كُرْزٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عَنِ الْغُلاَمِ شَاتَانِ مُكَافَأَتَانِ وَعَنِ الْجَارِيَةِ شَاةٌ ‏"‏ ‏.‏\hadithno{4216}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Umm Kurz that the Messenger of Allah said:"For a boy two sheep, Mukafaatan (of equal age), and for a girl, one sheep}}
\hadithdefcmd{nasai}{4217}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ، - وَهُوَ ابْنُ أَبِي يَزِيدَ - عَنْ سِبَاعِ بْنِ ثَابِتٍ، عَنْ أُمِّ كُرْزٍ، قَالَتْ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم بِالْحُدَيْبِيَةِ أَسْأَلُهُ عَنْ لُحُومِ الْهَدْىِ فَسَمِعْتُهُ يَقُولُ ‏ "‏ عَلَى الْغُلاَمِ شَاتَانِ وَعَلَى الْجَارِيَةِ شَاةٌ لاَ يَضُرُّكُمْ ذُكْرَانًا كُنَّ أَمْ إِنَاثًا ‏"‏ ‏.‏\hadithno{4217}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that umm Kurz said:"I came to the Prophet and asked him about the sacrificial meat. I heard him say: 'For a boy, two sheep, and for a girl, one sheep, and it does not matter if they are male or female}}
\hadithdefcmd{nasai}{4218}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ أَبِي يَزِيدَ، عَنْ سِبَاعِ بْنِ ثَابِتٍ، عَنْ أُمِّ كُرْزٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عَنِ الْغُلاَمِ شَاتَانِ وَعَنِ الْجَارِيَةِ شَاةٌ لاَ يَضُرُّكُمْ ذُكْرَانًا كُنَّ أَمْ إِنَاثًا ‏"‏ ‏.‏\hadithno{4218}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Umma Kurz that the Messenger of Allah said:"For a boy, two sheep, and or a girl, one sheep, and it does not matter if they are male or female}}
\hadithdefcmd{nasai}{4219}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصِ بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ، - هُوَ ابْنُ طَهْمَانَ - عَنِ الْحَجَّاجِ بْنِ الْحَجَّاجِ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ عَقَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْحَسَنِ وَالْحُسَيْنِ رضى الله عنهما بِكَبْشَيْنِ كَبْشَيْنِ ‏.‏\hadithno{4219}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah offered an 'Aqiqah for Al-Hasan and Al-Husain, may Allah be please with them, two rams for each}}
\hadithdefcmd{nasai}{4220}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - عَنْ سَعِيدٍ، أَنْبَأَنَا قَتَادَةُ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ غُلاَمٍ رَهِينٌ بِعَقِيقَتِهِ تُذْبَحُ عَنْهُ يَوْمَ سَابِعِهِ وَيُحْلَقُ رَأْسُهُ وَيُسَمَّى ‏"‏ ‏.‏\hadithno{4220}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Qatadah, from Al-Hasan, from Samurh bin Jundab that the Messenger of Allah said:"Every boy is in pledge for his 'Aqiqah, so slaughter (the animal) for him on the seventh day, and shave his head, and a name}}
\hadithdefcmd{nasai}{4221}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا قُرَيْشُ بْنُ أَنَسٍ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، قَالَ لِي مُحَمَّدُ بْنُ سِيرِينَ سَلِ الْحَسَنَ مِمَّنْ سَمِعَ حَدِيثَهُ، فِي الْعَقِيقَةِ ‏.‏ فَسَأَلْتُهُ عَنْ ذَلِكَ، فَقَالَ سَمِعْتُهُ مِنْ، سَمُرَةَ ‏.‏\hadithno{4221}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Habib bin Ash-Shahid:"Muhammad bin Sirin said to me: 'Ask Al-Hasan (Al-Basri) from whom he heard this Hadith about the 'Aqiqah.' I asked him about that and he said: 'I heard it from Samurh}}
