% Auto-generated chapter 27 for abudawud
% Hadiths in this chapter: 67

\hadithdefcmd{abudawud}{3669}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبُو حَيَّانَ، حَدَّثَنِي الشَّعْبِيُّ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، قَالَ نَزَلَ تَحْرِيمُ الْخَمْرِ يَوْمَ نَزَلَ وَهِيَ مِنْ خَمْسَةِ أَشْيَاءَ مِنَ الْعِنَبِ وَالتَّمْرِ وَالْعَسَلِ وَالْحِنْطَةِ وَالشَّعِيرِ وَالْخَمْرُ مَا خَامَرَ الْعَقْلَ وَثَلاَثٌ وَدِدْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يُفَارِقْنَا حَتَّى يَعْهَدَ إِلَيْنَا فِيهِنَّ عَهْدًا نَنْتَهِي إِلَيْهِ الْجَدُّ وَالْكَلاَلَةُ وَأَبْوَابٌ مِنْ أَبْوَابِ الرِّبَا ‏.‏\hadithno{3669}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (4619) Sahih Muslim (3032)}\hadithtrans{’Umar said :The prohibition of wine came down when (the Quranic verse ) came down. It was made from five thing namely, grapes, dates, honey, wheat ,barley. Wine is what infects (khamara) the mind. There are three things I wished that the prophet (ﷺ) would not leave us until he explained them fully to our satisfaction: (share of) grandfather, one who leaves no descendants or ascendants as hairs, and the details of usury}}
\hadithdefcmd{abudawud}{3670}{حَدَّثَنَا عَبَّادُ بْنُ مُوسَى الْخُتَّلِيُّ، أَخْبَرَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ جَعْفَرٍ - عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرٍو، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ لَمَّا نَزَلَ تَحْرِيمُ الْخَمْرِ قَالَ عُمَرُ اللَّهُمَّ بَيِّنْ لَنَا فِي الْخَمْرِ بَيَانًا شِفَاءً فَنَزَلَتِ الآيَةُ الَّتِي فِي الْبَقَرَةِ ‏\{‏ يَسْأَلُونَكَ عَنِ الْخَمْرِ وَالْمَيْسِرِ قُلْ فِيهِمَا إِثْمٌ كَبِيرٌ ‏\}‏ الآيَةَ قَالَ فَدُعِيَ عُمَرُ فَقُرِئَتْ عَلَيْهِ قَالَ اللَّهُمَّ بَيِّنْ لَنَا فِي الْخَمْرِ بَيَانًا شِفَاءً فَنَزَلَتِ الآيَةُ الَّتِي فِي النِّسَاءِ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَقْرَبُوا الصَّلاَةَ وَأَنْتُمْ سُكَارَى ‏\}‏ فَكَانَ مُنَادِي رَسُولِ اللَّهِ صلى الله عليه وسلم إِذَا أُقِيمَتِ الصَّلاَةُ يُنَادِي أَلاَ لاَ يَقْرَبَنَّ الصَّلاَةَ سَكْرَانُ فَدُعِيَ عُمَرُ فَقُرِئَتْ عَلَيْهِ فَقَالَ اللَّهُمَّ بَيِّنْ لَنَا فِي الْخَمْرِ بَيَانًا شِفَاءً فَنَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ فَهَلْ أَنْتُمْ مُنْتَهُونَ ‏\}‏ قَالَ عُمَرُ انْتَهَيْنَا ‏.‏\hadithno{3670}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar ibn al-Khattab: When the prohibition of wine (was yet to be) declared, Umar said: O Allah, give us a satisfactory explanation about wine. So the following verse of Surat al-Baqarah revealed; "They ask thee concerning wine and gambling. Say: In them is great sin...." Umar was then called and it was recited to him. He said: O Allah, give us a satisfactory explanation about wine. Then the following verse of Surat an-Nisa' was revealed: "O ye who believe! approach not prayers with a mind befogged...." Thereafter the herald of the Messenger of Allah (ﷺ) would call when the (congregational) prayer was performed: Beware, one who is drunk should not come to prayer. Umar was again called and it was recited to him). He said: O Allah, give us a satisfactory explanation about wine. This verse was revealed: "Will ye not then abstain?" Umar said: We abstained}}
\hadithdefcmd{abudawud}{3671}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَلَيْهِ السَّلاَمُ أَنَّ رَجُلاً، مِنَ الأَنْصَارِ دَعَاهُ وَعَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ فَسَقَاهُمَا قَبْلَ أَنْ تُحَرَّمَ الْخَمْرُ فَأَمَّهُمْ عَلِيٌّ فِي الْمَغْرِبِ فَقَرَأَ ‏\{‏ قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏\}‏ فَخَلَطَ فِيهَا فَنَزَلَتْ ‏\{‏ لاَ تَقْرَبُوا الصَّلاَةَ وَأَنْتُمْ سُكَارَى حَتَّى تَعْلَمُوا مَا تَقُولُونَ ‏\}‏ ‏.‏\hadithno{3671}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ali ibn AbuTalib: A man of the Ansar called him and AbdurRahman ibn Awf and supplied them wine before it was prohibited. Ali then led them in the evening prayer, and he recited; "Say: O ye who reject faith." He was confused in it. Then the following verse came down: "O ye who believe! approach not prayers with a mind befogged until you can understand all that ye say}}
\hadithdefcmd{abudawud}{3672}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، حَدَّثَنَا عَلِيُّ بْنُ حُسَيْنٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَقْرَبُوا الصَّلاَةَ وَأَنْتُمْ سُكَارَى ‏\}‏ وَ ‏\{‏ يَسْأَلُونَكَ عَنِ الْخَمْرِ وَالْمَيْسِرِ قُلْ فِيهِمَا إِثْمٌ كَبِيرٌ وَمَنَافِعُ لِلنَّاسِ ‏\}‏ نَسَخَتْهُمَا الَّتِي فِي الْمَائِدَةِ ‏\{‏ إِنَّمَا الْخَمْرُ وَالْمَيْسِرُ وَالأَنْصَابُ ‏\}‏ الآيَةَ ‏.‏\hadithno{3672}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Abbas said:The Quranic verse :”O ye who believe ,approach not prayer with minds befogged until you can understand all they say,” and the verse: “They ask thee concerning wine and gambling. Say: In them is great sin and some profit for men ,” were repeated by the verse in Surat al-Ma’idah: ”O ye who believe, intoxicants and gambling,(dedication) stones}}
\hadithdefcmd{abudawud}{3673}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كُنْتُ سَاقِيَ الْقَوْمِ حَيْثُ حُرِّمَتِ الْخَمْرُ فِي مَنْزِلِ أَبِي طَلْحَةَ وَمَا شَرَابُنَا يَوْمَئِذٍ إِلاَّ الْفَضِيخُ فَدَخَلَ عَلَيْنَا رَجُلٌ فَقَالَ إِنَّ الْخَمْرَ قَدْ حُرِّمَتْ وَنَادَى مُنَادِي رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْنَا هَذَا مُنَادِي رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3673}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4620) Sahih Muslim (1980)}\hadithtrans{Narrated Anas ibn Malik: I was serving wine to the people in the house of AbuTalhah when it was prohibited and that day our wine was made from unripe dates. A man entered upon us and said: The wine has been prohibited, and the herald of the Messenger of Allah (ﷺ) made an announcement. We then said: This is the herald of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{3674}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ عُمَرَ، عَنْ أَبِي عَلْقَمَةَ، مَوْلاَهُمْ وَعَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ الْغَافِقِيِّ أَنَّهُمَا سَمِعَا ابْنَ عُمَرَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَعَنَ اللَّهُ الْخَمْرَ وَشَارِبَهَا وَسَاقِيَهَا وَبَائِعَهَا وَمُبْتَاعَهَا وَعَاصِرَهَا وَمُعْتَصِرَهَا وَحَامِلَهَا وَالْمَحْمُولَةَ إِلَيْهِ ‏"‏ ‏.‏\hadithno{3674}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: Allah has cursed wine, its drinker, its server, its seller, its buyer, its presser, the one for whom it is pressed, the one who conveys it, and the one to whom it is conveyed}}
\hadithdefcmd{abudawud}{3675}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنِ السُّدِّيِّ، عَنْ أَبِي هُبَيْرَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ أَبَا طَلْحَةَ، سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنْ أَيْتَامٍ وَرِثُوا خَمْرًا قَالَ ‏"‏ أَهْرِقْهَا ‏"‏ ‏.‏ قَالَ أَفَلاَ أَجْعَلُهَا خَلاًّ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏\hadithno{3675}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (1983)}\hadithtrans{Anas b. Malik said :Abu Talhah asked the prophet (ﷺ) about the orphans who had inherited wine. He replied: Pour it out. He asked: May I not make vinegar of it ? He replied : No}}
\hadithdefcmd{abudawud}{3676}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنَ الْعِنَبِ خَمْرًا وَإِنَّ مِنَ التَّمْرِ خَمْرًا وَإِنَّ مِنَ الْعَسَلِ خَمْرًا وَإِنَّ مِنَ الْبُرِّ خَمْرًا وَإِنَّ مِنَ الشَّعِيرِ خَمْرًا ‏"‏ ‏.‏\hadithno{3676}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated An-Nu'man ibn Bashir: The Prophet (ﷺ) said: from grapes wine is made, from dried dates wine is made, from honey wine is made, from wheat wine is made, from barley wine is made}}
\hadithdefcmd{abudawud}{3677}{حَدَّثَنَا مَالِكُ بْنُ عَبْدِ الْوَاحِدِ أَبُو غَسَّانَ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ قَرَأْتُ عَلَى الْفُضَيْلِ بْنِ مَيْسَرَةَ عَنْ أَبِي حَرِيزٍ، أَنَّ عَامِرًا، حَدَّثَهُ أَنَّ النُّعْمَانَ بْنَ بَشِيرٍ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ الْخَمْرَ مِنَ الْعَصِيرِ وَالزَّبِيبِ وَالتَّمْرِ وَالْحِنْطَةِ وَالشَّعِيرِ وَالذُّرَةِ وَإِنِّي أَنْهَاكُمْ عَنْ كُلِّ مُسْكِرٍ ‏"‏ ‏.‏\hadithno{3677}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated An-Nu'man ibn Bashir: I heard the Messenger of Allah (ﷺ) say: Wine is made from grape-syrup, raisins, dried dates, wheat, barley, millet, and I forbid you from every intoxicant}}
\hadithdefcmd{abudawud}{3678}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، حَدَّثَنِي يَحْيَى، عَنْ أَبِي كَثِيرٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْخَمْرُ مِنْ هَاتَيْنِ الشَّجَرَتَيْنِ النَّخْلَةِ وَالْعِنَبَةِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ اسْمُ أَبِي كَثِيرٍ الْغُبَرِيِّ يَزِيدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ غُفَيْلَةَ السَّحْمِيُّ ‏.‏ وَقَالَ بَعْضُهُمْ أُذَيْنَةُ وَالصَّوَابُ غُفَيْلَةُ ‏.‏\hadithno{3678}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1985)}\hadithtrans{Abu Hurairah b. Bashir reported the Apostel of Allah (ﷺ)as saying:Wine comes from these two trees, the date-palm and the grapes-vine. Abu Dawud said : The name of Abu KAthir al-Ubari is Yazid b. ‘Abd al-Rahman b. Ghufailat al-Sahmi. Some said: Uzainah. What is correct is Ghufailah}}
\hadithdefcmd{abudawud}{3679}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ، وَمُحَمَّدُ بْنُ عِيسَى، - فِي آخَرِينَ - قَالُوا حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ مُسْكِرٍ خَمْرٌ وَكُلُّ مُسْكِرٍ حَرَامٌ وَمَنْ مَاتَ وَهُوَ يَشْرَبُ الْخَمْرَ يُدْمِنُهَا لَمْ يَشْرَبْهَا فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{3679}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2003)}\hadithtrans{Ibn ‘Umar reported the Apostel of Allah (ﷺ) as saying:Every intoxicant is forbidden. He who drinks wine in this world, and dies when he is addiction to it, will not drink it in the next}}
\hadithdefcmd{abudawud}{3680}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ النَّيْسَابُورِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عُمَرَ الصَّنْعَانِيُّ، قَالَ سَمِعْتُ النُّعْمَانَ، يَقُولُ عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ كُلُّ مُخَمِّرٍ خَمْرٌ وَكُلُّ مُسْكِرٍ حَرَامٌ وَمَنْ شَرِبَ مُسْكِرًا بُخِسَتْ صَلاَتُهُ أَرْبَعِينَ صَبَاحًا فَإِنْ تَابَ تَابَ اللَّهُ عَلَيْهِ فَإِنْ عَادَ الرَّابِعَةَ كَانَ حَقًّا عَلَى اللَّهِ أَنْ يَسْقِيَهُ مِنْ طِينَةِ الْخَبَالِ ‏"‏ ‏.‏ قِيلَ وَمَا طِينَةُ الْخَبَالِ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ صَدِيدُ أَهْلِ النَّارِ وَمَنْ سَقَاهُ صَغِيرًا لاَ يَعْرِفُ حَلاَلَهُ مِنْ حَرَامِهِ كَانَ حَقًّا عَلَى اللَّهِ أَنْ يَسْقِيَهُ مِنْ طِينَةِ الْخَبَالِ ‏"‏\hadithno{3680}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah Ibn Abbas: The Messenger of Allah (ﷺ) said: Every intoxicant is khamr (wine) and every intoxicant is forbidden. If anyone drinks wine, Allah will not accept prayer from him for forty days, but if he repents, Allah will accept his repentance. If he repeats it a fourth time, it is binding on Allah that He will give him tinat al-khabal to drink. He was asked: What is tinat al-khabal, Messenger of Allah? He replied: Discharge of wounds, flowing from the inhabitants of Hell. If anyone serves it to a minor who does not distinguish between the lawful and the unlawful, it is binding on Allah that He will give him to drink the discharge of wounds, flowing from the inhabitants of Hell}}
\hadithdefcmd{abudawud}{3681}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ جَعْفَرٍ - عَنْ دَاوُدَ بْنِ بَكْرِ بْنِ أَبِي الْفُرَاتِ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أَسْكَرَ كَثِيرُهُ فَقَلِيلُهُ حَرَامٌ ‏"‏ ‏.‏\hadithno{3681}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: If a large amount of anything causes intoxication, a small amount of it is prohibited}}
\hadithdefcmd{abudawud}{3682}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْبِتْعِ فَقَالَ ‏ "‏ كُلُّ شَرَابٍ أَسْكَرَ فَهُوَ حَرَامٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَرَأْتُ عَلَى يَزِيدَ بْنِ عَبْدِ رَبِّهِ الْجُرْجُسِيِّ حَدَّثَكُمْ مُحَمَّدُ بْنُ حَرْبٍ عَنِ الزُّبَيْدِيِّ عَنِ الزُّهْرِيِّ بِهَذَا الْحَدِيثِ بِإِسْنَادِهِ زَادَ وَالْبِتْعُ نَبِيذُ الْعَسَلِ كَانَ أَهْلُ الْيَمَنِ يَشْرَبُونَهُ ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ يَقُولُ لاَ إِلَهَ إِلاَّ اللَّهُ مَا كَانَ أَثْبَتَهُ مَا كَانَ فِيهِمْ مِثْلُهُ يَعْنِي فِي أَهْلِ حِمْصَ يَعْنِي الْجُرْجُسِيَّ ‏.‏\hadithno{3682}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5585) Sahih Muslim (2001)}\hadithtrans{’A’ishah said :The Messenger of Allah (ﷺ) was asked about bit’. He replied: Every liquor which intoxicates is forbidden. Abu Dawud said: I read out this tradition to Yazid bin 'Abd Rabbihi al-Jurjisi. Muhammad bin Hard told you this tradition from al-Zabidi from al-Zuhri through his chain of narrators. This version added: Bit' is the nabidh from honey, which the people of the Yemen would drink. Abu Dawud said: I heard Ahmad bin Hanbal say: There is no god but Allah. there was none stronger in memory and like al-Jurjisi among the people of Hims}}
\hadithdefcmd{abudawud}{3683}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا عَبْدَةُ، عَنْ مُحَمَّدٍ، - يَعْنِي ابْنَ إِسْحَاقَ - عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مَرْثَدِ بْنِ عَبْدِ اللَّهِ الْيَزَنِيِّ، عَنْ دَيْلَمٍ الْحِمْيَرِيِّ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّا بِأَرْضٍ بَارِدَةٍ نُعَالِجُ فِيهَا عَمَلاً شَدِيدًا وَإِنَّا نَتَّخِذُ شَرَابًا مِنْ هَذَا الْقَمْحِ نَتَقَوَّى بِهِ عَلَى أَعْمَالِنَا وَعَلَى بَرْدِ بِلاَدِنَا ‏.‏ قَالَ ‏"‏ هَلْ يُسْكِرُ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ فَاجْتَنِبُوهُ ‏"‏ ‏.‏ قَالَ قُلْتُ فَإِنَّ النَّاسَ غَيْرُ تَارِكِيهِ ‏.‏ قَالَ ‏"‏ فَإِنْ لَمْ يَتْرُكُوهُ فَقَاتِلُوهُمْ ‏"‏ ‏.‏\hadithno{3683}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Daylam al-Himyari: I asked the Prophet (ﷺ) and said: Messenger of Allah! we live in a cold land in which we do heavy work and we make a liquor from wheat to get strength from if for our work and to stand the cold of our country. He asked: Is it intoxicating? I replied: Yes. He said: You must avoid it. I said: The people will not abandon it. He said: If they do not abandon it, fight with them}}
\hadithdefcmd{abudawud}{3684}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنْ شَرَابٍ مِنَ الْعَسَلِ فَقَالَ ‏"‏ ذَاكَ الْبِتْعُ ‏"‏ ‏.‏ قُلْتُ وَيُنْتَبَذُ مِنَ الشَّعِيرِ وَالذُّرَةِ ‏.‏ فَقَالَ ‏"‏ ذَاكَ الْمِزْرُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَخْبِرْ قَوْمَكَ أَنَّ كُلَّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{3684}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari (6124، 4344) Sahih Muslim (1733 After  2001)}\hadithtrans{Abu Musa said :I asked the prophet (ﷺ) about wine made from honey. He said: That is bit. I said: And the one made from barley and millet ? He said :That is mizr. He then said: Tell your people that every intoxicant is prohibited}}
\hadithdefcmd{abudawud}{3685}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنِ الْوَلِيدِ بْنِ عَبْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْخَمْرِ وَالْمَيْسِرِ وَالْكُوبَةِ وَالْغُبَيْرَاءِ وَقَالَ ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ ابْنُ سَلاَمٍ أَبُو عُبَيْدٍ الْغُبَيْرَاءُ السُّكُرْكَةُ تُعْمَلُ مِنَ الذُّرَةِ شَرَابٌ يَعْمَلُهُ الْحَبَشَةُ ‏.‏\hadithno{3685}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) forbade wine (khamr), game of chance (maysir), drum (kubah), and wine made from millet (ghubayrah), saying: Every intoxicant is forbidden. Abu Dawud said: Ibn Sallam Abu 'Ubaid said: Ghubairah was an intoxicant liquor made from millet. This wine was made by the Abyssinians}}
\hadithdefcmd{abudawud}{3686}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو شِهَابٍ عَبْدُ رَبِّهِ بْنُ نَافِعٍ، عَنِ الْحَسَنِ بْنِ عَمْرٍو الْفُقَيْمِيِّ، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ كُلِّ مُسْكِرٍ وَمُفَتِّرٍ ‏.‏\hadithno{3686}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: The Messenger of Allah (ﷺ) forbade every intoxicant and everything which produces languidness}}
\hadithdefcmd{abudawud}{3687}{حَدَّثَنَا مُسَدَّدٌ، وَمُوسَى بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا مَهْدِيٌّ، - يَعْنِي ابْنَ مَيْمُونٍ - حَدَّثَنَا أَبُو عُثْمَانَ، - قَالَ مُوسَى هُوَ عَمْرُو بْنُ سَلْمٍ الأَنْصَارِيُّ - عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ كُلُّ مُسْكِرٍ حَرَامٌ وَمَا أَسْكَرَ مِنْهُ الْفَرْقُ فَمِلْءُ الْكَفِّ مِنْهُ حَرَامٌ ‏"‏ ‏.‏\hadithno{3687}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: I heard the Messenger of Allah (ﷺ) say: Every intoxicant is forbidden; if a faraq of anything causes intoxication, a handful of it is forbidden}}
\hadithdefcmd{abudawud}{3688}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ حَاتِمِ بْنِ حُرَيْثٍ، عَنْ مَالِكِ بْنِ أَبِي مَرْيَمَ، قَالَ دَخَلَ عَلَيْنَا عَبْدُ الرَّحْمَنِ بْنُ غَنْمٍ فَتَذَاكَرْنَا الطِّلاَءَ فَقَالَ حَدَّثَنِي أَبُو مَالِكٍ الأَشْعَرِيُّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَيَشْرَبَنَّ نَاسٌ مِنْ أُمَّتِي الْخَمْرَ يُسَمُّونَهَا بِغَيْرِ اسْمِهَا ‏"‏ ‏.‏\hadithno{3688}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbdurRahman ibn Ghanam: Malik ibn AbuMaryam said: AbdurRahman ibn Ghanam entered upon us and we discussed tila' and he said: AbuMalik al-Ash'ari told me that he heard the Messenger of Allah (ﷺ) say: Some of my people will assuredly drink wine calling it by another name}}
\hadithdefcmd{abudawud}{3689}{قَالَ أَبُو دَاوُدَ حَدَّثَنَا شَيْخٌ، مِنْ أَهْلِ وَاسِطٍ قَالَ حَدَّثَنَا أَبُو مَنْصُورٍ الْحَارِثُ بْنُ مَنْصُورٍ، قَالَ سَمِعْتُ سُفْيَانَ الثَّوْرِيَّ، وَسُئِلَ، عَنِ الدَّاذِيِّ، فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيَشْرَبَنَّ نَاسٌ مِنْ أُمَّتِي الْخَمْرَ يُسَمُّونَهَا بِغَيْرِ اسْمِهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَالَ سُفْيَانُ الثَّوْرِيُّ الدَّاذِيُّ شَرَابُ الْفَاسِقِينَ ‏.‏\hadithno{3689}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Dawud said:An old man of the people of Wasit narrated from Abu Mansur al-Harith bin Mansur saying: I heard Sufyan Al-Thawri who was asked about al-dadhi. He said: The Messenger of Allah (ﷺ) said: Some of my people will assuredly drink wine calling it by another name}}
\hadithdefcmd{abudawud}{3690}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا مَنْصُورُ بْنُ حَيَّانَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، وَابْنِ، عَبَّاسٍ قَالاَ نَشْهَدُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالْمُزَفَّتِ وَالنَّقِيرِ ‏.‏\hadithno{3690}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1997)}\hadithtrans{Ibn ‘Umar and Ibn ‘Abbas said :We testify that the Messenger of Allah (ﷺ) forbade (the use of) gourds, green jars, receptacles smeared with pitch, and hollowed stumps of palm-trees}}
\hadithdefcmd{abudawud}{3691}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، وَمُسْلِمُ بْنُ إِبْرَاهِيمَ، - الْمَعْنَى - قَالاَ حَدَّثَنَا جَرِيرٌ، عَنْ يَعْلَى، - يَعْنِي ابْنَ حَكِيمٍ - عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ حَرَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَبِيذَ الْجَرِّ فَخَرَجْتُ فَزِعًا مِنْ قَوْلِهِ حَرَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَبِيذَ الْجَرِّ فَدَخَلْتُ عَلَى ابْنِ عَبَّاسٍ فَقُلْتُ أَمَا تَسْمَعُ مَا يَقُولُ ابْنُ عُمَرَ قَالَ وَمَا ذَاكَ قُلْتُ قَالَ حَرَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَبِيذَ الْجَرِّ ‏.‏ قَالَ صَدَقَ حَرَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَبِيذَ الْجَرِّ ‏.‏ قُلْتُ مَا الْجَرُّ قَالَ كُلُّ شَىْءٍ يُصْنَعُ مِنْ مَدَرٍ ‏.‏\hadithno{3691}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1997)}\hadithtrans{Adb Allah bin 'Umar said:The Messenger of Allah (ﷺ) forbade the nabidh (date-wine) of jarr. I was alarmed by his statement: The Apostel of Allah (ﷺ) forbade the nabidh of jarr. I then entered upon Ibn ‘Abbas and asked him : Are you listening to what Ibn Umar says ? He asked : What is that ? I said : The Apostel of Allah (ﷺ) forbade the nabidh of jarr . He said :He spoke the truth. The Apostel of Allah (ﷺ) forbade the nabidh of jarr .I asked :what is jarr ? He replied : Anything made of clay}}
\hadithdefcmd{abudawud}{3692}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ عُبَيْدٍ، قَالاَ حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ، عَنْ أَبِي جَمْرَةَ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ - وَقَالَ مُسَدَّدٌ عَنِ ابْنِ عَبَّاسٍ، وَهَذَا، حَدِيثُ سُلَيْمَانَ قَالَ - قَدِمَ وَفْدُ عَبْدِ الْقَيْسِ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّا هَذَا الْحَىَّ مِنْ رَبِيعَةَ قَدْ حَالَ بَيْنَنَا وَبَيْنَكَ كُفَّارُ مُضَرَ وَلَسْنَا نَخْلُصُ إِلَيْكَ إِلاَّ فِي شَهْرٍ حَرَامٍ فَمُرْنَا بِشَىْءٍ نَأْخُذُ بِهِ وَنَدْعُو إِلَيْهِ مَنْ وَرَاءَنَا ‏.‏ قَالَ ‏"‏ آمُرُكُمْ بِأَرْبَعٍ وَأَنْهَاكُمْ عَنْ أَرْبَعٍ الإِيمَانُ بِاللَّهِ وَشَهَادَةُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏ وَعَقَدَ بِيَدِهِ وَاحِدَةً ‏.‏ وَقَالَ مُسَدَّدٌ الإِيمَانُ بِاللَّهِ ثُمَّ فَسَّرَهَا لَهُمْ شَهَادَةَ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ وَإِقَامُ الصَّلاَةِ وَإِيتَاءُ الزَّكَاةِ وَأَنْ تُؤَدُّوا الْخُمُسَ مِمَّا غَنِمْتُمْ وَأَنْهَاكُمْ عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالْمُزَفَّتِ وَالْمُقَيَّرِ ‏"‏ ‏.‏ وَقَالَ ابْنُ عُبَيْدٍ النَّقِيرِ مَكَانَ الْمُقَيَّرِ ‏.‏ وَقَالَ مُسَدَّدٌ وَالنَّقِيرِ وَالْمُقَيَّرِ وَلَمْ يَذْكُرِ الْمُزَفَّتِ ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو جَمْرَةَ نَصْرُ بْنُ عِمْرَانَ الضُّبَعِيُّ ‏.‏\hadithno{3692}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (523) Sahih Muslim (17 After 1995)}\hadithtrans{Ibn 'Abbas said:The deputation of 'Abd al-Qais came to Messenger of Allah (ﷺ) and said: This is the tribe of Rabi'ah, and the infidels of Mudar are between us and you. We are able to come to you only in the sacred month. So give a decisive command which we may follow ourselves and to which we call those at home behind us. He (the Prophet) said: I command you to observe four things, and forbade you four things: Belief in Allah. the testimony that there is no god but Allah, and he expresses one by folding his hand. Musadad's version has: Faith in Allah, and he explained to them: The testimony that there is no god but Allah and that Muhammad is the Messenger of Allah, observance of prayer, payment of zakat, and your giving the filth of the booty. I forbid you the use of pumpkins, green jarrs, vessels smeared with pitch, and hollow stumps of palm-trees. Ibn 'Ubaid's version has word muqayyar (vessels smeared with pitch) instead of naqir (hollow stumps). Musaddad's version has naqir and muqayyar (pitch); he did not mention muzaffat (vessels smeared with pitch). Abu Dawud said: The name of Abu Jamrah is Nasr bin 'Imran al-Duba'i}}
\hadithdefcmd{abudawud}{3693}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ نُوحِ بْنِ قَيْسٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَوْنٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِوَفْدِ عَبْدِ الْقَيْسِ ‏ "‏ أَنْهَاكُمْ عَنِ النَّقِيرِ وَالْمُقَيَّرِ وَالْحَنْتَمِ وَالدُّبَّاءِ وَالْمَزَادَةِ الْمَجْبُوبَةِ وَلَكِنِ اشْرَبْ فِي سِقَائِكَ وَأَوْكِهْ ‏"‏ ‏.‏\hadithno{3693}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1993)}\hadithtrans{Abu Hurairah said:The Messenger of Allah (ﷺ) said to the deputation of 'Abd al-Qais: I forbid you the use of hollow stumps, vessels smeared with pitch, green harrs, pumpkins, and a skin cut off at the top, but drink from your skin and tie it with string}}
\hadithdefcmd{abudawud}{3694}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبَانُ، حَدَّثَنَا قَتَادَةُ، عَنْ عِكْرِمَةَ، وَسَعِيدِ بْنِ الْمُسَيَّبِ، عَنِ ابْنِ عَبَّاسٍ، فِي قِصَّةِ وَفْدِ عَبْدِ الْقَيْسِ قَالُوا فِيمَ نَشْرَبُ يَا نَبِيَّ اللَّهِ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلَيْكُمْ بِأَسْقِيَةِ الأَدَمِ الَّتِي يُلاَثُ عَلَى أَفْوَاهِهَا ‏"‏ ‏.‏\hadithno{3694}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{In the story of the deputation of AbdulQays Ibn Abbas said:They (the people) asked: In which should we drink, Prophet of Allah? The Prophet (ﷺ) said: You should use those skin vessels that are tied at their mouths}}
\hadithdefcmd{abudawud}{3695}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، عَنْ عَوْفٍ، عَنْ أَبِي الْقَمُوصِ، زَيْدِ بْنِ عَلِيٍّ حَدَّثَنِي رَجُلٌ، كَانَ مِنَ الْوَفْدِ الَّذِينَ وَفَدُوا إِلَى النَّبِيِّ صلى الله عليه وسلم مِنْ عَبْدِ الْقَيْسِ يَحْسِبُ عَوْفٌ أَنَّ اسْمَهُ قَيْسُ بْنُ النُّعْمَانِ فَقَالَ ‏ "‏ لاَ تَشْرَبُوا فِي نَقِيرٍ وَلاَ مُزَفَّتٍ وَلاَ دُبَّاءٍ وَلاَ حَنْتَمٍ وَاشْرَبُوا فِي الْجِلْدِ الْمُوكَإِ عَلَيْهِ فَإِنِ اشْتَدَّ فَاكْسِرُوهُ بِالْمَاءِ فَإِنْ أَعْيَاكُمْ فَأَهْرِيقُوهُ ‏"‏ ‏.‏\hadithno{3695}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{A man of the deputation of 'Abd al-Qais who came to the Prophet (ﷺ) said - the narrator 'Awf thinks that his name was Qais bin al-Nu'man:The Prophet (ﷺ) said: Do not drink from hollowed stumps, vessel smeared with pitch, pumpkins, and green jars, but drink from a skin which is tied with string. If the drink ferments, lighten it by infusing water. If you are helpless, then pour it away}}
\hadithdefcmd{abudawud}{3696}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَلِيِّ بْنِ بَذِيمَةَ، حَدَّثَنِي قَيْسُ بْنُ حَبْتَرٍ النَّهْشَلِيُّ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ وَفْدَ عَبْدِ الْقَيْسِ، قَالُوا يَا رَسُولَ اللَّهِ فِيمَ نَشْرَبُ قَالَ ‏"‏ لاَ تَشْرَبُوا فِي الدُّبَّاءِ وَلاَ فِي الْمُزَفَّتِ وَلاَ فِي النَّقِيرِ وَانْتَبِذُوا فِي الأَسْقِيَةِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ فَإِنِ اشْتَدَّ فِي الأَسْقِيَةِ قَالَ ‏"‏ فَصُبُّوا عَلَيْهِ الْمَاءَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ لَهُمْ فِي الثَّالِثَةِ أَوِ الرَّابِعَةِ ‏"‏ أَهْرِيقُوهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ اللَّهَ حَرَّمَ عَلَىَّ أَوْ حُرِّمَ الْخَمْرُ وَالْمَيْسِرُ وَالْكُوبَةُ ‏"‏ ‏.‏ قَالَ ‏"‏ وَكُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏ قَالَ سُفْيَانُ فَسَأَلْتُ عَلِيَّ بْنَ بَذِيمَةَ عَنِ الْكُوبَةِ قَالَ الطَّبْلُ ‏.‏\hadithno{3696}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn ‘Abbas said :The deputation of ‘Abd al-Qais asked (the prophet):From which(vessels)should we drink ? He (the prophet) replied: Do not drink from the pumpkins, vessels smeared with pitch, and hollow stumps , and steep dates in skins. They asked: Messenger of Allah, if it ferments? He replied: infuse water in it. They asked: Messenger of Allah...” (repeating the same words). He replied to them third or fourth time: Pour it away. He then said: Allah has forbidden me, or he said: He has forbidden me wine, game of chance and kubah(drums). He said: Every intoxicant is unlawful. Sufyan said: I asked ‘All b. Badhimah about kubah	. He replied: Drum}}
\hadithdefcmd{abudawud}{3697}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ سُمَيْعٍ، حَدَّثَنَا مَالِكُ بْنُ عُمَيْرٍ، عَنْ عَلِيٍّ، عَلَيْهِ السَّلاَمُ قَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالنَّقِيرِ وَالْجِعَةِ ‏.‏\hadithno{3697}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ali ibn AbuTalib: The Messenger of Allah (ﷺ) forbade us the use of pumpkins, green jars, hollow stumps and wine made from barley}}
\hadithdefcmd{abudawud}{3698}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا مُعَرِّفُ بْنُ وَاصِلٍ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَهَيْتُكُمْ عَنْ ثَلاَثٍ وَأَنَا آمُرُكُمْ بِهِنَّ نَهَيْتُكُمْ عَنْ زِيَارَةِ الْقُبُورِ فَزُورُوهَا فَإِنَّ فِي زِيَارَتِهَا تَذْكِرَةً وَنَهَيْتُكُمْ عَنِ الأَشْرِبَةِ أَنْ تَشْرَبُوا إِلاَّ فِي ظُرُوفِ الأَدَمِ فَاشْرَبُوا فِي كُلِّ وِعَاءٍ غَيْرَ أَنْ لاَ تَشْرَبُوا مُسْكِرًا وَنَهَيْتُكُمْ عَنْ لُحُومِ الأَضَاحِي أَنْ تَأْكُلُوهَا بَعْدَ ثَلاَثٍ فَكُلُوا وَاسْتَمْتِعُوا بِهَا فِي أَسْفَارِكُمْ ‏"‏ ‏.‏\hadithno{3698}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (977)}\hadithtrans{Narrated Buraydah ibn al-Hasib: The Prophet (ﷺ) said: I forbade you three things, and now I command (permit) you for them. I forbade you to visit graves, now you may visit them, for in visiting them there is admonition. I forbade you drinks except from skin vessels, but now you may drink from any kind of vessels, but do not drink an intoxicant. I forbade you to eat the meat of sacrificial animals after three days, but now you may eat and enjoy it during your journeys}}
\hadithdefcmd{abudawud}{3699}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنِي مَنْصُورٌ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ لَمَّا نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الأَوْعِيَةِ قَالَ قَالَتِ الأَنْصَارُ إِنَّهُ لاَ بُدَّ لَنَا ‏.‏ قَالَ ‏ "‏ فَلاَ إِذًا ‏"‏ ‏.‏\hadithno{3699}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5592)}\hadithtrans{Jabir b. ‘Abd Allah said:When the Messenger of Allah(ﷺ) forbade the use of(wine) vessels, Ansar said: They are inevitable for us. Thereupon he said: If so, then no}}
\hadithdefcmd{abudawud}{3700}{حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرِ بْنِ زِيَادٍ، حَدَّثَنَا شَرِيكٌ، عَنْ زِيَادِ بْنِ فَيَّاضٍ، عَنْ أَبِي عِيَاضٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم الأَوْعِيَةَ الدُّبَّاءَ وَالْحَنْتَمَ وَالْمُزَفَّتَ وَالنَّقِيرَ فَقَالَ أَعْرَابِيٌّ إِنَّهُ لاَ ظُرُوفَ لَنَا ‏.‏ فَقَالَ ‏ "‏ اشْرَبُوا مَا حَلَّ ‏"‏ ‏.‏\hadithno{3700}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5593) Sahih Muslim (2000)}\hadithtrans{‘Abd Allah b.’ Amr said:The Prophet(ﷺ) mentioned the vessels: pumpkins, green jarrs, vessels smeared with pitch and hollow stumps. A desert Arab said: We have no vessels(except these). He said: Drink(from them) what is lawful}}
\hadithdefcmd{abudawud}{3701}{حَدَّثَنَا الْحَسَنُ، - يَعْنِي ابْنَ عَلِيٍّ - حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا شَرِيكٌ، بِإِسْنَادِهِ قَالَ ‏ "‏ اجْتَنِبُوا مَا أَسْكَرَ ‏"‏ ‏.‏\hadithno{3701}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Sharik through a different chain of narrators. This version has:Avoid that which produces intoxication}}
\hadithdefcmd{abudawud}{3702}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ يُنْبَذُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فِي سِقَاءٍ فَإِذَا لَمْ يَجِدُوا سِقَاءً نُبِذَ لَهُ فِي تَوْرٍ مِنْ حِجَارَةٍ ‏.‏\hadithno{3702}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1998)}\hadithtrans{Jabir b. ‘Abd Allah said:Dates were steeped for the Messenger of Allah (ﷺ) in a skin, but when they could not find a skin, they were steeped for him in a small stone vessel}}
\hadithdefcmd{abudawud}{3703}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ نَهَى أَنْ يُنْتَبَذَ الزَّبِيبُ وَالتَّمْرُ جَمِيعًا وَنَهَى أَنْ يُنْتَبَذَ الْبُسْرُ وَالرُّطَبُ جَمِيعًا ‏.‏\hadithno{3703}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5601) Sahih Muslim (1986)}\hadithtrans{Jabir b.’Abd Allah said:The Messenger of Allah(ﷺ) forbade mixing of raisins and dried dates: and unripe dates and fresh dates}}
\hadithdefcmd{abudawud}{3704}{حَدَّثَنَا أَبُو سَلَمَةَ، مُوسَى بْنُ إِسْمَاعِيلَ حَدَّثَنَا أَبَانُ، حَدَّثَنِي يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، أَنَّهُ نَهَى عَنْ خَلِيطِ الزَّبِيبِ، وَالتَّمْرِ، وَعَنْ خَلِيطِ الْبُسْرِ، وَالتَّمْرِ، وَعَنْ خَلِيطِ الزَّهْوِ، وَالرُّطَبِ، وَقَالَ، ‏ "‏ انْتَبِذُوا كُلَّ وَاحِدٍ عَلَى حِدَةٍ ‏"‏ ‏.‏ قَالَ وَحَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ عَنْ أَبِي قَتَادَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏.‏\hadithno{3704}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5602) Sahih Muslim (1988)}\hadithtrans{‘Abd Allah b. Abi Qatadah said that his father Abu Qatadah forbade mixing raisins and dried dates, mixing unripe dates and fresh dates, and mixing dates beginning to take on colour and fresh dates. He said:Make nabidh (drink) from each separately. He (the narrator Yahya) said: Abu Salamah bin 'Abd al-Rahman narrated to me this tradition on the authority of Abu Qatadah from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{3705}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَحَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنِ ابْنِ أَبِي لَيْلَى، - عَنْ رَجُلٍ، - قَالَ حَفْصٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ نَهَى عَنِ الْبَلَحِ وَالتَّمْرِ وَالزَّبِيبِ وَالتَّمْرِ ‏.‏\hadithno{3705}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated A man: A man from among the Companions of the Prophet (ﷺ) said: The Prophet (ﷺ) forbade (mixing) unripe dates and dried dates, and (mixing) raisins and dried dates}}
\hadithdefcmd{abudawud}{3706}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ ثَابِتِ بْنِ عُمَارَةَ، حَدَّثَتْنِي رَيْطَةُ، عَنْ كَبْشَةَ بِنْتِ أَبِي مَرْيَمَ، قَالَتْ سَأَلْتُ أُمَّ سَلَمَةَ مَا كَانَ النَّبِيُّ صلى الله عليه وسلم يَنْهَى عَنْهُ قَالَتْ كَانَ يَنْهَانَا أَنْ نَعْجُمَ النَّوَى طَبْخًا أَوْ نَخْلِطَ الزَّبِيبَ وَالتَّمْرَ ‏.‏\hadithno{3706}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: Kabshah, daughter of AbuMaryam, asked Umm Salamah (Allah be pleased with her): What did the Prophet (ﷺ) prohibit? She replied: He forbade us to boil dates so much so that the kernels are spoiled, and to mix raisins and dried dates}}
\hadithdefcmd{abudawud}{3707}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ مِسْعَرٍ، عَنْ مُوسَى بْنِ عَبْدِ اللَّهِ، عَنِ امْرَأَةٍ، مِنْ بَنِي أَسَدٍ عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُنْبَذُ لَهُ زَبِيبٌ فَيُلْقِي فِيهِ تَمْرًا وَتَمْرٌ فَيُلْقِي فِيهِ الزَّبِيبَ ‏.‏\hadithno{3707}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Raisins were steeped for the Messenger of Allah (ﷺ) and then dried dates were infused in them, or dried dates were steeped and then raisins were infused in them}}
\hadithdefcmd{abudawud}{3708}{حَدَّثَنَا زَيَادُ بْنُ يَحْيَى الْحَسَّانِيُّ، حَدَّثَنَا أَبُو بَحْرٍ، حَدَّثَنَا عَتَّابُ بْنُ عَبْدِ الْعَزِيزِ الْحِمَّانِيُّ، حَدَّثَتْنِي صَفِيَّةُ بِنْتُ عَطِيَّةَ، قَالَتْ دَخَلْتُ مَعَ نِسْوَةٍ مِنْ عَبْدِ الْقَيْسِ عَلَى عَائِشَةَ فَسَأَلْنَاهَا عَنِ التَّمْرِ وَالزَّبِيبِ فَقَالَتْ كُنْتُ آخُذُ قَبْضَةً مِنْ تَمْرٍ وَقَبْضَةً مِنْ زَبِيبٍ فَأُلْقِيهِ فِي إِنَاءٍ فَأَمْرُسُهُ ثُمَّ أَسْقِيهِ النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{3708}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Safiyyah, daughter of Atiyyah, said: I entered upon Aisha with some women of AbdulQays, and asked her about mixing dried dates and raisins (for drink). She replied: I used to take a handful of dried dates and a handful or raisins and put them in a vessel, and then crush them (and soak in water). Then I would give it to the Prophet (ﷺ) to drink}}
\hadithdefcmd{abudawud}{3709}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ جَابِرِ بْنِ زَيْدٍ، وَعِكْرِمَةَ، أَنَّهُمَا كَانَا يَكْرَهَانِ الْبُسْرَ وَحْدَهُ وَيَأْخُذَانِ ذَلِكَ عَنِ ابْنِ عَبَّاسٍ ‏.‏ وَقَالَ ابْنُ عَبَّاسٍ أَخْشَى أَنْ يَكُونَ الْمُزَّاءَ الَّذِي نُهِيَتْ عَنْهُ عَبْدُ الْقَيْسِ ‏.‏ فَقُلْتُ لِقَتَادَةَ مَا الْمُزَّاءُ قَالَ النَّبِيذُ فِي الْحَنْتَمِ وَالْمُزَفَّتِ ‏.‏\hadithno{3709}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Qatadah said on the authority of Jabir b. Zaid and ‘Ikrimah that they disapprove of drink made exclusively from unripe dates. This they reported on the authority of Ibn ‘Abbas said:I am afraid it may not be muzza from which(the people of) ‘Abd al-Qais were prohibited. I asked Qatadah : What is muzza’? He replied: Drink of dates made in a green jar and vessels smeared with pitch}}
\hadithdefcmd{abudawud}{3710}{حَدَّثَنَا عِيسَى بْنُ مُحَمَّدٍ، حَدَّثَنَا ضَمْرَةُ، عَنِ السَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الدَّيْلَمِيِّ، عَنْ أَبِيهِ، قَالَ أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْنَا يَا رَسُولَ اللَّهِ قَدْ عَلِمْتَ مَنْ نَحْنُ وَمِنْ أَيْنَ نَحْنُ فَإِلَى مَنْ نَحْنُ قَالَ ‏"‏ إِلَى اللَّهِ وَإِلَى رَسُولِهِ ‏"‏ ‏.‏ فَقُلْنَا يَا رَسُولَ اللَّهِ إِنَّ لَنَا أَعْنَابًا مَا نَصْنَعُ بِهَا قَالَ ‏"‏ زَبِّبُوهَا ‏"‏ ‏.‏ قُلْنَا مَا نَصْنَعُ بِالزَّبِيبِ قَالَ ‏"‏ انْبِذُوهُ عَلَى غَدَائِكُمْ وَاشْرَبُوهُ عَلَى عَشَائِكُمْ وَانْبِذُوهُ عَلَى عَشَائِكُمْ وَاشْرَبُوهُ عَلَى غَدَائِكُمْ وَانْبِذُوهُ فِي الشِّنَانِ وَلاَ تَنْبِذُوهُ فِي الْقُلَلِ فَإِنَّهُ إِذَا تَأَخَّرَ عَنْ عَصْرِهِ صَارَ خَلاًّ ‏"‏ ‏.‏\hadithno{3710}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ad-Daylami: We came to the Prophet (ﷺ) and said to him: Messenger of Allah, you know who we are, from where we are and to whom we have come. He said: To Allah and His Apostle. We said: Messenger of Allah, we have grapes; what should we do with them? He said: Make them raisins. We then asked: What should we do with raisins? He replied: Steep them in the morning and drink in the evening, and steep them in the evening and drink in the morning. Steep them in skin vessels and do not steep them in earthen jar, for it it is delayed in pressing, it becomes vinegar}}
\hadithdefcmd{abudawud}{3711}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْمَجِيدِ الثَّقَفِيُّ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنِ الْحَسَنِ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ يُنْبَذُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فِي سِقَاءٍ يُوكَأُ أَعْلاَهُ وَلَهُ عَزْلاَءُ يُنْبَذُ غُدْوَةً فَيَشْرَبُهُ عِشَاءً وَيُنْبَذُ عِشَاءً فَيَشْرَبُهُ غُدْوَةً ‏.‏\hadithno{3711}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2005)}\hadithtrans{A’ishah said :Dates were steeped for the Apostel of Allah (ﷺ) in skin which was tied up at the top and had a mouth. What was steeped in the morning he would drink in the evening and what was steeped in the evening he would drink in the morning}}
\hadithdefcmd{abudawud}{3712}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ شَبِيبَ بْنَ عَبْدِ الْمَلِكِ، يُحَدِّثُ عَنْ مُقَاتِلِ بْنِ حَيَّانَ، قَالَ حَدَّثَتْنِي عَمَّتِي، عَمْرَةُ عَنْ عَائِشَةَ، رضى الله عنها أَنَّهَا كَانَتْ تَنْبِذُ لِلنَّبِيِّ صلى الله عليه وسلم غُدْوَةً فَإِذَا كَانَ مِنَ الْعَشِيِّ فَتَعَشَّى شَرِبَ عَلَى عَشَائِهِ وَإِنْ فَضَلَ شَىْءٌ صَبَبْتُهُ - أَوْ فَرَغْتُهُ - ثُمَّ تَنْبِذُ لَهُ بِاللَّيْلِ فَإِذَا أَصْبَحَ تَغَدَّى فَشَرِبَ عَلَى غَدَائِهِ قَالَتْ نَغْسِلُ السِّقَاءَ غُدْوَةً وَعَشِيَّةً فَقَالَ لَهَا أَبِي مَرَّتَيْنِ فِي يَوْمٍ قَالَتْ نَعَمْ ‏.‏\hadithno{3712}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Amrah said on the authority of Aisha that she would steep dates for the Messenger of Allah (ﷺ) in the morning. When the evening came, he took his dinner and drank it after his dinner. If anything remained, she poured it out. She then would steep for him at night. When the morning came, he took his morning meal and drank it after his morning meal. She said: The skin vessel was washed in the morning and in the evening. My father (Hayyan) said to her: Twice a day? She said: Yes}}
\hadithdefcmd{abudawud}{3713}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي عُمَرَ، يَحْيَى الْبَهْرَانِيِّ عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ يُنْبَذُ لِلنَّبِيِّ صلى الله عليه وسلم الزَّبِيبُ فَيَشْرَبُهُ الْيَوْمَ وَالْغَدَ وَبَعْدَ الْغَدِ إِلَى مَسَاءِ الثَّالِثَةِ ثُمَّ يَأْمُرُ بِهِ فَيُسْقَى الْخَدَمَ أَوْ يُهَرَاقُ ‏.‏ قَالَ أَبُو دَاوُدَ مَعْنَى يُسْقَى الْخَدَمَ يُبَادَرُ بِهِ الْفَسَادُ ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو عُمَرَ يَحْيَى بْنُ عُبَيْدٍ الْبَهْرَانِيُّ ‏.‏\hadithno{3713}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2004)}\hadithtrans{Ibn abbas said :Raisins were steeped for the Prophet (ﷺ) and he would drink it in the morning and the night after, the following day and the night after. He then gave orders and it was given to servants to drinks or poured away. Abu Dawud said: That "it was given to servants to drink" means before it spoiled. Abu Dawud said: Abu 'Umar Yahya al-Bahrani}}
\hadithdefcmd{abudawud}{3714}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ عَنْ عَطَاءٍ، أَنَّهُ سَمِعَ عُبَيْدَ بْنَ عُمَيْرٍ، قَالَ سَمِعْتُ عَائِشَةَ، - رضى الله عنها - زَوْجَ النَّبِيِّ صلى الله عليه وسلم تُخْبِرُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَمْكُثُ عِنْدَ زَيْنَبَ بِنْتِ جَحْشٍ فَيَشْرَبُ عِنْدَهَا عَسَلاً فَتَوَاصَيْتُ أَنَا وَحَفْصَةُ أَيَّتُنَا مَا دَخَلَ عَلَيْهَا النَّبِيُّ صلى الله عليه وسلم فَلْتَقُلْ إِنِّي أَجِدُ مِنْكَ رِيحَ مَغَافِيرَ فَدَخَلَ عَلَى إِحْدَاهُنَّ فَقَالَتْ لَهُ ذَلِكَ فَقَالَ ‏"‏ بَلْ شَرِبْتُ عَسَلاً عِنْدَ زَيْنَبَ بِنْتِ جَحْشٍ وَلَنْ أَعُودَ لَهُ ‏"‏ ‏.‏ فَنَزَلَتْ ‏\{‏ لِمَ تُحَرِّمُ مَا أَحَلَّ اللَّهُ لَكَ تَبْتَغِي ‏\}‏ إِلَى ‏\{‏ إِنْ تَتُوبَا إِلَى اللَّهِ ‏\}‏ لِعَائِشَةَ وَحَفْصَةَ رضى الله عنهما ‏\{‏ وَإِذْ أَسَرَّ النَّبِيُّ إِلَى بَعْضِ أَزْوَاجِهِ حَدِيثًا ‏\}‏ لِقَوْلِهِ ‏"‏ بَلْ شَرِبْتُ عَسَلاً ‏"‏ ‏.‏\hadithno{3714}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5267) Sahih Muslim (1474)}\hadithtrans{A’ishah said that the prophet (ﷺ) used to stay with Zainab, daughter of Jahsh, and drink honey. I and Hafsah counseled each other that if the Prophet (ﷺ) enters upon any of us, she must say :I find the smell of gum (maghafir) from you. He then entered upon one of them; she said that to him. Thereupon he said : No, I drank honey at (the house of) Zainab daughter of jahsh, and I will not do it again. Then the following verse came down :’’O Prophet !why holdest thou to be forbidden that which Allah has made lawful to thee ? ‘’Thou seekest. . . If you two turn in repentance to Allah ‘’ refers to Hafsah and A’ishah , and the verse: ‘’When the Prophet disclosed a matter in confidence to one of his consorts’’ refers to the statements of the Prophet (ﷺ) disclosed a matter in confidence to one of his consorts’’ refers to the statement of the Prophet (ﷺ) :No, I drank honey}}
\hadithdefcmd{abudawud}{3715}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُحِبُّ الْحَلْوَاءَ وَالْعَسَلَ ‏.‏ فَذَكَرَ بَعْضَ هَذَا الْخَبَرِ ‏.‏ وَكَانَ النَّبِيُّ صلى الله عليه وسلم يَشْتَدُّ عَلَيْهِ أَنْ تُوجَدَ مِنْهُ الرِّيحُ ‏.‏ وَفِي الْحَدِيثِ قَالَتْ سَوْدَةُ بَلْ أَكَلْتَ مَغَافِيرَ ‏.‏ قَالَ ‏ "‏ بَلْ شَرِبْتُ عَسَلاً سَقَتْنِي حَفْصَةُ ‏"‏ ‏.‏ فَقُلْتُ جَرَسَتْ نَحْلُهُ الْعُرْفُطَ ‏.‏ قَالَ أَبُو دَاوُدَ الْمَغَافِيرُ مُقْلَةٌ وَهِيَ صَمْغَةٌ ‏.‏ وَجَرَسَتْ رَعَتْ ‏.‏ وَالْعُرْفُطُ نَبْتٌ مِنْ نَبْتِ النَّحْلِ ‏.‏\hadithno{3715}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5599) Sahih Muslim (1474)}\hadithtrans{‘A’ishah said :The Messenger of Allah(ﷺ) liked sweet meats and honey. The narrator then mentioned a part of the tradition mentioned above. The Messenger of Allah (ﷺ) felt it hard on him to find smell from him. In this tradition saudah said: but you ate gum ? He said : No, I drank honey. Hafsah gave it to me to drank. I said : Its bees ate ‘urfut. Abu Dawud said: Maghafir is a gum ; jarasat means ate; ’urfut is a bees ‘ plant}}
\hadithdefcmd{abudawud}{3716}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، حَدَّثَنَا زَيْدُ بْنُ وَاقِدٍ، عَنْ خَالِدِ بْنِ عَبْدِ اللَّهِ بْنِ حُسَيْنٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ عَلِمْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَصُومُ فَتَحَيَّنْتُ فِطْرَهُ بِنَبِيذٍ صَنَعْتُهُ فِي دُبَّاءٍ ثُمَّ أَتَيْتُهُ بِهِ فَإِذَا هُوَ يَنِشُّ فَقَالَ ‏ "‏ اضْرِبْ بِهَذَا الْحَائِطَ فَإِنَّ هَذَا شَرَابُ مَنْ لاَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ ‏"‏ ‏.‏\hadithno{3716}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuHurayrah: I knew that the Messenger of Allah (ﷺ) used to keep fast. I waited for the day when he did not fast to present him the drink (nabidh) which I made in a pumpkin. I then brought it to him while it fermented. He said: Throw it to this wall, for this is a drink of the one who does not believe in Allah and the Last Day}}
\hadithdefcmd{abudawud}{3717}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يَشْرَبَ الرَّجُلُ قَائِمًا ‏.‏\hadithno{3717}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2024)}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) forbade that a man should drink while standing}}
\hadithdefcmd{abudawud}{3718}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ مِسْعَرِ بْنِ كِدَامٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ مَيْسَرَةَ، عَنِ النَّزَّالِ بْنِ سَبْرَةَ، أَنَّ عَلِيًّا، دَعَا بِمَاءٍ فَشَرِبَهُ وَهُوَ قَائِمٌ ثُمَّ قَالَ إِنَّ رِجَالاً يَكْرَهُ أَحَدُهُمْ أَنْ يَفْعَلَ هَذَا وَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُ مِثْلَ مَا رَأَيْتُمُونِي أَفْعَلُهُ ‏.‏\hadithno{3718}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5615)}\hadithtrans{Nazzal b. Samurah said :‘Ali asked for water and he drank it while standing. He then said: some people disapprove of doing this (drinking while standing ), but I saw the Messenger of Allah (ﷺ) doing as I have done}}
\hadithdefcmd{abudawud}{3719}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا قَتَادَةُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الشُّرْبِ مِنْ فِي السِّقَاءِ وَعَنْ رُكُوبِ الْجَلاَّلَةِ وَالْمُجَثَّمَةِ ‏.‏ قَالَ أَبُو دَاوُدَ الْجَلاَّلَةُ الَّتِي تَأْكُلُ الْعَذِرَةَ ‏.‏\hadithno{3719}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas said:The apostle of allah (ﷺ) forbade drinking from the mouth of a water-skin, and riding the animal which feeds on filth and eating the animal which is killed in confinement. Abu Dawud said: Jallalah means an animal which eats filth and impurities}}
\hadithdefcmd{abudawud}{3720}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، أَنَّهُ سَمِعَ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ اخْتِنَاثِ الأَسْقِيَةِ ‏.‏\hadithno{3720}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5625) Sahih Muslim (2023)}\hadithtrans{Abu Sa’id al-Khudri said :The Messenger of Allah (ﷺ) prohibited drinking by inverting the heads of skin vessels}}
\hadithdefcmd{abudawud}{3721}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ عِيسَى بْنِ عَبْدِ اللَّهِ، - رَجُلٍ مِنَ الأَنْصَارِ - عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَعَا بِإِدَاوَةٍ يَوْمَ أُحُدٍ فَقَالَ ‏ "‏ اخْنُثْ فَمَ الإِدَاوَةِ ‏"‏ ‏.‏ ثُمَّ شَرِبَ مِنْ فِيهَا ‏.‏\hadithno{3721}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{A man of the Ansar quoting from his father said that the Prophet (ﷺ) called for a skin-vessel on the day of the battle of Uhud. He then said:Invert the head of the vessel and he drank from its mouth}}
\hadithdefcmd{abudawud}{3722}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي قُرَّةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الشُّرْبِ مِنْ ثُلْمَةِ الْقَدَحِ وَأَنْ يُنْفَخَ فِي الشَّرَابِ ‏.‏\hadithno{3722}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Abu sa’id al-Khudri said:The apostle of Allah (ﷺ) forbade drinking from the broken place (of a cup) and blowing into a drink}}
\hadithdefcmd{abudawud}{3723}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنِ ابْنِ أَبِي لَيْلَى، قَالَ كَانَ حُذَيْفَةُ بِالْمَدَائِنِ فَاسْتَسْقَى فَأَتَاهُ دِهْقَانٌ بِإِنَاءٍ مِنْ فِضَّةٍ فَرَمَاهُ بِهِ وَقَالَ إِنِّي لَمْ أَرْمِهِ بِهِ إِلاَّ أَنِّي قَدْ نَهَيْتُهُ فَلَمْ يَنْتَهِ وَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْحَرِيرِ وَالدِّيبَاجِ وَعَنِ الشُّرْبِ فِي آنِيَةِ الذَّهَبِ وَالْفِضَّةِ وَقَالَ ‏ "‏ هِيَ لَهُمْ فِي الدُّنْيَا وَلَكُمْ فِي الآخِرَةِ ‏"‏ ‏.‏\hadithno{3723}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5632) Sahih Muslim (2067)}\hadithtrans{Ibn Abi Laila said:Whan Hudhaifah was in al-Mada’in, he asked for water. A peasant brought him a silver vessel. He threw it away and said: I threw it away, for I prohibited (him) but he did not stop. The Messenger of Allah (ﷺ) forbade to wear silk or brocade, and to drink from gold and silver vessels. He said: Others have them in this world and you will have them in the next}}
\hadithdefcmd{abudawud}{3724}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنِي فُلَيْحٌ، عَنْ سَعِيدِ بْنِ الْحَارِثِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم وَرَجُلٌ مِنْ أَصْحَابِهِ عَلَى رَجُلٍ مِنَ الأَنْصَارِ وَهُوَ يُحَوِّلُ الْمَاءَ فِي حَائِطِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ كَانَ عِنْدَكَ مَاءٌ بَاتَ هَذِهِ اللَّيْلَةَ فِي شَنٍّ وَإِلاَّ كَرَعْنَا ‏"‏ ‏.‏ قَالَ بَلْ عِنْدِي مَاءٌ بَاتَ فِي شَنٍّ ‏.‏\hadithno{3724}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5621)}\hadithtrans{Jabir b. ‘abd Allah said:The Prophet (ﷺ) went to visit a man of the Ansar accompanied by one of his Companions who was watering his garden. The Messenger of Allah(ﷺ) said: If you have any water which has remained over night in a skin (we should like it), or shall sip (from a streamlet)}}
\hadithdefcmd{abudawud}{3725}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي الْمُخْتَارِ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ سَاقِيَ الْقَوْمِ آخِرُهُمْ شُرْبًا ‏"‏ ‏.‏\hadithno{3725}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn AbuAwfa: The Prophet (ﷺ) said: The supplier of the people is the last (man) to drink}}
\hadithdefcmd{abudawud}{3726}{حَدَّثَنَا الْقَعْنَبِيُّ عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِلَبَنٍ قَدْ شِيبَ بِمَاءٍ وَعَنْ يَمِينِهِ أَعْرَابِيٌّ وَعَنْ يَسَارِهِ أَبُو بَكْرٍ فَشَرِبَ ثُمَّ أَعْطَى الأَعْرَابِيَّ وَقَالَ ‏ "‏ الأَيْمَنَ فَالأَيْمَنَ ‏"‏ ‏.‏\hadithno{3726}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5619) Sahih Muslim (2029)}\hadithtrans{Anas b. Malik said:The Prophet (ﷺ) was brought milk that was mixed with water. A nomad Arab was on his right and Abu Bakr was on his left. He himself drank and gave it to the nomad Arab, and said: He who is on the right , then he who is on his right then he who is on his right}}
\hadithdefcmd{abudawud}{3727}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِي عِصَامٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا شَرِبَ تَنَفَّسَ ثَلاَثًا وَقَالَ ‏ "‏ هُوَ أَهْنَأُ وَأَمْرَأُ وَأَبْرَأُ ‏"‏ ‏.‏\hadithno{3727}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5631) Sahih Muslim (2028)}\hadithtrans{Anas b.Malik said :when the prophet (ﷺ) drank, he used to breathe three times in the course of a drink and say : It is more whole some ,thrist-quenching and healthier}}
\hadithdefcmd{abudawud}{3728}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُتَنَفَّسَ فِي الإِنَاءِ أَوْ يُنْفَخَ فِيهِ ‏.‏\hadithno{3728}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) forbade blowing or breathing into a vessel}}
\hadithdefcmd{abudawud}{3729}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ يَزِيدَ بْنِ خُمَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ، - مِنْ بَنِي سُلَيْمٍ - قَالَ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى أَبِي فَنَزَلَ عَلَيْهِ فَقَدَّمَ إِلَيْهِ طَعَامًا فَذَكَرَ حَيْسًا أَتَاهُ بِهِ ثُمَّ أَتَاهُ بِشَرَابٍ فَشَرِبَ فَنَاوَلَ مَنْ عَلَى يَمِينِهِ وَأَكَلَ تَمْرًا فَجَعَلَ يُلْقِي النَّوَى عَلَى ظَهْرِ أُصْبَعَيْهِ السَّبَّابَةِ وَالْوُسْطَى فَلَمَّا قَامَ قَامَ أَبِي فَأَخَذَ بِلِجَامِ دَابَّتِهِ فَقَالَ ادْعُ اللَّهَ لِي ‏.‏ فَقَالَ ‏ "‏ اللَّهُمَّ بَارِكْ لَهُمْ فِيمَا رَزَقْتَهُمْ وَاغْفِرْ لَهُمْ وَارْحَمْهُمْ ‏"‏ ‏.‏\hadithno{3729}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2042)}\hadithtrans{’Abd Allah b. Busr from Banu Sulaim said:The Messenger of Allah (ﷺ) came to my father and he was a guest with him. He offered food to him and brought hais. He then brought a drink which he drank and he gave it to the one on his right. He ate dried dates and began to put the kernels on the back of his ring finger and middle finger. When he got up, my father also got up, and held the rein of his mount. He said : Pray to Allah for me. He said : O Allah, bless them in what you provided them, and have mercy on them}}
\hadithdefcmd{abudawud}{3730}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - ح وَحَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ عُمَرَ بْنِ حَرْمَلَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنْتُ فِي بَيْتِ مَيْمُونَةَ فَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَعَهُ خَالِدُ بْنُ الْوَلِيدِ فَجَاءُوا بِضَبَّيْنِ مَشْوِيَّيْنِ عَلَى ثُمَامَتَيْنِ فَتَبَزَّقَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ خَالِدٌ إِخَالُكَ تَقْذُرُهُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أَجَلْ ‏"‏ ‏.‏ ثُمَّ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِلَبَنٍ فَشَرِبَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا أَكَلَ أَحَدُكُمْ طَعَامًا فَلْيَقُلِ اللَّهُمَّ بَارِكْ لَنَا فِيهِ وَأَطْعِمْنَا خَيْرًا مِنْهُ ‏.‏ وَإِذَا سُقِيَ لَبَنًا فَلْيَقُلِ اللَّهُمَّ بَارِكْ لَنَا فِيهِ وَزِدْنَا مِنْهُ ‏.‏ فَإِنَّهُ لَيْسَ شَىْءٌ يُجْزِئُ مِنَ الطَّعَامِ وَالشَّرَابِ إِلاَّ اللَّبَنُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا لَفْظُ مُسَدَّدٍ ‏.‏\hadithno{3730}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: I was in the house of Maymunah. The Messenger of Allah (ﷺ) accompanied by Khalid ibn al-Walid entered. Two roasted long-tailed lizards (dabb) placed on the sticks were brought to him. The Messenger of Allah (ﷺ) spat. Khalid said: I think that you abominate it, Messenger of Allah. He said: Yes. Then the Messenger of Allah (ﷺ) was brought milk, and he drank (it). The Messenger of Allah (ﷺ) then said: When one of you eats food, he should say: O Allah, bless us in it, and give us food (or nourishment) better than it. When he is given milk to drink he should say: O Allah! bless us in it and give us more of it, for no food or drink satisfies like milk. Abu Dawud said: This is the Musaddad's version}}
\hadithdefcmd{abudawud}{3731}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَغْلِقْ بَابَكَ وَاذْكُرِ اسْمَ اللَّهِ فَإِنَّ الشَّيْطَانَ لاَ يَفْتَحُ بَابًا مُغْلَقًا وَأَطْفِ مِصْبَاحَكَ وَاذْكُرِ اسْمَ اللَّهِ وَخَمِّرْ إِنَاءَكَ وَلَوْ بِعُودٍ تَعْرُضُهُ عَلَيْهِ وَاذْكُرِ اسْمَ اللَّهِ وَأَوْكِ سِقَاءَكَ وَاذْكُرِ اسْمَ اللَّهِ ‏"‏ ‏.‏\hadithno{3731}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5623) Sahih Muslim (2012)}\hadithtrans{Jabir reported the Prophet (ﷺ) as saying:Shut your door and make mention of Allah's name, for the devil does not open a door which has been shut; extinguish your lamp and make mention of Allah's name, cover up your vessel even by a piece of wood that you just put on it and make mention of Allah's name, and tie up your water-skin mentioning Allah's name}}
\hadithdefcmd{abudawud}{3732}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْخَبَرِ وَلَيْسَ بِتَمَامِهِ قَالَ ‏"‏ فَإِنَّ الشَّيْطَانَ لاَ يَفْتَحُ بَابًا غَلَقًا وَلاَ يَحُلُّ وِكَاءً وَلاَ يَكْشِفُ إِنَاءً وَإِنَّ الْفُوَيْسِقَةَ تُضْرِمُ عَلَى النَّاسِ بَيْتَهُمْ ‏"‏ ‏.‏ أَوْ ‏"‏ بُيُوتَهُمْ ‏"‏ ‏.‏\hadithno{3732}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2012)}\hadithtrans{Jabir b.’Abd Allah reported the Prophet (ﷺ)as saying this version is not complete ‘’for the devil does not open a shut door, or loosen a water-skin, or uncover a vessel, for a mouse sets a house on fire over its inhabitants’’}}
\hadithdefcmd{abudawud}{3733}{حَدَّثَنَا مُسَدَّدٌ، وَفُضَيْلُ بْنُ عَبْدِ الْوَهَّابِ السُّكَّرِيُّ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ كَثِيرِ بْنِ شِنْظِيرٍ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، رَفَعَهُ قَالَ ‏"‏ وَاكْفِتُوا صِبْيَانَكُمْ عِنْدَ الْعِشَاءِ ‏"‏ ‏.‏ وَقَالَ مُسَدَّدٌ ‏"‏ عِنْدَ الْمَسَاءِ ‏"‏ ‏"‏ فَإِنَّ لِلْجِنِّ انْتِشَارًا وَخَطْفَةً ‏"‏ ‏.‏\hadithno{3733}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3316) Sahih Muslim (2012)}\hadithtrans{Jabir b.Abd Allah reported the Prophet (ﷺ) as saying:Gather your children when darkness spreads, or in the evening (according to Musaddad), for the jinn are abroad and seize them}}
\hadithdefcmd{abudawud}{3734}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ جَابِرٍ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فَاسْتَسْقَى فَقَالَ رَجُلٌ مِنَ الْقَوْمِ أَلاَ نَسْقِيكَ نَبِيذًا قَالَ ‏"‏ بَلَى ‏"‏ ‏.‏ قَالَ فَخَرَجَ الرَّجُلُ يَشْتَدُّ فَجَاءَ بِقَدَحٍ فِيهِ نَبِيذٌ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَلاَّ خَمَّرْتَهُ وَلَوْ أَنْ تَعْرِضَ عَلَيْهِ عُودًا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ الأَصْمَعِيُّ تَعْرُضُهُ عَلَيْهِ ‏.‏\hadithno{3734}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5605) Sahih Muslim (2011)}\hadithtrans{Jabir said:We were with Prophet (ﷺ) and he asked for something to drink. A man from the company asked: Should we not give you nabidh (drink made from dates) to drink ? He replied : Yes . The man went quickly and bought a cup of nabidh. The Messenger of Allah (ﷺ) said: Why did you not cover it up even by putting a piece of wood on it ? Abu Dawud said: Al-Asma'i's version has: "You put it on it}}
\hadithdefcmd{abudawud}{3735}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَعَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالُوا حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُسْتَعْذَبُ لَهُ الْمَاءُ مِنْ بُيُوتِ السُّقْيَا ‏.‏ قَالَ قُتَيْبَةُ عَيْنٌ بَيْنَهَا وَبَيْنَ الْمَدِينَةِ يَوْمَانِ ‏.‏\hadithno{3735}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The water from as-Suqya' was considered sweetest by the Prophet (ﷺ). Qutaybah said: it was a well on two days' journey from Medina}}
