% Auto-generated chapter 50 for malik
% Hadiths in this chapter: 19

\hadithdefcmd{malik}{1711}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، أَنَّهُ سَمِعَ أَبَاهُ، يَقُولُ اغْتَسَلَ أَبِي سَهْلُ بْنُ حُنَيْفٍ بِالْخَرَّارِ فَنَزَعَ جُبَّةً كَانَتْ عَلَيْهِ وَعَامِرُ بْنُ رَبِيعَةَ يَنْظُرُ قَالَ وَكَانَ سَهْلٌ رَجُلاً أَبْيَضَ حَسَنَ الْجِلْدِ - قَالَ - فَقَالَ لَهُ عَامِرُ بْنُ رَبِيعَةَ مَا رَأَيْتُ كَالْيَوْمِ وَلاَ جِلْدَ عَذْرَاءَ ‏.‏ قَالَ فَوُعِكَ سَهْلٌ مَكَانَهُ وَاشْتَدَّ وَعْكُهُ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأُخْبِرَ أَنَّ سَهْلاً وُعِكَ وَأَنَّهُ غَيْرُ رَائِحٍ مَعَكَ يَا رَسُولَ اللَّهِ فَأَتَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ سَهْلٌ بِالَّذِي كَانَ مِنْ شَأْنِ عَامِرٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلاَمَ يَقْتُلُ أَحَدُكُمْ أَخَاهُ أَلاَّ بَرَّكْتَ إِنَّ الْعَيْنَ حَقٌّ تَوَضَّأْ لَهُ ‏"‏ ‏.‏ فَتَوَضَّأَ لَهُ عَامِرٌ فَرَاحَ سَهْلٌ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيْسَ بِهِ بَأْسٌ ‏.‏\hadithno{1711}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Muhammad ibn Abi Umama ibn Sahl ibn Hunayf heard his father say, "My father, Sahl ibn Hunayf did a ghusl at al-Kharrar. He removed the jubbah he had on while Amir ibn Rabia was watching, and Sahl was a man with beautiful white skin. Amir said to him, 'I have never seen anything like what I have seen today, not even the skin of a virgin.' Sahl fell ill on the spot, and his condition grew worse. Somebody went to the Messenger of Allah, may Allah bless him and grant him peace, and told him that Sahl was ill, and could not go with him. The Messenger of Allah, may Allah bless him and grant him peace, came to him, and Sahl told him what had happened with Amir. The Messenger of Allah, may Allah bless him and grant him peace, said, 'Why does one of you kill his brother? Why did you not say, "May Allah bless you?" (ta baraka-llah) The evil eye is true. Do wudu from it.' Amir did wudu from it and Sahl went with the Messenger of Allah, may Allah bless him and grant him peace, and there was nothing wrong with him}}
\hadithdefcmd{malik}{1712}{وَحَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، أَنَّهُ قَالَ رَأَى عَامِرُ بْنُ رَبِيعَةَ سَهْلَ بْنَ حُنَيْفٍ يَغْتَسِلُ فَقَالَ مَا رَأَيْتُ كَالْيَوْمِ وَلاَ جِلْدَ مُخْبَأَةٍ ‏.‏ فَلُبِطَ سَهْلٌ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقِيلَ يَا رَسُولَ اللَّهِ هَلْ لَكَ فِي سَهْلِ بْنِ حُنَيْفٍ وَاللَّهِ مَا يَرْفَعُ رَأْسَهُ ‏.‏ فَقَالَ ‏"‏ هَلْ تَتَّهِمُونَ لَهُ أَحَدًا ‏"‏ قَالُوا نَتَّهِمُ عَامِرَ بْنَ رَبِيعَةَ ‏.‏ قَالَ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَامِرًا فَتَغَيَّظَ عَلَيْهِ وَقَالَ ‏"‏ عَلاَمَ يَقْتُلُ أَحَدُكُمْ أَخَاهُ أَلاَّ بَرَّكْتَ اغْتَسِلْ لَهُ ‏"‏ ‏.‏ فَغَسَلَ عَامِرٌ وَجْهَهُ وَيَدَيْهِ وَمِرْفَقَيْهِ وَرُكْبَتَيْهِ وَأَطْرَافَ رِجْلَيْهِ وَدَاخِلَةَ إِزَارِهِ فِي قَدَحٍ ثُمَّ صُبَّ عَلَيْهِ فَرَاحَ سَهْلٌ مَعَ النَّاسِ لَيْسَ بِهِ بَأْسٌ ‏.‏\hadithno{1712}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Ibn Shihab that Abu Umama ibn Sahl ibn Hunayf said, ''Amir ibn Rabia saw Sahl ibn Hunayf doing a ghusl and said, 'I have not seen the like of what I see today, not even the skin of a maiden who has never been out of doors.' Sahl fell to the ground. The Messenger of Allah, may Allah bless him and grant him peace, was approached and it was said, 'Messenger of Allah, can you do anything about Sahl ibn Hunayf? By Allah, he can not raise his head.' He said, 'Do you suspect anyone of it?' They said, 'We suspect Amir ibn Rabia.' " He continued, "The Messenger of Allah, may Allah bless him and grant him peace, summoned Amir and was furious with him and said, 'Why does one of you kill his brother? Why did you not say, "May Allah bless you?" Do ghusl for it.' Amir washed his face, hands, elbows, knees, the end of his feet, and inside his lower garment in a vessel. Then he poured it over him, and Sahl went off with the people, and there was nothing wrong with him}}
\hadithdefcmd{malik}{1713}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ حُمَيْدِ بْنِ قَيْسٍ الْمَكِّيِّ، أَنَّهُ قَالَ دُخِلَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِابْنَىْ جَعْفَرِ بْنِ أَبِي طَالِبٍ فَقَالَ لِحَاضِنَتِهِمَا ‏"‏ مَا لِي أَرَاهُمَا ضَارِعَيْنِ ‏"‏ ‏.‏ فَقَالَتْ حَاضِنَتُهُمَا يَا رَسُولَ اللَّهِ إِنَّهُ تَسْرَعُ إِلَيْهِمَا الْعَيْنُ وَلَمْ يَمْنَعْنَا أَنْ نَسْتَرْقِيَ لَهُمَا إِلاَّ أَنَّا لاَ نَدْرِي مَا يُوَافِقُكَ مِنْ ذَلِكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اسْتَرْقُوا لَهُمَا فَإِنَّهُ لَوْ سَبَقَ شَىْءٌ الْقَدَرَ لَسَبَقَتْهُ الْعَيْنُ ‏"‏ ‏.‏\hadithno{1713}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Humayd ibn Qays al-Makki said, "A man came to the Messenger of Allah, may Allah bless him and grant him peace, with the two sons of Jafar ibn Abi Talib. He said to their nursemaid, 'Why do I see them so thin?' Their nursemaid said, 'Messenger of Allah, the evil eye goes quickly to them. Nothing stops us from asking someone to make incantations (using ayats of Qur'an) for them, except that we do not know what of that would agree with you.' The Messenger of ,Allah, may Allah bless him and grant him peace, said, 'Make incantations for them. Had anything been able to precede the decree, the evil eye would precede it}}
\hadithdefcmd{malik}{1714}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ بَيْتَ أُمِّ سَلَمَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَفِي الْبَيْتِ صَبِيٌّ يَبْكِي فَذَكَرُوا لَهُ أَنَّ بِهِ الْعَيْنَ - قَالَ عُرْوَةُ - فَقَالَ رَسُولُ اللَّهِ\hadithno{1714}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Sulayman ibn Yasar that Urwa ibn az-Zubayr told him that the Messenger of Allah, may Allah bless him and grant him peace, entered the house of Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace. There was a child weeping in the house, and they told him that it was from the evil eye. Urwa said, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'Why do you not find someone to make an incantation to protect it from the evil eye?}}
\hadithdefcmd{malik}{1715}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا مَرِضَ الْعَبْدُ بَعَثَ اللَّهُ تَعَالَى إِلَيْهِ مَلَكَيْنِ فَقَالَ انْظُرَا مَاذَا يَقُولُ لِعُوَّادِهِ ‏.‏ فَإِنْ هُوَ - إِذَا جَاءُوهُ - حَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ رَفَعَا ذَلِكَ إِلَى اللَّهِ عَزَّ وَجَلَّ - وَهُوَ أَعْلَمُ - فَيَقُولُ لِعَبْدِي عَلَىَّ إِنْ تَوَفَّيْتُهُ أَنْ أُدْخِلَهُ الْجَنَّةَ وَإِنْ أَنَا شَفَيْتُهُ أَنْ أُبْدِلَ لَهُ لَحْمًا خَيْرًا مِنْ لَحْمِهِ وَدَمًا خَيْرًا مِنْ دَمِهِ وَأَنْ أُكَفِّرَ عَنْهُ سَيِّئَاتِهِ ‏"‏ ‏.‏\hadithno{1715}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar that the Messenger of Allah, may Allah bless him and grant him peace, said, "When the slave is ill, Allah ta'ala sends two angels to him." He said, "They look at what he says to his visitors. If he praises Allah and lauds Him, when they come to him, they take that up to Allah, the Mighty, the Majestic, and He knows best, and He says, 'If I make my slave die, I will make him enter the Garden. If I heal him, I will replace his flesh with better flesh and his blood with better blood and I will efface his evil actions}}
\hadithdefcmd{malik}{1716}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّهُ قَالَ سَمِعْتُ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُصِيبُ الْمُؤْمِنَ مِنْ مُصِيبَةٍ حَتَّى الشَّوْكَةُ إِلاَّ قُصَّ بِهَا أَوْ كُفِّرَ بِهَا مِنْ خَطَايَاهُ ‏"‏ ‏.‏ لاَ يَدْرِي يَزِيدُ أَيَّهُمَا قَالَ عُرْوَةُ ‏.‏\hadithno{1716}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yazid ibn Khusayfa that Urwa ibn az-Zubayr said that he heard A'isha, the wife of the Prophet, may Allah bless him and grant him peace, say, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'When a mumin is afflicted by something, even a thorn, it removes (or effaces) his wrong actions.' " Yazid did not know which of them Urwa said}}
\hadithdefcmd{malik}{1717}{وَحَدَّثَنِي مَالِكٌ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي صَعْصَعَةَ، أَنَّهُ قَالَ سَمِعْتُ أَبَا الْحُبَابِ، سَعِيدَ بْنَ يَسَارٍ يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يُرِدِ اللَّهُ بِهِ خَيْرًا يُصِبْ مِنْهُ ‏"‏ ‏.‏\hadithno{1717}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Muhammad ibn Abdullah ibn Abi Sasaca said that he heard Abu'l-Hubab Said ibn Yasar say that he had heard Abu Hurayra say, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'Allah afflicts the one for whom He desires good}}
\hadithdefcmd{malik}{1718}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ رَجُلاً، جَاءَهُ الْمَوْتُ فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَجُلٌ هَنِيئًا لَهُ مَاتَ وَلَمْ يُبْتَلَ بِمَرَضٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَيْحَكَ وَمَا يُدْرِيكَ لَوْ أَنَّ اللَّهَ ابْتَلاَهُ بِمَرَضٍ يُكَفِّرُ بِهِ مِنْ سَيِّئَاتِهِ ‏"‏ ‏.‏\hadithno{1718}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that death came to a man in the time of the Messenger of Allah, may Allah bless him and grant him peace. A man said, "He was fortunate," as he had died without being tried by illness. The Messenger of Allah, may Allah bless him and grant him peace, said, "Alas for you, what will let you know that if Allah had tried him with illness, He would have wiped out his wrong actions}}
\hadithdefcmd{malik}{1719}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، أَنَّ عَمْرَو بْنَ عَبْدِ اللَّهِ بْنِ كَعْبٍ السَّلَمِيَّ، أَخْبَرَهُ أَنَّ نَافِعَ بْنَ جُبَيْرٍ أَخْبَرَهُ عَنْ عُثْمَانَ بْنِ أَبِي الْعَاصِ، أَنَّهُ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ عُثْمَانُ وَبِي وَجَعٌ قَدْ كَادَ يُهْلِكُنِي ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ امْسَحْهُ بِيَمِينِكَ سَبْعَ مَرَّاتٍ وَقُلْ أَعُوذُ بِعِزَّةِ اللَّهِ وَقُدْرَتِهِ مِنْ شَرِّ مَا أَجِدُ ‏"‏ ‏.‏ قَالَ فَقُلْتُ ذَلِكَ فَأَذْهَبَ اللَّهُ مَا كَانَ بِي فَلَمْ أَزَلْ آمُرُ بِهَا أَهْلِي وَغَيْرَهُمْ ‏.‏\hadithno{1719}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yazid ibn Khusayfa that Amr ibn Abdullah ibn Kab as-Salami told him that Nafi ibn Jubayr told him that Uthman ibn Abi al-As came to the Messenger of Allah, may Allah bless him and grant him peace. Uthman said that he had a pain which was enough to kill him. The Messenger of Allah, may Allah bless him and grant him peace, said, "Rub it with your right hand seven times and say, 'I take refuge with the might of Allah and His power from the evil of what I feel.' " Uthman added, "I said that, and Allah removed what I had. I still command my family and others to say it}}
\hadithdefcmd{malik}{1720}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا اشْتَكَى يَقْرَأُ عَلَى نَفْسِهِ بِالْمُعَوِّذَاتِ وَيَنْفِثُ ‏.‏ قَالَتْ فَلَمَّا اشْتَدَّ وَجَعُهُ كُنْتُ أَنَا أَقْرَأُ عَلَيْهِ وَأَمْسَحُ عَلَيْهِ بِيَمِينِهِ رَجَاءَ بَرَكَتِهَا ‏.‏\hadithno{1720}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Urwa ibn az- Zubayr from A'isha that the Messenger of Allah, may Allah bless him and grant him peace, when he had a complaint, would recite the last three suras of Qur'an, over himself and blow. She said, "When his pain was great, I would recite it over him and wipe him with his right hand hoping for its blessing}}
\hadithdefcmd{malik}{1721}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا بَكْرٍ الصِّدِّيقَ، دَخَلَ عَلَى عَائِشَةَ وَهِيَ تَشْتَكِي وَيَهُودِيَّةٌ تَرْقِيهَا فَقَالَ أَبُو بَكْرٍ ارْقِيهَا بِكِتَابِ اللَّهِ ‏.‏\hadithno{1721}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Amra bint Abd ar-Rahman that Abu Bakr as-Siddiq visited A'isha while she had a [health] complaint and a jewish woman was making incantation (ruqya) for her. Abu Bakr said, "Do it (incantation) with the Book of Allah}}
\hadithdefcmd{malik}{1722}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ رَجُلاً، فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَصَابَهُ جُرْحٌ فَاحْتَقَنَ الْجُرْحُ الدَّمَ وَأَنَّ الرَّجُلَ دَعَا رَجُلَيْنِ مِنْ بَنِي أَنْمَارٍ فَنَظَرَا إِلَيْهِ فَزَعَمَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُمَا ‏"‏ أَيُّكُمَا أَطَبُّ ‏"‏ ‏.‏ فَقَالاَ أَوَ فِي الطِّبِّ خَيْرٌ يَا رَسُولَ اللَّهِ فَزَعَمَ زَيْدٌ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَنْزَلَ الدَّوَاءَ الَّذِي أَنْزَلَ الأَدْوَاءَ ‏"‏ ‏.‏\hadithno{1722}\hadithgrade{Salim al-Hilali: Isnaad Daif}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that a man received a wound in the time of the Messenger of Allah, may Allah bless him and grant him peace. The blood clotted in the wound and the man called two men from the Banu Ammar tribe. They looked at it and claimed that the Messenger of Allah, may Allah bless him and grant him peace, said to them, "Which of you is the better doctor?" They said, "Is there any good in medicine, Messenger of Allah?" Zayd claimed that the Messenger of Allah, may Allah bless him and grant him peace, said, "The one who sent down the disease sent down the remedy}}
\hadithdefcmd{malik}{1723}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ بَلَغَنِي أَنَّ سَعْدَ بْنَ زُرَارَةَ، اكْتَوَى فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الذُّبَحَةِ فَمَاتَ ‏.‏\hadithno{1723}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said, "I heard that Sad ibn Zurara cauterized himself because of a pain in the throat accompanied by blood and he died}}
\hadithdefcmd{malik}{1724}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، اكْتَوَى مِنَ اللَّقْوَةِ وَرُقِيَ مِنَ الْعَقْرَبِ ‏.‏\hadithno{1724}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar cauterized for the palsy and he had a talisman made for a scorpion sting}}
\hadithdefcmd{malik}{1725}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، أَنَّ أَسْمَاءَ بِنْتَ أَبِي بَكْرٍ، كَانَتْ إِذَا أُتِيَتْ بِالْمَرْأَةِ وَقَدْ حُمَّتْ تَدْعُو لَهَا أَخَذَتِ الْمَاءَ فَصَبَّتْهُ بَيْنَهَا وَبَيْنَ جَيْبِهَا وَقَالَتْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْمُرُنَا أَنْ نُبْرِدَهَا بِالْمَاءِ ‏.‏\hadithno{1725}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from Fatima bint al-Mundhir that whenever a woman who had a fever, was brought to Asma bint Abi Bakr, she made dua for her and took water and poured it inside her collar. She said, "The Messenger of Allah, may Allah bless him and grant him peace, ordered us to cool it with water}}
\hadithdefcmd{malik}{1726}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ فَابْرُدُوهَا بِالْمَاءِ ‏"‏ ‏.‏\hadithno{1726}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that the Messenger of Allah, may Allah bless him and grant him peace, said, "Fever is from the vehemence of the heat of Jahannam, so cool it with water}}
\hadithdefcmd{malik}{1727}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْحُمَّى مِنْ فَيْحِ جَهَنَّمَ فَأَطْفِئُوهَا بِالْمَاءِ ‏"‏ ‏.‏\hadithno{1727}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Nafi from Ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "Fever is from the vehemence of the heat of Jahannam, so put it out with water}}
\hadithdefcmd{malik}{1728}{حَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا عَادَ الرَّجُلُ الْمَرِيضَ خَاضَ الرَّحْمَةَ حَتَّى إِذَا قَعَدَ عِنْدَهُ قَرَّتْ فِيهِ ‏"‏ ‏.‏ أَوْ نَحْوَ هَذَا ‏.‏\hadithno{1728}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he had heard from Jabir ibn Abdullah that the Messenger of Allah, may Allah bless him and grant him peace, said, "When a man visits an invalid, he plunges into mercy to the extent that when he sits with him, it settles in him," or the like of that}}
\hadithdefcmd{malik}{1729}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنِ ابْنِ عَطِيَّةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ عَدْوَى وَلاَ هَامَ وَلاَ صَفَرَ وَلاَ يَحُلَّ الْمُمْرِضُ عَلَى الْمُصِحِّ وَلْيَحْلُلِ الْمُصِحُّ حَيْثُ شَاءَ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ وَمَا ذَاكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهُ أَذًى ‏"‏ ‏.‏\hadithno{1729}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik that he had heard from Bukayr ibn Abdullah ibn al-Ashajj from Ibn Atiya that the Messenger of Allah, may Allah bless him and grant him peace, said:"There is no contagion, no hama and no serpent in a hungry belly. However, the possessor of sick livestock must not stop at the same place as the possessor of healthy livestock, but the possessor of healthy livestock may stop wherever he wishes." They said, "Messenger of Allah, Why is that?" The Messenger of Allah, may Allah bless him and grant him peace, said, "It is harmful." Note: The majority of scholars interpret this to mean that these things in and of themselves do not transmit or cause harm through supernatural or hidden means but that Allah is ultimately in control and any fearful superstition around these is false}}
