% Auto-generated chapter 24 for malik
% Hadiths in this chapter: 10

\hadithdefcmd{malik}{1042}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقِيلَ لَهُ يَا رَسُولَ اللَّهِ إِنَّ نَاسًا مِنْ أَهْلِ الْبَادِيَةِ يَأْتُونَنَا بِلُحْمَانٍ وَلاَ نَدْرِي هَلْ سَمَّوُا اللَّهَ عَلَيْهَا أَمْ لاَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سَمُّوا اللَّهَ عَلَيْهَا ثُمَّ كُلُوهَا ‏"‏ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ فِي أَوَّلِ الإِسْلاَمِ ‏.‏\hadithno{1042}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said, "The Messenger of Allah, may Allah bless him and grant him peace, was asked, 'Messenger of Allah! Some people from the desert bring us meat, and we do not know whether the name of Allah has been mentioned over it or not.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'Mention the name of Allah over it and eat.' " Malik said, "That was in the beginning of Islam}}
\hadithdefcmd{malik}{1043}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عَيَّاشِ بْنِ أَبِي رَبِيعَةَ الْمَخْزُومِيَّ، أَمَرَ غُلاَمًا لَهُ أَنْ يَذْبَحَ ذَبِيحَةً فَلَمَّا أَرَادَ أَنْ يَذْبَحَهَا قَالَ لَهُ سَمِّ اللَّهَ ‏.‏ فَقَالَ لَهُ الْغُلاَمُ قَدْ سَمَّيْتُ ‏.‏ فَقَالَ لَهُ سَمِّ اللَّهَ وَيْحَكَ ‏.‏ قَالَ لَهُ قَدْ سَمَّيْتُ اللَّهَ ‏.‏ فَقَالَ لَهُ عَبْدُ اللَّهِ بْنُ عَيَّاشٍ وَاللَّهِ لاَ أَطْعَمُهَا أَبَدًا ‏.‏\hadithno{1043}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Abdullah ibn Ayyash ibn Abi Rabia al-Makhzumi ordered one of his slaves to slaughter an animal. When he wanted to slaughter it, he said to him, "Mention Allah's name." The slave said to him, "I have mentioned the name!" He said to him, "Mention the name of Allah, bother you!" He said to him, "I have mentioned the name of Allah " Abdullah ibn Ayyash said, "By Allah, I shall never eat it}}
\hadithdefcmd{malik}{1044}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ مِنْ بَنِي حَارِثَةَ كَانَ يَرْعَى لِقْحَةً لَهُ بِأُحُدٍ فَأَصَابَهَا الْمَوْتُ فَذَكَّاهَا بِشِظَاظٍ فَسُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ لَيْسَ بِهَا بَأْسٌ فَكُلُوهَا ‏"‏ ‏.‏\hadithno{1044}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar that a man from the Ansar of the tribe of Banu Haritha was herding a pregnant she-camel at Uhud. It was about to die, so he slaughtered it with a sharp stake. The Messenger of Allah was asked about that, and he said, "There is no harm in it, eat it}}
\hadithdefcmd{malik}{1045}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ رَجُلٍ، مِنَ الأَنْصَارِ عَنْ مُعَاذِ بْنِ سَعْدٍ، أَوْ سَعْدِ بْنِ مُعَاذٍ أَنَّ جَارِيَةً، لِكَعْبِ بْنِ مَالِكٍ كَانَتْ تَرْعَى غَنَمًا لَهَا بِسَلْعٍ فَأُصِيبَتْ شَاةٌ مِنْهَا فَأَدْرَكَتْهَا فَذَكَّتْهَا بِحَجَرٍ فَسُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ لاَ بَأْسَ بِهَا فَكُلُوهَا ‏"‏ ‏.‏\hadithno{1045}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from a man of the Ansar from Muadh ibn Sad or Sad ibn Muadh that a slave-girl of Kab ibn Malik was herding some sheep at Sal (a mountain near Madina). One of the sheep was about to die, so she went over to it and slaughtered it with a stone. The Messenger of Allah, may Allah bless him and grant him peace, was asked about that, and he said, "There is no harm in it, so eat it}}
\hadithdefcmd{malik}{1046}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ سُئِلَ عَنْ ذَبَائِحِ، نَصَارَى الْعَرَبِ فَقَالَ لاَ بَأْسَ بِهَا وَتَلاَ هَذِهِ الآيَةَ ‏\{‏وَمَنْ يَتَوَلَّهُمْ مِنْكُمْ فَإِنَّهُ مِنْهُمْ ‏\}‏‏.‏\hadithno{1046}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Thawr ibn Zayd ad-Dili that Abdullah ibn Abbas was asked about animals slaughtered by the Christian Arabs. He said, "There is no harm in them," but he recited this ayat, "Whoever takes them as friends is from them." (Sura 5 ayat)}}
\hadithdefcmd{malik}{1047}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، كَانَ يَقُولُ مَا فَرَى الأَوْدَاجَ فَكُلُوهُ ‏.‏\hadithno{1047}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that Abdullah ibn Abbas used to say, "You can eat anything that has had its jugular vein cut}}
\hadithdefcmd{malik}{1048}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ كَانَ يَقُولُ مَا ذُبِحَ بِهِ إِذَا بَضَعَ فَلاَ بَأْسَ بِهِ إِذَا اضْطُرِرْتَ إِلَيْهِ ‏.‏\hadithno{1048}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab said, "There is no harm in whatever you slaughter with a cutting edge, as long as you are forced to do it by necessity}}
\hadithdefcmd{malik}{1049}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي مُرَّةَ، مَوْلَى عَقِيلِ بْنِ أَبِي طَالِبٍ أَنَّهُ سَأَلَ أَبَا هُرَيْرَةَ عَنْ شَاةٍ، ذُبِحَتْ فَتَحَرَّكَ بَعْضُهَا فَأَمَرَهُ أَنْ يَأْكُلَهَا ثُمَّ سَأَلَ عَنْ ذَلِكَ زَيْدَ بْنَ ثَابِتٍ فَقَالَ إِنَّ الْمَيْتَةَ لَتَتَحَرَّكُ وَنَهَاهُ عَنْ ذَلِكَ ‏.‏ وَسُئِلَ مَالِكٌ عَنْ شَاةٍ تَرَدَّتْ فَتَكَسَّرَتْ فَأَدْرَكَهَا صَاحِبُهَا فَذَبَحَهَا فَسَالَ الدَّمُ مِنْهَا وَلَمْ تَتَحَرَّكْ فَقَالَ مَالِكٌ إِذَا كَانَ ذَبَحَهَا وَنَفَسُهَا يَجْرِي وَهِيَ تَطْرِفُ فَلْيَأْكُلْهَا ‏.‏\hadithno{1049}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Abu Murra, the mawla of Aqil ibn Abi Talib asked Abu Hurayra about a sheep which was slaughtered and then part of it moved. He ordered him to eat it. Then he asked Zayd ibn Thabit about it, and he said, "Does a corpse move?" and he forbade eating its meat. Malik was asked about a sheep which fell down and injured itself badly and then its master reached it and slaughtered it. Blood flowed from it but it did not move. Malik said, "If he kills it and blood flows from it and its eyes blink, he should eat it}}
\hadithdefcmd{malik}{1050}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ إِذَا نُحِرَتِ النَّاقَةُ فَذَكَاةُ مَا فِي بَطْنِهَا فِي ذَكَاتِهَا إِذَا كَانَ قَدْ تَمَّ خَلْقُهُ وَنَبَتَ شَعَرُهُ فَإِذَا خَرَجَ مِنْ بَطْنِ أُمِّهِ ذُبِحَ حَتَّى يَخْرُجَ الدَّمُ مِنْ جَوْفِهِ ‏.‏\hadithno{1050}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "When a she-camel is slaughtered, what is in its womb is included in the slaughter if it is perfectly formed and its hair has begun to grow. If it comes out of its mother's womb, it is slaughtered so that blood flows from its heart}}
\hadithdefcmd{malik}{1051}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ قُسَيْطٍ اللَّيْثِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ كَانَ يَقُولُ ذَكَاةُ مَا فِي بَطْنِ الذَّبِيحَةِ فِي ذَكَاةِ أُمِّهِ إِذَا كَانَ قَدْ تَمَّ خَلْقُهُ وَنَبَتَ شَعَرُهُ ‏.‏\hadithno{1051}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yazid ibn Abdullah ibn Qusayt al-Laythi that Said ibn al- Musayyab said, "The slaughter of what is in the womb is included in the slaughter of the mother if it is perfectly formed and its hair has begun to grow}}
