% Auto-generated chapter 46 for muslim
% Hadiths in this chapter: 52

\hadithdefcmd{muslim}{6723}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ، اللَّهِ بْنِ نُمَيْرٍ الْهَمْدَانِيُّ - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي وَأَبُو مُعَاوِيَةَ وَوَكِيعٌ قَالُوا حَدَّثَنَا الأَعْمَشُ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ الصَّادِقُ الْمَصْدُوقُ ‏ "‏ إِنَّ أَحَدَكُمْ يُجْمَعُ خَلْقُهُ فِي بَطْنِ أُمِّهِ أَرْبَعِينَ يَوْمًا ثُمَّ يَكُونُ فِي ذَلِكَ عَلَقَةً مِثْلَ ذَلِكَ ثُمَّ يَكُونُ فِي ذَلِكَ مُضْغَةً مِثْلَ ذَلِكَ ثُمَّ يُرْسَلُ الْمَلَكُ فَيَنْفُخُ فِيهِ الرُّوحَ وَيُؤْمَرُ بِأَرْبَعِ كَلِمَاتٍ بِكَتْبِ رِزْقِهِ وَأَجَلِهِ وَعَمَلِهِ وَشَقِيٌّ أَوْ سَعِيدٌ فَوَالَّذِي لاَ إِلَهَ غَيْرُهُ إِنَّ أَحَدَكُمْ لَيَعْمَلُ بِعَمَلِ أَهْلِ الْجَنَّةِ حَتَّى مَا يَكُونَ بَيْنَهُ وَبَيْنَهَا إِلاَّ ذِرَاعٌ فَيَسْبِقُ عَلَيْهِ الْكِتَابُ فَيَعْمَلُ بِعَمَلِ أَهْلِ النَّارِ فَيَدْخُلُهَا وَإِنَّ أَحَدَكُمْ لَيَعْمَلُ بِعَمَلِ أَهْلِ النَّارِ حَتَّى مَا يَكُونَ بَيْنَهُ وَبَيْنَهَا إِلاَّ ذِرَاعٌ فَيَسْبِقُ عَلَيْهِ الْكِتَابُ فَيَعْمَلُ بِعَمَلِ أَهْلِ الْجَنَّةِ فَيَدْخُلُهَا ‏"‏ ‏.‏\hadithno{6723}\hadithtrans{Abdullah (b. Mas'ud) reported that Allah's Messenger (ﷺ) who is the most truthful (of the human beings) and his being truthful (is a fact) said:Verily your creation is on this wise. The constituents of one of you are collected for forty days in his mother's womb in the form of blood, after which it becomes a clot of blood in another period of forty days. Then it becomes a lump of flesh and forty days later Allah sends His angel to it with instructions concerning four things, so the angel writes down his livelihood, his death, his deeds, his fortune and misfortune. By Him, besides Whom there is no god, that one amongst you acts like the people deserving Paradise until between him and Paradise there remains but the distance of a cubit, when suddenly the writing of destiny overcomes him and he begins to act like the denizens of Hell and thus enters Hell, and another one acts in the way of the denizens of Hell, until there remains between him and Hell a distance of a cubit that the writing of destiny overcomes him and then he begins to act like the people of Paradise and enters Paradise}}
\hadithdefcmd{muslim}{6724}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، كِلاَهُمَا عَنْ جَرِيرِ بْنِ عَبْدِ، الْحَمِيدِ ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنِي أَبُو سَعِيدٍ، الأَشَجُّ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَاهُ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ بْنُ الْحَجَّاجِ، كُلُّهُمْ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ قَالَ فِي حَدِيثِ وَكِيعٍ ‏"‏ إِنَّ خَلْقَ أَحَدِكُمْ يُجْمَعُ فِي بَطْنِ أُمِّهِ أَرْبَعِينَ لَيْلَةً ‏"‏ ‏.‏ وَقَالَ فِي حَدِيثِ مُعَاذٍ عَنْ شُعْبَةَ ‏"‏ أَرْبَعِينَ لَيْلَةً أَرْبَعِينَ يَوْمًا ‏"‏ ‏.‏ وَأَمَّا فِي حَدِيثِ جَرِيرٍ وَعِيسَى ‏"‏ أَرْبَعِينَ يَوْمًا ‏"‏ ‏.‏\hadithno{6724}\hadithtrans{This hadith has been reported on the authority of A'mash with the same chain of transmitters and in the hadith transmitted on the authority of Waki' (the words are):" The creation of any one of you is like this that (semen) is collected in the womb of the mother for forty nights," and in the hadith transmitted on the authority of Shu'ba (the words are):" Forty nights and forty days." And in the hadith transmitted on the authority of Jarir and 'Isa (the words are):" Forty days}}
\hadithdefcmd{muslim}{6725}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لاِبْنِ نُمَيْرٍ - قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي الطُّفَيْلِ، عَنْ حُذَيْفَةَ بْنِ أَسِيدٍ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ يَدْخُلُ الْمَلَكُ عَلَى النُّطْفَةِ بَعْدَ مَا تَسْتَقِرُّ فِي الرَّحِمِ بِأَرْبَعِينَ أَوْ خَمْسَةٍ وَأَرْبَعِينَ لَيْلَةً فَيَقُولُ يَا رَبِّ أَشَقِيٌّ أَوْ سَعِيدٌ فَيُكْتَبَانِ فَيَقُولُ أَىْ رَبِّ أَذَكَرٌ أَوْ أُنْثَى فَيُكْتَبَانِ وَيُكْتَبُ عَمَلُهُ وَأَثَرُهُ وَأَجَلُهُ وَرِزْقُهُ ثُمَّ تُطْوَى الصُّحُفُ فَلاَ يُزَادُ فِيهَا وَلاَ يُنْقَصُ ‏"‏ ‏.‏\hadithno{6725}\hadithtrans{Hudhaifa b. Usaid reported directly from Allah's Messenger (ﷺ) that he said:When the drop of (semen) remains in the womb for forty or forty five nights, the angel comes and says: My Lord, will he be good or evil? And both these things would be written. Then the angel says: My Lord, would he be male or female? And both these things are written. And his deeds and actions, his death, his livelihood; these are also recorded. Then his document of destiny is rolled and there is no addition to nor subtraction from it}}
\hadithdefcmd{muslim}{6726}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو، بْنُ الْحَارِثِ عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، أَنَّ عَامِرَ بْنَ وَاثِلَةَ، حَدَّثَهُ أَنَّهُ، سَمِعَ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، يَقُولُ الشَّقِيُّ مَنْ شَقِيَ فِي بَطْنِ أُمِّهِ وَالسَّعِيدُ مَنْ وُعِظَ بِغَيْرِهِ ‏.‏ فَأَتَى رَجُلاً مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم يُقَالُ لَهُ حُذَيْفَةُ بْنُ أَسِيدٍ الْغِفَارِيُّ فَحَدَّثَهُ بِذَلِكَ مِنْ قَوْلِ ابْنِ مَسْعُودٍ فَقَالَ وَكَيْفَ يَشْقَى رَجُلٌ بِغَيْرِ عَمَلٍ فَقَالَ لَهُ الرَّجُلُ أَتَعْجَبُ مِنْ ذَلِكَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا مَرَّ بِالنُّطْفَةِ ثِنْتَانِ وَأَرْبَعُونَ لَيْلَةً بَعَثَ اللَّهُ إِلَيْهَا مَلَكًا فَصَوَّرَهَا وَخَلَقَ سَمْعَهَا وَبَصَرَهَا وَجِلْدَهَا وَلَحْمَهَا وَعِظَامَهَا ثُمَّ ‏.‏ قَالَ يَا رَبِّ أَذَكَرٌ أَمْ أُنْثَى فَيَقْضِي رَبُّكَ مَا شَاءَ وَيَكْتُبُ الْمَلَكُ ثُمَّ يَقُولُ يَا رَبِّ أَجَلُهُ ‏.‏ فَيَقُولُ رَبُّكَ مَا شَاءَ وَيَكْتُبُ الْمَلَكُ ثُمَّ يَقُولُ يَا رَبِّ رِزْقُهُ ‏.‏ فَيَقْضِي رَبُّكَ مَا شَاءَ وَيَكْتُبُ الْمَلَكُ ثُمَّ يَخْرُجُ الْمَلَكُ بِالصَّحِيفَةِ فِي يَدِهِ فَلاَ يَزِيدُ عَلَى مَا أُمِرَ وَلاَ يَنْقُصُ ‏"‏ ‏.‏\hadithno{6726}\hadithtrans{Abdullah b. Mas'ud reported:Evil one is he who is evil in the womb of his mother and the good one is he who takes a lesson from the (fate of) others. The narrator came to a person from amongst the Companions of Allah's Messenger (ﷺ) who was called Hudhaifa b. Usaid Ghifari and said: How can a person be an evil one without (committing an evil) deed? Thereupon the person said to him: You are surprised at this, whereas I have heard Allah's Messenger (ﷺ) as saying: When forty-two nights pass after the semen gets into the womb, Allah sends the angel and gives him shape. Then he creates his sense of hearing, sense of sight, his skin, his flesh, his bones, and then says: My Lord, would he be male or female? And your Lord decides as He desires and the angel then puts down that also and then says: My Lord, what about his age? And your Lord decides as He likes it and the angel puts it down. Then he says: My Lord, what about his livelihood? And then the Lord decides as He likes and the angel writes it down, and then the angel gets out with his scroll of destiny in his hand and nothing is added to it and nothing is subtracted from it}}
\hadithdefcmd{muslim}{6727}{حَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ النَّوْفَلِيُّ، أَخْبَرَنَا أَبُو عَاصِمٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّ أَبَا الطُّفَيْلِ، أَخْبَرَهُ أَنَّهُ، سَمِعَ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، يَقُولُ ‏.‏ وَسَاقَ الْحَدِيثَ بِمِثْلِ حَدِيثِ عَمْرِو بْنِ الْحَارِثِ ‏.‏\hadithno{6727}\hadithtrans{This hadith has been narrated on the authority of 'Abdullah b. Mas'ud through another chain of transmitters}}
\hadithdefcmd{muslim}{6728}{حَدَّثَنِي مُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا زُهَيْرٌ أَبُو خَيْثَمَةَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَطَاءٍ، أَنَّ عِكْرِمَةَ بْنَ خَالِدٍ، حَدَّثَهُ أَنَّ أَبَا الطُّفَيْلِ حَدَّثَهُ قَالَ دَخَلْتُ عَلَى أَبِي سَرِيحَةَ حُذَيْفَةَ بْنِ أَسِيدٍ الْغِفَارِيِّ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِأُذُنَىَّ هَاتَيْنِ يَقُولُ ‏"‏ إِنَّ النُّطْفَةَ تَقَعُ فِي الرَّحِمِ أَرْبَعِينَ لَيْلَةً ثُمَّ يَتَصَوَّرُ عَلَيْهَا الْمَلَكُ ‏"‏ ‏.‏ قَالَ زُهَيْرٌ حَسِبْتُهُ قَالَ الَّذِي يَخْلُقُهَا ‏"‏ فَيَقُولُ يَا رَبِّ أَذَكَرٌ أَوْ أُنْثَى فَيَجْعَلُهُ اللَّهُ ذَكَرًا أَوْ أُنْثَى ثُمَّ يَقُولُ يَا رَبِّ أَسَوِيٌّ أَوْ غَيْرُ سَوِيٍّ فَيَجْعَلُهُ اللَّهُ سَوِيًّا أَوْ غَيْرَ سَوِيٍّ ثُمَّ يَقُولُ يَا رَبِّ مَا رِزْقُهُ مَا أَجَلُهُ مَا خُلُقُهُ ثُمَّ يَجْعَلُهُ اللَّهُ شَقِيًّا أَوْ سَعِيدًا ‏"‏ ‏.‏\hadithno{6728}\hadithtrans{Abu Tufail reported:I visited Abu Sariha Hudhaifa b. Usaid al-Ghifari who said: I listened with these two ears of mine Allahs Messenger (ﷺ) as saying: The semen stays in the womb for forty nights, then the angel, gives it a shape. Zubair said: I think that he said: One who fashions that and decides whether he would be male or female. Then he (the angel) says: Would his limbs be full or imperfect? And then the Lord makes thein full and perfect or otherwise as He desires. Then he says: My Lord, what about his livelihood, and his death and what about his disposition? And then the Lord decides about his misfortune and fortune}}
\hadithdefcmd{muslim}{6729}{حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنِي أَبِي، حَدَّثَنَا رَبِيعَةُ بْنُ كُلْثُومٍ، حَدَّثَنِي أَبِي كُلْثُومٌ، عَنْ أَبِي الطُّفَيْلِ، عَنْ حُذَيْفَةَ بْنِ أَسِيدٍ الْغِفَارِيِّ، صَاحِبِ رَسُولِ اللَّهِ صلى الله عليه وسلم رَفَعَ الْحَدِيثَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَّ مَلَكًا مُوَكَّلاً بِالرَّحِمِ إِذَا أَرَادَ اللَّهُ أَنْ يَخْلُقَ شَيْئًا بِإِذْنِ اللَّهِ لِبِضْعٍ وَأَرْبَعِينَ لَيْلَةً ‏"‏ ‏.‏ ثُمَّ ذَكَرَ نَحْوَ حَدِيثِهِمْ ‏.‏\hadithno{6729}\hadithtrans{Hadhaifa b. Usaid Ghifari, a Companion of Allah's Messenger (ﷺ), reported it directly from Allah's Messenger (may peace upon him). as he said:There is an angel who looks after the womb when Allah decides to create any- thing after more than forty nights are over; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{6730}{حَدَّثَنِي أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا عُبَيْدُ، اللَّهِ بْنُ أَبِي بَكْرٍ عَنْ أَنَسِ بْنِ مَالِكٍ، وَرَفَعَ الْحَدِيثَ، أَنَّهُ قَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ قَدْ وَكَّلَ بِالرَّحِمِ مَلَكًا فَيَقُولُ أَىْ رَبِّ نُطْفَةٌ أَىْ رَبِّ عَلَقَةٌ أَىْ رَبِّ مُضْغَةٌ ‏.‏ فَإِذَا أَرَادَ اللَّهُ أَنْ يَقْضِيَ خَلْقًا - قَالَ - قَالَ الْمَلَكُ أَىْ رَبِّ ذَكَرٌ أَوْ أُنْثَى شَقِيٌّ أَوْ سَعِيدٌ فَمَا الرِّزْقُ فَمَا الأَجَلُ فَيُكْتَبُ كَذَلِكَ فِي بَطْنِ أُمِّهِ ‏"‏ ‏.‏\hadithno{6730}\hadithtrans{Anas b. Malik reported directly from Allah's Messenger (ﷺ) that he said:Allah, the Exlated and Glorious, has appointed an angel as the caretaker of the womb, and he would say: My Lord, it is now a drop of semen; my Lord, It is now a clot of blood; my Lord, it has now become a lump of flesh, and when Allah decides to give it a final shape, the angel says: My Lord, would it be male or female or would he be an evil or a good person? What about his livelihood and his age? And it is all written as he is in the womb of his mother}}
\hadithdefcmd{muslim}{6731}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَلِيٍّ، قَالَ كُنَّا فِي جَنَازَةٍ فِي بَقِيعِ الْغَرْقَدِ فَأَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَعَدَ وَقَعَدْنَا حَوْلَهُ وَمَعَهُ مِخْصَرَةٌ فَنَكَّسَ فَجَعَلَ يَنْكُتُ بِمِخْصَرَتِهِ ثُمَّ قَالَ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ مَا مِنْ نَفْسٍ مَنْفُوسَةٍ إِلاَّ وَقَدْ كَتَبَ اللَّهُ مَكَانَهَا مِنَ الْجَنَّةِ وَالنَّارِ وَإِلاَّ وَقَدْ كُتِبَتْ شَقِيَّةً أَوْ سَعِيدَةً ‏"‏ ‏.‏ قَالَ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَفَلاَ نَمْكُثُ عَلَى كِتَابِنَا وَنَدَعُ الْعَمَلَ فَقَالَ ‏"‏ مَنْ كَانَ مِنْ أَهْلِ السَّعَادَةِ فَسَيَصِيرُ إِلَى عَمَلِ أَهْلِ السَّعَادَةِ وَمَنْ كَانَ مِنْ أَهْلِ الشَّقَاوَةِ فَسَيَصِيرُ إِلَى عَمَلِ أَهْلِ الشَّقَاوَةِ ‏"‏ ‏.‏ فَقَالَ ‏"‏ اعْمَلُوا فَكُلٌّ مُيَسَّرٌ أَمَّا أَهْلُ السَّعَادَةِ فَيُيَسَّرُونَ لِعَمَلِ أَهْلِ السَّعَادَةِ وَأَمَّا أَهْلُ الشَّقَاوَةِ فَيُيَسَّرُونَ لِعَمَلِ أَهْلِ الشَّقَاوَةِ ‏"‏ ‏.‏ ثُمَّ قَرَأَ ‏\{‏ فَأَمَّا مَنْ أَعْطَى وَاتَّقَى * وَصَدَّقَ بِالْحُسْنَى * فَسَنُيَسِّرُهُ لِلْيُسْرَى * وَأَمَّا مَنْ بَخِلَ وَاسْتَغْنَى * وَكَذَّبَ بِالْحُسْنَى * فَسَنُيَسِّرُهُ لِلْعُسْرَى‏\}‏\hadithno{6731}\hadithtrans{Ali reported:We were in a funeral in the graveyard of Gharqad when Allah's Messenger (ﷺ) came to us and we sat around him. He had a stick with him. He lowered his head and began to scratch the earth with his stick, and then said: There is not one amongst you whom a seat in Paradise or Hell has not been allotted and about whom it has not been written down whether he would be an evil person or a blessed person. A person said: Allah's Messenger, should we not then depend upon our destiny and abandon our deeds? Thereupon he said: Acts of everyone will be facilitated in that which has been created for him so that whoever belongs to the company of the blessed will have good works made easier for him and whoever belongs to the unfortunate ones will have evil acts made easier for him. He then recited this verse (from the Qur'an): "Then, who gives to the needy and guards against evil and accepts the excellent (the truth of Islam and the path of righteousness it prescribes), We shall make easy for him the easy end and who is miserly and considers himself above need, We shall make easy for him the difficult end" (xcii)}}
\hadithdefcmd{muslim}{6732}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهَنَّادُ بْنُ السَّرِيِّ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ فِي مَعْنَاهُ وَقَالَ فَأَخَذَ عُودًا ‏.‏ وَلَمْ يَقُلْ مِخْصَرَةً ‏.‏ وَقَالَ ابْنُ أَبِي شَيْبَةَ فِي حَدِيثِهِ عَنْ أَبِي الأَحْوَصِ ثُمَّ قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{6732}\hadithtrans{This hadith has been narrated on the authority of Mansur with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{6733}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالُوا حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ جَالِسًا وَفِي يَدِهِ عُودٌ يَنْكُتُ بِهِ فَرَفَعَ رَأْسَهُ فَقَالَ ‏"‏ مَا مِنْكُمْ مِنْ نَفْسٍ إِلاَّ وَقَدْ عُلِمَ مَنْزِلُهَا مِنَ الْجَنَّةِ وَالنَّارِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ فَلِمَ نَعْمَلُ أَفَلاَ نَتَّكِلُ قَالَ ‏"‏ لاَ ‏.‏ اعْمَلُوا فَكُلٌّ مُيَسَّرٌ لِمَا خُلِقَ لَهُ ‏"‏ ‏.‏ ثُمَّ قَرَأَ ‏\{‏ فَأَمَّا مَنْ أَعْطَى وَاتَّقَى * وَصَدَّقَ بِالْحُسْنَى‏\}‏ إِلَى قَوْلِهِ ‏\{‏ فَسَنُيَسِّرُهُ لِلْعُسْرَى‏\}‏\hadithno{6733}\hadithtrans{Ali reported that one day Allah's Messenger (ﷺ) was sitting with a wood in his hand and he was scratching the ground. He raised his head and said:There is not one amongst you who has not been allotted his seat in Paradise or Hell. They said: Allah's Messenger. then, why should we perform good deeds, why not depend upon our destiny? Thereupon he said. No, do perform good deeds, for everyone is facilitated in that for which he has been created; then he recited this verse:" Then, who gives to the needy and guards against evil and accepts the excellent (the truth of Islam and the path of righteousness it prescribes), We shall make easy for him the easy end..." (xcii)}}
\hadithdefcmd{muslim}{6734}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، وَالأَعْمَشِ، أَنَّهُمَا سَمِعَا سَعْدَ بْنَ عُبَيْدَةَ، يُحَدِّثُهُ عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ ‏.‏\hadithno{6734}\hadithtrans{This hadith has been narrated on the authority of 'Ali through another chain of transmitters}}
\hadithdefcmd{muslim}{6735}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ جَاءَ سُرَاقَةُ بْنُ مَالِكِ بْنِ جُعْشُمٍ قَالَ يَا رَسُولَ اللَّهِ بَيِّنْ لَنَا دِينَنَا كَأَنَّا خُلِقْنَا الآنَ فِيمَا الْعَمَلُ الْيَوْمَ أَفِيمَا جَفَّتْ بِهِ الأَقْلاَمُ وَجَرَتْ بِهِ الْمَقَادِيرُ أَمْ فِيمَا نَسْتَقْبِلُ قَالَ ‏"‏ لاَ ‏.‏ بَلْ فِيمَا جَفَّتْ بِهِ الأَقْلاَمُ وَجَرَتْ بِهِ الْمَقَادِيرُ ‏"‏ ‏.‏ قَالَ فَفِيمَ الْعَمَلُ قَالَ زُهَيْرٌ ثُمَّ تَكَلَّمَ أَبُو الزُّبَيْرِ بِشَىْءٍ لَمْ أَفْهَمْهُ فَسَأَلْتُ مَا قَالَ فَقَالَ ‏"‏ اعْمَلُوا فَكُلٌّ مُيَسَّرٌ ‏"‏ ‏.‏\hadithno{6735}\hadithtrans{Jabir reported that Suriqa b. Malik b. Ju'shuin came and said:Allah's Messenger, explain our religion to us (in a way) as if we have been created just now. Whosoever deeds we do today, is it because of the fact that-the pens have dried (after recording them) and the destitiles have began to operate or these have effects in future? Thereupon he said: The pens have dried tmd destinies have begun to operate. (Suraqa b. Malik) said: If it Is so, then what is the use of doing good deeds? Zuhair said: Then Abu Zubair said something but I could not understand that and I said. What did he say? Thereupon he said: Act, for everyone is facilitated what he intends to do}}
\hadithdefcmd{muslim}{6736}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْمَعْنَى وَفِيهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ عَامِلٍ مُيَسَّرٌ لِعَمَلِهِ ‏"‏ ‏.‏\hadithno{6736}\hadithtrans{This hadith has been transmitted on the authority of Jabir b. Abdullah with the same wording (and includes these words):" Allah's Messenger (ﷺ) said: Every doer of deed is facilitated in his action}}
\hadithdefcmd{muslim}{6737}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَزِيدَ الضُّبَعِيِّ، حَدَّثَنَا مُطَرِّفٌ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ أَعُلِمَ أَهْلُ الْجَنَّةِ مِنْ أَهْلِ النَّارِ قَالَ فَقَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ قِيلَ فَفِيمَ يَعْمَلُ الْعَامِلُونَ قَالَ ‏"‏ كُلٌّ مُيَسَّرٌ لِمَا خُلِقَ لَهُ ‏"‏ ‏.‏\hadithno{6737}\hadithtrans{Imran b. Husain repotted that it was said to Allah's Messenger (ﷺ):Has there been drawn a distinction between the people of Paradise and the denizens of hell? He said: Yes. It was again said: (If it is so), then What is the use of doing good deeds? Thereupon he said: Everyone is facilitated in what has been created for him}}
\hadithdefcmd{muslim}{6738}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ وَابْنُ نُمَيْرٍ عَنِ ابْنِ عُلَيَّةَ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، كُلُّهُمْ عَنْ يَزِيدَ الرِّشْكِ، فِي هَذَا الإِسْنَادِ ‏.‏ بِمَعْنَى حَدِيثِ حَمَّادٍ وَفِي حَدِيثِ عَبْدِ الْوَارِثِ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ ‏.‏\hadithno{6738}\hadithtrans{This hadith has been narrated through other chains of transmiters with slight variations of wording}}
\hadithdefcmd{muslim}{6739}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا عَزْرَةُ بْنُ، ثَابِتٍ عَنْ يَحْيَى بْنِ عُقَيْلٍ، عَنْ يَحْيَى بْنِ يَعْمُرَ، عَنْ أَبِي الأَسْوَدِ الدِّئَلِيِّ، قَالَ قَالَ لِي عِمْرَانُ بْنُ الْحُصَيْنِ أَرَأَيْتَ مَا يَعْمَلُ النَّاسُ الْيَوْمَ وَيَكْدَحُونَ فِيهِ أَشَىْءٌ قُضِيَ عَلَيْهِمْ وَمَضَى عَلَيْهِمْ مِنْ قَدَرِ مَا سَبَقَ أَوْ فِيمَا يُسْتَقْبَلُونَ بِهِ مِمَّا أَتَاهُمْ بِهِ نَبِيُّهُمْ وَثَبَتَتِ الْحُجَّةُ عَلَيْهِمْ فَقُلْتُ بَلْ شَىْءٌ قُضِيَ عَلَيْهِمْ وَمَضَى عَلَيْهِمْ قَالَ فَقَالَ أَفَلاَ يَكُونُ ظُلْمًا قَالَ فَفَزِعْتُ مِنْ ذَلِكَ فَزَعًا شَدِيدًا وَقُلْتُ كُلُّ شَىْءٍ خَلْقُ اللَّهِ وَمِلْكُ يَدِهِ فَلاَ يُسْأَلُ عَمَّا يَفْعَلُ وَهُمْ يُسْأَلُونَ ‏.‏ فَقَالَ لِي يَرْحَمُكَ اللَّهُ إِنِّي لَمْ أُرِدْ بِمَا سَأَلْتُكَ إِلاَّ لأَحْزُرَ عَقْلَكَ إِنَّ رَجُلَيْنِ مِنْ مُزَيْنَةَ أَتَيَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالاَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ مَا يَعْمَلُ النَّاسُ الْيَوْمَ وَيَكْدَحُونَ فِيهِ أَشَىْءٌ قُضِيَ عَلَيْهِمْ وَمَضَى فِيهِمْ مِنْ قَدَرٍ قَدْ سَبَقَ أَوْ فِيمَا يُسْتَقْبَلُونَ بِهِ مِمَّا أَتَاهُمْ بِهِ نَبِيُّهُمْ وَثَبَتَتِ الْحُجَّةُ عَلَيْهِمْ فَقَالَ ‏"‏ لاَ بَلْ شَىْءٌ قُضِيَ عَلَيْهِمْ وَمَضَى فِيهِمْ وَتَصْدِيقُ ذَلِكَ فِي كِتَابِ اللَّهِ عَزَّ وَجَلَّ ‏\{‏ وَنَفْسٍ وَمَا سَوَّاهَا * فَأَلْهَمَهَا فُجُورَهَا وَتَقْوَاهَا‏\}‏ ‏"‏ ‏.‏\hadithno{6739}\hadithtrans{Abu al-Aswad reported that 'Imran b Husain asked him:What is your view, what the people do today in the world, and strive for, is it something decreed for them or preordained for them or will their fate in the Hereafter be deterrained by the fact that their Prophets brought them teaching which they did not act upon? I said: Of course, it is something which is predetermined for them and preordained for them. He (further) said: Then, would it not be an injustice (to punish them)? I felt greatly disturbed because of that, and said: Everything is created by Allah and lies in His Power. He would not be questioned as to what He does, but they would be questioned; thereupon he said to me: May Allah have mercy upon you, I did not mean to ask you but for testing your intelligence. Two men of the tribe of Muzaina came to Allah's Messenger (ﷺ) and said: Allah's Messenger, what is your opinion that the people do in the world and strive for, is something decreed for them; something preordained for them and will their fate in the Hereafter be determined by the fact that their Prophets brought them teachings which they did not act upon. and thus they became deserving of punishment? Thereupon, he said: Of course, it happens as it is decreed by Destiny and preordained for them, and this view is confirmed by this verse of the Book of Allah, the Exalted and Glorious:" Consider the soul and Him Who made it perfect, then breathed into it its sin and its piety" (xci)}}
\hadithdefcmd{muslim}{6740}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الرَّجُلَ لَيَعْمَلُ الزَّمَنَ الطَّوِيلَ بِعَمَلِ أَهْلِ الْجَنَّةِ ثُمَّ يُخْتَمُ لَهُ عَمَلُهُ بِعَمَلِ أَهْلِ النَّارِ وَإِنَّ الرَّجُلَ لَيَعْمَلُ الزَّمَنَ الطَّوِيلَ بِعَمَلِ أَهْلِ النَّارِ ثُمَّ يُخْتَمُ لَهُ عَمَلُهُ بِعَمَلِ أَهْلِ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{6740}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Verily, a man would perform the deeds of the people of Paradise for a long time, then his deeds would be concluded with the deeds of the people of Hell. And verily, a man would perform the deeds of the people of Hell for a long time, and then his deeds would be concluded with the deeds of the people of Paradise}}
\hadithdefcmd{muslim}{6741}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الرَّجُلَ لَيَعْمَلُ عَمَلَ أَهْلِ الْجَنَّةِ فِيمَا يَبْدُو لِلنَّاسِ وَهُوَ مِنْ أَهْلِ النَّارِ ‏.‏ وَإِنَّ الرَّجُلَ لَيَعْمَلُ عَمَلَ أَهْلِ النَّارِ فِيمَا يَبْدُو لِلنَّاسِ وَهُوَ مِنْ أَهْلِ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{6741}\hadithtrans{Sahl b. Sa'd reported it from Allah's Messenger (ﷺ) that a person performs deeds like the deeds of the people of Paradise apparently before people and he would be amongst the dwellers of Hell and a person acts apparently like the people of Hell, but (in fact) he would be among the dwellers of Paradise}}
\hadithdefcmd{muslim}{6742}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَإِبْرَاهِيمُ بْنُ دِينَارِ، وَابْنُ أَبِي عُمَرَ الْمَكِّيُّ، وَأَحْمَدُ بْنُ عَبْدَةَ، الضَّبِّيُّ جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - وَاللَّفْظُ لاِبْنِ حَاتِمٍ وَابْنِ دِينَارٍ - قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ، عُيَيْنَةَ عَنْ عَمْرٍو، عَنْ طَاوُسٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ احْتَجَّ آدَمُ وَمُوسَى فَقَالَ مُوسَى يَا آدَمُ أَنْتَ أَبُونَا خَيَّبْتَنَا وَأَخْرَجْتَنَا مِنَ الْجَنَّةِ فَقَالَ لَهُ آدَمُ أَنْتَ مُوسَى اصْطَفَاكَ اللَّهُ بِكَلاَمِهِ وَخَطَّ لَكَ بِيَدِهِ أَتَلُومُنِي عَلَى أَمْرٍ قَدَّرَهُ اللَّهُ عَلَىَّ قَبْلَ أَنْ يَخْلُقَنِي بِأَرْبَعِينَ سَنَةً ‏"‏ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَحَجَّ آدَمُ مُوسَى فَحَجَّ آدَمُ مُوسَى ‏"‏ ‏.‏ وَفِي حَدِيثِ ابْنِ أَبِي عُمَرَ وَابْنِ عَبْدَةَ قَالَ أَحَدُهُمَا خَطَّ ‏.‏ وَقَالَ الآخَرُ كَتَبَ لَكَ التَّوْرَاةَ بِيَدِهِ ‏.‏\hadithno{6742}\hadithtrans{Abu Huraira reported Allah's Messenger (way peace be upon him) as saying:There was argument between Adam and Moses. Moses said to Adam: You are our father. You did us harm and caused us to get out of Paradise. Adam said to him: You are Moses. Allah selected you (for direct conversation with you) and wrote with His own Hand the Book (Torah) for you. Despite this you blame me for an act which Allah had ordained for me forty years before He created me. Allah's Apostle (ﷺ) said:. This is how Adam came the better of Moses and Adam came the better of Moses}}
\hadithdefcmd{muslim}{6743}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَحَاجَّ آدَمُ وَمُوسَى فَحَجَّ آدَمُ مُوسَى فَقَالَ لَهُ مُوسَى أَنْتَ آدَمُ الَّذِي أَغْوَيْتَ النَّاسَ وَأَخْرَجْتَهُمْ مِنَ الْجَنَّةِ فَقَالَ آدَمُ أَنْتَ الَّذِي أَعْطَاهُ اللَّهُ عِلْمَ كُلِّ شَىْءٍ وَاصْطَفَاهُ عَلَى النَّاسِ بِرِسَالَتِهِ قَالَ نَعَمْ ‏.‏ قَالَ فَتَلُومُنِي عَلَى أَمْرٍ قُدِّرَ عَلَىَّ قَبْلَ أَنْ أُخْلَقَ ‏"‏ ‏.‏\hadithno{6743}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There was argument between Adam and Moses, and Adam came the better of Moses. Moses said to him: You are the same Adam who misled people, and caused them to get out of Paradise. Adam said: You are the same (Moses) whom Allah endowed the knowledge of everything and selected him amongst the people as His Messenger. He said: Yes. Adam then again said: Even then you blame me for an affair which had been ordained for me before I was created}}
\hadithdefcmd{muslim}{6744}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى بْنِ عَبْدِ اللَّهِ بْنِ مُوسَى بْنِ عَبْدِ اللَّهِ بْنِ يَزِيدَ الأَنْصَارِيُّ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، حَدَّثَنِي الْحَارِثُ بْنُ أَبِي ذُبَابٍ، عَنْ يَزِيدَ، - وَهُوَ ابْنُ هُرْمُزَ - وَعَبْدِ الرَّحْمَنِ الأَعْرَجِ قَالاَ سَمِعْنَا أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ احْتَجَّ آدَمُ وَمُوسَى عَلَيْهِمَا السَّلاَمُ عِنْدَ رَبِّهِمَا فَحَجَّ آدَمُ مُوسَى قَالَ مُوسَى أَنْتَ آدَمُ الَّذِي خَلَقَكَ اللَّهُ بِيَدِهِ وَنَفَخَ فِيكَ مِنْ رُوحِهِ وَأَسْجَدَ لَكَ مَلاَئِكَتَهُ وَأَسْكَنَكَ فِي جَنَّتِهِ ثُمَّ أَهْبَطْتَ النَّاسَ بِخَطِيئَتِكَ إِلَى الأَرْضِ فَقَالَ آدَمُ أَنْتَ مُوسَى الَّذِي اصْطَفَاكَ اللَّهُ بِرِسَالَتِهِ وَبِكَلاَمِهِ وَأَعْطَاكَ الأَلْوَاحَ فِيهَا تِبْيَانُ كُلِّ شَىْءٍ وَقَرَّبَكَ نَجِيًّا فَبِكَمْ وَجَدْتَ اللَّهَ كَتَبَ التَّوْرَاةَ قَبْلَ أَنْ أُخْلَقَ قَالَ مُوسَى بِأَرْبَعِينَ عَامًا ‏.‏ قَالَ آدَمُ فَهَلْ وَجَدْتَ فِيهَا ‏\{‏ وَعَصَى آدَمُ رَبَّهُ فَغَوَى‏\}‏ قَالَ نَعَمْ ‏.‏ قَالَ أَفَتَلُومُنِي عَلَى أَنْ عَمِلْتُ عَمَلاً كَتَبَهُ اللَّهُ عَلَىَّ أَنْ أَعْمَلَهُ قَبْلَ أَنْ يَخْلُقَنِي بِأَرْبَعِينَ سَنَةً قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَحَجَّ آدَمُ مُوسَى ‏"‏ ‏.‏\hadithno{6744}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There was an argument between Adam and Moses (peace be upon both of them) in the presence of their Lord. Adam came the better of Moses. Moses said: Are you that Adam whom Allah created with His Hand and breathed into himHis sprit, and commanded angels to fall in prostration before him and He made you live in Paradise with comfort and ease. Then you caused the people to get down to the earth because of your lapse. Adam said: Are you that Moses whom Allah selected for His Messengership and for His conversation with him and conferred upon you the tablets, in which everything was clearly explained and granted you the audience in order to have confidential talk with you. What is your opinion, how long Torah would haye been written before I was created? Moses said: Forty years before. Adam said: Did you not see these words: Adam committed an error and he was enticed to (do so). He (Moses) said: Yes. Whereupon, he (Adam) said: Do you then blame me for an act which Allah had ordained for me forty years before He created me? Allah's Messenger (ﷺ) said: This is how Adam came the better of Moses}}
\hadithdefcmd{muslim}{6745}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، حَاتِمٍ قَالاَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ احْتَجَّ آدَمُ وَمُوسَى فَقَالَ لَهُ مُوسَى أَنْتَ آدَمُ الَّذِي أَخْرَجَتْكَ خَطِيئَتُكَ مِنَ الْجَنَّةِ فَقَالَ لَهُ آدَمُ أَنْتَ مُوسَى الَّذِي اصْطَفَاكَ اللَّهُ بِرِسَالَتِهِ وَبِكَلاَمِهِ ثُمَّ تَلُومُنِي عَلَى أَمْرٍ قَدْ قُدِّرَ عَلَىَّ قَبْلَ أَنْ أُخْلَقَ فَحَجَّ آدَمُ مُوسَى ‏"‏ ‏.‏\hadithno{6745}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There was an argument between Adam and Moses. Moses said: Are you that Adam whose lapse caused you to get out of Paradise? Adam said to him: Are you that Moses whom Allah selected for His Messengership, for His conversation and you blame me for an affair which had been ordained for me before I was created? This is how Adam came the better of Moses}}
\hadithdefcmd{muslim}{6746}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا أَيُّوبُ بْنُ النَّجَّارِ الْيَمَامِيُّ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح\hadithno{6746}\hadithtrans{Abu Huraira narrated a hadith like this through another chain of transmitters}}
\hadithdefcmd{muslim}{6747}{وَحَدَّثَنَا ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي، هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِهِمْ ‏.‏\hadithno{6747}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{6748}{وَحَدَّثَنَا مُحَمَّدُ بْنُ مِنْهَالٍ الضَّرِيرُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم نَحْوَ حَدِيثِهِمْ ‏.‏\hadithno{6748}\hadithtrans{Abu Huraira reported a hadith like this through another chain of transmitters}}
\hadithdefcmd{muslim}{6749}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ سَرْحٍ حَدَّثَنَا ابْنُ، وَهْبٍ أَخْبَرَنِي أَبُو هَانِئٍ الْخَوْلاَنِيُّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو، بْنِ الْعَاصِ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ كَتَبَ اللَّهُ مَقَادِيرَ الْخَلاَئِقِ قَبْلَ أَنْ يَخْلُقَ السَّمَوَاتِ وَالأَرْضَ بِخَمْسِينَ أَلْفَ سَنَةٍ - قَالَ - وَعَرْشُهُ عَلَى الْمَاءِ ‏"‏ ‏.‏\hadithno{6749}\hadithtrans{Abdullah b. 'Amr b. al-'As reported:I heard Allah's Messenger (ﷺ) as saying: Allah ordained the measures (of quality) of the creation fifty thousand years before He created the heavens and the earth, as His Throne was upon water}}
\hadithdefcmd{muslim}{6750}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا الْمُقْرِئُ، حَدَّثَنَا حَيْوَةُ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ سَهْلٍ التَّمِيمِيُّ، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا نَافِعٌ، - يَعْنِي ابْنَ يَزِيدَ - كِلاَهُمَا عَنْ أَبِي هَانِئٍ، ‏.‏ بِهَذَا الإِسْنَادِ مِثْلَهُ غَيْرَ أَنَّهُمَا لَمْ يَذْكُرَا وَعَرْشُهُ عَلَى الْمَاءِ ‏.‏\hadithno{6750}\hadithtrans{This hadith has been narrated on the authority of Abu Hani with the same chain of transmitters, but there is no mention of" His Throne was upon water}}
\hadithdefcmd{muslim}{6751}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، نُمَيْرٍ كِلاَهُمَا عَنِ الْمُقْرِئِ، قَالَ زُهَيْرٌ حَدَّثَنَا عَبْدُ، اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ قَالَ حَدَّثَنَا حَيْوَةُ، أَخْبَرَنِي أَبُو هَانِئٍ، أَنَّهُ سَمِعَ أَبَا عَبْدِ الرَّحْمَنِ الْحُبُلِيَّ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ، يَقُولُ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ قُلُوبَ بَنِي آدَمَ كُلَّهَا بَيْنَ إِصْبَعَيْنِ مِنْ أَصَابِعِ الرَّحْمَنِ كَقَلْبٍ وَاحِدٍ يُصَرِّفُهُ حَيْثُ يَشَاءُ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ مُصَرِّفَ الْقُلُوبِ صَرِّفْ قُلُوبَنَا عَلَى طَاعَتِكَ ‏"‏ ‏.‏\hadithno{6751}\hadithtrans{Abdullah b. Amr b. al-'As reported that he heard Allah's Messenger (ﷺ) as saying:Verily, the hearts of all the sons of Adam are between the two fingers out of the fingers of the Compassionate Lord as one heart. He turns that to any (direction) He likes. Then Allahs Messenger (ﷺ) said: 0 Allah, the Turner of the hearts, turn our hearts to Thine obedience}}
\hadithdefcmd{muslim}{6752}{حَدَّثَنِي عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، قَالَ قَرَأْتُ عَلَى مَالِكِ بْنِ أَنَسٍ ح وَحَدَّثَنَا قُتَيْبَةُ، بْنُ سَعِيدٍ عَنْ مَالِكٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ زِيَادِ بْنِ سَعْدٍ، عَنْ عَمْرِو بْنِ مُسْلِمٍ، عَنْ طَاوُسٍ، أَنَّهُ قَالَ أَدْرَكْتُ نَاسًا مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُونَ كُلُّ شَىْءٍ بِقَدَرٍ ‏.‏ قَالَ وَسَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ شَىْءٍ بِقَدَرٍ حَتَّى الْعَجْزُ وَالْكَيْسُ أَوِ الْكَيْسُ وَالْعَجْزُ ‏"‏ ‏.‏\hadithno{6752}\hadithtrans{Tawus reported:I found some Companions of Allah's Messenger (ﷺ) as saying: Everything is by measure. And he further said: I heard Abdullah b. 'Umar as saying: There is a neasure for everything-even for incapacity and-capability}}
\hadithdefcmd{muslim}{6753}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ زِيَادِ، بْنِ إِسْمَاعِيلَ عَنْ مُحَمَّدِ بْنِ عَبَّادِ بْنِ جَعْفَرٍ الْمَخْزُومِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ مُشْرِكُو قُرَيْشٍ يُخَاصِمُونَ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي الْقَدَرِ فَنَزَلَتْ ‏\{‏ يَوْمَ يُسْحَبُونَ فِي النَّارِ عَلَى وُجُوهِهِمْ ذُوقُوا مَسَّ سَقَرَ* إِنَّا كُلَّ شَىْءٍ خَلَقْنَاهُ بِقَدَرٍ‏\}‏\hadithno{6753}\hadithtrans{Abu Huraira reported that the polytheists of the Quraish came to have an argument with Allah's Messenger (ﷺ) in regard to Destiny and then this verse was revealed:" On the day when they are dragged into the Fire upon their faces, taste the touch of Fire. Surely, We have created everything according to a measure" (liv)}}
\hadithdefcmd{muslim}{6754}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَاللَّفْظُ لإِسْحَاقَ - قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَا رَأَيْتُ شَيْئًا أَشْبَهَ بِاللَّمَمِ مِمَّا قَالَ أَبُو هُرَيْرَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ كَتَبَ عَلَى ابْنِ آدَمَ حَظَّهُ مِنَ الزِّنَى أَدْرَكَ ذَلِكَ لاَ مَحَالَةَ فَزِنَى الْعَيْنَيْنِ النَّظَرُ وَزِنَى اللِّسَانِ النُّطْقُ وَالنَّفْسُ تَمَنَّى وَتَشْتَهِي وَالْفَرْجُ يُصَدِّقُ ذَلِكَ أَوْ يُكَذِّبُهُ ‏"‏ ‏.‏ قَالَ عَبْدٌ فِي رِوَايَتِهِ ابْنِ طَاوُسٍ عَنْ أَبِيهِ سَمِعْتُ ابْنَ عَبَّاسٍ ‏.‏\hadithno{6754}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:Verily Allah has fixed the very portion of adultery which a man will indulge in, and which he of necessity must commit. The adultery of the eye is the lustful look, and the adultery of the tongue is the licentious speech, the heart desires and yearns, which the parts may or may not put into effect}}
\hadithdefcmd{muslim}{6755}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو هِشَامٍ الْمَخْزُومِيُّ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُتِبَ عَلَى ابْنِ آدَمَ نَصِيبُهُ مِنَ الزِّنَى مُدْرِكٌ ذَلِكَ لاَ مَحَالَةَ فَالْعَيْنَانِ زِنَاهُمَا النَّظَرُ وَالأُذُنَانِ زِنَاهُمَا الاِسْتِمَاعُ وَاللِّسَانُ زِنَاهُ الْكَلاَمُ وَالْيَدُ زِنَاهَا الْبَطْشُ وَالرِّجْلُ زِنَاهَا الْخُطَا وَالْقَلْبُ يَهْوَى وَيَتَمَنَّى وَيُصَدِّقُ ذَلِكَ الْفَرْجُ وَيُكَذِّبُهُ ‏"‏ ‏.‏\hadithno{6755}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying. Allah fixed the very portion of adultery which a man will indulge in. There would be no escape from it. The adultery of the eye is the lustful look and the adultery of the ears is listening to voluptuous (song or talk) and the adultery of the tongue is licentious speech and the adultery of the hand is the lustful grip (embrace) and the adultery of the feet is to walk (to the place) where he intends to commit adultery and the heart yearns and desires which he may or may not put into effect}}
\hadithdefcmd{muslim}{6756}{حَدَّثَنَا حَاجِبُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ كَانَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ مَوْلُودٍ إِلاَّ يُولَدُ عَلَى الْفِطْرَةِ فَأَبَوَاهُ يُهَوِّدَانِهِ وَيُنَصِّرَانِهِ وَيُمَجِّسَانِهِ كَمَا تُنْتَجُ الْبَهِيمَةُ بَهِيمَةً جَمْعَاءَ هَلْ تُحِسُّونَ فِيهَا مِنْ جَدْعَاءَ ‏"‏ ‏.‏ ثُمَّ يَقُولُ أَبُو هُرَيْرَةَ وَاقْرَءُوا إِنْ شِئْتُمْ ‏\{‏ فِطْرَةَ اللَّهِ الَّتِي فَطَرَ النَّاسَ عَلَيْهَا لاَ تَبْدِيلَ لِخَلْقِ اللَّهِ‏\}‏ الآيَةَ ‏.‏\hadithno{6756}\hadithtrans{There is none born but is created to his true nature (Islam). It is his parents who make him a Jew or a Christian or a Magian quite as beasts produce their young with their limbs perfect. Do you see anything deficient in them? Then he quoted the Qur'an., The nature made by Allah in which He has created men there is no altering of Allah's creation; that is the right religion" (ar-Rum:)}}
\hadithdefcmd{muslim}{6757}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، كِلاَهُمَا عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ كَمَا تُنْتَجُ الْبَهِيمَةُ بَهِيمَةً ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ جَمْعَاءَ ‏.‏\hadithno{6757}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters and there is no mention of his deficiency in limbs}}
\hadithdefcmd{muslim}{6758}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَأَحْمَدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ، يَزِيِدَ عَنِ ابْنِ شِهَابٍ، أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، أَخْبَرَهُ أَنَّ أَبَا هُرَيْرَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ مَوْلُودٍ إِلاَّ يُولَدُ عَلَى الْفِطْرَةِ ‏"‏ ‏.‏ ثُمَّ يَقُولُ اقْرَءُوا ‏\{‏ فِطْرَةَ اللَّهِ الَّتِي فَطَرَ النَّاسَ عَلَيْهَا لاَ تَبْدِيلَ لِخَلْقِ اللَّهِ ذَلِكَ الدِّينُ الْقَيِّمُ‏\}‏\hadithno{6758}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:No child is born but upon Fitra. He then said. Recite: The nature made by Allah in which He created man, there is no altering of Allah's nature; that is the right religion}}
\hadithdefcmd{muslim}{6759}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ مَوْلُودٍ إِلاَّ يُلِدَ عَلَى الْفِطْرَةِ فَأَبَوَاهُ يُهَوِّدَانِهِ وَيُنَصِّرَانِهِ وَيُشَرِّكَانِهِ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَرَأَيْتَ لَوْ مَاتَ قَبْلَ ذَلِكَ قَالَ ‏"‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏ ‏.‏\hadithno{6759}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:No babe is born but upon Fitra. It is his parents who make him a Jew or a Christian or a Polytheist. A person said: Allah's Messenger, what is your opinion if they were to die before that (before reaching the age of adolescence when they can distinguish between right and wrong)? He said: It is Allah alone Who knows what they would be doing}}
\hadithdefcmd{muslim}{6760}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا ابْنُ، نُمَيْرٍ حَدَّثَنَا أَبِي كِلاَهُمَا، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ فِي حَدِيثِ ابْنِ نُمَيْرٍ ‏"‏ مَا مِنْ مَوْلُودٍ يُولَدُ إِلاَّ وَهُوَ عَلَى الْمِلَّةِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ أَبِي بَكْرٍ عَنْ أَبِي مُعَاوِيَةَ ‏"‏ إِلاَّ عَلَى هَذِهِ الْمِلَّةِ حَتَّى يُبَيِّنَ عَنْهُ لِسَانُهُ ‏"‏ ‏.‏ وَفِي رِوَايَةِ أَبِي كُرَيْبٍ عَنْ أَبِي مُعَاوِيَةَ ‏"‏ لَيْسَ مِنْ مَوْلُودٍ يُولَدُ إِلاَّ عَلَى هَذِهِ الْفِطْرَةِ حَتَّى يُعَبِّرَ عَنْهُ لِسَانُهُ ‏"‏ ‏.‏\hadithno{6760}\hadithtrans{It is reported on the authority of Abu Mu'awiya that (the Holy Prophet) said:Every new-born babe is born on the millat (of Islam and he) remains on this until his tongue is enabled to express himself. This hadith has been narratted on the authority of Abu Mu'awiya through another chain of transmitters (and the words are):" Every child is born but on this Fitra so long as he does not express himself with his tongue}}
\hadithdefcmd{muslim}{6761}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ يُولَدُ يُولَدُ عَلَى هَذِهِ الْفِطْرَةِ فَأَبَوَاهُ يُهَوِّدَانِهِ وَيُنَصِّرَانِهِ كَمَا تَنْتِجُونَ الإِبِلَ فَهَلْ تَجِدُونَ فِيهَا جَدْعَاءَ حَتَّى تَكُونُوا أَنْتُمْ تَجْدَعُونَهَا ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَفَرَأَيْتَ مَنْ يَمُوتُ صَغِيرًا قَالَ ‏"‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏ ‏.‏\hadithno{6761}\hadithtrans{Abu Huraira reported from Allah's Messenger (may peace be upom him) many ahadith and one amongst them is that he is reported to have said:An infant is born according to his (true) nature. It is his parents Who make him a Jew, a Christian, just as a she-camel gives birth to its young ones. Do you find any deficiency in their limbs? You cut their ears (i. e. after birth). They (the Companions of the Holy Prophet) said: What is your opinion about him who dies in infancy? Thereupon Allah's Apostle (ﷺ) said: It is Allah alone Who knows best what they would be doing}}
\hadithdefcmd{muslim}{6762}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ إِنْسَانٍ تَلِدُهُ أُمُّهُ عَلَى الْفِطْرَةِ وَأَبَوَاهُ بَعْدُ يُهَوِّدَانِهِ وَيُنَصِّرَانِهِ وَيُمَجِّسَانِهِ فَإِنْ كَانَا مُسْلِمَيْنِ فَمُسْلِمٌ كُلُّ إِنْسَانٍ تَلِدُهُ أُمُّهُ يَلْكُزُهُ الشَّيْطَانُ فِي حِضْنَيْهِ إِلاَّ مَرْيَمَ وَابْنَهَا ‏"‏ ‏.‏\hadithno{6762}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The mother of every person gives him birth according to his true nature. It is subsequently his parents who make him a Jew or a Christian or a Magian. Had his parents been Muslim he would have also remained a Muslim. Every person to whom his mother gives birth (has two aspects of his life) ; when his mother gives birth Satan strikes him but it was not the case with Mary and her son (Jesus Christ)}}
\hadithdefcmd{muslim}{6763}{حَدَّثَنَا أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ أَبِي ذِئْبٍ، وَيُونُسُ، عَنِ ابْنِ، شِهَابٍ عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنْ أَوْلاَدِ الْمُشْرِكِينَ فَقَالَ ‏ "‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏ ‏.‏\hadithno{6763}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) was asked about the children of the polytheists, whereupon he said:It is Allah Who knows best what they would be doing}}
\hadithdefcmd{muslim}{6764}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ، عَبْدِ الرَّحْمَنِ بْنِ بَهْرَامَ أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، ح وَحَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، - وَهُوَ ابْنُ عُبَيْدِ اللَّهِ - كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِإِسْنَادِ يُونُسَ وَابْنِ أَبِي ذِئْبٍ ‏.‏ مِثْلَ حَدِيثِهِمَا غَيْرَ أَنَّ فِي، حَدِيثِ شُعَيْبٍ وَمَعْقِلٍ سُئِلَ عَنْ ذَرَارِيِّ الْمُشْرِكِينَ ‏.‏\hadithno{6764}\hadithtrans{This hadith has been transmitted on the authority of Shu'aib and Ma'qil with a slight variation of wording}}
\hadithdefcmd{muslim}{6765}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَطْفَالِ الْمُشْرِكِينَ مَنْ يَمُوتُ مِنْهُمْ صَغِيرًا فَقَالَ ‏ "‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏ ‏.‏\hadithno{6765}\hadithtrans{Abu Huraira reported that Allahs Messenger (way peace be upon him) was asked about the children of the polytheists who die young. Thereupon Allah's Apostle (ﷺ) said:It is Allah Who knows what they would be doing}}
\hadithdefcmd{muslim}{6766}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَطْفَالِ الْمُشْرِكِينَ قَالَ ‏ "‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ إِذْ خَلَقَهُمْ ‏"‏ ‏.‏\hadithno{6766}\hadithtrans{Ibn Abbas reported that Allah's Messenger (ﷺ) was asked about the children of the polytheists, whereupon he said:It is Allah alone Who knows what they would be doing according to their creation}}
\hadithdefcmd{muslim}{6767}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، عَنْ رَقَبَةَ، بْنِ مَسْقَلَةَ عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْغُلاَمَ الَّذِي قَتَلَهُ الْخَضِرُ طُبِعَ كَافِرًا وَلَوْ عَاشَ لأَرْهَقَ أَبَوَيْهِ طُغْيَانًا وَكُفْرًا ‏"‏ ‏.‏\hadithno{6767}\hadithtrans{Ubayy b. Ka'b reported that Allah's Messenger (ﷺ) said:The young man whom Khadir killed was a non-believer by his very nature and had he survived he would have involved his parents in defiance and unbelief}}
\hadithdefcmd{muslim}{6768}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الْعَلاَءِ بْنِ الْمُسَيَّبِ، عَنْ فُضَيْلِ بْنِ عَمْرٍو، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ تُوُفِّيَ صَبِيٌّ فَقُلْتُ طُوبَى لَهُ عُصْفُورٌ مِنْ عَصَافِيرِ الْجَنَّةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوَلاَ تَدْرِينَ أَنَّ اللَّهَ خَلَقَ الْجَنَّةَ وَخَلَقَ النَّارَ فَخَلَقَ لِهَذِهِ أَهْلاً وَلِهَذِهِ أَهْلاً ‏"‏ ‏.‏\hadithno{6768}\hadithtrans{A'isha, the mother of the believers, reported that a child died and I said:There is happiness for this child who is a bird from amongst the birds of Paradise. Thereupon Allah's Messenger (ﷺ) said: Don't you know that Allah created the Paradise and He created the Hell and He created the dwellers for this (Paradise) and the denizens for this (Hell)?}}
\hadithdefcmd{muslim}{6769}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ عَمَّتِهِ، عَائِشَةَ بِنْتِ طَلْحَةَ عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ دُعِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى جَنَازَةِ صَبِيٍّ مِنَ الأَنْصَارِ فَقُلْتُ يَا رَسُولَ اللَّهِ طُوبَى لِهَذَا عُصْفُورٌ مِنْ عَصَافِيرِ الْجَنَّةِ لَمْ يَعْمَلِ السُّوءَ وَلَمْ يُدْرِكْهُ قَالَ ‏ "‏ أَوَغَيْرَ ذَلِكَ يَا عَائِشَةُ إِنَّ اللَّهَ خَلَقَ لِلْجَنَّةِ أَهْلاً خَلَقَهُمْ لَهَا وَهُمْ فِي أَصْلاَبِ آبَائِهِمْ وَخَلَقَ لِلنَّارِ أَهْلاً خَلَقَهُمْ لَهَا وَهُمْ فِي أَصْلاَبِ آبَائِهِمْ ‏"‏ ‏.‏\hadithno{6769}\hadithtrans{A'isha, the mother of the believers, said that Allah's Messenger (ﷺ) was called to lead the funeral prayer of a child of the Ansar. I said:Allah's Messenger, there is happiness for this child who is a bird from the birds of Paradise for it committed no sin nor has he reached the age when one can commit sin. He said: 'A'isha, per adventure, it may be otherwise, because God created for Paradise those who are fit for it while they were yet in their father's loins and created for Hell those who are to go to Hell. He created them for Hell while they were yet in their father's loins}}
\hadithdefcmd{muslim}{6770}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ، عَنْ طَلْحَةَ بْنِ يَحْيَى، ح وَحَدَّثَنِي سُلَيْمَانُ بْنُ مَعْبَدٍ، حَدَّثَنَا الْحُسَيْنُ بْنُ حَفْصٍ، ح وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ يُوسُفَ، كِلاَهُمَا عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ طَلْحَةَ بْنِ يَحْيَى، بِإِسْنَادِ وَكِيعٍ نَحْوَ حَدِيثِهِ ‏.‏\hadithno{6770}\hadithtrans{This hadith has been narrated on the authority of Yahya with the same chain of transmitters}}
\hadithdefcmd{muslim}{6771}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنِ الْمُغِيرَةِ بْنِ عَبْدِ اللَّهِ الْيَشْكُرِيِّ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَتْ أُمُّ حَبِيبَةَ زَوْجُ النَّبِيِّ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ أَمْتِعْنِي بِزَوْجِي رَسُولِ اللَّهِ صلى الله عليه وسلم وَبِأَبِي أَبِي سُفْيَانَ وَبِأَخِي مُعَاوِيَةَ ‏.‏ قَالَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قَدْ سَأَلْتِ اللَّهَ لآجَالٍ مَضْرُوبَةٍ وَأَيَّامٍ مَعْدُودَةٍ وَأَرْزَاقٍ مَقْسُومَةٍ لَنْ يُعَجِّلَ شَيْئًا قَبْلَ حِلِّهِ أَوْ يُؤَخِّرَ شَيْئًا عَنْ حِلِّهِ وَلَوْ كُنْتِ سَأَلْتِ اللَّهَ أَنْ يُعِيذَكِ مِنْ عَذَابٍ فِي النَّارِ أَوْ عَذَابٍ فِي الْقَبْرِ كَانَ خَيْرًا وَأَفْضَلَ ‏"‏ ‏.‏ قَالَ وَذُكِرَتْ عِنْدَهُ الْقِرَدَةُ قَالَ مِسْعَرٌ وَأُرَاهُ قَالَ وَالْخَنَازِيرُ مِنْ مَسْخٍ فَقَالَ ‏"‏ إِنَّ اللَّهَ لَمْ يَجْعَلْ لِمَسْخٍ نَسْلاً وَلاَ عَقِبًا وَقَدْ كَانَتِ الْقِرَدَةُ وَالْخَنَازِيرُ قَبْلَ ذَلِكَ ‏"‏ ‏.‏\hadithno{6771}\hadithtrans{Abdullah reported that Umm Habiba, the wife of Allah's Apostle (ﷺ), said:0 Allah, enable me to derive benefit from my husband, the Messenger of Allah (ﷺ), and from my father Abu Sufyan and from my brother Mu'awiya. Allah's Apostle (ﷺ) said: You have asked from Allah about durations of life already set, and the length of days already allotted and the sustenances the share of which has been fixed. Allah would not do anything earlier before its due time, or He would not delay anything beyond its due time. And if you were to ask Allah to provide you refuge from the torment of the HellFire, or from the torment of the grave, it would have good in store for you and better for you also. He (the narrator) further said: Mention was made before him about monkeys, and Mis'ar (one of the narrators) said: I think that (the narrator) also (made a mention) of the swine, which had suffered metamorphosis. Thereupon he (the Holy Prophet) said: Verily, Allah did not cause the race of those which suffered metamorphosis to grow or they were not survived by young ones. Monkeys and swine had been in existence even before (the metamorphosis of the human beings)}}
\hadithdefcmd{muslim}{6772}{حَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ بِشْرٍ، عَنْ مِسْعَرٍ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّ فِي، حَدِيثِهِ عَنِ ابْنِ بِشْرٍ وَوَكِيعٍ جَمِيعًا ‏ "‏ مِنْ عَذَابٍ فِي النَّارِ وَعَذَابٍ فِي الْقَبْرِ ‏"‏ ‏.‏\hadithno{6772}\hadithtrans{This hadith has been reported on the authority of Mis'ar with the same chain of transmitters but with this variation that the hadith transmitted on the authority of Ibn Bishr and Waki', the torment of the Hell-Fire and the torment of grave have been mentioned together (and there is no conjunction" iw" or" between them)}}
\hadithdefcmd{muslim}{6773}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَحَجَّاجُ بْنُ الشَّاعِرِ، - وَاللَّفْظُ لِحَجَّاجٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، حَجَّاجٌ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا الثَّوْرِيُّ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنِ الْمُغِيرَةِ بْنِ عَبْدِ اللَّهِ الْيَشْكُرِيِّ، عَنْ مَعْرُورِ بْنِ سُوَيْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَتْ أُمُّ حَبِيبَةَ اللَّهُمَّ مَتِّعْنِي بِزَوْجِي رَسُولِ اللَّهِ صلى الله عليه وسلم وَبِأَبِي أَبِي سُفْيَانَ وَبِأَخِي مُعَاوِيَةَ ‏.‏ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّكِ سَأَلْتِ اللَّهَ لآجَالٍ مَضْرُوبَةٍ وَآثَارٍ مَوْطُوءَةٍ وَأَرْزَاقٍ مَقْسُومَةٍ لاَ يُعَجِّلُ شَيْئًا مِنْهَا قَبْلَ حِلِّهِ وَلاَ يُؤَخِّرُ مِنْهَا شَيْئًا بَعْدَ حِلِّهِ وَلَوْ سَأَلْتِ اللَّهَ أَنْ يُعَافِيَكِ مِنْ عَذَابٍ فِي النَّارِ وَعَذَابٍ فِي الْقَبْرِ لَكَانَ خَيْرًا لَكِ ‏"‏ ‏.‏ قَالَ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ الْقِرَدَةُ وَالْخَنَازِيرُ هِيَ مِمَّا مُسِخَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ لَمْ يُهْلِكْ قَوْمًا أَوْ يُعَذِّبْ قَوْمًا فَيَجْعَلَ لَهُمْ نَسْلاً وَإِنَّ الْقِرَدَةَ وَالْخَنَازِيرَ كَانُوا قَبْلَ ذَلِكَ ‏"‏ ‏.‏ حَدَّثَنِيهِ أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ مَعْبَدٍ حَدَّثَنَا الْحُسَيْنُ بْنُ حَفْصٍ، حَدَّثَنَا سُفْيَانُ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ ‏"‏ وَآثَارٍ مَبْلُوغَةٍ ‏"‏ ‏.‏ قَالَ ابْنُ مَعْبَدٍ وَرَوَى بَعْضُهُمْ ‏"‏ قَبْلَ حِلِّهِ ‏"‏ ‏.‏ أَىْ نُزُولِهِ ‏.‏\hadithno{6773}\hadithtrans{Ibn Mas'dd reported that Umm Habiba said:0 Allah, enable me to derive benefit from my husband, Allah's Messenger (ﷺ), and from my father Abu Sufyan, and from my brother Mu'awiya. Allah's Messenger (ﷺ) said to her: Verily, you have asked Allah about the durations of life already set, and the steps which you would take, and the sustenances the share of which is fixed. Nothing would take place earlier than its due time, and nothing would be deferred beyond that when it is due. So, if you were to ask Allah about your safety from the torment of Hell-Fire and from the torment of the grave, it would have been better for you. A person said: Allah's Messenger, what about those apes and swine which suffered metamorphosis? Thereupon Allah's Apostle (ﷺ) said: Verily, Allah, the Exalted and Glorious, did not destroy a people or did not torment a people, and let their race grow. Apes and swine had been even before that (when the deniers of truth were tormented and suffered metamorphosis). This hadith has been narrated on the authority of Sufyin through another chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{6774}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ رَبِيعَةَ بْنِ عُثْمَانَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُؤْمِنُ الْقَوِيُّ خَيْرٌ وَأَحَبُّ إِلَى اللَّهِ مِنَ الْمُؤْمِنِ الضَّعِيفِ وَفِي كُلٍّ خَيْرٌ احْرِصْ عَلَى مَا يَنْفَعُكَ وَاسْتَعِنْ بِاللَّهِ وَلاَ تَعْجِزْ وَإِنْ أَصَابَكَ شَىْءٌ فَلاَ تَقُلْ لَوْ أَنِّي فَعَلْتُ كَانَ كَذَا وَكَذَا ‏.‏ وَلَكِنْ قُلْ قَدَرُ اللَّهِ وَمَا شَاءَ فَعَلَ فَإِنَّ لَوْ تَفْتَحُ عَمَلَ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{6774}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:A strong believer is better and is more lovable to Allah than a weak believer, and there is good in everyone, (but) cherish that which gives you benefit (in the Hereafter) and seek help from Allah and do not lose heart, and if anything (in the form of trouble) comes to you, don't say: If I had not done that, it would not have happened so and so, but say: Allah did that what He had ordained to do and your" if" opens the (gate) for the Satan}}
