% Auto-generated chapter index for bukhari
% Source: ara-bukhari.json
% Total hadiths: 7589
% Chapters: 98

\hadithcollectionname{bukhari}{Sahih al Bukhari}

\hadithsectionname{bukhari}{1}{Revelation}
\hadithsectionname{bukhari}{2}{Belief}
\hadithsectionname{bukhari}{3}{Knowledge}
\hadithsectionname{bukhari}{4}{Ablutions (Wudu')}
\hadithsectionname{bukhari}{5}{Bathing (Ghusl)}
\hadithsectionname{bukhari}{6}{Menstrual Periods}
\hadithsectionname{bukhari}{7}{Rubbing hands and feet with dust (Tayammum)}
\hadithsectionname{bukhari}{8}{Prayers (Salat)}
\hadithsectionname{bukhari}{9}{Times of the Prayers}
\hadithsectionname{bukhari}{10}{Call to Prayers (Adhaan)}
\hadithsectionname{bukhari}{11}{Friday Prayer}
\hadithsectionname{bukhari}{12}{Fear Prayer}
\hadithsectionname{bukhari}{13}{The Two Festivals (Eids)}
\hadithsectionname{bukhari}{14}{Witr Prayer}
\hadithsectionname{bukhari}{15}{Invoking Allah for Rain (Istisqaa)}
\hadithsectionname{bukhari}{16}{Eclipses}
\hadithsectionname{bukhari}{17}{Prostration During Recital of Qur'an}
\hadithsectionname{bukhari}{18}{Shortening the Prayers (At-Taqseer)}
\hadithsectionname{bukhari}{19}{Prayer at Night (Tahajjud)}
\hadithsectionname{bukhari}{20}{Virtues of Prayer at Masjid Makkah and Madinah}
\hadithsectionname{bukhari}{21}{Actions while Praying}
\hadithsectionname{bukhari}{22}{Forgetfulness in Prayer}
\hadithsectionname{bukhari}{23}{Funerals (Al-Janaa'iz)}
\hadithsectionname{bukhari}{24}{Obligatory Charity Tax (Zakat)}
\hadithsectionname{bukhari}{25}{Hajj (Pilgrimage)}
\hadithsectionname{bukhari}{26}{`Umrah (Minor pilgrimage)}
\hadithsectionname{bukhari}{27}{Pilgrims Prevented from Completing the Pilgrimage}
\hadithsectionname{bukhari}{28}{Penalty of Hunting while on Pilgrimage}
\hadithsectionname{bukhari}{29}{Virtues of Madinah}
\hadithsectionname{bukhari}{30}{Fasting}
\hadithsectionname{bukhari}{31}{Praying at Night in Ramadaan (Taraweeh)}
\hadithsectionname{bukhari}{32}{Virtues of the Night of Qadr}
\hadithsectionname{bukhari}{33}{Retiring to a Mosque for Remembrance of Allah (I'tikaf)}
\hadithsectionname{bukhari}{34}{Sales and Trade}
\hadithsectionname{bukhari}{35}{Sales in which a Price is paid for Goods to be Delivered Later (As-Salam)}
\hadithsectionname{bukhari}{36}{Shuf'a}
\hadithsectionname{bukhari}{37}{Hiring}
\hadithsectionname{bukhari}{38}{Transferance of a Debt from One Person to Another (Al-Hawaala)}
\hadithsectionname{bukhari}{39}{Kafalah}
\hadithsectionname{bukhari}{40}{Representation, Authorization, Business by Proxy}
\hadithsectionname{bukhari}{41}{Agriculture}
\hadithsectionname{bukhari}{42}{Distribution of Water}
\hadithsectionname{bukhari}{43}{Loans, Payment of Loans, Freezing of Property, Bankruptcy}
\hadithsectionname{bukhari}{44}{Khusoomaat}
\hadithsectionname{bukhari}{45}{Lost Things Picked up by Someone (Luqatah)}
\hadithsectionname{bukhari}{46}{Oppressions}
\hadithsectionname{bukhari}{47}{Partnership}
\hadithsectionname{bukhari}{48}{Mortgaging}
\hadithsectionname{bukhari}{49}{Manumission of Slaves}
\hadithsectionname{bukhari}{50}{Makaatib}
\hadithsectionname{bukhari}{51}{Gifts}
\hadithsectionname{bukhari}{52}{Witnesses}
\hadithsectionname{bukhari}{53}{Peacemaking}
\hadithsectionname{bukhari}{54}{Conditions}
\hadithsectionname{bukhari}{55}{Wills and Testaments (Wasaayaa)}
\hadithsectionname{bukhari}{56}{Fighting for the Cause of Allah (Jihaad)}
\hadithsectionname{bukhari}{57}{One-fifth of Booty to the Cause of Allah (Khumus)}
\hadithsectionname{bukhari}{58}{Jizyah and Mawaada'ah}
\hadithsectionname{bukhari}{59}{Beginning of Creation}
\hadithsectionname{bukhari}{60}{Prophets}
\hadithsectionname{bukhari}{61}{Virtues and Merits of the Prophet (pbuh) and his Companions}
\hadithsectionname{bukhari}{62}{Companions of the Prophet}
\hadithsectionname{bukhari}{63}{Merits of the Helpers in Madinah (Ansaar)}
\hadithsectionname{bukhari}{64}{Military Expeditions led by the Prophet (pbuh) (Al-Maghaazi)}
\hadithsectionname{bukhari}{65}{Prophetic Commentary on the Qur'an (Tafseer of the Prophet (pbuh))}
\hadithsectionname{bukhari}{66}{Virtues of the Qur'an}
\hadithsectionname{bukhari}{67}{Wedlock, Marriage (Nikaah)}
\hadithsectionname{bukhari}{68}{Divorce}
\hadithsectionname{bukhari}{69}{Supporting the Family}
\hadithsectionname{bukhari}{70}{Food, Meals}
\hadithsectionname{bukhari}{71}{Sacrifice on Occasion of Birth (`Aqiqa)}
\hadithsectionname{bukhari}{72}{Hunting, Slaughtering}
\hadithsectionname{bukhari}{73}{Al-Adha Festival Sacrifice (Adaahi)}
\hadithsectionname{bukhari}{74}{Drinks}
\hadithsectionname{bukhari}{75}{Patients}
\hadithsectionname{bukhari}{76}{Medicine}
\hadithsectionname{bukhari}{77}{Dress}
\hadithsectionname{bukhari}{78}{Good Manners and Form (Al-Adab)}
\hadithsectionname{bukhari}{79}{Asking Permission}
\hadithsectionname{bukhari}{80}{Invocations}
\hadithsectionname{bukhari}{81}{To make the Heart Tender (Ar-Riqaq)}
\hadithsectionname{bukhari}{82}{Divine Will (Al-Qadar)}
\hadithsectionname{bukhari}{83}{Oaths and Vows}
\hadithsectionname{bukhari}{84}{Expiation for Unfulfilled Oaths}
\hadithsectionname{bukhari}{85}{Laws of Inheritance (Al-Faraa'id)}
\hadithsectionname{bukhari}{86}{Limits and Punishments set by Allah (Hudood)}
\hadithsectionname{bukhari}{87}{Blood Money (Ad-Diyat)}
\hadithsectionname{bukhari}{88}{Apostates}
\hadithsectionname{bukhari}{89}{(Statements made under) Coercion}
\hadithsectionname{bukhari}{90}{Tricks}
\hadithsectionname{bukhari}{91}{Interpretation of Dreams}
\hadithsectionname{bukhari}{92}{Afflictions and the End of the World}
\hadithsectionname{bukhari}{93}{Judgments (Ahkaam)}
\hadithsectionname{bukhari}{94}{Wishes}
\hadithsectionname{bukhari}{95}{Accepting Information Given by a Truthful Person}
\hadithsectionname{bukhari}{96}{Holding Fast to the Qur'an and Sunnah}
\hadithsectionname{bukhari}{97}{Oneness, Uniqueness of Allah (Tawheed)}

\hadithsectionrange{bukhari}{1}{1}{7}
\hadithsectionrange{bukhari}{2}{8}{58}
\hadithsectionrange{bukhari}{3}{59}{134}
\hadithsectionrange{bukhari}{4}{135}{247}
\hadithsectionrange{bukhari}{5}{248}{293}
\hadithsectionrange{bukhari}{6}{294}{333}
\hadithsectionrange{bukhari}{7}{334}{348}
\hadithsectionrange{bukhari}{8}{349}{520}
\hadithsectionrange{bukhari}{9}{522}{602}
\hadithsectionrange{bukhari}{10}{603}{875}
\hadithsectionrange{bukhari}{11}{876}{941}
\hadithsectionrange{bukhari}{12}{942}{947}
\hadithsectionrange{bukhari}{13}{948}{989}
\hadithsectionrange{bukhari}{14}{990}{1004}
\hadithsectionrange{bukhari}{15}{1005}{1039}
\hadithsectionrange{bukhari}{16}{1040}{1066}
\hadithsectionrange{bukhari}{17}{1067}{1079}
\hadithsectionrange{bukhari}{18}{1080}{1119}
\hadithsectionrange{bukhari}{19}{1120}{1187}
\hadithsectionrange{bukhari}{20}{1188}{1197}
\hadithsectionrange{bukhari}{21}{1198}{1223}
\hadithsectionrange{bukhari}{22}{1224}{1236}
\hadithsectionrange{bukhari}{23}{1237}{1394}
\hadithsectionrange{bukhari}{24}{1395}{1512}
\hadithsectionrange{bukhari}{25}{1513}{1772}
\hadithsectionrange{bukhari}{26}{1773}{1805}
\hadithsectionrange{bukhari}{27}{1806}{1820}
\hadithsectionrange{bukhari}{28}{1821}{1866}
\hadithsectionrange{bukhari}{29}{1867}{1890}
\hadithsectionrange{bukhari}{30}{1891}{2007}
\hadithsectionrange{bukhari}{31}{2008}{2013}
\hadithsectionrange{bukhari}{32}{2014}{2024}
\hadithsectionrange{bukhari}{33}{2025}{2046}
\hadithsectionrange{bukhari}{34}{2047}{2238}
\hadithsectionrange{bukhari}{35}{2239}{2256}
\hadithsectionrange{bukhari}{36}{2257}{2259}
\hadithsectionrange{bukhari}{37}{2260}{2286}
\hadithsectionrange{bukhari}{38}{2287}{2289}
\hadithsectionrange{bukhari}{39}{2290}{2298}
\hadithsectionrange{bukhari}{40}{2299}{2319}
\hadithsectionrange{bukhari}{41}{2320}{2350}
\hadithsectionrange{bukhari}{42}{2351}{2383}
\hadithsectionrange{bukhari}{43}{2385}{2409}
\hadithsectionrange{bukhari}{44}{2410}{2425}
\hadithsectionrange{bukhari}{45}{2426}{2439}
\hadithsectionrange{bukhari}{46}{2440}{2482}
\hadithsectionrange{bukhari}{47}{2483}{2507}
\hadithsectionrange{bukhari}{48}{2508}{2515}
\hadithsectionrange{bukhari}{49}{2517}{2559}
\hadithsectionrange{bukhari}{50}{2560}{2565}
\hadithsectionrange{bukhari}{51}{2566}{2636}
\hadithsectionrange{bukhari}{52}{2637}{2689}
\hadithsectionrange{bukhari}{53}{2690}{2710}
\hadithsectionrange{bukhari}{54}{2712}{2737}
\hadithsectionrange{bukhari}{55}{2738}{2781}
\hadithsectionrange{bukhari}{56}{2782}{3090}
\hadithsectionrange{bukhari}{57}{3091}{3155}
\hadithsectionrange{bukhari}{58}{3157}{3189}
\hadithsectionrange{bukhari}{59}{3190}{3325}
\hadithsectionrange{bukhari}{60}{3326}{3488}
\hadithsectionrange{bukhari}{61}{3489}{3648}
\hadithsectionrange{bukhari}{62}{3649}{3775}
\hadithsectionrange{bukhari}{63}{3776}{3948}
\hadithsectionrange{bukhari}{64}{3949}{4473}
\hadithsectionrange{bukhari}{65}{4474}{4977}
\hadithsectionrange{bukhari}{66}{4979}{5062}
\hadithsectionrange{bukhari}{67}{5063}{5250}
\hadithsectionrange{bukhari}{68}{5251}{5350}
\hadithsectionrange{bukhari}{69}{5351}{5372}
\hadithsectionrange{bukhari}{70}{5373}{5466}
\hadithsectionrange{bukhari}{71}{5467}{5474}
\hadithsectionrange{bukhari}{72}{5475}{5544}
\hadithsectionrange{bukhari}{73}{5545}{5574}
\hadithsectionrange{bukhari}{74}{5575}{5639}
\hadithsectionrange{bukhari}{75}{5640}{5677}
\hadithsectionrange{bukhari}{76}{5678}{5782}
\hadithsectionrange{bukhari}{77}{5783}{5969}
\hadithsectionrange{bukhari}{78}{5970}{6226}
\hadithsectionrange{bukhari}{79}{6227}{6303}
\hadithsectionrange{bukhari}{80}{6304}{6411}
\hadithsectionrange{bukhari}{81}{6412}{6593}
\hadithsectionrange{bukhari}{82}{6594}{6620}
\hadithsectionrange{bukhari}{83}{6621}{6707}
\hadithsectionrange{bukhari}{84}{6708}{6722}
\hadithsectionrange{bukhari}{85}{6723}{6771}
\hadithsectionrange{bukhari}{86}{6772}{6860}
\hadithsectionrange{bukhari}{87}{6861}{6917}
\hadithsectionrange{bukhari}{88}{6918}{6939}
\hadithsectionrange{bukhari}{89}{6940}{6952}
\hadithsectionrange{bukhari}{90}{6953}{6981}
\hadithsectionrange{bukhari}{91}{6982}{7047}
\hadithsectionrange{bukhari}{92}{7048}{7136}
\hadithsectionrange{bukhari}{93}{7137}{7225}
\hadithsectionrange{bukhari}{94}{7226}{7245}
\hadithsectionrange{bukhari}{95}{7246}{7267}
\hadithsectionrange{bukhari}{96}{7268}{7370}
\hadithsectionrange{bukhari}{97}{7371}{7563}

% Chapter index — which .def file to load for each chapter

\hadithchapterfile{bukhari}{0}{hadithtext-bukhari-ch00.def}{299}{7495}
\hadithchapterfile{bukhari}{1}{hadithtext-bukhari-ch01.def}{1}{7}
\hadithchapterfile{bukhari}{2}{hadithtext-bukhari-ch02.def}{8}{58}
\hadithchapterfile{bukhari}{3}{hadithtext-bukhari-ch03.def}{59}{134}
\hadithchapterfile{bukhari}{4}{hadithtext-bukhari-ch04.def}{135}{247}
\hadithchapterfile{bukhari}{5}{hadithtext-bukhari-ch05.def}{248}{293}
\hadithchapterfile{bukhari}{6}{hadithtext-bukhari-ch06.def}{294}{333}
\hadithchapterfile{bukhari}{7}{hadithtext-bukhari-ch07.def}{334}{348}
\hadithchapterfile{bukhari}{8}{hadithtext-bukhari-ch08.def}{349}{520}
\hadithchapterfile{bukhari}{9}{hadithtext-bukhari-ch09.def}{522}{602}
\hadithchapterfile{bukhari}{10}{hadithtext-bukhari-ch10.def}{603}{875}
\hadithchapterfile{bukhari}{11}{hadithtext-bukhari-ch11.def}{876}{941}
\hadithchapterfile{bukhari}{12}{hadithtext-bukhari-ch12.def}{942}{947}
\hadithchapterfile{bukhari}{13}{hadithtext-bukhari-ch13.def}{948}{989}
\hadithchapterfile{bukhari}{14}{hadithtext-bukhari-ch14.def}{990}{1004}
\hadithchapterfile{bukhari}{15}{hadithtext-bukhari-ch15.def}{1005}{1039}
\hadithchapterfile{bukhari}{16}{hadithtext-bukhari-ch16.def}{1040}{1066}
\hadithchapterfile{bukhari}{17}{hadithtext-bukhari-ch17.def}{1067}{1079}
\hadithchapterfile{bukhari}{18}{hadithtext-bukhari-ch18.def}{1080}{1119}
\hadithchapterfile{bukhari}{19}{hadithtext-bukhari-ch19.def}{1120}{1187}
\hadithchapterfile{bukhari}{20}{hadithtext-bukhari-ch20.def}{1188}{1197}
\hadithchapterfile{bukhari}{21}{hadithtext-bukhari-ch21.def}{1198}{1223}
\hadithchapterfile{bukhari}{22}{hadithtext-bukhari-ch22.def}{1224}{1236}
\hadithchapterfile{bukhari}{23}{hadithtext-bukhari-ch23.def}{1237}{1394}
\hadithchapterfile{bukhari}{24}{hadithtext-bukhari-ch24.def}{1395}{1512}
\hadithchapterfile{bukhari}{25}{hadithtext-bukhari-ch25.def}{1513}{1772}
\hadithchapterfile{bukhari}{26}{hadithtext-bukhari-ch26.def}{1773}{1805}
\hadithchapterfile{bukhari}{27}{hadithtext-bukhari-ch27.def}{1806}{1820}
\hadithchapterfile{bukhari}{28}{hadithtext-bukhari-ch28.def}{1821}{1866}
\hadithchapterfile{bukhari}{29}{hadithtext-bukhari-ch29.def}{1867}{1890}
\hadithchapterfile{bukhari}{30}{hadithtext-bukhari-ch30.def}{1891}{2007}
\hadithchapterfile{bukhari}{31}{hadithtext-bukhari-ch31.def}{2008}{2013}
\hadithchapterfile{bukhari}{32}{hadithtext-bukhari-ch32.def}{2014}{2024}
\hadithchapterfile{bukhari}{33}{hadithtext-bukhari-ch33.def}{2025}{2046}
\hadithchapterfile{bukhari}{34}{hadithtext-bukhari-ch34.def}{2047}{2238}
\hadithchapterfile{bukhari}{35}{hadithtext-bukhari-ch35.def}{2239}{2256}
\hadithchapterfile{bukhari}{36}{hadithtext-bukhari-ch36.def}{2257}{2259}
\hadithchapterfile{bukhari}{37}{hadithtext-bukhari-ch37.def}{2260}{2286}
\hadithchapterfile{bukhari}{38}{hadithtext-bukhari-ch38.def}{2287}{2289}
\hadithchapterfile{bukhari}{39}{hadithtext-bukhari-ch39.def}{2290}{2298}
\hadithchapterfile{bukhari}{40}{hadithtext-bukhari-ch40.def}{2299}{2319}
\hadithchapterfile{bukhari}{41}{hadithtext-bukhari-ch41.def}{2320}{2350}
\hadithchapterfile{bukhari}{42}{hadithtext-bukhari-ch42.def}{2351}{2383}
\hadithchapterfile{bukhari}{43}{hadithtext-bukhari-ch43.def}{2385}{2409}
\hadithchapterfile{bukhari}{44}{hadithtext-bukhari-ch44.def}{2410}{2425}
\hadithchapterfile{bukhari}{45}{hadithtext-bukhari-ch45.def}{2426}{2439}
\hadithchapterfile{bukhari}{46}{hadithtext-bukhari-ch46.def}{2440}{2482}
\hadithchapterfile{bukhari}{47}{hadithtext-bukhari-ch47.def}{2483}{2507}
\hadithchapterfile{bukhari}{48}{hadithtext-bukhari-ch48.def}{2508}{2515}
\hadithchapterfile{bukhari}{49}{hadithtext-bukhari-ch49.def}{2517}{2559}
\hadithchapterfile{bukhari}{50}{hadithtext-bukhari-ch50.def}{2560}{2565}
\hadithchapterfile{bukhari}{51}{hadithtext-bukhari-ch51.def}{2566}{2636}
\hadithchapterfile{bukhari}{52}{hadithtext-bukhari-ch52.def}{2637}{2689}
\hadithchapterfile{bukhari}{53}{hadithtext-bukhari-ch53.def}{2690}{2710}
\hadithchapterfile{bukhari}{54}{hadithtext-bukhari-ch54.def}{2712}{2737}
\hadithchapterfile{bukhari}{55}{hadithtext-bukhari-ch55.def}{2738}{2781}
\hadithchapterfile{bukhari}{56}{hadithtext-bukhari-ch56.def}{2782}{3090}
\hadithchapterfile{bukhari}{57}{hadithtext-bukhari-ch57.def}{3091}{3155}
\hadithchapterfile{bukhari}{58}{hadithtext-bukhari-ch58.def}{3157}{3189}
\hadithchapterfile{bukhari}{59}{hadithtext-bukhari-ch59.def}{3190}{3325}
\hadithchapterfile{bukhari}{60}{hadithtext-bukhari-ch60.def}{3326}{3488}
\hadithchapterfile{bukhari}{61}{hadithtext-bukhari-ch61.def}{3489}{3648}
\hadithchapterfile{bukhari}{62}{hadithtext-bukhari-ch62.def}{3649}{3775}
\hadithchapterfile{bukhari}{63}{hadithtext-bukhari-ch63.def}{3776}{3948}
\hadithchapterfile{bukhari}{64}{hadithtext-bukhari-ch64.def}{3949}{4473}
\hadithchapterfile{bukhari}{65}{hadithtext-bukhari-ch65.def}{4474}{4977}
\hadithchapterfile{bukhari}{66}{hadithtext-bukhari-ch66.def}{4979}{5062}
\hadithchapterfile{bukhari}{67}{hadithtext-bukhari-ch67.def}{5063}{5250}
\hadithchapterfile{bukhari}{68}{hadithtext-bukhari-ch68.def}{5251}{5350}
\hadithchapterfile{bukhari}{69}{hadithtext-bukhari-ch69.def}{5351}{5372}
\hadithchapterfile{bukhari}{70}{hadithtext-bukhari-ch70.def}{5373}{5466}
\hadithchapterfile{bukhari}{71}{hadithtext-bukhari-ch71.def}{5467}{5474}
\hadithchapterfile{bukhari}{72}{hadithtext-bukhari-ch72.def}{5475}{5544}
\hadithchapterfile{bukhari}{73}{hadithtext-bukhari-ch73.def}{5545}{5574}
\hadithchapterfile{bukhari}{74}{hadithtext-bukhari-ch74.def}{5575}{5639}
\hadithchapterfile{bukhari}{75}{hadithtext-bukhari-ch75.def}{5640}{5677}
\hadithchapterfile{bukhari}{76}{hadithtext-bukhari-ch76.def}{5678}{5782}
\hadithchapterfile{bukhari}{77}{hadithtext-bukhari-ch77.def}{5783}{5969}
\hadithchapterfile{bukhari}{78}{hadithtext-bukhari-ch78.def}{5970}{6226}
\hadithchapterfile{bukhari}{79}{hadithtext-bukhari-ch79.def}{6227}{6303}
\hadithchapterfile{bukhari}{80}{hadithtext-bukhari-ch80.def}{6304}{6411}
\hadithchapterfile{bukhari}{81}{hadithtext-bukhari-ch81.def}{6412}{6593}
\hadithchapterfile{bukhari}{82}{hadithtext-bukhari-ch82.def}{6594}{6620}
\hadithchapterfile{bukhari}{83}{hadithtext-bukhari-ch83.def}{6621}{6707}
\hadithchapterfile{bukhari}{84}{hadithtext-bukhari-ch84.def}{6708}{6722}
\hadithchapterfile{bukhari}{85}{hadithtext-bukhari-ch85.def}{6723}{6771}
\hadithchapterfile{bukhari}{86}{hadithtext-bukhari-ch86.def}{6772}{6860}
\hadithchapterfile{bukhari}{87}{hadithtext-bukhari-ch87.def}{6861}{6917}
\hadithchapterfile{bukhari}{88}{hadithtext-bukhari-ch88.def}{6918}{6939}
\hadithchapterfile{bukhari}{89}{hadithtext-bukhari-ch89.def}{6940}{6952}
\hadithchapterfile{bukhari}{90}{hadithtext-bukhari-ch90.def}{6953}{6981}
\hadithchapterfile{bukhari}{91}{hadithtext-bukhari-ch91.def}{6982}{7047}
\hadithchapterfile{bukhari}{92}{hadithtext-bukhari-ch92.def}{7048}{7136}
\hadithchapterfile{bukhari}{93}{hadithtext-bukhari-ch93.def}{7137}{7225}
\hadithchapterfile{bukhari}{94}{hadithtext-bukhari-ch94.def}{7226}{7245}
\hadithchapterfile{bukhari}{95}{hadithtext-bukhari-ch95.def}{7246}{7267}
\hadithchapterfile{bukhari}{96}{hadithtext-bukhari-ch96.def}{7268}{7370}
\hadithchapterfile{bukhari}{97}{hadithtext-bukhari-ch97.def}{7371}{7563}
