% Auto-generated chapter 30 for muslim
% Hadiths in this chapter: 28

\hadithdefcmd{muslim}{4470}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ أَخْبَرَنَا ابْنُ وَهْبٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ يُعْطَى النَّاسُ بِدَعْوَاهُمْ لاَدَّعَى نَاسٌ دِمَاءَ رِجَالٍ وَأَمْوَالَهُمْ وَلَكِنَّ الْيَمِينَ عَلَى الْمُدَّعَى عَلَيْهِ ‏"‏ ‏.‏\hadithno{4470}\hadithtrans{Ibn Abbas reported Allah's Apostle (ﷺ) as saying:If the people were given according to their claims, they would claim the lives of persons and their properties, but the oath must be taken by the defendant}}
\hadithdefcmd{muslim}{4471}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ نَافِعِ بْنِ عُمَرَ، عَنِ ابْنِ، أَبِي مُلَيْكَةَ عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى بِالْيَمِينِ عَلَى الْمُدَّعَى عَلَيْهِ ‏.‏\hadithno{4471}\hadithtrans{Ibn 'Abbas reported that Allah's Messenger (ﷺ) pronounced judgment on the basis of oath by the defendant}}
\hadithdefcmd{muslim}{4472}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، قَالاَ حَدَّثَنَا زَيْدٌ، - وَهُوَ ابْنُ حُبَابٍ - حَدَّثَنِي سَيْفُ بْنُ سُلَيْمَانَ، أَخْبَرَنِي قَيْسُ بْنُ سَعْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى بِيَمِينٍ وَشَاهِدٍ ‏.‏\hadithno{4472}\hadithtrans{Ibn 'Abbas reported that Allah's Messenger (ﷺ) pronounced judgment on the basis of an oath and a witness (by the plaintiff)}}
\hadithdefcmd{muslim}{4473}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ، شِهَابٍ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَمِعَ جَلَبَةَ خَصْمٍ بِبَابِ حُجْرَتِهِ فَخَرَجَ إِلَيْهِمْ فَقَالَ ‏ "‏ إِنَّمَا أَنَا بَشَرٌ وَإِنَّهُ يَأْتِينِي الْخَصْمُ فَلَعَلَّ بَعْضَهُمْ أَنْ يَكُونَ أَبْلَغَ مِنْ بَعْضٍ فَأَحْسِبُ أَنَّهُ صَادِقٌ فَأَقْضِي لَهُ فَمَنْ قَضَيْتُ لَهُ بِحَقِّ مُسْلِمٍ فَإِنَّمَا هِيَ قِطْعَةٌ مِنَ النَّارِ فَلْيَحْمِلْهَا أَوْ يَذَرْهَا ‏"‏ ‏.‏\hadithno{4473}\hadithtrans{Umm Salama, the wife of Allah's Apostle (ﷺ), reported that Allah's Messenger (ﷺ) heard the clamour of contenders at the door of his apartment. He went to them, and said:I am a human being and the claimants bring to me (the dispute) and perhaps some of them are more eloquent than the others. I judge him to be on the right, and thus decide in his favcur. So he whom I, by my judgment, (give the undue share) out of the right of a Muslim,. I give him a portion of Fire; he may burden himself with it or abandon it}}
\hadithdefcmd{muslim}{4474}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِ يُونُسَ ‏.‏ وَفِي حَدِيثِ مَعْمَرٍ قَالَتْ سَمِعَ النَّبِيُّ صلى الله عليه وسلم لَجَبَةَ خَصْمٍ بِبَابِ أُمِّ سَلَمَةَ ‏.‏\hadithno{4474}\hadithtrans{This hadith has been transmitted on the authority of Ma'mar with a slight variation of words}}
\hadithdefcmd{muslim}{4475}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّكُمْ تَخْتَصِمُونَ إِلَىَّ وَلَعَلَّ بَعْضَكُمْ أَنْ يَكُونَ أَلْحَنَ بِحُجَّتِهِ مِنْ بَعْضٍ فَأَقْضِي لَهُ عَلَى نَحْوٍ مِمَّا أَسْمَعُ مِنْهُ فَمَنْ قَطَعْتُ لَهُ مِنْ حَقِّ أَخِيهِ شَيْئًا فَلاَ يَأْخُذْهُ فَإِنَّمَا أَقْطَعُ لَهُ بِهِ قِطْعَةً مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{4475}\hadithtrans{Umm Salama reported Allah's Messenger (ﷺ) as saying:You bring to me, for (judgment) your disputes, some of you perhaps being more eloquent in their plea than others, so I give judgment on their behalf according to what I hear from them. (Bear in mind, in my judgment) if I slice off anything for him from the right of his brother, he should not accept that, for I sliced off for him a portion from the Hell}}
\hadithdefcmd{muslim}{4476}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ، نُمَيْرٍ كِلاَهُمَا عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4476}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{4477}{حَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَتْ هِنْدٌ بِنْتُ عُتْبَةَ امْرَأَةُ أَبِي سُفْيَانَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سُفْيَانَ رَجُلٌ شَحِيحٌ لاَ يُعْطِينِي مِنَ النَّفَقَةِ مَا يَكْفِينِي وَيَكْفِي بَنِيَّ إِلاَّ مَا أَخَذْتُ مِنْ مَالِهِ بِغَيْرِ عِلْمِهِ ‏.‏ فَهَلْ عَلَىَّ فِي ذَلِكَ مِنْ جُنَاحٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خُذِي مِنْ مَالِهِ بِالْمَعْرُوفِ مَا يَكْفِيكِ وَيَكْفِي بَنِيكِ ‏"‏ ‏.‏\hadithno{4477}\hadithtrans{A'isha reported:Hind. the daughter of 'Utba, wife of Abu Sufyan, came to Allah's Messenger (ﷺ) and said: Abu Sufyan is a miserly person. He does not give adequate maintenance for me and my children, but (I am constrained) to take from his wealth (some part of it) without his knowledge. Is there any sin for me? Thereupon Allah's Messenger (ﷺ) said: Take from his property what is customary which may suffice you and your children}}
\hadithdefcmd{muslim}{4478}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَأَبُو كُرَيْبٍ كِلاَهُمَا عَنْ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَوَكِيعٍ ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، - يَعْنِي ابْنَ عُثْمَانَ - كُلُّهُمْ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{4478}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chair of transmitters}}
\hadithdefcmd{muslim}{4479}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ هِنْدٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ وَاللَّهِ مَا كَانَ عَلَى ظَهْرِ الأَرْضِ أَهْلُ خِبَاءٍ أَحَبَّ إِلَىَّ مِنْ أَنْ يُذِلَّهُمُ اللَّهُ مِنْ أَهْلِ خِبَائِكَ وَمَا عَلَى ظَهْرِ الأَرْضِ أَهْلُ خِبَاءٍ أَحَبَّ إِلَىَّ مِنْ أَنْ يُعِزَّهُمُ اللَّهُ مِنْ أَهْلِ خِبَائِكَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَأَيْضًا وَالَّذِي نَفْسِي بِيَدِهِ ‏"‏ ‏.‏ ثُمَّ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سُفْيَانَ رَجُلٌ مُمْسِكٌ فَهَلْ عَلَىَّ حَرَجٌ أَنْ أُنْفِقَ عَلَى عِيَالِهِ مِنْ مَالِهِ بِغَيْرِ إِذْنِهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ حَرَجَ عَلَيْكِ أَنْ تُنْفِقِي عَلَيْهِمْ بِالْمَعْرُوفِ ‏"‏ ‏.‏\hadithno{4479}\hadithtrans{A'isha reported that Hind came to Allah's Apostle (ﷺ) and said:Messenger of Allah, by Allah, there was no other household upon the surface of the earth than your household about which I cherished Allah bringing disgrace upon it, (and now) there is no other household upon the surface of the earth than your household about which I cherish Allah granting it honour. Allah's Apostle (ﷺ) said: It is so, by Him in Whose Hand is my life She said: Allah's Messenger, Abu Sufyan is a niggardly person. Is there any harm for me if I spend upon his children out of his wealth without his permission? Thereupon Allah's Apostle (ﷺ) said: There is no harm for you if you spend upon them what is reasonable}}
\hadithdefcmd{muslim}{4480}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَخِي الزُّهْرِيِّ، عَنْ عَمِّهِ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، قَالَتْ جَاءَتْ هِنْدٌ بِنْتُ عُتْبَةَ بْنِ رَبِيعَةَ فَقَالَتْ يَا رَسُولَ اللَّهِ وَاللَّهِ مَا كَانَ عَلَى ظَهْرِ الأَرْضِ خِبَاءٌ أَحَبَّ إِلَىَّ مِنْ أَنْ يَذِلُّوا مِنْ أَهْلِ خِبَائِكَ وَمَا أَصْبَحَ الْيَوْمَ عَلَى ظَهْرِ الأَرْضِ خِبَاءٌ أَحَبَّ إِلَىَّ مِنْ أَنْ يَعِزُّوا مِنْ أَهْلِ خِبَائِكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَأَيْضًا وَالَّذِي نَفْسِي بِيَدِهِ ‏"‏ ‏.‏ ثُمَّ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سُفْيَانَ رَجُلٌ مِسِّيكٌ فَهَلْ عَلَىَّ حَرَجٌ مِنْ أَنْ أُطْعِمَ مِنَ الَّذِي لَهُ عِيَالَنَا فَقَالَ لَهَا ‏"‏ لاَ إِلاَّ بِالْمَعْرُوفِ ‏"‏ ‏.‏\hadithno{4480}\hadithtrans{A'isha reported that Hind, daughter of Utba h. Rabi', came to Allah's Messenger (ﷺ) and said:Allah's Messenger, by Allah, there was no household upon the surface of the earth than your household about which I cherished that it should be disgraced. But today there is no household on the surface of the earth than your household about which I cherish that it be honoured Thereupon Allah's Messenger (ﷺ) said. It will increase, by Him in Whose Hand is my life. She then said: Messenger of Allah, Abu Sufyan is a niggardly person; is there any harm for me if I spend out of that which belongs to him on our children? He said to her: No, but only that what is reasonable}}
\hadithdefcmd{muslim}{4481}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يَرْضَى لَكُمْ ثَلاَثًا وَيَكْرَهُ لَكُمْ ثَلاَثًا فَيَرْضَى لَكُمْ أَنْ تَعْبُدُوهُ وَلاَ تُشْرِكُوا بِهِ شَيْئًا وَأَنْ تَعْتَصِمُوا بِحَبْلِ اللَّهِ جَمِيعًا وَلاَ تَفَرَّقُوا وَيَكْرَهُ لَكُمْ قِيلَ وَقَالَ وَكَثْرَةَ السُّؤَالِ وَإِضَاعَةَ الْمَالِ ‏"‏ ‏.‏\hadithno{4481}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Verily Allah likes three things for you and He disapproves three things for you. He is pleased with you that you worship Him and associate nor anything with Him, that you hold fast the rope of Allah, and be not scattered; and He disapproves for you irrelevant talk, persistent questioning ane the wasting of wealth}}
\hadithdefcmd{muslim}{4482}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ سُهَيْلٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّهُ قَالَ وَيَسْخَطُ لَكُمْ ثَلاَثًا ‏.‏ وَلَمْ يَذْكُرْ وَلاَ تَفَرَّقُوا ‏.‏\hadithno{4482}\hadithtrans{This hadith has been narrated on the authority of Suhail with the same chain of transmitters, but with a slight variation of words}}
\hadithdefcmd{muslim}{4483}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الشَّعْبِيِّ، عَنْ وَرَّادٍ، مَوْلَى الْمُغِيرَةِ بْنِ شُعْبَةَ عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ حَرَّمَ عَلَيْكُمْ عُقُوقَ الأُمَّهَاتِ وَوَأْدَ الْبَنَاتِ وَمَنْعًا وَهَاتِ وَكَرِهَ لَكُمْ ثَلاَثًا قِيلَ وَقَالَ وَكَثْرَةَ السُّؤَالِ وَإِضَاعَةَ الْمَالِ ‏"‏ ‏.‏\hadithno{4483}\hadithtrans{Mughira b. Shu'ba reported Allah's Messenger (ﷺ) as saying:Verity Allah, the Glorious and Majestic, has forbidden for you: disobedience to mothers, and burying alive daughters, withholding the right of others in spite of having the power to return that to them and demanding that (which is not one's legitimate right). And He disapproved three things for you; irrelevant talk, persistent questioning and wasting of wealth}}
\hadithdefcmd{muslim}{4484}{وَحَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏ غَيْرَ أَنَّهُ قَالَ وَحَرَّمَ عَلَيْكُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ وَلَمْ يَقُلْ إِنَّ اللَّهَ حَرَّمَ عَلَيْكُمْ ‏.‏\hadithno{4484}\hadithtrans{A hadith like this has been trransmitted on the authority of Mansur with a slight vairiation of words}}
\hadithdefcmd{muslim}{4485}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ خَالِدٍ الْحَذَّاءِ، حَدَّثَنِي ابْنُ أَشْوَعَ، عَنِ الشَّعْبِيِّ، حَدَّثَنِي كَاتِبُ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ كَتَبَ مُعَاوِيَةُ إِلَى الْمُغِيرَةِ اكْتُبْ إِلَىَّ بِشَىْءٍ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَكَتَبَ إِلَيْهِ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ كَرِهَ لَكُمْ ثَلاَثًا قِيلَ وَقَالَ وَإِضَاعَةَ الْمَالِ وَكَثْرَةَ السُّؤَالِ ‏"‏ ‏.‏\hadithno{4485}\hadithtrans{Sha'bi reported that the scribe of al-Mughira b. Shu'ba said:Mu'awiya wrote to Mughira: Write for me something which you heard from Allah's Messenger (ﷺ) ; and he wrote: I heard Allah's Messenger (ﷺ) as saying. Verily Allah disapproves three thingq for you: irrelevant talk, wasting of wealth and persistent questioning}}
\hadithdefcmd{muslim}{4486}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، عَنْ مُحَمَّدِ بْنِ سُوقَةَ، أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ الثَّقَفِيُّ، عَنْ وَرَّادٍ، قَالَ كَتَبَ الْمُغِيرَةُ إِلَى مُعَاوِيَةَ سَلاَمٌ عَلَيْكَ أَمَّا بَعْدُ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ حَرَّمَ ثَلاَثًا وَنَهَى عَنْ ثَلاَثٍ حَرَّمَ عُقُوقَ الْوَالِدِ وَوَأْدَ الْبَنَاتِ وَلاَ وَهَاتِ ‏.‏ وَنَهَى عَنْ ثَلاَثٍ قِيلٍ وَقَالٍ وَكَثْرَةِ السُّؤَالِ وَإِضَاعَةِ الْمَالِ ‏"‏ ‏.‏\hadithno{4486}\hadithtrans{Warrad reported that al-Mughira wrote to Mu'awiya:Peace be upon you, and then coming to the poirt (I should say) that I heard Allah's Messenger (ﷺ) as saying: Verily Allah has Prohibited three things and has forbidden three things. He has declared absolutely haram the disobedience of father, burying of daughters alive, and withholding that which you have power to return, and has forbidden three things: irrelevant talk, persistent questioning, and wasting of wealth}}
\hadithdefcmd{muslim}{4487}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ يَزِيدَ بْنِ عَبْدِ، اللَّهِ بْنِ أُسَامَةَ بْنِ الْهَادِ عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي قَيْسٍ، مَوْلَى عَمْرِو بْنِ الْعَاصِ عَنْ عَمْرِو بْنِ الْعَاصِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا حَكَمَ الْحَاكِمُ فَاجْتَهَدَ ثُمَّ أَصَابَ فَلَهُ أَجْرَانِ ‏.‏ وَإِذَا حَكَمَ فَاجْتَهَدَ ثُمَّ أَخْطَأَ فَلَهُ أَجْرٌ ‏"‏ ‏.‏\hadithno{4487}\hadithtrans{Amr b. al-'As reported that he heard Allah's Messenger (ﷺ) as saying:When a judge gives a decision, having tried his best to decide correctly and is right, there are two rewards for him; and if he gave a judgment after having tried his best (to arrive at a correct decision) but erred, there is one reward for him}}
\hadithdefcmd{muslim}{4488}{وَحَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ أَبِي عُمَرَ، كِلاَهُمَا عَنْ عَبْدِ الْعَزِيزِ بْنِ، مُحَمَّدٍ بِهَذَا الإِسْنَادِ مِثْلَهُ وَزَادَ فِي عَقِبِ الْحَدِيثِ قَالَ يَزِيدُ فَحَدَّثْتُ هَذَا الْحَدِيثَ أَبَا بَكْرِ بْنَ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ فَقَالَ هَكَذَا حَدَّثَنِي أَبُو سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{4488}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira with another chain of transmitters}}
\hadithdefcmd{muslim}{4489}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا مَرْوَانُ، - يَعْنِي ابْنَ مُحَمَّدٍ الدِّمَشْقِيَّ - حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، حَدَّثَنِي يَزِيدُ بْنُ عَبْدِ اللَّهِ بْنِ أُسَامَةَ بْنِ الْهَادِ اللَّيْثِيُّ، بِهَذَا الْحَدِيثِ مِثْلَ رِوَايَةِ عَبْدِ الْعَزِيزِ بْنِ مُحَمَّدٍ بِالإِسْنَادَيْنِ جَمِيعًا ‏.‏\hadithno{4489}\hadithtrans{This hadith has been transmitted on the authority of Usama b. al-Had al-Laithi}}
\hadithdefcmd{muslim}{4490}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ أَبِي بَكْرَةَ ‏.‏ قَالَ كَتَبَ أَبِي - وَكَتَبْتُ لَهُ - إِلَى عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرَةَ وَهُوَ قَاضٍ بِسِجِسْتَانَ أَنْ لاَ، تَحْكُمَ بَيْنَ اثْنَيْنِ وَأَنْتَ غَضْبَانُ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحْكُمْ أَحَدٌ بَيْنَ اثْنَيْنِ وَهُوَ غَضْبَانُ ‏"‏ ‏.‏\hadithno{4490}\hadithtrans{Abd al-Rahman b. Abu Bakra reported:My father dictated (and I wrote for him) to Ubaidullah b. Abu Bakra while he was the judge of Sijistan: Do not judge between two persons when you are angry, for I have heard Allah's Messenger (ﷺ) as saying: None of you should judge between two persons when he is angry}}
\hadithdefcmd{muslim}{4491}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، ح وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، ح وَحَدَّثَنَا مُحَمَّدُ، بْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي كِلاَهُمَا، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، كُلُّ هَؤُلاَءِ عَنْ عَبْدِ الْمَلِكِ، بْنِ عُمَيْرٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ أَبِي عَوَانَةَ ‏.‏\hadithno{4491}\hadithtrans{This hadith has been narrated on the authority of 'Abd al-Rahman b. Abu Bakra through another chain of transmitters}}
\hadithdefcmd{muslim}{4492}{حَدَّثَنَا أَبُو جَعْفَرٍ، مُحَمَّدُ بْنُ الصَّبَّاحِ وَعَبْدُ اللَّهِ بْنُ عَوْنٍ الْهِلاَلِيُّ جَمِيعًا عَنْ إِبْرَاهِيمَ، بْنِ سَعْدٍ قَالَ ابْنُ الصَّبَّاحِ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، حَدَّثَنَا أَبِي، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَحْدَثَ فِي أَمْرِنَا هَذَا مَا لَيْسَ مِنْهُ فَهُوَ رَدٌّ ‏"‏ ‏.‏\hadithno{4492}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) as saying:He who innovates things in our affairs for which there is no valid (reason) (commits sin) and these are to be rejected}}
\hadithdefcmd{muslim}{4493}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ أَبِي عَامِرٍ، قَالَ عَبْدٌ حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الزُّهْرِيُّ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ سَأَلْتُ الْقَاسِمَ بْنَ مُحَمَّدٍ عَنْ رَجُلٍ، لَهُ ثَلاَثَةُ مَسَاكِنَ فَأَوْصَى بِثُلُثِ كُلِّ مَسْكَنٍ مِنْهَا قَالَ يُجْمَعُ ذَلِكَ كُلُّهُ فِي مَسْكَنٍ وَاحِدٍ ثُمَّ قَالَ أَخْبَرَتْنِي عَائِشَةُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ عَمِلَ عَمَلاً لَيْسَ عَلَيْهِ أَمْرُنَا فَهُوَ رَدٌّ ‏"‏ ‏.‏\hadithno{4493}\hadithtrans{Sa'd b. Ibrahim reported:I asked Qasim b. Muhammad about a person who had three dwelling houses and he willed away the third part of every one of these houses; he (Qasim b. Muhammad) said: All of them could be combined in one house; and then said: 'A'isha informed me that Allah's Messenger (ﷺ) said: He who did any act for which there is no sanction from our behalf, that is to be rejected}}
\hadithdefcmd{muslim}{4494}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عُثْمَانَ، عَنِ ابْنِ أَبِي عَمْرَةَ الأَنْصَارِيِّ، عَنْ زَيْدِ بْنِ خَالِدٍ، الْجُهَنِيِّ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ أُخْبِرُكُمْ بِخَيْرِ الشُّهَدَاءِ الَّذِي يَأْتِي بِشَهَادَتِهِ قَبْلَ أَنْ يُسْأَلَهَا ‏"‏ ‏.‏\hadithno{4494}\hadithtrans{Zaid b. Khalid al-Juhani reported Allah's Apostle (ﷺ) as saying:Should I not tell you of the best witnesses? He is the one who produces his evidence before he is asked for it}}
\hadithdefcmd{muslim}{4495}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنِي شَبَابَةُ، حَدَّثَنِي وَرْقَاءُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَمَا امْرَأَتَانِ مَعَهُمَا ابْنَاهُمَا جَاءَ الذِّئْبُ فَذَهَبَ بِابْنِ إِحْدَاهُمَا ‏.‏ فَقَالَتْ هَذِهِ لِصَاحِبَتِهَا إِنَّمَا ذَهَبَ بِابْنِكِ أَنْتِ ‏.‏ وَقَالَتِ الأُخْرَى إِنَّمَا ذَهَبَ بِابْنِكِ ‏.‏ فَتَحَاكَمَتَا إِلَى دَاوُدَ فَقَضَى بِهِ لِلْكُبْرَى فَخَرَجَتَا عَلَى سُلَيْمَانَ بْنِ دَاوُدَ عَلَيْهِمَا السَّلاَمُ فَأَخْبَرَتَاهُ فَقَالَ ائْتُونِي بِالسِّكِّينِ أَشُقُّهُ بَيْنَكُمَا ‏.‏ فَقَالَتِ الصُّغْرَى لاَ يَرْحَمُكَ اللَّهُ هُوَ ابْنُهَا ‏.‏ فَقَضَى بِهِ لِلصُّغْرَى ‏"‏ ‏.‏ قَالَ قَالَ أَبُو هُرَيْرَةَ وَاللَّهِ إِنْ سَمِعْتُ بِالسِّكِّينِ قَطُّ إِلاَّ يَوْمَئِذٍ مَا كُنَّا نَقُولُ إِلاَّ الْمُدْيَةَ ‏.‏\hadithno{4495}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:While two women had been going along witn their two sons, a wolf came and made away with the child of one of them. One of them said to her companion: It is with your child that it (the wolf) has run away The other one said: It has run away with your child. They brought the matter to (Hadrat) Dawud (David) for decision and he made a decision in favour of the elder one. They then went to Sulaiman b. Dawud (may there be peace upon both of them) and told them (the story). He said: Bring me a knife so that I may cut him (the child) (into two parts) for you. The younger one said: No, it can't be, may Allah have mercy upon you, he (the child) belongs to her (the elder). So he gave a decision in favour of the younger one. abu Huraira said: If ever I heard of the word as-sikin at all, it was that day. We called it by no other name but al-Mudya}}
\hadithdefcmd{muslim}{4496}{وَحَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنِي حَفْصٌ، - يَعْنِي ابْنَ مَيْسَرَةَ الصَّنْعَانِيَّ - عَنْ مُوسَى بْنِ عُقْبَةَ، ح وَحَدَّثَنَا أُمَيَّةُ بْنُ بِسْطَامَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا رَوْحٌ، - وَهُوَ ابْنُ الْقَاسِمِ - عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، جَمِيعًا عَنْ أَبِي الزِّنَادِ، بِهَذَا الإِسْنَادِ مِثْلَ مَعْنَى حَدِيثِ وَرْقَاءَ ‏.‏\hadithno{4496}\hadithtrans{This hadith has been narrated on the authority of Abu az-Zinad with the same chain of transmitters}}
\hadithdefcmd{muslim}{4497}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اشْتَرَى رَجُلٌ مِنْ رَجُلٍ عَقَارًا لَهُ فَوَجَدَ الرَّجُلُ الَّذِي اشْتَرَى الْعَقَارَ فِي عَقَارِهِ جَرَّةً فِيهَا ذَهَبٌ فَقَالَ لَهُ الَّذِي اشْتَرَى الْعَقَارَ خُذْ ذَهَبَكَ مِنِّي إِنَّمَا اشْتَرَيْتُ مِنْكَ الأَرْضَ وَلَمْ أَبْتَعْ مِنْكَ الذَّهَبَ ‏.‏ فَقَالَ الَّذِي شَرَى الأَرْضَ إِنَّمَا بِعْتُكَ الأَرْضَ وَمَا فِيهَا - قَالَ - فَتَحَاكَمَا إِلَى رَجُلٍ فَقَالَ الَّذِي تَحَاكَمَا إِلَيْهِ أَلَكُمَا وَلَدٌ فَقَالَ أَحَدُهُمَا لِي غُلاَمٌ وَقَالَ الآخَرُ لِي جَارِيَةٌ ‏.‏ قَالَ أَنْكِحُوا الْغُلاَمَ الْجَارِيَةَ وَأَنْفِقُوا عَلَى أَنْفُسِكُمَا مِنْهُ وَتَصَدَّقَا ‏"‏ ‏.‏\hadithno{4497}\hadithtrans{Hammim b. Munabbih said:Abu Huraira reported (so many) ahadith of Allah's Messenger (ﷺ), and one of them is this: A person bought from another person a piece of land, and the person who had, bought that land found in it an earthen ware which contained gold. The person who had bought the land said (to the seller of the land): Take your gold from me, for I bought only the land from you and not the gold. The man who had sold the land said: I sold the land to you and whatever was in it. They referred the matter to a person. One who was made as a judge said to them: Have you any issue? One of them said: I have a boy, and the other said: I have a young daughter He (the judge) said: Marry this young boy with the girl, and spend something on yourselves and also give (some) charity out of it}}
