% Auto-generated chapter 41 for nasai
% Hadiths in this chapter: 41

\hadithdefcmd{nasai}{4222}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ فَرَعَ وَلاَ عَتِيرَةَ ‏"‏ ‏.‏\hadithno{4222}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"There is no fara' and no' Atirah}}
\hadithdefcmd{nasai}{4223}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثْتُ أَبَا إِسْحَاقَ، عَنْ مَعْمَرٍ، وَسُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَحَدُهُمَا نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْفَرَعِ وَالْعَتِيرَةِ ‏.‏ وَقَالَ الآخَرُ ‏ "‏ لاَ فَرَعَ وَلاَ عَتِيرَةَ ‏"‏ ‏.‏\hadithno{4223}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah that:the Messenger of Allah forbade Fara' and 'Atirah}}
\hadithdefcmd{nasai}{4224}{أَخْبَرَنَا عَمْرُو بْنُ زُرَارَةَ، قَالَ حَدَّثَنَا مُعَاذٌ، - وَهُوَ ابْنُ مُعَاذٍ - قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، قَالَ حَدَّثَنَا أَبُو رَمْلَةَ، قَالَ أَنْبَأَنَا مِخْنَفُ بْنُ سُلَيْمٍ، قَالَ بَيْنَا نَحْنُ وُقُوفٌ مَعَ النَّبِيِّ صلى الله عليه وسلم بِعَرَفَةَ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ إِنَّ عَلَى أَهْلِ بَيْتٍ فِي كُلِّ عَامٍ أَضْحَاةً وَعَتِيرَةً ‏"‏ ‏.‏ قَالَ مُعَاذٌ كَانَ ابْنُ عَوْنٍ يَعْتِرُ أَبْصَرَتْهُ عَيْنِي فِي رَجَبٍ ‏.‏\hadithno{4224}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Mikhnaf bin Sulaim said:"While we were standing with the Messenger of Allah at 'Arafat, he said: 'O people, it is upon each family to offer a sacrifice (Udhiyah) and an 'Atirah each year." (One of the narrators) Muadh said: "Ibn 'Awn used to offer slaughter the 'Atirah, and I saw that with my own eyes during Rajab." (Daif)}}
\hadithdefcmd{nasai}{4225}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ بْنِ إِسْحَاقَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ أَبُو عَلِيٍّ الْحَنَفِيُّ، قَالَ حَدَّثَنَا دَاوُدُ بْنُ قَيْسٍ، قَالَ سَمِعْتُ عَمْرَو بْنَ شُعَيْبِ بْنِ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ أَبِيهِ، ‏\{‏ عَنْ أَبِيهِ، ‏\}‏ وَزَيْدِ بْنِ أَسْلَمَ قَالُوا يَا رَسُولَ اللَّهِ الْفَرَعَ ‏.‏ قَالَ ‏"‏ حَقٌّ فَإِنْ تَرَكْتَهُ حَتَّى يَكُونَ بَكْرًا فَتَحْمِلَ عَلَيْهِ فِي سَبِيلِ اللَّهِ أَوْ تُعْطِيَهُ أَرْمَلَةً خَيْرٌ مِنْ أَنْ تَذْبَحَهُ فَيَلْصَقَ لَحْمُهُ بِوَبَرِهِ فَتُكْفِئَ إِنَاءَكَ وَتُوَلِّهَ نَاقَتَكَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ فَالْعَتِيرَةُ قَالَ ‏"‏ الْعَتِيرَةُ حَقٌّ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ أَبُو عَلِيٍّ الْحَنَفِيُّ هُمْ أَرْبَعَةُ إِخْوَةٍ أَحَدُهُمْ أَبُو بَكْرٍ وَبِشْرٌ وَشَرِيكٌ وَآخَرُ ‏.‏\hadithno{4225}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr bin Shu'aib bin Muhammad bin 'Abdullah bin 'Amr (narrated) that his father and Zaid bin Aslam said:"O Messenger of Allah! (What about) the Fara'?" He said: "It is a duty, but if you leave it (the animal) until it becomes half-grown and you load upon it (in Jihad) in the cause of Allah or give it to a widow, that is better than if you slaughter it (when it is just born) and its flesh is difficult to separate from its skin, then you turn your vessel upside down (because you will no longer be able to get milk from the mother) and you cause your she-camel to grieve (at the loss of its young)." They said: "O Messenger of Allah, (what about) the 'Atirah?" He said: "The 'Atirah is a duty." (Hasan) Abu 'Abdur-Rahman (An-Nasa'i) said: Abu 'Ali Al-Hanafi (one of the narrators); they are four brothers: One of them is Abu Bakr, and Bishr, and Sharik, and the other}}
\hadithdefcmd{nasai}{4226}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، - يَعْنِي ابْنَ الْمُبَارَكِ - عَنْ يَحْيَى، - وَهُوَ ابْنُ زُرَارَةَ بْنِ كُرَيْمِ بْنِ الْحَارِثِ بْنِ عَمْرٍو الْبَاهِلِيُّ - قَالَ سَمِعْتُ أَبِي يَذْكُرُ، أَنَّهُ سَمِعَ جَدَّهُ الْحَارِثَ بْنَ عَمْرٍو، يُحَدِّثُ أَنَّهُ لَقِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ وَهُوَ عَلَى نَاقَتِهِ الْعَضْبَاءِ فَأَتَيْتُهُ مِنْ أَحَدِ شِقَّيْهِ فَقُلْتُ يَا رَسُولَ اللَّهِ بِأَبِي أَنْتَ وَأُمِّي اسْتَغْفِرْ لِي ‏.‏ فَقَالَ ‏"‏ غَفَرَ اللَّهُ لَكُمْ ‏"‏ ‏.‏ ثُمَّ أَتَيْتُهُ مِنَ الشِّقِّ الآخَرِ أَرْجُو أَنْ يَخُصَّنِي دُونَهُمْ فَقُلْتُ يَا رَسُولَ اللَّهِ اسْتَغْفِرْ لِي ‏.‏ فَقَالَ بِيَدِهِ ‏"‏ غَفَرَ اللَّهُ لَكُمْ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ النَّاسِ يَا رَسُولَ اللَّهِ الْعَتَائِرُ وَالْفَرَائِعُ ‏.‏ قَالَ ‏"‏ مَنْ شَاءَ عَتَرَ وَمَنْ شَاءَ لَمْ يَعْتِرْ وَمَنْ شَاءَ فَرَّعَ وَمَنْ شَاءَ لَمْ يُفَرِّعْ فِي الْغَنَمِ أُضْحِيَتُهَا ‏"‏ ‏.‏ وَقَبَضَ أَصَابِعَهُ إِلاَّ وَاحِدَةً ‏.‏\hadithno{4226}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Yahya bin Zurarah bin Karim bin Al-Harith bin 'Amr Al-Bahili said:"I heard my father say, that he heard his grandfather Al-Harith bin 'Amr, that he met the Messenger of Allah during the Farewell Pilgrimage, when he was atop his slit-eared camel. (He said): 'I said: O Messenger of Allah, May my father and mother be ransomed for you; pray for forgiveness for me. He said: May Allah forgive you (plural). Then I came to him from the other side, hoping that he would supplicate just for me alone, and not them. I said: O Messenger of Allah, pray for forgiveness for me. He said: May Allah forgive you (plural). Then a man among the people said: O Messenger of Allah, (what about) the 'Atirah and Fara'? He said: Whoever wishes to offer and 'Atirah may do so, and whoever does not wish to, may not. Whoever wishes to offer a Fara' may do so, and whoever does not wish to, may not. And with regard to sheep, a sacrifice should be offered. And he clasped between his fingers except for one}}
\hadithdefcmd{nasai}{4227}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا عَفَّانُ، قَالَ حَدَّثَنَا يَحْيَى بْنُ زُرَارَةَ السَّهْمِيُّ، قَالَ حَدَّثَنِي أَبِي، عَنْ جَدِّهِ الْحَارِثِ بْنِ عَمْرٍو، ح وَأَنْبَأَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ، قَالَ حَدَّثَنِي يَحْيَى بْنُ زُرَارَةَ السَّهْمِيُّ، قَالَ حَدَّثَنِي أَبِي، عَنْ جَدِّهِ الْحَارِثِ بْنِ عَمْرٍو، أَنَّهُ لَقِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ فَقُلْتُ بِأَبِي أَنْتَ يَا رَسُولَ اللَّهِ وَأُمِّي اسْتَغْفِرْ لِي ‏.‏ فَقَالَ ‏ "‏ غَفَرَ اللَّهُ لَكُمْ ‏"‏ ‏.‏ وَهُوَ عَلَى نَاقَتِهِ الْعَضْبَاءِ ثُمَّ اسْتَدَرْتُ مِنَ الشِّقِّ الآخَرِ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{4227}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Yahya bin Zurarah As-Sahmi said:"My father narrated to me from his grandfather, Al-Harith bin 'Amr that he met the Messenger of Allah during the Farewell Pilgrimage and said: 'May my father and mother be sacrificed for you! O Messenger of Allah; pray for forgiveness for me.' He said: 'May Allah forgive you (plural).' He was atop his slit-eared camel and I came around to the other side"' and he quoted the Hadith}}
\hadithdefcmd{nasai}{4228}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، قَالَ حَدَّثَنَا جَمِيلٌ، عَنْ أَبِي الْمَلِيحِ، عَنْ نُبَيْشَةَ، قَالَ ذُكِرَ لِلنَّبِيِّ صلى الله عليه وسلم قَالَ كُنَّا نَعْتِرُ فِي الْجَاهِلِيَّةِ ‏.‏ قَالَ ‏ "‏ اذْبَحُوا لِلَّهِ عَزَّ وَجَلَّ فِي أَىِّ شَهْرٍ مَا كَانَ وَبَرُّوا اللَّهَ عَزَّ وَجَلَّ وَأَطْعِمُوا ‏"‏ ‏.‏\hadithno{4228}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Nubaishah said:"It was said to the prophet: 'During the Jahiliyyah we used to offer the 'Atirah.' He said: 'Slaughter for the sake of Allah, the Mighty and sublime, no matter what month it is; do good for the sake of Allah, the Mighty and sublime, and feed the poor}}
\hadithdefcmd{nasai}{4229}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا بِشْرٌ، - وَهُوَ ابْنُ الْمُفَضَّلِ - عَنْ خَالِدٍ، وَرُبَّمَا، قَالَ عَنْ أَبِي الْمَلِيحِ، وَرُبَّمَا، ذَكَرَ أَبَا قِلاَبَةَ عَنْ نُبَيْشَةَ، قَالَ نَادَى رَجُلٌ وَهُوَ بِمِنًى فَقَالَ يَا رَسُولَ اللَّهِ إِنَّا كُنَّا نَعْتِرُ عَتِيرَةً فِي الْجَاهِلِيَّةِ فِي رَجَبٍ فَمَا تَأْمُرُنَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ اذْبَحُوا فِي أَىِّ شَهْرٍ مَا كَانَ وَبَرُّوا اللَّهَ عَزَّ وَجَلَّ وَأَطْعِمُوا ‏"‏ ‏.‏ قَالَ إِنَّا كُنَّا نُفْرِعُ فَرَعًا فَمَا تَأْمُرُنَا قَالَ ‏"‏ فِي كُلِّ سَائِمَةٍ فَرَعٌ تَغْذُوهُ مَاشِيَتُكَ حَتَّى إِذَا اسْتَحْمَلَ ذَبَحْتَهُ وَتَصَدَّقْتَ بِلَحْمِهِ ‏"‏ ‏.‏\hadithno{4229}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Nubaishah said:"A man called out while he was in Mina and said: 'O Messenger of Allah, we used to sacrifice the 'Atirah during the Jahiliyyah in Rajab; what do you command us to do?' He said: 'Sacrifice during whatever month it is, do good for the sake of Allah, the Mighty and Sublime, and feed (the poor).' They said: 'O Messenger of Allah, we used to sacrifice the Fara' during the Jahiliyyah; what do you command us to do?' He said: 'For every flock of grazing animals, feed the firstborn as you feed the rest of you flock until it reaches an age where it could be used carry loads, then sacrifice it, and give its meat in charity}}
\hadithdefcmd{nasai}{4230}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمَلِيحِ، وَأَحْسَبُنِي، قَدْ سَمِعْتُهُ مِنَ أَبِي الْمَلِيحِ، عَنْ نُبَيْشَةَ، - رَجُلٌ مِنْ هُذَيْلٍ - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنِّي كُنْتُ نَهَيْتُكُمْ عَنْ لُحُومِ الأَضَاحِي فَوْقَ ثَلاَثٍ كَيْمَا تَسَعَكُمْ فَقَدْ جَاءَ اللَّهُ عَزَّ وَجَلَّ بِالْخَيْرِ فَكُلُوا وَتَصَدَّقُوا وَادَّخِرُوا وَإِنَّ هَذِهِ الأَيَّامَ أَيَّامُ أَكْلٍ وَشُرْبٍ وَذِكْرِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ إِنَّا كُنَّا نَعْتِرُ عَتِيرَةً فِي الْجَاهِلِيَّةِ فِي رَجَبٍ فَمَا تَأْمُرُنَا قَالَ ‏"‏ اذْبَحُوا لِلَّهِ عَزَّ وَجَلَّ فِي أَىِّ شَهْرٍ مَا كَانَ وَبَرُّوا اللَّهَ عَزَّ وَجَلَّ وَأَطْعِمُوا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ إِنَّا كُنَّا نُفَرِّعُ فَرَعًا فِي الْجَاهِلِيَّةِ فَمَا تَأْمُرُنَا قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فِي كُلِّ سَائِمَةٍ مِنَ الْغَنَمِ فَرَعٌ تَغْذُوهُ غَنَمُكَ حَتَّى إِذَا اسْتَحْمَلَ ذَبَحْتَهُ وَتَصَدَّقْتَ بِلَحْمِهِ عَلَى ابْنِ السَّبِيلِ فَإِنَّ ذَلِكَ هُوَ خَيْرٌ ‏"‏ ‏.‏\hadithno{4230}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Nubaishah, a man of Hudhail, that the Prophet said:"I used to forbid you to store the meat of the sacrifices for more than three days so that there would be enough for everyone. But now Allah, the mighty and sublime, has bestowed plenty upon us, so eat some, give some in charity and store some, For these days are the days of eating, drinking and remembering Allah." A man said: "O Messenger of Allah, we used to sacrifice the 'Atirah during the Jahiliyyah in Rajab; what do you command us to do?" He said: "Sacrifice to Allah, the Mighty and Sublime, whatever month it is, do good for the sake of Allah, the Mighty and Sublime, and feed (the poor)." He said: "O Messenger of Allah, we used to sacrifice the Fara' during the Jahiliyyah; what do you command us to do?" He said: "For every flock of grazing animals, feed the firstborn as you feed the rest of your flock, until it reaches an age where it could be used to carry loads, then sacrifice it, and give its meat in charity to the wayfarer, for that is good}}
\hadithdefcmd{nasai}{4231}{أَخْبَرَنَا أَبُو الأَشْعَثِ، أَحْمَدُ بْنُ الْمِقْدَامِ قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ أَنْبَأَنَا خَالِدٌ، عَنْ أَبِي الْمَلِيحِ، عَنْ نُبَيْشَةَ، قَالَ نَادَى النَّبِيَّ صلى الله عليه وسلم رَجُلٌ فَقَالَ إِنَّا كُنَّا نَعْتِرُ عَتِيرَةً يَعْنِي فِي الْجَاهِلِيَّةِ فِي رَجَبٍ فَمَا تَأْمُرُنَا قَالَ ‏"‏ اذْبَحُوهَا فِي أَىِّ شَهْرٍ كَانَ وَبَرُّوا اللَّهَ عَزَّ وَجَلَّ وَأَطْعِمُوا ‏"‏ ‏.‏ قَالَ إِنَّا كُنَّا نُفْرِعُ فَرَعًا فِي الْجَاهِلِيَّةِ ‏.‏ قَالَ ‏"‏ فِي كُلِّ سَائِمَةٍ فَرَعٌ حَتَّى إِذَا اسْتَحْمَلَ ذَبَحْتَهُ وَتَصَدَّقْتَ بِلَحْمِهِ فَإِنَّ ذَلِكَ هُوَ خُيْرٌ ‏"‏ ‏.‏\hadithno{4231}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Nubaishah said:"A man called out to the Prophet and said: 'We used to sacrifice the 'Atirah - i.e., during the Jahiliyyah - in Rajab; what do you command us to do?' He said: 'Sacrifice, whatever month it is, do good for the sake of Allah, the Mighty and Sublime, and feed (the poor).' He said: 'We used to sacrifice the Fara' during the Jahiliyyah; what do you command us to do?' He said: 'For every flock of grazing animals, feed the firstborn as you feed the rest of your flock until it reaches an age where it could be used to carry loads, then sacrifice it, and give its meat in charity, for that is good}}
\hadithdefcmd{nasai}{4232}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ عُلَيَّةَ، عَنْ خَالِدٍ، قَالَ حَدَّثَنِي أَبُو قِلاَبَةَ، عَنْ أَبِي الْمَلِيحِ، فَلَقِيتُ أَبَا الْمَلِيحِ فَسَأَلْتُهُ فَحَدَّثَنِي عَنْ نُبَيْشَةَ الْهُذَلِيِّ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ إِنَّا كُنَّا نَعْتِرُ عَتِيرَةً فِي الْجَاهِلِيَّةِ فَمَا تَأْمُرُنَا قَالَ ‏ "‏ اذْبَحُوا لِلَّهِ عَزَّ وَجَلَّ فِي أَىِّ شَهْرٍ مَا كَانَ وَبَرُّوا اللَّهَ عَزَّ وَجَلَّ وَأَطْعِمُوا ‏"‏ ‏.‏\hadithno{4232}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Nubaishah Al-Hudhaili said:"A man said: 'O Messenger of Allah, we used to sacrifice the 'Atirah during the Jahiliyyah in Rajab; what do you command us to do?' He said: 'Sacrifice to Allah, the Mighty and Sublime, whatever month it is, do good for the sake of Allah, the Mighty and Sublime, and feed (the poor)}}
\hadithdefcmd{nasai}{4233}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ وَكِيعِ بْنِ عُدُسٍ، عَنْ عَمِّهِ أَبِي رَزِينٍ، لَقِيطِ بْنِ عَامِرٍ الْعُقَيْلِيِّ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا كُنَّا نَذْبَحُ ذَبَائِحَ فِي الْجَاهِلِيَّةِ فِي رَجَبٍ فَنَأْكُلُ وَنُطْعِمُ مَنْ جَاءَنَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ بَأْسَ بِهِ ‏"‏ ‏.‏ قَالَ وَكِيعُ بْنُ عُدُسٍ فَلاَ أَدَعُهُ ‏.‏\hadithno{4233}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Razin Laqit bin 'Amir Al-Uqaili said:"I said: 'O Messenger of Allah, we used to offer sacrifices during the Jahiliyyah in Rajab, and eat of (their meat) and offer some to those who came to us.' The Messenger of Allah said: 'There is nothing wrong with that."' (One of the narrators) Waki bin 'Udus said: "I will not leave it}}
\hadithdefcmd{nasai}{4234}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ عَلَى شَاةٍ مَيِّتَةٍ مُلْقَاةٍ فَقَالَ ‏"‏ لِمَنْ هَذِهِ ‏"‏ ‏.‏ فَقَالُوا لِمَيْمُونَةَ ‏.‏ فَقَالَ ‏"‏ مَا عَلَيْهَا لَوِ انْتَفَعَتْ بِإِهَابِهَا ‏"‏ ‏.‏ قَالُوا إِنَّهَا مَيْتَةٌ ‏.‏ فَقَالَ ‏"‏ إِنَّمَا حَرَّمَ اللَّهُ عَزَّ وَجَلَّ أَكْلَهَا ‏"‏ ‏.‏\hadithno{4234}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Abbas, from Maimunah, that:the Prophet passed by a dead sheep that had been thrown aside. He said: "Who does this belong to?" They said: "Maimunah." He said: "Why did she not make use of its skin?" They said: "It is dead meat (i.e., it was not slaughtered properly)." He said: "Allah, the Mighty and Sublime, has only forbidden us to eat it}}
\hadithdefcmd{nasai}{4235}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَاةٍ مَيِّتَةٍ كَانَ أَعْطَاهَا مَوْلاَةً لِمَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ هَلاَّ انْتَفَعْتُمْ بِجِلْدِهَا ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ إِنَّهَا مَيْتَةٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا حُرِّمَ أَكْلُهَا ‏"‏ ‏.‏\hadithno{4235}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah passed by a dead sheep that he had given to a freed slave woman of Maimunah, the wife of the Prophet. He said: 'Why don't you make use of its hide?' They said: 'O Messenger of Allah, it is dead meat.' The Messenger of Allah said: 'It is only forbidden to eat it}}
\hadithdefcmd{nasai}{4236}{أَخْبَرَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ بْنِ سَعْدٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ جَدِّي، عَنِ ابْنِ أَبِي حَبِيبٍ، - يَعْنِي يَزِيدَ - عَنْ حَفْصِ بْنِ الْوَلِيدِ، عَنْ مُحَمَّدِ بْنِ مُسْلِمٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، حَدَّثَهُ أَنَّ ابْنَ عَبَّاسٍ حَدَّثَهُ قَالَ أَبْصَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَاةً مَيِّتَةً لِمَوْلاَةٍ لِمَيْمُونَةَ وَكَانَتْ مِنَ الصَّدَقَةِ فَقَالَ ‏"‏ لَوْ نَزَعُوا جِلْدَهَا فَانْتَفَعُوا بِهِ ‏"‏ ‏.‏ قَالُوا إِنَّهَا مَيْتَةٌ ‏.‏ قَالَ ‏"‏ إِنَّمَا حُرِّمَ أَكْلُهَا ‏"‏ ‏.‏\hadithno{4236}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Ibn'Abbas said:"The Messenger of Allah saw a dead sheep that belonged to the freed slave woman of Maimunah, and had come from the Sadaqah." He said: "Why don't you take off its hide and make use of it?" They said: "It is dead meat." He said: "It is only unlawful to eat it}}
\hadithdefcmd{nasai}{4237}{أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ الْقَطَّانُ الرَّقِّيُّ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، مُنْذُ حِينٍ عَنِ ابْنِ عَبَّاسٍ، أَخْبَرَتْنِي مَيْمُونَةُ، أَنَّ شَاةً، مَاتَتْ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَلاَّ دَفَعْتُمْ إِهَابَهَا فَاسْتَمْتَعْتُمْ بِهِ ‏"‏ ‏.‏\hadithno{4237}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn 'Abbas:"Maimunah told me that a sheep died, and the Prophet said: 'Why don't you tan its skin and make use of it'?}}
\hadithdefcmd{nasai}{4238}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، قَالَ مَرَّ النَّبِيُّ صلى الله عليه وسلم بِشَاةٍ لِمَيْمُونَةَ مَيِّتَةٍ فَقَالَ ‏ "‏ أَلاَّ أَخَذْتُمْ إِهَابَهَا فَدَبَغْتُمْ فَانْتَفَعْتُمْ ‏"‏ ‏.‏\hadithno{4238}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn 'Abbas said:"The Prophet passed by a sheep belonging to Maimunah that had died and said: 'Why don't you take its skin and tan it and make use of it'?}}
\hadithdefcmd{nasai}{4239}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، عَنْ جَرِيرٍ، عَنْ مُغِيرَةَ، عَنِ الشَّعْبِيِّ، قَالَ قَالَ ابْنُ عَبَّاسٍ مَرَّ النَّبِيُّ صلى الله عليه وسلم عَلَى شَاةٍ مَيِّتَةٍ فَقَالَ ‏ "‏ أَلاَّ انْتَفَعْتُمْ بِإِهَابِهَا ‏"‏ ‏.‏\hadithno{4239}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn 'Abbas said:"The Prophet passed by a dead sheep and said: 'Why don't you make use of its skin'?}}
\hadithdefcmd{nasai}{4240}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ بْنِ أَبِي رِزْمَةَ، قَالَ أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنْ سَوْدَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ مَاتَتْ شَاةٌ لَنَا فَدَبَغْنَا مَسْكَهَا فَمَازِلْنَا نَنْبِذُ فِيهَا حَتَّى صَارَتْ شَنًّا ‏.‏\hadithno{4240}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Sawdah, the wife of the Prophet, said:"A sheep of ours died, and we tanned its skin, and continued to make Nabidh in it until it wore out}}
\hadithdefcmd{nasai}{4241}{أَخْبَرَنَا قُتَيْبَةُ، وَعَلِيُّ بْنُ حُجْرٍ، عَنْ سُفْيَانَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنِ ابْنِ وَعْلَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا إِهَابٍ دُبِغَ فَقَدْ طَهُرَ ‏"‏ ‏.‏\hadithno{4241}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah said: 'Any skin that is tanned has been purified}}
\hadithdefcmd{nasai}{4242}{أَخْبَرَنِي الرَّبِيعُ بْنُ سُلَيْمَانَ بْنِ دَاوُدَ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ بَكْرٍ، - وَهُوَ ابْنُ مُضَرَ - قَالَ حَدَّثَنِي أَبِي، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، أَنَّهُ سَمِعَ أَبَا الْخَيْرِ، عَنِ ابْنِ وَعْلَةَ، أَنَّهُ سَأَلَ ابْنَ عَبَّاسٍ فَقَالَ إِنَّا نَغْزُو هَذَا الْمَغْرِبَ وَإِنَّهُمْ أَهْلُ وَثَنٍ وَلَهُمْ قِرَبٌ يَكُونُ فِيهَا اللَّبَنُ وَالْمَاءُ فَقَالَ ابْنُ عَبَّاسٍ الدِّبَاغُ طَهُورٌ ‏.‏ قَالَ ابْنُ وَعْلَةَ عَنْ رَأْيِكَ أَوْ شَىْءٍ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ بَلْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4242}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Wa'lah that he asked Ibn 'Abbas:"We are attacking the Maghrib, and they are people who worship idols, and they have waterskins in which they keep milk and water." Ibn 'Abbas said: "Tanning is purification." Ibn Wa'lah said: "Is this your own opinion, or something that you heard from the Messenger of Allah?" He said: "No, (I heard it) from the Messneger of Allah}}
\hadithdefcmd{nasai}{4243}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ جَوْنِ بْنِ قَتَادَةَ، عَنْ سَلَمَةَ بْنِ الْمُحَبِّقِ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ دَعَا بِمَاءٍ مِنْ عِنْدِ امْرَأَةٍ قَالَتْ مَا عِنْدِي إِلاَّ فِي قِرْبَةٍ لِي مَيْتَةٍ ‏.‏ قَالَ ‏"‏ أَلَيْسَ قَدْ دَبَغْتِهَا ‏"‏ ‏.‏ قَالَتْ بَلَى ‏.‏ قَالَ ‏"‏ فَإِنَّ دِبَاغَهَا ذَكَاتُهَا ‏"‏ ‏.‏\hadithno{4243}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Salamah bin Al-Muhabbaq that:during the campaign of Tabuk, the Prophet of Allah called for water from a woman. She said: "I only have a waterskin of mine made from an (unslaughtered) dead animal." He said: "Didn't you tan it?" She said: "Of course." He said: "Then it's tanning is its slaughter". (Daif)}}
\hadithdefcmd{nasai}{4244}{أَخْبَرَنَا الْحُسَيْنُ بْنُ مَنْصُورِ بْنِ جَعْفَرٍ النَّيْسَابُورِيُّ، قَالَ حَدَّثَنَا الْحُسَيْنُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنْ جُلُودِ الْمَيْتَةِ فَقَالَ ‏ "‏ دِبَاغُهَا طَهُورُهَا ‏"‏ ‏.‏\hadithno{4244}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Prophet was asked about the hides of dead animals." He said: "Tanning it purifies it}}
\hadithdefcmd{nasai}{4245}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا شَرِيكٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ جُلُودِ الْمَيْتَةِ فَقَالَ ‏ "‏ دِبَاغُهَا ذَكَاتُهَا ‏"‏ ‏.‏\hadithno{4245}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah was asked about the hides of dead animals." He said: "Tanning it purifies it}}
\hadithdefcmd{nasai}{4246}{أَخْبَرَنَا أَيُّوبُ بْنُ مُحَمَّدٍ الْوَزَّانُ، قَالَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ ذَكَاةُ الْمَيْتَةِ دِبَاغُهَا ‏"‏ ‏.‏\hadithno{4246}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Prophet said:"The dead animal is purified by tanning it}}
\hadithdefcmd{nasai}{4247}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا إِسْرَائِيلُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ذَكَاةُ الْمَيْتَةِ دِبَاغُهَا ‏"‏ ‏.‏\hadithno{4247}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Prophet said: 'The dead animal is purified by tanning it}}
\hadithdefcmd{nasai}{4248}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، وَاللَّيْثُ بْنُ سَعْدٍ، عَنْ كَثِيرِ بْنِ فَرْقَدٍ، أَنَّ عَبْدَ اللَّهِ بْنَ مَالِكِ بْنِ حُذَافَةَ، حَدَّثَهُ عَنِ الْعَالِيَةِ بِنْتِ سُبَيْعٍ، أَنَّ مَيْمُونَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم حَدَّثَتْهَا أَنَّهُ مَرَّ بِرَسُولِ اللَّهِ صلى الله عليه وسلم رِجَالٌ مِنْ قُرَيْشٍ يَجُرُّونَ شَاةً لَهُمْ مِثْلَ الْحِصَانِ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ أَخَذْتُمْ إِهَابَهَا ‏"‏ ‏.‏ قَالُوا إِنَّهَا مَيْتَةٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُطَهِّرُهَا الْمَاءُ وَالْقَرَظُ ‏"‏ ‏.‏\hadithno{4248}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Maimunah, the wife of the Prophet, that:some men of Quraish passed by the Messenger of Allah dragging a sheep the size of a donkey. He said to them: "Why don't you take its skin?" They said: "It is dead meat." The Messenger of Allah said: "Purify it with water and Qaraz}}
\hadithdefcmd{nasai}{4249}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ الْمُفَضَّلِ - قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عَبْدِ اللَّهِ بْنِ عُكَيْمٍ، قَالَ قُرِئَ عَلَيْنَا كِتَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا غُلاَمٌ شَابٌّ ‏ "‏ أَنْ لاَ تَنْتَفِعُوا مِنَ الْمَيْتَةِ بِإِهَابٍ وَلاَ عَصَبٍ ‏"‏ ‏.‏\hadithno{4249}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Ukaim said:"The letter of the Messenger of Allah was read to us when I was a young boy: 'Do not make use of the skins and sinew of dead animals}}
\hadithdefcmd{nasai}{4250}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَبْدِ اللَّهِ بْنِ عُكَيْمٍ، قَالَ كَتَبَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنْ لاَ تَسْتَمْتِعُوا مِنَ الْمَيْتَةِ بِإِهَابٍ وَلاَ عَصَبٍ ‏"‏ ‏.‏\hadithno{4250}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that'Abdullah bin 'Ukaim said:"The Messenger of Allah wrote to us: 'Do not make use of the skins and sinew of dead animals}}
\hadithdefcmd{nasai}{4251}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ هِلاَلٍ الْوَزَّانِ، عَنْ عَبْدِ اللَّهِ بْنِ عُكَيْمٍ، قَالَ كَتَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى جُهَيْنَةَ ‏ "‏ أَنْ لاَ تَنْتَفِعُوا مِنَ الْمَيْتَةِ بِإِهَابٍ وَلاَ عَصَبٍ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ أَصَحُّ مَا فِي هَذَا الْبَابِ فِي جُلُودِ الْمَيْتَةِ إِذَا دُبِغَتْ حَدِيثُ الزُّهْرِيِّ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ عَنِ ابْنِ عَبَّاسٍ عَنْ مَيْمُونَةَ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{4251}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Ukaim said:"The Messenger of Allah wrote to Juhainah: 'Do not make use of the skin and sinew of dead animals."' (Hasan) Abu 'Abdur-Rahman )An-Nasa'i) said: The most correct about this topic, regarding the skins of the dead animal when it is tanned, is the narration of Az-Zuhri, from 'Ubaidullah bin 'Abdullah, from Ibn 'Abbas, from Maimunah, and Allah knows best}}
\hadithdefcmd{nasai}{4252}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا بِشْرُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا مَالِكٌ، ح وَالْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ قُسَيْطٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ أَنْ يُسْتَمْتَعَ بِجُلُودِ الْمَيْتَةِ إِذَا دُبِغَتْ ‏.‏\hadithno{4252}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Aishah that:the Messenger of Allah ordered that the hides of dead animals be made use of if they had been tanned. (Daif)}}
\hadithdefcmd{nasai}{4253}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، عَنْ يَحْيَى، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي الْمَلِيحِ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ جُلُودِ السِّبَاعِ ‏.‏\hadithno{4253}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Al-Malih, from his father, that:the Prophet forbade (the use of) the hides of Predators. (Hassan)}}
\hadithdefcmd{nasai}{4254}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ بَحِيرٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْحَرِيرِ وَالذَّهَبِ وَمَيَاثِرِ النُّمُورِ ‏.‏\hadithno{4254}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Miqdam bin Ma di Karib said:"The Messenger of Allah forbade silk, gold and saddlecloths (Miyathir) made of leopard skin}}
\hadithdefcmd{nasai}{4255}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ بَحِيرٍ، عَنْ خَالِدٍ، قَالَ وَفَدَ الْمِقْدَامُ بْنُ مَعْدِيكَرِبَ عَلَى مُعَاوِيَةَ فَقَالَ لَهُ أَنْشُدُكَ بِاللَّهِ هَلْ تَعْلَمُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُبُوسِ جُلُودِ السِّبَاعِ وَالرُّكُوبِ عَلَيْهَا قَالَ نَعَمْ ‏.‏\hadithno{4255}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Khalid said:"Al-Miqdam bin Madikarib came to visit Muawiyah and said to him: I adjure you by Allah, do you know that the messenger of Allah forbade wearing the Hides of predators and riding on them? He said: 'yes}}
\hadithdefcmd{nasai}{4256}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ وَهُوَ بِمَكَّةَ يَقُولُ ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ وَرَسُولَهُ حَرَّمَ بَيْعَ الْخَمْرِ وَالْمَيْتَةِ وَالْخِنْزِيرِ وَالأَصْنَامِ ‏"‏ ‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ شُحُومَ الْمَيْتَةِ فَإِنَّهُ يُطْلَى بِهَا السُّفُنُ وَيُدَّهَنُ بِهَا الْجُلُودُ وَيَسْتَصْبِحُ بِهَا النَّاسُ ‏.‏ فَقَالَ ‏"‏ لاَ هُوَ حَرَامٌ ‏"‏ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ ذَلِكَ ‏"‏ قَاتَلَ اللَّهُ الْيَهُودَ إِنَّ اللَّهَ عَزَّ وَجَلَّ لَمَّا حَرَّمَ عَلَيْهِمُ الشُّحُومَ جَمَّلُوهُ ثُمَّ بَاعُوهُ فَأَكَلُوا ثَمَنَهُ ‏"‏ ‏.‏\hadithno{4256}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narraterd from Jabir bin 'Abdullah that, during the year of the Conquest, while he was in Makkah, he heard the Messenger of Allah say:"Allah, the Mighty and Sublime, and His Messenger have forbidden the sale of alcohol, dead meat, pigs and idols." It was said to him: "O Messenger of Allah, what do you think of their fat of dead animals, for it is used to caulk ships, it is daubed on animal skins, and people use it to light their lamps?" He said: "No, it is unlawful." Then the Messenger of Allah said: "May Allah, the Mighty and Sublime, curse the Jews, for Allah forbade them the fat (of dead animals) but they rendered it, sold it, and consumed its price}}
\hadithdefcmd{nasai}{4257}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أُبْلِغَ عُمَرُ أَنَّ سَمُرَةَ، بَاعَ خَمْرًا قَالَ قَاتَلَ اللَّهُ سَمُرَةَ أَلَمْ يَعْلَمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَاتَلَ اللَّهُ الْيَهُودَ حُرِّمَتْ عَلَيْهِمُ الشُّحُومُ فَجَمَّلُوهَا ‏"‏ ‏.‏ قَالَ سُفْيَانُ يَعْنِي أَذَابُوهَا ‏.‏\hadithno{4257}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn'Abbas said:"It reached 'Umar that Samurah had sold some wine, and he said: 'May Allah ruin Samurah! Does he not know that the Messenger of Allah said: May Allah curse the Jews, for animal fat was forbidden to them, but they rendered it.' Sufyan (one of the narrators) said: "Meaning: They melted it down}}
\hadithdefcmd{nasai}{4258}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، أَنَّ فَأْرَةً، وَقَعَتْ، فِي سَمْنٍ فَمَاتَتْ فَسُئِلَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَلْقُوهَا وَمَا حَوْلَهَا وَكُلُوهُ ‏"‏ ‏.‏\hadithno{4258}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Abbas, form Maimunah, that:a mouse fell into some cooking fat and died. The Prophet was asked (about that) and he said: "Throw it away, and whatever is around it, and eat (the rest)}}
\hadithdefcmd{nasai}{4259}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، وَمُحَمَّدُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ النَّيْسَابُورِيُّ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ عَنْ فَأْرَةٍ وَقَعَتْ فِي سَمْنٍ جَامِدٍ فَقَالَ ‏ "‏ خُذُوهَا وَمَا حَوْلَهَا فَأَلْقُوهُ ‏"‏ ‏.‏\hadithno{4259}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn' Abbas, from Maimunah, that:the Prophet was asked about a mouse that had fallen into some solid cooking fat. He said. "Take it, and whatever is around it, and throw it away}}
\hadithdefcmd{nasai}{4260}{أَخْبَرَنَا خُشَيْشُ بْنُ أَصْرَمَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ بُؤْذُويَةَ، أَنَّ مَعْمَرًا، ذَكَرَهُ عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ سُئِلَ عَنِ الْفَأْرَةِ تَقَعُ فِي السَّمْنِ فَقَالَ ‏ "‏ إِنْ كَانَ جَامِدًا فَأَلْقُوهَا وَمَا حَوْلَهَا وَإِنْ كَانَ مَائِعًا فَلاَ تَقْرَبُوهُ ‏"‏ ‏.‏\hadithno{4260}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn' Abbas, from Maimunah, that:the Prophet was asked about a mouse that fell into the cooking fat. He said: "If it (the fat) is solid, then throw it away, and whatever is around it. If it is liquid then do not use it at all."(Daif)}}
\hadithdefcmd{nasai}{4261}{أَخْبَرَنَا سَلَمَةُ بْنُ أَحْمَدَ بْنِ سُلَيْمِ بْنِ عُثْمَانَ الْفَوْزِيُّ، قَالَ حَدَّثَنَا جَدِّي الْخَطَّابُ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ حِمْيَرٍ، قَالَ حَدَّثَنَا ثَابِتُ بْنُ عَجْلاَنَ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، يَقُولُ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِعَنْزٍ مَيِّتَةٍ فَقَالَ ‏ "‏ مَا كَانَ عَلَى أَهْلِ هَذِهِ الشَّاةِ لَوِ انْتَفَعُوا بِإِهَابِهَا ‏"‏ ‏.‏\hadithno{4261}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ibn ' Abbas said:" I heard Sa'eed bin Jubair say: 'The Messenger of Allah passed by a dead goat and said: "Why didn't the owners of this sheep makes use of its skin?}}
\hadithdefcmd{nasai}{4262}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ خَالِدٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا وَقَعَ الذُّبَابُ فِي إِنَاءِ أَحَدِكُمْ فَلْيَمْقُلْهُ ‏"‏ ‏.‏\hadithno{4262}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that the Prophet said:"If a fly falls into the vessel of one of you, let him dip it in}}
