% Auto-generated chapter 36 for abudawud
% Hadiths in this chapter: 26

\hadithdefcmd{abudawud}{4214}{حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ مُطَرِّفٍ الرُّؤَاسِيُّ، حَدَّثَنَا عِيسَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَرَادَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَكْتُبَ إِلَى بَعْضِ الأَعَاجِمِ فَقِيلَ لَهُ إِنَّهُمْ لاَ يَقْرَءُونَ كِتَابًا إِلاَّ بِخَاتَمٍ فَاتَّخَذَ خَاتَمًا مِنْ فِضَّةٍ وَنَقَشَ فِيهِ ‏ "‏ مُحَمَّدٌ رَسُولُ اللَّهِ ‏"‏ ‏.‏\hadithno{4214}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5872)}\hadithtrans{Narrated Anas bin Malik:The Messenger of Allah (ﷺ) wanted to write to some persian rulers. He was told that they would not read a letter without a seal in the form of a silver ring on which he engraved "Muhammad the Messenger of Allah}}
\hadithdefcmd{abudawud}{4215}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، بِمَعْنَى حَدِيثِ عِيسَى بْنِ يُونُسَ زَادَ فَكَانَ فِي يَدِهِ حَتَّى قُبِضَ وَفِي يَدِ أَبِي بَكْرٍ حَتَّى قُبِضَ وَفِي يَدِ عُمَرَ حَتَّى قُبِضَ وَفِي يَدِ عُثْمَانَ فَبَيْنَمَا هُوَ عِنْدَ بِئْرٍ إِذْ سَقَطَ فِي الْبِئْرِ فَأَمَرَ بِهَا فَنُزِحَتْ فَلَمْ يُقْدَرْ عَلَيْهِ ‏.‏\hadithno{4215}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Anas through a different chain of narrators. This version as transmitted by 'Isa b. Yunus adds:It remained in his hand until he died, in the hand of 'Abu Bakr until he died, in the hand of 'Umar until he died, and in the hand of 'Uthman. When he was near a well, it fell down in it. He ordered to take it out, but it could not be found}}
\hadithdefcmd{abudawud}{4216}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَحْمَدُ بْنُ صَالِحٍ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي أَنَسٌ، قَالَ كَانَ خَاتَمُ النَّبِيِّ صلى الله عليه وسلم مِنْ وَرِقٍ فَصُّهُ حَبَشِيٌّ ‏.‏\hadithno{4216}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5868) Sahih Muslim (2094)}\hadithtrans{Narrated Anas:The signet-ring of the Prophet (ﷺ) was of silver with an Abyssinian stone}}
\hadithdefcmd{abudawud}{4217}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا حُمَيْدٌ الطَّوِيلُ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ خَاتَمُ النَّبِيِّ صلى الله عليه وسلم مِنْ فِضَّةٍ كُلُّهُ فَصُّهُ مِنْهُ ‏.‏\hadithno{4217}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas:The signet-ring of the Prophet (ﷺ) was all of silver as was also its stone}}
\hadithdefcmd{abudawud}{4218}{حَدَّثَنَا نُصَيْرُ بْنُ الْفَرَجِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ اتَّخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَاتَمًا مِنْ ذَهَبٍ وَجَعَلَ فَصَّهُ مِمَّا يَلِي بَطْنَ كَفِّهِ وَنَقَشَ فِيهِ ‏"‏ مُحَمَّدٌ رَسُولُ اللَّهِ ‏"‏ ‏.‏ فَاتَّخَذَ النَّاسُ خَوَاتِمَ الذَّهَبِ فَلَمَّا رَآهُمْ قَدِ اتَّخَذُوهَا رَمَى بِهِ وَقَالَ ‏"‏ لاَ أَلْبَسُهُ أَبَدًا ‏"‏ ‏.‏ ثُمَّ اتَّخَذَ خَاتَمًا مِنْ فِضَّةٍ نَقَشَ فِيهِ ‏"‏ مُحَمَّدٌ رَسُولُ اللَّهِ ‏"‏ ‏.‏ ثُمَّ لَبِسَ الْخَاتَمَ بَعْدَهُ أَبُو بَكْرٍ ثُمَّ لَبِسَهُ بَعْدَ أَبِي بَكْرٍ عُمَرُ ثُمَّ لَبِسَهُ بَعْدَهُ عُثْمَانُ حَتَّى وَقَعَ فِي بِئْرِ أَرِيسَ ‏.‏ قَالَ أَبُو دَاوُدَ وَلَمْ يَخْتَلِفِ النَّاسُ عَلَى عُثْمَانَ حَتَّى سَقَطَ الْخَاتَمُ مِنْ يَدِهِ ‏.‏\hadithno{4218}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5866) Sahih Muslim (2091)}\hadithtrans{Narrated Ibn 'Umar: The Messenger of Allah (ﷺ) took a signet-ring of gold, and put the stone next the palm of his hand. He engraved on it "Muhammad, the Messenger of Allah". The people then took signet-rings of gold. When he saw that they had taken them (like his ring) he threw it away and said: I shall never wear it. He then fashioned a silver ring and engraved on it "Muhammad, the Messenger of Allah". Then Abu Bakr wore it after him, then 'Umar wore it after Abu Bakr, and the 'Uthman wore it after 'Umar till it fell down in a well called Aris. Abu Dawud said: The people did not disagree on 'Uthman till the signet-rin fell down from his hand}}
\hadithdefcmd{abudawud}{4219}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، فِي هَذَا الْخَبَرِ عَنِ النَّبِيِّ صلى الله عليه وسلم فَنَقَشَ فِيهِ ‏"‏ مُحَمَّدٌ رَسُولُ اللَّهِ ‏"‏ ‏.‏ وَقَالَ ‏"‏ لاَ يَنْقُشْ أَحَدٌ عَلَى نَقْشِ خَاتَمِي هَذَا ‏"‏ ‏.‏ ثُمَّ سَاقَ الْحَدِيثَ ‏.‏\hadithno{4219}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2091)}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn 'Umar through a different chain of narrators from the Prophet (ﷺ). This version adds:He engraved on it "Muhammad, the Messenger of Allah." and said: "No one must engrave anything in the manner of this signet-ring of mine. He then transmitted the rest of the tradition}}
\hadithdefcmd{abudawud}{4220}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ الْمُغِيرَةِ بْنِ زِيَادٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، بِهَذَا الْخَبَرِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ فَالْتَمَسُوهُ فَلَمْ يَجِدُوهُ فَاتَّخَذَ عُثْمَانُ خَاتَمًا وَنَقَشَ فِيهِ ‏ "‏ مُحَمَّدٌ رَسُولُ اللَّهِ ‏"‏ ‏.‏ قَالَ فَكَانَ يَخْتِمُ بِهِ أَوْ يَتَخَتَّمُ بِهِ ‏.‏\hadithno{4220}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn 'Umar through different chain of narrators from the Prophet (ﷺ). This version adds:They searched for it but could not find it. 'Uthman then fashioned a signet-ring and engraved on it "Muhammad, the Messenger of Allah". He used to wear it or stamp with it}}
\hadithdefcmd{abudawud}{4221}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ، لُوَيْنٌ عَنْ إِبْرَاهِيمَ بْنِ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ رَأَى فِي يَدِ النَّبِيِّ صلى الله عليه وسلم خَاتَمًا مِنْ وَرِقٍ يَوْمًا وَاحِدًا فَصَنَعَ النَّاسُ فَلَبِسُوا وَطَرَحَ النَّبِيُّ صلى الله عليه وسلم فَطَرَحَ النَّاسُ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ عَنِ الزُّهْرِيِّ زِيَادُ بْنُ سَعْدٍ وَشُعَيْبٌ وَابْنُ مُسَافِرٍ كُلُّهُمْ قَالَ مِنْ وَرِقٍ ‏.‏\hadithno{4221}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2094) Sahih Muslim (5868)}\hadithtrans{Anas b. Malik said that he saw a silver signet-ring on the hand of the Prophet (ﷺ) only for a day. The people then fashioned and wore (rings). The Prophet (ﷺ) then threw it away and the people also threw (them.) Abu Dawud said:Ziyad b. Sa'd, Shu'aib and Ibn Musafir transmitted it from al-Zuhri. 'Ali said in their versions: "of silver}}
\hadithdefcmd{abudawud}{4222}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ الرُّكَيْنَ بْنَ الرَّبِيعِ، يُحَدِّثُ عَنِ الْقَاسِمِ بْنِ حَسَّانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حَرْمَلَةَ، أَنَّ ابْنَ مَسْعُودٍ، كَانَ يَقُولُ كَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم يَكْرَهُ عَشْرَ خِلاَلٍ الصُّفْرَةَ - يَعْنِي الْخَلُوقَ - وَتَغْيِيرَ الشَّيْبِ وَجَرَّ الإِزَارِ وَالتَّخَتُّمَ بِالذَّهَبِ وَالتَّبَرُّجَ بِالزِّينَةِ لِغَيْرِ مَحِلِّهَا وَالضَّرْبَ بِالْكِعَابِ وَالرُّقَى إِلاَّ بِالْمُعَوِّذَاتِ وَعَقْدَ التَّمَائِمِ وَعَزْلَ الْمَاءِ لِغَيْرِ أَوْ غَيْرِ مَحِلِّهِ أَوْ عَنْ مَحِلِّهِ وَفَسَادَ الصَّبِيِّ غَيْرَ مُحَرِّمِهِ ‏.‏ قَالَ أَبُو دَاوُدَ انْفَرَدَ بِإِسْنَادِ هَذَا الْحَدِيثِ أَهْلُ الْبَصْرَةِ وَاللَّهُ أَعْلَمُ ‏.‏\hadithno{4222}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Prophet of Allah (ﷺ) disliked ten things: Yellow colouring, meaning khaluq, dyeing grey hair, trailing the lower garment, wearing a gold signet-ring, a woman decking herself before people who are not within the prohibited degrees, throwing dice, using spells except with the Mu'awwidhatan, wearing amulets, withdrawing the penis before the semen is discharged, in the case of a woman who is wife or not a wife, and having intercourse with a woman who is suckling a child; but he did not declare them to be prohibited. Abu Dawud said: Only the transmitters of Basrah have transmitted this tradition}}
\hadithdefcmd{abudawud}{4223}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ بْنِ أَبِي رِزْمَةَ، - الْمَعْنَى - أَنَّ زَيْدَ بْنَ حُبَابٍ، أَخْبَرَهُمْ عَنْ عَبْدِ اللَّهِ بْنِ مُسْلِمٍ السُّلَمِيِّ الْمَرْوَزِيِّ أَبِي طَيْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَعَلَيْهِ خَاتَمٌ مِنْ شَبَهٍ فَقَالَ لَهُ ‏"‏ مَا لِي أَجِدُ مِنْكَ رِيحَ الأَصْنَامِ ‏"‏ ‏.‏ فَطَرَحَهُ ثُمَّ جَاءَ وَعَلَيْهِ خَاتَمٌ مِنْ حَدِيدٍ فَقَالَ ‏"‏ مَا لِي أَرَى عَلَيْكَ حِلْيَةَ أَهْلِ النَّارِ ‏"‏ ‏.‏ فَطَرَحَهُ فَقَالَ يَا رَسُولَ اللَّهِ مِنْ أَىِّ شَىْءٍ أَتَّخِذُهُ قَالَ ‏"‏ اتَّخِذْهُ مِنْ وَرِقٍ وَلاَ تُتِمَّهُ مِثْقَالاً ‏"‏ ‏.‏ وَلَمْ يَقُلْ مُحَمَّدٌ عَبْدِ اللَّهِ بْنِ مُسْلِمٍ ‏.‏ وَلَمْ يَقُلِ الْحَسَنُ السُّلَمِيِّ الْمَرْوَزِيِّ ‏.‏\hadithno{4223}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Buraydah ibn al-Hasib: A man came to the Prophet (ﷺ) and he was wearing a signet-ring of yellow copper. He said to him: How is it that I notice the odour of idols in you? So he threw it away, and came wearing an iron signet ring. He (the Prophet) said: What is it that I see you wearing the adornment of the inhabitants of Hell? So he threw it away. He asked: Messenger of Allah, what material I must use? He said: Make it of silver, but do not weigh it as much as a mithqal, The narrator Muhammad did not say: " 'Abd Allah b. Muslim," and al-Hasan did not say: "al-Sulami al-Marwazi}}
\hadithdefcmd{abudawud}{4224}{حَدَّثَنَا ابْنُ الْمُثَنَّى، وَزِيَادُ بْنُ يَحْيَى، وَالْحَسَنُ بْنُ عَلِيٍّ، قَالُوا حَدَّثَنَا سَهْلُ بْنُ حَمَّادٍ أَبُو عَتَّابٍ، حَدَّثَنَا أَبُو مَكِينٍ، نُوحُ بْنُ رَبِيعَةَ حَدَّثَنِي إِيَاسُ بْنُ الْحَارِثِ بْنِ الْمُعَيْقِيبِ، وَجَدُّهُ، مِنْ قِبَلِ أُمِّهِ أَبُو ذُبَابٍ عَنْ جَدِّهِ، قَالَ كَانَ خَاتَمُ النَّبِيِّ صلى الله عليه وسلم مِنْ حَدِيدٍ مَلْوِيٌّ عَلَيْهِ فِضَّةٌ ‏.‏ قَالَ فَرُبَّمَا كَانَ فِي يَدِهِ قَالَ وَكَانَ الْمُعَيْقِيبُ عَلَى خَاتَمِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{4224}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Iyas b. al-Harith b. al-Mu'aiqib quoting his grandfather said and his grandfather from his mother's side was Abu Dhubab:The signet-ring of the Prophet (ﷺ) was of iron polished with silver. Sometimes it remained in my possession. Al-Mu'ayqib was in charge of the signet-ring of the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{4225}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا عَاصِمُ بْنُ كُلَيْبٍ، عَنْ أَبِي بُرْدَةَ، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قُلِ اللَّهُمَّ اهْدِنِي وَسَدِّدْنِي وَاذْكُرْ بِالْهِدَايَةِ هِدَايَةَ الطَّرِيقِ وَاذْكُرْ بِالسَّدَادِ تَسْدِيدَكَ السَّهْمَ ‏"‏ ‏.‏ قَالَ وَنَهَانِي أَنْ أَضَعَ الْخَاتَمَ فِي هَذِهِ أَوْ فِي هَذِهِ لِلسَّبَّابَةِ وَالْوُسْطَى - شَكَّ عَاصِمٌ - وَنَهَانِي عَنِ الْقَسِّيَّةِ وَالْمِيثَرَةِ ‏.‏ قَالَ أَبُو بُرْدَةَ فَقُلْنَا لِعَلِيٍّ مَا الْقَسِّيَّةُ قَالَ ثِيَابٌ تَأْتِينَا مِنَ الشَّامِ أَوْ مِنْ مِصْرَ مُضَلَّعَةٌ فِيهَا أَمْثَالُ الأُتْرُجِّ قَالَ وَالْمِيثَرَةُ شَىْءٌ كَانَتْ تَصْنَعُهُ النِّسَاءُ لِبُعُولَتِهِنَّ ‏.‏\hadithno{4225}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2078 After 2095)}\hadithtrans{Narrated Ali:The Messenger of Allah (ﷺ) said to me: Say: O Allah, guide me, and set me right. Remember by guidance (hidayah) the showing of the straight path, and remember by setting right (sadad) the setting right of an arrow. Then pointing to the middle finger and the one next to it, he said: He forbade me to wear a signet-ring on this finger of mine or on this (Asim was doubtful). He forbade me to wear qassiyyah (qasi garments) and mitharah. Abu Burdah said: We asked 'Ali: What is qasiyyah ? He said: These are garments imported to us from Syria or Egypt. They are stripped and marked like citrons. And mitharah was a thing made by women for their husbands}}
\hadithdefcmd{abudawud}{4226}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ شَرِيكِ بْنِ أَبِي نَمِرٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، - رضى الله تعالى عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ شَرِيكٌ وَأَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَخَتَّمُ فِي يَمِينِهِ ‏.‏\hadithno{4226}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ali ibn AbuTalib: The Prophet (ﷺ) used to wear the signet-ring on his right hand}}
\hadithdefcmd{abudawud}{4227}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنِي أَبِي، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي رَوَّادٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَخَتَّمُ فِي يَسَارِهِ وَكَانَ فَصُّهُ فِي بَاطِنِ كَفِّهِ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ ابْنُ إِسْحَاقَ وَأُسَامَةَ - يَعْنِي ابْنَ زَيْدٍ - عَنْ نَافِعٍ بِإِسْنَادِهِ فِي يَمِينِهِ ‏.‏\hadithno{4227}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) used to wear the signet-ring on his left hand, and put its stone next the palm of his hand. Abu Dawud said: Ibn Ishaq and Usamah b. Zaid transmitted from Nafi': "On his right hand}}
\hadithdefcmd{abudawud}{4228}{حَدَّثَنَا هَنَّادٌ، عَنْ عَبْدَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، كَانَ يَلْبَسُ خَاتَمَهُ فِي يَدِهِ الْيُسْرَى ‏.‏\hadithno{4228}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Nafi' said that Ibn 'Umar used to wear his signet-ring on his left hand}}
\hadithdefcmd{abudawud}{4229}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، قَالَ رَأَيْتُ عَلَى الصَّلْتِ بْنِ عَبْدِ اللَّهِ بْنِ نَوْفَلِ بْنِ عَبْدِ الْمُطَّلِبِ خَاتَمًا فِي خِنْصَرِهِ الْيُمْنَى فَقُلْتُ مَا هَذَا قَالَ رَأَيْتُ ابْنَ عَبَّاسٍ يَلْبَسُ خَاتَمَهُ هَكَذَا وَجَعَلَ فَصَّهُ عَلَى ظَهْرِهَا ‏.‏ قَالَ وَلاَ يَخَالُ ابْنَ عَبَّاسٍ إِلاَّ قَدْ كَانَ يَذْكُرُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَلْبَسُ خَاتَمَهُ كَذَلِكَ ‏.‏\hadithno{4229}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Muhammad ibn Ishaq said:I saw as-Salt ibn Abdullah ibn Nawfal ibn AbdulMuttalib wearing the signet-ring on his right small finger. I asked: What is this? He replied: I saw Ibn Abbas wearing his ring in this manner. He put its stone towards the upper part of his palm. Ibn Abbas also mentioned that the Messenger of Allah (ﷺ) used to wear his signet-ring in his manner}}
\hadithdefcmd{abudawud}{4230}{حَدَّثَنَا عَلِيُّ بْنُ سَهْلٍ، وَإِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالاَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي عُمَرُ بْنُ حَفْصٍ، أَنَّ عَامِرَ بْنَ عَبْدِ اللَّهِ، - قَالَ عَلِيُّ بْنُ سَهْلٍ ابْنِ الزُّبَيْرِ - أَخْبَرَهُ أَنَّ مَوْلاَةً لَهُمْ ذَهَبَتْ بِابْنَةِ الزُّبَيْرِ إِلَى عُمَرَ بْنِ الْخَطَّابِ وَفِي رِجْلِهَا أَجْرَاسٌ فَقَطَعَهَا عُمَرُ ثُمَّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ مَعَ كُلِّ جَرَسٍ شَيْطَانًا ‏"‏ ‏.‏\hadithno{4230}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn az-Zubayr told that a woman client of theirs took az-Zubayr's daughter to Umar ibn al-Khattab wearing bells on her legs. Umar cut them off and said that he had heard the Messenger of Allah (ﷺ) say:There is a devil along with each bell}}
\hadithdefcmd{abudawud}{4231}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ بُنَانَةَ، مَوْلاَةِ عَبْدِ الرَّحْمَنِ بْنِ حَسَّانَ الأَنْصَارِيِّ عَنْ عَائِشَةَ، قَالَتْ بَيْنَمَا هِيَ عِنْدَهَا إِذْ دُخِلَ عَلَيْهَا بِجَارِيَةٍ وَعَلَيْهَا جَلاَجِلُ يُصَوِّتْنَ فَقَالَتْ لاَ تُدْخِلْنَهَا عَلَىَّ إِلاَّ أَنْ تَقْطَعُوا جَلاَجِلَهَا وَقَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ جَرَسٌ ‏"‏ ‏.‏\hadithno{4231}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Bunanah, female client of 'Abd al-Rahman b. Hayyan al-Ansari told that when she was with 'Aishah a girl wearing little tinkling bells was brought in to her. She ordered that they were not to bring her in where she was unless they cut off her little bells. She said:I heard the Messenger of Allah (ﷺ) say: The angels do not enter a house in which there is a bell}}
\hadithdefcmd{abudawud}{4232}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ الْخُزَاعِيُّ، - الْمَعْنَى - قَالاَ حَدَّثَنَا أَبُو الأَشْهَبِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ طَرَفَةَ، أَنَّ جَدَّهُ، عَرْفَجَةَ بْنَ أَسْعَدَ قُطِعَ أَنْفُهُ يَوْمَ الْكُلاَبِ فَاتَّخَذَ أَنْفًا مِنْ وَرِقٍ فَأَنْتَنَ عَلَيْهِ فَأَمَرَهُ النَّبِيُّ صلى الله عليه وسلم فَاتَّخَذَ أَنْفًا مِنْ ذَهَبٍ ‏.‏\hadithno{4232}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{AbdurRahman ibn Tarafah said that his grandfather Arfajah ibn As'ad who had his nose cut off at the battle of al-Kilab got a silver nose, but it developed a stench, so the Prophet (ﷺ) ordered him to get a gold nose}}
\hadithdefcmd{abudawud}{4233}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، وَأَبُو عَاصِمٍ قَالاَ حَدَّثَنَا أَبُو الأَشْهَبِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ طَرَفَةَ، عَنْ عَرْفَجَةَ بْنِ أَسْعَدَ، بِمَعْنَاهُ ‏.‏ قَالَ يَزِيدُ قُلْتُ لأَبِي الأَشْهَبِ أَدْرَكَ عَبْدُ الرَّحْمَنِ بْنُ طَرَفَةَ جَدَّهُ عَرْفَجَةَ قَالَ نَعَمْ ‏.‏\hadithno{4233}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above (No. 4220) has also been transmitted by Arfajah ibn As'ad through a different chain to the same effect. Yazid said:I asked AbulAshhab: Did AbdurRahman ibn Tarafah meet his grandfather Arfajah? He replied: Yes}}
\hadithdefcmd{abudawud}{4234}{حَدَّثَنَا مُؤَمَّلُ بْنُ هِشَامٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَبِي الأَشْهَبِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ طَرَفَةَ بْنِ عَرْفَجَةَ بْنِ أَسْعَدَ، عَنْ أَبِيهِ، أَنَّ عَرْفَجَةَ، بِمَعْنَاهُ ‏.‏\hadithno{4234}\hadithgrade{Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by 'Arfajah through a different chain of narrators to the same effect}}
\hadithdefcmd{abudawud}{4235}{حَدَّثَنَا ابْنُ نُفَيْلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، قَالَ حَدَّثَنِي يَحْيَى بْنُ عَبَّادٍ، عَنْ أَبِيهِ، عَبَّادِ بْنِ عَبْدِ اللَّهِ عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ قَدِمَتْ عَلَى النَّبِيِّ صلى الله عليه وسلم حِلْيَةٌ مِنْ عِنْدِ النَّجَاشِيِّ أَهْدَاهَا لَهُ فِيهَا خَاتَمٌ مِنْ ذَهَبٍ فِيهِ فَصٌّ حَبَشِيٌّ - قَالَتْ - فَأَخَذَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِعُودٍ مُعْرِضًا عَنْهُ أَوْ بِبَعْضِ أَصَابِعِهِ ثُمَّ دَعَى أُمَامَةَ ابْنَةَ أَبِي الْعَاصِ ابْنَةَ ابْنَتِهِ زَيْنَبَ فَقَالَ ‏ "‏ تَحَلَّىْ بِهَذَا يَا بُنَيَّةُ ‏"‏ ‏.‏\hadithno{4235}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) got some ornaments presented by Negus as a gift to him. They contained a gold ring with an Abyssinian stone. The Messenger of Allah (ﷺ) turning his attention from it took it by means of a stick or his finger, then called Umamah, daughter of Abul'As and daughter of his daughter Zaynab, and said: Wear it, my dear daughter}}
\hadithdefcmd{abudawud}{4236}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ أَسِيدِ بْنِ أَبِي أَسِيدٍ الْبَرَّادِ، عَنْ نَافِعِ بْنِ عَيَّاشٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَحَبَّ أَنْ يُحَلِّقَ حَبِيبَهُ حَلْقَةً مِنْ نَارٍ فَلْيُحَلِّقْهُ حَلْقَةً مِنْ ذَهَبٍ وَمَنْ أَحَبَّ أَنْ يُطَوِّقَ حَبِيبَهُ طَوْقًا مِنْ نَارٍ فَلْيُطَوِّقْهُ طَوْقًا مِنْ ذَهَبٍ وَمَنْ أَحَبَّ أَنْ يُسَوِّرَ حَبِيبَهُ سِوَارًا مِنْ نَارٍ فَلْيُسَوِّرْهُ سِوَارًا مِنْ ذَهَبٍ وَلَكِنْ عَلَيْكُمْ بِالْفِضَّةِ فَالْعَبُوا بِهَا ‏"‏ ‏.‏\hadithno{4236}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone wants to put a ring of fire on one he loves, let him put a gold ring on him: if anyone wants to put a necklace of fire on one he loves, let him put a gold necklace on him, and if anyone wants to put a bracelet of fire on one he loves let him put a gold bracelet on him. Keep to silver and amuse yourselves with it}}
\hadithdefcmd{abudawud}{4237}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنِ امْرَأَتِهِ، عَنْ أُخْتٍ، لِحُذَيْفَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَا مَعْشَرَ النِّسَاءِ أَمَا لَكُنَّ فِي الْفِضَّةِ مَا تَحَلَّيْنَ بِهِ أَمَا إِنَّهُ لَيْسَ مِنْكُنَّ امْرَأَةٌ تَحَلَّى ذَهَبًا تُظْهِرُهُ إِلاَّ عُذِّبَتْ بِهِ ‏"‏ ‏.‏\hadithno{4237}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated A sister of Hudhayfah: The Prophet (ﷺ) as saying : You women folk, have in silver something with which you adorn yourselves. I assure you that any woman of you who adorns herself with gold which she displays will be punished for it}}
\hadithdefcmd{abudawud}{4238}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ بْنُ يَزِيدَ الْعَطَّارُ، حَدَّثَنَا يَحْيَى، أَنَّ مَحْمُودَ بْنَ عَمْرٍو الأَنْصَارِيَّ، حَدَّثَهُ أَنَّ أَسْمَاءَ بِنْتَ يَزِيدَ حَدَّثَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا امْرَأَةٍ تَقَلَّدَتْ قِلاَدَةً مِنْ ذَهَبٍ قُلِّدَتْ فِي عُنُقِهَا مِثْلَهُ مِنَ النَّارِ يَوْمَ الْقِيَامَةِ وَأَيُّمَا امْرَأَةٍ جَعَلَتْ فِي أُذُنِهَا خُرْصًا مِنْ ذَهَبٍ جُعِلَ فِي أُذُنِهَا مِثْلُهُ مِنَ النَّارِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4238}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Asma' daughter of Yazid: The Prophet (ﷺ) as saying: Any woman who wears a gold necklace will have a similar one of fire put on her neck on the Day of Resurrection, and any woman who puts a gold earring in her ear will have a similar one of fire put in her ear on the Day of Resurrection}}
\hadithdefcmd{abudawud}{4239}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا خَالِدٌ، عَنْ مَيْمُونٍ الْقَنَّادِ، عَنْ أَبِي قِلاَبَةَ، عَنْ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ رُكُوبِ النِّمَارِ وَعَنْ لُبْسِ الذَّهَبِ إِلاَّ مُقَطَّعًا ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو قِلاَبَةَ لَمْ يَلْقَ مُعَاوِيَةَ ‏.‏\hadithno{4239}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Mu'awiyah ibn AbuSufyan: The Messenger of Allah (ﷺ) forbade to ride on panther skins and to wear gold except a little. Abu Dawud said: The narrator Abu Qilabah did not meet Mu'awiyah}}
