% Auto-generated chapter 82 for bukhari
% Hadiths in this chapter: 26

\hadithdefcmd{bukhari}{6594}{حَدَّثَنَا أَبُو الْوَلِيدِ، هِشَامُ بْنُ عَبْدِ الْمَلِكِ حَدَّثَنَا شُعْبَةُ، أَنْبَأَنِي سُلَيْمَانُ الأَعْمَشُ، قَالَ سَمِعْتُ زَيْدَ بْنَ وَهْبٍ، عَنْ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهْوَ الصَّادِقُ الْمَصْدُوقُ قَالَ ‏ "‏ إِنَّ أَحَدَكُمْ يُجْمَعُ فِي بَطْنِ أُمِّهِ أَرْبَعِينَ يَوْمًا، ثُمَّ عَلَقَةً مِثْلَ ذَلِكَ، ثُمَّ يَكُونُ مُضْغَةً مِثْلَ ذَلِكَ، ثُمَّ يَبْعَثُ اللَّهُ مَلَكًا فَيُؤْمَرُ بِأَرْبَعٍ بِرِزْقِهِ، وَأَجَلِهِ، وَشَقِيٌّ، أَوْ سَعِيدٌ، فَوَاللَّهِ إِنَّ أَحَدَكُمْ ـ أَوِ الرَّجُلَ ـ يَعْمَلُ بِعَمَلِ أَهْلِ النَّارِ، حَتَّى مَا يَكُونُ بَيْنَهُ وَبَيْنَهَا غَيْرُ بَاعٍ أَوْ ذِرَاعٍ، فَيَسْبِقُ عَلَيْهِ الْكِتَابُ، فَيَعْمَلُ بِعَمَلِ أَهْلِ الْجَنَّةِ، فَيَدْخُلُهَا، وَإِنَّ الرَّجُلَ لَيَعْمَلُ بِعَمَلِ أَهْلِ الْجَنَّةِ، حَتَّى مَا يَكُونُ بَيْنَهُ وَبَيْنَهَا غَيْرُ ذِرَاعٍ أَوْ ذِرَاعَيْنِ، فَيَسْبِقُ عَلَيْهِ الْكِتَابُ، فَيَعْمَلُ بِعَمَلِ أَهْلِ النَّارِ، فَيَدْخُلُهَا ‏"‏‏.‏ قَالَ آدَمُ إِلاَّ ذِرَاعٌ‏.‏\hadithno{6594}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ), the truthful and truly-inspired, said, "Each one of you collected in the womb of his mother for forty days, and then turns into a clot for an equal period (of forty days) and turns into a piece of flesh for a similar period (of forty days) and then Allah sends an angel and orders him to write four things, i.e., his provision, his age, and whether he will be of the wretched or the blessed (in the Hereafter). Then the soul is breathed into him. And by Allah, a person among you (or a man) may do deeds of the people of the Fire till there is only a cubit or an arm-breadth distance between him and the Fire, but then that writing (which Allah has ordered the angel to write) precedes, and he does the deeds of the people of Paradise and enters it; and a man may do the deeds of the people of Paradise till there is only a cubit or two between him and Paradise, and then that writing precedes and he does the deeds of the people of the Fire and enters it}}
\hadithdefcmd{bukhari}{6595}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ وَكَّلَ اللَّهُ بِالرَّحِمِ مَلَكًا فَيَقُولُ أَىْ رَبِّ نُطْفَةٌ، أَىْ رَبِّ عَلَقَةٌ، أَىْ رَبِّ مُضْغَةٌ‏.‏ فَإِذَا أَرَادَ اللَّهُ أَنْ يَقْضِيَ خَلْقَهَا قَالَ أَىْ رَبِّ ذَكَرٌ أَمْ أُنْثَى أَشَقِيٌّ أَمْ سَعِيدٌ فَمَا الرِّزْقُ فَمَا الأَجَلُ فَيُكْتَبُ كَذَلِكَ فِي بَطْنِ أُمِّهِ ‏"‏‏.‏\hadithno{6595}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "Allah puts an angel in charge of the uterus and the angel says, 'O Lord, (it is) semen! O Lord, (it is now ) a clot! O Lord, (it is now) a piece of flesh.' And then, if Allah wishes to complete its creation, the angel asks, 'O Lord, (will it be) a male or a female? A wretched (an evil doer) or a blessed (doer of good)? How much will his provisions be? What will his age be?' So all that is written while the creature is still in the mother's womb}}
\hadithdefcmd{bukhari}{6596}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا يَزِيدُ الرِّشْكُ، قَالَ سَمِعْتُ مُطَرِّفَ بْنَ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، يُحَدِّثُ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَيُعْرَفُ أَهْلُ الْجَنَّةِ مِنْ أَهْلِ النَّارِ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ قَالَ فَلِمَ يَعْمَلُ الْعَامِلُونَ قَالَ ‏"‏كُلٌّ يَعْمَلُ لِمَا خُلِقَ لَهُ ـ أَوْ لِمَا يُسِّرَ لَهُ‏"‏ ‏.‏\hadithno{6596}\hadithtrans{Narrated `Imran bin Husain:A man said, "O Allah's Messenger (ﷺ)! Can the people of Paradise be known (differentiated) from the people of the Fire; The Prophet (ﷺ) replied, "Yes." The man said, "Why do people (try to) do (good) deeds?" The Prophet said, "Everyone will do the deeds for which he has been created to do or he will do those deeds which will be made easy for him to do." (i.e. everybody will find easy to do such deeds as will lead him to his destined place for which he has been created)}}
\hadithdefcmd{bukhari}{6597}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنْ أَوْلاَدِ الْمُشْرِكِينَ فَقَالَ ‏ "‏ اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏"‏‏.‏\hadithno{6597}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) ; was asked about the offspring of the pagans. He said, "Allah knows what they would have done (were they to live)}}
\hadithdefcmd{bukhari}{6598}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ وَأَخْبَرَنِي عَطَاءُ بْنُ يَزِيدَ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ذَرَارِيِّ الْمُشْرِكِينَ فَقَالَ ‏\{‏اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ ‏\}‏\hadithno{6598}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) was asked about the offspring of the pagans. He said, "Allah knows what they would have done (were they to live)}}
\hadithdefcmd{bukhari}{6600}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ مَوْلُودٍ إِلاَّ يُولَدُ عَلَى الْفِطْرَةِ، فَأَبَوَاهُ يُهَوِّدَانِهِ وَيُنَصِّرَانِهِ، كَمَا تُنْتِجُونَ الْبَهِيمَةَ، هَلْ تَجِدُونَ فِيهَا مِنْ جَدْعَاءَ حَتَّى تَكُونُوا أَنْتُمْ تَجْدَعُونَهَا ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَفَرَأَيْتَ مَنْ يَمُوتُ وَهْوَ صَغِيرٌ قَالَ ‏\{‏اللَّهُ أَعْلَمُ بِمَا كَانُوا عَامِلِينَ‏\}‏\hadithno{6600}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "No child is born but has the Islamic Faith, but its parents turn it into a Jew or a Christian. It is as you help the animals give birth. Do you find among their offspring a mutilated one before you mutilate them yourself?" The people said, "O Allah's Messenger (ﷺ)! What do you think about those (of them) who die young?" The Prophet (ﷺ) said, "Allah knows what they would have done (were they to live)}}
\hadithdefcmd{bukhari}{6601}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَسْأَلِ الْمَرْأَةُ طَلاَقَ أُخْتِهَا لِتَسْتَفْرِغَ صَحْفَتَهَا، وَلْتَنْكِحْ، فَإِنَّ لَهَا مَا قُدِّرَ لَهَا ‏"‏‏.‏\hadithno{6601}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "No woman should ask for the divorce of her sister (Muslim) so as to take her place, but she should marry the man (without compelling him to divorce his other wife), for she will have nothing but what Allah has written for her}}
\hadithdefcmd{bukhari}{6602}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ عَاصِمٍ، عَنْ أَبِي عُثْمَانَ، عَنْ أُسَامَةَ، قَالَ كُنْتُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم إِذْ جَاءَهُ رَسُولُ إِحْدَى بَنَاتِهِ وَعِنْدَهُ سَعْدٌ وَأُبَىُّ بْنُ كَعْبٍ وَمُعَاذٌ أَنَّ ابْنَهَا يَجُودُ بِنَفْسِهِ‏.‏ فَبَعَثَ إِلَيْهَا ‏ "‏ لِلَّهِ مَا أَخَذَ، وَلِلَّهِ مَا أَعْطَى، كُلٌّ بِأَجَلٍ، فَلْتَصْبِرْ وَلْتَحْتَسِبْ ‏"‏‏.‏\hadithno{6602}\hadithtrans{Narrated Usama:Once while I was with the Prophet (ﷺ) and Sa`d, Ubai bin Ka`b and Mu`adh were also sitting with him, there came to him a messenger from one of his daughters, telling him that her child was on the verge of death. The Prophet (ﷺ) told the messenger to tell her, "It is for Allah what He takes, and it is for Allah what He gives, and everything has its fixed time (limit). So (she should) be patient and look for Allah's reward}}
\hadithdefcmd{bukhari}{6603}{حَدَّثَنَا حِبَّانُ بْنُ مُوسَى، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ مُحَيْرِيزٍ الْجُمَحِيُّ، أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ، أَخْبَرَهُ أَنَّهُ، بَيْنَمَا هُوَ جَالِسٌ عِنْدَ النَّبِيِّ صلى الله عليه وسلم جَاءَ رَجُلٌ مِنِ الأَنْصَارِ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّا نُصِيبُ سَبْيًا وَنُحِبُّ الْمَالَ، كَيْفَ تَرَى فِي الْعَزْلِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوَإِنَّكُمْ تَفْعَلُونَ ذَلِكَ، لاَ عَلَيْكُمْ أَنْ لاَ تَفْعَلُوا، فَإِنَّهُ لَيْسَتْ نَسَمَةٌ كَتَبَ اللَّهُ أَنْ تَخْرُجَ إِلاَّ هِيَ كَائِنَةٌ ‏"‏‏.‏\hadithno{6603}\hadithtrans{Narrated Abu Sa`id Al-Khudri:That while he was sitting with the Prophet (ﷺ) a man from the Ansar came and said, "O Allah's Messenger (ﷺ)! We get slave girls from the war captives and we love property; what do you think about coitus interruptus?" Allah's Messenger (ﷺ) said, "Do you do that? It is better for you not to do it, for there is no soul which Allah has ordained to come into existence but will be created}}
\hadithdefcmd{bukhari}{6604}{حَدَّثَنَا مُوسَى بْنُ مَسْعُودٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ ـ رضى الله عنه ـ قَالَ لَقَدْ خَطَبَنَا النَّبِيُّ صلى الله عليه وسلم خُطْبَةً، مَا تَرَكَ فِيهَا شَيْئًا إِلَى قِيَامِ السَّاعَةِ إِلاَّ ذَكَرَهُ، عَلِمَهُ مَنْ عَلِمَهُ، وَجَهِلَهُ مَنْ جَهِلَهُ، إِنْ كُنْتُ لأَرَى الشَّىْءَ قَدْ نَسِيتُ، فَأَعْرِفُ مَا يَعْرِفُ الرَّجُلُ إِذَا غَابَ عَنْهُ فَرَآهُ فَعَرَفَهُ‏.‏\hadithno{6604}\hadithtrans{Narrated Hudhaifa:The Prophet (ﷺ) once delivered a speech in front of us wherein he left nothing but mentioned (about) everything that would happen till the Hour. Some of us stored that our minds and some forgot it. (After that speech) I used to see events taking place (which had been referred to in that speech) but I had forgotten them (before their occurrence). Then I would recognize such events as a man recognizes another man who has been absent and then sees and recognizes him}}
\hadithdefcmd{bukhari}{6605}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ كُنَّا جُلُوسًا مَعَ النَّبِيِّ صلى الله عليه وسلم وَمَعَهُ عُودٌ يَنْكُتُ فِي الأَرْضِ وَقَالَ ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ إِلاَّ قَدْ كُتِبَ مَقْعَدُهُ مِنَ النَّارِ أَوْ مِنَ الْجَنَّةِ ‏"‏‏.‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ أَلاَ نَتَّكِلُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لاَ اعْمَلُوا فَكُلٌّ مُيَسَّرٌ ‏"‏ ثُمَّ قَرَأَ ‏\{‏فَأَمَّا مَنْ أَعْطَى وَاتَّقَى‏\}‏ الآيَةَ‏.‏\hadithno{6605}\hadithtrans{Narrated `Ali:While we were sitting with the Prophet (ﷺ) who had a stick with which he was scraping the earth, he lowered his head and said, "There is none of you but has his place assigned either in the Fire or in Paradise." Thereupon a man from the people said, "Shall we not depend upon this, O Allah's Apostle?" The Prophet (ﷺ) said, "No, but carry on and do your deeds, for everybody finds it easy to do such deeds (as will lead him to his place)." The Prophet (ﷺ) then recited the Verse: 'As for him who gives (in charity) and keeps his duty to Allah}}
\hadithdefcmd{bukhari}{6606}{حَدَّثَنَا حِبَّانُ بْنُ مُوسَى، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ شَهِدْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم خَيْبَرَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِرَجُلٍ مِمَّنْ مَعَهُ يَدَّعِي الإِسْلاَمَ ‏"‏ هَذَا مِنْ أَهْلِ النَّارِ ‏"‏‏.‏ فَلَمَّا حَضَرَ الْقِتَالُ قَاتَلَ الرَّجُلُ مِنْ أَشَدِّ الْقِتَالِ، وَكَثُرَتْ بِهِ الْجِرَاحُ فَأَثْبَتَتْهُ، فَجَاءَ رَجُلٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ الَّذِي تَحَدَّثْتَ أَنَّهُ مِنْ أَهْلِ النَّارِ قَدْ قَاتَلَ فِي سَبِيلِ اللَّهِ مِنْ أَشَدِّ الْقِتَالِ، فَكَثُرَتْ بِهِ الْجِرَاحُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَمَا إِنَّهُ مِنْ أَهْلِ النَّارِ ‏"‏‏.‏ فَكَادَ بَعْضُ الْمُسْلِمِينَ يَرْتَابُ فَبَيْنَمَا هُوَ عَلَى ذَلِكَ إِذْ وَجَدَ الرَّجُلُ أَلَمَ الْجِرَاحِ فَأَهْوَى بِيَدِهِ إِلَى كِنَانَتِهِ، فَانْتَزَعَ مِنْهَا سَهْمًا فَانْتَحَرَ بِهَا، فَاشْتَدَّ رِجَالٌ مِنَ الْمُسْلِمِينَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ صَدَّقَ اللَّهُ حَدِيثَكَ، قَدِ انْتَحَرَ فُلاَنٌ فَقَتَلَ نَفْسَهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا بِلاَلُ قُمْ فَأَذِّنْ، لاَ يَدْخُلُ الْجَنَّةَ إِلاَّ مُؤْمِنٌ، وَإِنَّ اللَّهَ لَيُؤَيِّدُ هَذَا الدِّينَ بِالرَّجُلِ الْفَاجِرِ ‏"‏‏.‏\hadithno{6606}\hadithtrans{Narrated Abu Huraira:We witnessed along with Allah's Messenger (ﷺ) the Khaibar (campaign). Allah's Messenger (ﷺ) told his companions about a man who claimed to be a Muslim, "This man is from the people of the Fire." When the battle started, the man fought very bravely and received a great number of wounds and got crippled. On that, a man from among the companions of the Prophet (ﷺ) came and said, "O Allah's Apostle! Do you know what the man you described as of the people of the Fire has done? He has fought very bravely for Allah's Cause and he has received many wounds." The Prophet (ﷺ) said, "But he is indeed one of the people of the Fire." Some of the Muslims were about to have some doubt about that statement. So while the man was in that state, the pain caused by the wounds troubled him so much that he put his hand into his quiver and took out an arrow and committed suicide with it. Off went some men from among the Muslims to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Allah has made your statement true. So-and-so has committed suicide." Allah's Messenger (ﷺ) said, "O Bilal! Get up and announce in public: None will enter Paradise but a believer, and Allah may support this religion (Islam) with a wicked man}}
\hadithdefcmd{bukhari}{6607}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلٍ، أَنَّ رَجُلاً، مِنْ أَعْظَمِ الْمُسْلِمِينَ غَنَاءً عَنِ الْمُسْلِمِينَ فِي غَزْوَةٍ غَزَاهَا مَعَ النَّبِيِّ صلى الله عليه وسلم فَنَظَرَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ مَنْ أَحَبَّ أَنْ يَنْظُرَ إِلَى الرَّجُلِ مِنْ أَهْلِ النَّارِ فَلْيَنْظُرْ إِلَى هَذَا ‏"‏‏.‏ فَاتَّبَعَهُ رَجُلٌ مِنَ الْقَوْمِ، وَهْوَ عَلَى تِلْكَ الْحَالِ مِنْ أَشَدِّ النَّاسِ عَلَى الْمُشْرِكِينَ، حَتَّى جُرِحَ فَاسْتَعْجَلَ الْمَوْتَ، فَجَعَلَ ذُبَابَةَ سَيْفِهِ بَيْنَ ثَدْيَيْهِ حَتَّى خَرَجَ مِنْ بَيْنِ كَتِفَيْهِ فَأَقْبَلَ الرَّجُلُ إِلَى النَّبِيِّ صلى الله عليه وسلم مُسْرِعًا فَقَالَ أَشْهَدُ أَنَّكَ رَسُولُ اللَّهِ‏.‏ فَقَالَ ‏"‏ وَمَا ذَاكَ ‏"‏‏.‏ قَالَ قُلْتَ لِفُلاَنٍ ‏"‏ مَنْ أَحَبَّ أَنْ يَنْظُرَ إِلَى رَجُلٍ مِنْ أَهْلِ النَّارِ فَلْيَنْظُرْ إِلَيْهِ ‏"‏‏.‏ وَكَانَ مِنْ أَعْظَمِنَا غَنَاءً عَنِ الْمُسْلِمِينَ، فَعَرَفْتُ أَنَّهُ لاَ يَمُوتُ عَلَى ذَلِكَ فَلَمَّا جُرِحَ اسْتَعْجَلَ الْمَوْتَ فَقَتَلَ نَفْسَهُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم عِنْدَ ذَلِكَ ‏"‏ إِنَّ الْعَبْدَ لَيَعْمَلُ عَمَلَ أَهْلِ النَّارِ، وَإِنَّهُ مِنْ أَهْلِ الْجَنَّةِ، وَيَعْمَلُ عَمَلَ أَهْلِ الْجَنَّةِ، وَإِنَّهُ مِنْ أَهْلِ النَّارِ، وَإِنَّمَا الأَعْمَالُ بِالْخَوَاتِيمِ ‏"‏‏.‏\hadithno{6607}\hadithtrans{Narrated Sahl bin Sa`d:There was a man who fought most bravely of all the Muslims on behalf of the Muslims in a battle (Ghazwa) in the company of the Prophet. The Prophet (ﷺ) looked at him and said. "If anyone would like to see a man from the people of the Fire, let him look at this (brave man)." On that, a man from the People (Muslims) followed him, and he was in that state i.e., fighting fiercely against the pagans till he was wounded, and then he hastened to end his life by placing his sword between his breasts (and pressed it with great force) till it came out between his shoulders. Then the man (who was watching that person) went quickly to the Prophet (ﷺ) and said, "I testify that you are Allah's Messenger (ﷺ)!" The Prophet (ﷺ) asked him, "Why do you say that?" He said, "You said about so-and-so, 'If anyone would like to see a man from the people of the Fire, he should look at him.' He fought most bravely of all of us on behalf of the Muslims and I knew that he would not die as a Muslim (Martyr). So when he got wounded, he hastened to die and committed suicide." There-upon the Prophet (ﷺ) said, "A man may do the deeds of the people of the Fire while in fact he is one of the people of Paradise, and he may do the deeds of the people of Paradise while in fact he belongs to the people of Fire, and verily, (the rewards of) the deeds are decided by the last actions (deeds)}}
\hadithdefcmd{bukhari}{6608}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ النَّذْرِ قَالَ ‏ "‏ إِنَّهُ لاَ يَرُدُّ شَيْئًا، وَإِنَّمَا يُسْتَخْرَجُ بِهِ مِنَ الْبَخِيلِ ‏"‏‏.‏\hadithno{6608}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) forbade vowing and said, "In fact, vowing does not prevent anything, but it makes a miser to spend his property}}
\hadithdefcmd{bukhari}{6609}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَأْتِي ابْنَ آدَمَ النَّذْرُ بِشَىْءٍ لَمْ يَكُنْ قَدْ قَدَّرْتُهُ، وَلَكِنْ يُلْقِيهِ الْقَدَرُ وَقَدْ قَدَّرْتُهُ لَهُ، أَسْتَخْرِجُ بِهِ مِنَ الْبَخِيلِ ‏"‏‏.‏\hadithno{6609}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said (that Allah said), "Vowing does not bring to the son of Adam anything I have not already written in his fate, but vowing is imposed on him by way of fore ordainment. Through vowing I make a miser spend of his wealth}}
\hadithdefcmd{bukhari}{6610}{حَدَّثَنِي مُحَمَّدُ بْنُ مُقَاتِلٍ أَبُو الْحَسَنِ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أَبِي مُوسَى، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزَاةٍ فَجَعَلْنَا لاَ نَصْعَدُ شَرَفًا، وَلاَ نَعْلُو شَرَفًا، وَلاَ نَهْبِطُ فِي وَادٍ، إِلاَّ رَفَعْنَا أَصْوَاتَنَا بِالتَّكْبِيرِ ـ قَالَ ـ فَدَنَا مِنَّا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ يَا أَيُّهَا النَّاسُ ارْبَعُوا عَلَى أَنْفُسِكُمْ فَإِنَّكُمْ لاَ تَدْعُونَ أَصَمَّ وَلاَ غَائِبًا إِنَّمَا تَدْعُونَ سَمِيعًا بَصِيرًا ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ يَا عَبْدَ اللَّهِ بْنَ قَيْسٍ، أَلاَ أُعَلِّمُكَ كَلِمَةً هِيَ مِنْ كُنُوزِ الْجَنَّةِ، لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏"‏‏.‏\hadithno{6610}\hadithtrans{Narrated Abu Musa:While we were with Allah's Messenger (ﷺ) in a holy battle, we never went up a hill or reached its peak or went down a valley but raised our voices with Takbir. Allah's Messenger (ﷺ) came close to us and said, "O people! Don't exert yourselves, for you do not call a deaf or an absent one, but you call the All- Listener, the All-Seer." The Prophet (ﷺ) then said, "O `Abdullah bin Qais! Shall I teach you a sentence which is from the treasures of Paradise? ( It is): 'La haula wala quwata illa billah. (There is neither might nor power except with Allah)}}
\hadithdefcmd{bukhari}{6611}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا اسْتُخْلِفَ خَلِيفَةٌ إِلاَّ لَهُ بِطَانَتَانِ بِطَانَةٌ تَأْمُرُهُ بِالْخَيْرِ وَتَحُضُّهُ عَلَيْهِ، وَبِطَانَةٌ تَأْمُرُهُ بِالشَّرِّ وَتَحُضُّهُ عَلَيْهِ، وَالْمَعْصُومُ مَنْ عَصَمَ اللَّهُ ‏"‏‏.‏\hadithno{6611}\hadithtrans{Narrated Abu Sa`id Al-Khudri:That the Prophet (ﷺ) said, "No Caliph is appointed but has two groups of advisors: One group advises him to do good and urges him to adopt it, and the other group advises him to do bad and urges him to adopt it; and the protected is the one whom Allah protects}}
\hadithdefcmd{bukhari}{6612}{حَدَّثَنِي مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَا رَأَيْتُ شَيْئًا أَشْبَهَ بِاللَّمَمِ مِمَّا قَالَ أَبُو هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ كَتَبَ عَلَى ابْنِ آدَمَ حَظَّهُ مِنَ الزِّنَا، أَدْرَكَ ذَلِكَ لاَ مَحَالَةَ، فَزِنَا الْعَيْنِ النَّظَرُ، وَزِنَا اللِّسَانِ الْمَنْطِقُ، وَالنَّفْسُ تَمَنَّى وَتَشْتَهِي، وَالْفَرْجُ يُصَدِّقُ ذَلِكَ، وَيُكَذِّبُهُ ‏"‏‏.‏ وَقَالَ شَبَابَةُ حَدَّثَنَا وَرْقَاءُ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6612}\hadithtrans{Narrated Ibn `Abbas:I did not see anything so resembling minor sins as what Abu Huraira said from the Prophet, who said, "Allah has written for the son of Adam his inevitable share of adultery whether he is aware of it or not: The adultery of the eye is the looking (at something which is sinful to look at), and the adultery of the tongue is to utter (what it is unlawful to utter), and the innerself wishes and longs for (adultery) and the private parts turn that into reality or refrain from submitting to the temptation}}
\hadithdefcmd{bukhari}{6613}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ ‏\{‏وَمَا جَعَلْنَا الرُّؤْيَا الَّتِي أَرَيْنَاكَ إِلاَّ فِتْنَةً لِلنَّاسِ‏\}‏ قَالَ هِيَ رُؤْيَا عَيْنٍ أُرِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةَ أُسْرِيَ بِهِ إِلَى بَيْتِ الْمَقْدِسِ‏.‏ قَالَ ‏\{‏وَالشَّجَرَةَ الْمَلْعُونَةَ فِي الْقُرْآنِ‏\}‏ قَالَ هِيَ شَجَرَةُ الزَّقُّومِ‏.‏\hadithno{6613}\hadithtrans{Narrated Ibn `Abbas:(regarding the Verse) "And We granted the vision (Ascension to the heavens "Miraj") which We showed you (O Muhammad as an actual eye witness) but as a trial for mankind.' (17.60): Allah's Apostle actually saw with his own eyes the vision (all the things which were shown to him) on the night of his Night Journey to Jerusalem (and then to the heavens). The cursed tree which is mentioned in the Qur'an is the tree of Az-Zaqqum}}
\hadithdefcmd{bukhari}{6614}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ حَفِظْنَاهُ مِنْ عَمْرٍو عَنْ طَاوُسٍ، سَمِعْتُ أَبَا هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ احْتَجَّ آدَمُ وَمُوسَى، فَقَالَ لَهُ مُوسَى يَا آدَمُ أَنْتَ أَبُونَا خَيَّبْتَنَا وَأَخْرَجْتَنَا مِنَ الْجَنَّةِ‏.‏ قَالَ لَهُ آدَمُ يَا مُوسَى اصْطَفَاكَ اللَّهُ بِكَلاَمِهِ، وَخَطَّ لَكَ بِيَدِهِ، أَتَلُومُنِي عَلَى أَمْرٍ قَدَّرَ اللَّهُ عَلَىَّ قَبْلَ أَنْ يَخْلُقَنِي بِأَرْبَعِينَ سَنَةً‏.‏ فَحَجَّ آدَمُ مُوسَى، فَحَجَّ آدَمُ مُوسَى ‏"‏ ثَلاَثًا‏.‏ قَالَ سُفْيَانُ حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ‏.‏\hadithno{6614}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Adam and Moses argued with each other. Moses said to Adam. 'O Adam! You are our father who disappointed us and turned us out of Paradise.' Then Adam said to him, 'O Moses! Allah favored you with His talk (talked to you directly) and He wrote (the Torah) for you with His Own Hand. Do you blame me for action which Allah had written in my fate forty years before my creation?' So Adam confuted Moses, Adam confuted Moses," the Prophet (ﷺ) added, repeating the Statement three times}}
\hadithdefcmd{bukhari}{6615}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا فُلَيْحٌ، حَدَّثَنَا عَبْدَةُ بْنُ أَبِي لُبَابَةَ، عَنْ وَرَّادٍ، مَوْلَى الْمُغِيرَةِ بْنِ شُعْبَةَ قَالَ كَتَبَ مُعَاوِيَةُ إِلَى الْمُغِيرَةِ اكْتُبْ إِلَىَّ مَا سَمِعْتَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ خَلْفَ الصَّلاَةِ‏.‏ فَأَمْلَى عَلَىَّ الْمُغِيرَةُ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ خَلْفَ الصَّلاَةِ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ، وَحْدَهُ لاَ شَرِيكَ لَهُ، اللَّهُمَّ لاَ مَانِعَ لِمَا أَعْطَيْتَ، وَلاَ مُعْطِيَ لِمَا مَنَعْتَ، وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏"‏‏.‏ وَقَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عَبْدَةُ أَنَّ وَرَّادًا أَخْبَرَهُ بِهَذَا‏.‏ ثُمَّ وَفَدْتُ بَعْدُ إِلَى مُعَاوِيَةَ فَسَمِعْتُهُ يَأْمُرُ النَّاسَ بِذَلِكَ الْقَوْلِ‏.‏\hadithno{6615}\hadithtrans{Narrated Warrad:(the freed slave of Al-Mughira bin Shu`ba) Muawiya wrote to Mughira. 'Write to me what you heard the Prophet (ﷺ) saying after his prayer.' So Al-Mughira dictated to me and said, "I heard the Prophet (ﷺ) saying after the prayer, 'None has the right to be worshipped but Allah Alone Who has no partner. O Allah! No-one can withhold what You give, and none can give what You withhold, and the fortune of a man of means is useless before You (i.e., only good deeds are of value)}}
\hadithdefcmd{bukhari}{6616}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تَعَوَّذُوا بِاللَّهِ مِنْ جَهْدِ الْبَلاَءِ، وَدَرَكِ الشَّقَاءِ، وَسُوءِ الْقَضَاءِ، وَشَمَاتَةِ الأَعْدَاءِ ‏"‏‏.‏\hadithno{6616}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Take refuge with Allah from the difficulties of severe calamities, from having an evil end and a bad fate and from the malicious joy of your enemies}}
\hadithdefcmd{bukhari}{6617}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ أَبُو الْحَسَنِ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ سَالِمٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كَثِيرًا مِمَّا كَانَ النَّبِيُّ صلى الله عليه وسلم يَحْلِفُ ‏(‏لاَ وَمُقَلِّبِ الْقُلُوبِ‏)‏‏.‏\hadithno{6617}\hadithtrans{Narrated `Abdullah:When taking an oath, the Prophet (ﷺ) very often used to say, "No, by Him Who turns the hearts}}
\hadithdefcmd{bukhari}{6618}{حَدَّثَنَا عَلِيُّ بْنُ حَفْصٍ، وَبِشْرُ بْنُ مُحَمَّدٍ، قَالاَ أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم لاِبْنِ صَيَّادٍ ‏"‏ خَبَأْتُ لَكَ خَبِيئًا ‏"‏‏.‏ قَالَ الدُّخُّ‏.‏ قَالَ ‏"‏ اخْسَأْ فَلَنْ تَعْدُوَ قَدْرَكَ ‏"‏‏.‏ قَالَ عُمَرُ ائْذَنْ لِي فَأَضْرِبَ عُنُقَهُ‏.‏ قَالَ ‏"‏ دَعْهُ، إِنْ يَكُنْ هُوَ فَلاَ تُطِيقُهُ، وَإِنْ لَمْ يَكُنْ هُوَ فَلاَ خَيْرَ لَكَ فِي قَتْلِهِ ‏"‏‏.‏\hadithno{6618}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said to Ibn Saiyad, "I have kept for you a secret." Ibn Saiyad said, "Ad-Dukh." The Prophet said, "Keep quiet, for you cannot go beyond your limits (or you cannot exceed what has been foreordained for you)." On that, `Umar said (to the Prophet (ﷺ) ), "Allow me to chop off his neck!" The Prophet said, "Leave him, for if he is he (i.e., Ad-Dajjal), then you will not be able to overcome him, and if he is not, then you gain no good by killing him}}
\hadithdefcmd{bukhari}{6619}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا النَّضْرُ، حَدَّثَنَا دَاوُدُ بْنُ أَبِي الْفُرَاتِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ يَحْيَى بْنِ يَعْمَرَ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ أَخْبَرَتْهُ أَنَّهَا، سَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الطَّاعُونِ فَقَالَ ‏ "‏ كَانَ عَذَابًا يَبْعَثُهُ اللَّهُ عَلَى مَنْ يَشَاءُ، فَجَعَلَهُ اللَّهُ رَحْمَةً لِلْمُؤْمِنِينَ، مَا مِنْ عَبْدٍ يَكُونُ فِي بَلَدٍ يَكُونُ فِيهِ، وَيَمْكُثُ فِيهِ، لاَ يَخْرُجُ مِنَ الْبَلَدِ، صَابِرًا مُحْتَسِبًا، يَعْلَمُ أَنَّهُ لاَ يُصِيبُهُ إِلاَّ مَا كَتَبَ اللَّهُ لَهُ، إِلاَّ كَانَ لَهُ مِثْلُ أَجْرِ شَهِيدٍ ‏"‏‏.‏\hadithno{6619}\hadithtrans{Narrated `Aisha:I asked Allah's Messenger (ﷺ) about the plague. He said, "That was a means of torture which Allah used to send upon whom-so-ever He wished, but He made it a source of mercy for the believers, for anyone who is residing in a town in which this disease is present, and remains there and does not leave that town, but has patience and hopes for Allah's reward, and knows that nothing will befall him except what Allah has written for him, then he will get such reward as that of a martyr}}
\hadithdefcmd{bukhari}{6620}{حَدَّثَنَا أَبُو النُّعْمَانِ، أَخْبَرَنَا جَرِيرٌ ـ هُوَ ابْنُ حَازِمٍ ـ عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَوْمَ الْخَنْدَقِ يَنْقُلُ مَعَنَا التُّرَابَ وَهْوَ يَقُولُ ‏ "‏ وَاللَّهِ لَوْلاَ اللَّهُ مَا اهْتَدَيْنَا، وَلاَ صُمْنَا وَلاَ صَلَّيْنَا، فَأَنْزِلَنْ سَكِينَةً عَلَيْنَا، وَثَبِّتِ الأَقْدَامَ إِنْ لاَقَيْنَا، وَالْمُشْرِكُونَ قَدْ بَغَوْا عَلَيْنَا، إِذَا أَرَادُوا فِتْنَةً أَبَيْنَا‏"‏‏.‏\hadithno{6620}\hadithtrans{Narrated Al-Bara' bin `Azib:I saw the Prophet (ﷺ) on the Day of (the battle of) Al-Khandaq, carrying earth with us and saying, "By Allah, without Allah we would not have been guided, neither would we have fasted, nor would we have prayed. O Allah! Send down Sakina (calmness) upon us and make our feet firm when we meet (the enemy). The pagans have rebelled against us, but if they want to put us in affliction (i.e., fight us) we refuse (to flee)." (See Hadith No. 430, Vol)}}
