% Auto-generated chapter 26 for muslim
% Hadiths in this chapter: 17

\hadithdefcmd{muslim}{4235}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَمُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ، عَبَّاسٍ أَنَّهُ قَالَ اسْتَفْتَى سَعْدُ بْنُ عُبَادَةَ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي نَذْرٍ كَانَ عَلَى أُمِّهِ تُوُفِّيَتْ قَبْلَ أَنْ تَقْضِيَهُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَاقْضِهِ عَنْهَا‏"‏ ‏.‏\hadithno{4235}\hadithtrans{Ibn Abbas reported that Sa'd b. Ubida asked Allah's Messenger (ﷺ) for a decision about a vow taken by his mother who had died before fulfilling it. Allah's Messenger (ﷺ) said:Fulfil it on her behalf}}
\hadithdefcmd{muslim}{4236}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ عَنِ ابْنِ عُيَيْنَةَ، ح وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ بَكْرِ بْنِ وَائِلٍ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، ‏.‏ بِإِسْنَادِ اللَّيْثِ وَمَعْنَى حَدِيثِهِ ‏.‏\hadithno{4236}\hadithtrans{This hadith has been narrated on the authority of Zuhri with a different chains of transmitters}}
\hadithdefcmd{muslim}{4237}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، زُهَيْرٌ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ أَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا يَنْهَانَا عَنِ النَّذْرِ وَيَقُولُ ‏ "‏ إِنَّهُ لاَ يَرُدُّ شَيْئًا وَإِنَّمَا يُسْتَخْرَجُ بِهِ مِنَ الشَّحِيحِ ‏"‏ ‏.‏\hadithno{4237}\hadithtrans{Abdullah b. Umar reported:Allah's Messenger (may peace he upon him) singled out one day forbidding us to take vows and said: It would not avert anything; it is by which something is extracted from the miserly person}}
\hadithdefcmd{muslim}{4238}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَزِيدُ بْنُ أَبِي حَكِيمٍ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ، دِينَارٍ عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ النَّذْرُ لاَ يُقَدِّمُ شَيْئًا وَلاَ يُؤَخِّرُهُ وَإِنَّمَا يُسْتَخْرَجُ بِهِ مِنَ الْبَخِيلِ ‏"‏ ‏\hadithno{4238}\hadithtrans{Ibn Umar reported Allah's Apostle (ﷺ) as saying:The vow neither hastens anything nor defers anything, but is the means whereby (something) is extracted from the miserly person}}
\hadithdefcmd{muslim}{4239}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنِ النَّذْرِ وَقَالَ ‏ "‏ إِنَّهُ لاَ يَأْتِي بِخَيْرٍ وَإِنَّمَا يُسْتَخْرَجُ بِهِ مِنَ الْبَخِيلِ ‏"‏ ‏.‏\hadithno{4239}\hadithtrans{Ibn Umar reported that Allah's Apostle (ﷺ) forbade (people) taking vows, and said:It does not (necessarily) bring good (in the form of substantial, and tangible results), but it is the meant whereby something is extracted from the miserly persons}}
\hadithdefcmd{muslim}{4240}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا مُفَضَّلٌ، ح وَحَدَّثَنَا مُحَمَّدُ، بْنُ الْمُثَنَّى وَابْنُ بَشَّارٍ قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، كِلاَهُمَا عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِ جَرِيرٍ ‏.‏\hadithno{4240}\hadithtrans{This hadith has been narrated on the authority of Mansur with the same chain of transmitters}}
\hadithdefcmd{muslim}{4241}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَنْذُرُوا فَإِنَّ النَّذْرَ لاَ يُغْنِي مِنَ الْقَدَرِ شَيْئًا وَإِنَّمَا يُسْتَخْرَجُ بِهِ مِنَ الْبَخِيلِ ‏"‏ ‏.‏\hadithno{4241}\hadithtrans{Abu Heraira reported Allah's Messenger (ﷺ) as saying:Do not take vows, for a vow has no effect against Fate; it is only from the miserly that something is extracted}}
\hadithdefcmd{muslim}{4242}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ الْعَلاَءَ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنِ النَّذْرِ وَقَالَ ‏ "‏ إِنَّهُ لاَ يَرُدُّ مِنَ الْقَدَرِ وَإِنَّمَا يُسْتَخْرَجُ بِهِ مِنَ الْبَخِيلِ ‏"‏ ‏.‏\hadithno{4242}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) forbidding taking of vows, and said:It does not avert Fate, but is the means by which something is extracted from the miser}}
\hadithdefcmd{muslim}{4243}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ عَمْرٍو، - وَهْوَ ابْنُ أَبِي عَمْرٍو - عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ النَّذْرَ لاَ يُقَرِّبُ مِنِ ابْنِ آدَمَ شَيْئًا لَمْ يَكُنِ اللَّهُ قَدَّرَهُ لَهُ وَلَكِنِ النَّذْرُ يُوَافِقُ الْقَدَرَ فَيُخْرَجُ بِذَلِكَ مِنَ الْبَخِيلِ مَا لَمْ يَكُنِ الْبَخِيلُ يُرِيدُ أَنْ يُخْرِجَ ‏"‏ ‏.‏\hadithno{4243}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:The vow does not bring anything near to the son of Adam which Allah has not ordained for him, but (at times) the vow coincides with Destiny, and this is how something is extracted from the miserly person, which that miser was not willing to give}}
\hadithdefcmd{muslim}{4244}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - وَعَبْدُ الْعَزِيزِ - يَعْنِي الدَّرَاوَرْدِيَّ - كِلاَهُمَا عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4244}\hadithtrans{This hadith has been transmitted on the authority of 'Amr b. Abu 'Amr}}
\hadithdefcmd{muslim}{4245}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ كَانَتْ ثَقِيفُ حُلَفَاءَ لِبَنِي عُقَيْلٍ فَأَسَرَتْ ثَقِيفُ رَجُلَيْنِ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَسَرَ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم رَجُلاً مِنْ بَنِي عُقَيْلٍ وَأَصَابُوا مَعَهُ الْعَضْبَاءَ فَأَتَى عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهْوَ فِي الْوَثَاقِ قَالَ يَا مُحَمَّدُ ‏.‏ فَأَتَاهُ فَقَالَ ‏"‏ مَا شَأْنُكَ ‏"‏ ‏.‏ فَقَالَ بِمَ أَخَذْتَنِي وَبِمَ أَخَذْتَ سَابِقَةَ الْحَاجِّ فَقَالَ إِعْظَامًا لِذَلِكَ ‏"‏ أَخَذْتُكَ بِجَرِيرَةِ حُلَفَائِكَ ثَقِيفَ ‏"‏ ‏.‏ ثُمَّ انْصَرَفَ عَنْهُ فَنَادَاهُ فَقَالَ يَا مُحَمَّدُ يَا مُحَمَّدُ ‏.‏ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَحِيمًا رَقِيقًا فَرَجَعَ إِلَيْهِ فَقَالَ ‏"‏ مَا شَأْنُكَ ‏"‏ ‏.‏ قَالَ إِنِّي مُسْلِمٌ ‏.‏ قَالَ ‏"‏ لَوْ قُلْتَهَا وَأَنْتَ تَمْلِكُ أَمْرَكَ أَفْلَحْتَ كُلَّ الْفَلاَحِ ‏"‏ ‏.‏ ثُمَّ انْصَرَفَ فَنَادَاهُ فَقَالَ يَا مُحَمَّدُ يَا مُحَمَّدُ ‏.‏ فَأَتَاهُ فَقَالَ ‏"‏ مَا شَأْنُكَ ‏"‏ ‏.‏ قَالَ إِنِّي جَائِعٌ فَأَطْعِمْنِي وَظَمْآنُ فَأَسْقِنِي ‏.‏ قَالَ ‏"‏ هَذِهِ حَاجَتُكَ ‏"‏ ‏.‏ فَفُدِيَ بِالرَّجُلَيْنِ - قَالَ - وَأُسِرَتِ امْرَأَةٌ مِنَ الأَنْصَارِ وَأُصِيبَتِ الْعَضْبَاءُ فَكَانَتِ الْمَرْأَةُ فِي الْوَثَاقِ وَكَانَ الْقَوْمُ يُرِيحُونَ نَعَمَهُمْ بَيْنَ يَدَىْ بُيُوتِهِمْ فَانْفَلَتَتْ ذَاتَ لَيْلَةٍ مِنَ الْوَثَاقِ فَأَتَتِ الإِبِلَ فَجَعَلَتْ إِذَا دَنَتْ مِنَ الْبَعِيرِ رَغَا فَتَتْرُكُهُ حَتَّى تَنْتَهِيَ إِلَى الْعَضْبَاءِ فَلَمْ تَرْغُ قَالَ وَنَاقَةٌ مُنَوَّقَةٌ فَقَعَدَتْ فِي عَجُزِهَا ثُمَّ زَجَرَتْهَا فَانْطَلَقَتْ وَنَذِرُوا بِهَا فَطَلَبُوهَا فَأَعْجَزَتْهُمْ - قَالَ - وَنَذَرَتْ لِلَّهِ إِنْ نَجَّاهَا اللَّهُ عَلَيْهَا لَتَنْحَرَنَّهَا فَلَمَّا قَدِمَتِ الْمَدِينَةَ رَآهَا النَّاسُ ‏.‏ فَقَالُوا الْعَضْبَاءُ نَاقَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَتْ إِنَّهَا نَذَرَتْ إِنْ نَجَّاهَا اللَّهُ عَلَيْهَا لَتَنْحَرَنَّهَا ‏.‏ فَأَتَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرُوا ذَلِكَ لَهُ ‏.‏ فَقَالَ ‏"‏ سُبْحَانَ اللَّهِ بِئْسَمَا جَزَتْهَا نَذَرَتْ لِلَّهِ إِنْ نَجَّاهَا اللَّهُ عَلَيْهَا لَتَنْحَرَنَّهَا لاَ وَفَاءَ لِنَذْرٍ فِي مَعْصِيَةٍ وَلاَ فِيمَا لاَ يَمْلِكُ الْعَبْدُ ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ حُجْرٍ ‏"‏ لاَ نَذْرَ فِي مَعْصِيَةِ اللَّهِ ‏"‏ ‏.‏\hadithno{4245}\hadithtrans{Imran b. Husain reported that the tribe of Thaqif was the ally of Banu 'Uqail. Thaqif took two persons from amongst the Companions of Allah's Messenger (ﷺ) as prisoners. The Companions of Allah's Messenger (ﷺ) took one person at Banu Uqail as prisoner, and captured al-'Adbi (the she-camel of the Holy Prophet) along with him. Allah's Messenger (ﷺ) came to him and he was tied with ropes. He said:Muhammad. He came near him and said: What is the matter with you? Thereupon he (the prisoner) said: Why have you taken me as prisoner and why have you caught hold of one proceeding the pilgrims (the she-camel as she carried the Prophet on her back and walked ahead of the multitude)? He (the Holy Prophet) said: (Yours is a great fault). I (my men) have caught hold of you for the crime of your allies, Banu Thaqif. He (the Holy Prophet) then turned away. He again called him and said: Muhammad, Muhammad, and since Allah's Messenger (ﷺ) was very compassionate, and tenderhearted, he returned to him, and said: What is the matter with you? He said: I am a Muslim, whereupon he (the Holy Prophet) said: Had you said this when you had been the master of yourself, you would have gained every success. He then turned away. He (the prisoner) called him again saying: Muhammad, Muhammad. He came to him and said: What is the matter with you? He said: I am hungry, feed me, and I am thirsty, so provide me with drink. He (the Holy Prophet) said: That is (to satisfy) your want. He was then ransomed for two persons (who had been taken prisoner by Thaqif). He (the narrator) said: A woman of the Ansar had been taken prisoner and also al-Adbi' was caught. The woman had been tied with ropes. The people were giving rest to their animals before their houses. She escaped one night from the bondage and came to the camels. As she drew near the camels, they fretted and fumed and so she left them until she came to al-, Adbi'. It did not fret and fume; it was docile She rode upon its back and drove it away and she went off. When they (the enemies of Islam) were warned of this, they went in search of it, but it (the she-camel) exhausted them. She (the woman) took vow for Allah, that in case He would save her through it, she would offer that as a sacrifice. As she reached Medina, the people saw her and they said: Here is al-Adbi, the she-camel of Allah's Messenger (ﷺ). She (the woman) said that she had taken a vow that if Allah would save her on its back, she would sacrifice it. They (the Prophet's Companions) came to Allah's Messenger (ﷺ) and made a mention of that to him, whereupon he said: Hallowed be Allah, how ill she rewarded it that she took vow to Allah that if He saves her on its back, she would sacrifice it! There is no fulfillment of the vow in an act of disobedience, nor in an act over which a person has no control. In the version of Ibn Hujr (the words are):" There is no vow in disobedience to Allah}}
\hadithdefcmd{muslim}{4246}{حَدَّثَنَا أَبُو الرَّبِيعِ الْعَتَكِيُّ، حَدَّثَنَا حَمَّادٌ يَعْنِي ابْنَ زَيْدٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ عَنْ عَبْدِ الْوَهَّابِ الثَّقَفِيِّ، كِلاَهُمَا عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ نَحْوَهُ وَفِي حَدِيثِ حَمَّادٍ قَالَ كَانَتِ الْعَضْبَاءُ لِرَجُلٍ مِنْ بَنِي عُقَيْلٍ وَكَانَتْ مِنْ سَوَابِقِ الْحَاجِّ وَفِي حَدِيثِهِ أَيْضًا فَأَتَتْ عَلَى نَاقِةٍ ذَلُولٍ مُجَرَّسَةٍ ‏.‏ وَفِي حَدِيثِ الثَّقَفِيِّ وَهِيَ نَاقَةٌ مُدَرَّبَةٌ ‏.‏\hadithno{4246}\hadithtrans{This hadith is narrated on the authority of Ayyub with the same chain of transmitters and a slight variation of words}}
\hadithdefcmd{muslim}{4247}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ حُمَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، ح. وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، حَدَّثَنَا حُمَيْدٌ، حَدَّثَنِي ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَىَ شَيْخًا يُهَادَى بَيْنَ ابْنَيْهِ فَقَالَ ‏"‏ مَا بَالُ هَذَا ‏"‏ ‏.‏ قَالُوا نَذَرَ أَنْ يَمْشِيَ ‏.‏ قَالَ ‏"‏ إِنَّ اللَّهَ عَنْ تَعْذِيبِ هَذَا نَفْسَهُ لَغَنِيٌّ ‏"‏ ‏.‏ وَأَمَرَهُ أَنْ يَرْكَبَ ‏.‏\hadithno{4247}\hadithtrans{Anas reported that Allah's Apostle (ﷺ) saw an old man being supported between his two sons. He (the Holy Prophet) said:What is the matter with him? They said: He had taken the vow to walk (on foot to the Ka'ba). Thereupon he (Allah's Apoitle) said: Allah is indifferent to his inflicting upon himself chastisement, and he commanded him to ride}}
\hadithdefcmd{muslim}{4248}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ عَمْرٍو، - وَهُوَ ابْنُ أَبِي عَمْرٍو - عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَدْرَكَ شَيْخًا يَمْشِي بَيْنَ ابْنَيْهِ يَتَوَكَّأُ عَلَيْهِمَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا شَأْنُ هَذَا ‏"‏ ‏.‏ قَالَ ابْنَاهُ يَا رَسُولَ اللَّهِ كَانَ عَلَيْهِ نَذْرٌ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ارْكَبْ أَيُّهَا الشَّيْخُ فَإِنَّ اللَّهَ غَنِيٌّ عَنْكَ وَعَنْ نَذْرِكَ ‏"‏ ‏.‏ وَاللَّفْظُ لِقُتَيْبَةَ وَابْنِ حُجْرٍ ‏.‏\hadithno{4248}\hadithtrans{Abu Huraira reported:Allah's Apostle (ﷺ) found an old man walking between his two sons supported by them, whereupon Allah's Apostle (ﷺ) said: What is the matter with him? He (the narrator) said: Allah's Messenger, they are his sons and there is upon him the (fulfilment) of the vow, whereupon Allah's Apostle (ﷺ) said: Ride, old man, for Allah is not in need of you and your vow}}
\hadithdefcmd{muslim}{4249}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنْ عَمْرِو، بْنِ أَبِي عَمْرٍو بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4249}\hadithtrans{This hadith has been narrated on the authority of 'Amr b. Abu 'Amr with the same chain of transmitters}}
\hadithdefcmd{muslim}{4250}{وَحَدَّثَنَا زَكَرِيَّاءُ بْنُ يَحْيَى بْنِ صَالِحٍ الْمِصْرِيُّ، حَدَّثَنَا الْمُفَضَّلُ، - يَعْنِي ابْنَ فَضَالَةَ - حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَيَّاشٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّهُ قَالَ نَذَرَتْ أُخْتِي أَنْ تَمْشِيَ، إِلَى بَيْتِ اللَّهِ حَافِيَةً فَأَمَرَتْنِي أَنْ أَسْتَفْتِيَ لَهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَاسْتَفْتَيْتُهُ فَقَالَ ‏ "‏ لِتَمْشِ وَلْتَرْكَبْ ‏"‏ ‏.‏\hadithno{4250}\hadithtrans{Uqba b. Amir reported:My sister took a vow that she would walk bare foot to the house of Allah (Ka'ba). She asked me to inquire from Allah's Messenger (ﷺ) about it. I sought his decision and he said: She should walk on foot and ride also}}
\hadithdefcmd{muslim}{4253}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَيُونُسُ بْنُ عَبْدِ الأَعْلَى، وَأَحْمَدُ بْنُ عِيسَى، قَالَ يُونُسُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ كَعْبِ بْنِ، عَلْقَمَةَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ شُمَاسَةَ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كَفَّارَةُ النَّذْرِ كَفَّارَةُ الْيَمِينِ ‏"‏ ‏.‏\hadithno{4253}\hadithtrans{Uqba. b. Amir reported Allah's Messenger (ﷺ) as saying:The expiation of the (breach of) a vow is the same as that of the (breach of an oath)}}
