% Auto-generated chapter 35 for tirmidhi
% Hadiths in this chapter: 9

\hadithdefcmd{tirmidhi}{2295}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عُثْمَانَ، عَنْ أَبِي عَمْرَةَ الأَنْصَارِيِّ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ أُخْبِرُكُمْ بِخَيْرِ الشُّهَدَاءِ الَّذِي يَأْتِي بِالشَّهَادَةِ قَبْلَ أَنْ يُسْأَلَهَا ‏"‏ ‏.‏\hadithno{2295}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Zaid bin Khalid Al-Juhani narrated that the Messenger of Allah (s.a.w) said:"Shall l not inform you of the best of witnesses? The one who comes with his testimony before being asked for it}}
\hadithdefcmd{tirmidhi}{2296}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، نَحْوَهُ وَقَالَ ابْنُ أَبِي عَمْرَةَ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَأَكْثَرُ النَّاسِ يَقُولُونَ عَبْدُ الرَّحْمَنِ بْنُ أَبِي عَمْرَةَ وَاخْتَلَفُوا عَلَى مَالِكٍ فِي رِوَايَةِ هَذَا الْحَدِيثِ فَرَوَى بَعْضُهُمْ عَنْ أَبِي عَمْرَةَ وَرَوَى بَعْضُهُمْ عَنِ ابْنِ أَبِي عَمْرَةَ وَهُوَ عَبْدُ الرَّحْمَنِ بْنُ أَبِي عَمْرَةَ الأَنْصَارِيُّ وَهَذَا أَصَحُّ لأَنَّهُ قَدْ رُوِيَ مِنْ غَيْرِ حَدِيثِ مَالِكٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ عَنْ زَيْدِ بْنِ خَالِدٍ وَقَدْ رُوِيَ عَنِ ابْنِ أَبِي عَمْرَةَ عَنْ زَيْدِ بْنِ خَالِدٍ غَيْرُ هَذَا الْحَدِيثِ وَهُوَ حَدِيثٌ صَحِيحٌ أَيْضًا وَأَبُو عَمْرَةَ مَوْلَى زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ وَلَهُ حَدِيثُ الْغُلُولِ وَأَكْثَرُ النَّاسِ يَقُولُونَ عَبْدُ الرَّحْمَنِ بْنُ أَبِي عَمْرَةَ ‏.‏\hadithno{2296}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{(Another chain) from Malik in which he said:Ibn Abi 'Amrah}}
\hadithdefcmd{tirmidhi}{2297}{حَدَّثَنَا بِشْرُ بْنُ آدَمَ ابْنُ بِنْتِ أَزْهَرَ السَّمَّانِ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا أُبَىُّ بْنُ عَبَّاسِ بْنِ سَهْلِ بْنِ سَعْدٍ، حَدَّثَنِي أَبُو بَكْرِ بْنُ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ عُثْمَانَ، حَدَّثَنِي خَارِجَةُ بْنُ زَيْدِ بْنِ ثَابِتٍ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي عَمْرَةَ، حَدَّثَنِي زَيْدُ بْنُ خَالِدٍ الْجُهَنِيُّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ خَيْرُ الشُّهَدَاءِ مَنْ أَدَّى شَهَادَتَهُ قَبْلَ أَنْ يُسْأَلَهَا ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2297}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Zaid bin Khalid Al-Juhani narrated that the Messenger of Allah(s.a.w) said:"The best of witnesses is the one who gives his testimony before being asked for it}}
\hadithdefcmd{tirmidhi}{2299}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنْ سُفْيَانَ بْنِ زِيَادٍ الأَسَدِيِّ، عَنْ فَاتِكِ بْنِ فَضَالَةَ، عَنْ أَيْمَنَ بْنِ خُرَيْمٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَامَ خَطِيبًا فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ عُدِلَتْ شَهَادَةُ الزُّورِ إِشْرَاكًا بِاللَّهِ ‏"‏ ‏.‏ ثُمَّ قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏:‏ ‏(‏وَاجْتَنِبُوا الرِّجْسَ مِنَ الأَوْثَانِ وَاجْتَنِبُوا قَوْلَ الزُّورِ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ سُفْيَانَ بْنِ زِيَادٍ وَاخْتَلَفُوا فِي رِوَايَةِ هَذَا الْحَدِيثِ عَنْ سُفْيَانَ بْنِ زِيَادٍ ‏.‏ وَلاَ نَعْرِفُ لأَيْمَنَ بْنِ خُرَيْمٍ سَمَاعًا مِنَ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2299}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ayman bin Khuraim narrated that the Prophet (s.a.w) stood to give a Khutbah and said:"O you people False witness is tantamount to Shirk with Allah" Then the Messenger of Allah (s.a.w)recited: So shun the Rijs of the idols, and shun false speech}}
\hadithdefcmd{tirmidhi}{2300}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا سُفْيَانُ، وَهُوَ ابْنُ زِيَادٍ الْعُصْفُرِيُّ عَنْ أَبِيهِ، عَنْ حَبِيبِ بْنِ النُّعْمَانِ الأَسَدِيِّ، عَنْ خُرَيْمِ بْنِ فَاتِكٍ الأَسَدِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى صَلاَةَ الصُّبْحِ فَلَمَّا انْصَرَفَ قَامَ قَائِمًا فَقَالَ ‏"‏ عُدِلَتْ شَهَادَةُ الزُّورِ بِالشِّرْكِ بِاللَّهِ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ثُمَّ تَلاَ هَذِهِ الآيَةَ ‏(‏وَاجْتَنِبُوا قَوْلَ الزُّورِ ‏)‏ إِلَى آخِرِ الآيَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا عِنْدِي أَصَحُّ ‏.‏ وَخُرَيْمُ بْنُ فَاتِكٍ لَهُ صُحْبَةٌ وَقَدْ رَوَى عَنِ النَّبِيِّ صلى الله عليه وسلم أَحَادِيثَ وَهُوَ مَشْهُورٌ ‏.‏\hadithno{2300}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Khuraim bin Fatik Al-Asadi narrated that the Messenger of Allah (s.a.w) performed the Subh (Fajr)prayer. Then when he turned he got up to stand and said:"O you people! False witness is tantamount to Shirk with Allah."Saying it three times, then he recited this Ayah And shun false speech Until the end of the Ayah}}
\hadithdefcmd{tirmidhi}{2301}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنِ الْجُرَيْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَلاَ أُخْبِرُكُمْ بِأَكْبَرِ الْكَبَائِرِ ‏"‏ ‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ الإِشْرَاكُ بِاللَّهِ وَعُقُوقُ الْوَالِدَيْنِ وَشَهَادَةُ الزُّورِ أَوْ قَوْلُ الزُّورِ ‏"‏ ‏.‏ قَالَ فَمَا زَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُهَا حَتَّى قُلْنَا لَيْتَهُ سَكَتَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏\hadithno{2301}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdur-Rahman bin Abi Bakrah narrated from his father that the Messenger of Allah (s.a.w) said:"Shall I not inform you of the greatest of the major sins?" They said: "Of course O Messenger of Allah(s.a.w)!" He said: "Shirk with Allah disobeying parents, and false testimony." Or: "False speech" He said: "So the Messenger of Allah(s.a.w) would not stop saying it until we said ( to ourselves): 'I wish he would be quiet}}
\hadithdefcmd{tirmidhi}{2302}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنِ الأَعْمَشِ، عَنْ عَلِيِّ بْنِ مُدْرِكٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ خَيْرُ النَّاسِ قَرْنِي ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ثَلاَثًا ثُمَّ يَجِيءُ قَوْمٌ مِنْ بَعْدِهِمْ يَتَسَمَّنُونَ وَيُحِبُّونَ السِّمَنَ يُعْطُونَ الشَّهَادَةَ قَبْلَ أَنْ يُسْأَلُوهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ الأَعْمَشِ عَنْ عَلِيِّ بْنِ مُدْرِكٍ وَأَصْحَابُ الأَعْمَشِ إِنَّمَا رَوَوْا عَنِ الأَعْمَشِ عَنْ هِلاَلِ بْنِ يِسَافٍ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ ‏.‏\hadithno{2302}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Imran bin Husain narrated that the Messenger of Allah(s.a.w)said:"The best of people are my generation, then those who follow them,then those who follow them, then those who follow them."(He(s.a.w)said that) three times. "Then, after them a people will come who increase in fatness, loving fatness, giving testimony before they are asked for it}}
\hadithdefcmd{tirmidhi}{2302p2}{حَدَّثَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، حَدَّثَنَا هِلاَلُ بْنُ يِسَافٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ فُضَيْلٍ ‏.‏ قَالَ وَمَعْنَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ ‏"‏ يُعْطُونَ الشَّهَادَةَ قَبْلَ أَنْ يُسْأَلُوهَا ‏"‏ ‏.‏ إِنَّمَا يَعْنِي شَهَادَةَ الزُّورِ يَقُولُ يَشْهَدُ أَحَدُهُمْ مِنْ غَيْرِ أَنْ يُسْتَشْهَدَ وَبَيَانُ هَذَا فِي [الحديث التالي]\hadithno{2302.2}\hadithtrans{Another chain on the authority of 'Imran bin Husain narrates a similar narration}}
\hadithdefcmd{tirmidhi}{2303}{حَدِيثِ عُمَرَ بْنِ الْخَطَّابِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ خَيْرُ النَّاسِ قَرْنِي ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ يَفْشُو الْكَذِبُ حَتَّى يَشْهَدَ الرَّجُلُ وَلاَ يُسْتَشْهَدُ وَيَحْلِفُ الرَّجُلُ وَلاَ يُسْتَحْلَفُ ‏"‏ ‏.‏ وَمَعْنَى حَدِيثِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ خَيْرُ الشُّهَدَاءِ الَّذِي يَأْتِي بِشَهَادَتِهِ قَبْلَ أَنْ يُسْأَلَهَا ‏"‏ ‏.‏ هُوَ عِنْدَنَا إِذَا أُشْهِدَ الرَّجُلُ عَلَى الشَّىْءِ أَنْ يُؤَدِّيَ شَهَادَتَهُ وَلاَ يَمْتَنِعَ مِنَ الشَّهَادَةِ هَكَذَا وَجْهُ الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ ‏.‏ كَمُلَ وَالْحَمْدُ لِلَّهِ كِتَابُ الشَّهَادَاتِ وَيَلِيهِ كِتَابُ الزُّهْدِ\hadithno{2303}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{Clarification of this is in the Hadith of 'Umar bin Al-Khattab, from the Prophet(s.a.w) who said:"The best of people are my generation, then those who follow them,then those who follow them. Then lying will spread, until a man testifies while his testimony was not requested, and a man will take an oath while an oath was not sought}}
