% Auto-generated chapter 55 for bukhari
% Hadiths in this chapter: 44

\hadithdefcmd{bukhari}{2738}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا حَقُّ امْرِئٍ مُسْلِمٍ لَهُ شَىْءٌ، يُوصِي فِيهِ يَبِيتُ لَيْلَتَيْنِ، إِلاَّ وَوَصِيَّتُهُ مَكْتُوبَةٌ عِنْدَهُ ‏"‏‏.‏ تَابَعَهُ مُحَمَّدُ بْنُ مُسْلِمٍ عَنْ عَمْرٍو عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2738}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "It is not permissible for any Muslim who has something to will to stay for two nights without having his last will and testament written and kept ready with him}}
\hadithdefcmd{bukhari}{2739}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْحَارِثِ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ الْجُعْفِيُّ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ عَمْرِو بْنِ الْحَارِثِ، خَتَنِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَخِي جُوَيْرِيَةَ بِنْتِ الْحَارِثِ قَالَ مَا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ مَوْتِهِ دِرْهَمًا وَلاَ دِينَارًا وَلاَ عَبْدًا وَلاَ أَمَةً وَلاَ شَيْئًا، إِلاَّ بَغْلَتَهُ الْبَيْضَاءَ وَسِلاَحَهُ وَأَرْضًا جَعَلَهَا صَدَقَةً‏.‏\hadithno{2739}\hadithtrans{Narrated `Amr bin Al-Harith:(The brother of the wife of Allah's Messenger (ﷺ), Juwairiya bint Al-Harith) When Allah's Messenger (ﷺ) died, he did not leave any Dirham or Dinar (i.e. money), a slave or a slave woman or anything else except his white mule, his arms and a piece of land which he had given in charity}}
\hadithdefcmd{bukhari}{2740}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا مَالِكٌ، حَدَّثَنَا طَلْحَةُ بْنُ مُصَرِّفٍ، قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى ـ رضى الله عنهما ـ هَلْ كَانَ النَّبِيُّ صلى الله عليه وسلم أَوْصَى فَقَالَ لاَ‏.‏ فَقُلْتُ كَيْفَ كُتِبَ عَلَى النَّاسِ الْوَصِيَّةُ أَوْ أُمِرُوا بِالْوَصِيَّةِ قَالَ أَوْصَى بِكِتَابِ اللَّهِ‏.‏\hadithno{2740}\hadithtrans{Narrated Talha bin Musarrif:I asked `Abdullah bin Abu `Aufa "Did the Prophet (ﷺ) make a will?" He replied, "No," I asked him, "How is it then that the making of a will has been enjoined on people, (or that they are ordered to make a will)?" He replied, "The Prophet (ﷺ) bequeathed Allah's Book (i.e. Qur'an)}}
\hadithdefcmd{bukhari}{2741}{حَدَّثَنَا عَمْرُو بْنُ زُرَارَةَ، أَخْبَرَنَا إِسْمَاعِيلُ، عَنِ ابْنِ عَوْنٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، قَالَ ذَكَرُوا عِنْدَ عَائِشَةَ أَنَّ عَلِيًّا ـ رضى الله عنهما ـ كَانَ وَصِيًّا‏.‏ فَقَالَتْ مَتَى أَوْصَى إِلَيْهِ وَقَدْ كُنْتُ مُسْنِدَتَهُ إِلَى صَدْرِي ـ أَوْ قَالَتْ حَجْرِي ـ فَدَعَا بِالطَّسْتِ، فَلَقَدِ انْخَنَثَ فِي حَجْرِي، فَمَا شَعَرْتُ أَنَّهُ قَدْ مَاتَ، فَمَتَى أَوْصَى إِلَيْهِ\hadithno{2741}\hadithtrans{Narrated Al-Aswad:In the presence of `Aisha some people mentioned that the Prophet (ﷺ) had appointed `Ali by will as his successor. `Aisha said, "When did he appoint him by will? Verily when he died he was resting against my chest (or said: in my lap) and he asked for a wash-basin and then collapsed while in that state, and I could not even perceive that he had died, so when did he appoint him by will?}}
\hadithdefcmd{bukhari}{2742}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ ـ رضى الله عنه ـ قَالَ جَاءَ النَّبِيُّ صلى الله عليه وسلم يَعُودُنِي وَأَنَا بِمَكَّةَ، وَهْوَ يَكْرَهُ أَنْ يَمُوتَ بِالأَرْضِ الَّتِي هَاجَرَ مِنْهَا قَالَ ‏"‏ يَرْحَمُ اللَّهُ ابْنَ عَفْرَاءَ ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ، أُوصِي بِمَالِي كُلِّهِ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ فَالشَّطْرُ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ الثُّلُثُ‏.‏ قَالَ ‏"‏ فَالثُّلُثُ، وَالثُّلُثُ كَثِيرٌ، إِنَّكَ أَنْ تَدَعَ وَرَثَتَكَ أَغْنِيَاءَ خَيْرٌ مِنْ أَنْ تَدَعَهُمْ عَالَةً يَتَكَفَّفُونَ النَّاسَ فِي أَيْدِيهِمْ، وَإِنَّكَ مَهْمَا أَنْفَقْتَ مِنْ نَفَقَةٍ فَإِنَّهَا صَدَقَةٌ، حَتَّى اللُّقْمَةُ الَّتِي تَرْفَعُهَا إِلَى فِي امْرَأَتِكَ، وَعَسَى اللَّهُ أَنْ يَرْفَعَكَ فَيَنْتَفِعَ بِكَ نَاسٌ وَيُضَرَّ بِكَ آخَرُونَ ‏"‏‏.‏ وَلَمْ يَكُنْ لَهُ يَوْمَئِذٍ إِلاَّ ابْنَةٌ‏.‏\hadithno{2742}\hadithtrans{Narrated Sa`d bin Abu Waqqas:The Prophet (ﷺ) came visiting me while I was (sick) in Mecca, ('Amir the sub-narrator said, and he disliked to die in the land, whence he had already migrated). He (i.e. the Prophet) said, "May Allah bestow His Mercy on Ibn Afra (Sa`d bin Khaula)." I said, "O Allah's Messenger (ﷺ)! May I will all my property (in charity)?" He said, "No." I said, "Then may I will half of it?" He said, "No". I said, "One third?" He said: "Yes, one third, yet even one third is too much. It is better for you to leave your inheritors wealthy than to leave them poor begging others, and whatever you spend for Allah's sake will be considered as a charitable deed even the handful of food you put in your wife's mouth. Allah may lengthen your age so that some people may benefit by you, and some others be harmed by you." At that time Sa`d had only one daughter}}
\hadithdefcmd{bukhari}{2743}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَوْ غَضَّ النَّاسُ إِلَى الرُّبْعِ، لأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الثُّلُثُ، وَالثُّلُثُ كَثِيرٌ أَوْ كَبِيرٌ ‏"‏‏.‏\hadithno{2743}\hadithtrans{Narrated Ibn `Abbas:I recommend that people reduce the proportion of what they bequeath by will to the fourth (of the whole legacy), for Allah's Messenger (ﷺ) said, "One-third, yet even one third is too much}}
\hadithdefcmd{bukhari}{2744}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ عَدِيٍّ، حَدَّثَنَا مَرْوَانُ، عَنْ هَاشِمِ بْنِ هَاشِمٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ مَرِضْتُ فَعَادَنِي النَّبِيُّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ لاَ يَرُدَّنِي عَلَى عَقِبِي‏.‏ قَالَ ‏"‏ لَعَلَّ اللَّهَ يَرْفَعُكَ وَيَنْفَعُ بِكَ نَاسًا ‏"‏‏.‏ قُلْتُ أُرِيدُ أَنْ أُوصِيَ، وَإِنَّمَا لِي ابْنَةٌ ـ قُلْتُ ـ أُوصِي بِالنِّصْفِ قَالَ ‏"‏ النِّصْفُ كَثِيرٌ ‏"‏‏.‏ قُلْتُ فَالثُّلُثِ‏.‏ قَالَ ‏"‏ الثُّلُثُ، وَالثُّلُثُ كَثِيرٌ أَوْ كَبِيرٌ ‏"‏‏.‏ قَالَ فَأَوْصَى النَّاسُ بِالثُّلُثِ، وَجَازَ ذَلِكَ لَهُمْ‏.‏\hadithno{2744}\hadithtrans{Narrated Sa`d:I fell sick and the Prophet (ﷺ) paid me a visit. I said to him, "O Allah's Messenger (ﷺ)! I invoke Allah that He may not let me expire in the land whence I migrated (i.e. Mecca)." He said, "May Allah give you health and let the people benefit by you." I said, "I want to will my property, and I have only one daughter and I want to will half of my property (to be given in charity)." He said," Half is too much." I said, "Then I will one third." He said, "One-third, yet even one-third is too much." (The narrator added, "So the people started to will one third of their property and that was Permitted for them)}}
\hadithdefcmd{bukhari}{2745}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كَانَ عُتْبَةُ بْنُ أَبِي وَقَّاصٍ عَهِدَ إِلَى أَخِيهِ سَعْدِ بْنِ أَبِي وَقَّاصٍ أَنَّ ابْنَ وَلِيدَةِ زَمْعَةَ مِنِّي، فَاقْبِضْهُ إِلَيْكَ‏.‏ فَلَمَّا كَانَ عَامُ الْفَتْحِ أَخَذَهُ سَعْدٌ فَقَالَ ابْنُ أَخِي، قَدْ كَانَ عَهِدَ إِلَىَّ فِيهِ‏.‏ فَقَامَ عَبْدُ بْنُ زَمْعَةَ فَقَالَ أَخِي، وَابْنُ أَمَةِ أَبِي، وُلِدَ عَلَى فِرَاشِهِ‏.‏ فَتَسَاوَقَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَقَالَ سَعْدٌ يَا رَسُولَ اللَّهِ، ابْنُ أَخِي، كَانَ عَهِدَ إِلَىَّ فِيهِ‏.‏ فَقَالَ عَبْدُ بْنُ زَمْعَةَ أَخِي وَابْنُ وَلِيدَةِ أَبِي‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هُوَ لَكَ يَا عَبْدُ ابْنَ زَمْعَةَ، الْوَلَدُ لِلْفِرَاشِ، وَلِلْعَاهِرِ الْحَجَرُ ‏"‏‏.‏ ثُمَّ قَالَ لِسَوْدَةَ بِنْتِ زَمْعَةَ ‏"‏ احْتَجِبِي مِنْهُ ‏"‏‏.‏ لِمَا رَأَى مِنْ شَبَهِهِ بِعُتْبَةَ، فَمَا رَآهَا حَتَّى لَقِيَ اللَّهَ‏.‏\hadithno{2745}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) `Utba bin Abi Waqqas entrusted (his son) to his brother Sa`d bin Abi Waqqas saying, "The son of the slave-girl of Zam`a is my (illegal) son, take him into your custody." So during the year of the Conquest (of Mecca) Sa`d took the boy and said, "This is my brother's son whom my brother entrusted to me." 'Abu bin Zam'a got up and said, "He is my brother and the son of the slave girl of my father and was born on my father's bed." Then both of them came to Allah's Apostle and Sa`d said, "O Allah's Messenger (ﷺ)! This is my brother's son whom my brother entrusted to me." Then 'Abu bin Zam`a got up and said, "This is my brother and the son of the slave-girl of my father." Allah's Messenger (ﷺ) said, "O Abu bin Zam`a! This boy is for you as the boy belongs to the bed (where he was born), and for the adulterer is the stone (i.e. deprivation)." Then the Prophet (ﷺ) said to his wife Sauda bint Zam`a, "Screen yourself from this boy," when he saw the boy's resemblance to `Utba. Since then the boy did not see Sauda till he died}}
\hadithdefcmd{bukhari}{2746}{حَدَّثَنَا حَسَّانُ بْنُ أَبِي عَبَّادٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ يَهُوِدِيًّا، رَضَّ رَأْسَ جَارِيَةٍ بَيْنَ حَجَرَيْنِ، فَقِيلَ لَهَا مَنْ فَعَلَ بِكِ، أَفُلاَنٌ أَوْ فُلاَنٌ حَتَّى سُمِّيَ الْيَهُودِيُّ، فَأَوْمَأَتْ بِرَأْسِهَا، فَجِيءَ بِهِ، فَلَمْ يَزَلْ حَتَّى اعْتَرَفَ، فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم فَرُضَّ رَأْسُهُ بِالْحِجَارَةِ‏.‏\hadithno{2746}\hadithtrans{Narrated Anas:A Jew crushed the head of a girl between two stones. She was asked, "Who has done so to you, so-and-so? So-and-so?" Till the name of the Jew was mentioned, whereupon she nodded (in agreement). So the Jew was brought and was questioned till he confessed. The Prophet (ﷺ) then ordered that his head be crushed with stones}}
\hadithdefcmd{bukhari}{2747}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنْ وَرْقَاءَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ الْمَالُ لِلْوَلَدِ، وَكَانَتِ الْوَصِيَّةُ لِلْوَالِدَيْنِ، فَنَسَخَ اللَّهُ مِنْ ذَلِكَ مَا أَحَبَّ، فَجَعَلَ لِلذَّكَرِ مِثْلَ حَظِّ الأُنْثَيَيْنِ، وَجَعَلَ لِلأَبَوَيْنِ لِكُلِّ وَاحِدٍ مِنْهُمَا السُّدُسَ، وَجَعَلَ لِلْمَرْأَةِ الثُّمُنَ وَالرُّبْعَ، وَلِلزَّوْجِ الشَّطْرَ وَالرُّبُعَ‏.‏\hadithno{2747}\hadithtrans{Narrated Ibn `Abbas:The custom (in old days) was that the property of the deceased would be inherited by his offspring; as for the parents (of the deceased), they would inherit by the will of the deceased. Then Allah cancelled from that custom whatever He wished and fixed for the male double the amount inherited by the female, and for each parent a sixth (of the whole legacy) and for the wife an eighth or a fourth and for the husband a half or a fourth}}
\hadithdefcmd{bukhari}{2748}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ سُفْيَانَ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَجُلٌ لِلنَّبِيِّ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ، أَىُّ الصَّدَقَةِ أَفْضَلُ قَالَ ‏ "‏ أَنْ تَصَدَّقَ وَأَنْتَ صَحِيحٌ حَرِيصٌ‏.‏ تَأْمُلُ الْغِنَى، وَتَخْشَى الْفَقْرَ، وَلاَ تُمْهِلْ حَتَّى إِذَا بَلَغَتِ الْحُلْقُومَ قُلْتَ لِفُلاَنٍ كَذَا وَلِفُلاَنٍ كَذَا، وَقَدْ كَانَ لِفُلاَنٍ ‏"‏‏.‏\hadithno{2748}\hadithtrans{Narrated Abu Huraira:A man asked the Prophet, "O Allah's Messenger (ﷺ)! What kind of charity is the best?" He replied. "To give in charity when you are healthy and greedy hoping to be wealthy and afraid of becoming poor. Don't delay giving in charity till the time when you are on the death bed when you say, 'Give so much to so-and-so and so much to so-and-so,' and at that time the property is not yours but it belongs to so-and-so (i.e. your inheritors)}}
\hadithdefcmd{bukhari}{2749}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ أَبُو الرَّبِيعِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، حَدَّثَنَا نَافِعُ بْنُ مَالِكِ بْنِ أَبِي عَامِرٍ أَبُو سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ آيَةُ الْمُنَافِقِ ثَلاَثٌ، إِذَا حَدَّثَ كَذَبَ، وَإِذَا اؤْتُمِنَ خَانَ، وَإِذَا وَعَدَ أَخْلَفَ ‏"‏‏.‏\hadithno{2749}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The signs of a hypocrite are three: Whenever he speaks he tells a lie; whenever he is entrusted he proves dishonest; whenever he promises he breaks his promise}}
\hadithdefcmd{bukhari}{2750}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَعُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ حَكِيمَ بْنَ حِزَامٍ ـ رضى الله عنه ـ قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَعْطَانِي، ثُمَّ سَأَلْتُهُ فَأَعْطَانِي ثُمَّ قَالَ لِي ‏ "‏ يَا حَكِيمُ، إِنَّ هَذَا الْمَالَ خَضِرٌ حُلْوٌ، فَمَنْ أَخَذَهُ بِسَخَاوَةِ نَفْسٍ بُورِكَ لَهُ فِيهِ، وَمَنْ أَخَذَهُ بِإِشْرَافِ نَفْسٍ لَمْ يُبَارَكْ لَهُ فِيهِ، وَكَانَ كَالَّذِي يَأْكُلُ وَلاَ يَشْبَعُ، وَالْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى ‏"‏‏.‏ قَالَ حَكِيمٌ فَقُلْتُ يَا رَسُولَ اللَّهِ، وَالَّذِي بَعَثَكَ بِالْحَقِّ لاَ أَرْزَأُ أَحَدًا بَعْدَكَ شَيْئًا حَتَّى أُفَارِقَ الدُّنْيَا‏.‏ فَكَانَ أَبُو بَكْرٍ يَدْعُو حَكِيمًا لِيُعْطِيَهُ الْعَطَاءَ فَيَأْبَى أَنْ يَقْبَلَ مِنْهُ شَيْئًا، ثُمَّ إِنَّ عُمَرَ دَعَاهُ لِيُعْطِيَهُ فَيَأْبَى أَنْ يَقْبَلَهُ فَقَالَ يَا مَعْشَرَ الْمُسْلِمِينَ، إِنِّي أَعْرِضُ عَلَيْهِ حَقَّهُ الَّذِي قَسَمَ اللَّهُ لَهُ مِنْ هَذَا الْفَىْءِ فَيَأْبَى أَنْ يَأْخُذَهُ‏.‏ فَلَمْ يَرْزَأْ حَكِيمٌ أَحَدًا مِنَ النَّاسِ بَعْدَ النَّبِيِّ صلى الله عليه وسلم حَتَّى تُوُفِّيَ رَحِمَهُ اللَّهُ‏.‏\hadithno{2750}\hadithtrans{Narrated `Urwa bin Az-Zubair:Hakim bin Hizam said, "I asked Allah's Messenger (ﷺ) for something, and he gave me, and I asked him again and he gave me and said, 'O Hakim! This wealth is green and sweet (i.e. as tempting as fruits), and whoever takes it without greed then he is blessed in it, and whoever takes it with greediness, he is not blessed in it and he is like one who eats and never gets satisfied. The upper (i.e. giving) hand is better than the lower (i.e. taking) hand." Hakim added, "I said, O Allah's Messenger (ﷺ)! By Him Who has sent you with the Truth I will never demand anything from anybody after you till I die." Afterwards Abu Bakr used to call Hakim to give him something but he refused to accept anything from him. Then `Umar called him to give him (something) but he refused. Then `Umar said, "O Muslims! I offered to him (i.e. Hakim) his share which Allah has ordained for him from this booty and he refuses to take it." Thus Hakim did not ask anybody for anything after the Prophet, till he died--may Allah bestow His mercy upon him}}
\hadithdefcmd{bukhari}{2751}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ السَّخْتِيَانِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ كُلُّكُمْ رَاعٍ وَمَسْئُولٌ عَنْ رَعِيَّتِهِ، وَالإِمَامُ رَاعٍ وَمَسْئُولٌ عَنْ رَعِيَّتِهِ، وَالرَّجُلُ رَاعٍ فِي أَهْلِهِ وَمَسْئُولٌ عَنْ رَعِيَّتِهِ، وَالْمَرْأَةُ فِي بَيْتِ زَوْجِهَا رَاعِيَةٌ وَمَسْئُولَةٌ عَنْ رَعِيَّتِهَا، وَالْخَادِمُ فِي مَالِ سَيِّدِهِ رَاعٍ وَمَسْئُولٌ عَنْ رَعِيَّتِهِ ‏"‏‏.‏ قَالَ وَحَسِبْتُ أَنْ قَدْ قَالَ ‏"‏ وَالرَّجُلُ رَاعٍ فِي مَالِ أَبِيهِ ‏"‏‏.‏\hadithno{2751}\hadithtrans{Narrated Ibn `Umar:I heard Allah's Messenger (ﷺ) saying, "All of you are guardians and responsible for your charges: the Ruler (i.e. Imam) is a guardian and responsible for his subjects; and a man is a guardian of his family and is responsible for his charges; and a lady is a guardian in the house of her husband and is responsible for her charge; and a servant is a guardian of the property of his master and is responsible for his charge." I think he also said, "And a man is a guardian of the property of his father}}
\hadithdefcmd{bukhari}{2752}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسًا ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم لأَبِي طَلْحَةَ ‏"‏ أَرَى أَنْ تَجْعَلَهَا فِي الأَقْرَبِينَ ‏"‏‏.‏ قَالَ أَبُو طَلْحَةَ أَفْعَلُ يَا رَسُولَ اللَّهِ‏.‏ فَقَسَمَهَا أَبُو طَلْحَةَ فِي أَقَارِبِهِ وَبَنِي عَمِّهِ‏.‏ وَقَالَ ابْنُ عَبَّاسٍ لَمَّا نَزَلَتْ ‏\{‏وَأَنْذِرْ عَشِيرَتَكَ الأَقْرَبِينَ‏\}‏ جَعَلَ النَّبِيُّ صلى الله عليه وسلم يُنَادِي ‏"‏ يَا بَنِي فِهْرٍ، يَا بَنِي عَدِيٍّ ‏"‏‏.‏ لِبُطُونِ قُرَيْشٍ‏.‏ وَقَالَ أَبُو هُرَيْرَةَ لَمَّا نَزَلَتْ ‏\{‏وَأَنْذِرْ عَشِيرَتَكَ الأَقْرَبِينَ‏\}‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا مَعْشَرَ قُرَيْشٍ ‏"‏‏.‏\hadithno{2752}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said to Abu Talha, "I recommend that you divide (this garden) amongst your relatives." Abu Talha said, "O Allah's Messenger (ﷺ)! I will do the same." So Abu Talha divided it among his relatives and cousins. Ibn 'Abbas said, "When the Qur'anic Verse: "Warn your nearest kinsmen." (26.214) Was revealed, the Prophet (ﷺ) started calling the various big families of Quraish, "O Bani Fihr! O Bani Adi!". Abu Huraira said, "When the Verse: "Warn your nearest kinsmen" was revealed, the Prophet (ﷺ) said (in a loud voice), "O people of Quraish}}
\hadithdefcmd{bukhari}{2753}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏وَأَنْذِرْ عَشِيرَتَكَ الأَقْرَبِينَ ‏\}‏ قَالَ ‏"‏ يَا مَعْشَرَ قُرَيْشٍ ـ أَوْ كَلِمَةً نَحْوَهَا ـ اشْتَرُوا أَنْفُسَكُمْ، لاَ أُغْنِي عَنْكُمْ مِنَ اللَّهِ شَيْئًا، يَا بَنِي عَبْدِ مَنَافٍ لاَ أُغْنِي عَنْكُمْ مِنَ اللَّهِ شَيْئًا، يَا عَبَّاسُ بْنَ عَبْدِ الْمُطَّلِبِ لاَ أُغْنِي عَنْكَ مِنَ اللَّهِ شَيْئًا، وَيَا صَفِيَّةُ عَمَّةَ رَسُولِ اللَّهِ لاَ أُغْنِي عَنْكِ مِنَ اللَّهِ شَيْئًا، وَيَا فَاطِمَةُ بِنْتَ مُحَمَّدٍ سَلِينِي مَا شِئْتِ مِنْ مَالِي لاَ أُغْنِي عَنْكِ مِنَ اللَّهِ شَيْئًا ‏"‏‏.‏ تَابَعَهُ أَصْبَغُ عَنِ ابْنِ وَهْبٍ عَنْ يُونُسَ عَنِ ابْنِ شِهَابٍ‏.‏\hadithno{2753}\hadithtrans{Narrated Abu Huraira:When Allah revealed the Verse: "Warn your nearest kinsmen," Allah's Messenger (ﷺ) got up and said, "O people of Quraish (or said similar words)! Buy (i.e. save) yourselves (from the Hellfire) as I cannot save you from Allah's Punishment; O Bani `Abd Manaf! I cannot save you from Allah's Punishment, O Safiya, the Aunt of Allah's Messenger (ﷺ)! I cannot save you from Allah's Punishment; O Fatima bint Muhammad! Ask me anything from my wealth, but I cannot save you from Allah's Punishment}}
\hadithdefcmd{bukhari}{2754}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى رَجُلاً يَسُوقُ بَدَنَةً، فَقَالَ لَهُ ‏"‏ ارْكَبْهَا ‏"‏‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّهَا بَدَنَةٌ‏.‏ قَالَ فِي الثَّالِثَةِ أَوِ الرَّابِعَةِ ‏"‏ ارْكَبْهَا، وَيْلَكَ، أَوْ وَيْحَكَ ‏"‏‏.‏\hadithno{2754}\hadithtrans{Narrated Anas:The Prophet (ﷺ) saw a man driving a Badana (i.e. camel for sacrifice) and said to him, "Ride on it." The man said, "O Allah's Messenger (ﷺ)! It is a Badana." (The Prophet (ﷺ) repeated his order) and on the third or fourth time he said, "Ride it, (woe to you" or said: "May Allah be merciful to you)}}
\hadithdefcmd{bukhari}{2755}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً يَسُوقُ بَدَنَةً، فَقَالَ ‏"‏ ارْكَبْهَا ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ إِنَّهَا بَدَنَةٌ‏.‏ قَالَ ‏"‏ ارْكَبْهَا، وَيْلَكَ ‏"‏‏.‏ فِي الثَّانِيَةِ أَوْ فِي الثَّالِثَةِ‏.‏\hadithno{2755}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) saw a man driving a Badana and said to him, "Ride on it," and on the second or the third time he added, "Woe to you}}
\hadithdefcmd{bukhari}{2756}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا مَخْلَدُ بْنُ يَزِيدَ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي يَعْلَى، أَنَّهُ سَمِعَ عِكْرِمَةَ، يَقُولُ أَنْبَأَنَا ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ سَعْدَ بْنَ عُبَادَةَ ـ رضى الله عنه ـ تُوُفِّيَتْ أُمُّهُ وَهْوَ غَائِبٌ عَنْهَا، فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمِّي تُوُفِّيَتْ وَأَنَا غَائِبٌ عَنْهَا، أَيَنْفَعُهَا شَىْءٌ إِنْ تَصَدَّقْتُ بِهِ عَنْهَا قَالَ ‏ "‏ نَعَمْ ‏"‏‏.‏ قَالَ فَإِنِّي أُشْهِدُكَ أَنَّ حَائِطِي الْمِخْرَافَ صَدَقَةٌ عَلَيْهَا‏.‏\hadithno{2756}\hadithtrans{Narrated Ibn `Abbas:The mother of Sa`d bin 'Ubada died in his absence. He said, "O Allah's Messenger (ﷺ)! My mother died in my absence; will it be of any benefit for her if I give Sadaqa on her behalf?" The Prophet (ﷺ) said, "Yes," Sa`d said, "I make you a witness that I gave my garden called Al Makhraf in charity on her behalf}}
\hadithdefcmd{bukhari}{2757}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبٍ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبٍ، قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ ـ رضى الله عنه‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ، إِنَّ مِنْ تَوْبَتِي أَنْ أَنْخَلِعَ مِنْ مَالِي صَدَقَةً إِلَى اللَّهِ وَإِلَى رَسُولِهِ صلى الله عليه وسلم‏.‏ قَالَ ‏ "‏ أَمْسِكْ عَلَيْكَ بَعْضَ مَالِكَ فَهُوَ خَيْرٌ لَكَ ‏"‏‏.‏ قُلْتُ فَإِنِّي أُمْسِكُ سَهْمِي الَّذِي بِخَيْبَرَ‏.‏\hadithno{2757}\hadithtrans{Narrated Ka`b bin Malik:I said, "O Allah's Messenger (ﷺ)! For the acceptance of my repentance I wish to give all my property in charity for Allah's sake through His Apostle ." He said, "It is better for you to keep some of the property for yourself." I said, "Then I will keep my share in Khaibar}}
\hadithdefcmd{bukhari}{2758}{وَقَالَ إِسْمَاعِيلُ أَخْبَرَنِي عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي سَلَمَةَ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ،، لاَ أَعْلَمُهُ إِلاَّ عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ لَمَّا نَزَلَتْ ‏\{‏لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ جَاءَ أَبُو طَلْحَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ يَقُولُ اللَّهُ تَبَارَكَ وَتَعَالَى فِي كِتَابِهِ ‏\{‏لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ وَإِنَّ أَحَبَّ أَمْوَالِي إِلَىَّ بِيرُحَاءَ ـ قَالَ وَكَانَتْ حَدِيقَةً كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْخُلُهَا وَيَسْتَظِلُّ بِهَا وَيَشْرَبُ مِنْ مَائِهَا ـ فَهِيَ إِلَى اللَّهِ عَزَّ وَجَلَّ وَإِلَى رَسُولِهِ صلى الله عليه وسلم أَرْجُو بِرَّهُ وَذُخْرَهُ، فَضَعْهَا أَىْ رَسُولَ اللَّهِ حَيْثُ أَرَاكَ اللَّهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَخْ يَا أَبَا طَلْحَةَ، ذَلِكَ مَالٌ رَابِحٌ، قَبِلْنَاهُ مِنْكَ وَرَدَدْنَاهُ عَلَيْكَ، فَاجْعَلْهُ فِي الأَقْرَبِينَ ‏"‏‏.‏ فَتَصَدَّقَ بِهِ أَبُو طَلْحَةَ عَلَى ذَوِي رَحِمِهِ، قَالَ وَكَانَ مِنْهُمْ أُبَىٌّ وَحَسَّانُ، قَالَ وَبَاعَ حَسَّانُ حِصَّتَهُ مِنْهُ مِنْ مُعَاوِيَةَ، فَقِيلَ لَهُ تَبِيعُ صَدَقَةَ أَبِي طَلْحَةَ فَقَالَ أَلاَ أَبِيعُ صَاعًا مِنْ تَمْرٍ بِصَاعٍ مِنْ دَرَاهِمَ قَالَ وَكَانَتْ تِلْكَ الْحَدِيقَةُ فِي مَوْضِعِ قَصْرِ بَنِي حُدَيْلَةَ الَّذِي بَنَاهُ مُعَاوِيَةُ‏.‏\hadithno{2758}\hadithtrans{Narrated Anas (ra):When the Holy Verse: 'By no means shall you attain Al-Birr (piety, righteousness, it means here Allah's Reward i.e., Paradise), unless you spend of that which you love..', (V 3:92) was revealed, Abu Talha went to Allah's Messenger (ﷺ) and said, "O Allah's Messenger ! Allah, the Blessed, the Superior stated in His book: 'By no means shall you attain Birr, unless you spend of that which you love....' (V 3:92) and the most beloved property to me is Bairuha' (which was a garden where Allah's Messenger (ﷺ) used to go to sit in its shade and drink from its water). I give it to Allah and His Messenger (ﷺ) hoping for Allah's Reward in the Hereafter. So, O Allah's Messenger! Use it as Allah orders you to use it." Allah's Messenger (ﷺ) said, "Bravo! O Abu Talha, it is fruitful property. We have accepted it from you and now we return it to you. Distribute it amongst your relatives." So, Abu Talha distributed it amongst his relatives, amongst whom were Ubai and Hassan. When Hassan sold his share of that garden to Mu'awiyya, he was asked, "How do you sell Abu Talha's Sadaqa?" He replied, "Why should not I sell a Sa' of date for Sa' of money?" The garden was situated on the courtyard of the palace of Bani Hudailah built by Mu'awiya}}
\hadithdefcmd{bukhari}{2759}{حَدَّثَنَا مُحَمَّدُ بْنُ الْفَضْلِ أَبُو النُّعْمَانِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ إِنَّ نَاسًا يَزْعُمُونَ أَنَّ هَذِهِ الآيَةَ نُسِخَتْ، وَلاَ وَاللَّهِ مَا نُسِخَتْ، وَلَكِنَّهَا مِمَّا تَهَاوَنَ النَّاسُ، هُمَا وَالِيَانِ وَالٍ يَرِثُ، وَذَاكَ الَّذِي يَرْزُقُ، وَوَالٍ لاَ يَرِثُ، فَذَاكَ الَّذِي يَقُولُ بِالْمَعْرُوفِ، يَقُولُ لاَ أَمْلِكُ لَكَ أَنْ أُعْطِيَكَ‏.‏\hadithno{2759}\hadithtrans{Narrated Ibn `Abbas:Some people claim that the order in the above Verse is cancelled, by Allah, it is not cancelled, but the people have stopped acting on it. There are two kinds of guardians (who are in charge of the inheritance): One is that who inherits; such a person should give (of what he inherits to the relatives, the orphans and the needy, etc.), the other is that who does not inherit (e.g. the guardian of the orphans): such a person should speak kindly and say (to those who are present at the time of distribution), "I can not give it to you (as the wealth belongs to the orphans)}}
\hadithdefcmd{bukhari}{2760}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَجُلاً، قَالَ لِلنَّبِيِّ صلى الله عليه وسلم إِنَّ أُمِّي افْتُلِتَتْ نَفْسَهَا، وَأُرَاهَا لَوْ تَكَلَّمَتْ تَصَدَّقَتْ، أَفَأَتَصَدَّقُ عَنْهَا قَالَ ‏ "‏ نَعَمْ، تَصَدَّقْ عَنْهَا ‏"‏‏.‏\hadithno{2760}\hadithtrans{Narrated `Aisha:A man said to the Prophet, "My mother died suddenly, and I think that if she could speak, she would have given in charity. May I give in charity on her behalf?" He said, "Yes! Give in charity on her behalf}}
\hadithdefcmd{bukhari}{2761}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ سَعْدَ بْنَ عُبَادَةَ ـ رضى الله عنه ـ اسْتَفْتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ أُمِّي مَاتَتْ وَعَلَيْهَا نَذْرٌ‏.‏ فَقَالَ ‏ "‏ اقْضِهِ عَنْهَا ‏"‏‏.‏\hadithno{2761}\hadithtrans{Narrated Ibn `Abbas:Sa`d bin Ubada consulted Allah's Messenger (ﷺ) saying, "My mother died and she had an unfulfilled vow." The Prophet (ﷺ) said, "Fulfill it on her behalf}}
\hadithdefcmd{bukhari}{2762}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي يَعْلَى، أَنَّهُ سَمِعَ عِكْرِمَةَ، مَوْلَى ابْنِ عَبَّاسٍ يَقُولُ أَنْبَأَنَا ابْنُ عَبَّاسٍ، أَنَّ سَعْدَ بْنَ عُبَادَةَ ـ رضى الله عنهم ـ أَخَا بَنِي سَاعِدَةَ تُوُفِّيَتْ أُمُّهُ وَهْوَ غَائِبٌ، فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمِّي تُوُفِّيَتْ وَأَنَا غَائِبٌ عَنْهَا، فَهَلْ يَنْفَعُهَا شَىْءٌ إِنْ تَصَدَّقْتُ بِهِ عَنْهَا قَالَ ‏ "‏ نَعَمْ ‏"‏‏.‏ قَالَ فَإِنِّي أُشْهِدُكَ أَنَّ حَائِطِي الْمِخْرَافَ صَدَقَةٌ عَلَيْهَا‏.‏\hadithno{2762}\hadithtrans{Narrated Ibn `Abbas:That the mother of Sa`d bin Ubada the brother of Bani Saida died in Sa`d's absence, so he came to the Prophet saying, "O Allah's Messenger (ﷺ)! My mother died in my absence, will it benefit her if I give in charity on her behalf?" The Prophet (ﷺ) said, "Yes." Sa`d said, "I take you as my witness that I give my garden Al-Makhraf in charity on her behalf}}
\hadithdefcmd{bukhari}{2763}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ كَانَ عُرْوَةُ بْنُ الزُّبَيْرِ يُحَدِّثُ أَنَّهُ سَأَلَ عَائِشَةَ ـ رضى الله عنها – ‏\{‏وَإِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى فَانْكِحُوا مَا طَابَ لَكُمْ مِنَ النِّسَاءِ‏\}‏ قَالَتْ هِيَ الْيَتِيمَةُ فِي حَجْرِ وَلِيِّهَا، فَيَرْغَبُ فِي جَمَالِهَا وَمَالِهَا، وَيُرِيدُ أَنْ يَتَزَوَّجَهَا بِأَدْنَى مِنْ سُنَّةِ نِسَائِهَا، فَنُهُوا عَنْ نِكَاحِهِنَّ، إِلاَّ أَنْ يُقْسِطُوا لَهُنَّ فِي إِكْمَالِ الصَّدَاقِ، وَأُمِرُوا بِنِكَاحِ مَنْ سِوَاهُنَّ مِنَ النِّسَاءِ قَالَتْ عَائِشَةُ ثُمَّ اسْتَفْتَى النَّاسُ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدُ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏وَيَسْتَفْتُونَكَ فِي النِّسَاءِ قُلِ اللَّهُ يُفْتِيكُمْ فِيهِنَّ‏\}‏ قَالَتْ فَبَيَّنَ اللَّهُ فِي هَذِهِ أَنَّ الْيَتِيمَةَ إِذَا كَانَتْ ذَاتَ جَمَالٍ وَمَالٍ رَغِبُوا فِي نِكَاحِهَا، وَلَمْ يُلْحِقُوهَا بِسُنَّتِهَا بِإِكْمَالِ الصَّدَاقِ، فَإِذَا كَانَتْ مَرْغُوبَةً عَنْهَا فِي قِلَّةِ الْمَالِ وَالْجَمَالِ تَرَكُوهَا وَالْتَمَسُوا غَيْرَهَا مِنَ النِّسَاءِ، قَالَ فَكَمَا يَتْرُكُونَهَا حِينَ يَرْغَبُونَ عَنْهَا فَلَيْسَ لَهُمْ أَنْ يَنْكِحُوهَا إِذَا رَغِبُوا فِيهَا إِلاَّ أَنْ يُقْسِطُوا لَهَا الأَوْفَى مِنَ الصَّدَاقِ وَيُعْطُوهَا حَقَّهَا‏.‏\hadithno{2763}\hadithtrans{Narrated Az-Zuhri:`Urwa bin Az-Zubair said that he asked `Aisha about the meaning of the Qur'anic Verse:-- "And if you fear that you will not deal fairly with the orphan girls then marry (other) women of your choice." (4.2-3) Aisha said, "It is about a female orphan under the guardianship of her guardian who is inclined towards her because of her beauty and wealth, and likes to marry her with a Mahr less than what is given to women of her standard. So they (i.e. guardians) were forbidden to marry the orphans unless they paid them a full appropriate Mahr (otherwise) they were ordered to marry other women instead of them. Later on the people asked Allah's Messenger (ﷺ) about it. So Allah revealed the following Verse:-- "They ask your instruction (O Muhammad!) regarding women. Say: Allah instructs you regarding them..." (4.127) and in this Verse Allah indicated that if the orphan girl was beautiful and wealthy, her guardian would have the desire to marry her without giving her an appropriate Mahr equal to what her peers could get, but if she was undesirable for lack of beauty or wealth, then he would not marry her, but seek to marry some other woman instead of her. So, since he did not marry her when he had no inclination towards her, he had not the right to marry her when he had an interest in her, unless he treated her justly by giving her a full Mahr and securing all her rights}}
\hadithdefcmd{bukhari}{2764}{حَدَّثَنَا هَارُونُ، حَدَّثَنَا أَبُو سَعِيدٍ، مَوْلَى بَنِي هَاشِمٍ حَدَّثَنَا صَخْرُ بْنُ جُوَيْرِيَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ عُمَرَ، تَصَدَّقَ بِمَالٍ لَهُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَ يُقَالُ لَهُ ثَمْغٌ، وَكَانَ نَخْلاً، فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ إِنِّي اسْتَفَدْتُ مَالاً وَهُوَ عِنْدِي نَفِيسٌ فَأَرَدْتُ أَنْ أَتَصَدَّقَ بِهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ تَصَدَّقْ بِأَصْلِهِ، لاَ يُبَاعُ وَلاَ يُوهَبُ وَلاَ يُورَثُ، وَلَكِنْ يُنْفَقُ ثَمَرُهُ ‏"‏‏.‏ فَتَصَدَّقَ بِهِ عُمَرُ، فَصَدَقَتُهُ ذَلِكَ فِي سَبِيلِ اللَّهِ وَفِي الرِّقَابِ وَالْمَسَاكِينِ وَالضَّيْفِ وَابْنِ السَّبِيلِ وَلِذِي الْقُرْبَى، وَلاَ جُنَاحَ عَلَى مَنْ وَلِيَهُ أَنْ يَأْكُلَ مِنْهُ بِالْمَعْرُوفِ، أَوْ يُوكِلَ صَدِيقَهُ غَيْرَ مُتَمَوِّلٍ بِهِ‏.‏\hadithno{2764}\hadithtrans{Narrated Ibn `Umar:In the lifetime of Allah's Messenger (ﷺ) , `Umar gave in charity some of his property, a garden of date-palms called Thamgh. `Umar said, "O Allah's Messenger (ﷺ)! I have some property which I prize highly and I want to give it in charity." The Prophet; said, "Give it in charity (i.e. as an endowment) with its land and trees on the condition that the land and trees will neither be sold nor given as a present, nor bequeathed, but the fruits are to be spent in charity." So `Umar gave it in charity, and it was for Allah's Cause, the emancipation of slaves, for the poor, for guests, for travelers, and for kinsmen. The person acting as its administrator could eat from it reasonably and fairly, and could let a friend of his eat from it provided he had no intention of becoming wealthy by its means}}
\hadithdefcmd{bukhari}{2765}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها – ‏\{‏وَمَنْ كَانَ غَنِيًّا فَلْيَسْتَعْفِفْ وَمَنْ كَانَ فَقِيرًا فَلْيَأْكُلْ بِالْمَعْرُوفِ‏\}‏‏.‏ قَالَتْ أُنْزِلَتْ فِي وَالِي الْيَتِيمِ أَنْ يُصِيبَ مِنْ مَالِهِ إِذَا كَانَ مُحْتَاجًا بِقَدْرِ مَالِهِ بِالْمَعْرُوفِ‏.‏\hadithno{2765}\hadithtrans{Narrated `Aisha:The following Verse:-- "If a guardian is well-off, let him claim no remuneration (i.e. wages), but if he is poor, let him have for himself what is just and reasonable." (4.6) was revealed in connection with the guardian of an orphan, and it means that if he is poor he can have for himself (from the orphan's wealth) what is just and reasonable according to the orphan's share of the inheritance}}
\hadithdefcmd{bukhari}{2766}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ الْمَدَنِيِّ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ اجْتَنِبُوا السَّبْعَ الْمُوبِقَاتِ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ، وَمَا هُنَّ قَالَ ‏"‏ الشِّرْكُ بِاللَّهِ، وَالسِّحْرُ، وَقَتْلُ النَّفْسِ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ، وَأَكْلُ الرِّبَا، وَأَكْلُ مَالِ الْيَتِيمِ، وَالتَّوَلِّي يَوْمَ الزَّحْفِ، وَقَذْفُ الْمُحْصَنَاتِ الْمُؤْمِنَاتِ الْغَافِلاَتِ ‏"‏‏.‏\hadithno{2766}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Avoid the seven great destructive sins." The people enquired, "O Allah's Messenger (ﷺ)! What are they?" He said, "To join others in worship along with Allah, to practice sorcery, to kill the life which Allah has forbidden except for a just cause, (according to Islamic law), to eat up Riba (usury), to eat up an orphan's wealth, to give back to the enemy and fleeing from the battlefield at the time of fighting, and to accuse, chaste women, who never even think of anything touching chastity and are good believers}}
\hadithdefcmd{bukhari}{2767}{وَقَالَ لَنَا سُلَيْمَانُ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، قَالَ مَا رَدَّ ابْنُ عُمَرَ عَلَى أَحَدٍ وَصِيَّةً‏.‏ وَكَانَ ابْنُ سِيرِينَ أَحَبَّ الأَشْيَاءِ إِلَيْهِ فِي مَالِ الْيَتِيمِ أَنْ يَجْتَمِعَ إِلَيْهِ نُصَحَاؤُهُ وَأَوْلِيَاؤُهُ فَيَنْظُرُوا الَّذِي هُوَ خَيْرٌ لَهُ‏.‏ وَكَانَ طَاوُسٌ إِذَا سُئِلَ عَنْ شَىْءٍ مِنْ أَمْرِ الْيَتَامَى قَرَأَ ‏\{‏وَاللَّهُ يَعْلَمُ الْمُفْسِدَ مِنَ الْمُصْلِحِ‏\}‏‏.‏ وَقَالَ عَطَاءٌ فِي يَتَامَى الصَّغِيرُ وَالْكَبِيرُ يُنْفِقُ الْوَلِيُّ عَلَى كُلِّ إِنْسَانٍ بِقَدْرِهِ مِنْ حِصَّتِهِ‏.‏\hadithno{2767}\hadithtrans{Nafi' said:"Ibn 'Umar never refused to be appointed as guardian." The most beloved thing to Ibn Sirin concerning an orphan's wealth was that the orphan's advisor and guardians would assemble to decide what is best for him. When Tawus was asked about something concerning an orphan's affairs, he would recite: '...And Allah knows him who means mischief from him who means good...' (V 2:220). 'Ata said concerning some orphans, "The guardian is to provide for the young and the old orphans according to their needs from their shares}}
\hadithdefcmd{bukhari}{2768}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ كَثِيرٍ، حَدَّثَنَا ابْنُ عُلَيَّةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ لَيْسَ لَهُ خَادِمٌ، فَأَخَذَ أَبُو طَلْحَةَ بِيَدِي، فَانْطَلَقَ بِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أَنَسًا غُلاَمٌ كَيِّسٌ، فَلْيَخْدُمْكَ‏.‏ قَالَ فَخَدَمْتُهُ فِي السَّفَرِ وَالْحَضَرِ، مَا قَالَ لِي لِشَىْءٍ صَنَعْتُهُ لِمَ صَنَعْتَ هَذَا هَكَذَا وَلاَ لِشَىْءٍ لَمْ أَصْنَعْهُ لِمَ لَمْ تَصْنَعْ هَذَا هَكَذَا\hadithno{2768}\hadithtrans{Narrated Anas:When Allah's Messenger (ﷺ) came to Medina; he did not have any servant. Abu Talha (Anas' step-father) took me to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Anas is a wise boy, so let him serve you." So, I served him at home and on journeys. If I did anything, he never asked me why I did it, and if I refrained from doing anything, he never asked me why I refrained from doing it}}
\hadithdefcmd{bukhari}{2769}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ كَانَ أَبُو طَلْحَةَ أَكْثَرَ أَنْصَارِيٍّ بِالْمَدِينَةِ مَالاً مِنْ نَخْلٍ، وَكَانَ أَحَبُّ مَالِهِ إِلَيْهِ بَيْرَحَاءَ مُسْتَقْبِلَةَ الْمَسْجِدِ، وَكَانَ النَّبِيُّ صلى الله عليه وسلم يَدْخُلُهَا وَيَشْرَبُ مِنْ مَاءٍ فِيهَا طَيِّبٍ‏.‏ قَالَ أَنَسٌ فَلَمَّا نَزَلَتْ ‏\{‏لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ قَامَ أَبُو طَلْحَةَ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ يَقُولُ ‏\{‏لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ وَإِنَّ أَحَبَّ أَمْوَالِي إِلَىَّ بِيرُحَاءَ، وَإِنَّهَا صَدَقَةٌ لِلَّهِ أَرْجُو بِرَّهَا وَذُخْرَهَا عِنْدَ اللَّهِ، فَضَعْهَا حَيْثُ أَرَاكَ اللَّهُ‏.‏ فَقَالَ ‏"‏ بَخْ، ذَلِكَ مَالٌ رَابِحٌ ـ أَوْ رَايِحٌ ـ شَكَّ ابْنُ مَسْلَمَةَ وَقَدْ سَمِعْتُ مَا قُلْتَ، وَإِنِّي أَرَى أَنْ تَجْعَلَهَا فِي الأَقْرَبِينَ ‏"‏‏.‏ قَالَ أَبُو طَلْحَةَ أَفْعَلُ ذَلِكَ يَا رَسُولَ اللَّهِ‏.‏ فَقَسَمَهَا أَبُو طَلْحَةَ فِي أَقَارِبِهِ وَفِي بَنِي عَمِّهِ‏.‏ وَقَالَ إِسْمَاعِيلُ وَعَبْدُ اللَّهِ بْنُ يُوسُفَ وَيَحْيَى بْنُ يَحْيَى عَنْ مَالِكٍ ‏"‏ رَايِحٌ ‏"‏‏.‏\hadithno{2769}\hadithtrans{Narrated Anas bin Malik:Abu Talha had the greatest wealth of date-palms amongst the Ansar in Medina, and he prized above all his wealth (his garden) Bairuha', which was situated opposite the Mosque (of the Prophet (ﷺ) ). The Prophet used to enter It and drink from its fresh water. When the following Divine Verse came:-- "By no means shall you attain piety until you spend of what you love," (3.92) Abu Talha got up saying. "O Allah's Messenger (ﷺ)! Allah says, 'You will not attain piety until you spend of what you love,' and I prize above all my wealth, Bairuha' which I want to give in charity for Allah's Sake, hoping for its reward from Allah. So you can use it as Allah directs you." On that the Prophet (ﷺ) said, "Bravo! It is a profitable (or perishable) property. (Ibn Maslama is not sure as to which word is right, i.e. profitable or perishable.) I have heard what you have said, and I recommend that you distribute this amongst your relatives." On that Abu Talha said, "O Allah's Messenger (ﷺ)! I will do (as you have suggested)." So, Abu Talha distributed that garden amongst his relatives and cousins}}
\hadithdefcmd{bukhari}{2770}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنِي عَمْرُو بْنُ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما أَنَّ رَجُلاً، قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّ أُمَّهُ تُوُفِّيَتْ أَيَنْفَعُهَا إِنْ تَصَدَّقْتُ عَنْهَا قَالَ ‏ "‏ نَعَمْ ‏"‏‏.‏ قَالَ فَإِنَّ لِي مِخْرَافًا وَأُشْهِدُكَ أَنِّي قَدْ تَصَدَّقْتُ عَنْهَا‏.‏\hadithno{2770}\hadithtrans{Narrated Ibn `Abbas:A man said to Allah's Messenger (ﷺ) , "My mother died, will it benefit her if I give in charity on her behalf?" The Prophet (ﷺ) replied in the affirmative. The man said, "I have a garden and I make you a witness that I give it in charity on her behalf}}
\hadithdefcmd{bukhari}{2771}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ أَمَرَ النَّبِيُّ صلى الله عليه وسلم بِبِنَاءِ الْمَسْجِدِ فَقَالَ ‏ "‏ يَا بَنِي النَّجَّارِ ثَامِنُونِي بِحَائِطِكُمْ هَذَا ‏"‏‏.‏ قَالُوا لاَ‏.‏ وَاللَّهِ لاَ نَطْلُبُ ثَمَنَهُ إِلاَّ إِلَى اللَّهِ‏.‏\hadithno{2771}\hadithtrans{Narrated Anas:When the Prophet (ﷺ) ordered that the mosque be built, he said, "O Bani An-Najjar! Suggest to me a price for this garden of yours." They replied, "By Allah! We will demand its price from none but Allah}}
\hadithdefcmd{bukhari}{2772}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ أَصَابَ عُمَرُ بِخَيْبَرَ أَرْضًا فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ أَصَبْتُ أَرْضًا لَمْ أُصِبْ مَالاً قَطُّ أَنْفَسَ مِنْهُ، فَكَيْفَ تَأْمُرُنِي بِهِ قَالَ ‏ "‏ إِنْ شِئْتَ حَبَّسْتَ أَصْلَهَا، وَتَصَدَّقْتَ بِهَا ‏"‏‏.‏ فَتَصَدَّقَ عُمَرُ أَنَّهُ لاَ يُبَاعُ أَصْلُهَا وَلاَ يُوهَبُ وَلاَ يُورَثُ، فِي الْفُقَرَاءِ وَالْقُرْبَى وَالرِّقَابِ وَفِي سَبِيلِ اللَّهِ وَالضَّيْفِ وَابْنِ السَّبِيلِ، وَلاَ جُنَاحَ عَلَى مَنْ وَلِيَهَا أَنْ يَأْكُلَ مِنْهَا بِالْمَعْرُوفِ، أَوْ يُطْعِمَ صَدِيقًا غَيْرَ مُتَمَوِّلٍ فِيهِ‏.‏\hadithno{2772}\hadithtrans{Narrated Ibn `Umar:When `Umar got a piece of land in Khaibar, he came to the Prophet (ﷺ) saying, "I have got a piece of land, better than which I have never got. So what do you advise me regarding it?" The Prophet (ﷺ) said, "If you wish you can keep it as an endowment to be used for charitable purposes." So, `Umar gave the land in charity (i.e. as an endowment) on the condition that the land would neither be sold nor given as a present, nor bequeathed, (and its yield) would be used for the poor, the kinsmen, the emancipation of slaves, Jihad, and for guests and travelers; and its administrator could eat in a reasonable just manner, and he also could feed his friends without intending to be wealthy by its means}}
\hadithdefcmd{bukhari}{2773}{حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، رضى الله عنه وَجَدَ مَالاً بِخَيْبَرَ، فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرَهُ، قَالَ ‏ "‏ إِنْ شِئْتَ تَصَدَّقْتَ بِهَا ‏"‏‏.‏ فَتَصَدَّقَ بِهَا فِي الْفُقَرَاءِ وَالْمَسَاكِينِ وَذِي الْقُرْبَى وَالضَّيْفِ‏.‏\hadithno{2773}\hadithtrans{Narrated Ibn `Umar:`Umar got some property in Khaibar and he came to the Prophet (ﷺ) and informed him about it. The Prophet said to him, "If you wish you can give it in charity." So `Umar gave it in charity (i.e. as an endowment) the yield of which was to be used for the good of the poor, the needy, the kinsmen and the guests}}
\hadithdefcmd{bukhari}{2774}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا عَبْدُ الصَّمَدِ، قَالَ سَمِعْتُ أَبِي، حَدَّثَنَا أَبُو التَّيَّاحِ، قَالَ حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ أَمَرَ بِالْمَسْجِدِ وَقَالَ ‏ "‏ يَا بَنِي النَّجَّارِ ثَامِنُونِي بِحَائِطِكُمْ هَذَا ‏"‏‏.‏ قَالُوا لاَ وَاللَّهِ لاَ نَطْلُبُ ثَمَنَهُ إِلاَّ إِلَى اللَّهِ‏.‏\hadithno{2774}\hadithtrans{Narrated Anas bin Malik:When Allah's Messenger (ﷺ) came to Medina, he ordered that a mosque be built. He said, "O Bani An- Najjar! Suggest me a price for the garden of yours." They replied, "By Allah, we will not ask its price except from Allah}}
\hadithdefcmd{bukhari}{2775}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا عُبَيْدُ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ عُمَرَ، حَمَلَ عَلَى فَرَسٍ لَهُ فِي سَبِيلِ اللَّهِ أَعْطَاهَا رَسُولَ اللَّهِ صلى الله عليه وسلم لِيَحْمِلَ عَلَيْهَا رَجُلاً، فَأُخْبِرَ عُمَرُ أَنَّهُ قَدْ وَقَفَهَا يَبِيعُهَا، فَسَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يَبْتَاعَهَا فَقَالَ ‏ "‏ لاَ تَبْتَعْهَا، وَلاَ تَرْجِعَنَّ فِي صَدَقَتِكَ ‏"‏‏.‏\hadithno{2775}\hadithtrans{Narrated Ibn `Umar:Once `Umar gave a horse in charity to be used in holy fighting. It had been given to him by Allah's Apostle . `Umar gave it to another man to ride. Then `Umar was informed that the man put the horse for sale, so he asked Allah's Messenger (ﷺ) whether he could buy it. Allah's Messenger (ﷺ) replied, "You should not buy it, for you should not take back what you have given in charity}}
\hadithdefcmd{bukhari}{2776}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقْتَسِمْ وَرَثَتِي دِينَارًا، مَا تَرَكْتُ بَعْدَ نَفَقَةِ نِسَائِي وَمَئُونَةِ عَامِلِي فَهْوَ صَدَقَةٌ ‏"‏‏.‏\hadithno{2776}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "My heirs will not inherit a Dinar or a Dirham (i.e. money), for whatever I leave (excluding the adequate support of my wives and the wages of my employees) is given in charity}}
\hadithdefcmd{bukhari}{2777}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ عُمَرَ، اشْتَرَطَ فِي وَقْفِهِ أَنْ يَأْكُلَ مَنْ وَلِيَهُ وَيُوكِلَ صَدِيقَهُ غَيْرَ مُتَمَوِّلٍ مَالاً‏.‏\hadithno{2777}\hadithtrans{Narrated Ibn `Umar:When `Umar founded an endowment he stipulated that its administrator could eat from it and also feed his friend on the condition that he would not store anything for himself from it}}
\hadithdefcmd{bukhari}{2778}{وَقَالَ عَبْدَانُ أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّ عُثْمَانَ ـ رضى الله عنه ـ حَيْثُ حُوصِرَ أَشْرَفَ عَلَيْهِمْ وَقَالَ أَنْشُدُكُمْ وَلاَ أَنْشُدُ إِلاَّ أَصْحَابَ النَّبِيِّ صلى الله عليه وسلم، أَلَسْتُمْ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ حَفَرَ رُومَةَ فَلَهُ الْجَنَّةُ ‏"‏‏.‏ فَحَفَرْتُهَا، أَلَسْتُمْ تَعْلَمُونَ أَنَّهُ قَالَ ‏"‏ مَنْ جَهَّزَ جَيْشَ الْعُسْرَةِ فَلَهُ الْجَنَّةُ ‏"‏‏.‏ فَجَهَّزْتُهُمْ‏.‏ قَالَ فَصَدَّقُوهُ بِمَا قَالَ‏.‏ وَقَالَ عُمَرُ فِي وَقْفِهِ لاَ جُنَاحَ عَلَى مَنْ وَلِيَهُ أَنْ يَأْكُلَ‏.‏ وَقَدْ يَلِيهِ الْوَاقِفُ وَغَيْرُهُ فَهْوَ وَاسِعٌ لِكُلٍّ‏.‏\hadithno{2778}\hadithtrans{Abu 'Abdur-Rahman narrated:When 'Uthman (ra) was circled (by the rebels), he looked upon them from above and said, "I ask you by Allah, I ask nobody but the Companions of the Prophet (ﷺ), don't you know that Allah's Messenger (ﷺ) said, 'Whoever will (buy and) dig the well of Ruma will be granted Paradise,' and I (bought and) dug it? Don't you know that he said. 'Whoever equip the army of 'Usra (i.e., Tabuk's Ghazwa) will be granted Paradise,' and I equipped it ?" They attested whatever he said. When 'Umar founded his endowment he said, "Its administrator can eat from it." The management of the endowment can be taken over by the founder himself or any other person, for both cases are permissible}}
\hadithdefcmd{bukhari}{2779}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا بَنِي النَّجَّارِ ثَامِنُونِي بِحَائِطِكُمْ ‏"‏‏.‏ قَالُوا لاَ نَطْلُبُ ثَمَنَهُ إِلاَّ إِلَى اللَّهِ‏.‏\hadithno{2779}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said (at the time of building the Mosque), "O Bani An-Najjar! Suggest to me a price for your garden." They replied, "We do not ask its price except from Allah}}
\hadithdefcmd{bukhari}{2780}{وَقَالَ لِي عَلِيُّ بْنُ عَبْدِ اللَّهِ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ مُحَمَّدِ بْنِ أَبِي الْقَاسِمِ، عَنْ عَبْدِ الْمَلِكِ بْنِ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ خَرَجَ رَجُلٌ مِنْ بَنِي سَهْمٍ مَعَ تَمِيمٍ الدَّارِيِّ وَعَدِيِّ بْنِ بَدَّاءٍ فَمَاتَ السَّهْمِيُّ بِأَرْضٍ لَيْسَ بِهَا مُسْلِمٌ، فَلَمَّا قَدِمَا بِتَرِكَتِهِ فَقَدُوا جَامًا مِنْ فِضَّةٍ مُخَوَّصًا مِنْ ذَهَبٍ، فَأَحْلَفَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم، ثُمَّ وُجِدَ الْجَامُ بِمَكَّةَ فَقَالُوا ابْتَعْنَاهُ مِنْ تَمِيمٍ وَعَدِيٍّ‏.‏ فَقَامَ رَجُلاَنِ مِنْ أَوْلِيَائِهِ، فَحَلَفَا لَشَهَادَتُنَا أَحَقُّ مِنْ شَهَادَتِهِمَا، وَإِنَّ الْجَامَ لِصَاحِبِهِمْ‏.‏ قَالَ وَفِيهِمْ نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا شَهَادَةُ بَيْنِكُمْ ‏إِذَا حَضَرَ أَحَدَكُمُ الْمَوْتُ\}‏\hadithno{2780}\hadithtrans{Ibn 'Abbas (ra) said, "A man from the tribe of Bani Sahm went out in the company of Tamim Ad-Dari and 'Adi bin Badda'. The man of Bani Sahm died in a land where there was no Muslim. When Tamim and 'Adi returned conveying the property of the deceased, they claimed that they had lost a silver bowl with gold engraving. Allah's Messenger (ﷺ) made them take an oath (to confirm their claim), and then the bowl was found in Makkah with some people who claimed that they had bought it from Tamim and 'Adi. Then two witnesses from the relatives of the deceased got up and swore that their witnesses were more valid than the witnesses of 'Adi and Tamim, and that the bowl belonged to their deceased fellow. So, this verse was revealed in connection with this case: 'O you who believe! When death approached any of you ...'," (V 5:)}}
\hadithdefcmd{bukhari}{2781}{حَدَّثَنَا مُحَمَّدُ بْنُ سَابِقٍ، أَوِ الْفَضْلُ بْنُ يَعْقُوبَ عَنْهُ حَدَّثَنَا شَيْبَانُ أَبُو مُعَاوِيَةَ، عَنْ فِرَاسٍ، قَالَ قَالَ الشَّعْبِيُّ حَدَّثَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ ـ رضى الله عنهما ـ أَنَّ أَبَاهُ اسْتُشْهِدَ يَوْمَ أُحُدٍ، وَتَرَكَ سِتَّ بَنَاتٍ، وَتَرَكَ عَلَيْهِ دَيْنًا، فَلَمَّا حَضَرَ جِدَادُ النَّخْلِ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ قَدْ عَلِمْتَ أَنَّ وَالِدِي اسْتُشْهِدَ يَوْمَ أُحُدٍ وَتَرَكَ عَلَيْهِ دَيْنًا كَثِيرًا، وَإِنِّي أُحِبُّ أَنْ يَرَاكَ الْغُرَمَاءُ قَالَ ‏"‏ اذْهَبْ فَبَيْدِرْ كُلَّ تَمْرٍ عَلَى نَاحِيَتِهِ ‏"‏‏.‏ فَفَعَلْتُ ثُمَّ دَعَوْتُهُ، فَلَمَّا نَظَرُوا إِلَيْهِ أُغْرُوا بِي تِلْكَ السَّاعَةَ، فَلَمَّا رَأَى مَا يَصْنَعُونَ أَطَافَ حَوْلَ أَعْظَمِهَا بَيْدَرًا ثَلاَثَ مَرَّاتٍ ثُمَّ جَلَسَ عَلَيْهِ ثُمَّ قَالَ ‏"‏ ادْعُ أَصْحَابَكَ ‏"‏‏.‏ فَمَا زَالَ يَكِيلُ لَهُمْ حَتَّى أَدَّى اللَّهُ أَمَانَةَ وَالِدِي، وَأَنَا وَاللَّهِ رَاضٍ أَنْ يُؤَدِّيَ اللَّهُ أَمَانَةَ وَالِدِي وَلاَ أَرْجِعَ إِلَى أَخَوَاتِي بِتَمْرَةٍ، فَسَلِمَ وَاللَّهِ الْبَيَادِرُ كُلُّهَا حَتَّى أَنِّي أَنْظُرُ إِلَى الْبَيْدَرِ الَّذِي عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم كَأَنَّهُ لَمْ يَنْقُصْ تَمْرَةً وَاحِدَةً‏.‏ قَالَ أَبُو عَبْد اللَّهِ أُغْرُوا بِي يَعْنِي هِيجُوا بِي فَأَغْرَيْنَا بَيْنَهُمْ الْعَدَاوَةَ وَالْبَغْضَاءَ\hadithno{2781}\hadithtrans{Narrated Jabir bin `Abdullah Al-Ansari:My father was martyred on the day (of the Ghazwa) of Uhud and left six daughters and some debts to be paid. When the time of plucking the date-fruits came, I went to Allah's Messenger (ﷺ) and said, "O Allah's Apostle! you know that my father was martyred on Uhud's day and owed much debt, and I wish that the creditors would see you." The Prophet (ﷺ) said, "Go and collect the various kinds of dates and place them separately in heaps"' I did accordingly and called him. On seeing him, the creditors started claiming their rights pressingly at that time. When the Prophet (ﷺ) saw how they behaved, he went round the biggest heap for three times and sat over it and said, "Call your companions (i.e. the creditors)." Then he kept on measuring and giving them, till Allah cleared all my father's debts. By Allah, it would have pleased me that Allah would clear the debts of my father even though I had not taken a single date to my sisters. But by Allah, all the heaps were complete, (as they were) and I looked at the heap where Allah's Messenger (ﷺ) was sitting and noticed as if not a single date had been taken thereof}}
