% Auto-generated chapter 53 for bukhari
% Hadiths in this chapter: 20

\hadithdefcmd{bukhari}{2690}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه أَنَّ أُنَاسًا، مِنْ بَنِي عَمْرِو بْنِ عَوْفٍ كَانَ بَيْنَهُمْ شَىْءٌ، فَخَرَجَ إِلَيْهِمُ النَّبِيُّ صلى الله عليه وسلم فِي أُنَاسٍ مِنْ أَصْحَابِهِ يُصْلِحُ بَيْنَهُمْ، فَحَضَرَتِ الصَّلاَةُ، وَلَمْ يَأْتِ النَّبِيُّ صلى الله عليه وسلم، فَجَاءَ بِلاَلٌ، فَأَذَّنَ بِلاَلٌ بِالصَّلاَةِ، وَلَمْ يَأْتِ النَّبِيُّ صلى الله عليه وسلم فَجَاءَ إِلَى أَبِي بَكْرٍ فَقَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم حُبِسَ، وَقَدْ حَضَرَتِ الصَّلاَةُ فَهَلْ لَكَ أَنْ تَؤُمَّ النَّاسَ فَقَالَ نَعَمْ إِنْ شِئْتَ‏.‏ فَأَقَامَ الصَّلاَةَ فَتَقَدَّمَ أَبُو بَكْرٍ، ثُمَّ جَاءَ النَّبِيُّ صلى الله عليه وسلم يَمْشِي فِي الصُّفُوفِ، حَتَّى قَامَ فِي الصَّفِّ الأَوَّلِ، فَأَخَذَ النَّاسُ بِالتَّصْفِيحِ حَتَّى أَكْثَرُوا، وَكَانَ أَبُو بَكْرٍ لاَ يَكَادُ يَلْتَفِتُ فِي الصَّلاَةِ، فَالْتَفَتَ فَإِذَا هُوَ بِالنَّبِيِّ صلى الله عليه وسلم وَرَاءَهُ فَأَشَارَ إِلَيْهِ بِيَدِهِ، فَأَمَرَهُ يُصَلِّي كَمَا هُوَ، فَرَفَعَ أَبُو بَكْرٍ يَدَهُ، فَحَمِدَ اللَّهَ، ثُمَّ رَجَعَ الْقَهْقَرَى وَرَاءَهُ حَتَّى دَخَلَ فِي الصَّفِّ، وَتَقَدَّمَ النَّبِيُّ صلى الله عليه وسلم فَصَلَّى بِالنَّاسِ، فَلَمَّا فَرَغَ أَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ مَا لَكُمْ إِذَا نَابَكُمْ شَىْءٌ فِي صَلاَتِكُمْ أَخَذْتُمْ بِالتَّصْفِيحِ، إِنَّمَا التَّصْفِيحُ لِلنِّسَاءِ، مَنْ نَابَهُ شَىْءٌ فِي صَلاَتِهِ فَلْيَقُلْ سُبْحَانَ اللَّهِ، فَإِنَّهُ لا يَسْمَعُهُ أَحَدٌ إِلاَّ الْتَفَتَ، يَا أَبَا بَكْرٍ مَا مَنَعَكَ حِينَ أَشَرْتُ إِلَيْكَ لَمْ تُصَلِّ بِالنَّاسِ ‏"‏‏.‏ فَقَالَ مَا كَانَ يَنْبَغِي لاِبْنِ أَبِي قُحَافَةَ أَنْ يُصَلِّيَ بَيْنَ يَدَىِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2690}\hadithtrans{Narrated Sahl bin Sa`d:There was a dispute amongst the people of the tribe of Bani `Amr bin `Auf. The Prophet (ﷺ) went to them along with some of his companions in order to make peace between them. The time for the prayer became due but the Prophet (ﷺ) did not turn up; Bilal pronounced the Adhan (i.e. call) for the prayer but the Prophet (ﷺ) did not turn up, so Bilal went to Abu Bakr and said, "The time for the prayer is due and the Prophet (ﷺ) is detained, would you lead the people in the prayer?" Abu Bakr replied, "Yes, if you wish." So, Bilal pronounced the Iqama of the prayer and Abu Bakr went ahead (to lead the prayer), but the Prophet came walking among the rows till he joined the first row. The people started clapping and they clapped too much, and Abu Bakr used not to look hither and thither in the prayer, but he turned round and saw the Prophet (ﷺ) standing behind him. The Prophet (ﷺ) beckoned him with his hand to keep on praying where he was. Abu Bakr raised his hand and praised Allah and then retreated till he came in the (first) row, and the Prophet (ﷺ) went ahead and lead the people in the prayer. When the Prophet (ﷺ) finished the prayer, he turned towards the people and said, "O people! When something happens to you during the prayer, you start clapping. Really clapping is (permissible) for women only. If something happens to one of you in his prayer, he should say: 'Subhan Allah', (Glorified be Allah), for whoever hears him (saying so) will direct his attention towards him. O Abu Bakr! What prevented you from leading the people in the prayer when I beckoned to you (to continue)?" Abu Bakr replied, "It did not befit the son of Abu Quhafa to lead the prayer in front of the Prophet}}
\hadithdefcmd{bukhari}{2691}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي أَنَّ أَنَسًا ـ رضى الله عنه ـ قَالَ قِيلَ لِلنَّبِيِّ صلى الله عليه وسلم لَوْ أَتَيْتَ عَبْدَ اللَّهِ بْنَ أُبَىٍّ‏.‏ فَانْطَلَقَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم وَرَكِبَ حِمَارًا، فَانْطَلَقَ الْمُسْلِمُونَ يَمْشُونَ مَعَهُ، وَهْىَ أَرْضٌ سَبِخَةٌ، فَلَمَّا أَتَاهُ النَّبِيُّ صلى الله عليه وسلم فَقَالَ إِلَيْكَ عَنِّي، وَاللَّهِ لَقَدْ آذَانِي نَتْنُ حِمَارِكَ‏.‏ فَقَالَ رَجُلٌ مِنَ الأَنْصَارِ مِنْهُمْ وَاللَّهِ لَحِمَارُ رَسُولِ اللَّهِ صلى الله عليه وسلم أَطْيَبُ رِيحًا مِنْكَ‏.‏ فَغَضِبَ لِعَبْدِ اللَّهِ رَجُلٌ مِنْ قَوْمِهِ فَشَتَمَا، فَغَضِبَ لِكُلِّ وَاحِدٍ مِنْهُمَا أَصْحَابُهُ، فَكَانَ بَيْنَهُمَا ضَرْبٌ بِالْجَرِيدِ وَالأَيْدِي وَالنِّعَالِ، فَبَلَغَنَا أَنَّهَا أُنْزِلَتْ ‏\{‏وَإِنْ طَائِفَتَانِ مِنَ الْمُؤْمِنِينَ اقْتَتَلُوا فَأَصْلِحُوا بَيْنَهُمَا‏\}‏‏.‏\hadithno{2691}\hadithtrans{Narrated Anas:It was said to the Prophet (ﷺ) "Would that you see `Abdullah bin Ubai." So, the Prophet (ﷺ) went to him, riding a donkey, and the Muslims accompanied him, walking on salty barren land. When the Prophet (ﷺ) reached `Abdullah bin Ubai, the latter said, "Keep away from me! By Allah, the bad smell of your donkey has harmed me." On that an Ansari man said (to `Abdullah), "By Allah! The smell of the donkey of Allah's Messenger (ﷺ) is better than your smell." On that a man from `Abdullah's tribe got angry for `Abdullah's sake, and the two men abused each other which caused the friends of the two men to get angry, and the two groups started fighting with sticks, shoes and hands. We were informed that the following Divine Verse was revealed (in this concern):-- "And if two groups of Believers fall to fighting then, make peace between them}}
\hadithdefcmd{bukhari}{2692}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ حُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ، أَخْبَرَهُ أَنَّ أُمَّهُ أُمَّ كُلْثُومٍ بِنْتَ عُقْبَةَ أَخْبَرَتْهُ أَنَّهَا، سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَيْسَ الْكَذَّابُ الَّذِي يُصْلِحُ بَيْنَ النَّاسِ، فَيَنْمِي خَيْرًا، أَوْ يَقُولُ خَيْرًا ‏"‏‏.‏\hadithno{2692}\hadithtrans{Narrated Um Kulthum bint `Uqba:That she heard Allah's Messenger (ﷺ) saying, "He who makes peace between the people by inventing good information or saying good things, is not a liar}}
\hadithdefcmd{bukhari}{2693}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ الأُوَيْسِيُّ، وَإِسْحَاقُ بْنُ مُحَمَّدٍ الْفَرْوِيُّ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه أَنَّ أَهْلَ، قُبَاءٍ اقْتَتَلُوا حَتَّى تَرَامَوْا بِالْحِجَارَةِ، فَأُخْبِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِذَلِكَ فَقَالَ ‏ "‏ اذْهَبُوا بِنَا نُصْلِحُ بَيْنَهُمْ ‏"‏‏.‏\hadithno{2693}\hadithtrans{Narrated Sahl bin Sa`d:Once the people of Quba fought with each other till they threw stones on each other. When Allah's Apostle was informed about it, he said, "Let us go to bring about a reconciliation between them}}
\hadithdefcmd{bukhari}{2694}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها – ‏\{‏وَإِنِ امْرَأَةٌ خَافَتْ مِنْ بَعْلِهَا نُشُوزًا أَوْ إِعْرَاضًا‏\}‏ قَالَتْ هُوَ الرَّجُلُ يَرَى مِنِ امْرَأَتِهِ مَا لاَ يُعْجِبُهُ، كِبَرًا أَوْ غَيْرَهُ، فَيُرِيدُ فِرَاقَهَا فَتَقُولُ أَمْسِكْنِي، وَاقْسِمْ لِي مَا شِئْتَ‏.‏ قَالَتْ فَلاَ بَأْسَ إِذَا تَرَاضَيَا‏.‏\hadithno{2694}\hadithtrans{Narrated Aisha:The following Verse: If a woman fears cruelty or desertion on her husband's part (i.e. the husband notices something unpleasant about his wife, such as old age or the like, and wants to divorce her, but she asks him to keep her and provide for her as he wishes). (4.128) "There is no blame on them if they reconcile on such basis}}
\hadithdefcmd{bukhari}{2695}{حَدَّثَنَا آدَمُ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، رضى الله عنهما قَالاَ جَاءَ أَعْرَابِيٌّ فَقَالَ يَا رَسُولَ اللَّهِ اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ‏.‏ فَقَامَ خَصْمُهُ فَقَالَ صَدَقَ، اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ‏.‏ فَقَالَ الأَعْرَابِيُّ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا، فَزَنَى بِامْرَأَتِهِ، فَقَالُوا لِي عَلَى ابْنِكَ الرَّجْمُ‏.‏ فَفَدَيْتُ ابْنِي مِنْهُ بِمِائَةٍ مِنَ الْغَنَمِ وَوَلِيدَةٍ، ثُمَّ سَأَلْتُ أَهْلَ الْعِلْمِ، فَقَالُوا إِنَّمَا عَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ، أَمَّا الْوَلِيدَةُ وَالْغَنَمُ فَرَدٌّ عَلَيْكَ، وَعَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، وَأَمَّا أَنْتَ يَا أُنَيْسُ ـ لِرَجُلٍ ـ فَاغْدُ عَلَى امْرَأَةِ هَذَا فَارْجُمْهَا ‏"‏‏.‏ فَغَدَا عَلَيْهَا أُنَيْسٌ فَرَجَمَهَا‏.‏\hadithno{2695}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid Al-Juhani:A bedouin came and said, "O Allah's Messenger (ﷺ)! Judge between us according to Allah's Laws." His opponent got up and said, "He is right. Judge between us according to Allah's Laws." The bedouin said, "My son was a laborer working for this man, and he committed illegal sexual intercourse with his wife. The people told me that my son should be stoned to death; so, in lieu of that, I paid a ransom of one hundred sheep and a slave girl to save my son. Then I asked the learned scholars who said, "Your son has to be lashed one-hundred lashes and has to be exiled for one year." The Prophet (ﷺ) said, "No doubt I will judge between you according to Allah's Laws. The slave-girl and the sheep are to go back to you, and your son will get a hundred lashes and one year exile." He then addressed somebody, "O Unais! go to the wife of this (man) and stone her to death" So, Unais went and stoned her to death}}
\hadithdefcmd{bukhari}{2697}{حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَحْدَثَ فِي أَمْرِنَا هَذَا مَا لَيْسَ فِيهِ فَهُوَ رَدٌّ ‏"‏‏.‏ رَوَاهُ عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الْمَخْرَمِيُّ وَعَبْدُ الْوَاحِدِ بْنُ أَبِي عَوْنٍ عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ‏.‏\hadithno{2697}\hadithtrans{Narrated Aisha:Allah's Messenger (ﷺ) said, "If somebody innovates something which is not in harmony with the principles of our religion, that thing is rejected}}
\hadithdefcmd{bukhari}{2698}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ ـ رضى الله عنهما ـ قَالَ لَمَّا صَالَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَهْلَ الْحُدَيْبِيَةِ كَتَبَ عَلِيٌّ بَيْنَهُمْ كِتَابًا فَكَتَبَ مُحَمَّدٌ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ فَقَالَ الْمُشْرِكُونَ لاَ تَكْتُبْ مُحَمَّدٌ رَسُولُ اللَّهِ، لَوْ كُنْتَ رَسُولاً لَمْ نُقَاتِلْكَ‏.‏ فَقَالَ لِعَلِيٍّ ‏ "‏ امْحُهُ ‏"‏‏.‏ فَقَالَ عَلِيٌّ مَا أَنَا بِالَّذِي أَمْحَاهُ‏.‏ فَمَحَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ، وَصَالَحَهُمْ عَلَى أَنْ يَدْخُلَ هُوَ وَأَصْحَابُهُ ثَلاَثَةَ أَيَّامٍ، وَلاَ يَدْخُلُوهَا إِلاَّ بِجُلُبَّانِ السِّلاَحِ، فَسَأَلُوهُ مَا جُلُبَّانُ السِّلاَحِ فَقَالَ الْقِرَابُ بِمَا فِيهِ‏.‏\hadithno{2698}\hadithtrans{Narrated Al-Bara bin `Azib:When Allah's Messenger (ﷺ) concluded a peace treaty with the people of Hudaibiya, `Ali bin Abu Talib wrote the document and he mentioned in it, "Muhammad, Allah's Messenger (ﷺ) ." The pagans said, "Don't write: 'Muhammad, Allah's Messenger (ﷺ)', for if you were an apostle we would not fight with you." Allah's Apostle asked `Ali to rub it out, but `Ali said, "I will not be the person to rub it out." Allah's Messenger (ﷺ) rubbed it out and made peace with them on the condition that the Prophet (ﷺ) and his companions would enter Mecca and stay there for three days, and that they would enter with their weapons in cases}}
\hadithdefcmd{bukhari}{2699}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ اعْتَمَرَ النَّبِيُّ صلى الله عليه وسلم فِي ذِي الْقَعْدَةِ، فَأَبَى أَهْلُ مَكَّةَ أَنْ يَدَعُوهُ يَدْخُلُ مَكَّةَ، حَتَّى قَاضَاهُمْ عَلَى أَنْ يُقِيمَ بِهَا ثَلاَثَةَ أَيَّامٍ، فَلَمَّا كَتَبُوا الْكِتَابَ كَتَبُوا هَذَا مَا قَاضَى عَلَيْهِ مُحَمَّدٌ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ فَقَالُوا لاَ نُقِرُّ بِهَا، فَلَوْ نَعْلَمُ أَنَّكَ رَسُولُ اللَّهِ مَا مَنَعْنَاكَ، لَكِنْ أَنْتَ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ‏.‏ قَالَ ‏"‏ أَنَا رَسُولُ اللَّهِ وَأَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ ‏"‏‏.‏ ثُمَّ قَالَ لِعَلِيٍّ ‏"‏ امْحُ رَسُولُ اللَّهِ ‏"‏‏.‏ قَالَ لاَ، وَاللَّهِ لاَ أَمْحُوكَ أَبَدًا، فَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْكِتَابَ، فَكَتَبَ هَذَا مَا قَاضَى عَلَيْهِ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، لاَ يَدْخُلُ مَكَّةَ سِلاَحٌ إِلاَّ فِي الْقِرَابِ، وَأَنْ لاَ يَخْرُجَ مِنْ أَهْلِهَا بِأَحَدٍ، إِنْ أَرَادَ أَنْ يَتَّبِعَهُ، وَأَنْ لاَ يَمْنَعَ أَحَدًا مِنْ أَصْحَابِهِ أَرَادَ أَنْ يُقِيمَ بِهَا‏.‏ فَلَمَّا دَخَلَهَا، وَمَضَى الأَجَلُ أَتَوْا عَلِيًّا، فَقَالُوا قُلْ لِصَاحِبِكَ اخْرُجْ عَنَّا فَقَدْ مَضَى الأَجَلُ‏.‏ فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم فَتَبِعَتْهُمُ ابْنَةُ حَمْزَةَ يَا عَمِّ يَا عَمِّ‏.‏ فَتَنَاوَلَهَا عَلِيٌّ فَأَخَذَ بِيَدِهَا، وَقَالَ لِفَاطِمَةَ عَلَيْهَا السَّلاَمُ دُونَكِ ابْنَةَ عَمِّكِ، احْمِلِيهَا‏.‏ فَاخْتَصَمَ فِيهَا عَلِيٌّ وَزَيْدٌ وَجَعْفَرٌ، فَقَالَ عَلِيٌّ أَنَا أَحَقُّ بِهَا وَهْىَ ابْنَةُ عَمِّي‏.‏ وَقَالَ جَعْفَرٌ ابْنَةُ عَمِّي وَخَالَتُهَا تَحْتِي‏.‏ وَقَالَ زَيْدٌ ابْنَةُ أَخِي‏.‏ فَقَضَى بِهَا النَّبِيُّ صلى الله عليه وسلم لِخَالَتِهَا‏.‏ وَقَالَ ‏"‏ الْخَالَةُ بِمَنْزِلَةِ الأُمِّ ‏"‏‏.‏ وَقَالَ لِعَلِيٍّ ‏"‏ أَنْتَ مِنِّي وَأَنَا مِنْكَ ‏"‏‏.‏ وَقَالَ لِجَعْفَرٍ ‏"‏ أَشْبَهْتَ خَلْقِي وَخُلُقِي ‏"‏‏.‏ وَقَالَ لِزَيْدٍ ‏"‏ أَنْتَ أَخُونَا وَمَوْلاَنَا ‏"‏‏.‏\hadithno{2699}\hadithtrans{Narrated Al-Bara:When the Prophet (ﷺ) intended to perform `Umra in the month of Dhul-Qada, the people of Mecca did not let him enter Mecca till he settled the matter with them by promising to stay in it for three days only. When the document of treaty was written, the following was mentioned: 'These are the terms on which Muhammad, Allah's Messenger (ﷺ) agreed (to make peace).' They said, "We will not agree to this, for if we believed that you are Allah's Messenger (ﷺ) we would not prevent you, but you are Muhammad bin `Abdullah." The Prophet (ﷺ) said, "I am Allah's Messenger (ﷺ) and also Muhammad bin `Abdullah." Then he said to `Ali, "Rub off (the words) 'Allah's Messenger (ﷺ)' ", but `Ali said, "No, by Allah, I will never rub off your name." So, Allah's Messenger (ﷺ) took the document and wrote, 'This is what Muhammad bin `Abdullah has agreed upon: No arms will be brought into Mecca except in their cases, and nobody from the people of Mecca will be allowed to go with him (i.e. the Prophet (ﷺ) ) even if he wished to follow him and he (the Prophet (ﷺ) ) will not prevent any of his companions from staying in Mecca if the latter wants to stay.' When the Prophet (ﷺ) entered Mecca and the time limit passed, the Meccans went to `Ali and said, "Tell your Friend (i.e. the Prophet (ﷺ) ) to go out, as the period (agreed to) has passed." So, the Prophet (ﷺ) went out of Mecca. The daughter of Hamza ran after them (i.e. the Prophet (ﷺ) and his companions), calling, "O Uncle! O Uncle!" `Ali received her and led her by the hand and said to Fatima, "Take your uncle's daughter." Zaid and Ja`far quarreled about her. `Ali said, "I have more right to her as she is my uncle's daughter." Ja`far said, "She is my uncle's daughter, and her aunt is my wife." Zaid said, "She is my brother's daughter." The Prophet (ﷺ) judged that she should be given to her aunt, and said that the aunt was like the mother. He then said to 'Ali, "You are from me and I am from you", and said to Ja`far, "You resemble me both in character and appearance", and said to Zaid, "You are our brother (in faith) and our freed slave}}
\hadithdefcmd{bukhari}{2700}{وَقَالَ مُوسَى بْنُ مَسْعُودٍ حَدَّثَنَا سُفْيَانُ بْنُ سَعِيدٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ ـ رضى الله عنهما ـ قَالَ صَالَحَ النَّبِيُّ صلى الله عليه وسلم الْمُشْرِكِينَ يَوْمَ الْحُدَيْبِيَةِ عَلَى ثَلاَثَةِ أَشْيَاءَ عَلَى أَنَّ مَنْ أَتَاهُ مِنَ الْمُشْرِكِينَ رَدَّهُ إِلَيْهِمْ، وَمَنْ أَتَاهُمْ مِنَ الْمُسْلِمِينَ لَمْ يَرُدُّوهُ، وَعَلَى أَنْ يَدْخُلَهَا مِنْ قَابِلٍ وَيُقِيمَ بِهَا ثَلاَثَةَ أَيَّامٍ، وَلاَ يَدْخُلَهَا إِلاَّ بِجُلُبَّانِ السِّلاَحِ السَّيْفِ وَالْقَوْسِ وَنَحْوِهِ‏.‏ فَجَاءَ أَبُو جَنْدَلٍ يَحْجُلُ فِي قُيُودِهِ فَرَدَّهُ إِلَيْهِمْ‏.‏ قَالَ لَمْ يَذْكُرْ مُؤَمَّلٌ عَنْ سُفْيَانَ أَبَا جَنْدَلٍ وَقَالَ إِلاَّ بِجُلُبِّ السِّلاَحِ‏.‏\hadithno{2700}\hadithtrans{Narrated Al-Bara' bin 'Azib (ra):On the day of Hudaibiya, the Prophet (ﷺ), the Prophet (ﷺ) made a peace treaty with the Al-Mushrikun on three conditions: 1. The Prophet (ﷺ) would return to them any person from Al-Mushrikun (polytheists, idolaters, pagans). 2. Al-Mushrikun pagans would not return any of the Muslims going to them, and 3. The Prophet (ﷺ) and his companions would come to Makkah the following year and would stay there for three days and would enter with their weapons in cases, e.g., swords, arrows, bows, etc. Abu Jandal came hopping, his legs being chained, but the Prophet (ﷺ) returned him to Al-Mushrikun}}
\hadithdefcmd{bukhari}{2701}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا سُرَيْجُ بْنُ النُّعْمَانِ، حَدَّثَنَا فُلَيْحٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ مُعْتَمِرًا، فَحَالَ كُفَّارُ قُرَيْشٍ بَيْنَهُ وَبَيْنَ الْبَيْتِ، فَنَحَرَ هَدْيَهُ، وَحَلَقَ رَأْسَهُ بِالْحُدَيْبِيَةِ، وَقَاضَاهُمْ عَلَى أَنْ يَعْتَمِرَ الْعَامَ الْمُقْبِلَ، وَلاَ يَحْمِلَ سِلاَحًا عَلَيْهِمْ إِلاَّ سُيُوفًا، وَلاَ يُقِيمَ بِهَا إِلاَّ مَا أَحَبُّوا، فَاعْتَمَرَ مِنَ الْعَامِ الْمُقْبِلِ فَدَخَلَهَا كَمَا كَانَ صَالَحَهُمْ، فَلَمَّا أَقَامَ بِهَا ثَلاَثًا أَمَرُوهُ أَنْ يَخْرُجَ فَخَرَجَ‏.‏\hadithno{2701}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) set out for the `Umra but the pagans of Quraish prevented him from reaching the Ka`ba. So, he slaughtered his sacrifice and got his head shaved at Al-Hudaibiya, and agreed with them that he would perform `Umra the following year and would not carry weapons except swords and would not stay in Mecca except for the period they allowed. So, the Prophet (ﷺ) performed the `Umra in the following year and entered Mecca according to the treaty, and when he stayed for three days, the pagans ordered him to depart, and he departed}}
\hadithdefcmd{bukhari}{2702}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ، حَدَّثَنَا يَحْيَى، عَنْ بُشَيْرِ بْنِ يَسَارٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، قَالَ انْطَلَقَ عَبْدُ اللَّهِ بْنُ سَهْلٍ وَمُحَيِّصَةُ بْنُ مَسْعُودِ بْنِ زَيْدٍ إِلَى خَيْبَرَ، وَهْىَ يَوْمَئِذٍ صُلْحٌ‏.‏\hadithno{2702}\hadithtrans{Narrated Sahl bin Abu Hathma:`Abdullah bin Sahl and Muhaiyisa bin Mas`ud bin Zaid went to Khaibar when it had a peace treaty (with the Muslims)}}
\hadithdefcmd{bukhari}{2703}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، قَالَ حَدَّثَنِي حُمَيْدٌ، أَنَّ أَنَسًا، حَدَّثَهُمْ أَنَّ الرُّبَيِّعَ ـ وَهْىَ ابْنَةُ النَّضْرِ ـ كَسَرَتْ ثَنِيَّةَ جَارِيَةٍ، فَطَلَبُوا الأَرْشَ وَطَلَبُوا الْعَفْوَ، فَأَبَوْا فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم فَأَمَرَهُمْ بِالْقِصَاصِ‏.‏ فَقَالَ أَنَسُ بْنُ النَّضْرِ أَتُكْسَرُ ثَنِيَّةُ الرُّبَيِّعِ يَا رَسُولَ اللَّهِ لاَ وَالَّذِي بَعَثَكَ بِالْحَقِّ لاَ تُكْسَرُ ثَنِيَّتُهَا فَقَالَ ‏"‏ يَا أَنَسُ كِتَابُ اللَّهِ الْقِصَاصُ ‏"‏‏.‏ فَرَضِيَ الْقَوْمُ وَعَفَوْا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ عِبَادِ اللَّهِ مَنْ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ ‏"‏‏.‏ زَادَ الْفَزَارِيُّ عَنْ حُمَيْدٍ عَنْ أَنَسٍ فَرَضِيَ الْقَوْمُ وَقَبِلُوا الأَرْشَ‏.‏\hadithno{2703}\hadithtrans{Narrated Anas:Ar-Rabi, the daughter of An-Nadr broke the tooth of a girl, and the relatives of Ar-Rabi` requested the girl's relatives to accept the Irsh (compensation for wounds etc.) and forgive (the offender), but they refused. So, they went to the Prophet (ﷺ) who ordered them to bring about retaliation. Anas bin An-Nadr asked, "O Allah's Apostle! Will the tooth of Ar-Rabi` be broken? No, by Him Who has sent you with the Truth, her tooth will not be broken." The Prophet (ﷺ) said, "O Anas! Allah's law ordains retaliation." Later the relatives of the girl agreed and forgave her. The Prophet (ﷺ) said, "There are some of Allah's slaves who, if they take an oath by Allah, are responded to by Allah i.e. their oath is fulfilled). Anas added, "The people agreed and accepted the Irsh}}
\hadithdefcmd{bukhari}{2704}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي مُوسَى، قَالَ سَمِعْتُ الْحَسَنَ، يَقُولُ اسْتَقْبَلَ وَاللَّهِ الْحَسَنُ بْنُ عَلِيٍّ مُعَاوِيَةَ بِكَتَائِبَ أَمْثَالِ الْجِبَالِ فَقَالَ عَمْرُو بْنُ الْعَاصِ إِنِّي لأَرَى كَتَائِبَ لاَ تُوَلِّي حَتَّى تَقْتُلَ أَقْرَانَهَا‏.‏ فَقَالَ لَهُ مُعَاوِيَةُ ـ وَكَانَ وَاللَّهِ خَيْرَ الرَّجُلَيْنِ ـ أَىْ عَمْرُو إِنْ قَتَلَ هَؤُلاَءِ هَؤُلاَءِ وَهَؤُلاَءِ هَؤُلاَءِ مَنْ لِي بِأُمُورِ النَّاسِ مَنْ لِي بِنِسَائِهِمْ، مَنْ لِي بِضَيْعَتِهِمْ فَبَعَثَ إِلَيْهِ رَجُلَيْنِ مِنْ قُرَيْشٍ مِنْ بَنِي عَبْدِ شَمْسٍ عَبْدَ الرَّحْمَنِ بْنَ سَمُرَةَ وَعَبْدَ اللَّهِ بْنَ عَامِرِ بْنِ كُرَيْزٍ، فَقَالَ اذْهَبَا إِلَى هَذَا الرَّجُلِ فَاعْرِضَا عَلَيْهِ، وَقُولاَ لَهُ، وَاطْلُبَا إِلَيْهِ‏.‏ فَأَتَيَاهُ، فَدَخَلاَ عَلَيْهِ فَتَكَلَّمَا، وَقَالاَ لَهُ، فَطَلَبَا إِلَيْهِ، فَقَالَ لَهُمَا الْحَسَنُ بْنُ عَلِيٍّ إِنَّا بَنُو عَبْدِ الْمُطَّلِبِ، قَدْ أَصَبْنَا مِنْ هَذَا الْمَالِ، وَإِنَّ هَذِهِ الأُمَّةَ قَدْ عَاثَتْ فِي دِمَائِهَا‏.‏ قَالاَ فَإِنَّهُ يَعْرِضُ عَلَيْكَ كَذَا وَكَذَا وَيَطْلُبُ إِلَيْكَ وَيَسْأَلُكَ‏.‏ قَالَ فَمَنْ لِي بِهَذَا قَالاَ نَحْنُ لَكَ بِهِ‏.‏ فَمَا سَأَلَهُمَا شَيْئًا إِلاَّ قَالاَ نَحْنُ لَكَ بِهِ‏.‏ فَصَالَحَهُ، فَقَالَ الْحَسَنُ وَلَقَدْ سَمِعْتُ أَبَا بَكْرَةَ يَقُولُ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ وَالْحَسَنُ بْنُ عَلِيٍّ إِلَى جَنْبِهِ، وَهْوَ يُقْبِلُ عَلَى النَّاسِ مَرَّةً وَعَلَيْهِ أُخْرَى وَيَقُولُ ‏ "‏ إِنَّ ابْنِي هَذَا سَيِّدٌ، وَلَعَلَّ اللَّهَ أَنْ يُصْلِحَ بِهِ بَيْنَ فِئَتَيْنِ عَظِيمَتَيْنِ مِنَ الْمُسْلِمِينَ ‏"‏‏.‏ قَالَ لِي عَلِيُّ بْنُ عَبْدِ اللَّهِ إِنَّمَا ثَبَتَ لَنَا سَمَاعُ الْحَسَنِ مِنْ أَبِي بَكْرَةَ بِهَذَا الْحَدِيثِ‏.‏\hadithno{2704}\hadithtrans{Narrated Al-Hasan Al-Basri:By Allah, Al-Hasan bin `Ali led large battalions like mountains against Muawiya. `Amr bin Al-As said (to Muawiya), "I surely see battalions which will not turn back before killing their opponents." Muawiya who was really the best of the two men said to him, "O `Amr! If these killed those and those killed these, who would be left with me for the jobs of the public, who would be left with me for their women, who would be left with me for their children?" Then Muawiya sent two Quraishi men from the tribe of `Abd-i-Shams called `Abdur Rahman bin Sumura and `Abdullah bin 'Amir bin Kuraiz to Al-Hasan saying to them, "Go to this man (i.e. Al-Hasan) and negotiate peace with him and talk and appeal to him." So, they went to Al-Hasan and talked and appealed to him to accept peace. Al-Hasan said, "We, the offspring of `Abdul Muttalib, have got wealth and people have indulged in killing and corruption (and money only will appease them)." They said to Al-Hasan, "Muawiya offers you so and so, and appeals to you and entreats you to accept peace." Al-Hasan said to them, "But who will be responsible for what you have said?" They said, "We will be responsible for it." So, whatever Al- Hasan asked they said, "We will be responsible for it for you." So, Al-Hasan concluded a peace treaty with Muawiya. Al-Hasan (Al-Basri) said: I heard Abu Bakr saying, "I saw Allah's Messenger (ﷺ) on the pulpit and Al-Hasan bin `Ali was by his side. The Prophet (ﷺ) was looking once at the people and once at Al-Hasan bin `Ali saying, 'This son of mine is a Saiyid (i.e. a noble) and may Allah make peace between two big groups of Muslims through him}}
\hadithdefcmd{bukhari}{2705}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، قَالَ حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي الرِّجَالِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ أَنَّ أُمَّهُ، عَمْرَةَ بِنْتَ عَبْدِ الرَّحْمَنِ قَالَتْ سَمِعْتُ عَائِشَةَ ـ رضى الله عنها ـ تَقُولُ سَمِعَ رَسُولُ اللَّهِ صلى الله عليه وسلم صَوْتَ خُصُومٍ بِالْبَابِ عَالِيَةٍ أَصْوَاتُهُمَا، وَإِذَا أَحَدُهُمَا يَسْتَوْضِعُ الآخَرَ، وَيَسْتَرْفِقُهُ فِي شَىْءٍ وَهْوَ يَقُولُ وَاللَّهِ لاَ أَفْعَلُ‏.‏ فَخَرَجَ عَلَيْهِمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَيْنَ الْمُتَأَلِّي عَلَى اللَّهِ لاَ يَفْعَلُ الْمَعْرُوفَ ‏"‏‏.‏ فَقَالَ أَنَا يَا رَسُولَ اللَّهِ، وَلَهُ أَىُّ ذَلِكَ أَحَبَّ‏.‏\hadithno{2705}\hadithtrans{Narrated Aisha:Once Allah's Messenger (ﷺ) heard the loud voices of some opponents quarreling at the door. One of them was appealing to the other to deduct his debt and asking him to be lenient but the other was saying, "By Allah I will not do so." Allah's Messenger (ﷺ) went out to them and said, "Who is the one who was swearing by Allah that he would not do a favor?" That man said, "I am that person, O Allah's Messenger (ﷺ)! I will give my opponent whatever he wishes}}
\hadithdefcmd{bukhari}{2706}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ كَعْبِ بْنِ مَالِكٍ، عَنْ كَعْبِ بْنِ مَالِكٍ، أَنَّهُ كَانَ لَهُ عَلَى عَبْدِ اللَّهِ بْنِ أَبِي حَدْرَدٍ الأَسْلَمِيِّ مَالٌ، فَلَقِيَهُ فَلَزِمَهُ حَتَّى ارْتَفَعَتْ أَصْوَاتُهُمَا، فَمَرَّ بِهِمَا النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ يَا كَعْبُ ‏"‏‏.‏ فَأَشَارَ بِيَدِهِ كَأَنَّهُ يَقُولُ النِّصْفَ‏.‏ فَأَخَذَ نِصْفَ مَا عَلَيْهِ وَتَرَكَ نِصْفًا‏.‏\hadithno{2706}\hadithtrans{Narrated `Abdullah bin Ka`b bin Malik from Ka`b bin Malik:`Abdullah bin Abu Hadrad Al-Aslami owed Ka`b bin Malik some money. One day the latter met the former and demanded his right, and their voices grew very loud. The Prophet (ﷺ) passed by them and said, "O Ka`b," beckoning with his hand as if intending to say, "Deduct half the debts." So, Ka`b took half what the other owed him and remitted the other half}}
\hadithdefcmd{bukhari}{2707}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ سُلاَمَى مِنَ النَّاسِ عَلَيْهِ صَدَقَةٌ، كُلَّ يَوْمٍ تَطْلُعُ فِيهِ الشَّمْسُ يَعْدِلُ بَيْنَ النَّاسِ صَدَقَةٌ ‏"‏‏.‏\hadithno{2707}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There is a Sadaqa to be given for every joint of the human body; and for every day on which the sun rises there is a reward of a Sadaqa (i.e. charitable gift) for the one who establishes justice among people}}
\hadithdefcmd{bukhari}{2708}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ الزُّبَيْرَ، كَانَ يُحَدِّثُ أَنَّهُ خَاصَمَ رَجُلاً مِنَ الأَنْصَارِ قَدْ شَهِدَ بَدْرًا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي شِرَاجٍ مِنَ الْحَرَّةِ كَانَا يَسْقِيَانِ بِهِ كِلاَهُمَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلزُّبَيْرِ ‏"‏ اسْقِ يَا زُبَيْرُ ثُمَّ أَرْسِلْ إِلَى جَارِكَ ‏"‏‏.‏ فَغَضِبَ الأَنْصَارِيُّ فَقَالَ يَا رَسُولَ اللَّهِ آنْ كَانَ ابْنَ عَمَّتِكَ فَتَلَوَّنَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ اسْقِ ثُمَّ احْبِسْ حَتَّى يَبْلُغَ الْجَدْرَ ‏"‏‏.‏ فَاسْتَوْعَى رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَئِذٍ حَقَّهُ لِلزُّبَيْرِ، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَبْلَ ذَلِكَ أَشَارَ عَلَى الزُّبَيْرِ بِرَأْىٍ سَعَةٍ لَهُ وَلِلأَنْصَارِيِّ، فَلَمَّا أَحْفَظَ الأَنْصَارِيُّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَوْعَى لِلزُّبَيْرِ حَقَّهُ فِي صَرِيحِ الْحُكْمِ‏.‏ قَالَ عُرْوَةُ قَالَ الزُّبَيْرُ وَاللَّهِ مَا أَحْسِبُ هَذِهِ الآيَةَ نَزَلَتْ إِلاَّ فِي ذَلِكَ ‏\{‏فَلاَ وَرَبِّكَ لاَ يُؤْمِنُونَ حَتَّى يُحَكِّمُوكَ فِيمَا شَجَرَ بَيْنَهُمْ‏\}‏ الآيَةَ‏.‏\hadithno{2708}\hadithtrans{Narrated `Urwa bin Az-Zubair:Az-Zubair told me that he quarreled with an Ansari man who had participated in (the battle of) Badr in front of Allah's Messenger (ﷺ) about a water stream which both of them used for irrigation. Allah's Messenger (ﷺ) said to Az-Zubair, "O Zubair! Irrigate (your garden) first, and then let the water flow to your neighbor." The Ansari became angry and said, "O Allah's Messenger (ﷺ)! Is it because he is your cousin?" On that the complexion of Allah's Messenger (ﷺ) changed (because of anger) and said (to Az-Zubair), "Irrigate (your garden) and then withhold the water till it reaches the walls (surrounding the palms)." So, Allah's Messenger (ﷺ) gave Az-Zubair his full right. Before that Allah's Messenger (ﷺ) had given a generous judgment beneficial for Az-Zubair and the Ansari, but when the Ansari irritated Allah's Messenger (ﷺ) he gave Az-Zubair his full right according to the evident law. Az-Zubair said, "By Allah ! I think the following Verse was revealed concerning that case: "But no by your Lord They can have No faith Until they make you judge In all disputes between them}}
\hadithdefcmd{bukhari}{2709}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ تُوُفِّيَ أَبِي وَعَلَيْهِ دَيْنٌ، فَعَرَضْتُ عَلَى غُرَمَائِهِ أَنْ يَأْخُذُوا التَّمْرَ بِمَا عَلَيْهِ، فَأَبَوْا وَلَمْ يَرَوْا أَنَّ فِيهِ وَفَاءً، فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ، فَقَالَ ‏"‏ إِذَا جَدَدْتَهُ فَوَضَعْتَهُ فِي الْمِرْبَدِ آذَنْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏"‏‏.‏ فَجَاءَ وَمَعَهُ أَبُو بَكْرٍ وَعُمَرُ فَجَلَسَ عَلَيْهِ، وَدَعَا بِالْبَرَكَةِ ثُمَّ قَالَ ‏"‏ ادْعُ غُرَمَاءَكَ، فَأَوْفِهِمْ ‏"‏‏.‏ فَمَا تَرَكْتُ أَحَدًا لَهُ عَلَى أَبِي دَيْنٌ إِلاَّ قَضَيْتُهُ، وَفَضَلَ ثَلاَثَةَ عَشَرَ وَسْقًا سَبْعَةٌ عَجْوَةٌ، وَسِتَّةٌ لَوْنٌ أَوْ سِتَّةٌ عَجْوَةٌ وَسَبْعَةٌ لَوْنٌ، فَوَافَيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْمَغْرِبَ فَذَكَرْتُ ذَلِكَ لَهُ فَضَحِكَ فَقَالَ ‏"‏ ائْتِ أَبَا بَكْرٍ وَعُمَرَ فَأَخْبِرْهُمَا ‏"‏‏.‏ فَقَالاَ لَقَدْ عَلِمْنَا إِذْ صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا صَنَعَ أَنْ سَيَكُونُ ذَلِكَ‏.‏ وَقَالَ هِشَامٌ عَنْ وَهْبٍ عَنْ جَابِرٍ صَلاَةَ الْعَصْرِ‏.‏ وَلَمْ يَذْكُرْ أَبَا بَكْرٍ وَلاَ ضَحِكَ، وَقَالَ وَتَرَكَ أَبِي عَلَيْهِ ثَلاَثِينَ وَسْقًا دَيْنًا‏.‏ وَقَالَ ابْنُ إِسْحَاقَ عَنْ وَهْبٍ عَنْ جَابِرٍ صَلاَةَ الظُّهْرِ‏.‏\hadithno{2709}\hadithtrans{Narrated Jabir bin `Abdullah:My father died and was in debt. I suggested that his creditors take the fruits (i.e. dates) of my garden in lieu of the debt of my father, but they refused the offer, as they thought that it would not cover the full debt. So, I went to the Prophet (ﷺ) and told him about it. He said (to me), "When you pluck the dates and collect them in the Mirbad (i.e. a place where dates are dried), call me (Allah's Messenger (ﷺ))." Finally he came accompanied by Abu Bakr and `Umar and sat on the dates and invoked Allah to bless them. Then he said, "Call your creditors and give them their full rights." So, I paid all my father's creditors in full and yet thirteen extra Wasqs of dates remained, seven of which were 'Ajwa and six were Laun or six of which were Ajwa and seven were Laun. I met Allah's Messenger (ﷺ) at sunset and informed him about it. On that he smiled and said, "Go to Abu Bakr and `Umar and tell them about it." They said, "We perceived that was going to happen, as Allah's Messenger (ﷺ) did what he did}}
\hadithdefcmd{bukhari}{2710}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا يُونُسُ،‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ كَعْبٍ، أَنَّ كَعْبَ بْنَ مَالِكٍ، أَخْبَرَهُ أَنَّهُ، تَقَاضَى ابْنَ أَبِي حَدْرَدٍ دَيْنًا كَانَ لَهُ عَلَيْهِ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ، فَارْتَفَعَتْ أَصْوَاتُهُمَا حَتَّى سَمِعَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهْوَ فِي بَيْتٍ، فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَيْهِمَا حَتَّى كَشَفَ سِجْفَ حُجْرَتِهِ، فَنَادَى كَعْبَ بْنَ مَالِكٍ فَقَالَ ‏"‏ يَا كَعْبُ ‏"‏‏.‏ فَقَالَ لَبَّيْكَ يَا رَسُولَ اللَّهِ‏.‏ فَأَشَارَ بِيَدِهِ أَنْ ضَعِ الشَّطْرَ‏.‏ فَقَالَ كَعْبٌ قَدْ فَعَلْتُ يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قُمْ فَاقْضِهِ ‏"‏‏.‏\hadithno{2710}\hadithtrans{Narrated `Abdullah bin Ka`b:That Ka`b bin Malik told him that in the lifetime of Allah's Messenger (ﷺ) he demanded his debt from Ibn Abu Hadrad in the Mosque. Their voices grew louder till Allah's Messenger (ﷺ) heard them while he was in his house. So he lifted the curtain of his room and called Ka`b bin Malik saying, "O Ka`b!" He replied, "Labbaik! O Allah's Messenger (ﷺ)!" He beckoned to him with his hand suggesting that he deduct half the debt. Ka`b said, "I agree, O Allah's Messenger (ﷺ)!" Allah's Messenger (ﷺ) then said (to Ibn Abu Hadrad), "Get up and pay him the rest}}
