% Auto-generated chapter 31 for muslim
% Hadiths in this chapter: 19

\hadithdefcmd{muslim}{4498}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ، الرَّحْمَنِ عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّهُ قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَسَأَلَهُ عَنِ اللُّقَطَةِ فَقَالَ ‏"‏ اعْرِفْ عِفَاصَهَا وَوِكَاءَهَا ثُمَّ عَرِّفْهَا سَنَةً فَإِنْ جَاءَ صَاحِبُهَا وَإِلاَّ فَشَأْنَكَ بِهَا ‏"‏ ‏.‏ قَالَ فَضَالَّةُ الْغَنَمِ قَالَ ‏"‏ لَكَ أَوْ لأَخِيكَ أَوْ لِلذِّئْبِ ‏"‏ ‏.‏ قَالَ فَضَالَّةُ الإِبِلِ قَالَ ‏"‏ مَا لَكَ وَلَهَا مَعَهَا سِقَاؤُهَا وَحِذَاؤُهَا تَرِدُ الْمَاءَ وَتَأْكُلُ الشَّجَرَ حَتَّى يَلْقَاهَا رَبُّهَا ‏"‏ ‏.‏ قَالَ يَحْيَى أَحْسِبُ قَرَأْتُ عِفَاصَهَا\hadithno{4498}\hadithtrans{Zaid b. Khalid al-Juhani reported:A man came to Allah's Apostle (ﷺ) and asked him about picking up of stray articles. He said: Recognise (well) its bag and the strap (by which it is tied) then make announcement of that for a year. If its owner comes (within this time return that to him), otherwise it is yours. He (again) said: (What about) the lost goat? Thereupon he (the Holy Prophet) said: It is yours or for your brother, or for the wolf. He said: (What about) the lost camel? Thereupon he said: You have nothing to do with it; it has a leather bag along with it, and its shoes also. It comes to the watering-place, eats (the leaves of the) trees until its master finds him}}
\hadithdefcmd{muslim}{4499}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالَ ابْنُ حُجْرٍ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا إِسْمَاعِيلُ، - وَهْوَ ابْنُ جَعْفَرٍ - عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ اللُّقَطَةِ فَقَالَ ‏"‏ عَرِّفْهَا سَنَةً ثُمَّ اعْرِفْ وِكَاءَهَا وَعِفَاصَهَا ثُمَّ اسْتَنْفِقْ بِهَا فَإِنْ جَاءَ رَبُّهَا فَأَدِّهَا إِلَيْهِ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ فَضَالَّةُ الْغَنَمِ قَالَ ‏"‏ خُذْهَا فَإِنَّمَا هِيَ لَكَ أَوْ لأَخِيكَ أَوْ لِلذِّئْبِ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ فَضَالَّةُ الإِبِلِ قَالَ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى احْمَرَّتْ وَجْنَتَاهُ - أَوِ احْمَرَّ وَجْهُهُ - ثُمَّ قَالَ ‏"‏ مَا لَكَ وَلَهَا مَعَهَا حِذَاؤُهَا وَسِقَاؤُهَا حَتَّى يَلْقَاهَا رَبُّهَا ‏"‏ ‏.‏\hadithno{4499}\hadithtrans{Zaid b. Khalid al-Juhani reported that a person asked Allah's Apostle (ﷺ) about picking up of stray articles, whereupon he said:Make announcement about it for a year, and recognise well the strap and the bag (containing that) ; then spend that; and if its owner comes, make him the payment of that. He (the inquirer) said: Messenger of Allah, what about the lost goat? he said: Take it, for that is yours or for your brother, or for the wolf. He (again) said: (What about) the lost camel? The Messenger of Allah (ﷺ) was enraged until his cheeks became red (or his face became red) and then said: You have nothing to do about that; it has feet and a leather bag (to quench its thirst) until its owner finds it}}
\hadithdefcmd{muslim}{4500}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي سُفْيَانُ الثَّوْرِيُّ، وَمَالِكُ، بْنُ أَنَسٍ وَعَمْرُو بْنُ الْحَارِثِ وَغَيْرُهُمْ أَنَّ رَبِيعَةَ بْنَ أَبِي عَبْدِ الرَّحْمَنِ، حَدَّثَهُمْ بِهَذَا الإِسْنَادِ، مِثْلَ حَدِيثِ مَالِكٍ غَيْرَ أَنَّهُ زَادَ قَالَ أَتَى رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَنَا مَعَهُ فَسَأَلَهُ عَنِ اللُّقَطَةِ ‏.‏ قَالَ وَقَالَ عَمْرٌو فِي الْحَدِيثِ ‏ "‏ فَإِذَا لَمْ يَأْتِ لَهَا طَالِبٌ فَاسْتَنْفِقْهَا ‏"‏ ‏.‏\hadithno{4500}\hadithtrans{This hadith has been narrated on the authority of Rabi'a b. Abu Abd al-Rahman with the same chain of transmitters but with this addition:" There came a person to Allah's Messenger (ﷺ) while I was with him, and he asked him about picking up of a stray article, and he said: When none comes to demand it, then spend that}}
\hadithdefcmd{muslim}{4501}{وَحَدَّثَنِي أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ الأَوْدِيُّ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنِي سُلَيْمَانُ، - وَهُوَ ابْنُ بِلاَلٍ - عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ قَالَ سَمِعْتُ زَيْدَ بْنَ خَالِدٍ الْجُهَنِيَّ، يَقُولُ أَتَى رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ إِسْمَاعِيلَ بْنِ جَعْفَرٍ ‏.‏ غَيْرَ أَنَّهُ قَالَ فَاحْمَارَّ وَجْهُهُ وَجَبِينُهُ وَغَضِبَ ‏.‏ وَزَادَ بَعْدَ قَوْلِهِ ‏"‏ ثُمَّ عَرِّفْهَا سَنَةً ‏"‏ ‏.‏ ‏"‏ فَإِنْ لَمْ يَجِئْ صَاحِبُهَا كَانَتْ وَدِيعَةً عِنْدَكَ ‏"‏ ‏.‏\hadithno{4501}\hadithtrans{Zaid b. Khalid al-Juhani reported. There came to Allah's Messenger (ﷺ) a person, the rest of the hadith is the same but with the variation (of these words):His face became red, his forehead too, and he felt annoyed; and made an addition after the words: He should make announcement of that for a year, and if its owner does not turn up, then it is a trust with you}}
\hadithdefcmd{muslim}{4502}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ أَنَّهُ سَمِعَ زَيْدَ بْنَ خَالِدٍ الْجُهَنِيَّ، صَاحِبَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ اللُّقَطَةِ الذَّهَبِ أَوِ الْوَرِقِ فَقَالَ ‏"‏ اعْرِفْ وِكَاءَهَا وَعِفَاصَهَا ثُمَّ عَرِّفْهَا سَنَةً فَإِنْ لَمْ تَعْرِفْ فَاسْتَنْفِقْهَا وَلْتَكُنْ وَدِيعَةً عِنْدَكَ فَإِنْ جَاءَ طَالِبُهَا يَوْمًا مِنَ الدَّهْرِ فَأَدِّهَا إِلَيْهِ ‏"‏ ‏.‏ وَسَأَلَهُ عَنْ ضَالَّةِ الإِبِلِ فَقَالَ ‏"‏ مَا لَكَ وَلَهَا دَعْهَا فَإِنَّ مَعَهَا حِذَاءَهَا وَسِقَاءَهَا تَرِدُ الْمَاءَ وَتَأْكُلُ الشَّجَرَ حَتَّى يَجِدَهَا رَبُّهَا ‏"‏ ‏.‏ وَسَأَلَهُ عَنِ الشَّاةِ فَقَالَ ‏"‏ خُذْهَا فَإِنَّمَا هِيَ لَكَ أَوْ لأَخِيكَ أَوْ لِلذِّئْبِ ‏"‏ ‏.‏\hadithno{4502}\hadithtrans{Zaid b. Khalid al-Juhani, the Companion ot Allah's Messenger (ﷺ), said that Allah's Messenger (ﷺ) was asked about the picking up of stray gold or silver, whereupon he said:Recognise well the strap and the bag (containing) that and then make an announcement regarding that for one year, but if none recognises it, then spend that and it would be a trust with you; and if someone comes one day to make demand of that, then pay that to him. He (the inquirer) asked about the lost camel, whereupon he said: You have nothing to do with that. Leave that alone, for it has feet and also a leather bag, it drinks water, and eats (the leaves) of the trees. He asked him about sheep, whereupon he said: Take it, it is for you, or for your brother, or for the wolf}}
\hadithdefcmd{muslim}{4503}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، وَرَبِيعَةُ الرَّأْىِ بْنُ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ، خَالِدٍ الْجُهَنِيِّ أَنَّ رَجُلاً، سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنْ ضَالَّةِ الإِبِلِ ‏.‏ زَادَ رَبِيعَةُ فَغَضِبَ حَتَّى احْمَرَّتْ وَجْنَتَاهُ ‏.‏ وَاقْتَصَّ الْحَدِيثَ بِنَحْوِ حَدِيثِهِمْ وَزَادَ ‏ "‏ فَإِنْ جَاءَ صَاحِبُهَا فَعَرَفَ عِفَاصَهَا وَعَدَدَهَا وَوِكَاءَهَا فَأَعْطِهَا إِيَّاهُ وَإِلاَّ فَهْىَ لَكَ ‏"‏ ‏.‏\hadithno{4503}\hadithtrans{Zaid b. Khalid al-Juhani reported:A person asked Allah's Apostle (ﷺ) about a lost camel; Rabi'a made this addition: He (the Holy Prophet) was so much annoyed that his cheeks became red." The rest of the hadith is the same. He (the narrator) made this addition:" If its (that of the article) owner comes and he recognises the bag (which contained it) and its number, and the strap. then give that to them, but if not, then it is for you}}
\hadithdefcmd{muslim}{4506}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنِي أَبُو بَكْرِ، بْنُ نَافِعٍ - وَاللَّفْظُ لَهُ - حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، قَالَ سَمِعْتُ سُوَيْدَ، بْنَ غَفَلَةَ قَالَ خَرَجْتُ أَنَا وَزَيْدُ بْنُ صُوحَانَ، وَسَلْمَانُ بْنُ رَبِيعَةَ، غَازِينَ فَوَجَدْتُ سَوْطًا فَأَخَذْتُهُ فَقَالاَ لِي دَعْهُ ‏.‏ فَقُلْتُ لاَ وَلَكِنِّي أُعَرِّفُهُ فَإِنْ جَاءَ صَاحِبُهُ وَإِلاَّ اسْتَمْتَعْتُ بِهِ ‏.‏ قَالَ فَأَبَيْتُ عَلَيْهِمَا فَلَمَّا رَجَعْنَا مِنْ غَزَاتِنَا قُضِيَ لِي أَنِّي حَجَجْتُ فَأَتَيْتُ الْمَدِينَةَ فَلَقِيتُ أُبَىَّ بْنَ كَعْبٍ فَأَخْبَرْتُهُ بِشَأْنِ السَّوْطِ وَبِقَوْلِهِمَا فَقَالَ إِنِّي وَجَدْتُ صُرَّةً فِيهَا مِائَةُ دِينَارٍ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَتَيْتُ بِهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ عَرِّفْهَا حَوْلاً ‏"‏ ‏.‏ قَالَ فَعَرَّفْتُهَا فَلَمْ أَجِدْ مَنْ يَعْرِفُهَا ثُمَّ أَتَيْتُهُ ‏.‏ فَقَالَ ‏"‏ عَرِّفْهَا حَوْلاً ‏"‏ ‏.‏ فَعَرَّفْتُهَا فَلَمْ أَجِدْ مَنْ يَعْرِفُهَا ثُمَّ أَتَيْتُهُ ‏.‏ فَقَالَ ‏"‏ عَرِّفْهَا حَوْلاً ‏"‏ ‏.‏ فَعَرَّفْتُهَا فَلَمْ أَجِدْ مَنْ يَعْرِفُهَا ‏.‏ فَقَالَ ‏"‏ احْفَظْ عَدَدَهَا وَوِعَاءَهَا وَوِكَاءَهَا فَإِنْ جَاءَ صَاحِبُهَا وَإِلاَّ فَاسْتَمْتِعْ بِهَا ‏"‏ ‏.‏ فَاسْتَمْتَعْتُ بِهَا ‏.‏ فَلَقِيتُهُ بَعْدَ ذَلِكَ بِمَكَّةَ فَقَالَ لاَ أَدْرِي بِثَلاَثَةِ أَحْوَالٍ أَوْ حَوْلٍ وَاحِدٍ ‏.‏\hadithno{4506}\hadithtrans{Salama b. Kuhail reported:I heard Sowaid b. Ghafala say: I went out, and also Zaid b. Suhan and Salman b. Rabi'a for Jihad, and I found a whip and took it up. They said to me: Leave it. I said: No. but I will make announcement of it and if its owner comes (then I will return that), otherwise I will use it, and I refused them. When we returned from Jihad. by a good fortune for me, I performed Pilgrimage. I came to Medina and met Ubayy b. Ka'b, and related to him the affair of the whip and their opinion (the opinion of Zaid b. Suhan and Salman b. Rabi'a) about it (i. e. I should throw it). Thereupon he said: I found a money bag during the lifetime of Allah's Messenger (ﷺ) which contained one hundred dinars. I came to him along with it, and he said: Make an announcement of it for one year; so I announced it, but did not find anyone who could (claim it after) recognising it. I again came to him and he said: Make announcement for one year. So I made announcement of it, but I found none who could recognise it. I came to him he said: Make announcement of it for one year. I made announcement of that but did not find one who could recognise it, whereupon he said: Preserve (in your mind) its number, its bag and its strap, and if its owner comes (then return that to him), otherwise make use of it. So I made use of that. I (Shu'ba) met him (Salama b. Kuhail) after this in Mecca, and he said: I do not know whether he said three years or one year}}
\hadithdefcmd{muslim}{4507}{وَحَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ الْعَبْدِيُّ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي سَلَمَةُ، بْنُ كُهَيْلٍ أَوْ أَخْبَرَ الْقَوْمَ، وَأَنَا فِيهِمْ، قَالَ سَمِعْتُ سُوَيْدَ بْنَ غَفَلَةَ، قَالَ خَرَجْتُ مَعَ زَيْدِ بْنِ صُوحَانَ وَسَلْمَانَ بْنِ رَبِيعَةَ فَوَجَدْتُ سَوْطًا ‏.‏ وَاقْتَصَّ الْحَدِيثَ بِمِثْلِهِ إِلَى قَوْلِهِ فَاسْتَمْتَعْتُ بِهَا ‏.‏ قَالَ شُعْبَةُ فَسَمِعْتُهُ بَعْدَ عَشْرِ سِنِينَ يَقُولُ عَرَّفَهَا عَامًا وَاحِدًا ‏.‏\hadithno{4507}\hadithtrans{Shu'ba reported:Salama b. Kuhail informed me or he informed people and I was among them. He said: I heard Sawaid b. Ghafala who reported: I went out along with Zaid b. Suhan and Salman b. Rabi'a, and found a whip, the rest of the hadith is the same up to the words:" I made use of that." Shu'ba said: I heard him say after ten years, that he made an announcement of it for one year}}
\hadithdefcmd{muslim}{4508}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي، شَيْبَةَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي جَمِيعًا، عَنْ سُفْيَانَ، ح وَحَدَّثَنِي مُحَمَّدُ، بْنُ حَاتِمٍ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الرَّقِّيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ عَمْرٍو - عَنْ زَيْدِ، بْنِ أَبِي أُنَيْسَةَ ح وَحَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، كُلُّ هَؤُلاَءِ عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ شُعْبَةَ ‏.‏ وَفِي حَدِيثِهِمْ جَمِيعًا ثَلاَثَةَ أَحْوَالٍ إِلاَّ حَمَّادَ بْنَ سَلَمَةَ فَإِنَّ فِي حَدِيثِهِ عَامَيْنِ أَوْ ثَلاَثَةً ‏.‏ وَفِي حَدِيثِ سُفْيَانَ وَزَيْدِ بْنِ أَبِي أُنَيْسَةَ وَحَمَّادِ بْنِ سَلَمَةَ ‏"‏ فَإِنْ جَاءَ أَحَدٌ يُخْبِرُكَ بِعَدَدِهَا وَوِعَائِهَا وَوِكَائِهَا فَأَعْطِهَا إِيَّاهُ ‏"‏ ‏.‏ وَزَادَ سُفْيَانُ فِي رِوَايَةِ وَكِيعٍ ‏"‏ وَإِلاَّ فَهِيَ كَسَبِيلِ مَالِكَ ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ نُمَيْرٍ ‏"‏ وَإِلاَّ فَاسْتَمْتِعْ بِهَا ‏"‏ ‏.‏\hadithno{4508}\hadithtrans{This hadith has been narrated on the authority of Salama b. Kuhail through different chains of transmitters. In their ahadith, it is three years, except in the hadith of Hammid b. Salama it is two years or three years. In the hadith transmitted on the authority of Sufyan and Zaid b. Abu Unaisa and Hammid b. Salama (the words are):" If someone comes and informs you about the number (of articles) of the bag and the straps, then give that to him." Sufyan has made this addition in the narration of Waki':" Otherwise it is like your property." And in the narration of Ibn Numair the words are:" Otherwise make use of that}}
\hadithdefcmd{muslim}{4509}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَيُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالاَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ يَحْيَى بْنِ عَبْدِ الرَّحْمَنِ بْنِ حَاطِبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عُثْمَانَ التَّيْمِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُقَطَةِ الْحَاجِّ ‏.‏\hadithno{4509}\hadithtrans{Abd al-Rahman b. 'Uthman al-Taimi reported that Allah's Messenger (ﷺ) forbade taking into custody the stray thing of the pilgrims}}
\hadithdefcmd{muslim}{4510}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَيُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ بَكْرِ بْنِ سَوَادَةَ، عَنْ أَبِي سَالِمٍ الْجَيْشَانِيِّ، عَنْ زَيْدِ بْنِ خَالِدٍ، الْجُهَنِيِّ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ آوَى ضَالَّةً فَهُوَ ضَالٌّ مَا لَمْ يُعَرِّفْهَا ‏"‏ ‏.‏\hadithno{4510}\hadithtrans{Zaid b. Khalid al-Juhani reported Allah's Messenger (ﷺ) as sayin.:He who found a stray article is himself led astray if he does not advertise it}}
\hadithdefcmd{muslim}{4511}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكِ بْنِ أَنَسٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحْلُبَنَّ أَحَدٌ مَاشِيَةَ أَحَدٍ إِلاَّ بِإِذْنِهِ أَيُحِبُّ أَحَدُكُمْ أَنْ تُؤْتَى مَشْرُبَتُهُ فَتُكْسَرَ خِزَانَتُهُ فَيُنْتَقَلَ طَعَامُهُ إِنَّمَا تَخْزُنُ لَهُمْ ضُرُوعُ مَوَاشِيهِمْ أَطْعِمَتَهُمْ فَلاَ يَحْلُبَنَّ أَحَدٌ مَاشِيَةَ أَحَدٍ إِلاَّ بِإِذْنِهِ ‏"‏ ‏.‏\hadithno{4511}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) having said this:None (of you) should milk the animal of another, but with his permission. Does any one of you like that his chamber be raided, and his vaults be broken, and his foodstuff be removed? Verily the treasures for them (those who keep animals) are the udders of the animals which feed them. So none of you should milk the animal of another but with his permission}}
\hadithdefcmd{muslim}{4512}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ رُمْحٍ، جَمِيعًا عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنِي أَبِي كِلاَهُمَا، عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنِي أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - جَمِيعًا عَنْ أَيُّوبَ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ،عَنْ أَيُّوبَ، وَابْنُ، جُرَيْجٍ عَنْ مُوسَى، كُلُّ هَؤُلاَءِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ نَحْوَ حَدِيثِ مَالِكٍ غَيْرَ أَنَّ فِي حَدِيثِهِمْ جَمِيعًا ‏"‏ فَيُنْتَثَلَ ‏"‏ ‏.‏ إِلاَّ اللَّيْثَ بْنَ سَعْدٍ فَإِنَّ فِي حَدِيثِهِ ‏"‏ فَيُنْتَقَلَ طَعَامُهُ ‏"‏ ‏.‏ كَرِوَايَةِ مَالِكٍ ‏.‏\hadithno{4512}\hadithtrans{This hadith has been narrated through another chain of transmitters with a slight variation of words}}
\hadithdefcmd{muslim}{4513}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي شُرَيْحٍ الْعَدَوِيِّ، أَنَّهُ قَالَ سَمِعَتْ أُذُنَاىَ، وَأَبْصَرَتْ، عَيْنَاىَ حِينَ تَكَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيُكْرِمْ ضَيْفَهُ جَائِزَتَهُ ‏"‏ ‏.‏ قَالُوا وَمَا جَائِزَتُهُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ يَوْمُهُ وَلَيْلَتُهُ وَالضِّيَافَةُ ثَلاَثَةُ أَيَّامٍ فَمَا كَانَ وَرَاءَ ذَلِكَ فَهُوَ صَدَقَةٌ عَلَيْهِ - وَقَالَ - مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيَقُلْ خَيْرًا أَوْ لِيَصْمُتْ ‏"‏ ‏.‏\hadithno{4513}\hadithtrans{Abd Shuraib al-Adawi reported:My eare listened and my eye saw when Allah's Messenger (ﷺ) spoke and said: He who believes In Allah and the eireafter should show respect to the guest even with utmost kindness and courtesy. They said: Messenger of Allah, what is this utmost kindness and courtesy? He replied: It is for a day and a night. Hospitality extends for three days, and what is beyond that is a Sadaqa for him; and he who believes in Allah and the Hereafter should say something good or keep quiet}}
\hadithdefcmd{muslim}{4514}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي شُرَيْحٍ الْخُزَاعِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الضِّيَافَةُ ثَلاَثَةُ أَيَّامٍ وَجَائِزَتُهُ يَوْمٌ وَلَيْلَةٌ وَلاَ يَحِلُّ لِرَجُلٍ مُسْلِمٍ أَنْ يُقِيمَ عِنْدَ أَخِيهِ حَتَّى يُؤْثِمَهُ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَكَيْفَ يُؤْثِمُهُ قَالَ ‏"‏ يُقِيمُ عِنْدَهُ وَلاَ شَىْءَ لَهُ يَقْرِيهِ بِهِ ‏"‏ ‏.‏\hadithno{4514}\hadithtrans{Abu Shuriah al-Khuza'i reported Allah's Messenger (ﷺ) as saying:(The period of the entertainment of a guest is three days, and utmost kindness and courtesy is for a day and a night. =" It is not permissible for a Muslim to stay with, his brother until he makes him sinful. They said: Messenger of Allah, how he would make him sinful? He (the Holy Prophet) said: He stays with him (so long) that nothing is left with him to entertain him}}
\hadithdefcmd{muslim}{4515}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو بَكْرٍ، - يَعْنِي الْحَنَفِيَّ - حَدَّثَنَا عَبْدُ الْحَمِيدِ، بْنُ جَعْفَرٍ حَدَّثَنَا سَعِيدٌ الْمَقْبُرِيُّ، أَنَّهُ سَمِعَ أَبَا شُرَيْحٍ الْخُزَاعِيَّ، يَقُولُ سَمِعَتْ أُذُنَاىَ، وَبَصُرَ، عَيْنِي وَوَعَاهُ قَلْبِي حِينَ تَكَلَّمَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ اللَّيْثِ وَذَكَرَ فِيهِ ‏ "‏ وَلاَ يَحِلُّ لأَحَدِكُمْ أَنْ يُقِيمَ عِنْدَ أَخِيهِ حَتَّى يُؤْثِمَهُ ‏"‏ ‏.‏ بِمِثْلِ مَا فِي حَدِيثِ وَكِيعٍ ‏.‏\hadithno{4515}\hadithtrans{Sa'id al-Maqburi reported:I heard Abu Shuraih al-Khuzill saying: My ears heard and my eyes saw and my mind retained it, when Allah's Messenger (ﷺ) spok this, and he then narrated the hadith and made mention of this:" It is not permissible for any one of you to stay with his brother until he makes him sinful}}
\hadithdefcmd{muslim}{4516}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّهُ قَالَ قُلْنَا يَا رَسُولَ اللَّهِ إِنَّكَ تَبْعَثُنَا فَنَنْزِلُ بِقَوْمٍ فَلاَ يَقْرُونَنَا فَمَا تَرَى فَقَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ نَزَلْتُمْ بِقَوْمٍ فَأَمَرُوا لَكُمْ بِمَا يَنْبَغِي لِلضَّيْفِ فَاقْبَلُوا فَإِنْ لَمْ يَفْعَلُوا فَخُذُوا مِنْهُمْ حَقَّ الضَّيْفِ الَّذِي يَنْبَغِي لَهُمْ ‏"‏ ‏.‏\hadithno{4516}\hadithtrans{Uqba b. Amir reported:We said to Allah's Messenger (ﷺ): You send us out and we come to the people who do not give us hospitality, so what is your opinion? Thereupon Allah's Messenger (ﷺ) said: If you come to the people who order for you what is befitting a guest, accept it; but if they do not. take from them what befits them to give to a guest}}
\hadithdefcmd{muslim}{4517}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا أَبُو الأَشْهَبِ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ بَيْنَمَا نَحْنُ فِي سَفَرٍ مَعَ النَّبِيِّ صلى الله عليه وسلم إِذْ جَاءَ رَجُلٌ عَلَى رَاحِلَةٍ لَهُ قَالَ فَجَعَلَ يَصْرِفُ بَصَرَهُ يَمِينًا وَشِمَالاً فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَ مَعَهُ فَضْلُ ظَهْرٍ فَلْيَعُدْ بِهِ عَلَى مَنْ لاَ ظَهْرَ لَهُ وَمَنْ كَانَ لَهُ فَضْلٌ مِنْ زَادٍ فَلْيَعُدْ بِهِ عَلَى مَنْ لاَ زَادَ لَهُ ‏"‏ ‏.‏ قَالَ فَذَكَرَ مِنْ أَصْنَافِ الْمَالِ مَا ذَكَرَ حَتَّى رَأَيْنَا أَنَّهُ لاَ حَقَّ لأَحَدٍ مِنَّا فِي فَضْلٍ ‏.‏\hadithno{4517}\hadithtrans{Abu Sa'id al-Khudri reported:While we were with the Messenger of Allah (ﷺ) on a journey, a person came upon his mount and began to stare on the right and on the left, (it was at this moment) that Allah's Messenger (ﷺ) said: He who has an extra mount should give that to one who has no mount for him, and he who has surplus of provisions should give them to him who has no provisions, and he made mention of so many kinds of wealth until we were of the opinion that none of us has any right over the surplus}}
\hadithdefcmd{muslim}{4518}{حَدَّثَنِي أَحْمَدُ بْنُ يُوسُفَ الأَزْدِيُّ، حَدَّثَنَا النَّضْرُ، - يَعْنِي ابْنَ مُحَمَّدٍ الْيَمَامِيَّ - حَدَّثَنَا عِكْرِمَةُ، - وَهُوَ ابْنُ عَمَّارٍ - حَدَّثَنَا إِيَاسُ بْنُ سَلَمَةَ، عَنْ أَبِيهِ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةٍ فَأَصَابَنَا جَهْدٌ حَتَّى هَمَمْنَا أَنْ نَنْحَرَ بَعْضَ ظَهْرِنَا فَأَمَرَ نَبِيُّ اللَّهِ صلى الله عليه وسلم فَجَمَعْنَا مَزَاوِدَنَا فَبَسَطْنَا لَهُ نِطَعًا فَاجْتَمَعَ زَادُ الْقَوْمِ عَلَى النِّطَعِ قَالَ فَتَطَاوَلْتُ لأَحْزُرَهُ كَمْ هُوَ فَحَزَرْتُهُ كَرَبْضَةِ الْعَنْزِ وَنَحْنُ أَرْبَعَ عَشْرَةَ مِائَةً قَالَ فَأَكَلْنَا حَتَّى شَبِعْنَا جَمِيعًا ثُمَّ حَشَوْنَا جُرُبَنَا فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ فَهَلْ مِنْ وَضُوءٍ ‏"‏ ‏.‏ قَالَ فَجَاءَ رَجُلٌ بِإِدَاوَةٍ لَهُ فِيهَا نُطْفَةٌ فَأَفْرَغَهَا فِي قَدَحٍ فَتَوَضَّأْنَا كُلُّنَا نُدَغْفِقُهُ دَغْفَقَةً أَرْبَعَ عَشْرَةَ مِائَةً ‏.‏ قَالَ ثُمَّ جَاءَ بَعْدَ ذَلِكَ ثَمَانِيَةٌ فَقَالُوا هَلْ مِنْ طَهُورٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَرِغَ الْوَضُوءُ ‏"‏ ‏.‏\hadithno{4518}\hadithtrans{Iyas b. Salama reported on the authority of his father:We set out on an expedition with, Allah's Messenger (ﷺ). We faced hardship (in getting provisions) until we decided to slaughter some of our riding animals. Allah's Apostle (ﷺ), commanded us to pool our provisions of food. So we spread a sheet of leather and the provisions of the people were collected on it. I stretched myself to measure how much that was (the length and breadth of the sheet on which the provisions were laid). I measured it and (found) that it was (in length and breadth) of (so much size) on which a goat could sit. We were fourteen hundred persons. We (all) ate until we were fully satisfied and then filled our bags with provisions. Then Allah's Apostle (ﷺ) said: Is there any water for performing ablution. Then there came a man with a small bucket containing some water. He threw it in a basin. We all fourteen hundred persons performed ablution using the water in plenty. Then there came after that eight persons and they said: Is there any water to perform ablution? Thereupon Allah's Messenger (ﷺ) said: The ablution has already been performed}}
