% Auto-generated chapter 48 for bukhari
% Hadiths in this chapter: 8

\hadithdefcmd{bukhari}{2508}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ وَلَقَدْ رَهَنَ النَّبِيُّ صلى الله عليه وسلم دِرْعَهُ بِشَعِيرٍ، وَمَشَيْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم بِخُبْزِ شَعِيرٍ وَإِهَالَةٍ سَنِخَةٍ، وَلَقَدْ سَمِعْتُهُ يَقُولُ ‏ "‏ مَا أَصْبَحَ لآلِ مُحَمَّدٍ صلى الله عليه وسلم إِلاَّ صَاعٌ، وَلاَ أَمْسَى ‏"‏‏.‏ وَإِنَّهُمْ لَتِسْعَةُ أَبْيَاتٍ‏.‏\hadithno{2508}\hadithtrans{Narrated Anas:No doubt, the Prophet (ﷺ) mortgaged his armor for barley grains. Once I took barley bread with some dissolved fat on it to the Prophet (ﷺ) and I heard him saying, "The household of Muhammad did not possess except a Sa (of food grain, barley, etc.) for both the morning and the evening meals although they were nine houses}}
\hadithdefcmd{bukhari}{2509}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، قَالَ تَذَاكَرْنَا عِنْدَ إِبْرَاهِيمَ الرَّهْنَ، وَالْقَبِيلَ فِي السَّلَفِ، فَقَالَ إِبْرَاهِيمُ حَدَّثَنَا الأَسْوَدُ عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم اشْتَرَى مِنْ يَهُودِيٍّ طَعَامًا إِلَى أَجَلٍ وَرَهَنَهُ دِرْعَهُ‏.‏\hadithno{2509}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) bought some foodstuff on credit for a limited period and mortgaged his armor for it}}
\hadithdefcmd{bukhari}{2510}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لِكَعْبِ بْنِ الأَشْرَفِ فَإِنَّهُ آذَى اللَّهَ وَرَسُولَهُ صلى الله عليه وسلم ‏"‏‏.‏ فَقَالَ مُحَمَّدُ بْنُ مَسْلَمَةَ أَنَا‏.‏ فَأَتَاهُ فَقَالَ أَرَدْنَا أَنْ تُسْلِفَنَا وَسْقًا أَوْ وَسْقَيْنِ‏.‏ فَقَالَ ارْهَنُونِي نِسَاءَكُمْ‏.‏ قَالُوا كَيْفَ نَرْهَنُكَ نِسَاءَنَا، وَأَنْتَ أَجْمَلُ الْعَرَبِ قَالَ فَارْهَنُونِي أَبْنَاءَكُمْ‏.‏ قَالُوا كَيْفَ نَرْهَنُ أَبْنَاءَنَا فَيُسَبُّ أَحَدُهُمْ، فَيُقَالُ رُهِنَ بِوَسْقٍ أَوْ وَسْقَيْنِ هَذَا عَارٌ عَلَيْنَا وَلَكِنَّا نَرْهَنُكَ اللأْمَةَ ـ قَالَ سُفْيَانُ يَعْنِي السِّلاَحَ ـ فَوَعَدَهُ أَنْ يَأْتِيَهُ فَقَتَلُوهُ، ثُمَّ أَتَوُا النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرُوهُ‏.‏\hadithno{2510}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) said, "Who would kill Ka`b bin Al-Ashraf as he has harmed Allah and His Apostle ?" Muhammad bin Maslama (got up and) said, "I will kill him." So, Muhammad bin Maslama went to Ka`b and said, "I want a loan of one or two Wasqs of food grains." Ka`b said, "Mortgage your women to me." Muhammad bin Maslama said, "How can we mortgage our women, and you are the most handsome among the Arabs?" He said, "Then mortgage your sons to me." Muhammad said, "How can we mortgage our sons, as the people will abuse them for being mortgaged for one or two Wasqs of food grains? It is shameful for us. But we will mortgage our arms to you." So, Muhammad bin Maslama promised him that he would come to him next time. They (Muhammad bin Maslama and his companions came to him as promised and murdered him. Then they went to the Prophet (ﷺ) and told him about it}}
\hadithdefcmd{bukhari}{2511}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا زَكَرِيَّاءُ، عَنْ عَامِرٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَقُولُ ‏ "‏ الرَّهْنُ يُرْكَبُ بِنَفَقَتِهِ، وَيُشْرَبُ لَبَنُ الدَّرِّ إِذَا كَانَ مَرْهُونًا ‏"‏‏.‏\hadithno{2511}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "One can ride the mortgaged animal because of what one spends on it, and one can drink the milk of a milch animal as long as it is mortgaged}}
\hadithdefcmd{bukhari}{2512}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا زَكَرِيَّاءُ، عَنِ الشَّعْبِيِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ ‏ "‏ الرَّهْنُ يُرْكَبُ بِنَفَقَتِهِ إِذَا كَانَ مَرْهُونًا، وَلَبَنُ الدَّرِّ يُشْرَبُ بِنَفَقَتِهِ إِذَا كَانَ مَرْهُونًا، وَعَلَى الَّذِي يَرْكَبُ وَيَشْرَبُ النَّفَقَةُ ‏"‏‏.‏\hadithno{2512}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The mortgaged animal can be used for riding as long as it is fed and the milk of the milch animal can be drunk according to what one spends on it. The one who rides the animal or drinks its milk should provide the expenditures}}
\hadithdefcmd{bukhari}{2513}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتِ اشْتَرَى رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ يَهُودِيٍّ طَعَامًا وَرَهَنَهُ دِرْعَهُ‏.‏\hadithno{2513}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) bought some foodstuff from a Jew and mortgaged his armor to him}}
\hadithdefcmd{bukhari}{2514}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا نَافِعُ بْنُ عُمَرَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ كَتَبْتُ إِلَى ابْنِ عَبَّاسٍ فَكَتَبَ إِلَىَّ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى أَنَّ الْيَمِينَ عَلَى الْمُدَّعَى عَلَيْهِ‏.‏\hadithno{2514}\hadithtrans{Narrated Ibn Abu Mulaika:I wrote a letter to Ibn `Abbas and he wrote to me that the Prophet (ﷺ) had given the verdict that the defendant had to take an oath}}
\hadithdefcmd{bukhari}{2515}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ عَبْدُ اللَّهِ ـ رضى الله عنه مَنْ حَلَفَ عَلَى يَمِينٍ، يَسْتَحِقُّ بِهَا مَالاً وَهْوَ فِيهَا فَاجِرٌ، لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ، فَأَنْزَلَ اللَّهُ تَصْدِيقَ ذَلِكَ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ فَقَرَأَ إِلَى ‏\{‏عَذَابٌ أَلِيمٌ‏\}‏‏.‏ثُمَّ إِنَّ الأَشْعَثَ بْنَ قَيْسٍ خَرَجَ إِلَيْنَا فَقَالَ مَا يُحَدِّثُكُمْ أَبُو عَبْدِ الرَّحْمَنِ قَالَ فَحَدَّثْنَاهُ قَالَ فَقَالَ صَدَقَ لَفِيَّ وَاللَّهِ أُنْزِلَتْ، كَانَتْ بَيْنِي وَبَيْنَ رَجُلٍ خُصُومَةٌ فِي بِئْرٍ فَاخْتَصَمْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ شَاهِدُكَ أَوْ يَمِينُهُ ‏"‏‏.‏ قُلْتُ إِنَّهُ إِذًا يَحْلِفُ وَلاَ يُبَالِي‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ يَسْتَحِقُّ بِهَا مَالاً هُوَ فِيهَا فَاجِرٌ، لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ فَأَنْزَلَ اللَّهُ تَصْدِيقَ ذَلِكَ، ثُمَّ اقْتَرَأَ هَذِهِ الآيَةَ ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ إِلَى ‏\{‏وَلَهُمْ عَذَابٌ أَلِيمٌ‏\}‏‏.‏\hadithno{2515}\hadithtrans{Narrated Abu Wail: Abdullah (bin Mas'ud) said, "Whoever took a false oath in order to grab somebody's property will meet Allah while Allah will be angry with him." Allah revealed the following verse to confirm that:--"Verily! Those who purchase a small gain at the cost of Allah's covenant And their oaths...a painful torment." (3.77) Al-Ash'ath bin Qais came to us and asked as to what Abu Abdur-Rehman (i.e. Ibn Mas'ud) was telling you." We related the story to him. On that he said, "He has told the truth. This verse was revealed about me. I had some dispute with another man regarding a well and we took the case before Allah's Messenger (ﷺ). Allah's Messenger (ﷺ) said (to me), "Produce two witnesses (to support your claim); otherwise the defendant has the right to take an oath (to refute your claim).' I said, 'The defendant would not mind to take a false oath." Allah's Messenger (ﷺ) then said, 'Whoever took a false oath in order to grab someone else's property will meet Allah, Allah will be angry with him.' Allah then revealed what Confirmed it." Al-Ash'ath then recited the following Verse:--"Verily! Those who purchase a small gain at the cost of Allah's covenant, And their oaths . . . (to) . . . they shall have a painful torment!' (3.77) (See Hadith No)}}
