% Auto-generated chapter 36 for malik
% Hadiths in this chapter: 56

\hadithdefcmd{malik}{1399}{حَدَّثَنَا يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا أَنَا بَشَرٌ وَإِنَّكُمْ تَخْتَصِمُونَ إِلَىَّ فَلَعَلَّ بَعْضَكُمْ أَنْ يَكُونَ أَلْحَنَ بِحُجَّتِهِ مِنْ بَعْضٍ فَأَقْضِيَ لَهُ عَلَى نَحْوِ مَا أَسْمَعُ مِنْهُ فَمَنْ قَضَيْتُ لَهُ بِشَىْءٍ مِنْ حَقِّ أَخِيهِ فَلاَ يَأْخُذَنَّ مِنْهُ شَيْئًا فَإِنَّمَا أَقْطَعُ لَهُ قِطْعَةً مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{1399}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father from Zaynab bint Abi Salama from Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, that the Messenger of Allah, may Allah bless him and grant him peace, said, "I am but a man to whom you bring your disputes. Perhaps one of you is more eloquent in his proof than the other, so I give judgement according to what I have heard from him. Whatever I decide for him which is part of the right of his brother, he must not take any of it, for I am granting him a portion of the Fire}}
\hadithdefcmd{malik}{1400}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، اخْتَصَمَ إِلَيْهِ مُسْلِمٌ وَيَهُودِيٌّ فَرَأَى عُمَرُ أَنَّ الْحَقَّ لِلْيَهُودِيِّ فَقَضَى لَهُ فَقَالَ لَهُ الْيَهُودِيُّ وَاللَّهِ لَقَدْ قَضَيْتَ بِالْحَقِّ ‏.‏ فَضَرَبَهُ عُمَرُ بْنُ الْخَطَّابِ بِالدِّرَّةِ ثُمَّ قَالَ وَمَا يُدْرِيكَ فَقَالَ لَهُ الْيَهُودِيُّ إِنَّا نَجِدُ أَنَّهُ لَيْسَ قَاضٍ يَقْضِي بِالْحَقِّ إِلاَّ كَانَ عَنْ يَمِينِهِ مَلَكٌ وَعَنْ شِمَالِهِ مَلَكٌ يُسَدِّدَانِهِ وَيُوَفِّقَانِهِ لِلْحَقِّ مَادَامَ مَعَ الْحَقِّ فَإِذَا تَرَكَ الْحَقَّ عَرَجَا وَتَرَكَاهُ ‏.‏\hadithno{1400}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Yahya ibn Said from Said ibn al-Musayyab that Umar ibn al-Khattab had a dispute brought to him between a muslim and a jew. Umar saw that the right belonged to the jew and decided in his favour. The jew said to him, "By Allah! You have judged correctly.'' So Umar ibn al-Khattab struck him with a whip and said, "How can you be sure." The jew said to him, "We find that there is no judge who judges correctly but that there is an angel on his right side and an angel on his left side who guide him and give him success in the truth as long as he is with the truth. When he leaves the truth, they rise and leave him}}
\hadithdefcmd{malik}{1401}{حَدَّثَنَا يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عُثْمَانَ، عَنْ أَبِي عَمْرَةَ الأَنْصَارِيِّ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ أُخْبِرُكُمْ بِخَيْرِ الشُّهَدَاءِ الَّذِي يَأْتِي بِشَهَادَتِهِ قَبْلَ أَنْ يُسْأَلَهَا أَوْ يُخْبِرُ بِشَهَادَتِهِ قَبْلَ أَنْ يُسْأَلَهَا ‏"‏ ‏.‏\hadithno{1401}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr ibn Muhammad ibn Amr ibn Hazm from his father from Abdullah ibn Amr ibn Uthman from Abu Amra al-Ansari from Zayd ibn Khalid al-Juhani that the Messenger of Allah, may Allah bless him and grant him peace, said, "Shall I not tell you who is the best of witnesses? The one who brings his testimony before he is asked for it, or tells his testimony before he is asked for it}}
\hadithdefcmd{malik}{1402}{وَحَدَّثَنِي مَالِكٌ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّهُ قَالَ قَدِمَ عَلَى عُمَرَ بْنِ الْخَطَّابِ رَجُلٌ مِنْ أَهْلِ الْعِرَاقِ فَقَالَ لَقَدْ جِئْتُكَ لأَمْرٍ مَا لَهُ رَأْسٌ وَلاَ ذَنَبٌ ‏.‏ فَقَالَ عُمَرُ مَا هُوَ قَالَ شَهَادَاتُ الزُّورِ ظَهَرَتْ بِأَرْضِنَا ‏.‏ فَقَالَ عُمَرُ أَوَقَدْ كَانَ ذَلِكَ قَالَ نَعَمْ ‏.‏ فَقَالَ عُمَرُ وَاللَّهِ لاَ يُؤْسَرُ رَجُلٌ فِي الإِسْلاَمِ بِغَيْرِ الْعُدُولِ ‏.‏\hadithno{1402}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me that Rabia ibn Abi Abd ar-Rahman said, "An Iraqi man came before Umar ibn al-Khattab and said, 'I have come to you because of a matter which has no beginning and no end.' Umar said, 'What is it?' The man said, 'False testimony has appeared in our land.' Umar said, 'Is that so?' He said, 'Yes.' Umar said, 'By Allah! A man is not detained in Islam without just witnesses}}
\hadithdefcmd{malik}{1403}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ لاَ تَجُوزُ شَهَادَةُ خَصْمٍ وَلاَ ظَنِينٍ ‏.‏\hadithno{1403}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me that Umar ibn al-Khattab said, "The testimony of some one known to bear a grudge or to be unreliable is not accepted}}
\hadithdefcmd{malik}{1404}{قَالَ يَحْيَى عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، وَغَيْرِهِ، أَنَّهُمْ سُئِلُوا عَنْ رَجُلٍ، جُلِدَ الْحَدَّ أَتَجُوزُ شَهَادَتُهُ فَقَالُوا نَعَمْ إِذَا ظَهَرَتْ مِنْهُ التَّوْبَةُ ‏.‏\hadithno{1404}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya said from Malik that he heard from Sulayman ibn Yasar and others that when they were asked whether the testimony of a man flogged for a hadd crime was permitted, they said, "Yes, when repentance (tawba) appears from him." Malik related to me that he heard Ibn Shihab being asked about that and he said the like of what Sulayman ibn Yasar said. Malik said, "That is what is done in our community. It is by the word of Allah, the Blessed, the Exalted, 'And those who accuse women who are muhsan, and then do not bring four witnesses, flog them with eighty lashes, and do not accept any testimony of theirs ever. They indeed are evil-doers, save those who turn in tawba after that and make amends. Allah is Forgiving, Merciful.' " (Sura 24 ayat)}}
\hadithdefcmd{malik}{1405}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ سَمِعَ ابْنَ شِهَابٍ، يُسْأَلُ عَنْ ذَلِكَ، فَقَالَ مِثْلَ مَا قَالَ سُلَيْمَانُ بْنُ يَسَارٍ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ الأَمْرُ عِنْدَنَا وَذَلِكَ لِقَوْلِ اللَّهِ تَبَارَكَ وَتَعَالَى ‏\{‏وَالَّذِينَ يَرْمُونَ الْمُحْصَنَاتِ ثُمَّ لَمْ يَأْتُوا بِأَرْبَعَةِ شُهَدَاءَ فَاجْلِدُوهُمْ ثَمَانِينَ جَلْدَةً وَلاَ تَقْبَلُوا لَهُمْ شَهَادَةً أَبَدًا وَأُولَئِكَ هُمُ الْفَاسِقُونَ * إِلاَّ الَّذِينَ تَابُوا مِنْ بَعْدِ ذَلِكَ وَأَصْلَحُوا فَإِنَّ اللَّهَ غَفُورٌ رَحِيمٌ‏\}‏‏.‏ قَالَ مَالِكٌ فَالأَمْرُ الَّذِي لاَ اخْتِلاَفَ فِيهِ عِنْدَنَا أَنَّ الَّذِي يُجْلَدُ الْحَدَّ ثُمَّ تَابَ وَأَصْلَحَ تَجُوزُ شَهَادَتُهُ وَهُوَ أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي ذَلِكَ ‏.‏\hadithno{1405}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Hadith Translation Not available}}
\hadithdefcmd{malik}{1406}{قَالَ يَحْيَى قَالَ مَالِكٌ عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى بِالْيَمِينِ مَعَ الشَّاهِدِ ‏.‏\hadithno{1406}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya said, "Malik said from Jafar ibn Muhammad from his father that the Messenger of Allah, may Allah bless him and grant him peace, pronounced judgement on the basis of an oath with one witness}}
\hadithdefcmd{malik}{1407}{وَعَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، كَتَبَ إِلَى عَبْدِ الْحَمِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ زَيْدِ بْنِ الْخَطَّابِ وَهُوَ عَامِلٌ عَلَى الْكُوفَةِ أَنِ اقْضِ بِالْيَمِينِ مَعَ الشَّاهِدِ ‏.‏\hadithno{1407}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{From Malik from Abu'z-Zinad that Umar ibn Abd al-Aziz wrote to Abd al-Hamid ibn Abd ar-Rahman ibn Zayd ibn al-Khattab who was the governor of Kufa, "Pronounce judgement on the basis of an oath with one witness}}
\hadithdefcmd{malik}{1408}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، وَسُلَيْمَانَ بْنَ يَسَارٍ، سُئِلاَ هَلْ يُقْضَى بِالْيَمِينِ مَعَ الشَّاهِدِ فَقَالاَ نَعَمْ ‏.‏ قَالَ مَالِكٌ مَضَتِ السُّنَّةُ فِي الْقَضَاءِ بِالْيَمِينِ مَعَ الشَّاهِدِ الْوَاحِدِ يَحْلِفُ صَاحِبُ الْحَقِّ مَعَ شَاهِدِهِ وَيَسْتَحِقُّ حَقَّهُ فَإِنْ نَكَلَ وَأَبَى أَنْ يَحْلِفَ أُحْلِفَ الْمَطْلُوبُ فَإِنْ حَلَفَ سَقَطَ عَنْهُ ذَلِكَ الْحَقُّ وَإِنْ أَبَى أَنْ يَحْلِفَ ثَبَتَ عَلَيْهِ الْحَقُّ لِصَاحِبِهِ ‏.‏ قَالَ مَالِكٌ وَإِنَّمَا يَكُونُ ذَلِكَ فِي الأَمْوَالِ خَاصَّةً وَلاَ يَقَعُ ذَلِكَ فِي شَىْءٍ مِنَ الْحُدُودِ وَلاَ فِي نِكَاحٍ وَلاَ فِي طَلاَقٍ وَلاَ فِي عَتَاقَةٍ وَلاَ فِي سَرِقَةٍ وَلاَ فِي فِرْيَةٍ فَإِنْ قَالَ قَائِلٌ فَإِنَّ الْعَتَاقَةَ مِنَ الأَمْوَالِ ‏.‏ فَقَدْ أَخْطَأَ لَيْسَ ذَلِكَ عَلَى مَا قَالَ وَلَوْ كَانَ ذَلِكَ عَلَى مَا قَالَ لَحَلَفَ الْعَبْدُ مَعَ شَاهِدِهِ إِذَا جَاءَ بِشَاهِدٍ أَنَّ سَيِّدَهُ أَعْتَقَهُ وَأَنَّ الْعَبْدَ إِذَا جَاءَ بِشَاهِدٍ عَلَى مَالٍ مِنَ الأَمْوَالِ ادَّعَاهُ حَلَفَ مَعَ شَاهِدِهِ وَاسْتَحَقَّ حَقَّهُ كَمَا يَحْلِفُ الْحُرُّ ‏.‏ قَالَ مَالِكٌ فَالسُّنَّةُ عِنْدَنَا أَنَّ الْعَبْدَ إِذَا جَاءَ بِشَاهِدٍ عَلَى عَتَاقَتِهِ اسْتُحْلِفَ سَيِّدُهُ مَا أَعْتَقَهُ وَبَطَلَ ذَلِكَ عَنْهُ ‏.‏ قَالَ مَالِكٌ وَكَذَلِكَ السُّنَّةُ عِنْدَنَا أَيْضًا فِي الطَّلاَقِ إِذَا جَاءَتِ الْمَرْأَةُ بِشَاهِدٍ أَنَّ زَوْجَهَا طَلَّقَهَا أُحْلِفَ زَوْجُهَا مَا طَلَّقَهَا فَإِذَا حَلَفَ لَمْ يَقَعْ عَلَيْهِ الطَّلاَقُ ‏.‏ قَالَ مَالِكٌ فَسُنَّةُ الطَّلاَقِ وَالْعَتَاقَةِ فِي الشَّاهِدِ الْوَاحِدِ وَاحِدَةٌ إِنَّمَا يَكُونُ الْيَمِينُ عَلَى زَوْجِ الْمَرْأَةِ وَعَلَى سَيِّدِ الْعَبْدِ وَإِنَّمَا الْعَتَاقَةُ حَدٌّ مِنَ الْحُدُودِ لاَ تَجُوزُ فِيهَا شَهَادَةُ النِّسَاءِ لأَنَّهُ إِذَا عَتَقَ الْعَبْدُ ثَبَتَتْ حُرْمَتُهُ وَوَقَعَتْ لَهُ الْحُدُودُ وَوَقَعَتْ عَلَيْهِ وَإِنْ زَنَى وَقَدْ أُحْصِنَ رُجِمَ وَإِنْ قَتَلَ الْعَبْدَ قُتِلَ بِهِ وَثَبَتَ لَهُ الْمِيرَاثُ بَيْنَهُ وَبَيْنَ مَنْ يُوَارِثُهُ فَإِنِ احْتَجَّ مُحْتَجٌّ فَقَالَ لَوْ أَنَّ رَجُلاً أَعْتَقَ عَبْدَهُ وَجَاءَ رَجُلٌ يَطْلُبُ سَيِّدَ الْعَبْدِ بِدَيْنٍ لَهُ عَلَيْهِ فَشَهِدَ لَهُ عَلَى حَقِّهِ ذَلِكَ رَجُلٌ وَامْرَأَتَانِ فَإِنَّ ذَلِكَ يُثْبِتُ الْحَقَّ عَلَى سَيِّدِ الْعَبْدِ حَتَّى تُرَدَّ بِهِ عَتَاقَتُهُ إِذَا لَمْ يَكُنْ لِسَيِّدِ الْعَبْدِ مَالٌ غَيْرُ الْعَبْدِ يُرِيدُ أَنْ يُجِيزَ بِذَلِكَ شَهَادَةَ النِّسَاءِ فِي الْعَتَاقَةِ فَإِنَّ ذَلِكَ لَيْسَ عَلَى مَا قَالَ وَإِنَّمَا مَثَلُ ذَلِكَ الرَّجُلُ يَعْتِقُ عَبْدَهُ ثُمَّ يَأْتِي طَالِبُ الْحَقِّ عَلَى سَيِّدِهِ بِشَاهِدٍ وَاحِدٍ فَيَحْلِفُ مَعَ شَاهِدِهِ ثُمَّ يَسْتَحِقُّ حَقَّهُ وَتُرَدُّ بِذَلِكَ عَتَاقَةُ الْعَبْدِ أَوْ يَأْتِي الرَّجُلُ قَدْ كَانَتْ بَيْنَهُ وَبَيْنَ سَيِّدِ الْعَبْدِ مُخَالَطَةٌ وَمُلاَبَسَةٌ فَيَزْعُمُ أَنَّ لَهُ عَلَى سَيِّدِ الْعَبْدِ مَالاً فَيُقَالُ لِسَيِّدِ الْعَبْدِ احْلِفْ مَا عَلَيْكَ مَا ادَّعَى فَإِنْ نَكَلَ وَأَبَى أَنْ يَحْلِفَ حُلِّفَ صَاحِبُ الْحَقِّ وَثَبَتَ حَقُّهُ عَلَى سَيِّدِ الْعَبْدِ فَيَكُونُ ذَلِكَ يَرُدُّ عَتَاقَةَ الْعَبْدِ إِذَا ثَبَتَ الْمَالُ عَلَى سَيِّدِهِ ‏.‏ قَالَ وَكَذَلِكَ أَيْضًا الرَّجُلُ يَنْكِحُ الأَمَةَ فَتَكُونُ امْرَأَتَهُ فَيَأْتِي سَيِّدُ الأَمَةِ إِلَى الرَّجُلِ الَّذِي تَزَوَّجَهَا فَيَقُولُ ابْتَعْتَ مِنِّي جَارِيَتِي فُلاَنَةَ أَنْتَ وَفُلاَنٌ بِكَذَا وَكَذَا دِينَارًا ‏.‏ فَيُنْكِرُ ذَلِكَ زَوْجُ الأَمَةِ فَيَأْتِي سَيِّدُ الأَمَةِ بِرَجُلٍ وَامْرَأَتَيْنِ فَيَشْهَدُونَ عَلَى مَا قَالَ فَيَثْبُتُ بَيْعُهُ وَيَحِقُّ حَقُّهُ وَتَحْرُمُ الأَمَةُ عَلَى زَوْجِهَا وَيَكُونُ ذَلِكَ فِرَاقًا بَيْنَهُمَا وَشَهَادَةُ النِّسَاءِ لاَ تَجُوزُ فِي الطَّلاَقِ ‏.‏ قَالَ مَالِكٌ وَمِنْ ذَلِكَ أَيْضًا الرَّجُلُ يَفْتَرِي عَلَى الرَّجُلِ الْحُرِّ فَيَقَعُ عَلَيْهِ الْحَدُّ فَيَأْتِي رَجُلٌ وَامْرَأَتَانِ فَيَشْهَدُونَ أَنَّ الَّذِي افْتُرِيَ عَلَيْهِ عَبْدٌ مَمْلُوكٌ فَيَضَعُ ذَلِكَ الْحَدَّ عَنِ الْمُفْتَرِي بَعْدَ أَنْ وَقَعَ عَلَيْهِ وَشَهَادَةُ النِّسَاءِ لاَ تَجُوزُ فِي الْفِرْيَةِ ‏.‏ قَالَ مَالِكٌ وَمِمَّا يُشْبِهُ ذَلِكَ أَيْضًا مِمَّا يَفْتَرِقُ فِيهِ الْقَضَاءُ وَمَا مَضَى مِنَ السُّنَّةِ أَنَّ الْمَرْأَتَيْنِ يَشْهَدَانِ عَلَى اسْتِهْلاَلِ الصَّبِيِّ فَيَجِبُ بِذَلِكَ مِيرَاثُهُ حَتَّى يَرِثَ وَيَكُونُ مَالُهُ لِمَنْ يَرِثُهُ إِنْ مَاتَ الصَّبِيُّ وَلَيْسَ مَعَ الْمَرْأَتَيْنِ اللَّتَيْنِ شَهِدَتَا رَجُلٌ وَلاَ يَمِينٌ وَقَدْ يَكُونُ ذَلِكَ فِي الأَمْوَالِ الْعِظَامِ مِنَ الذَّهَبِ وَالْوَرِقِ وَالرِّبَاعِ وَالْحَوَائِطِ وَالرَّقِيقِ وَمَا سِوَى ذَلِكَ مِنَ الأَمْوَالِ وَلَوْ شَهِدَتِ امْرَأَتَانِ عَلَى دِرْهَمٍ وَاحِدٍ أَوْ أَقَلَّ مِنْ ذَلِكَ أَوْ أَكْثَرَ لَمْ تَقْطَعْ شَهَادَتُهُمَا شَيْئًا وَلَمْ تَجُزْ إِلاَّ أَنْ يَكُونَ مَعَهُمَا شَاهِدٌ أَوْ يَمِينٌ ‏.‏ قَالَ مَالِكٌ وَمِنَ النَّاسِ مَنْ يَقُولُ لاَ تَكُونُ الْيَمِينُ مَعَ الشَّاهِدِ الْوَاحِدِ ‏.‏ وَيَحْتَجُّ بِقَوْلِ اللَّهِ تَبَارَكَ وَتَعَالَى وَقَوْلُهُ الْحَقُّ ‏\{‏وَاسْتَشْهِدُوا شَهِيدَيْنِ مِنْ رِجَالِكُمْ فَإِنْ لَمْ يَكُونَا رَجُلَيْنِ فَرَجُلٌ وَامْرَأَتَانِ مِمَّنْ تَرْضَوْنَ مِنَ الشُّهَدَاءِ‏\}‏ يَقُولُ فَإِنْ لَمْ يَأْتِ بِرَجُلٍ وَامْرَأَتَيْنِ فَلاَ شَىْءَ لَهُ وَلاَ يُحَلَّفُ مَعَ شَاهِدِهِ ‏.‏ قَالَ مَالِكٌ فَمِنَ الْحُجَّةِ عَلَى مَنْ قَالَ ذَلِكَ الْقَوْلَ أَنْ يُقَالَ لَهُ أَرَأَيْتَ لَوْ أَنَّ رَجُلاً ادَّعَى عَلَى رَجُلٍ مَالاً أَلَيْسَ يَحْلِفُ الْمَطْلُوبُ مَا ذَلِكَ الْحَقُّ عَلَيْهِ فَإِنْ حَلَفَ بَطَلَ ذَلِكَ عَنْهُ وَإِنْ نَكَلَ عَنِ الْيَمِينِ حُلِّفَ صَاحِبُ الْحَقِّ إِنَّ حَقَّهُ لَحَقٌّ ‏.‏ وَثَبَتَ حَقُّهُ عَلَى صَاحِبِهِ فَهَذَا مَا لاَ اخْتِلاَفَ فِيهِ عِنْدَ أَحَدٍ مِنَ النَّاسِ وَلاَ بِبَلَدٍ مِنَ الْبُلْدَانِ فَبِأَىِّ شَىْءٍ أَخَذَ هَذَا أَوْ فِي أَىِّ مَوْضِعٍ مِنْ كِتَابِ اللَّهِ وَجَدَهُ فَإِنْ أَقَرَّ بِهَذَا فَلْيُقْرِرْ بِالْيَمِينِ مَعَ الشَّاهِدِ وَإِنْ لَمْ يَكُنْ ذَلِكَ فِي كِتَابِ اللَّهِ عَزَّ وَجَلَّ وَأَنَّهُ لَيَكْفِي مِنْ ذَلِكَ مَا مَضَى مِنَ السُّنَّةِ وَلَكِنِ الْمَرْءُ قَدْ يُحِبُّ أَنْ يَعْرِفَ وَجْهَ الصَّوَابِ وَمَوْقِعَ الْحُجَّةِ فَفِي هَذَا بَيَانُ مَا أَشْكَلَ مِنْ ذَلِكَ إِنْ شَاءَ اللَّهُ تَعَالَى ‏.‏\hadithno{1408}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Malik related to me that he heard that Abu Salama ibn Abd ar- Rahman and Sulayman ibn Yasar were both asked, "Does one pronounce judgement on the basis of an oath with one witness?" They both said, "Yes." Malik said, "The precedent of the sunna in judging by an oath with one witness is that if the plaintiff takes an oath with his witness, he is confirmed in his right. If he draws back and refuses to take an oath, the defendant is made to take an oath. If he takes an oath, the claim against him is dropped. If he refuses to take an oath, the claim is confirmed against him." Malik said, "This procedure pertains to property cases in particular. It does not occur in any of the hadd-punishments, nor in marriage, divorce, freeing slaves, theft or slander. If some one says, 'Freeing slaves comes under property,' he has erred. It is not as he said. Had it been as he said, a slave could take an oath with one witness, if he could find one, that his master had freed him. "However, when a slave lays claim to a piece of property, he can take an oath with one witness and demand his right as the freeman demands his right." Malik said, "The sunna with us is that when a slave brings somebody who witnesses that he has been set free, his master is made to take an oath that he has not freed him, and the slave's claim is dropped." Malik said, "The sunna about divorce is also like that with us. When a woman brings somebody who witnesses that her husband has divorced her, the husband is made to take an oath that he has not divorced her. If he takes the oath, the divorce does not proceed . " Malik said, "There is only one sunna of bringing a witness in cases of divorce and freeing a slave. The right to make an oath only belongs to the husband of the woman, and the master of the slave. Freeing is a hadd matter, and the testimony of women is not permitted in it because when a slave is freed, his inviolability is affirmed and the hadd punishments are applied for and against him. If he commits fornication and he is a muhsan, he is stoned. If he kills a slave, he is killed for it. Inheritance is established for him, between him and whoever inherits from him. If somebody disputes this, arguing that if a man frees his slave and then a man comes to demand from the master of the slave payment of a debt, and a man and two women testify to his right, that establishes the right against the master of the slave so that his freeing him is cancelled if he only has the slave as property, inferring by this case that the testimony of women is permitted in cases of setting free. The case is not as he suggests (i.e. it is a case of property not freeing). It is like a man who frees his slave, and then the claimant of a debt comes to the master and takes an oath with one witness, demanding his right. By that, the freeing of the slave would be cancelled. Or else a man comes who has frequent dealings and transactions with the master of the slave. He claims that he is owed money by the master of the slave. Someone says to the master of the slave, 'Take an oath that you don't owe what he claims'. If he draws back and refuses to take an oath, the one making the claim takes an oath and his right against the master of the slave is confirmed. That would cancel the freeing of the slave if it is confirmed that property is owed by the master." Malik said, "It is the same case with a man who marries a slave-girl and then the master of the slave-girl comes to the man who has married her and claims, 'You and so-and-so have bought my slave-girl from me for such an amount of dinars. The husband of the slave-girl denies that. The master of the slave-girl brings a man and two women and they testify to what he has said. The sale is confirmed and his claim is considered true. So the slave-girl is haram for her husband and they have to separate, even though the testimony of women is not accepted in divorce." Malik said, "It is also the same case with a man who accuses a free man, so the hadd falls on him. A man and two women come and testify that the one accused is a slave. That would remove the hadd from the accused after it had befallen him, even though the testimony of women is not accepted in accusations involving hadd punishments." Malik said, "Another similar case in which judgement appears to go against the precedent of the sunna is that two women testify that a child is born alive and so it is necessary for him to inherit if a situation arises where he is entitled to inherit, and the child's property goes to those who inherit from him, if he dies, and it is not necessary that the two women witnesses should be accompanied by a man or an oath even though it may involve vast properties of gold, silver, live-stock, gardens and slaves and other properties. However, had two women testified to one dirham or more or less than that in a property case, their testimony would not affect anything and would not be permitted unless there was a witness or an oath with them." Malik said, "There are people who say that an oath is not acceptable with only one witness and they argue by the word of Allah the Blessed, the Exalted, and His word is the Truth, 'And call in to witness two witnesses, men; or if the two be not men, then one man and two women, such witnesses as you approve of.' (Sura 2 ayat 282). Such people argue that if he does not bring one man and two women, he has no claim and he is not allowed to take an oath with one witness." Malik said, "Part of the proof against those who argue this, is to reply to them, 'Do you think that if a man claimed property from a man, the one claimed from would not swear that the claim was false?' If he swears, the claim against him is dropped. If he refuses to take an oath, the claimant is made to take an oath that his claim is true, and his right against his companion is established. There is no dispute about this with any of the people nor in any country. By what does he take this? In what place in the Book of Allah does he find it? So if he confirms this, let him confirm the oath with one witness, even if it is not in the Book of Allah, the Mighty, the Majestic! It is enough that this is the precedent of the sunna. However, man wants to recognise the proper course of action and the location of the proof. In this there is a clarification for what is obscure about that, if Allah ta'ala wills}}
\hadithdefcmd{malik}{1409}{قَالَ يَحْيَى قَالَ مَالِكٌ عَنْ جَمِيلِ بْنِ عَبْدِ الرَّحْمَنِ الْمُؤَذِّنِ، أَنَّهُ كَانَ يَحْضُرُ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ وَهُوَ يَقْضِي بَيْنَ النَّاسِ فَإِذَا جَاءَهُ الرَّجُلُ يَدَّعِي عَلَى الرَّجُلِ حَقًّا نَظَرَ فَإِنْ كَانَتْ بَيْنَهُمَا مُخَالَطَةٌ أَوْ مُلاَبَسَةٌ أَحْلَفَ الَّذِي ادُّعِيَ عَلَيْهِ وَإِنْ لَمْ يَكُنْ شَىْءٌ مِنْ ذَلِكَ لَمْ يُحَلِّفْهُ ‏.‏ قَالَ مَالِكٌ وَعَلَى ذَلِكَ الأَمْرُ عِنْدَنَا أَنَّهُ مَنِ ادَّعَى عَلَى رَجُلٍ بِدَعْوَى نُظِرَ فَإِنْ كَانَتْ بَيْنَهُمَا مُخَالَطَةٌ أَوْ مُلاَبَسَةٌ أُحْلِفَ الْمُدَّعَى عَلَيْهِ فَإِنْ حَلَفَ بَطَلَ ذَلِكَ الْحَقُّ عَنْهُ وَإِنْ أَبَى أَنْ يَحْلِفَ وَرَدَّ الْيَمِينَ عَلَى الْمُدَّعِي فَحَلَفَ طَالِبُ الْحَقِّ أَخَذَ حَقَّهُ ‏.‏\hadithno{1409}\hadithgrade{Salim al-Hilali: Maqtu Hasan}\hadithtrans{Yahya said that Malik spoke about a man who died and had a debt owing to him and there was one witness, and some people had a debt against him and they had only one witness, and his heirs refused to take an oath on their rights with their witness. He said, "The creditors take an oath and take their rights. If there is anything left over, the heirs do not take any of it. That is because the oaths were offered to them before and they abandoned them, unless they say, 'We did not know that our companion had extra,' and it is known that they only abandoned the oaths because of that. I think that they should take an oath and take what remains after his debt." Yahya said, "Malik said about Jamil ibn Abd ar-Rahman al-Muadhdin that he was present with Umar ibn Abd al-Aziz when he was judging between people. If a man came to him with a claim against a man, he examined whether or not there were frequent transactions and dealings between them. If there were, the defendant could make an oath. If there was nothing of that nature he did not accept an oath from him." Malik summed up, "What is done in our community is that if some one makes a claim against a man, it is examined. If there are frequent transactions and dealings between them, the defendant is made to take an oath. If he takes an oath, the claim against him is dropped. If the defendant refuses to take an oath, and returns the oath to the claimant, the one claiming his right takes an oath and takes his due}}
\hadithdefcmd{malik}{1410}{قَالَ يَحْيَى قَالَ مَالِكٌ عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، كَانَ يَقْضِي بِشَهَادَةِ الصِّبْيَانِ فِيمَا بَيْنَهُمْ مِنَ الْجِرَاحِ ‏.‏ قَالَ مَالِكٌ الأَمْرُ الْمُجْتَمَعُ عَلَيْهِ عِنْدَنَا أَنَّ شَهَادَةَ الصِّبْيَانِ تَجُوزُ فِيمَا بَيْنَهُمْ مِنَ الْجِرَاحِ وَلاَ تَجُوزُ عَلَى غَيْرِهِمْ وَإِنَّمَا تَجُوزُ شَهَادَتُهُمْ فِيمَا بَيْنَهُمْ مِنَ الْجِرَاحِ وَحْدَهَا لاَ تَجُوزُ فِي غَيْرِ ذَلِكَ إِذَا كَانَ ذَلِكَ قَبْلَ أَنْ يَتَفَرَّقُوا أَوْ يُخَبَّبُوا أَوْ يُعَلَّمُوا فَإِنِ افْتَرَقُوا فَلاَ شَهَادَةَ لَهُمْ إِلاَّ أَنْ يَكُونُوا قَدْ أَشْهَدُوا الْعُدُولَ عَلَى شَهَادَتِهِمْ قَبْلَ أَنْ يَفْتَرِقُوا ‏.‏\hadithno{1410}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya said, "Malik said from Hisham ibn Urwa that Abdullah ibn az-Zubayr gave judgment based on the testimony of children concerning the injuries between them." Malik said, "The generally agreed on way of doing things in our community is that the testimony of children is permitted concerning injuries between them. It is not accepted about anything else. It is only permitted between them if they testify before they leave the scene of the incident and have been deceived or instructed. If they leave the scene, they have no testimony unless they call just witnesses to witness their testimony before they leave}}
\hadithdefcmd{malik}{1411}{قَالَ يَحْيَى حَدَّثَنَا مَالِكٌ، عَنْ هَاشِمِ بْنِ هَاشِمِ بْنِ عُتْبَةَ بْنِ أَبِي وَقَّاصٍ، عَنْ عَبْدِ اللَّهِ بْنِ نِسْطَاسٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ الأَنْصَارِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَلَفَ عَلَى مِنْبَرِي آثِمًا تَبَوَّأَ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{1411}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya said, Malik related to us from Hisham ibn Hisham ibn Utba ibn Abi Waqqas from Abdullah ibn Nistas from Jabir ibn Abdullah al- Ansari that the Messenger of Allah, may Allah bless him and grant him peace, said, 'If someone swears a false oath near this mimbar of mine, he will take his seat in the fire}}
\hadithdefcmd{malik}{1412}{وَحَدَّثَنِي مَالِكٌ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ مَعْبَدِ بْنِ كَعْبٍ السَّلَمِيِّ، عَنْ أَخِيهِ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ الأَنْصَارِيِّ، عَنْ أَبِي أُمَامَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ اقْتَطَعَ حَقَّ امْرِئٍ مُسْلِمٍ بِيَمِينِهِ حَرَّمَ اللَّهُ عَلَيْهِ الْجَنَّةَ وَأَوْجَبَ لَهُ النَّارَ ‏"‏ ‏.‏ قَالُوا وَإِنْ كَانَ شَيْئًا يَسِيرًا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَإِنْ كَانَ قَضِيبًا مِنْ أَرَاكٍ وَإِنْ كَانَ قَضِيبًا مِنْ أَرَاكٍ وَإِنْ كَانَ قَضِيبًا مِنْ أَرَاكٍ ‏"‏ ‏.‏ قَالَهَا ثَلاَثَ مَرَّاتٍ ‏.‏\hadithno{1412}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from al-Ala ibn Abd ar-Rahman from Mabad ibn Kab as-Salami from his brother Abdullah ibn Kab ibn Malik al-Ansari from Abu Umama that the Messenger of Allah, may Allah bless him and grant him peace, said, "Whoever cuts off the right of a muslim man by his oath, Allah forbids him the Garden and obliges the Fire for him." They said, "Even if it is something insignificant, Messenger of Allah?" He said, "Even if it is a tooth-stick, even if it is a tooth- stick," repeating it three times}}
\hadithdefcmd{malik}{1413}{قَالَ يَحْيَى قَالَ مَالِكٌ عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، أَنَّهُ سَمِعَ أَبَا غَطَفَانَ بْنَ طَرِيفٍ الْمُرِّيَّ، يَقُولُ اخْتَصَمَ زَيْدُ بْنُ ثَابِتٍ الأَنْصَارِيُّ وَابْنُ مُطِيعٍ فِي دَارٍ كَانَتْ بَيْنَهُمَا إِلَى مَرْوَانَ بْنِ الْحَكَمِ وَهُوَ أَمِيرٌ عَلَى الْمَدِينَةِ فَقَضَى مَرْوَانُ عَلَى زَيْدِ بْنِ ثَابِتٍ بِالْيَمِينِ عَلَى الْمِنْبَرِ ‏.‏ فَقَالَ زَيْدُ بْنُ ثَابِتٍ أَحْلِفُ لَهُ مَكَانِي ‏.‏ قَالَ فَقَالَ مَرْوَانُ لاَ وَاللَّهِ إِلاَّ عِنْدَ مَقَاطِعِ الْحُقُوقِ ‏.‏ قَالَ فَجَعَلَ زَيْدُ بْنُ ثَابِتٍ يَحْلِفُ أَنَّ حَقَّهُ لَحَقٌّ ‏.‏ وَيَأْبَى أَنْ يَحْلِفَ عَلَى الْمِنْبَرِ - قَالَ - فَجَعَلَ مَرْوَانُ بْنُ الْحَكَمِ يَعْجَبُ مِنْ ذَلِكَ ‏.‏ قَالَ مَالِكٌ لاَ أَرَى أَنْ يُحَلَّفَ أَحَدٌ عَلَى الْمِنْبَرِ عَلَى أَقَلَّ مِنْ رُبُعِ دِينَارٍ وَذَلِكَ ثَلاَثَةُ دَرَاهِمَ ‏.‏\hadithno{1413}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya said that Malik had said from Da'ud ibn al-Husayn that he heard Abu Ghatafan ibn Tarif al-Muriyi say, "Zayd ibn Thabit al-Ansari and Ibn Muti had a dispute about a house which they shared. They went to Marwan ibn al-Hakam who was the Amir of Madina. Marwan decided that Zayd ibn Thabit must take an oath on the mimbar. Zayd ibn Thabit said, 'I swear to it where I am.' Marwan said, 'No, by Allah! only in the place of sorting out claims (i.e. the mimbar).' Zayd ibn Thabit began to take an oath that his right was true, and he refused to take an oath near the mimbar. Marwan ibn al-Hakam began to wonder at that." Malik said, "I do not think that anyone should be made to take an oath near the mimbar for less than a fourth of a dinar, and that is three dirhams}}
\hadithdefcmd{malik}{1414}{قَالَ يَحْيَى حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَغْلَقُ الرَّهْنُ ‏"‏ ‏.‏\hadithno{1414}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya said, "Malik related to us from Ibn Shihab from Sa'id ibn al-Musayyab that the Messenger of Allah, may Allah bless him and grant him peace, said, 'The pledge given as security is not forfeited.' " Malik said, "The explanation of that according to what we think - and Allah knows best - is that a man gives a pledge to somebody in security for something. The pledge is superior to that for which he pawned it. The pledger says to the pawn-broker, 'I will bring you your due, after such-and-such a time. If not, the pledge is yours for what it was pawned for.' " Malik said, "This transaction is not good and it is not halal. This is what was forbidden. If the owner brings what he pledged it for after the period, it is his. I think that the time condition is void}}
\hadithdefcmd{malik}{1415}{حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، أَنَّ عَبْدَ الْمَلِكِ بْنَ مَرْوَانَ، قَضَى فِي امْرَأَةٍ أُصِيبَتْ مُسْتَكْرَهَةً بِصَدَاقِهَا عَلَى مَنْ فَعَلَ ذَلِكَ بِهَا ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ الأَمْرُ عِنْدَنَا فِي الرَّجُلِ يَغْتَصِبُ الْمَرْأَةَ بِكْرًا كَانَتْ أَوْ ثَيِّبًا إِنَّهَا إِنْ كَانَتْ حُرَّةً فَعَلَيْهِ صَدَاقُ مِثْلِهَا وَإِنْ كَانَتْ أَمَةً فَعَلَيْهِ مَا نَقَصَ مِنْ ثَمَنِهَا وَالْعُقُوبَةُ فِي ذَلِكَ عَلَى الْمُغْتَصِبِ وَلاَ عُقُوبَةَ عَلَى الْمُغْتَصَبَةِ فِي ذَلِكَ كُلِّهِ وَإِنْ كَانَ الْمُغْتَصِبُ عَبْدًا فَذَلِكَ عَلَى سَيِّدِهِ إِلاَّ أَنْ يَشَاءَ أَنْ يُسَلِّمَهُ ‏.‏\hadithno{1415}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya said, "I heard Malik say that if a man pledges his garden for a stated period and the fruits of that garden are ready before the end of that period, the fruits are not included in the pledge with the real estate, unless it is stipulated by the pledger in his pledge. However, if a man receives a slave-girl as a pledge and she is pregnant or she becomes pregnant after his taking her as a pledge, her child is included with her. "A distinction is made between the fruit and the child of the slave-girl. The Messenger of Allah, may Allah bless him and grant him peace, said, 'If someone sells a palm which has been pollinated, the fruit belongs to the seller unless the buyer stipulates its inclusion.' The undisputed way of doing things in our community is that if a man sells a slave-girl or an animal with a foetus in its womb, the foetus belongs to the buyer, whether or not the buyer stipulates it. The palm is not like the animal. Fruit is not like the foetus in its mother's womb. Part of what clarifies that is also that it is the usage of people to have a man pawn the fruit of the palm apart from the palm. No one pawns the foetus in its mother's womb whether of slaves or animals." Yahya said that he had heard Malik say, "The undisputed way of doing things in our community concerning pledges is that in cases where land or a house or an animal are known to have been destroyed whilst in the possession of the broker of the pledge, and the circumstances of the loss are known, the loss is against the pledger. There is no deduction made from what is due to the broker at all. Any pledge which perishes in the possession of the broker and the circumstances of its loss are only known by his word, the loss is against the broker and he is liable for its value. He is asked to describe whatever was destroyed and then he is made to take an oath about that description and what he loaned on security for it. "Then people of discernment evaluate the description. If the pledge was worth more than what the broker loaned, the pledger takes the extra. If the assessed value of the pledge is less than what he was loaned, the pledger is made to take an oath as to what the broker loaned and he does not have to pay the extra which the broker loaned above the assessed value of the pledge. If the pledger refuses to take an oath, he has to give the broker the extra above the assessed value of the pledge. If the broker says that he doesn't know the value of the pledge, the pledger is made to take an oath on the description of the pledge and that is his if he brings a matter which is not disapproved of." Malik said, "All this applies when the broker takes the pledge and does not put it in the hands of another." Yahya said that he heard Malik speak about two men who had a pledge between them. One of them undertook to sell his pledge, and the other one had asked him to wait a year for his due. He said, "If it is possible to divide the pledge, and the due of the one who asked him to wait will not be decreased, half the pledge which is between them is sold for him and he is given his due. If it is feared that his right will be decreased, all the pledge is sold, and the one who undertook to sell his pledge is given his due from that. If the one who asked him to wait for his due is pleased in himself, half of the price is paid to the pledger. If not, the pledgee is made to take an oath that he only asked him to wait so that he could transfer my pledge to me in its form.' Then he is given his due immediately." Yahya said that he heard Malik say about a slave whose master had pledged him and the slave had property of his own, "The property of the slave is not part of the pledge unless the broker stipulates that." Yahya said that he heard Malik speak about someone who pledged goods as security for a loan, and they perished with the broker. The one who took out the loan confirmed its specification. They agreed on the amount of the loan, but challenged each other about the value of the pledge, the pledger saying that it had been worth twenty dinars, whilst the broker said that it had been worth only ten, and that the amount loaned on security was twenty dinars. Malik said, "It is said to the one in whose hand the pledge is, 'describe it.' If he describes it he is made to take an oath on it and then the people of experience evaluate that description. If the value is more than what was loaned on security for it, it is said to the broker, 'Return the rest of his due to the pledger.' If the value is less than what was loaned on security for it, the broker takes the rest of his due from the pledger. If the value is the exact amount of the loan, the pledge is compensated for by the loan." Yahya said that he heard Malik say, "What is done in our community about two men who have a dispute about an amount of money loaned on the security of a pledge - the pledger claiming that he pledged it for ten dinars and the broker insisting that he took the pledge as security for twenty dinars, and the pledge is clearly in the possession of the broker - is that the broker is made to take an oath when the value of the pledge is fully known. If the value of the pledge is exactly what he swore that he had loaned on security for it, the broker takes the pledge as his right. He is more entitled to take precedence with an oath since he has possession of the pledge. If the owner of the pledge wants to give him the amount which he swore that he was owed, he can take the pledge back. If the pledge is worth less than the twenty dinars he loaned, then it is said to the pledger, 'Either you give him what he has sworn to and take your pledge back, or you swear to what you said you pledged it for.' If the pledger takes the oath, then what the broker has increased over the value of the pledge will become invalid. If the pledger does not take an oath, he must pay what the broker swore to." Malik said, "If a pledge given on security for a loan perishes, and both parties deny each other's rights, with the broker who is owed the loan saying that he gave twenty dinars, and the pledger who owes the loan saying that he was given only ten, and with the broker who is owed the loan saying the pledge was worth ten dinars, and the broker who owes the loan saying it was worth twenty, then the broker who is owed the loan is asked to describe the pledge. If he describes it, he must take an oath on its description. Then people with experience of it evaluate that description. If the value of the pledge is estimated to be more than what the broker claims it was, he takes an oath as to what he claimed, and the pledger is given what is over from the value of the pledge. If its value is less than what the broker claims of it, he is made to take an oath as to what he claims is his. Then he demands settlement according to the actual value of the pledge. The one who owes the loan is then made to take an oath on the extra amount which remains owing against him to the claimant after the price of the pledge is reached. That is because the broker becomes a claimant against the pledger. If he takes an oath, the rest of what the broker swore to of what he claimed above the value of the pledge is invalidated. If he draws back, he is bound to pay what remains due to the broker after the value of the pledge." Yahya said that he heard Malik say, "What is done in our community about a man who rents an animal for a journey to a specified place and then he goes beyond that place and further, is that the owner of the animal has a choice. If he wants to take extra rent for his animal to cover the distance overstepped, he is given that on top of the first rent and the animal is returned. If the owner of the animal likes to sell the animal from the place where he over-steps, he has the price of the animal on top of the rent. If, however, the hirer rented the animal to go and return and then he overstepped when he reached the city to which he rented him, the owner of the animal only has half the first rent. That is because half of the rent is going, and half of it is returning. If he oversteps with the animal, only half of the first rent is obliged for him. Had the animal died when he reached the city to which it was rented, the hirer would not be liable and the renter would only have half the rent." Malik said, "That is what is done with people who overstep and dispute about what they took the animal for." Malik said, "It is also like that with some one who takes qirad-money from his companion. The owner of the property says to him, 'Do not buy such-and-such animals or such- and-such goods.' He names them and forbids them and disapproves of his money being invested in them. The one who takes the money then buys what he was forbidden. By that, he intends to be liable for the money and take the profit of his companion. When he does that, the owner of the money has an option. If he wants to enter with him in the goods according to the original stipulations between them about the profit, he does so. If he likes, he has his capital guaranteed against the one who took the capital and over stepped the mark." Malik said, "It is also like that with a man with whom another man invests some goods. The owner of the property orders him to buy certain goods for him which he names. He differs, and buys with the goods something other than what he was ordered to buy. He exceeded his orders. The owner of the goods has an option. If he wants to take what was bought with his property, he takes it. If he wants the partner to be liable for his capital he has that." Malik related to me from Ibn Shihab that Abd al-Malik ibn Marwan gave a judgment that the rapist had to pay the raped woman her bride- price. Yahya said that he heard Malik say, "What is done in our community about the man who rapes a woman, virgin or non-virgin, if she is free, is that he must pay the bride-price of the like of her. If she is a slave, he must pay what he has diminished of her worth. The hadd-punishment in such cases is applied to the rapist, and there is no punishment applied to the raped woman. If the rapist is a slave, that is against his master unless he wishes to surrender him}}
\hadithdefcmd{malik}{1416}{حَدَّثَنَا يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ غَيَّرَ دِينَهُ فَاضْرِبُوا عُنُقَهُ ‏"‏ ‏.‏ وَمَعْنَى قَوْلِ النَّبِيِّ صلى الله عليه وسلم فِيمَا نُرَى - وَاللَّهُ أَعْلَمُ - ‏"‏ مَنْ غَيَّرَ دِينَهُ فَاضْرِبُوا عُنُقَهُ ‏"‏ ‏.‏ أَنَّهُ مَنْ خَرَجَ مِنَ الإِسْلاَمِ إِلَى غَيْرِهِ مِثْلُ الزَّنَادِقَةِ وَأَشْبَاهِهِمْ فَإِنَّ أُولَئِكَ إِذَا ظُهِرَ عَلَيْهِمْ قُتِلُوا وَلَمْ يُسْتَتَابُوا لأَنَّهُ لاَ تُعْرَفُ تَوْبَتُهُمْ وَأَنَّهُمْ كَانُوا يُسِرُّونَ الْكُفْرَ وَيُعْلِنُونَ الإِسْلاَمَ فَلاَ أَرَى أَنْ يُسْتَتَابَ هَؤُلاَءِ وَلاَ يُقْبَلُ مِنْهُمْ قَوْلُهُمْ وَأَمَّا مَنْ خَرَجَ مِنَ الإِسْلاَمِ إِلَى غَيْرِهِ وَأَظْهَرَ ذَلِكَ فَإِنَّهُ يُسْتَتَابُ فَإِنْ تَابَ وَإِلاَّ قُتِلَ وَذَلِكَ لَوْ أَنَّ قَوْمًا كَانُوا عَلَى ذَلِكَ رَأَيْتُ أَنْ يُدْعَوْا إِلَى الإِسْلاَمِ وَيُسْتَتَابُوا فَإِنْ تَابُوا قُبِلَ ذَلِكَ مِنْهُمْ وَإِنْ لَمْ يَتُوبُوا قُتِلُوا وَلَمْ يُعْنَ بِذَلِكَ فِيمَا نُرَى وَاللَّهُ أَعْلَمُ مَنْ خَرَجَ مِنَ الْيَهُودِيَّةِ إِلَى النَّصْرَانِيَّةِ وَلاَ مِنَ النَّصْرَانِيَّةِ إِلَى الْيَهُودِيَّةِ وَلاَ مَنْ يُغَيِّرُ دِينَهُ مِنْ أَهْلِ الأَدْيَانِ كُلِّهَا إِلاَّ الإِسْلاَمَ فَمَنْ خَرَجَ مِنَ الإِسْلاَمِ إِلَى غَيْرِهِ وَأَظْهَرَ ذَلِكَ فَذَلِكَ الَّذِي عُنِيَ بِهِ وَاللَّهُ أَعْلَمُ ‏.‏\hadithno{1416}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya said that he heard Malik say, "What is done in our community about someone who consumed an animal without the permission of its owner, is that he must pay its price on the day he consumed it. He is not obliged to replace it with a similar animal nor does he compensate the owner with any kind of animal. He must pay its price on the day it was consumed, and giving the value is more equitable in compensation for animals and goods." Yahya said that he heard Malik say about someone who consumes some food without the permission of its owner, "He returns to the owner a like weight of the same kind of food. Food is in the position of gold and silver. Gold and silver are returned with gold and silver. The animal is not in the position of gold in that. What distinguishes between them is the sunna and the behaviour which is in force. Yahya said that he heard Malik say, "If a man is entrusted with some wealth and then trades with it for himself and makes a profit, the profit is his because he is responsible for the property until he returns it to its owner. " Yahya related to me from Malik from Zayd ibn Aslam that the Messenger of Allah, may Allah bless him and grant him peace, said, "If someone changes his deen - strike his neck!" The meaning of the statement of the Prophet, may Allah bless him and grant him peace, in our opinion and Allah knows best, is that "if someone changes his deen, strike his neck!" refers to those who leave Islam for other than it - like the heretics and their like, about whom it is known. They are killed without being called to tawba because their tawba is not recognised. They were hiding their kufr and publishing their Islam, so I do not think that one calls such people to tawba, and one does not accept their word. As for the one who goes out of Islam to something else and divulges it, one calls him to tawba. If he does not turn in tawba, he is killed. If there are people in that situation, I think that one should call them to Islam and call them to tawba. If they turn in tawba, that is accepted from them. If they do not turn in tawba, they are killed. That does not refer as we see it, and Allah knows best, to those who come out of Judaism to Christianity or from Christianity to Judaism, nor to someone who changes his deen from the various forms of deen except for Islam. Whoever comes out of Islam to other than it and divulges that, that is the one who is referred to, and Allah knows best}}
\hadithdefcmd{malik}{1417}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدٍ الْقَارِيِّ، عَنْ أَبِيهِ، أَنَّهُ قَالَ قَدِمَ عَلَى عُمَرَ بْنِ الْخَطَّابِ رَجُلٌ مِنْ قِبَلِ أَبِي مُوسَى الأَشْعَرِيِّ فَسَأَلَهُ عَنِ النَّاسِ، فَأَخْبَرَهُ ثُمَّ، قَالَ لَهُ عُمَرُ هَلْ كَانَ فِيكُمْ مِنْ مُغَرِّبَةِ خَبَرٍ فَقَالَ نَعَمْ رَجُلٌ كَفَرَ بَعْدَ إِسْلاَمِهِ ‏.‏ قَالَ فَمَا فَعَلْتُمْ بِهِ قَالَ قَرَّبْنَاهُ فَضَرَبْنَا عُنُقَهُ ‏.‏ فَقَالَ عُمَرُ أَفَلاَ حَبَسْتُمُوهُ ثَلاَثًا وَأَطْعَمْتُمُوهُ كُلَّ يَوْمٍ رَغِيفًا وَاسْتَتَبْتُمُوهُ لَعَلَّهُ يَتُوبُ وَيُرَاجِعُ أَمْرَ اللَّهِ ثُمَّ قَالَ عُمَرُ اللَّهُمَّ إِنِّي لَمْ أَحْضُرْ وَلَمْ آمُرْ وَلَمْ أَرْضَ إِذْ بَلَغَنِي ‏.‏\hadithno{1417}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me from Abd ar-Rahman ibn Muhammad ibn Abdullah ibn Abd al-Qari that his father said, "A man came to Umar ibn al- Khattab from Abu Musa al-Ashari. Umar asked after various people, and he informed him. Then Umar inquired, 'Do you have any recent news?' He said, 'Yes. A man has become a kafir after his Islam.' Umar asked, 'What have you done with him?' He said, 'We let him approach and struck off his head.' Umar said, 'Didn't you imprison him for three days and feed him a loaf of bread every day and call on him to tawba that he might turn in tawba and return to the command of Allah?' Then Umar said, 'O Allah! I was not present and I did not order it and I am not pleased since it has come to me}}
\hadithdefcmd{malik}{1418}{حَدَّثَنَا يَحْيَى، عَنْ مَالِكٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ سَعْدَ بْنَ عُبَادَةَ، قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَرَأَيْتَ إِنْ وَجَدْتُ مَعَ امْرَأَتِي رَجُلاً أَأُمْهِلُهُ حَتَّى آتِيَ بِأَرْبَعَةِ شُهَدَاءَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَعَمْ ‏"‏ ‏.‏\hadithno{1418}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Suhayl ibn Abi Salih as- Samman from his father from Abu Hurayra that Sad ibn Ubada said to the Messenger of Allah, may Allah bless him and grant him peace, "What do you think if I find a man with my wife? Shall I grant him a respite until I bring four witnesses?" The Messenger of Allah, may Allah bless him and grant him peace, replied, "Yes}}
\hadithdefcmd{malik}{1419}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ رَجُلاً، مِنْ أَهْلِ الشَّامِ - يُقَالُ لَهُ ابْنُ خَيْبَرِيٍّ - وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً فَقَتَلَهُ أَوْ قَتَلَهُمَا مَعًا فَأَشْكَلَ عَلَى مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ الْقَضَاءُ فِيهِ فَكَتَبَ إِلَى أَبِي مُوسَى الأَشْعَرِيِّ يَسْأَلُ لَهُ عَلِيَّ بْنَ أَبِي طَالِبٍ عَنْ ذَلِكَ فَسَأَلَ أَبُو مُوسَى عَنْ ذَلِكَ عَلِيَّ بْنَ أَبِي طَالِبٍ فَقَالَ لَهُ عَلِيٌّ إِنَّ هَذَا الشَّىْءَ مَا هُوَ بِأَرْضِي عَزَمْتُ عَلَيْكَ لَتُخْبِرَنِّي ‏.‏ فَقَالَ لَهُ أَبُو مُوسَى كَتَبَ إِلَىَّ مُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ أَنْ أَسْأَلَكَ عَنْ ذَلِكَ ‏.‏ فَقَالَ عَلِيٌّ أَنَا أَبُو حَسَنٍ إِنْ لَمْ يَأْتِ بِأَرْبَعَةِ شُهَدَاءَ فَلْيُعْطَ بِرُمَّتِهِ ‏.‏\hadithno{1419}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Malik related to me from Yahya ibn Said from Said ibn al-Musayyab that a Syrian man called Ibn Khaybari found a man with his wife and killed him, or killed them both. Muawiya ibn Abi Sufyan found it difficult to make a decision and he wrote to Abu Musa al-Ashari to ask Ali ibn Abi Talib for him about that. So Abu Musa asked Ali ibn Abi Talib and AIi said to him, "Is this thing in my land? I adjure you, you must tell me." Abu Musa explained to him how Muawiya ibn Abi Sufyan had written him to ask Ali about it. Ali said, "I am Abu Hasan. If he does not bring four witnesses, then let him be completely handed over," (to the relatives of the murdered man)}}
\hadithdefcmd{malik}{1420}{قَالَ يَحْيَى قَالَ مَالِكٌ عَنِ ابْنِ شِهَابٍ، عَنْ سُنَيْنٍ أَبِي جَمِيلَةَ، رَجُلٌ مِنْ بَنِي سُلَيْمٍ أَنَّهُ وَجَدَ مَنْبُوذًا فِي زَمَانِ عُمَرَ بْنِ الْخَطَّابِ قَالَ فَجِئْتُ بِهِ إِلَى عُمَرَ بْنِ الْخَطَّابِ فَقَالَ مَا حَمَلَكَ عَلَى أَخْذِ هَذِهِ النَّسَمَةِ فَقَالَ وَجَدْتُهَا ضَائِعَةً فَأَخَذْتُهَا ‏.‏ فَقَالَ لَهُ عَرِيفُهُ يَا أَمِيرَ الْمُؤْمِنِينَ إِنَّهُ رَجُلٌ صَالِحٌ ‏.‏ فَقَالَ لَهُ عُمَرُ أَكَذَلِكَ قَالَ نَعَمْ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ اذْهَبْ فَهُوَ حُرٌّ وَلَكَ وَلاَؤُهُ وَعَلَيْنَا نَفَقَتُهُ ‏.‏\hadithno{1420}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya said that Malik related from Ibn Shihab that Sunayn Abi Jamila, a man from the Banu Sulaym, found an abandoned child in the time of Umar ibn al-Khattab. Sunayn took him to Umar ibn al-Khattab. He asked, "What has induced you to take this person?" He answered, "I found him lost, so I took him.'' Umar's advisor said to him,' 'Amir al-Muminin! He is a man who does good." Umar inquired of him, "Is it so?" He replied, "Yes." Umar ibn al-Khattab said, "Go, he is free, and you have his wala' inheritance, and we will provide for him." Yahya said that he heard Malik say, "What is done in our community about an abandoned child is that he is free, and his wala' inheritance belongs to the muslims, and they inherit from him and pay his blood money}}
\hadithdefcmd{malik}{1421}{قَالَ يَحْيَى عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كَانَ عُتْبَةُ بْنُ أَبِي وَقَّاصٍ عَهِدَ إِلَى أَخِيهِ سَعْدِ بْنِ أَبِي وَقَّاصٍ أَنَّ ابْنَ وَلِيدَةِ زَمْعَةَ مِنِّي فَاقْبِضْهُ إِلَيْكَ ‏.‏ قَالَتْ فَلَمَّا كَانَ عَامُ الْفَتْحِ أَخَذَهُ سَعْدٌ وَقَالَ ابْنُ أَخِي قَدْ كَانَ عَهِدَ إِلَىَّ فِيهِ ‏.‏ فَقَامَ إِلَيْهِ عَبْدُ بْنُ زَمْعَةَ فَقَالَ أَخِي وَابْنُ وَلِيدَةِ أَبِي وُلِدَ عَلَى فِرَاشِهِ ‏.‏ فَتَسَاوَقَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ سَعْدٌ يَا رَسُولَ اللَّهِ ابْنُ أَخِي قَدْ كَانَ عَهِدَ إِلَىَّ فِيهِ ‏.‏ وَقَالَ عَبْدُ بْنُ زَمْعَةَ أَخِي وَابْنُ وَلِيدَةِ أَبِي وُلِدَ عَلَى فِرَاشِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هُوَ لَكَ يَا عَبْدُ بْنَ زَمْعَةَ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْوَلَدُ لِلْفِرَاشِ وَلِلْعَاهِرِ الْحَجَرُ ‏"‏ ‏.‏ ثُمَّ قَالَ لِسَوْدَةَ بِنْتِ زَمْعَةَ ‏"‏ احْتَجِبِي مِنْهُ ‏"‏ ‏.‏ لِمَا رَأَى مِنْ شَبَهِهِ بِعُتْبَةَ بْنِ أَبِي وَقَّاصٍ قَالَتْ فَمَا رَآهَا حَتَّى لَقِيَ اللَّهَ عَزَّ وَجَلَّ ‏.‏\hadithno{1421}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya said from Malik from Ibn Shihab from Urwa ibn az-Zubayr that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, ''Utba ibn Abi Waqqas disclosed to his brother, Sad ibn Abi Waqqas, that he was the father of the son of the slave-girl of Zama, and made him promise to look after him (after his death). In the year of the conquest, Sad took him and said, 'He is the son of my brother. He covenanted with me about him.' Abd ibn Zama stood up and said, 'He is my brother and the son of my father's slave-girl. He was born on his bed.' They went to the Messenger of Allah, may Allah bless him and grant him peace. Sad said, 'Messenger of Allah! He is the son of my brother, he made a covenant with me about him.' Abd ibn Zama said, 'He is my brother and the son of my father's slave-girl and was born on my father's bed.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'He is yours, Abd ibn Zama.' Then the Messenger of Allah, may Allah bless him and grant him peace, said, 'A child belongs to the household (where he was born) and the adulterer is stoned.' Then he told Sawda bint Zama, 'Veil yourself from him,' since he saw in him a resemblance to Utba ibn Abi Waqqas." A'isha added, "He did not see her until he met Allah, the Mighty, the Majestic}}
\hadithdefcmd{malik}{1422}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الْهَادِي، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أُمَيَّةَ، أَنَّ امْرَأَةً، هَلَكَ عَنْهَا زَوْجُهَا فَاعْتَدَّتْ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ثُمَّ تَزَوَّجَتْ حِينَ حَلَّتْ فَمَكَثَتْ عِنْدَ زَوْجِهَا أَرْبَعَةَ أَشْهُرٍ وَنِصْفَ شَهْرٍ ثُمَّ وَلَدَتْ وَلَدًا تَامًّا فَجَاءَ زَوْجُهَا إِلَى عُمَرَ بْنِ الْخَطَّابِ فَذَكَرَ ذَلِكَ لَهُ فَدَعَا عُمَرُ نِسْوَةً مِنْ نِسَاءِ الْجَاهِلِيَّةِ قُدَمَاءَ فَسَأَلَهُنَّ عَنْ ذَلِكَ فَقَالَتِ امْرَأَةٌ مِنْهُنَّ أَنَا أُخْبِرُكَ عَنْ هَذِهِ الْمَرْأَةِ هَلَكَ عَنْهَا زَوْجُهَا حِينَ حَمَلَتْ مِنْهُ فَأُهْرِيقَتْ عَلَيْهِ الدِّمَاءُ فَحَشَّ وَلَدُهَا فِي بَطْنِهَا فَلَمَّا أَصَابَهَا زَوْجُهَا الَّذِي نَكَحَهَا وَأَصَابَ الْوَلَدَ الْمَاءُ تَحَرَّكَ الْوَلَدُ فِي بَطْنِهَا وَكَبِرَ ‏.‏ فَصَدَّقَهَا عُمَرُ بْنُ الْخَطَّابِ وَفَرَّقَ بَيْنَهُمَا وَقَالَ عُمَرُ أَمَا إِنَّهُ لَمْ يَبْلُغْنِي عَنْكُمَا إِلاَّ خَيْرٌ وَأَلْحَقَ الْوَلَدَ بِالأَوَّلِ ‏.‏\hadithno{1422}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Yazid ibn Abdullah ibn al-Hadi from Muhammad ibn Ibrahim ibn al-Harith at-Taymi from Sulayman ibn Yasar from Abdullah ibn Abi Umayya that a woman's husband died, and she did the idda of four months and ten days. Then she married when she was free to marry. She stayed with her husband for four and a half months, then gave birth to a fully developed child. Her husband went to Umar ibn al-Khattab and mentioned that to him, so Umar called some of the old women of the Jahiliyya and asked them about that. One of the women said, "I will tell you what happened with this woman. When her husband died, she was pregnant by him, but then the blood flowed from her because of his death and the child became dry in her womb. When her new husband had intercourse with her and the water reached the child, the child moved in the womb and grew." Umar ibn al-Khattab believed her and separated them (until she had completed her idda). Umar said, "Only good has reached me about you two," and he connected the child to the first husband}}
\hadithdefcmd{malik}{1423}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ يُلِيطُ أَوْلاَدَ الْجَاهِلِيَّةِ بِمَنِ ادَّعَاهُمْ فِي الإِسْلاَمِ فَأَتَى رَجُلاَنِ كِلاَهُمَا يَدَّعِي وَلَدَ امْرَأَةٍ فَدَعَا عُمَرُ بْنُ الْخَطَّابِ قَائِفًا فَنَظَرَ إِلَيْهِمَا فَقَالَ الْقَائِفُ لَقَدِ اشْتَرَكَا فِيهِ فَضَرَبَهُ عُمَرُ بْنُ الْخَطَّابِ بِالدِّرَّةِ ثُمَّ دَعَا الْمَرْأَةَ فَقَالَ أَخْبِرِينِي خَبَرَكِ فَقَالَتْ كَانَ هَذَا - لأَحَدِ الرَّجُلَيْنِ - يَأْتِينِي ‏.‏ وَهِيَ فِي إِبِلٍ لأَهْلِهَا فَلاَ يُفَارِقُهَا حَتَّى يَظُنَّ وَتَظُنَّ أَنَّهُ قَدِ اسْتَمَرَّ بِهَا حَبَلٌ ثُمَّ انْصَرَفَ عَنْهَا فَأُهْرِيقَتْ عَلَيْهِ دِمَاءٌ ثُمَّ خَلَفَ عَلَيْهَا هَذَا - تَعْنِي الآخَرَ - فَلاَ أَدْرِي مِنْ أَيِّهِمَا هُوَ قَالَ فَكَبَّرَ الْقَائِفُ فَقَالَ عُمَرُ لِلْغُلاَمِ وَالِ أَيَّهُمَا شِئْتَ ‏.‏\hadithno{1423}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me from Yahya ibn Said from Sulayman ibn Yasar that Umar ibn al-Khattab used to attach the children of the Jahiliyya to whoever claimed them in Islam. Two men came and each of them claimed a woman's child. Umar ibn al-Khattab summoned a person who scrutinized features and he looked at them. The scrutinizer said, "They both share in him." Umar ibn al-Khattab hit him with a whip. Then he summoned the woman, and said, "Tell me your tale." She said, "It was this one (indicating one of the two men) who used to come to me while I was with my people's camels. He did not leave me until he thought and I thought that I was pregnant. Then he left me, and blood flowed from me, and this other one took his place. I do not know from which of them the child is." The scrutinizer said, "Allah is greater." Umar said to the child, "Go to whichever of them you wish}}
\hadithdefcmd{malik}{1424}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، أَوْ عُثْمَانَ بْنَ عَفَّانَ قَضَى أَحَدُهُمَا فِي امْرَأَةٍ غَرَّتْ رَجُلاً بِنَفْسِهَا وَذَكَرَتْ أَنَّهَا حُرَّةٌ فَتَزَوَّجَهَا فَوَلَدَتْ لَهُ أَوْلاَدًا فَقَضَى أَنْ يَفْدِيَ وَلَدَهُ بِمِثْلِهِمْ ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ وَالْقِيمَةُ أَعْدَلُ فِي هَذَا إِنْ شَاءَ اللَّهُ ‏.‏\hadithno{1424}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me that he had heard that Umar ibn al-Khattab or Uthman ibn Affan gave a judgement about a slave woman who misled a man about herself and said that she was free. He married her and she bore children. It was decided that he should ransom his children with their like of slaves. Yahya said that he heard Malik say, "To ransom them with their price is more equitable in this case, Allah willing}}
\hadithdefcmd{malik}{1425}{قَالَ يَحْيَى قَالَ مَالِكٌ عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ مَا بَالُ رِجَالٍ يَطَئُونَ وَلاَئِدَهُمْ ثُمَّ يَعْزِلُوهُنَّ لاَ تَأْتِينِي وَلِيدَةٌ يَعْتَرِفُ سَيِّدُهَا أَنْ قَدْ أَلَمَّ بِهَا إِلاَّ أَلْحَقْتُ بِهِ وَلَدَهَا فَاعْزِلُوا بَعْدُ أَوِ اتْرُكُوا ‏.‏\hadithno{1425}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya said that he heard Malik say, "The way of doing things generally agreed upon in our community in the case of a man who dies and has sons and one of them claims, 'My father confirmed that so-and- so was his son,' is that the relationship is not established by the testimony of one man, and the confirmation of the one who confirmed it is only permitted as regards his own share in the division of his father's property. The one testified for is only given his due from the share of the testifier." Malik said, "An example of this is that a man dies leaving two sons, and 600 dinars. Each of them takes 300 dinars. Then one of them testifies that his deceased father confirmed that so-and-so was his son. The one who testifies is obliged to give 100 dinars to the one thus connected. This is half of the inheritance of the one thought to be related, had he been related. If the other confirms him, he takes the other 100 and so he completes his right and his relationship is established. His position is similar to that of a woman who confirms a debt against her father or her husband and the other heirs deny it. She must pay to the person whose debt she confirms, the amount according to her share of the full debt, had it been confirmed against all the heirs. If the woman inherits an eighth, she pays the creditor an eighth of his debt. If a daughter inherits a half, she pays the creditor half of his debt. Whichever women confirm him, pay him according to this. Malik said, "If a man's testimony is in agreement with what the woman testified to, that so- and-so had a debt against his father, the creditor is made to take an oath with one witness and he is given all his due. This is not the position with women because a man's testimony is allowed and the creditor must take an oath with the testimony of his witness, and take all his due. If he does not take an oath, he only takes from the inheritance of the one who confirmed him according to his share of the debt, because he confirmed his right and the other heirs denied it. It is permitted for him to confirm it." Yahya said that Malik related from Ibn Shihab from Salim ibn Abdullah ibn Umar from his father that Umar ibn al-Khattab said, "What's the matter with men who have intercourse with their slave- girls and then dismiss them? No slave-girl comes to me whose master confesses that he has had intercourse with her but that I connect her child to him, whether or not he has practised coitus interruptus or stopped having intercourse with her}}
\hadithdefcmd{malik}{1426}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ، أَنَّهَا أَخْبَرَتْهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ قَالَ مَا بَالُ رِجَالٍ يَطَئُونَ وَلاَئِدَهُمْ ثُمَّ يَدَعُوهُنَّ يَخْرُجْنَ لاَ تَأْتِينِي وَلِيدَةٌ يَعْتَرِفُ سَيِّدُهَا أَنْ قَدْ أَلَمَّ بِهَا إِلاَّ قَدْ أَلْحَقْتُ بِهِ وَلَدَهَا فَأَرْسِلُوهُنَّ بَعْدُ أَوْ أَمْسِكُوهُنَّ ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ الأَمْرُ عِنْدَنَا فِي أُمِّ الْوَلَدِ إِذَا جَنَتْ جِنَايَةً ضَمِنَ سَيِّدُهَا مَا بَيْنَهَا وَبَيْنَ قِيمَتِهَا وَلَيْسَ لَهُ أَنْ يُسَلِّمَهَا وَلَيْسَ عَلَيْهِ أَنْ يَحْمِلَ مِنْ جِنَايَتِهَا أَكْثَرَ مِنْ قِيمَتِهَا ‏.‏\hadithno{1426}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Nafi that Safiyya bint Abi Ubayd informed him that Umar ibn al-Khattab said, "What is the matter with men who have intercourse with their slave-girls and then leave them to go? No slave-girl comes to me whose master confesses that he has had intercourse with her but that I connect her child to him, whether or not he has practised coitus interruptus or left off from intercourse with her." Yahya said that he heard Malik say, "What is done in our community about an umm walad who commits a crime is that her master is liable for what she has done up to her value. He does not have to surrender her, and he cannot be made to bear more than her value for her crime}}
\hadithdefcmd{malik}{1427}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَحْيَا أَرْضًا مَيِّتَةً فَهِيَ لَهُ وَلَيْسَ لِعِرْقٍ ظَالِمٍ حَقٌّ ‏"‏ ‏.‏\hadithno{1427}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related from Malik from Hisham ibn Urwa from his father that the Messenger of Allah, may Allah bless him and grant him peace, said, "If anyone revives dead land, it belongs to him, and the unjust root has no right." Malik explained, "The unjust root is whatever is taken, or planted without right}}
\hadithdefcmd{malik}{1428}{وَحَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ مَنْ أَحْيَا أَرْضًا مَيِّتَةً فَهِيَ لَهُ ‏.‏ قَالَ مَالِكٌ وَعَلَى ذَلِكَ الأَمْرُ عِنْدَنَا ‏.‏\hadithno{1428}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Ibn Shihab from Salim ibn Abdullah from his father that Umar ibn al-Khattab said, "Whoever revives dead land, it belongs to him." Malik said, "That is what is done in our community}}
\hadithdefcmd{malik}{1429}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي سَيْلِ مَهْزُورٍ وَمُذَيْنِبٍ ‏ "‏ يُمْسَكُ حَتَّى الْكَعْبَيْنِ ثُمَّ يُرْسِلُ الأَعْلَى عَلَى الأَسْفَلِ ‏"‏ ‏.‏\hadithno{1429}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr ibn Muhammad ibn Amr ibn Hazm that he heard that the Messenger of Allah, may Allah bless him and grant him peace, said about the flood-channels of Mahzur and Mudhaynib (in Madina), "Dam them systematically, so that the water is diverted into each property in turn up to ankle level, starting upstream}}
\hadithdefcmd{malik}{1430}{وَحَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُمْنَعُ فَضْلُ الْمَاءِ لِيُمْنَعَ بِهِ الْكَلأُ ‏"‏ ‏.‏\hadithno{1430}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Excess water is not withheld in order to prevent herbage from growing}}
\hadithdefcmd{malik}{1431}{وَحَدَّثَنِي مَالِكٌ، عَنْ أَبِي الرِّجَالِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أُمِّهِ، عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ أَنَّهَا أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُمْنَعُ نَقْعُ بِئْرٍ ‏"‏ ‏.‏\hadithno{1431}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abu'r-Rijal Muhammad ibn Abd ar-Rahman from his mother Amra bint Abd ar-Rahman that she informed him that the Messenger of Allah, may Allah bless him and grant him peace, said, "Do not withhold the surplus water of a well from people}}
\hadithdefcmd{malik}{1432}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ ضَرَرَ وَلاَ ضِرَارَ ‏"‏ ‏.‏\hadithno{1432}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Amr ibn Yahya al-Mazini from his father that the Messenger of Allah, may Allah bless him and grant him peace, said, "There is no injury nor return of injury}}
\hadithdefcmd{malik}{1433}{وَحَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمْنَعُ أَحَدُكُمْ جَارَهُ خَشَبَةً يَغْرِزُهَا فى جِدَارِهِ ‏"‏ ‏.‏ ثُمَّ يَقُولُ أَبُو هُرَيْرَةَ مَا لِي أَرَاكُمْ عَنْهَا مُعْرِضِينَ وَاللَّهِ لأَرْمِيَنَّ بِهَا بَيْنَ أَكْتَافِكُمْ ‏.‏\hadithno{1433}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Ibn Shihab from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "No one should prevent his neighbour from fixing a wooden peg in his wall." Then Abu Hurayra said, "Why do I see you turning away from it? By Allah! I shall keep on at you about it}}
\hadithdefcmd{malik}{1434}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ أَبِيهِ، أَنَّ الضَّحَّاكَ بْنَ خَلِيفَةَ، سَاقَ خَلِيجًا لَهُ مِنَ الْعُرَيْضِ فَأَرَادَ أَنْ يَمُرَّ بِهِ فِي أَرْضِ مُحَمَّدِ بْنِ مَسْلَمَةَ فَأَبَى مُحَمَّدٌ ‏.‏ فَقَالَ لَهُ الضَّحَّاكُ لِمَ تَمْنَعُنِي وَهُوَ لَكَ مَنْفَعَةٌ تَشْرَبُ بِهِ أَوَّلاً وَآخِرًا وَلاَ يَضُرُّكَ ‏.‏ فَأَبَى مُحَمَّدٌ فَكَلَّمَ فِيهِ الضَّحَّاكُ عُمَرَ بْنَ الْخَطَّابِ فَدَعَا عُمَرُ بْنُ الْخَطَّابِ مُحَمَّدَ بْنَ مَسْلَمَةَ فَأَمَرَهُ أَنْ يُخَلِّيَ سَبِيلَهُ فَقَالَ مُحَمَّدٌ لاَ ‏.‏ فَقَالَ عُمَرُ لِمَ تَمْنَعُ أَخَاكَ مَا يَنْفَعُهُ وَهُوَ لَكَ نَافِعٌ تَسْقِي بِهِ أَوَّلاً وَآخِرًا وَهُوَ لاَ يَضُرُّكَ ‏.‏ فَقَالَ مُحَمَّدٌ لاَ وَاللَّهِ ‏.‏ فَقَالَ عُمَرُ وَاللَّهِ لَيَمُرَّنَّ بِهِ وَلَوْ عَلَى بَطْنِكَ ‏.‏ فَأَمَرَهُ عُمَرُ أَنْ يَمُرَّ بِهِ فَفَعَلَ الضَّحَّاكُ ‏.‏\hadithno{1434}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me from Amr ibn Yahya al-Mazini from his father that ad-Dahhak ibn Khalifa watered his irrigation ditch from a large source of water. He wanted to have it pass through the land of Muhammad ibn Maslama, and Muhammad refused. Ad-Dahhak said to him, "Why do you prevent me? It will benefit you. You can drink from it first and last and it will not harm you." Muhammed refused so ad- Dahhak spoke about it to Umar ibn al-Khattab, and Umar ibn al-Khattab summoned Muhammad ibn Maslama and ordered him to clear the way. Muhammad said, "No." Umar said, "Why do you prevent your brother from what will benefit him and is also useful for you? You will take water from it first and last and it will not harm you." Muhammad said, "No, by Allah!" Umar said, "By Allah, he will pass it through, even if it is over your belly!" Umar ordered him to allow its passage and ad-Dahhak did so}}
\hadithdefcmd{malik}{1435}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ أَبِيهِ، أَنَّهُ قَالَ كَانَ فِي حَائِطِ جَدِّهِ رَبِيعٌ لِعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ فَأَرَادَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ أَنْ يُحَوِّلَهُ إِلَى نَاحِيَةٍ مِنَ الْحَائِطِ هِيَ أَقْرَبُ إِلَى أَرْضِهِ فَمَنَعَهُ صَاحِبُ الْحَائِطِ فَكَلَّمَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ عُمَرَ بْنَ الْخَطَّابِ فِي ذَلِكَ فَقَضَى لِعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ بِتَحْوِيلِهِ ‏.‏\hadithno{1435}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me from Amr ibn Yahya al-Mazini that his father said, "There was a stream in my grand-father's garden belonging to Abd ar-Rahman ibn Awf Abd ar-Rahman ibn Awf wanted to transfer it to a corner of the garden nearer to his land, and the owner of the garden prevented him. Abd ar-Rahman ibn Awf spoke to Umar ibn al-Khattab about it, and he gave a judgement to Abd ar-Rahman ibn Awf that he should transfer it}}
\hadithdefcmd{malik}{1436}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، أَنَّهُ قَالَ بَلَغَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا دَارٍ أَوْ أَرْضٍ قُسِمَتْ فِي الْجَاهِلِيَّةِ فَهِيَ عَلَى قَسْمِ الْجَاهِلِيَّةِ وَأَيُّمَا دَارٍ أَوْ أَرْضٍ أَدْرَكَهَا الإِسْلاَمُ وَلَمْ تُقْسَمْ فَهِيَ عَلَى قَسْمِ الإِسْلاَمِ ‏"‏ ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ فِيمَنْ هَلَكَ وَتَرَكَ أَمْوَالاً بِالْعَالِيَةِ وَالسَّافِلَةِ إِنَّ الْبَعْلَ لاَ يُقْسَمُ مَعَ النَّضْحِ إِلاَّ أَنْ يَرْضَى أَهْلُهُ بِذَلِكَ وَإِنَّ الْبَعْلَ يُقْسَمُ مَعَ الْعَيْنِ إِذَا كَانَ يُشْبِهُهَا وَأَنَّ الأَمْوَالَ إِذَا كَانَتْ بِأَرْضٍ وَاحِدَةٍ الَّذِي بَيْنَهُمَا مُتَقَارِبٌ أَنَّهُ يُقَامُ كُلُّ مَالٍ مِنْهَا ثُمَّ يُقْسَمُ بَيْنَهُمْ وَالْمَسَاكِنُ وَالدُّورُ بِهَذِهِ الْمَنْزِلَةِ ‏.‏\hadithno{1436}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Thawr ibn Zayd ad-Dili said, "I heard that the Messenger of Allah, may Allah bless him and grant him peace, said, 'A house or land that has been divided in the Jahiliyya, it is according to the division of the Jahiliyya. A house or land which has not been divided before the coming of Islam is divided according to Islam}}
\hadithdefcmd{malik}{1437}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حَرَامِ بْنِ سَعْدِ بْنِ مُحَيِّصَةَ، أَنَّ نَاقَةً، لِلْبَرَاءِ بْنِ عَازِبٍ دَخَلَتْ حَائِطَ رَجُلٍ فَأَفْسَدَتْ فِيهِ فَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّ عَلَى أَهْلِ الْحَوَائِطِ حِفْظَهَا بِالنَّهَارِ وَأَنَّ مَا أَفْسَدَتِ الْمَوَاشِي بِاللَّيْلِ ضَامِنٌ عَلَى أَهْلِهَا ‏.‏\hadithno{1437}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya said that he heard Malik speak about a man who died and left properties in Aliya and Safila (outlying districts of Madina). He said, "Unirrigated naturally watered land is not in the same category as irrigated land unless the family are satisfied with that. Unirrigated land is only in the same category as land with a spring when it resembles it. When the properties are in one land, and are close together, each individual property is evaluated and then divided between the heirs. Dwellings and houses are in the same position." Yahya related to me from Malik from Ibn Shihab from Haram ibn Sad ibn Muhayyisa that a female camel of al-Bara ibn Azib entered the garden of a man and it did some damage to it. The Messenger of Allah, may Allah bless him and grant him peace, gave a judgement that the people of the garden were responsible for guarding it in the day, and the owner of the animals was liable for what the animals destroyed at night}}
\hadithdefcmd{malik}{1438}{وَحَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ يَحْيَى بْنِ عَبْدِ الرَّحْمَنِ بْنِ حَاطِبٍ، أَنَّ رَقِيقًا، لِحَاطِبٍ سَرَقُوا نَاقَةً لِرَجُلٍ مِنْ مُزَيْنَةَ فَانْتَحَرُوهَا فَرُفِعَ ذَلِكَ إِلَى عُمَرَ بْنِ الْخَطَّابِ فَأَمَرَ عُمَرُ كَثِيرَ بْنَ الصَّلْتِ أَنْ يَقْطَعَ أَيْدِيَهُمْ ثُمَّ قَالَ عُمَرُ أَرَاكَ تُجِيعُهُمْ ‏.‏ ثُمَّ قَالَ عُمَرُ وَاللَّهِ لأُغَرِّمَنَّكَ غُرْمًا يَشُقُّ عَلَيْكَ ثُمَّ قَالَ لِلْمُزَنِيِّ كَمْ ثَمَنُ نَاقَتِكَ فَقَالَ الْمُزَنِيُّ قَدْ كُنْتُ وَاللَّهِ أَمْنَعُهَا مِنْ أَرْبَعِمِائَةِ دِرْهَمٍ ‏.‏ فَقَالَ عُمَرُ أَعْطِهِ ثَمَانَمِائَةِ دِرْهَمٍ ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ وَلَيْسَ عَلَى هَذَا الْعَمَلُ عِنْدَنَا فِي تَضْعِيفِ الْقِيمَةِ وَلَكِنْ مَضَى أَمْرُ النَّاسِ عِنْدَنَا عَلَى أَنَّهُ إِنَّمَا يَغْرَمُ الرَّجُلُ قِيمَةَ الْبَعِيرِ أَوِ الدَّابَّةِ يَوْمَ يَأْخُذُهَا ‏.‏\hadithno{1438}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Hisham ibn Urwa from his father from Yahya ibn Abd ar-Rahman ibn Hatib that some slaves of Hatib stole a she-camel belonging to a man from the Muzayna tribe and they slaughtered it. The case was brought before Umar ibn al-Khattab, and Umar ordered Kathir ibn as-Salt to cut off their hands. Then Umar said to Habib, "I think you must be starving them," and he added, "By Allah! I will make you pay such a fine that it will be heavy for you." He enquired of the man from the Muzayna tribe, "What was the price of your camel?" The Muzayni said, "By Allah, I refused to sell her for 400 dirhams.'' Umar said, ''Give him 800 dirhams." Yahya said that he heard Malik say, "Doubling the price is not the behaviour of our community. What people have settled on among us is that the man is obliged to pay the value of the camel or animal on the day he took it}}
\hadithdefcmd{malik}{1439}{حَدَّثَنَا يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، وَعَنْ مُحَمَّدِ بْنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّهُمَا حَدَّثَاهُ عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّهُ قَالَ إِنَّ أَبَاهُ بَشِيرًا أَتَى بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنِّي نَحَلْتُ ابْنِي هَذَا غُلاَمًا كَانَ لِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَكُلَّ وَلَدِكَ نَحَلْتَهُ مِثْلَ هَذَا ‏"‏ ‏.‏ فَقَالَ لاَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَارْتَجِعْهُ ‏"‏ ‏.‏\hadithno{1439}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya said that he heard Malik say, "What is done in our community about injury to a domestic animal, is that the one who injures it must pay the amount by which he has diminished the animal's price." Yahya said that he heard Malik speak about a camel who attacked a man and he feared for himself and killed it or hamstrung it. He said, "If he has a clear proof that it was heading for him and had attacked him, there are no damages against him. If there is no clear proof except his word, he is responsible for the camel." Yahya related that he heard Malik say that if a man gave a washer a garment to dye and he dyed it, and then the owner of the garment said, "I did not order you to use this dye," and the washer protested that he had done so, then the washer was to be believed. It was the same with the tailor and the gold-smith. They took an oath about it unless they produced something they would not normally have been employed to do. In that situation their statement was not allowed and the owner of the garment had to take an oath . If he rejected it and refused to swear, then the dyer was made to take an oath. Yahya said, "I heard Malik speak about a dyer who was given a garment and he made a mistake and gave it to another man and the one to whom he gave it wore it. He said, 'The one who wore it has no damages against him, and the washer pays damages to the owner of the garment. That is when the man wears the garment which was given him without recognizing that it is not his. If he wears it knowing that it is not his garment, he is responsible for it.' " Yahya said that he heard Malik say, "What is done in our community about a man who refers a creditor to another man for the debt he owes him is that if the one referred to goes bankrupt or dies, and does not leave enough to pay the debt, then the creditor has nothing against the one who referred him and the debt does not return to the first party." Malik said, "This is the way of doing things about which there is no dispute in our community." Malik said, "If a man has his debt to somebody taken on for him by another man and then the man who took it on dies or goes bankrupt, then whatever was taken on by him returns to the first debtor." Yahya said that he heard Malik say, "If a man buys a garment which has a defect, a burn or something else, which the seller knows about and that is testified against him or he confirms it, and the man who has bought it causes a new tear which decreases the price of the garment, and then he learns about the original defect, he can return it to the seller and he is not liable for his tearing it. "If a man buys a garment which has a defect of a burn or flaw, and the one who sold it to him claims that he did not know about it, and the buyer has cut the garment or dyed it, then the buyer has an option . If he wishes, he can have a reduction according to what the burn or flaw detracts from the price of the garment and he can keep the garment, or if he wishes to pay damages for what the cutting or dyeing has decreased of the price of the garment and return it, he can do so. "If the buyer has dyed the garment with a dye which increases the value, the buyer has an option. If he wishes, he has a reduction from the price of the garment according to what the defect diminishes or if he wishes to become a partner with the one who sold the garment he does so. The price of the garment with a burn or flaw is looked at. If the price is ten dirhams, and the amount by which the dyeing increased the value is five dirhams, then they are partners in the garment, each according to his share. In this reckoning is the amount by which the dyeing increases the price of the garment." Yahya related to us from Malik from Ibn Shihab from Humayd ibn Abd ar-Rah man ibn Awf and from Muhammad ibn an-Numan ibn Bashir that they related to him that an-Numan ibn Bashir said that his father Bashir brought him to the Messenger of Allah, may Allah bless him and grant him peace, and said, "I have given this son of mine one of my slaves." The Messenger of Allah, may Allah bless him and grant him peace, said, "Have you given each of your children the same as this?" He said, "No." The Messenger of Allah, may Allah bless him and grant him peace, said, "Then take the slave back}}
\hadithdefcmd{malik}{1440}{وَحَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ إِنَّ أَبَا بَكْرٍ الصِّدِّيقَ كَانَ نَحَلَهَا جَادَّ عِشْرِينَ وَسْقًا مِنْ مَالِهِ بِالْغَابَةِ فَلَمَّا حَضَرَتْهُ الْوَفَاةُ قَالَ وَاللَّهِ يَا بُنَيَّةُ مَا مِنَ النَّاسِ أَحَدٌ أَحَبُّ إِلَىَّ غِنًى بَعْدِي مِنْكِ وَلاَ أَعَزُّ عَلَىَّ فَقْرًا بَعْدِي مِنْكِ وَإِنِّي كُنْتُ نَحَلْتُكِ جَادَّ عِشْرِينَ وَسْقًا فَلَوْ كُنْتِ جَدَدْتِيهِ وَاحْتَزْتِيهِ كَانَ لَكِ وَإِنَّمَا هُوَ الْيَوْمَ مَالُ وَارِثٍ وَإِنَّمَا هُمَا أَخَوَاكِ وَأُخْتَاكِ فَاقْتَسِمُوهُ عَلَى كِتَابِ اللَّهِ ‏.‏ قَالَتْ عَائِشَةُ فَقُلْتُ يَا أَبَتِ وَاللَّهِ لَوْ كَانَ كَذَا وَكَذَا لَتَرَكْتُهُ إِنَّمَا هِيَ أَسْمَاءُ فَمَنِ الأُخْرَى فَقَالَ أَبُو بَكْرٍ ذُو بَطْنِ بِنْتِ خَارِجَةَ ‏.‏ أُرَاهَا جَارِيَةً ‏.‏\hadithno{1440}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Ibn Shihab from Urwa ibn az-Zubayr that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "Abu Bakr as-Siddiq gave me palm trees whose produce was twenty awsuq from his property at al-Ghaba. When he was dying, he said, 'By Allah, little daughter, there is no one I would prefer to be wealthy after I die than you. There is no one it is more difficult for me to see poor after I die than you. I gave you palm-trees whose produce is twenty awsuq. Had you cut them and taken possession of them, they would have been yours, but today they are the property of the heirs, and they are your two brothers and your two sisters, so divide it according to the Book of Allah.' A'isha continued, "I said, 'My father! By Allah, even if it had been more, I would have left it. There is only Asma. Who is my other sister?" Abu Bakr replied, 'What is in the womb of Kharija? (Kharija was the wife of Abu Bakr's 'brother' from the Ansar.) I think that it is going to be a girl}}
\hadithdefcmd{malik}{1441}{وَحَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدٍ الْقَارِيِّ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ مَا بَالُ رِجَالٍ يَنْحَلُونَ أَبْنَاءَهُمْ نُحْلاً ثُمَّ يُمْسِكُونَهَا فَإِنْ مَاتَ ابْنُ أَحَدِهِمْ قَالَ مَالِي بِيَدِي لَمْ أُعْطِهِ أَحَدًا ‏.‏ وَإِنْ مَاتَ هُوَ قَالَ هُوَ لاِبْنِي قَدْ كُنْتُ أَعْطَيْتُهُ إِيَّاهُ ‏.‏ مَنْ نَحَلَ نِحْلَةً فَلَمْ يَحُزْهَا الَّذِي نُحِلَهَا - حَتَّى يَكُونَ إِنْ مَاتَ لِوَرَثَتِهِ - فَهِيَ بَاطِلٌ ‏.‏\hadithno{1441}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Ibn Shihab from Urwa ibn az-Zubayr from Abd ar-Rahman ibn Abd al-Qari that Umar ibn al-Khattab said, "What is wrong with men who give their sons gifts and then keep them and if the son dies, they say, 'My property is in my possession and I did not give it to anyone.' But if they themselves are dying, they say, 'It belongs to my son, I gave it to him.' Whoever gives a gift, and does not hand it over to the one to whom it was given, the gift is invalid, and if he dies it belongs to the heirs in general}}
\hadithdefcmd{malik}{1442}{حَدَّثَنِي مَالِكٌ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ أَبِي غَطَفَانَ بْنِ طَرِيفٍ الْمُرِّيِّ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ مَنْ وَهَبَ هِبَةً لِصِلَةِ رَحِمٍ أَوْ عَلَى وَجْهِ صَدَقَةٍ فَإِنَّهُ لاَ يَرْجِعُ فِيهَا وَمَنْ وَهَبَ هِبَةً يَرَى أَنَّهُ إِنَّمَا أَرَادَ بِهَا الثَّوَابَ فَهُوَ عَلَى هِبَتِهِ يَرْجِعُ فِيهَا إِذَا لَمْ يُرْضَ مِنْهَا ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ الأَمْرُ الْمُجْتَمَعُ عَلَيْهِ عِنْدَنَا أَنَّ الْهِبَةَ إِذَا تَغَيَّرَتْ عِنْدَ الْمَوْهُوبِ لَهُ لِلثَّوَابِ بِزِيَادَةٍ أَوْ نُقْصَانٍ فَإِنَّ عَلَى الْمَوْهُوبِ لَهُ أَنْ يُعْطِيَ صَاحِبَهَا قِيمَتَهَا يَوْمَ قَبَضَهَا ‏.‏\hadithno{1442}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya said that he heard Malik say, "What is done in our community about some one who gives a gift not intending a reward is that he calls witnesses to it. It is affirmed for the one to whom it has been given unless the giver dies before the one to whom it was given receives the gift." He said, "If the giver wants to keep the gift after he has had it witnessed, he cannot. If the recipient claims it from him, he takes it." Malik said, "If some one gives a gift and then withdraws it and the recipient brings a witness to testify for him that he was given the gift, be it goods, gold, silver or animals, the recipient is made to take an oath. If he refuses, the giver is made to take an oath. If he also refuses to take an oath, he gives to the recipient what he claims from him if he has at least one witness. If he does not have a witness, he has nothing . " Malik said, "If someone gives a gift not expecting anything in return and then the recipient dies, the heirs are in his place. If the giver dies before the recipient has received his gift, the recipient has nothing. That is because he was given a gift which he did not take possession of. If the giver wants to keep it, and he has called witnesses to the gift, he cannot do that. If the recipient claims his right he takes it." Malik related to me from Da'ud ibn al-Husayn from Abu Ghatafan ibn Tarif al-Muriyi that Umar ibn al-Khattab said, "If someone gives a gift to strengthen ties with a relative or as sadaqa, he cannot have it returned. If some one, however, gives a gift seeking by it favour or reward, he has his gift and can reclaim it if he does not have satisfaction from it." Yahya said that he heard Malik say, "The generally agreed-on way of doing things in our community is that if the gift is returned to the one who gave it for recompense, and its value has been either increased or decreased, the one to whom it has been given gives the owner its value on the day he received it}}
\hadithdefcmd{malik}{1443}{حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ الأَنْصَارِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا رَجُلٍ أُعْمِرَ عُمْرَى لَهُ وَلِعَقِبِهِ فَإِنَّهَا لِلَّذِي يُعْطَاهَا لاَ تَرْجِعُ إِلَى الَّذِي أَعْطَاهَا أَبَدًا ‏"‏ ‏.‏ لأَنَّهُ أَعْطَى عَطَاءً وَقَعَتْ فِيهِ الْمَوَارِيثُ ‏.‏\hadithno{1443}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya said that he heard Malik say, "The way of doing things in our community about which there is no dispute, is that if a man gives sadaqa to his son - sadaqa which the son takes possession of or which is in the father's keeping and the father has had his sadaqa witnessed, he cannot take back any of it because he cannot reclaim any sadaqa." Yahya said that he heard Malik say, "The generally agreed-on way of doing things in our community in the case of someone who gives his son a gift or grants him a gift which is not sadaqa is that he can take it back as long as the child does not start a debt, which people claim from him, and which they trust him for on the strength of the gift his father has given him. The father cannot take back anything from the gift after debts are started against it. "If a man gives his son or daughter something and a woman marries the man, and she only marries him for the wealth and the property which his father has given him and so the father wants to take that back, or, if a man marries a woman whose father has given her a gift and he marries her with an increased bride-price because of the wealth and property that her father has given, then the father says, 'I will take that back,' then the father cannot take back any of that from the son or daughter if it is as I have described to you." Malik related to me from Ibn Shihab from Abu Salama ibn Abd ar- Rahman ibn Awf from Jabir ibn Abdullah al-Ansari that the Messenger of Allah, may Allah bless him and grant him peace, said, "If someone is given a life pension, for him and his posterity, it belongs to the person to whom it has been given. It never reverts to the one who gave it because he gave a gift and the rules of inheritance apply to it}}
\hadithdefcmd{malik}{1444}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، أَنَّهُ سَمِعَ مَكْحُولاً الدِّمَشْقِيَّ، يَسْأَلُ الْقَاسِمَ بْنَ مُحَمَّدٍ عَنِ الْعُمْرَى، وَمَا يَقُولُ النَّاسُ فِيهَا فَقَالَ الْقَاسِمُ بْنُ مُحَمَّدٍ مَا أَدْرَكْتُ النَّاسَ إِلاَّ وَهُمْ عَلَى شُرُوطِهِمْ فِي أَمْوَالِهِمْ وَفِيمَا أُعْطُوا ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ وَعَلَى ذَلِكَ الأَمْرُ عِنْدَنَا أَنَّ الْعُمْرَى تَرْجِعُ إِلَى الَّذِي أَعْمَرَهَا إِذَا لَمْ يَقُلْ هِيَ لَكَ وَلِعَقِبِكَ ‏.‏\hadithno{1444}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me from Yahya ibn Said that Abd ar-Rahman ibn al-Qasim ibn Muhammad heard Makhul ad-Dimashqi ask al-Qasim ibn Muhammad about the life pension and what people said about it. Al- Qasim ibn Muhammad said, "I have only come upon people who keep to the conditions they make about their property and what they are given." Yahya said that he heard Malik say, "What is done in our community is that the life pension reverts to the one who makes it a life pension unless he says, 'It belongs to you and your posterity}}
\hadithdefcmd{malik}{1445}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، ‏.‏ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، وَرِثَ مِنْ حَفْصَةَ بِنْتِ عُمَرَ دَارَهَا قَالَ وَكَانَتْ حَفْصَةُ قَدْ أَسْكَنَتْ بِنْتَ زَيْدِ بْنِ الْخَطَّابِ مَا عَاشَتْ فَلَمَّا تُوُفِّيَتْ بِنْتُ زَيْدٍ قَبَضَ عَبْدُ اللَّهِ بْنُ عُمَرَ الْمَسْكَنَ وَرَأَى أَنَّهُ لَهُ ‏.‏\hadithno{1445}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Nafi that Abdullah ibn Umar inherited the house of Hafsa bint Umar. He said, "Hafsa gave lodging to the daughter of Zayd ibn al-Khattab for as long as she lived. When the daughter of Zayd died, Abdullah ibn Umar took possession of the dwelling and considered that it was his}}
\hadithdefcmd{malik}{1446}{حَدَّثَنِي مَالِكٌ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّهُ قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ عَنِ اللُّقَطَةِ ‏.‏ فَقَالَ ‏"‏ اعْرِفْ عِفَاصَهَا وَوِكَاءَهَا ثُمَّ عَرِّفْهَا سَنَةً فَإِنْ جَاءَ صَاحِبُهَا وَإِلاَّ فَشَأْنَكَ بِهَا ‏"‏ ‏.‏ قَالَ فَضَالَّةُ الْغَنَمِ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ هِيَ لَكَ أَوْ لأَخِيكَ أَوْ لِلذِّئْبِ ‏"‏ ‏.‏ قَالَ فَضَالَّةُ الإِبِلِ قَالَ ‏"‏ مَا لَكَ وَلَهَا مَعَهَا سِقَاؤُهَا وَحِذَاؤُهَا تَرِدُ الْمَاءَ وَتَأْكُلُ الشَّجَرَ حَتَّى يَلْقَاهَا رَبُّهَا ‏"‏ ‏.‏\hadithno{1446}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Rabia ibn Abi Abd ar-Rahman from Yazid, the mawla of al-Munbaith that Zayd ibn Khalid al-Juhani said, "A man came to the Messenger of Allah, may Allah bless him and grant him peace, and asked him about finds. He said, 'Memorize the characteristics of the object found, then publicise it for a year. If the owner comes, give it to him. If not, then it is your business.' He said, 'What about lost sheep, Messenger of Allah?' He said, 'They are yours, your brother's or the wolf's.' He said, 'And the lost camel?' He said, 'It's none of your concern. It has its water and its feet. It will reach water and eat trees until its owner finds it}}
\hadithdefcmd{malik}{1447}{وَحَدَّثَنِي مَالِكٌ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ مُعَاوِيَةَ بْنِ عَبْدِ اللَّهِ بْنِ بَدْرٍ الْجُهَنِيِّ، أَنَّ أَبَاهُ، أَخْبَرَهُ أَنَّهُ، نَزَلَ مَنْزِلَ قَوْمٍ بِطَرِيقِ الشَّامِ فَوَجَدَ صُرَّةً فِيهَا ثَمَانُونَ دِينَارًا فَذَكَرَهَا لِعُمَرَ بْنِ الْخَطَّابِ فَقَالَ لَهُ عُمَرُ عَرِّفْهَا عَلَى أَبْوَابِ الْمَسَاجِدِ وَاذْكُرْهَا لِكُلِّ مَنْ يَأْتِي مِنَ الشَّأْمِ سَنَةً فَإِذَا مَضَتِ السَّنَةُ فَشَأْنَكَ بِهَا ‏.‏\hadithno{1447}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Malik related to me from Ayyub ibn Musa from Muawiya ibn Abdullah ibn Badr al-Juhani that his father informed him that he stopped with a people on the way to Syria and he found a purse which had eighty dinars in it. He mentioned that to Umar ibn al-Khattab. Umar said to him, "Announce it at the doors of the mosques and mention it to everyone who comes from Syria for a year. When a year passes, it is your business}}
\hadithdefcmd{malik}{1448}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، أَنَّ رَجُلاً، وَجَدَ لُقَطَةً فَجَاءَ إِلَى عَبْدِ اللَّهِ بْنِ عُمَرَ فَقَالَ لَهُ إِنِّي وَجَدْتُ لُقَطَةً فَمَاذَا تَرَى فِيهَا فَقَالَ لَهُ عَبْدُ اللَّهِ بْنُ عُمَرَ عَرِّفْهَا ‏.‏ قَالَ قَدْ فَعَلْتُ ‏.‏ قَالَ زِدْ ‏.‏ قَالَ قَدْ فَعَلْتُ ‏.‏ فَقَالَ عَبْدُ اللَّهِ لاَ آمُرُكَ أَنْ تَأْكُلَهَا وَلَوْ شِئْتَ لَمْ تَأْخُذْهَا ‏.‏\hadithno{1448}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Nafi that a man found something and went to Abdullah ibn Umar and said to him, "I have found something. What do you think I should do about it?" Abdullah ibn Umar said to him, "Publicise it!" He said, "I have done so." He said, "Do it again." He said, "I have done so." Abdullah said, "I do not order you to use it. If you wished, you could have left it}}
\hadithdefcmd{malik}{1449}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ ثَابِتَ بْنَ الضَّحَّاكِ الأَنْصَارِيَّ، أَخْبَرَهُ ‏.‏ أَنَّهُ، وَجَدَ بَعِيرًا بِالْحَرَّةِ فَعَقَلَهُ ثُمَّ ذَكَرَهُ لِعُمَرَ بْنِ الْخَطَّابِ فَأَمَرَهُ عُمَرُ أَنْ يُعَرِّفَهُ ثَلاَثَ مَرَّاتٍ فَقَالَ لَهُ ثَابِتٌ إِنَّهُ قَدْ شَغَلَنِي عَنْ ضَيْعَتِي ‏.‏ فَقَالَ لَهُ عُمَرُ أَرْسِلْهُ حَيْثُ وَجَدْتَهُ ‏.‏\hadithno{1449}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya said that he heard Malik say, "What is done in our community about a slave who finds something and uses it before the term which is set for finds has been reached, and that is a year, is that it is against his person. Either his master gives the price of what his slave has used, or he surrenders his slave to them as compensation. If he withheld it until the term was reached which is set for finds and he used it, it is a debt against him which follows him and it is not against his person and there is nothing against his master in it." Malik related to me from Yahya ibn Said from Sulayman ibn Yasar that Thabit ibn ad-Dahhak al-Ansari told him that he had found a camel at Harra, so he hobbled it and mentioned it to Umar ibn al-Khattab and Umar ordered him to make it known three times. Thabit said to him, "That would distract me from the running of my estate." Umar said to him, "Then let it go where you found it}}
\hadithdefcmd{malik}{1450}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ وَهُوَ مُسْنِدٌ ظَهْرَهُ إِلَى الْكَعْبَةِ مَنْ أَخَذَ ضَالَّةً فَهُوَ ضَالٌّ ‏.‏\hadithno{1450}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Yahya ibn Said from Said ibn al-Musayyab that Umar ibn al-Khattab said while he was leaning his back against the Kaba, "Whoever takes a stray is astray}}
\hadithdefcmd{malik}{1451}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ سَمِعَ ابْنَ شِهَابٍ، يَقُولُ كَانَتْ ضَوَالُّ الإِبِلِ فِي زَمَانِ عُمَرَ بْنِ الْخَطَّابِ إِبِلاً مُؤَبَّلَةً تَنَاتَجُ لاَ يَمَسُّهَا أَحَدٌ حَتَّى إِذَا كَانَ زَمَانُ عُثْمَانَ بْنِ عَفَّانَ أَمَرَ بِتَعْرِيفِهَا ثُمَّ تُبَاعُ فَإِذَا جَاءَ صَاحِبُهَا أُعْطِيَ ثَمَنَهَا ‏.‏\hadithno{1451}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me that he heard Ibn Shihab say, "The stray camels in the time of Umar ibn al-Khattab were numerous and left alone. No one touched them until the time of Uthman ibn Affan. He ordered that they be publicised and then sold, and if the owner came afterwards, he was given their price}}
\hadithdefcmd{malik}{1452}{حَدَّثَنِي مَالِكٌ، عَنْ سَعِيدِ بْنِ عَمْرِو بْنِ شُرَحْبِيلَ بْنِ سَعِيدِ بْنِ سَعْدِ بْنِ عُبَادَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّهُ قَالَ خَرَجَ سَعْدُ بْنُ عُبَادَةَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ مَغَازِيهِ فَحَضَرَتْ أُمَّهُ الْوَفَاةُ بِالْمَدِينَةِ فَقِيلَ لَهَا أَوْصِي ‏.‏ فَقَالَتْ فِيمَ أُوصِي إِنَّمَا الْمَالُ مَالُ سَعْدٍ ‏.‏ فَتُوُفِّيَتْ قَبْلَ أَنْ يَقْدَمَ سَعْدٌ فَلَمَّا قَدِمَ سَعْدُ بْنُ عُبَادَةَ ذُكِرَ ذَلِكَ لَهُ فَقَالَ سَعْدٌ\hadithno{1452}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Malik related to me from Said ibn Amr Shurahbil ibn Said ibn Sad ibn Ubada from his father that his father said, ''Sad ibn Ubada went out with the Messenger of Allah, may Allah bless him and grant him peace, in one of his raids and his mother was dying in Madina. Someone said to her, 'Leave a testament.' She said, 'In what shall I leave a testament? The property is Sad's property.' Then she died before Sad returned. When Sad ibn Ubada returned, that was mentioned to him. Sad said, 'Messenger of Allah! Will it help her if I give sadaqa for her?' The Messenger of Allah, may Allah bless him and grant him peace, said, 'Yes' Sad said, 'Such-and-such a garden is sadaqa for her,' naming the garden}}
\hadithdefcmd{malik}{1453}{وَحَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَجُلاً قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّ أُمِّي افْتُلِتَتْ نَفْسُهَا وَأُرَاهَا لَوْ تَكَلَّمَتْ تَصَدَّقَتْ أَفَأَتَصَدَّقُ عَنْهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَعَمْ ‏"‏ ‏.‏\hadithno{1453}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Hisham ibn Urwa from his father from A'isha, the wife of the Prophet, may Allah bless him and grant him peace, that a man said to the Messenger of Allah, may Allah bless him and grant him peace, "My mother died suddenly, and I think that had she spoken, she would have given sadaqa. Shall I give sadaqa for her?" The Messenger of Allah, may Allah bless him and grant him peace, said, "Yes}}
\hadithdefcmd{malik}{1454}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ رَجُلاً، مِنَ الأَنْصَارِ مِنْ بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ تَصَدَّقَ عَلَى أَبَوَيْهِ بِصَدَقَةٍ فَهَلَكَا فَوَرِثَ ابْنُهُمَا الْمَالَ وَهُوَ نَخْلٌ فَسَأَلَ عَنْ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ قَدْ أُجِرْتَ فِي صَدَقَتِكَ وَخُذْهَا بِمِيرَاثِكَ ‏"‏ ‏.‏\hadithno{1454}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Malik related to me that he heard that a man of the Ansar from the tribe of Banu al-Harith ibn al-Khazraj, gave sadaqa to his parents and then they died. Their son inherited the property he had given them and it was palm-trees. He asked the Messenger of Allah, may Allah bless him and grant him peace, about it and he said, "You are rewarded for your sadaqa, and take it as your inheritance}}
