% Auto-generated chapter 26 for malik
% Hadiths in this chapter: 7

\hadithdefcmd{malik}{1067}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ رَجُلٍ، مِنْ بَنِي ضَمْرَةَ عَنْ أَبِيهِ، أَنَّهُ قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْعَقِيقَةِ فَقَالَ ‏"‏ لاَ أُحِبُّ الْعُقُوقَ ‏"‏ ‏.‏ وَكَأَنَّهُ إِنَّمَا كَرِهَ الاِسْمَ وَقَالَ ‏"‏ مَنْ وُلِدَ لَهُ وَلَدٌ فَأَحَبَّ أَنْ يَنْسُكَ عَنْ وَلَدِهِ فَلْيَفْعَلْ ‏"‏ ‏.‏\hadithno{1067}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that the best of what he had heard about a man who is forced by necessity to eat carrion is that he ate it until he was full and then he took provision from it. If he found something which would enable him to dispense with it, he threw it away. Malik when asked whether or not a man who had been forced by necessity to eat carrion, should eat it when he also found the fruit, crops or sheep of a people in that place, answered, "If he thinks that the owners of the fruit, crops, or sheep will believe his necessity so that he will not be deemed a thief and have his hand cut off, then I think that he should eat from whatever he finds that which will remove his hunger but he should not carry any of it away. I prefer that he does that than that he eat carrion. If he fears that he will not be believed, and will be deemed a thief for what he has taken, then I think that it is better for him to eat the carrion, and he has leeway to eat carrion in this respect. Even so, I fear that someone who is not forced by necessity to eat carrion might exceed the limits out of a desire to consume other peoples' property, crops or fruit." Malik said, "That is the best of what I have heard." Yahya related to me from Zayd ibn Aslam from a man of the Banu Damra that his father said, "The Messenger of Allah, may Allah bless him and grant him peace, was asked about the Aqiqa. He said, 'I do not like disobedience (uquq),' as if he disliked the name. He said, 'If anyone has a child born to him, and wants to sacrifice for his child, then let him do it}}
\hadithdefcmd{malik}{1068}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، أَنَّهُ قَالَ وَزَنَتْ فَاطِمَةُ بِنْتُ رَسُولِ اللَّهِ صلى الله عليه وسلم شَعَرَ حَسَنٍ وَحُسَيْنٍ وَزَيْنَبَ وَأُمِّ كُلْثُومٍ فَتَصَدَّقَتْ بِزِنَةِ ذَلِكَ فِضَّةً ‏.‏\hadithno{1068}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Jafar ibn Muhammad that his father said, "Fatima, the daughter of the Messenger of Allah, may Allah bless him and grant him peace, weighed the hair of Hasan, Husayn, Zaynab and Umm Kulthum, and gave away in sadaqa an equivalent weight of silver}}
\hadithdefcmd{malik}{1069}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ مُحَمَّدِ بْنِ عَلِيِّ بْنِ الْحُسَيْنِ، أَنَّهُ قَالَ وَزَنَتْ فَاطِمَةُ بِنْتُ رَسُولِ اللَّهِ صلى الله عليه وسلم شَعَرَ حَسَنٍ وَحُسَيْنٍ فَتَصَدَّقَتْ بِزِنَتِهِ فِضَّةً ‏.‏\hadithno{1069}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Rabia ibn Abi Abd ar-Rahman that Muhammad ibn Ali ibn al-Husayn said, "Fatima, the daughter of the Messenger of Allah, may Allah bless him and grant him peace, weighed the hair of Hasan and Husayn, and gave away in sadaqa the equivalent weight in silver}}
\hadithdefcmd{malik}{1070}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، لَمْ يَكُنْ يَسْأَلُهُ أَحَدٌ مِنْ أَهْلِهِ عَقِيقَةً إِلاَّ أَعْطَاهُ إِيَّاهَا وَكَانَ يَعُقُّ عَنْ وَلَدِهِ بِشَاةٍ شَاةٍ عَنِ الذُّكُورِ وَالإِنَاثِ ‏.‏\hadithno{1070}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that if any of Abdullah ibn Umar's family asked him for an aqiqa, he would give it to them. He gave a sheep as aqiqa for both his male and female children}}
\hadithdefcmd{malik}{1071}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، أَنَّهُ قَالَ سَمِعْتُ أَبِي يَسْتَحِبُّ الْعَقِيقَةَ، وَلَوْ بِعُصْفُورٍ ‏.‏\hadithno{1071}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Rabia ibn Abi Abd ar-Rahman that Muhammad ibn Ibrahim ibn al-Harith at-Taymi said, "I heard my father say that the aqiqa was desirable, even if it was only a sparrow}}
\hadithdefcmd{malik}{1072}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّهُ عُقَّ عَنْ حَسَنٍ، وَحُسَيْنٍ، ابْنَىْ عَلِيِّ بْنِ أَبِي طَالِبٍ ‏.‏\hadithno{1072}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik that he heard that there had been an aqiqa for Hasan and Husayn, the sons of Ali ibn Abi Talib}}
\hadithdefcmd{malik}{1073}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّ أَبَاهُ، عُرْوَةَ بْنَ الزُّبَيْرِ كَانَ يَعُقُّ عَنْ بَنِيهِ الذُّكُورِ، وَالإِنَاثِ، بِشَاةٍ شَاةٍ ‏.‏ قَالَ مَالِكٌ الأَمْرُ عِنْدَنَا فِي الْعَقِيقَةِ أَنَّ مَنْ عَقَّ فَإِنَّمَا يَعُقُّ عَنْ وَلَدِهِ بِشَاةٍ شَاةٍ الذُّكُورِ وَالإِنَاثِ وَلَيْسَتِ الْعَقِيقَةُ بِوَاجِبَةٍ وَلَكِنَّهَا يُسْتَحَبُّ الْعَمَلُ بِهَا وَهِيَ مِنَ الأَمْرِ الَّذِي لَمْ يَزَلْ عَلَيْهِ النَّاسُ عِنْدَنَا فَمَنْ عَقَّ عَنْ وَلَدِهِ فَإِنَّمَا هِيَ بِمَنْزِلَةِ النُّسُكِ وَالضَّحَايَا لاَ يَجُوزُ فِيهَا عَوْرَاءُ وَلاَ عَجْفَاءُ وَلاَ مَكْسُورَةٌ وَلاَ مَرِيضَةٌ وَلاَ يُبَاعُ مِنْ لَحْمِهَا شَىْءٌ وَلاَ جِلْدُهَا وَيُكْسَرُ عِظَامُهَا وَيَأْكُلُ أَهْلُهَا مِنْ لَحْمِهَا وَيَتَصَدَّقُونَ مِنْهَا وَلاَ يُمَسُّ الصَّبِيُّ بِشَىْءٍ مِنْ دَمِهَا ‏.‏\hadithno{1073}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father, Urwa ibn az-Zubayr made an aqiqa for his male and female children of a sheep each. Malik said, "What we do about the aqiqa is that if someone makes an aqiqa for his children, he gives a sheep for both male and female. The aqiqa is not obligatory but it is desirable to do it, and people continue to come to us about it. If someone makes an aqiqa for his children, the same rules apply as with all sacrificial animals - one-eyed, emaciated, injured, or sick animals must not be used, and neither the meat or the skin is to be sold. The bones are broken and the family eat the meat and give some of it away as sadaqa. The child is not smeared with any of the blood}}
