% Auto-generated chapter 9 for nasai
% Hadiths in this chapter: 35

\hadithdefcmd{nasai}{742}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، عَنْ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ فَصَلَّى نَحْوَ بَيْتِ الْمَقْدِسِ سِتَّةَ عَشَرَ شَهْرًا ثُمَّ وُجِّهَ إِلَى الْكَعْبَةِ فَمَرَّ رَجُلٌ قَدْ كَانَ صَلَّى مَعَ النَّبِيِّ صلى الله عليه وسلم عَلَى قَوْمٍ مِنَ الأَنْصَارِ فَقَالَ أَشْهَدُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ وُجِّهَ إِلَى الْكَعْبَةِ ‏.‏ فَانْحَرَفُوا إِلَى الْكَعْبَةِ ‏.‏\hadithno{742}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Al Bara bin Azib:Al Bara bin Azib said: The messenger of Allah (peace be upon him) came to Al-Madinah and prayed toward Bait-al-Maqdis for sixteen months, then he was commanded to pray toward the Ka'bah. A man who had prayed with the prophet (peace be upon him)passed by some of the Ansar and said: "I bear witness that the messenger of Allah (peace be upon him) has been commanded to face toward the Ka'bah. So they turned to face the Ka'bah}}
\hadithdefcmd{nasai}{743}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي عَلَى رَاحِلَتِهِ فِي السَّفَرِ حَيْثُمَا تَوَجَّهَتْ بِهِ ‏.‏ قَالَ مَالِكٌ قَالَ عَبْدُ اللَّهِ بْنُ دِينَارٍ وَكَانَ ابْنُ عُمَرَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{743}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Umar said:"The messenger of Allah (peace be upon him) used to pray atop his mount while travelling, facing whatever direction it was facing." (One of the narrators) Malik said: "Abdullah bin Dinar said: and Ibn Umar used to do likewise}}
\hadithdefcmd{nasai}{744}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي عَلَى الرَّاحِلَةِ قِبَلَ أَىِّ وَجْهٍ تَوَجَّهُ بِهِ وَيُوتِرُ عَلَيْهَا غَيْرَ أَنَّهُ لاَ يُصَلِّي عَلَيْهَا الْمَكْتُوبَةَ ‏.‏\hadithno{744}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abdullah said:"The messenger of Allah (peace be upon him) used to pray atop his mount while traveling, facing whatever direction it was facing, and he would pray witr atop it, but he did not pray the prescribed prayers atop it}}
\hadithdefcmd{nasai}{745}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ بَيْنَمَا النَّاسُ بِقُبَاءٍ فِي صَلاَةِ الصُّبْحِ جَاءَهُمْ آتٍ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أُنْزِلَ عَلَيْهِ اللَّيْلَةَ قُرْآنٌ وَقَدْ أُمِرَ أَنْ يَسْتَقْبِلَ الْقِبْلَةَ ‏.‏ فَاسْتَقْبَلُوهَا وَكَانَتْ وُجُوهُهُمْ إِلَى الشَّامِ فَاسْتَدَارُوا إِلَى الْكَعْبَةِ ‏.‏\hadithno{745}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Umar said:"While the people were in Quba praying Subh prayer, someone came to them and said that revelation had come to Messenger of Allah(ﷺ) the night before, and he had been commanded to face Ka'bah. So face toward it. They had been facing toward Ash-Sham, so they turned to face toward Ka'bah}}
\hadithdefcmd{nasai}{746}{أَخْبَرَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، عَنْ أَبِي الأَسْوَدِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ عَنْ سُتْرَةِ الْمُصَلِّي فَقَالَ ‏ "‏ مِثْلُ مُؤْخِرَةِ الرَّحْلِ ‏"‏ ‏.‏\hadithno{746}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Aisha(ra) said:"The messenger of Allah(ﷺ) was asked during the campaign of Tabuk about the Sutra of one who is praying. He said: "Something as high as the back of a camel saddle}}
\hadithdefcmd{nasai}{747}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَنْبَأَنَا نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ كَانَ يَرْكُزُ الْحَرْبَةَ ثُمَّ يُصَلِّي إِلَيْهَا ‏.‏\hadithno{747}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn Umar:It was narrated from Ibn Umar concerning the Messenger of Allah (ﷺ) he said: "He used to set up a short spear then pray facing toward it}}
\hadithdefcmd{nasai}{748}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا صَلَّى أَحَدُكُمْ إِلَى سُتْرَةٍ فَلْيَدْنُ مِنْهَا لاَ يَقْطَعُ الشَّيْطَانُ عَلَيْهِ صَلاَتَهُ ‏"‏ ‏.‏\hadithno{748}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Sahl bin Abi Hathmah said:"When anyone of you prays toward a Sutra, let him get close to it and not allow the Shaitan to sever his prayer for him}}
\hadithdefcmd{nasai}{749}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ الْكَعْبَةَ هُوَ وَأُسَامَةُ بْنُ زَيْدٍ وَبِلاَلٌ وَعُثْمَانُ بْنُ طَلْحَةَ الْحَجَبِيُّ فَأَغْلَقَهَا عَلَيْهِ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَسَأَلْتُ بِلاَلاً حِينَ خَرَجَ مَاذَا صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ جَعَلَ عَمُودًا عَنْ يَسَارِهِ وَعَمُودَيْنِ عَنْ يَمِينِهِ وَثَلاَثَةَ أَعْمِدَةٍ وَرَاءَهُ - وَكَانَ الْبَيْتُ يَوْمَئِذٍ عَلَى سِتَّةِ أَعْمِدَةٍ - ثُمَّ صَلَّى وَجَعَلَ بَيْنَهُ وَبَيْنَ الْجِدَارِ نَحْوًا مِنْ ثَلاَثَةِ أَذْرُعٍ ‏.‏\hadithno{749}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abdullah bin Umar:It was narrated from Abdullah bin Umar that the Messenger of Allah (ﷺ) entered the Ka'bah with Usamah bin Zaid, Bilal and Uthman bin Talha al Hajabi, and locked the door behind him. Abdullah bin Umar said: "I asked Bilal when he came out: " What did the Messenger of Allah (ﷺ) do?" He said: "He stood with one pillar to his left, two pillars to his right and three pillars behind him - at that time the House stood on six pillars - and he prayed with approximately three forearm's length between him and the wall}}
\hadithdefcmd{nasai}{750}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ أَنْبَأَنَا يَزِيدُ، قَالَ حَدَّثَنَا يُونُسُ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا كَانَ أَحَدُكُمْ قَائِمًا يُصَلِّي فَإِنَّهُ يَسْتُرُهُ إِذَا كَانَ بَيْنَ يَدَيْهِ مِثْلُ آخِرَةِ الرَّحْلِ فَإِنْ لَمْ يَكُنْ بَيْنَ يَدَيْهِ مِثْلُ آخِرَةِ الرَّحْلِ فَإِنَّهُ يَقْطَعُ صَلاَتَهُ الْمَرْأَةُ وَالْحِمَارُ وَالْكَلْبُ الأَسْوَدُ ‏"‏ ‏.‏ قُلْتُ مَا بَالُ الأَسْوَدِ مِنَ الأَصْفَرِ مِنَ الأَحْمَرِ فَقَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم كَمَا سَأَلْتَنِي فَقَالَ ‏"‏ الْكَلْبُ الأَسْوَدُ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{750}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Dharr said:The messenger of Allah(ﷺ) said: "When anyone of you stands to pray, then he is screened if he has in front of him something as high as the back of a camel saddle. If he does not have something as high as the back of a camel saddle in front of him, then his prayer is nullified by a woman, a donkey or a black dog." I (one of the narrators)said: "What is the difference between a black dog, a yellow one and a red one?" He said: I asked the Messenger of Allah (ﷺ) just like you and he said:"The black dog is a shaitan}}
\hadithdefcmd{nasai}{751}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنِي شُعْبَةُ، وَهِشَامٌ، عَنْ قَتَادَةَ، قَالَ قُلْتُ لِجَابِرِ بْنِ زَيْدٍ مَا يَقْطَعُ الصَّلاَةَ قَالَ كَانَ ابْنُ عَبَّاسٍ يَقُولُ الْمَرْأَةُ الْحَائِضُ وَالْكَلْبُ ‏.‏ قَالَ يَحْيَى رَفَعَهُ شُعْبَةُ ‏.‏\hadithno{751}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Qatadah said:"I aid to Jabir bin Zaid: "What invalidates prayer?" He said: "Ibn Abbas used to say: A menstruating woman and a dog." (One of the narrators)Yahya said: "Shubah said it was a marfu report}}
\hadithdefcmd{nasai}{752}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، قَالَ حَدَّثَنَا الزُّهْرِيُّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جِئْتُ أَنَا وَالْفَضْلُ، عَلَى أَتَانٍ لَنَا وَرَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِالنَّاسِ بِعَرَفَةَ ثُمَّ ذَكَرَ كَلِمَةً مَعْنَاهَا فَمَرَرْنَا عَلَى بَعْضِ الصَّفِّ فَنَزَلْنَا وَتَرَكْنَاهَا تَرْتَعُ فَلَمْ يَقُلْ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم شَيْئًا ‏.‏\hadithno{752}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Abbas said:"Al-Fadl and I came riding a female donkey of ours, and the Messenger of Allah(ﷺ) was leading the people at Arafat." Then he said something to that effect. "We passed by part of the row, and then we dismounted and left the donkey grazing, and the Messenger of Allah(ﷺ)did not say anything to us}}
\hadithdefcmd{nasai}{753}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي مُحَمَّدُ بْنُ عُمَرَ بْنِ عَلِيٍّ، عَنْ عَبَّاسِ بْنِ عُبَيْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنِ الْفَضْلِ بْنِ الْعَبَّاسِ، قَالَ زَارَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَبَّاسًا فِي بَادِيَةٍ لَنَا وَلَنَا كُلَيْبَةٌ وَحِمَارَةٌ تَرْعَى فَصَلَّى النَّبِيُّ صلى الله عليه وسلم الْعَصْرَ وَهُمَا بَيْنَ يَدَيْهِ فَلَمْ يُزْجَرَا وَلَمْ يُؤَخَّرَا ‏.‏\hadithno{753}\hadithgrade{Abu Ghuddah: Munkar Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Al-Fadl bin 'Abbas said:"The Messenger of Allah(ﷺ)visited Al Abbas in some land of ours outside the city, and we had a small dog and a donkey which was grazing. The Messenger of Allah(ﷺ) prayed Asr and they were in front of him, and they were not shooed away or pushed away}}
\hadithdefcmd{nasai}{754}{أَخْبَرَنَا أَبُو الأَشْعَثِ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، أَنَّ الْحَكَمَ، أَخْبَرَهُ قَالَ سَمِعْتُ يَحْيَى بْنَ الْجَزَّارِ، يُحَدِّثُ عَنْ صُهَيْبٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يُحَدِّثُ أَنَّهُ مَرَّ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم هُوَ وَغُلاَمٌ مِنْ بَنِي هَاشِمٍ عَلَى حِمَارٍ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يُصَلِّي فَنَزَلُوا وَدَخَلُوا مَعَهُ فَصَلَّوْا وَلَمْ يَنْصَرِفْ فَجَاءَتْ جَارِيَتَانِ تَسْعَيَانِ مِنْ بَنِي عَبْدِ الْمُطَّلِبِ فَأَخَذَتَا بِرُكْبَتَيْهِ فَفَرَعَ بَيْنَهُمَا وَلَمْ يَنْصَرِفْ ‏.‏\hadithno{754}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Suhaib said:"I heard Ibn Abbas narrate that he passed in front of the Messenger of Allah (ﷺ), he and a young boy of Banu Hashim, riding a donkey in front of the Messenger of Allah(ﷺ) when he was praying. Then they dismounted and joined the prayer, and he did not stop praying. Then two young girls of Banu Abdul-Muttalib started running around and grabbing him by the knees. He separated them but he did not stop praying}}
\hadithdefcmd{nasai}{755}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كُنْتُ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يُصَلِّي فَإِذَا أَرَدْتُ أَنْ أَقُومَ كَرِهْتُ أَنْ أَقُومَ - فَأَمُرَّ بَيْنَ يَدَيْهِ - انْسَلَلْتُ انْسِلاَلاً ‏.‏\hadithno{755}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aishah, may Allah be pleased with her, said:"I was in front of the Messenger of Allah (ﷺ) when he was praying, and when I wanted to leave I did not want to get up and pass in front of him, so I just slipped away slowly and quietly}}
\hadithdefcmd{nasai}{756}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، أَنَّ زَيْدَ بْنَ خَالِدٍ، أَرْسَلَهُ إِلَى أَبِي جُهَيْمٍ يَسْأَلُهُ مَاذَا سَمِعَ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي الْمَارِّ بَيْنَ يَدَىِ الْمُصَلِّي فَقَالَ أَبُو جُهَيْمٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ يَعْلَمُ الْمَارُّ بَيْنَ يَدَىِ الْمُصَلِّي مَاذَا عَلَيْهِ لَكَانَ أَنْ يَقِفَ أَرْبَعِينَ خَيْرًا لَهُ مِنْ أَنْ يَمُرَّ بَيْنَ يَدَيْهِ ‏"‏ ‏.‏\hadithno{756}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Busr bin Saeed:It was narrated from Busr bin Sa'eed said that Zaid bin Khalid sent him to Abu Juhaim to ask him what he had heard the Messenger of Allah (ﷺ) say about one who passes in front of a person who is praying? Abu Juhaim said: "The Messenger of Allah(ﷺ)said: "If the one who passes in front of a person who is praying knew what (burden of sin) there is on him, standing for forty would be better for him than passing in front of him}}
\hadithdefcmd{nasai}{757}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانَ أَحَدُكُمْ يُصَلِّي فَلاَ يَدَعْ أَحَدًا أَنْ يَمُرَّ بَيْنَ يَدَيْهِ فَإِنْ أَبَى فَلْيُقَاتِلْهُ ‏"‏ ‏.‏\hadithno{757}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Saeed:It was narrated from Abu Saeed that the Messenger of Allah(ﷺ) said: " If anyone of you is praying, he should not let anyone pass in front of him, and if he insists (on passing) then let him fight him}}
\hadithdefcmd{nasai}{758}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عِيسَى بْنُ يُونُسَ، قَالَ حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَبْدِ الْعَزِيزِ بْنِ جُرَيْجٍ، عَنْ كَثِيرِ بْنِ كَثِيرٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم طَافَ بِالْبَيْتِ سَبْعًا ثُمَّ صَلَّى رَكْعَتَيْنِ بِحِذَائِهِ فِي حَاشِيَةِ الْمَقَامِ وَلَيْسَ بَيْنَهُ وَبَيْنَ الطُّوَّافِ أَحَدٌ ‏.‏\hadithno{758}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Kathir bin Kathir:It was narrated from Kathir bin Kathir, from his father, that his grandfather said: "I saw the Messenger of Allah (ﷺ) circumambulate the House seven times, then he prayed two Rak'ahs at the edge of the Maqam, and there was nothing between him and the people who were performing Tawaf}}
\hadithdefcmd{nasai}{759}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ وَأَنَا رَاقِدَةٌ مُعْتَرِضَةٌ بَيْنَهُ وَبَيْنَ الْقِبْلَةِ عَلَى فِرَاشِهِ فَإِذَا أَرَادَ أَنْ يُوتِرَ أَيْقَظَنِي فَأَوْتَرْتُ ‏.‏\hadithno{759}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aisha said:"The Messenger of Allah(ﷺ)used to pray at night while I was lying down sleeping between him and the Qibla on his bed. When he wanted to pray witr he would wake me up and I would pray witr}}
\hadithdefcmd{nasai}{760}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، عَنِ ابْنِ جَابِرٍ، عَنْ بُسْرِ بْنِ عُبَيْدِ اللَّهِ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، عَنْ أَبِي مَرْثَدٍ الْغَنَوِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُصَلُّوا إِلَى الْقُبُورِ وَلاَ تَجْلِسُوا عَلَيْهَا ‏"‏ ‏.‏\hadithno{760}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Marthad al Ghanawi said:"The Messenger of Allah(ﷺ)said: 'Do not pray toward graves and do not sit on them}}
\hadithdefcmd{nasai}{761}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، قَالَ سَمِعْتُ الْقَاسِمَ، يُحَدِّثُ عَنْ عَائِشَةَ، قَالَتْ كَانَ فِي بَيْتِي ثَوْبٌ فِيهِ تَصَاوِيرُ فَجَعَلْتُهُ إِلَى سَهْوَةٍ فِي الْبَيْتِ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي إِلَيْهِ ثُمَّ قَالَ ‏ "‏ يَا عَائِشَةُ أَخِّرِيهِ عَنِّي ‏"‏ ‏.‏ فَنَزَعْتُهُ فَجَعَلْتُهُ وَسَائِدَ ‏.‏\hadithno{761}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Aisha said:"In my house there was a cloth on which there were images, which I covered a closet which is in the house, and the Messenger of Allah (ﷺ) used to pray toward it. Then he said: '0 Aisha, take it away from me.' So I removed it and made pillows out of it}}
\hadithdefcmd{nasai}{762}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم حَصِيرَةٌ يَبْسُطُهَا بِالنَّهَارِ وَيَحْتَجِرُهَا بِاللَّيْلِ فَيُصَلِّي فِيهَا فَفَطِنَ لَهُ النَّاسُ فَصَلَّوْا بِصَلاَتِهِ وَبَيْنَهُ وَبَيْنَهُمُ الْحَصِيرَةُ فَقَالَ ‏ "‏ اكْلَفُوا مِنَ الْعَمَلِ مَا تُطِيقُونَ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ لاَ يَمَلُّ حَتَّى تَمَلُّوا وَإِنَّ أَحَبَّ الأَعْمَالِ إِلَى اللَّهِ عَزَّ وَجَلَّ أَدْوَمُهُ وَإِنْ قَلَّ ‏"‏ ‏.‏ ثُمَّ تَرَكَ مُصَلاَّهُ ذَلِكَ فَمَا عَادَ لَهُ حَتَّى قَبَضَهُ اللَّهُ عَزَّ وَجَلَّ وَكَانَ إِذَا عَمِلَ عَمَلاً أَثْبَتَهُ ‏.‏\hadithno{762}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) had a mat which he would spread in the day and make into a small booth at night to pray in it. The people found out about that and they prayed when he prayed, with the mat in between him and them. He said: 'Do as much of good deeds as you can, for Allah does not get tired (of giving reward) until you get tired. And the most beloved of deeds to Allah are those that are continuous, even if they are few.' Then he stopped that prayer and did not return to it until Allah took him (in death), and if he started to do something he would persist in it}}
\hadithdefcmd{nasai}{763}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ سَائِلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّلاَةِ فِي الثَّوْبِ الْوَاحِدِ فَقَالَ ‏ "‏ أَوَلِكُلِّكُمْ ثَوْبَانِ ‏"‏ ‏.‏\hadithno{763}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that someone asked the Messenger of Allah(ﷺ) about praying in a single garment, and he said:"Does everyone of you have two garments?}}
\hadithdefcmd{nasai}{764}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِي ثَوْبٍ وَاحِدٍ فِي بَيْتِ أُمِّ سَلَمَةَ وَاضِعًا طَرَفَيْهِ عَلَى عَاتِقَيْهِ ‏.‏\hadithno{764}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Umar bin Abi Salamah:It was narrated from Umar bin Abi Salamah that he saw Messenger of Allah(ﷺ)praying in a single garment in the house of Umm Salamah, putting the ends of it on his shoulders}}
\hadithdefcmd{nasai}{765}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا الْعَطَّافُ، عَنْ مُوسَى بْنِ إِبْرَاهِيمَ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي لأَكُونُ فِي الصَّيْدِ وَلَيْسَ عَلَىَّ إِلاَّ الْقَمِيصُ أَفَأُصَلِّي فِيهِ قَالَ ‏ "‏ وَزُرَّهُ عَلَيْكَ وَلَوْ بِشَوْكَةٍ ‏"‏ ‏.‏\hadithno{765}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Salamah bin Al-Akwa said:" I said: 'O Messenger of Allah(ﷺ), I go hunting wearing nothing but a single shirt. Can I pray in it?' He said: 'Fasten it to yourself even with a thorn}}
\hadithdefcmd{nasai}{766}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ كَانَ رِجَالٌ يُصَلُّونَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَاقِدِينَ أُزْرَهُمْ كَهَيْئَةِ الصِّبْيَانِ فَقِيلَ لِلنِّسَاءِ لاَ تَرْفَعْنَ رُءُوسَكُنَّ حَتَّى يَسْتَوِيَ الرِّجَالُ جُلُوسًا ‏.‏\hadithno{766}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Sahl bin Sa'd said:"Some men used to pray with Messenger of Allah(ﷺ) tying their lower garments tight like children, it was said to the women: 'Do not raise your heads until the men have sat up completely}}
\hadithdefcmd{nasai}{767}{أَخْبَرَنَا شُعَيْبُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَنْبَأَنَا عَاصِمٌ، عَنْ عَمْرِو بْنِ سَلِمَةَ، قَالَ لَمَّا رَجَعَ قَوْمِي مِنْ عِنْدِ النَّبِيِّ صلى الله عليه وسلم قَالُوا إِنَّهُ قَالَ ‏ "‏ لِيَؤُمَّكُمْ أَكْثَرُكُمْ قِرَاءَةً لِلْقُرْآنِ ‏"‏ ‏.‏ قَالَ فَدَعَوْنِي فَعَلَّمُونِي الرُّكُوعَ وَالسُّجُودَ فَكُنْتُ أُصَلِّي بِهِمْ وَكَانَتْ عَلَىَّ بُرْدَةٌ مَفْتُوقَةٌ فَكَانُوا يَقُولُونَ لأَبِي أَلاَ تُغَطِّي عَنَّا اسْتَ ابْنِكَ ‏.‏\hadithno{767}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Amr bin Salamah said:"When my people came back from the Prophet (ﷺ)they said that he had said: 'Let the one who recites the Quran most lead you in prayer.' So they called me and taught me how to bow and prostrate, and I used to lead them in prayer, wearing a torn cloak, and they used to say to my father: 'Will you not conceal your son's backside from us?}}
\hadithdefcmd{nasai}{768}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا وَكِيعٌ، قَالَ حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِاللَّيْلِ وَأَنَا إِلَى جَنْبِهِ وَأَنَا حَائِضٌ وَعَلَىَّ مِرْطٌ بَعْضُهُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{768}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Aisha said:"The Messenger of Allah(ﷺ)used to pray at night when I was beside him and I was menstruating, and there was a garment over me, part of which was over Messenger of Allah(ﷺ)}}
\hadithdefcmd{nasai}{769}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُصَلِّيَنَّ أَحَدُكُمْ فِي الثَّوْبِ الْوَاحِدِ لَيْسَ عَلَى عَاتِقِهِ مِنْهُ شَىْءٌ ‏"‏ ‏.‏\hadithno{769}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Huraira said:"The Messenger of Allah(ﷺ)said: 'No one of you should pray in a single garment with no part of it on his shoulder}}
\hadithdefcmd{nasai}{770}{أَخْبَرَنَا قُتَيْبَةُ، وَعِيسَى بْنُ حَمَّادٍ، زُغْبَةُ عَنِ اللَّيْثِ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ أُهْدِيَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَرُّوجُ حَرِيرٍ فَلَبِسَهُ ثُمَّ صَلَّى فِيهِ ثُمَّ انْصَرَفَ فَنَزَعَهُ نَزْعًا شَدِيدًا كَالْكَارِهِ لَهُ ثُمَّ قَالَ ‏ "‏ لاَ يَنْبَغِي هَذَا لِلْمُتَّقِينَ ‏"‏ ‏.‏\hadithno{770}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Uqbah bin Amir said:"A silken Farruj was presented to the Messenger of Allah (ﷺ) and he put it on and offered the prayer in it, then when he had finished the prayer he tore it off as if he disliked it and said:'This is not befitting for those who have Taqwa}}
\hadithdefcmd{nasai}{771}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، - وَاللَّفْظُ لَهُ - عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى فِي خَمِيصَةٍ لَهَا أَعْلاَمٌ ثُمَّ قَالَ ‏ "‏ شَغَلَتْنِي أَعْلاَمُ هَذِهِ اذْهَبُوا بِهَا إِلَى أَبِي جَهْمٍ وَائْتُونِي بِأَنْبِجَانِيِّهِ ‏"‏ ‏.‏\hadithno{771}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Aisha (ra) that the Messenger of Allah(ﷺ)prayed in a khamisah that had markings, then he said:"These markings distracted me. Take it to Abu Jahm and bring me his Anbijani (a woolen garment with no markings)}}
\hadithdefcmd{nasai}{772}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ فِي حُلَّةٍ حَمْرَاءَ فَرَكَزَ عَنَزَةً فَصَلَّى إِلَيْهَا يَمُرُّ مِنْ وَرَائِهَا الْكَلْبُ وَالْمَرْأَةُ وَالْحِمَارُ ‏.‏\hadithno{772}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Awn bin Abi Juhaifah, from his father that, the Messenger of Allah(ﷺ) went out in a red Hullah, and he set up a short spear (Anazah) and prayed facing toward it, while dogs, women and donkeys were passing beyond it}}
\hadithdefcmd{nasai}{773}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا جَابِرُ بْنُ صُبْحٍ، قَالَ سَمِعْتُ خِلاَسَ بْنَ عَمْرٍو، يَقُولُ سَمِعْتُ عَائِشَةَ، تَقُولُ كُنْتُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم أَبُو الْقَاسِمِ فِي الشِّعَارِ الْوَاحِدِ وَأَنَا حَائِضٌ، طَامِثٌ فَإِنْ أَصَابَهُ مِنِّي شَىْءٌ غَسَلَ مَا أَصَابَهُ لَمْ يَعْدُهُ إِلَى غَيْرِهِ وَصَلَّى فِيهِ ثُمَّ يَعُودُ مَعِي فَإِنْ أَصَابَهُ مِنِّي شَىْءٌ فَعَلَ مِثْلَ ذَلِكَ لَمْ يَعْدُهُ إِلَى غَيْرِهِ ‏.‏\hadithno{773}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Khilas bin 'Amr said:"I heard Aisha (ra) say: 'The Messenger of Allah (ﷺ), Abii Al-Qbim, and I were beneath a single blanket, and I was menstruating. If something got on him from me, he would wash whatever had got on him and he did not wash anywhere else, and he prayed in it then came back to me.And if anything got on him from me,he would do exactly the same and he did not wash anywhere else}}
\hadithdefcmd{nasai}{774}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامٍ، قَالَ رَأَيْتُ جَرِيرًا بَالَ ثُمَّ دَعَا بِمَاءٍ فَتَوَضَّأَ وَمَسَحَ عَلَى خُفَّيْهِ ثُمَّ قَامَ فَصَلَّى فَسُئِلَ عَنْ ذَلِكَ فَقَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم صَنَعَ مِثْلَ هَذَا ‏.‏\hadithno{774}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Hammam said:"I saw Jarir urinate, then he called for water and performed wudhu, and wiped over his Khuffs, then he stood up and prayed. He was asked about that and he said: 'I saw the Prophet(ﷺ) do exactly like this}}
\hadithdefcmd{nasai}{775}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، عَنْ يَزِيدَ بْنِ زُرَيْعٍ، وَغَسَّانَ بْنِ مُضَرَ، قَالاَ حَدَّثَنَا أَبُو مَسْلَمَةَ، - وَاسْمُهُ سَعِيدُ بْنُ يَزِيدَ بَصْرِيٌّ - ثِقَةٌ قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِي النَّعْلَيْنِ قَالَ نَعَمْ ‏.‏\hadithno{775}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Maslamah - whose name is Saeed bin Yazid, a trustworthy Basri - told us:"I asked Anas bin Malik: 'Did the Prophet (ﷺ) pray in sandals?' He said: 'Yes}}
\hadithdefcmd{nasai}{776}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، وَشُعَيْبُ بْنُ يُوسُفَ، عَنْ يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ عَبَّادٍ، عَنْ عَبْدِ اللَّهِ بْنِ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ السَّائِبِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى يَوْمَ الْفَتْحِ فَوَضَعَ نَعْلَيْهِ عَنْ يَسَارِهِ ‏.‏\hadithno{776}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abdullah bin As Saib that the Messenger of Allah(ﷺ) prayed on the day of Conquest (of Makkah), and he put his sandals to his left}}
