% Auto-generated chapter 34 for malik
% Hadiths in this chapter: 5

\hadithdefcmd{malik}{1390}{حَدَّثَنَا يَحْيَى، عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ حَنْظَلَةَ بْنِ قَيْسٍ الزُّرَقِيِّ، عَنْ رَافِعِ بْنِ خَدِيجٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ كِرَاءِ الْمَزَارِعِ قَالَ حَنْظَلَةُ فَسَأَلْتُ رَافِعَ بْنَ خَدِيجٍ بِالذَّهَبِ وَالْوَرِقِ فَقَالَ أَمَّا بِالذَّهَبِ وَالْوَرِقِ فَلاَ بَأْسَ بِهِ ‏.‏\hadithno{1390}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{}}
\hadithdefcmd{malik}{1391}{وَحَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ سَأَلْتُ سَعِيدَ بْنَ الْمُسَيَّبِ عَنْ كِرَاءِ الأَرْضِ، بِالذَّهَبِ وَالْوَرِقِ فَقَالَ لاَ بَأْسَ بِهِ ‏.‏\hadithno{1391}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me that Ibn Shihab said, "I asked Said ibn al- Musayyab about renting land for gold or silver, and he said, 'There is no harm in it}}
\hadithdefcmd{malik}{1392}{وَحَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ سَأَلَ سَالِمَ بْنَ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ كِرَاءِ الْمَزَارِعِ، فَقَالَ لاَ بَأْسَ بِهَا بِالذَّهَبِ وَالْوَرِقِ ‏.‏ قَالَ ابْنُ شِهَابٍ فَقُلْتُ لَهُ أَرَأَيْتَ الْحَدِيثَ الَّذِي يُذْكَرُ عَنْ رَافِعِ بْنِ خَدِيجٍ فَقَالَ أَكْثَرَ رَافِعٌ وَلَوْ كَانَ لِي مَزْرَعَةٌ أَكْرَيْتُهَا ‏.‏\hadithno{1392}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me from Ibn Shihab that he asked Salim ibn 'Abdullah ibn Umar about renting out fields. He said, "There is no harm in it for gold or silver." Ibn Shihab said, "I said to him, 'What do you think of the hadith which is mentioned from Rafi ibn Khadij?'" He said, ''Rafi has exaggerated. If I had a field, I would rent it out}}
\hadithdefcmd{malik}{1393}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ، تَكَارَى أَرْضًا فَلَمْ تَزَلْ فِي يَدَيْهِ بِكِرَاءٍ حَتَّى مَاتَ قَالَ ابْنُهُ فَمَا كُنْتُ أُرَاهَا إِلاَّ لَنَا مِنْ طُولِ مَا مَكَثَتْ فِي يَدَيْهِ حَتَّى ذَكَرَهَا لَنَا عِنْدَ مَوْتِهِ فَأَمَرَنَا بِقَضَاءِ شَىْءٍ كَانَ عَلَيْهِ مِنْ كِرَائِهَا ذَهَبٍ أَوْ وَرِقٍ ‏.‏\hadithno{1393}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me that he had heard that Abd ar-Rahman ibn Awf rented land, and he continued to have it in his possession until he died. His son said, "I thought that it was ours because of the length of time which it had remained in his hands, until he mentioned it to us at his death. He ordered us to pay some rent which he owed in gold or silver}}
\hadithdefcmd{malik}{1394}{وَحَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يُكْرِي أَرْضَهُ بِالذَّهَبِ وَالْوَرِقِ ‏.‏ وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ أَكْرَى مَزْرَعَتَهُ بِمِائَةِ صَاعٍ مِنْ تَمْرٍ أَوْ مِمَّا يَخْرُجُ مِنْهَا مِنَ الْحِنْطَةِ أَوْ مِنْ غَيْرِ مَا يَخْرُجُ مِنْهَا فَكَرِهَ ذَلِكَ ‏.‏\hadithno{1394}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me from Hisham ibn Urwa that his father used to rent out his land for gold and silver. Malik was asked about a man who rented his field for 100 sa of dates or part of its produce of wheat or from other than its produce. He disapproved of that}}
