% Auto-generated chapter 29 for nasai
% Hadiths in this chapter: 17

\hadithdefcmd{nasai}{3594}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ الْحَارِثِ، قَالَ مَا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم دِينَارًا وَلاَ دِرْهَمًا وَلاَ عَبْدًا وَلاَ أَمَةً إِلاَّ بَغْلَتَهُ الشَّهْبَاءَ الَّتِي كَانَ يَرْكَبُهَا وَسِلاَحَهُ وَأَرْضًا جَعَلَهَا فِي سَبِيلِ اللَّهِ ‏.‏ وَقَالَ قُتَيْبَةُ مَرَّةً أُخْرَى صَدَقَةً ‏.‏\hadithno{3594}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Amr bin Al-Harith said:"The Messenger of Allah did not leave behind a Dinar nor a Dirham, or any slave, male or female; except his white mule which he used to ride, his weapon and some land which he left to be used for the cause of Allah." (One of the narrators) Qutaibah said on one occasion: "In charity}}
\hadithdefcmd{nasai}{3595}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي أَبُو إِسْحَاقَ، قَالَ سَمِعْتُ عَمْرَو بْنَ الْحَارِثِ، يَقُولُ مَا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلاَّ بَغْلَتَهُ الْبَيْضَاءَ وَسِلاَحَهُ وَأَرْضًا تَرَكَهَا صَدَقَةً ‏.‏\hadithno{3595}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Ishaq narrated:"I heard 'Amr bin Al-Harith say: 'The Messenger of Allah did not leave behind anything except his white mule, his weapon and some land which he left as a charity}}
\hadithdefcmd{nasai}{3596}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، قَالَ حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عَمْرَو بْنَ الْحَارِثِ، يَقُولُ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم مَا تَرَكَ إِلاَّ بَغْلَتَهُ الشَّهْبَاءَ وَسِلاَحَهُ وَأَرْضًا تَرَكَهَا صَدَقَةً ‏.‏\hadithno{3596}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Yunus bin Abi Ishaq narrated that his father said:"I heard 'Amr bin Al-Harith say: 'I saw the Messenger of Allah and he left nothing behind except his white mule, his weapon and some land which he left as a charity}}
\hadithdefcmd{nasai}{3597}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عُمَرُ بْنُ سَعْدٍ عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنِ ابْنِ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، قَالَ أَصَبْتُ أَرْضًا مِنْ أَرْضِ خَيْبَرَ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ أَصَبْتُ أَرْضًا لَمْ أُصِبْ مَالاً أَحَبَّ إِلَىَّ وَلاَ أَنْفَسَ عِنْدِي مِنْهَا ‏.‏ قَالَ ‏ "‏ إِنْ شِئْتَ تَصَدَّقْتَ بِهَا ‏"‏ ‏.‏ فَتَصَدَّقَ بِهَا - عَلَى أَنْ لاَ تُبَاعَ وَلاَ تُوهَبَ - فِي الْفُقَرَاءِ وَذِي الْقُرْبَى وَالرِّقَابِ وَالضَّيْفِ وَابْنِ السَّبِيلِ لاَ جُنَاحَ عَلَى مَنْ وَلِيَهَا أَنْ يَأْكُلَ بِالْمَعْرُوفِ غَيْرَ مُتَمَوِّلٍ مَالاً وَيُطْعِمَ ‏.‏\hadithno{3597}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Sufyan Ath-Thawri, from Ibn 'Awn, from Nafi', from Ibn 'Umar, from 'Umar, that he said:"I was allocated some land of Khaibar. I came to the Messenger of Allah and said: 'I have acquired some land and I have never acquired any wealth that is dearer to me or more precious than it.' He said: 'If you wish, you can give it in charity.'" So he gave it in charity on condition that it would not be bought or given away, for the poor, relatives, slaves, guests and wayfarers. And there is no sin on the administrator if he eats from it or feeds others on a reasonable basis, with no intention of becoming wealthy from it}}
\hadithdefcmd{nasai}{3598}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، عَنْ أَبِي إِسْحَاقَ الْفَزَارِيِّ، عَنِ ابْنِ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، رضى الله عنه عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{3598}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{A similar report was narrated from Abu Ishaq Al-Fazari, from (Ayyub) bin 'Awn, from Nafi', from Ibn 'Umar, from 'Umar, may Allah be pleased with him, from the Prophet}}
\hadithdefcmd{nasai}{3599}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، قَالَ أَصَابَ عُمَرُ أَرْضًا بِخَيْبَرَ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ أَصَبْتُ أَرْضًا لَمْ أُصِبْ مَالاً قَطُّ أَنْفَسَ عِنْدِي فَكَيْفَ تَأْمُرُ بِهِ قَالَ ‏ "‏ إِنْ شِئْتَ حَبَّسْتَ أَصْلَهَا وَتَصَدَّقْتَ بِهَا ‏"‏ ‏.‏ فَتَصَدَّقَ بِهَا - عَلَى أَنْ لاَ تُبَاعَ وَلاَ تُوهَبَ وَلاَ تُورَثَ - فِي الْفُقَرَاءِ وَالْقُرْبَى وَالرِّقَابِ وَفِي سَبِيلِ اللَّهِ وَالضَّيْفِ وَابْنِ السَّبِيلِ لاَ جُنَاحَ عَلَى مَنْ وَلِيَهَا أَنْ يَأْكُلَ مِنْهَا بِالْمَعْرُوفِ وَيُطْعِمَ صَدِيقًا غَيْرَ مُتَمَوِّلٍ فِيهِ ‏.‏\hadithno{3599}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Yazid -Ibn Ruzaiq- said:"Ibn 'Awn narrated to us, from Nafi', from Ibn 'Umar, from 'Umar, who said: 'I acquired some land at Khaibar. He came to the Prophet and said: I have acquired some land at Khaibar, and I have never been given any wealth that is more precious to me than it. What do you command me to do with it? He said: If you wish, you can 'freeze' it and give it in charity. So he gave it in charity on condition that it would not be sold, given away or inherited, to the poor, relatives, slaves, for the cause of Allah, guests and wayfarers. There is no sin on the one who administers it if he eats from it on a reasonable basis and feeds his friend, with no intention of becoming wealthy from it}}
\hadithdefcmd{nasai}{3600}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا بِشْرٌ، عَنِ ابْنِ عَوْنٍ، قَالَ وَأَنْبَأَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا بِشْرٌ، قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ أَصَابَ عُمَرُ أَرْضًا بِخَيْبَرَ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَاسْتَأْمَرَهُ فِيهَا فَقَالَ إِنِّي أَصَبْتُ أَرْضًا كَثِيرًا لَمْ أُصِبْ مَالاً قَطُّ أَنْفَسَ عِنْدِي مِنْهُ فَمَا تَأْمُرُ فِيهَا قَالَ ‏ "‏ إِنْ شِئْتَ حَبَّسْتَ أَصْلَهَا وَتَصَدَّقْتَ بِهَا ‏"‏ ‏.‏ فَتَصَدَّقَ بِهَا - عَلَى أَنَّهُ لاَ تُبَاعُ وَلاَ تُوهَبُ - فَتَصَدَّقَ بِهَا فِي الْفُقَرَاءِ وَالْقُرْبَى وَفِي الرِّقَابِ وَفِي سَبِيلِ اللَّهِ وَابْنِ السَّبِيلِ وَالضَّيْفِ لاَ جُنَاحَ - يَعْنِي - عَلَى مَنْ وَلِيَهَا أَنْ يَأْكُلَ أَوْ يُطْعِمَ صَدِيقًا غَيْرَ مُتَمَوِّلٍ اللَّفْظُ لإِسْمَاعِيلَ ‏.‏\hadithno{3600}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Bishr, from Ibn 'Awn, from Nafi', from Ibn 'Umar who said:"Umar acquired some land at Khaibar. He came to the Prophet and consulted him about it. He said: 'I have acquired a great deal of land, and I have never acquired any wealth that is more precious to me than it. What do you command me to do with it?' He said: 'If you wish, you may freeze it and give it in charity.' So he gave it in charity on condition that it would not be sold or given away, and he gave it in charity to the poor, relatives, to emancipate slaves, for the cause of Allah, for wayfarers and guests. There is no sin -on the administrator- if he eats (from it) or feeds a friend, with no intention of becoming wealthy from it.'" These are the wordings of Isma'il}}
\hadithdefcmd{nasai}{3601}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَزْهَرُ السَّمَّانُ، عَنِ ابْنِ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، أَصَابَ أَرْضًا بِخَيْبَرَ فَأَتَى النَّبِيَّ صلى الله عليه وسلم يَسْتَأْمِرُهُ فِي ذَلِكَ فَقَالَ ‏ "‏ إِنْ شِئْتَ حَبَّسْتَ أَصْلَهَا وَتَصَدَّقْتَ بِهَا ‏"‏ ‏.‏ فَحَبَّسَ أَصْلَهَا أَنْ لاَ تُبَاعَ وَ لاَ تُوهَبَ وَلاَ تُورَثَ فَتَصَدَّقَ بِهَا عَلَى الْفُقَرَاءِ وَالْقُرْبَى وَالرِّقَابِ وَفِي الْمَسَاكِينِ وَابْنِ السَّبِيلِ وَالضَّيْفِ لاَ جُنَاحَ عَلَى مَنْ وَلِيَهَا أَنْ يَأْكُلَ مِنْهَا بِالْمَعْرُوفِ أَوْ يُطْعِمَ صَدِيقَهُ غَيْرَ مُتَمَوِّلٍ فِيهِ ‏.‏\hadithno{3601}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Azhar As-Samman, from Ibn 'Awn, from Nafi', from Ibn 'Umar, that 'Umar acquired some land at Khaibar. He came to the Prophet and consulted him about that. He said:"If you wish, you may 'freeze' it and give it in charity." So he 'froze' it, stipulating that it should not be sold, given as a gift or inherited, and he gave it in charity to the poor, relatives, slaves, the needy, wayfarers and guests. There is no sin on the administrator if he eats from it on a reasonable basis or feeds a friend with no intention of becoming wealthy from it}}
\hadithdefcmd{nasai}{3602}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ نَافِعٍ، قَالَ حَدَّثَنَا بَهْزٌ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ ‏\}‏ قَالَ أَبُو طَلْحَةَ إِنَّ رَبَّنَا لَيَسْأَلُنَا عَنْ أَمْوَالِنَا فَأُشْهِدُكَ يَا رَسُولَ اللَّهِ أَنِّي قَدْ جَعَلْتُ أَرْضِي لِلَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اجْعَلْهَا فِي قَرَابَتِكَ فِي حَسَّانَ بْنِ ثَابِتٍ وَأُبَىِّ بْنِ كَعْبٍ ‏"‏ ‏.‏\hadithno{3602}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas said:"When this Verse was revealed -'By no means shall you attain Al Birr (piety, righteousness--here it means Allah's reward, i.e. Paradise), unless you spend (in Allah's cause) of that which you love'- Abu Talha said: 'Our Lord will ask us about our wealth. I adjure you, O Messenger of Allah! I am giving my land to Allah.' The Messenger of Allah said: 'Make it for your relatives, Hassan bin Thabit and Ubayy bin Ka'b}}
\hadithdefcmd{nasai}{3603}{أَخْبَرَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ عُمَرُ لِلنَّبِيِّ صلى الله عليه وسلم إِنَّ الْمِائَةَ سَهْمٍ الَّتِي لِي بِخَيْبَرَ لَمْ أُصِبْ مَالاً قَطُّ أَعْجَبَ إِلَىَّ مِنْهَا قَدْ أَرَدْتُ أَنْ أَتَصَدَّقَ بِهَا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ احْبِسْ أَصْلَهَا وَسَبِّلْ ثَمَرَتَهَا ‏"‏ ‏.‏\hadithno{3603}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"Umar said to the Prophet: 'The one hundred shares that I acquired in Khaibar -I have never acquired any wealth that I like more than that, and I want to give it in charity.' The Prophet said: Freeze it and donate its fruits}}
\hadithdefcmd{nasai}{3604}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الْخَلَنْجِيُّ، بِبَيْتِ الْمَقْدِسِ قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، رضى الله عنه قَالَ جَاءَ عُمَرُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَصَبْتُ مَالاً لَمْ أُصِبْ مِثْلَهُ قَطُّ كَانَ لِي مِائَةُ رَأْسٍ فَاشْتَرَيْتُ بِهَا مِائَةَ سَهْمٍ مِنْ خَيْبَرَ مِنْ أَهْلِهَا وَإِنِّي قَدْ أَرَدْتُ أَنْ أَتَقَرَّبَ بِهَا إِلَى اللَّهِ عَزَّ وَجَلَّ ‏.‏ قَالَ ‏ "‏ فَاحْبِسْ أَصْلَهَا وَسَبِّلِ الثَّمَرَةَ ‏"‏ ‏.‏\hadithno{3604}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Umar, may Allah be pleased with him, said:"Umar came to the Messenger of Allah and said: 'O Messenger of Allah, I have acquired some wealth the like of which I have never acquired before. I had one hundred head (of livestock) with which I bought one hundred shares of Khaibar from its people. I wanted to draw closer to Allah, the Mighty and Sublime, by means of it.' He said: 'Freeze it and donate its fruits}}
\hadithdefcmd{nasai}{3605}{أَخْبَرَنَا مُحَمَّدُ بْنُ مُصَفَّى بْنِ بُهْلُولٍ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ سَعِيدِ بْنِ سَالِمٍ الْمَكِّيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ أَرْضٍ لِي بِثَمْغٍ قَالَ ‏ "‏ احْبِسْ أَصْلَهَا وَسَبِّلْ ثَمَرَتَهَا ‏"‏ ‏.‏\hadithno{3605}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Umar said:"I asked the Messenger of Allah about some land of mine in Thamgh. He said: 'Freeze it and donate its fruits}}
\hadithdefcmd{nasai}{3606}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ حُصَيْنِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَمْرِو بْنِ جَاوَانَ، - رَجُلٌ مِنْ بَنِي تَمِيمٍ - وَذَاكَ أَنِّي قُلْتُ لَهُ أَرَأَيْتَ اعْتِزَالَ الأَحْنَفِ بْنِ قَيْسٍ مَا كَانَ قَالَ سَمِعْتُ الأَحْنَفَ يَقُولُ أَتَيْتُ الْمَدِينَةَ وَأَنَا حَاجٌّ فَبَيْنَا نَحْنُ فِي مَنَازِلِنَا نَضَعُ رِحَالَنَا إِذْ أَتَى آتٍ فَقَالَ قَدِ اجْتَمَعَ النَّاسُ فِي الْمَسْجِدِ فَاطَّلَعْتُ فَإِذَا يَعْنِي النَّاسَ مُجْتَمِعُونَ وَإِذَا بَيْنَ أَظْهُرِهِمْ نَفَرٌ قُعُودٌ فَإِذَا هُوَ عَلِيُّ بْنُ أَبِي طَالِبٍ وَالزُّبَيْرُ وَطَلْحَةُ وَسَعْدُ بْنُ أَبِي وَقَّاصٍ رَحْمَةُ اللَّهِ عَلَيْهِمْ فَلَمَّا قُمْتُ عَلَيْهِمْ قِيلَ هَذَا عُثْمَانُ بْنُ عَفَّانَ قَدْ جَاءَ - قَالَ - فَجَاءَ وَعَلَيْهِ مُلَيَّةٌ صَفْرَاءُ فَقُلْتُ لِصَاحِبِي كَمَا أَنْتَ حَتَّى أَنْظُرَ مَا جَاءَ بِهِ ‏.‏ فَقَالَ عُثْمَانُ أَهَا هُنَا عَلِيٌّ أَهَا هُنَا الزُّبَيْرُ أَهَا هُنَا طَلْحَةُ أَهَا هُنَا سَعْدٌ قَالُوا نَعَمْ ‏.‏ قَالَ فَأَنْشُدُكُمْ بِاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ أَتَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ يَبْتَاعُ مِرْبَدَ بَنِي فُلاَنٍ غَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏ فَابْتَعْتُهُ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ إِنِّي ابْتَعْتُ مِرْبَدَ بَنِي فُلاَنٍ ‏.‏ قَالَ ‏"‏ فَاجْعَلْهُ فِي مَسْجِدِنَا وَأَجْرُهُ لَكَ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ فَأَنْشُدُكُمْ بِاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ هَلْ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ يَبْتَاعُ بِئْرَ رُومَةَ غَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ قَدِ ابْتَعْتُ بِئْرَ رُومَةَ ‏.‏ قَالَ ‏"‏ فَاجْعَلْهَا سِقَايَةً لِلْمُسْلِمِينَ وَأَجْرُهَا لَكَ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ فَأَنْشُدُكُمْ بِاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ هَلْ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ يُجَهِّزْ جَيْشَ الْعُسْرَةِ غَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏ فَجَهَّزْتُهُمْ حَتَّى مَا يَفْقِدُونَ عِقَالاً وَلاَ خِطَامًا ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ اللَّهُمَّ اشْهَدِ اللَّهُمَّ اشْهَدِ اللَّهُمَّ اشْهَدْ ‏.‏\hadithno{3606}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Al-Ahnaf said:"I came to Al-Madinah, and I was performing Hajj, and while we were in our camping place unloading our mounts, someone came to us and said: 'The people have gathered in the Masjid.' I looked and found the people gathered, and in the midst of them was a group; there I saw 'Ali bin Abi Talib, Az-Zubair, Talhah and Sa'd bin Abi Waqqas, may Allah have mercy on them. When I got there, it was said that 'Uthman bin 'Affan had come. He came, wearing a yellowish cloak. I said to my companion: Stay where you are until I find out what is happening. 'Uthman said: Is 'Ali here? Is Az-Zubair here? Is Talhah here? Is Sa'd here? They said: Yes. He said: I adjure you by Allah, beside Whom there is none worthy of worship, are you aware that the Messenger of Allah said: Whoever buys the Mirbad of Banu so and so, Allah will forgive him, and I bought it, then I came to the Messenger of Allah and told him, and he said: Add it to our Masjid and the reward for it will be yours? They said: Yes. He said: I adjure you by Allah, beside Whom there is none worthy of worship, are you aware that the Messenger of Allah said: Whoever buys the well of Rumah, Allah will forgive him, so I came to the Messenger of Allah and said: I have bought the well of Rumah. He said: Give it to provide water for the Muslims, and the reward for it will be yours? They said: Yes. He said: 'I adjure you by Allah, beside Whom there is none worthy of worship, are you aware that the Messenger of Allah said: Whoever equips the army of Al-'Usrah (i.e. Tabuk), Allah will forgive him, so I equipped them until they were not lacking even a rope or a bridle?' They said: Yes. He said: O Allah, bear witness, O Allah, bear witness, O Allah, bear witness}}
\hadithdefcmd{nasai}{3607}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، قَالَ سَمِعْتُ حُصَيْنَ بْنَ عَبْدِ الرَّحْمَنِ، يُحَدِّثُ عَنْ عَمْرِو بْنِ جَاوَانَ، عَنِ الأَحْنَفِ بْنِ قَيْسٍ، قَالَ خَرَجْنَا حُجَّاجًا فَقَدِمْنَا الْمَدِينَةَ وَنَحْنُ نُرِيدُ الْحَجَّ فَبَيْنَا نَحْنُ فِي مَنَازِلِنَا نَضَعُ رِحَالَنَا إِذْ أَتَانَا آتٍ فَقَالَ إِنَّ النَّاسَ قَدِ اجْتَمَعُوا فِي الْمَسْجِدِ وَفَزِعُوا ‏.‏ فَانْطَلَقْنَا فَإِذَا النَّاسُ مُجْتَمِعُونَ عَلَى نَفَرٍ فِي وَسَطِ الْمَسْجِدِ وَإِذَا عَلِيٌّ وَالزُّبَيْرُ وَطَلْحَةُ وَسَعْدُ بْنُ أَبِي وَقَّاصٍ فَإِنَّا لَكَذَلِكَ إِذْ جَاءَ عُثْمَانُ بْنُ عَفَّانَ عَلَيْهِ مُلاَءَةٌ صَفْرَاءُ قَدْ قَنَّعَ بِهَا رَأْسَهُ فَقَالَ أَهَا هُنَا عَلِيٌّ أَهَا هُنَا طَلْحَةُ أَهَا هُنَا الزُّبَيْرُ أَهَا هُنَا سَعْدٌ قَالُوا نَعَمْ ‏.‏ قَالَ فَإِنِّي أَنْشُدُكُمْ بِاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ أَتَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ يَبْتَاعُ مِرْبَدَ بَنِي فُلاَنٍ غَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏ فَابْتَعْتُهُ بِعِشْرِينَ أَلْفًا أَوْ بِخَمْسَةٍ وَعِشْرِينَ أَلْفًا فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَقَالَ ‏"‏ اجْعَلْهَا فِي مَسْجِدِنَا وَأَجْرُهُ لَكَ ‏"‏ ‏.‏ قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ فَأَنْشُدُكُمْ بِاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ أَتَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ يَبْتَاعُ بِئْرَ رُومَةَ غَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏ فَابْتَعْتُهُ بِكَذَا وَكَذَا فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ قَدِ ابْتَعْتُهَا بِكَذَا وَكَذَا ‏.‏ قَالَ ‏"‏ اجْعَلْهَا سِقَايَةً لِلْمُسْلِمِينَ وَأَجْرُهَا لَكَ ‏"‏ ‏.‏ قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ فَأَنْشُدُكُمْ بِاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ أَتَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَظَرَ فِي وُجُوهِ الْقَوْمِ فَقَالَ ‏"‏ مَنْ جَهَّزَ هَؤُلاَءِ اللَّهُ غَفَرَ لَهُ ‏"‏ ‏.‏ يَعْنِي جَيْشَ الْعُسْرَةِ فَجَهَّزْتُهُمْ حَتَّى مَا يَفْقِدُونَ عِقَالاً وَلاَ خِطَامًا ‏.‏ قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ اللَّهُمَّ اشْهَدِ اللَّهُمَّ اشْهَدْ ‏.‏\hadithno{3607}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Ahnaf bin Qais said:"We set out for Hajj, and came to Al-Madinah intending to perform Hajj. While we were in our camping place unloading our mounts, someone came to us and said: 'The people have gathered in the Masjid and there is panic.' So we set out and found the people gathered around a group in the middle of the Masjid, among whom were 'Ali, Az-Zubair, Talhah and Sa'd bin Abi Waqqas. While we were like that, 'Uthman came, wearing a yellowish cloak with which he had covered his head. He said: Is 'Ali here? Is Talhah here? Is Az-Zubair here? Is Sa'd here? They said: Yes. He said: I adjure you by Allah, beside Whom there is none worthy of worship, are you aware that the Messenger of Allah said: Whoever buys the Mirbad of Banu so and so, Allah will forgive him, and I bought it for twenty or twenty-five thousand, then I came to the Messenger of Allah and told him, and he said: Add it to our Masjid and the reward for it will be yours? They said: By Allah, yes. He said: 'I adjure you by Allah, beside Whom there is none worthy of worship, are you aware that the Messenger of Allah said: Whoever buys the well of Rumah, Allah will forgive him, so I bought it for such and such an amount, then I came to the Messenger of Allah and told him, and he said: Give it to provide water for the Muslims, and the reward for it will be yours?' They said: By Allah, yes. He said: 'I adjure you by Allah, beside Whom there is none worthy of worship, are you aware that the Messenger of Allah said: Whoever equips these (men), Allah will forgive him, -meaning the army of Al-'Usrah (i.e. Tabuk)- so I equipped them until they were not lacking even a rope or a bridle?' They said: By Allah, yes. He said: O Allah, bear witness, O Allah, bear witness}}
\hadithdefcmd{nasai}{3608}{أَخْبَرَنِي زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ، عَنْ يَحْيَى بْنِ أَبِي الْحَجَّاجِ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، عَنْ ثُمَامَةَ بْنِ حَزْنٍ الْقُشَيْرِيِّ، قَالَ شَهِدْتُ الدَّارَ حِينَ أَشْرَفَ عَلَيْهِمْ عُثْمَانُ فَقَالَ أَنْشُدُكُمْ بِاللَّهِ وَبِالإِسْلاَمِ هَلْ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدِمَ الْمَدِينَةَ وَلَيْسَ بِهَا مَاءٌ يُسْتَعْذَبُ غَيْرَ بِئْرِ رُومَةَ فَقَالَ ‏"‏ مَنْ يَشْتَرِي بِئْرَ رُومَةَ فَيَجْعَلُ فِيهَا دَلْوَهُ مَعَ دِلاَءِ الْمُسْلِمِينَ بِخَيْرٍ لَهُ مِنْهَا فِي الْجَنَّةِ ‏"‏ ‏.‏ فَاشْتَرَيْتُهَا مِنْ صُلْبِ مَالِي فَجَعَلْتُ دَلْوِي فِيهَا مَعَ دِلاَءِ الْمُسْلِمِينَ وَأَنْتُمُ الْيَوْمَ تَمْنَعُونِي مِنَ الشُّرْبِ مِنْهَا حَتَّى أَشْرَبَ مِنْ مَاءِ الْبَحْرِ قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ فَأَنْشُدُكُمْ بِاللَّهِ وَالإِسْلاَمِ هَلْ تَعْلَمُونَ أَنِّي جَهَّزْتُ جَيْشَ الْعُسْرَةِ مِنْ مَالِي قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ فَأَنْشُدُكُمْ بِاللَّهِ وَالإِسْلاَمِ هَلْ تَعْلَمُونَ أَنَّ الْمَسْجِدَ ضَاقَ بِأَهْلِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ يَشْتَرِي بُقْعَةَ آلِ فُلاَنٍ فَيَزِيدُهَا فِي الْمَسْجِدِ بِخَيْرٍ لَهُ مِنْهَا فِي الْجَنَّةِ ‏"‏ ‏.‏ فَاشْتَرَيْتُهَا مِنْ صُلْبِ مَالِي فَزِدْتُهَا فِي الْمَسْجِدِ وَأَنْتُمْ تَمْنَعُونِي أَنْ أُصَلِّيَ فِيهِ رَكْعَتَيْنِ قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ أَنْشُدُكُمْ بِاللَّهِ وَالإِسْلاَمِ هَلْ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عَلَى ثَبِيرٍ ثَبِيرِ مَكَّةَ وَمَعَهُ أَبُو بَكْرٍ وَعُمَرُ وَأَنَا فَتَحَرَّكَ الْجَبَلُ فَرَكَضَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِرِجْلِهِ وَقَالَ ‏"‏ اسْكُنْ ثَبِيرُ فَإِنَّمَا عَلَيْكَ نَبِيٌّ وَصِدِّيقٌ وَشَهِيدَانِ ‏"‏ ‏.‏ قَالُوا اللَّهُمَّ نَعَمْ ‏.‏ قَالَ اللَّهُ أَكْبَرُ شَهِدُوا لِي وَرَبِّ الْكَعْبَةِ ‏.‏ يَعْنِي أَنِّي شَهِيدٌ ‏.‏\hadithno{3608}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Thumamah bin Hazn Al-Qushairi said:"I was present at the house when 'Uthman looked out over them and said: 'I adjure you by Allah and by Islam, are you aware that when the Messenger of Allah came to Al-Madinah, and it had no water that was considered sweet (suitable for drinking) except the well of Rumah, he said: "Who will buy the well of Rumah and dip his bucket in it alongside the buckets of the Muslims, in return for a better one in Paradise?" and I bought it with my capital and dipped my bucket into it alongside the buckets of the Muslims? Yet today you are preventing me from drinking from it, so that I have to drink salty water.' They said: 'By Allah, yes.' He said: 'I adjure you by Allah and by Islam, are you aware that I equipped the army of Al-'Usrah (Tabuk) from my own wealth?' They said: 'By Allah, yes.' He said: 'I adjure you by Allah and by Islam, are you aware that when the Masjid became too small for the people and the Messenger of Allah said: Who will buy the plot of the family of so and so and add it to the Masjid, in return for a better plot in Paradise? I bought it with my capital and added it to the Masjid? Yet now you are preventing me from praying two Rak'ahs therein.' They said: 'By Allah, yes.' He said: 'I adjure you by Allah and by Islam, are you aware that when the Messenger of Allah was atop Thabir -the Thabir in Makkah- and with him were Abu Bakr, 'Umar and myself, the mountain shook, and the Messenger of Allah kicked it with his foot and said: Be still, Thabir, for upon you are a Prophet, a Siddiq and two martyrs?' They said: 'By Allah, yes.' He said: 'Allahu Akbar! They have testified for me, by the Lord of the Ka'bah' -i.e., that I am a martyr}}
\hadithdefcmd{nasai}{3609}{أَخْبَرَنَا عِمْرَانُ بْنُ بَكَّارِ بْنِ رَاشِدٍ، قَالَ حَدَّثَنَا خَطَّابُ بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنِي أَبِي، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ عُثْمَانَ، أَشْرَفَ عَلَيْهِمْ حِينَ حَصَرُوهُ فَقَالَ أَنْشُدُ بِاللَّهِ رَجُلاً سَمِعَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ يَوْمَ الْجَبَلِ حِينَ اهْتَزَّ فَرَكَلَهُ بِرِجْلِهِ وَقَالَ ‏"‏ اسْكُنْ فَإِنَّهُ لَيْسَ عَلَيْكَ إِلاَّ نَبِيٌّ أَوْ صِدِّيقٌ أَوْ شَهِيدَانِ ‏"‏ ‏.‏ وَأَنَا مَعَهُ فَانْتَشَدَ لَهُ رِجَالٌ ثُمَّ قَالَ أَنْشُدُ بِاللَّهِ رَجُلاً شَهِدَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمَ بَيْعَةِ الرِّضْوَانِ يَقُولُ ‏"‏ هَذِهِ يَدُ اللَّهِ وَهَذِهِ يَدُ عُثْمَانَ ‏"‏ ‏.‏ فَانْتَشَدَ لَهُ رِجَالٌ ثُمَّ قَالَ أَنْشُدُ بِاللَّهِ رَجُلاً سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمَ جَيْشِ الْعُسْرَةِ يَقُولُ ‏"‏ مَنْ يُنْفِقُ نَفَقَةً مُتَقَبَّلَةً ‏"‏ ‏.‏ فَجَهَّزْتُ نِصْفَ الْجَيْشِ مِنْ مَالِي فَانْتَشَدَ لَهُ رِجَالٌ ثُمَّ قَالَ أَنْشُدُ بِاللَّهِ رَجُلاً سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ يَزِيدُ فِي هَذَا الْمَسْجِدِ بِبَيْتٍ فِي الْجَنَّةِ ‏"‏ ‏.‏ فَاشْتَرَيْتُهُ مِنْ مَالِي فَانْتَشَدَ لَهُ رِجَالٌ ثُمَّ قَالَ أَنْشُدُ بِاللَّهِ رَجُلاً شَهِدَ رُومَةَ تُبَاعُ فَاشْتَرَيْتُهَا مِنْ مَالِي فَأَبَحْتُهَا لاِبْنِ السَّبِيلِ فَانْتَشَدَ لَهُ رِجَالٌ ‏.‏\hadithno{3609}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Salamah bin 'Abdur-Rahman that 'Uthman looked out over them when they besieged him and said:"By Allah, I adjure a man who heard the Messenger of Allah, on the day when the mountain shook with him, and he kicked it with his foot and said: 'Be still, for there is no one upon you but a Prophet or a Siddiq or two martyrs,' and I was with him." Some men responded and affirmed that. Then he said: "By Allah, I adjure a man who witnessed the Messenger of Allah, on the day of Bai'at Al-Ridwan, say: 'This is the Hand of Allah and this is the hand of 'Uthman.'" Some men responded and affirmed that. He said: "By Allah, I adjure a man who heard the Messenger of Allah say, on the day of the army of Al-'Usrah (i.e. Tabuk): 'Who will spend and it will be accepted?' And I equipped half of the army from my own wealth." Some men responded and affirmed that. Then he said: "By Allah, I adjure a man who heard the Messenger of Allah say: 'Who will add to this Masjid in return for a house in Paradise,' and I bought it with my own wealth." Some men responded and affirmed that. Then he said: "By Allah, I adjure a man who witness Rumah being sold, and I bought it from my own wealth and allowed wayfarers to use it." Some men responded and affirmed that}}
\hadithdefcmd{nasai}{3610}{أَخْبَرَنِي مُحَمَّدُ بْنُ وَهْبٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنِي أَبُو عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنِي زَيْدُ بْنُ أَبِي أُنَيْسَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، قَالَ لَمَّا حُصِرَ عُثْمَانُ فِي دَارِهِ اجْتَمَعَ النَّاسُ حَوْلَ دَارِهِ - قَالَ - فَأَشْرَفَ عَلَيْهِمْ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{3610}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdur-Rahman Al-Sulami said:"When 'Uthman was besieged in his house, the people gathered around his house and he looked out over them" and he quoted the same Hadith}}
