% Auto-generated chapter 32 for abudawud
% Hadiths in this chapter: 40

\hadithdefcmd{abudawud}{3969}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، ح وَحَدَّثَنَا نَصْرُ بْنُ عَاصِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم قَرَأَ ‏\{‏ وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى ‏\}‏\hadithno{3969}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) read the Qur'anic verse, "And take ye the Station of Abraham as a place of prayer}}
\hadithdefcmd{abudawud}{3970}{حَدَّثَنَا مُوسَى، - يَعْنِي ابْنَ إِسْمَاعِيلَ - حَدَّثَنَا حَمَّادٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَجُلاً، قَامَ مِنَ اللَّيْلِ فَقَرَأَ فَرَفَعَ صَوْتَهُ بِالْقُرْآنِ فَلَمَّا أَصْبَحَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَرْحَمُ اللَّهُ فُلاَنًا كَائِنٌ مِنْ آيَةٍ أَذْكَرَنِيهَا اللَّيْلَةَ كُنْتُ قَدْ أَسْقَطْتُهَا ‏"‏ ‏.‏\hadithno{3970}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated A'ishah:A man got up (for prayer) at night, he read the Qur'an and raised his voice in reading. When the morning came, the Messenger of Allah (ﷺ) said: May Allah have mercy on so-and-so! Last night he reminded me a number of verses which I was about to forget}}
\hadithdefcmd{abudawud}{3971}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا خُصَيْفٌ، حَدَّثَنَا مِقْسَمٌ، مَوْلَى ابْنِ عَبَّاسٍ قَالَ قَالَ ابْنُ عَبَّاسٍ رضى الله عنهما نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ وَمَا كَانَ لِنَبِيٍّ أَنْ يَغُلَّ ‏\}‏ فِي قَطِيفَةٍ حَمْرَاءَ فُقِدَتْ يَوْمَ بَدْرٍ فَقَالَ بَعْضُ النَّاسِ لَعَلَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَخَذَهَا فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَمَا كَانَ لِنَبِيٍّ أَنْ يَغُلَّ ‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏ قَالَ أَبُو دَاوُدَ يَغُلَّ مَفْتُوحَةُ الْيَاءِ ‏.‏\hadithno{3971}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The verse "And no Prophet could (ever) be false to his trust" was revealed about a red velvet. When it was found missing on the day of Badr, some people said; Perhaps the Messenger of Allah (ﷺ) has taken it. So Allah, the Exalted, sent down "And no prophet could (ever) be false to his trust" to the end of the verse. Abu Dawud said: In the word yaghulla the letter ya has a short vowel a}}
\hadithdefcmd{abudawud}{3972}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي قَالَ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْبُخْلِ وَالْهَرَمِ ‏"‏ ‏.‏\hadithno{3972}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2823) Sahih Muslim (2706)}\hadithtrans{Anas b. Malik reported that Messenger of Allah (ﷺ) as saying:O Allah, I seek refuge in Thee from niggardliness and old age}}
\hadithdefcmd{abudawud}{3973}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنْ إِسْمَاعِيلَ بْنِ كَثِيرٍ، عَنْ عَاصِمِ بْنِ لَقِيطِ بْنِ صَبِرَةَ، عَنْ أَبِيهِ، لَقِيطِ بْنِ صَبِرَةَ قَالَ كُنْتُ وَافِدَ بَنِي الْمُنْتَفِقِ - أَوْ فِي وَفْدِ بَنِي الْمُنْتَفِقِ - إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ الْحَدِيثَ فَقَالَ - يَعْنِي النَّبِيَّ صلى الله عليه وسلم - ‏ "‏ لاَ تَحْسِبَنَّ ‏"‏ ‏.‏ وَلَمْ يَقُلْ لاَ تَحْسَبَنَّ ‏.‏\hadithno{3973}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Laqit ibn Sabirah: I came in the deputation of Banu al-Muntafiq to the Messenger of Allah (ﷺ). He then narrated the rest of the tradition. The Prophet (ﷺ) said: la tahsibanna (do not think) and did not say: la tahsabanna (do not think)}}
\hadithdefcmd{abudawud}{3974}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَحِقَ الْمُسْلِمُونَ رَجُلاً فِي غُنَيْمَةٍ لَهُ فَقَالَ السَّلاَمُ عَلَيْكُمْ فَقَتَلُوهُ وَأَخَذُوا تِلْكَ الْغُنَيْمَةَ فَنَزَلَتْ ‏\{‏ وَلاَ تَقُولُوا لِمَنْ أَلْقَى إِلَيْكُمُ السَّلاَمَ لَسْتَ مُؤْمِنًا تَبْتَغُونَ عَرَضَ الْحَيَاةِ الدُّنْيَا ‏\}‏ تِلْكَ الْغُنَيْمَةَ ‏.‏\hadithno{3974}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4591) Sahih Muslim (3025)}\hadithtrans{Narrated Ibn 'Abbas:The Muslims met a man with some sheep of his. He said: Peace be upon you. But they killed him and took those few sheep. Thereupon the following Qur'anic verse was revealed: "...And say to anyone who offers you a salutation: Thou art none of believer, coveting the perishable good of this life." meaning these few sheep}}
\hadithdefcmd{abudawud}{3975}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا ابْنُ أَبِي الزِّنَادِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، عَنِ ابْنِ أَبِي الزِّنَادِ، - وَهُوَ أَشْبَعُ - عَنْ أَبِيهِ، عَنْ خَارِجَةَ بْنِ زَيْدِ بْنِ ثَابِتٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ ‏\{‏ غَيْرُ أُولِي الضَّرَرِ ‏\}‏ وَلَمْ يَقُلْ سَعِيدٌ كَانَ يَقْرَأُ ‏.‏\hadithno{3975}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Zayd ibn Thabit: The Prophet (ﷺ) used to read: "Not equal are those believers who sit (at home) and receive no hurt (ghayru ulid-darari) but the narrator Sa'id did not say the words "used to read}}
\hadithdefcmd{abudawud}{3976}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، حَدَّثَنَا يُونُسُ بْنُ يَزِيدَ، عَنْ أَبِي عَلِيِّ بْنِ يَزِيدَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَرَأَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏\{‏ وَالْعَيْنُ بِالْعَيْنِ ‏\}‏ ‏.‏\hadithno{3976}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The Messenger of Allah (ﷺ) read the verse: "eye for eye" (al-'aynu bil-'ayn)}}
\hadithdefcmd{abudawud}{3977}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، حَدَّثَنَا يُونُسُ بْنُ يَزِيدَ، عَنْ أَبِي عَلِيِّ بْنِ يَزِيدَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، رَضِيَ اللَّهُ عَنْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ ‏\{‏ وَكَتَبْنَا عَلَيْهِمْ فِيهَا أَنَّ النَّفْسَ بِالنَّفْسِ وَالْعَيْنُ بِالْعَيْنِ ‏\}‏ ‏.‏\hadithno{3977}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) read the verse: "We ordained therein for them: Life for life and eye for eye (an-nafsa bin-nafsi wal-'aynu bil-'ayn)}}
\hadithdefcmd{abudawud}{3978}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا فُضَيْلُ بْنُ مَرْزُوقٍ، عَنْ عَطِيَّةَ بْنِ سَعْدٍ الْعَوْفِيِّ، قَالَ قَرَأْتُ عَلَى عَبْدِ اللَّهِ بْنِ عُمَرَ ‏\{‏ اللَّهُ الَّذِي خَلَقَكُمْ مِنْ ضَعْفٍ ‏\}‏ فَقَالَ ‏\{‏ مِنْ ضُعْفٍ ‏\}‏ قَرَأْتُهَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم كَمَا قَرَأْتَهَا عَلَىَّ فَأَخَذَ عَلَىَّ كَمَا أَخَذْتُ عَلَيْكَ ‏.‏\hadithno{3978}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: Atiyyah ibn Sa'd al-Awfi said: I recited to Abdullah ibn Umar the verse: "It is Allah Who created you in a state of (helplessness) weakness (min da'f)." He said: (Read) min du'f. I recited it to the Messenger of Allah (ﷺ) as you recited it to me, and he gripped me as I gripped you}}
\hadithdefcmd{abudawud}{3979}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الْقُطَعِيُّ، حَدَّثَنَا عُبَيْدٌ، - يَعْنِي ابْنَ عَقِيلٍ - عَنْ هَارُونَ، عَنْ عَبْدِ اللَّهِ بْنِ جَابِرٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏\{‏ مِنْ ضُعْفٍ ‏\}‏ ‏.‏\hadithno{3979}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) read the verse mentioned above, "min du'f}}
\hadithdefcmd{abudawud}{3980}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَسْلَمَ الْمِنْقَرِيِّ، عَنْ عَبْدِ اللَّهِ، عَنْ أَبِيهِ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، قَالَ قَالَ أُبَىُّ بْنُ كَعْبٍ ‏\{‏ بِفَضْلِ اللَّهِ وَبِرَحْمَتِهِ فَبِذَلِكَ فَلْتَفْرَحُوا ‏\}‏ ‏.‏ قَالَ أَبُو دَاوُدَ بِالتَّاءِ ‏.‏\hadithno{3980}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ubayy b. Ka'b:"Say, in the bounty of Allah, and in His mercy- in that let you rejoice}}
\hadithdefcmd{abudawud}{3981}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا الْمُغِيرَةُ بْنُ سَلَمَةَ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنِ الأَجْلَحِ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى، عَنْ أَبِيهِ، عَنْ أُبَىٍّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَرَأَ ‏\{‏ بِفَضْلِ اللَّهِ وَبِرَحْمَتِهِ فَبِذَلِكَ فَلْيَفْرَحُوا هُوَ خَيْرٌ مِمَّا تَجْمَعُونَ ‏\}‏ ‏.‏\hadithno{3981}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{(Narrated Ibn Abzi: Ubayy ibn Ka'b) said: The Prophet (ﷺ) read the verse: "Say: In the bounty of Allah and in His mercy--in that let you rejoice: that is better than the wealth you hoard}}
\hadithdefcmd{abudawud}{3982}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا ثَابِتٌ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ، أَنَّهَا سَمِعَتِ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ ‏\{‏ إِنَّهُ عَمِلَ غَيْرَ صَالِحٍ ‏\}‏ ‏.‏\hadithno{3982}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Asma' daughter of Yazid: She heard the Prophet (ﷺ) read the verse: "He acted unrighteously." (innahu 'amila ghayra salih)}}
\hadithdefcmd{abudawud}{3983}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ الْمُخْتَارِ - حَدَّثَنَا ثَابِتٌ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، قَالَ سَأَلْتُ أُمَّ سَلَمَةَ كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم صلى الله عليه وسلم يَقْرَأُ هَذِهِ الآيَةَ ‏\{‏ إِنَّهُ عَمَلٌ غَيْرُ صَالِحٍ ‏\}‏ فَقَالَتْ قَرَأَهَا ‏\{‏ إِنَّهُ عَمِلَ غَيْرَ صَالِحٍ ‏\}‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ هَارُونُ النَّحْوِيُّ وَمُوسَى بْنُ خَلَفٍ عَنْ ثَابِتٍ كَمَا قَالَ عَبْدُ الْعَزِيزِ ‏.‏\hadithno{3983}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: Shahr ibn Hawshab said: I asked Umm Salamah: How did the Messenger of Allah (ﷺ) read this verse: "For his conduct is unrighteous (innahu 'amalun ghayru salih". She replied: He read it: "He acted unrighteously" (innahu 'amila ghayra salih). Abu Dawud said: This tradition has been transmitted by Harun al-Nahwi and Musa b. Khalaf from Thabit as reported by the narrator 'Abd al-Aziz}}
\hadithdefcmd{abudawud}{3984}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عِيسَى، عَنْ حَمْزَةَ الزَّيَّاتِ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا دَعَا بَدَأَ بِنَفْسِهِ وَقَالَ ‏"‏ رَحْمَةُ اللَّهِ عَلَيْنَا وَعَلَى مُوسَى لَوْ صَبَرَ لَرَأَى مِنْ صَاحِبِهِ الْعَجَبَ وَلَكِنَّهُ قَالَ ‏\{‏ إِنْ سَأَلْتُكَ عَنْ شَىْءٍ بَعْدَهَا فَلاَ تُصَاحِبْنِي قَدْ بَلَغْتَ مِنْ لَدُنِي ‏\}‏ ‏"‏ ‏.‏ طَوَّلَهَا حَمْزَةُ ‏.‏\hadithno{3984}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ubayy ibn Ka'b:: When the Messenger of Allah (ﷺ) prayed, he began with himself and said: May the mercy of Allah be upon us and upon Moses. If he had patience, he would have seen marvels from his Companion. But he said: "(Moses) said: If ever I ask thee about anything after this, keep me not in they company: then wouldst thou have received (full) excuse from my side". Hamzah lengthened it}}
\hadithdefcmd{abudawud}{3985}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ أَبُو عَبْدِ اللَّهِ الْعَنْبَرِيُّ، حَدَّثَنَا أُمَيَّةُ بْنُ خَالِدٍ، حَدَّثَنَا أَبُو الْجَارِيَةِ الْعَبْدِيُّ، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَرَأَهَا ‏\{‏ قَدْ بَلَغْتَ مِنْ لَدُنِّي ‏\}‏ وَثَقَّلَهَا ‏.‏\hadithno{3985}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ubayy ibn Ka'b: The Prophet (ﷺ) read the Qur'anic verse: "Thou hast received (full) excuse from me (min ladunni)" and put tashdid (doubling of consonants) on nun (n)}}
\hadithdefcmd{abudawud}{3986}{حَدَّثَنَا مُحَمَّدُ بْنُ مَسْعُودٍ الْمِصِّيصِيُّ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا مُحَمَّدُ بْنُ دِينَارٍ، حَدَّثَنَا سَعْدُ بْنُ أَوْسٍ، عَنْ مِصْدَعٍ أَبِي يَحْيَى، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ أَقْرَأَنِي أُبَىُّ بْنُ كَعْبٍ كَمَا أَقْرَأَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏\{‏ فِي عَيْنٍ حَمِئَةٍ ‏\}‏ مُخَفَّفَةً ‏.‏\hadithno{3986}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: Ubayy ibn Ka'b made me read the following verse as the Messenger of Allah (ﷺ) made him read: "in a spring of murky water" (fi 'aynin hami'atin) with short vowel a after h}}
\hadithdefcmd{abudawud}{3987}{حَدَّثَنَا يَحْيَى بْنُ الْفَضْلِ، حَدَّثَنَا وُهَيْبٌ، - يَعْنِي ابْنَ عَمْرٍو النَّمَرِيَّ - أَخْبَرَنَا هَارُونُ، أَخْبَرَنِي أَبَانُ بْنُ تَغْلِبَ، عَنْ عَطِيَّةَ الْعَوْفِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الرَّجُلَ مِنْ أَهْلِ عِلِّيِّينَ لَيُشْرِفُ عَلَى أَهْلِ الْجَنَّةِ فَتُضِيءُ الْجَنَّةُ لِوَجْهِهِ كَأَنَّهَا كَوْكَبٌ دُرِّيٌّ ‏"‏ ‏.‏ قَالَ وَهَكَذَا جَاءَ الْحَدِيثُ ‏"‏ دُرِّيٌّ ‏"‏ ‏.‏ مَرْفُوعَةُ الدَّالِ لاَ تُهْمَزُ ‏"‏ وَإِنَّ أَبَا بَكْرٍ وَعُمَرَ لَمِنْهُمْ وَأَنْعَمَا ‏"‏ ‏.‏\hadithno{3987}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) said: A man from the Illiyyun will look downwards at the people of Paradise and Paradise will be glittering as if it were a brilliant star. He (the narrator) said: In this way the word durri (brilliant) occurs in this tradition, i.e. the letter dal (d) has short vowel u and it has no hamzah ('). AbuBakr and Umar will be of them and will have some additional blessings}}
\hadithdefcmd{abudawud}{3988}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنِي الْحَسَنُ بْنُ الْحَكَمِ النَّخَعِيُّ، حَدَّثَنَا أَبُو سَبْرَةَ النَّخَعِيُّ، عَنْ فَرْوَةَ بْنِ مُسَيْكٍ الْغُطَيْفِيِّ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ الْحَدِيثَ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ يَا رَسُولَ اللَّهِ أَخْبِرْنَا عَنْ سَبَإٍ مَا هُوَ أَرْضٌ أَمِ امْرَأَةٌ فَقَالَ ‏ "‏ لَيْسَ بِأَرْضٍ وَلاَ امْرَأَةٍ وَلَكِنَّهُ رَجُلٌ وَلَدَ عَشَرَةً مِنَ الْعَرَبِ فَتَيَامَنَ سِتَّةٌ وَتَشَاءَمَ أَرْبَعَةٌ ‏"‏ ‏.‏ قَالَ عُثْمَانُ الْغَطَفَانِيِّ مَكَانَ الْغُطَيْفِيِّ وَقَالَ حَدَّثَنَا الْحَسَنُ بْنُ الْحَكَمِ النَّخَعِيُّ ‏.‏\hadithno{3988}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Farwah ibn Musayk al-Ghutayfi: I came to the Prophet (ﷺ). He then narrated the rest of the tradition. A man from the people said: "Messenger of Allah! tell us about Saba'; what is it: land or woman? He replied: It is neither land nor woman; it is a man to whom ten children of the Arabs were born: six of them lived in the Yemen and four lived in Syria. The narrator Uthman said al-Ghatafani instead of al-Ghutayfi. He said: It has been transmitted to us by al-Hasan ibn al-Hakam an-Nakha'i}}
\hadithdefcmd{abudawud}{3989}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، وَإِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ أَبُو مَعْمَرٍ الْهُذَلِيُّ، عَنْ سُفْيَانَ، عَنْ عَمْرٍو، عَنْ عِكْرِمَةَ، قَالَ حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم - قَالَ إِسْمَاعِيلُ عَنْ أَبِي هُرَيْرَةَ رِوَايَةً - فَذَكَرَ حَدِيثَ الْوَحْىِ قَالَ فَذَلِكَ قَوْلُهُ تَعَالَى ‏\{‏ حَتَّى إِذَا فُزِّعَ عَنْ قُلُوبِهِمْ ‏\}‏ ‏.‏\hadithno{3989}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (4800، 4701)}\hadithtrans{Narrated Abu Hurairah:The Prophet (ﷺ) as saying - the narrator Isma'il transmitted it from Abu Hurairah, and mentioned the tradition about the coming down of revelation-: "So far (is this the case) that when terror is removed from their hearts}}
\hadithdefcmd{abudawud}{3990}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ النَّيْسَابُورِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ الرَّازِيُّ، سَمِعْتُ أَبَا جَعْفَرٍ، يَذْكُرُ عَنِ الرَّبِيعِ بْنِ أَنَسٍ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ قِرَاءَةُ النَّبِيِّ صلى الله عليه وسلم ‏\{‏ بَلَى قَدْ جَاءَتْكِ آيَاتِي فَكَذَّبْتِ بِهَا وَاسْتَكْبَرْتِ وَكُنْتِ مِنَ الْكَافِرِينَ ‏\}‏ قَالَ أَبُو دَاوُدَ هَذَا مُرْسَلٌ الرَّبِيعُ لَمْ يُدْرِكْ أُمَّ سَلَمَةَ ‏.‏\hadithno{3990}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Salamah, wife of the Prophet (ﷺ): The reading of the following verse by the Prophet (ﷺ) goes: "Nay, but there came to thee (ja'atki) my signs, and thou didst reject them (fakadhdhabti biha) ; thou wast haughty (wastakbarti) and became one of those who reject Faith (wa kunti). Abu Dawud said: This is a mursal tradition, i.e. the link of the Companion has been omitted, for the narrator al-Rabi' did not meet Umm Salamah}}
\hadithdefcmd{abudawud}{3991}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هَارُونُ بْنُ مُوسَى النَّحْوِيُّ، عَنْ بُدَيْلِ بْنِ مَيْسَرَةَ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَائِشَةَ، - رضى الله تعالى عنها - قَالَتْ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَؤُهَا ‏\{‏ فَرُوحٌ وَرَيْحَانٌ ‏\}‏ ‏.‏\hadithno{3991}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: I heard the Messenger of Allah (ﷺ) read: "(There is for him) Rest and satisfaction" (faruhun wa rayhan)}}
\hadithdefcmd{abudawud}{3992}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَأَحْمَدُ بْنُ عَبْدَةَ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، - قَالَ ابْنُ حَنْبَلٍ لَمْ أَفْهَمْهُ جَيِّدًا - عَنْ صَفْوَانَ، - قَالَ ابْنُ عَبْدَةَ ابْنِ يَعْلَى - عَنْ أَبِيهِ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم عَلَى الْمِنْبَرِ يَقْرَأُ ‏\{‏ وَنَادَوْا يَا مَالِكُ ‏\}‏ ‏.‏ قَالَ أَبُو دَاوُدَ يَعْنِي بِلاَ تَرْخِيمٍ ‏.‏\hadithno{3992}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (4819) Sahih Muslim (871)}\hadithtrans{Safwan b. Ya'la quoting his father said:I heard the Prophet (ﷺ) read on the pulpit the verse: "They will cry: O Malik." Abu Dawud said: That is, without shortening the name (Malik)}}
\hadithdefcmd{abudawud}{3993}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا أَبُو أَحْمَدَ، أَخْبَرَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ أَقْرَأَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏\{‏ إِنِّي أَنَا الرَّزَّاقُ ذُو الْقُوَّةِ الْمَتِينُ ‏\}‏ ‏.‏\hadithno{3993}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Messenger of Allah (ﷺ) made me read the verse "It is I who give (all) sustenance, Lord of power, steadfast (for ever)}}
\hadithdefcmd{abudawud}{3994}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَؤُهَا ‏\{‏ فَهَلْ مِنْ مُدَّكِرٍ ‏\}‏ يَعْنِي مُثَقَّلاً ‏.‏ قَالَ أَبُو دَاوُدَ مَضْمُومَةَ الْمِيمِ مَفْتُوحَةَ الدَّالِ مَكْسُورَةَ الْكَافِ ‏.‏\hadithno{3994}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Prophet (ﷺ) used to read the verse "Is there any that will receive admonition (muddakir)? " that is with doubling of consonant [(dal)(d)]. Abu Dawud said: The word muddakir may be pronounced as mim (m) with a short vowel u. (dal)(d) with a short vowel and kaf (k) with a short vowel i}}
\hadithdefcmd{abudawud}{3995}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَبْدِ الرَّحْمَنِ الذِّمَارِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ جَابِرٍ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ ‏\{‏ يَحْسَبُ أَنَّ مَالَهُ أَخْلَدَهُ ‏\}‏\hadithno{3995}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: I saw the Prophet (ﷺ) reading the verse; "does he think that his wealth would make him last for ever?}}
\hadithdefcmd{abudawud}{3996}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، عَمَّنْ أَقْرَأَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏\{‏ فَيَوْمَئِذٍ لاَ يُعَذَّبُ عَذَابَهُ أَحَدٌ * وَلاَ يُوثَقُ وَثَاقَهُ أَحَدٌ ‏\}‏ ‏.‏ قَالَ أَبُو دَاوُدَ بَعْضُهُمْ أَدْخَلَ بَيْنَ خَالِدٍ وَأَبِي قِلاَبَةَ رَجُلاً ‏.‏\hadithno{3996}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Qilabah:That the Prophet (ﷺ) made a man read the verse: "For, that day His chastisement will be such as none (else) can be chastised. And his bonds will be such as none (other) can be bound. Abu Dawud said: According to some (scholars), there is a narrator between the narrator Khalid and Abu Qilabah}}
\hadithdefcmd{abudawud}{3997}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادٌ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، قَالَ أَنْبَأَنِي مَنْ، أَقْرَأَهُ النَّبِيُّ صلى الله عليه وسلم أَوْ مَنْ أَقْرَأَهُ مَنْ أَقْرَأَهُ النَّبِيُّ صلى الله عليه وسلم ‏\{‏ فَيَوْمَئِذٍ لاَ يُعَذَّبُ ‏\}‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَرَأَ عَاصِمٌ وَالأَعْمَشُ وَطَلْحَةُ بْنُ مُصَرِّفٍ وَأَبُو جَعْفَرٍ يَزِيدُ بْنُ الْقَعْقَاعِ وَشَيْبَةُ بْنُ نَصَّاحٍ وَنَافِعُ بْنُ عَبْدِ الرَّحْمَنِ وَعَبْدُ اللَّهِ بْنُ كَثِيرٍ الدَّارِيُّ وَأَبُو عَمْرِو بْنِ الْعَلاَءِ وَحَمْزَةُ الزَّيَّاتُ وَعَبْدُ الرَّحْمَنِ الأَعْرَجُ وَقَتَادَةُ وَالْحَسَنُ الْبَصْرِيُّ وَمُجَاهِدٌ وَحُمَيْدٌ الأَعْرَجُ وَعَبْدُ اللَّهِ بْنُ عَبَّاسٍ وَعَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرٍ ‏\{‏ لاَ يُعَذِّبُ ‏\}‏ ‏\{‏ وَلاَ يُوثِقُ ‏\}‏ إِلاَّ الْحَدِيثَ الْمَرْفُوعَ فَإِنَّهُ ‏\{‏ يُعَذَّبُ ‏\}‏ بِالْفَتْحِ ‏.‏\hadithno{3997}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Qilabah: A man whom the Prophet (ﷺ) made the following verse read informed me, or he was informed by a man whom a man made the following verse read through a man whom the Prophet (ﷺ) made the following verse read: "For, that day His chastisement will be such as none (else) can be inflicted (la yu'adhdhabu) Abu Dawud said: 'Asim, al-A'mash, Talhah b. Musarrif, Abu Ja'far Yazid b. al-Qa'qa', Shaibah b. Nassah, Nafi' b. 'Abd al-Rahman, 'Abd Allah b. Kathir al-Dari, Abu 'Amr b. al-'Ala', Hamzat al-Zayyat, 'Abd al-Rahman al-A'raj, Qatadah, al-Hasan al-Basri, Mujahid, Hamid al=A'raj, Abd Allah b. 'Abbas and 'Abd al-Rahman b. Abi Bakr recited: "For,that day His chastisement will be such as none (else) can inflict (la ya'adhdhibu), and His bonds will be such as none (other) can bind (wa la yathiqu), except the verse mentioned in this tradition from the Prophet (ﷺ). It has een read yu'adhdhabu with short vowel a in passive voice}}
\hadithdefcmd{abudawud}{3998}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، أَنَّ مُحَمَّدَ بْنَ أَبِي عُبَيْدَةَ، حَدَّثَهُمْ قَالَ حَدَّثَنَا أَبِي، عَنِ الأَعْمَشِ، عَنْ سَعْدٍ الطَّائِيِّ، عَنْ عَطِيَّةَ الْعَوْفِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ حَدَّثَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَدِيثًا ذَكَرَ فِيهِ ‏ "‏ جِبْرِيلَ وَمِيكَالَ ‏"‏ ‏.‏ فَقَرَأَ ‏\{‏ جِبْرَائِلَ وَمِيكَائِلَ ‏\}‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ خَلَفٌ مُنْذُ أَرْبَعِينَ سَنَةً لَمْ أَرْفَعِ الْقَلَمَ عَنْ كِتَابَةِ الْحُرُوفِ مَا أَعْيَانِي شَىْءٌ مَا أَعْيَانِي جِبْرَائِلُ وَمِيكَائِلُ ‏.‏\hadithno{3998}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: The Messenger of Allah (ﷺ) related a tradition in which he mentioned the words "Jibril and Mikal" and he pronounced them "Jibra'ila wa Mika'ila." Abu Dawud said: Khalaf said: I did not put the pen aside from writing letters (huruf) for forty years: nothing tired me (or made me incapable of writing), even Jibril and Mika'il did not tire me}}
\hadithdefcmd{abudawud}{3999}{حَدَّثَنَا زَيْدُ بْنُ أَخْزَمَ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ عُمَرَ - حَدَّثَنَا مُحَمَّدُ بْنُ خَازِمٍ، قَالَ ذُكِرَ كَيْفَ قِرَاءَةُ جِبْرَائِلَ وَمِيكَائِلَ عِنْدَ الأَعْمَشِ فَحَدَّثَنَا الأَعْمَشُ عَنْ سَعْدٍ الطَّائِيِّ عَنْ عَطِيَّةَ الْعَوْفِيِّ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ قَالَ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم صَاحِبَ الصُّورِ فَقَالَ ‏ "‏ عَنْ يَمِينِهِ جِبْرَائِلُ وَعَنْ يَسَارِهِ مِيكَائِلُ ‏"‏ ‏.‏\hadithno{3999}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: The Messenger of Allah (ﷺ) mentioned the name of the one who will sound the trumpet (sahib as-sur) and said: On his right will be Jibra'il and on his left will be Mika'il}}
\hadithdefcmd{abudawud}{4000}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ مَعْمَرٌ وَرُبَّمَا ذَكَرَ ابْنَ الْمُسَيَّبِ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ يَقْرَءُونَ ‏\{‏ مَالِكِ يَوْمِ الدِّينِ ‏\}‏ وَأَوَّلُ مَنْ قَرَأَهَا ‏\{‏ مَلِكِ يَوْمِ الدِّينِ ‏\}‏ مَرْوَانُ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا أَصَحُّ مِنْ حَدِيثِ الزُّهْرِيِّ عَنْ أَنَسٍ وَالزُّهْرِيِّ عَنْ سَالِمٍ عَنْ أَبِيهِ ‏.‏\hadithno{4000}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn al-Musayyab: The Prophet (ﷺ), AbuBakr, Umar and Uthman used to read "maliki yawmid-din (master of the Day of Judgment)". The first to read maliki yawmid-din was Marwan. Abu Dawud said: This is sounder that the tradition which transmitted by al-Zuhri from Anas, and al-Zuhri from Salim, from his father (Ibn 'Umar)}}
\hadithdefcmd{abudawud}{4001}{حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى الأُمَوِيُّ، حَدَّثَنِي أَبِي، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّهَا ذَكَرَتْ - أَوْ كَلِمَةً غَيْرَهَا - قِرَاءَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏\{‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ * الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ * الرَّحْمَنِ الرَّحِيمِ * مَلِكِ يَوْمِ الدِّينِ ‏\}‏ يَقْطَعُ قِرَاءَتَهُ آيَةً آيَةً ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ أَحْمَدَ يَقُولُ الْقِرَاءَةُ الْقَدِيمَةُ ‏\{‏ مَالِكِ يَوْمِ الدِّينِ ‏\}‏ ‏.‏\hadithno{4001}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: The Messenger of Allah (ﷺ) used to recite: "In the name of Allah, the Cherisher and Sustainer of the worlds; most Gracious, most Merciful; Master of the Day of Judgment," breaking its recitation into verses, one after another. Abu Dawud said: I heard Ahmad (b. Hanbal) say: The early reading is: Maliki yawmi'l-din}}
\hadithdefcmd{abudawud}{4002}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَعُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، - الْمَعْنَى - قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ سُفْيَانَ بْنِ حُسَيْنٍ، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، قَالَ كُنْتُ رَدِيفَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى حِمَارٍ وَالشَّمْسُ عِنْدَ غُرُوبِهَا فَقَالَ ‏"‏ هَلْ تَدْرِي أَيْنَ تَغْرُبُ هَذِهِ ‏"‏ ‏.‏ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ فَإِنَّهَا تَغْرُبُ فِي عَيْنِ حَامِيَةٍ ‏"‏ ‏.‏\hadithno{4002}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Sahih Bukhari (3199، 4802، 4803) Sahih Muslim (159)}\hadithtrans{Narrated Abu Dharr:I was sitting behind the Messenger of Allah (ﷺ) who was riding a donkey while the sun was setting. He asked: Do you know where this sets ? I replied: Allah and his Apostle know best. He said: It sets in a spring of warm water (Hamiyah)}}
\hadithdefcmd{abudawud}{4003}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عُمَرُ بْنُ عَطَاءٍ، أَنَّ مَوْلًى، لاِبْنِ الأَسْقَعِ - رَجُلَ صِدْقٍ - أَخْبَرَهُ عَنِ ابْنِ الأَسْقَعِ أَنَّهُ سَمِعَهُ يَقُولُ إِنَّ النَّبِيَّ صلى الله عليه وسلم جَاءَهُمْ فِي صُفَّةِ الْمُهَاجِرِينَ فَسَأَلَهُ إِنْسَانٌ أَىُّ آيَةٍ فِي الْقُرْآنِ أَعْظَمُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ‏\{‏ اللَّهُ لاَ إِلَهَ إِلاَّ هُوَ الْحَىُّ الْقَيُّومُ لاَ تَأْخُذُهُ سِنَةٌ وَلاَ نَوْمٌ ‏\}‏ ‏"‏ ‏.‏\hadithno{4003}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn al-Asqa':The Prophet (ﷺ) came to them in the swelling place of immigrants and a man asked him: Which is the greatest verse of the Qur'an ? The Prophet (ﷺ) replied: Allah, there is no god but He - the Living, the Self-Subsisting Eternal. No slumber can seize Him nor sleep}}
\hadithdefcmd{abudawud}{4004}{حَدَّثَنَا أَبُو مَعْمَرٍ عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ أَبِي الْحَجَّاجِ الْمِنْقَرِيُّ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا شَيْبَانُ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنِ ابْنِ مَسْعُودٍ، أَنَّهُ قَرَأَ ‏\{‏ هَيْتَ لَكَ ‏\}‏ فَقَالَ شَقِيقٌ إِنَّا نَقْرَؤُهَا ‏\{‏ هِئْتُ لَكَ ‏\}‏ يَعْنِي فَقَالَ ابْنُ مَسْعُودٍ أَقْرَؤُهَا كَمَا عُلِّمْتُ أَحَبُّ إِلَىَّ ‏.‏\hadithno{4004}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4692)}\hadithtrans{Narrated Shariq:Ibn Mas'ud said read the verse: "Now come, thou" (haita laka). Then Shariq said: We read it, "hi'tu laka" (I am prepared for thee). Ibn Mas'ud said: I read it as I have been taught ; it is dearer to me}}
\hadithdefcmd{abudawud}{4005}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، قَالَ قِيلَ لِعَبْدِ اللَّهِ إِنَّ أُنَاسًا يَقْرَءُونَ هَذِهِ الآيَةَ ‏\{‏ وَقَالَتْ هِيتَ لَكَ ‏\}‏ فَقَالَ إِنِّي أَقْرَأُ كَمَا عُلِّمْتُ أَحَبُّ إِلَىَّ ‏\{‏ وَقَالَتْ هَيْتَ لَكَ ‏\}‏ ‏.‏\hadithno{4005}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Shariq:'Abd Allah (b. Mas'ud) was told that the people had read this verse: "She said: Now come, thou" (hita laka). He said: I read it as I have been taught ; it is dearer to me. It goes "wa qalat haita laka" (She said: Now come thou)}}
\hadithdefcmd{abudawud}{4006}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، قَالَ حَدَّثَنَا ح، وَحَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَالَ اللَّهُ عَزَّ وَجَلَّ لِبَنِي إِسْرَائِيلَ ‏\{‏ ادْخُلُوا الْبَابَ سُجَّدًا وَقُولُوا حِطَّةٌ تُغْفَرْ لَكُمْ خَطَايَاكُمْ ‏\}‏ ‏"‏ ‏.‏\hadithno{4006}\hadithgrade{Al-Albani: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Sa’id Al Khudri :The Messenger of Allah (ﷺ) said: Allah, the Exalted, said to the children of Israel : "... but enter the gate with humility, in posture and in words, and you will be forgiven your faults (tughfar lakum)}}
\hadithdefcmd{abudawud}{4007}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ هِشَامِ بْنِ سَعْدٍ، بِإِسْنَادِهِ مِثْلَهُ ‏.‏\hadithno{4007}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Hisham b. Sa'd with a different chain of narrators in a similar way}}
\hadithdefcmd{abudawud}{4008}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، - رضى الله عنها - قَالَتْ نَزَلَ الْوَحْىُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَرَأَ عَلَيْنَا ‏\{‏ سُورَةٌ أَنْزَلْنَاهَا وَفَرَضْنَاهَا ‏\}‏ ‏.‏ قَالَ أَبُو دَاوُدَ يَعْنِي مُخَفَّفَةً حَتَّى أَتَى عَلَى هَذِهِ الآيَاتِ ‏.‏\hadithno{4008}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Aishah: The revelation came down to Messenger of Allah (ﷺ) and he recited to is: "A surah which We have sent down and which We have ordained (faradnaha)" Abu Dawud said: The letter ra (r) is the word faradnaha has short vowel a (with out doubling of consonant r), and then he reached the verses after this verse}}
