% Auto-generated chapter 16 for bukhari
% Hadiths in this chapter: 24

\hadithdefcmd{bukhari}{1040}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَانْكَسَفَتِ الشَّمْسُ، فَقَامَ النَّبِيُّ صلى الله عليه وسلم يَجُرُّ رِدَاءَهُ حَتَّى دَخَلَ الْمَسْجِدَ، فَدَخَلْنَا فَصَلَّى بِنَا رَكْعَتَيْنِ، حَتَّى انْجَلَتِ الشَّمْسُ فَقَالَ صلى الله عليه وسلم ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ، فَإِذَا رَأَيْتُمُوهُمَا فَصَلُّوا، وَادْعُوا، حَتَّى يُكْشَفَ مَا بِكُمْ ‏"‏‏.‏\hadithno{1040}\hadithtrans{Narrated Abu Bakra:We were with Allah's Messenger (ﷺ) when the sun eclipsed. Allah's Messenger (ﷺ) stood up dragging his cloak till he entered the Mosque. He led us in a two-rak`at prayer till the sun (eclipse) had cleared. Then the Prophet (ﷺ) said, "The sun and the moon do not eclipse because of someone's death. So whenever you see these eclipses pray and invoke (Allah) till the eclipse is over}}
\hadithdefcmd{bukhari}{1041}{حَدَّثَنَا شِهَابُ بْنُ عَبَّادٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ حُمَيْدٍ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، قَالَ سَمِعْتُ أَبَا مَسْعُودٍ، يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ مِنَ النَّاسِ، وَلَكِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ، فَإِذَا رَأَيْتُمُوهُمَا فَقُومُوا فَصَلُّوا ‏"‏‏.‏\hadithno{1041}\hadithtrans{Narrated Abu Mas`ud:The Prophet (ﷺ) said, "The sun and the moon do not eclipse because of the death of someone from the people but they are two signs amongst the signs of Allah. When you see them stand up and pray}}
\hadithdefcmd{bukhari}{1042}{حَدَّثَنَا أَصْبَغُ، قَالَ أَخْبَرَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، حَدَّثَهُ عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ كَانَ يُخْبِرُ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ، وَلَكِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ، فَإِذَا رَأَيْتُمُوهَا فَصَلُّوا ‏"‏‏.‏\hadithno{1042}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "The sun and the moon do not eclipse because of the death or life (i.e. birth) of someone but they are two signs amongst the signs of Allah. When you see them offer the prayer}}
\hadithdefcmd{bukhari}{1043}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، قَالَ حَدَّثَنَا شَيْبَانُ أَبُو مُعَاوِيَةَ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ كَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ مَاتَ إِبْرَاهِيمُ، فَقَالَ النَّاسُ كَسَفَتِ الشَّمْسُ لِمَوْتِ إِبْرَاهِيمَ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ، فَإِذَا رَأَيْتُمْ فَصَلُّوا وَادْعُوا اللَّهَ ‏"‏‏.‏\hadithno{1043}\hadithtrans{Narrated Al-Mughira bin Shu`ba:"The sun eclipsed in the lifetime of Allah's Messenger (ﷺ) on the day when (his son) Ibrahim died. So the people said that the sun had eclipsed because of the death of Ibrahim. Allah's Messenger (ﷺ) said, "The sun and the moon do not eclipse because of the death or life (i.e. birth) of someone. When you see the eclipse pray and invoke Allah}}
\hadithdefcmd{bukhari}{1044}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ خَسَفَتِ الشَّمْسُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالنَّاسِ، فَقَامَ فَأَطَالَ الْقِيَامَ، ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ، ثُمَّ قَامَ فَأَطَالَ الْقِيَامَ وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ، وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ سَجَدَ فَأَطَالَ السُّجُودَ، ثُمَّ فَعَلَ فِي الرَّكْعَةِ الثَّانِيَةِ مِثْلَ مَا فَعَلَ فِي الأُولَى، ثُمَّ انْصَرَفَ وَقَدِ انْجَلَتِ الشَّمْسُ، فَخَطَبَ النَّاسَ، فَحَمِدَ اللَّهَ، وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ، لاَ يَنْخَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ، فَإِذَا رَأَيْتُمْ ذَلِكَ فَادْعُوا اللَّهَ وَكَبِّرُوا، وَصَلُّوا وَتَصَدَّقُوا ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ يَا أُمَّةَ مُحَمَّدٍ، وَاللَّهِ مَا مِنْ أَحَدٍ أَغْيَرُ مِنَ اللَّهِ أَنْ يَزْنِيَ عَبْدُهُ أَوْ تَزْنِيَ أَمَتُهُ، يَا أُمَّةَ مُحَمَّدٍ، وَاللَّهِ لَوْ تَعْلَمُونَ مَا أَعْلَمُ لَضَحِكْتُمْ قَلِيلاً وَلَبَكَيْتُمْ كَثِيرًا ‏"‏‏.‏\hadithno{1044}\hadithtrans{Narrated `Aisha:In the lifetime of Allah's Messenger (ﷺ) the sun eclipsed, so he led the people in prayer, and stood up and performed a long Qiyam, then bowed for a long while. He stood up again and performed a long Qiyam but this time the period of standing was shorter than the first. He bowed again for a long time but shorter than the first one, then he prostrated and prolonged the prostration. He did the same in the second rak`a as he did in the first and then finished the prayer; by then the sun (eclipse) had cleared. He delivered the Khutba (sermon) and after praising and glorifying Allah he said, "The sun and the moon are two signs amongst the signs of Allah; they do not eclipse on the death or life of anyone. So when you see the eclipse, remember Allah and say Takbir, pray and give Sadaqa." The Prophet then said, "O followers of Muhammad! By Allah! There is none who has more ghaira (self-respect) than Allah as He has forbidden that His slaves, male or female commit adultery (illegal sexual intercourse). O followers of Muhammad! By Allah! If you knew that which I know you would laugh little and weep much}}
\hadithdefcmd{bukhari}{1045}{حَدَّثَنَا إِسْحَاقُ، قَالَ أَخْبَرَنَا يَحْيَى بْنُ صَالِحٍ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ سَلاَّمِ بْنِ أَبِي سَلاَّمٍ الْحَبَشِيُّ الدِّمَشْقِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ الزُّهْرِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ـ رضى الله عنهما ـ قَالَ لَمَّا كَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم نُودِيَ إِنَّ الصَّلاَةَ جَامِعَةٌ‏.‏\hadithno{1045}\hadithtrans{Narrated `Abdullah bin `Amr:"When the sun eclipsed in the lifetime of Allah's Messenger (ﷺ) an announcement was made that a prayer was to be offered in congregation}}
\hadithdefcmd{bukhari}{1046}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، ح وَحَدَّثَنِي أَحْمَدُ بْنُ صَالِحٍ، قَالَ حَدَّثَنَا عَنْبَسَةُ، قَالَ حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُرْوَةُ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ خَسَفَتِ الشَّمْسُ فِي حَيَاةِ النَّبِيِّ صلى الله عليه وسلم فَخَرَجَ إِلَى الْمَسْجِدِ فَصَفَّ النَّاسُ وَرَاءَهُ، فَكَبَّرَ فَاقْتَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم قِرَاءَةً طَوِيلَةً، ثُمَّ كَبَّرَ فَرَكَعَ رُكُوعًا طَوِيلاً، ثُمَّ قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ فَقَامَ وَلَمْ يَسْجُدْ، وَقَرَأَ قِرَاءَةً طَوِيلَةً، هِيَ أَدْنَى مِنَ الْقِرَاءَةِ الأُولَى، ثُمَّ كَبَّرَ وَرَكَعَ رُكُوعًا طَوِيلاً، وَهْوَ أَدْنَى مِنَ الرُّكُوعِ الأَوَّلِ، ثُمَّ قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ، رَبَّنَا وَلَكَ الْحَمْدُ‏.‏ ثُمَّ سَجَدَ، ثُمَّ قَالَ فِي الرَّكْعَةِ الآخِرَةِ مِثْلَ ذَلِكَ، فَاسْتَكْمَلَ أَرْبَعَ رَكَعَاتٍ فِي أَرْبَعِ سَجَدَاتٍ، وَانْجَلَتِ الشَّمْسُ قَبْلَ أَنْ يَنْصَرِفَ، ثُمَّ قَامَ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏ "‏ هُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ، لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ، فَإِذَا رَأَيْتُمُوهُمَا فَافْزَعُوا إِلَى الصَّلاَةِ ‏"‏‏.‏ وَكَانَ يُحَدِّثُ كَثِيرُ بْنُ عَبَّاسٍ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ ـ رضى الله عنهما ـ كَانَ يُحَدِّثُ يَوْمَ خَسَفَتِ الشَّمْسُ بِمِثْلِ حَدِيثِ عُرْوَةَ عَنْ عَائِشَةَ‏.‏ فَقُلْتُ لِعُرْوَةَ إِنَّ أَخَاكَ يَوْمَ خَسَفَتْ بِالْمَدِينَةِ لَمْ يَزِدْ عَلَى رَكْعَتَيْنِ مِثْلَ الصُّبْحِ‏.‏ قَالَ أَجَلْ لأَنَّهُ أَخْطَأَ السُّنَّةَ‏.‏\hadithno{1046}\hadithtrans{Narrated `Aisha:(the wife of the Prophet (ﷺ) In the lifetime of the Prophet (ﷺ) the sun eclipsed and he went to the Mosque and the people aligned behind him. He said the Takbir (starting the prayer) and prolonged the recitation (from the Qur'an) and then said Takbir and performed a prolonged bowing; then he (lifted his head and) said, "Sami allahu liman hamidah" (Allah heard him who sent his praises to Him). He then did not prostrate but stood up and recited a prolonged recitation which was shorter than the first recitation. He again said Takbir and then bowed a prolonged bowing but shorter than the first one and then said, "Sami`a l-lahu Lyman hamidah Rabbana walak-lhamd, (Allah heard him who sent his praises to Him. O our Sustainer! All the praises are for You)" and then prostrated and did the same in the second rak`a; thus he completed four bowing and four prostrations. The sun (eclipse) had cleared before he finished the prayer. (After the prayer) he stood up, glorified and praised Allah as He deserved and then said, "The sun and the moon are two of the signs of Allah. They do not eclipse because of the death or the life (i.e. birth) of someone. When you see them make haste for the prayer." Narrated Az-Zuhri: I said to 'Urwa, "When the sun eclipsed at Medina your brother (`Abdullah bin Az-Zubair) offered only a two-rak`at prayer like that of the morning (Fajr) prayer." 'Urwa replied, "Yes, for he missed the Prophet's tradition (concerning this matter)}}
\hadithdefcmd{bukhari}{1047}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى يَوْمَ خَسَفَتِ الشَّمْسُ، فَقَامَ فَكَبَّرَ، فَقَرَأَ قِرَاءَةً طَوِيلَةً، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، ثُمَّ رَفَعَ رَأْسَهُ، فَقَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ وَقَامَ كَمَا هُوَ، ثُمَّ قَرَأَ قِرَاءَةً طَوِيلَةً، وَهْىَ أَدْنَى مِنَ الْقِرَاءَةِ الأُولَى، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، وَهْىَ أَدْنَى مِنَ الرَّكْعَةِ الأُولَى، ثُمَّ سَجَدَ سُجُودًا طَوِيلاً، ثُمَّ فَعَلَ فِي الرَّكْعَةِ الآخِرَةِ مِثْلَ ذَلِكَ، ثُمَّ سَلَّمَ وَقَدْ تَجَلَّتِ الشَّمْسُ، فَخَطَبَ النَّاسَ، فَقَالَ فِي كُسُوفِ الشَّمْسِ وَالْقَمَرِ ‏ "‏ إِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ، لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ، فَإِذَا رَأَيْتُمُوهُمَا فَافْزَعُوا إِلَى الصَّلاَةِ ‏"‏‏.‏\hadithno{1047}\hadithtrans{Narrated Aisha:(the wife of the Prophet) On the day when the sun Khasafat (eclipsed) Allah's Messenger (ﷺ) prayed; he stood up and said Takbir and recited a prolonged recitation, then he performed a prolonged bowing, then he raised his head and said, "Sami`a l-lahu Lyman Hamidah," and then remained standing and recited a prolonged recitation which was shorter than the first. Then he performed a prolonged bowing which was shorter than the first. Then he prostrated and prolonged the prostration and he did the same in the second rak`a as in the first and then finished the prayer with Taslim. By that time the sun (eclipse) had cleared He addressed the people and said, "The sun and the moon are two of the signs of Allah; they do not eclipse (Yakhsifan) because of the death or the life (i.e. birth) of someone. So when you see them make haste for the prayer}}
\hadithdefcmd{bukhari}{1048}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ، لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ، وَلَكِنَّ اللَّهَ تَعَالَى يُخَوِّفُ بِهَا عِبَادَهُ ‏"‏‏.‏ وَقَالَ أَبُو عَبْدِ اللَّهِ لَمْ يَذْكُرْ عَبْدُ الْوَارِثِ وَشُعْبَةُ وَخَالِدُ بْنُ عَبْدِ اللَّهِ وَحَمَّادُ بْنُ سَلَمَةَ عَنْ يُونُسَ ‏"‏ يُخَوِّفُ بِهَا عِبَادَهُ ‏"‏‏.‏ وَتَابَعَهُ مُوسَى عَنْ مُبَارَكٍ عَنِ الْحَسَنِ قَالَ أَخْبَرَنِي أَبُو بَكْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ ‏"‏ إِنَّ اللَّهَ تَعَالَى يُخَوِّفُ بِهِمَا عِبَادَهُ ‏"‏‏.‏ وَتَابَعَهُ أَشْعَثُ عَنِ الْحَسَنِ‏.‏\hadithno{1048}\hadithtrans{Narrated Abu Bakra:Allah's Messenger (ﷺ) said: "The sun and the moon are two signs amongst the signs of Allah and they do not eclipse because of the death of someone but Allah frightens His devotees with them}}
\hadithdefcmd{bukhari}{1050}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ يَهُودِيَّةً جَاءَتْ تَسْأَلُهَا فَقَالَتْ لَهَا أَعَاذَكِ اللَّهُ مِنْ عَذَابِ الْقَبْرِ‏.‏ فَسَأَلَتْ عَائِشَةُ ـ رضى الله عنها ـ رَسُولَ اللَّهِ صلى الله عليه وسلم أَيُعَذَّبُ النَّاسُ فِي قُبُورِهِمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَائِذًا بِاللَّهِ مِنْ ذَلِكَ‏.‏ ثُمَّ رَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ غَدَاةٍ مَرْكَبًا، فَخَسَفَتِ الشَّمْسُ، فَرَجَعَ ضُحًى، فَمَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ ظَهْرَانَىِ الْحُجَرِ، ثُمَّ قَامَ يُصَلِّي، وَقَامَ النَّاسُ وَرَاءَهُ، فَقَامَ قِيَامًا طَوِيلاً، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً، وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ رَفَعَ فَسَجَدَ، ثُمَّ قَامَ فَقَامَ قِيَامًا طَوِيلاً، وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ قَامَ قِيَامًا طَوِيلاً وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ رَفَعَ فَسَجَدَ وَانْصَرَفَ، فَقَالَ مَا شَاءَ اللَّهُ أَنْ يَقُولَ، ثُمَّ أَمَرَهُمْ أَنْ يَتَعَوَّذُوا مِنْ عَذَابِ الْقَبْرِ‏.‏\hadithno{1050}\hadithtrans{Narrated `Amra bint `Abdur-Rahman:A Jewess came to ask `Aisha (the wife of the Prophet) about something. She said to her, "May Allah give you refuge from the punishment of the grave." So `Aisha ' asked Allah's Messenger (ﷺ) "Would the people be punished in their graves?" Allah's Messenger (ﷺ) after seeking refuge with Allah from the punishment of the grave (and thus replied in the affirmative). Then one day, Allah's Messenger (ﷺ) rode to go to some place but the sun eclipsed. He returned in the forenoon and passed through the rear of the dwellings (of his wives) and stood for the (eclipse) prayer, and the people stood behind him. He stood up for a long period and then performed a prolonged bowing which was shorter than the first bowing. Then he raised his head and prostrated. Then he stood up (for the second rak`a) for a long while but the standing was shorter than that of the first rak`a. Then he performed a prolonged bowing which was shorter than the first one. Then he raised his head and prostrated. Then he stood up for a long time but shorter than the first. Then he performed a prolonged bowing but shorter than the first. Then he raised his head and prostrated and finished the prayer and (then delivered the sermon and) said as much as Allah wished. And then he ordered the people to seek refuge with Allah from the punishment of the grave}}
\hadithdefcmd{bukhari}{1051}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّهُ قَالَ لَمَّا كَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم نُودِيَ إِنَّ الصَّلاَةَ جَامِعَةٌ فَرَكَعَ النَّبِيُّ صلى الله عليه وسلم رَكْعَتَيْنِ فِي سَجْدَةٍ ثُمَّ قَامَ فَرَكَعَ رَكْعَتَيْنِ فِي سَجْدَةٍ، ثُمَّ جَلَسَ، ثُمَّ جُلِّيَ عَنِ الشَّمْسِ‏.‏ قَالَ وَقَالَتْ عَائِشَةُ ـ رضى الله عنها ـ مَا سَجَدْتُ سُجُودًا قَطُّ كَانَ أَطْوَلَ مِنْهَا‏.‏\hadithno{1051}\hadithtrans{Narrated `Abdullah bin `Amr:When the sun eclipsed in the lifetime of Allah's Messenger (ﷺ) and an announcement was made that the prayer was to be held in congregation. The Prophet (ﷺ) performed two bowing in one rak`a. Then he stood up and performed two bowing in one rak`a. Then he sat down and finished the prayer; and by then the (eclipse) had cleared `Aisha said, "I had never performed such a long prostration}}
\hadithdefcmd{bukhari}{1052}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ انْخَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم، فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم، فَقَامَ قِيَامًا طَوِيلاً نَحْوًا مِنْ قِرَاءَةِ سُورَةِ الْبَقَرَةِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً، وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ سَجَدَ، ثُمَّ قَامَ قِيَامًا طَوِيلاً وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً، وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ سَجَدَ، ثُمَّ انْصَرَفَ وَقَدْ تَجَلَّتِ الشَّمْسُ، فَقَالَ صلى الله عليه وسلم ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ، لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ، فَإِذَا رَأَيْتُمْ ذَلِكَ فَاذْكُرُوا اللَّهَ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ، رَأَيْنَاكَ تَنَاوَلْتَ شَيْئًا فِي مَقَامِكَ، ثُمَّ رَأَيْنَاكَ كَعْكَعْتَ‏.‏ قَالَ صلى الله عليه وسلم ‏"‏ إِنِّي رَأَيْتُ الْجَنَّةَ، فَتَنَاوَلْتُ عُنْقُودًا، وَلَوْ أَصَبْتُهُ لأَكَلْتُمْ مِنْهُ مَا بَقِيَتِ الدُّنْيَا، وَأُرِيتُ النَّارَ، فَلَمْ أَرَ مَنْظَرًا كَالْيَوْمِ قَطُّ أَفْظَعَ، وَرَأَيْتُ أَكْثَرَ أَهْلِهَا النِّسَاءَ ‏"‏‏.‏ قَالُوا بِمَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ بِكُفْرِهِنَّ ‏"‏‏.‏ قِيلَ يَكْفُرْنَ بِاللَّهِ قَالَ ‏"‏ يَكْفُرْنَ الْعَشِيرَ، وَيَكْفُرْنَ الإِحْسَانَ، لَوْ أَحْسَنْتَ إِلَى إِحْدَاهُنَّ الدَّهْرَ كُلَّهُ، ثُمَّ رَأَتْ مِنْكَ شَيْئًا قَالَتْ مَا رَأَيْتُ مِنْكَ خَيْرًا قَطُّ ‏"‏‏.‏\hadithno{1052}\hadithtrans{Narrated `Abdullah bin `Abbas:The sun eclipsed in the lifetime of the Prophet (ﷺ) . Allah's Messenger (ﷺ) offered the eclipse prayer and stood for a long period equal to the period in which one could recite Surat-al-Baqara. Then he bowed for a long time and then stood up for a long period which was shorter than that of the first standing, then bowed again for a long time but for a shorter period than the first; then he prostrated twice and then stood up for a long period which was shorter than that of the first standing; then he bowed for a long time which was shorter than the previous one, and then he raised his head and stood up for a long period which was shorter than the first standing, then he bowed for a long time which was shorter than the first bowing, and then prostrated (twice) and finished the prayer. By then, the sun (eclipse) had cleared. The Prophet (ﷺ) then said, "The sun and the moon are two of the signs of Allah. They eclipse neither because of the death of somebody nor because of his life (i.e. birth). So when you see them, remember Allah." The people said, "O Allah's Messenger (ﷺ)! We saw you taking something from your place and then we saw you retreating." The Prophet (ﷺ) replied, "I saw Paradise and stretched my hands towards a bunch (of its fruits) and had I taken it, you would have eaten from it as long as the world remains. I also saw the Hell-fire and I had never seen such a horrible sight. I saw that most of the inhabitants were women." The people asked, "O Allah's Messenger (ﷺ)! Why is it so?" The Prophet (ﷺ) replied, "Because of their ungratefulness." It was asked whether they are ungrateful to Allah. The Prophet said, "They are ungrateful to their companions of life (husbands) and ungrateful to good deeds. If you are benevolent to one of them throughout the life and if she sees anything (undesirable) in you, she will say, 'I have never had any good from you}}
\hadithdefcmd{bukhari}{1053}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنِ امْرَأَتِهِ، فَاطِمَةَ بِنْتِ الْمُنْذِرِ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ أَنَّهَا قَالَتْ أَتَيْتُ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم حِينَ خَسَفَتِ الشَّمْسُ، فَإِذَا النَّاسُ قِيَامٌ يُصَلُّونَ، وَإِذَا هِيَ قَائِمَةٌ تُصَلِّي فَقُلْتُ مَا لِلنَّاسِ فَأَشَارَتْ بِيَدِهَا إِلَى السَّمَاءِ، وَقَالَتْ سُبْحَانَ اللَّهِ‏.‏ فَقُلْتُ آيَةٌ فَأَشَارَتْ أَىْ نَعَمْ‏.‏ قَالَتْ فَقُمْتُ حَتَّى تَجَلاَّنِي الْغَشْىُ، فَجَعَلْتُ أَصُبُّ فَوْقَ رَأْسِي الْمَاءَ، فَلَمَّا انْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏ "‏ مَا مِنْ شَىْءٍ كُنْتُ لَمْ أَرَهُ إِلاَّ قَدْ رَأَيْتُهُ فِي مَقَامِي هَذَا حَتَّى الْجَنَّةَ وَالنَّارَ، وَلَقَدْ أُوحِيَ إِلَىَّ أَنَّكُمْ تُفْتَنُونَ فِي الْقُبُورِ مِثْلَ ـ أَوْ قَرِيبًا مِنْ ـ فِتْنَةِ الدَّجَّالِ ـ لاَ أَدْرِي أَيَّتَهُمَا قَالَتْ أَسْمَاءُ ـ يُؤْتَى أَحَدُكُمْ فَيُقَالُ لَهُ مَا عِلْمُكَ بِهَذَا الرَّجُلِ فَأَمَّا الْمُؤْمِنُ ـ أَوِ الْمُوقِنُ لاَ أَدْرِي أَىَّ ذَلِكَ قَالَتْ أَسْمَاءُ ـ فَيَقُولُ مُحَمَّدٌ رَسُولُ اللَّهِ صلى الله عليه وسلم جَاءَنَا بِالْبَيِّنَاتِ وَالْهُدَى، فَأَجَبْنَا وَآمَنَّا وَاتَّبَعْنَا‏.‏ فَيُقَالُ لَهُ نَمْ صَالِحًا، فَقَدْ عَلِمْنَا إِنْ كُنْتَ لَمُوقِنًا‏.‏ وَأَمَّا الْمُنَافِقُ ـ أَوِ الْمُرْتَابُ لاَ أَدْرِي أَيَّتَهُمَا قَالَتْ أَسْمَاءُ ـ فَيَقُولُ لاَ أَدْرِي، سَمِعْتُ النَّاسَ يَقُولُونَ شَيْئًا فَقُلْتُهُ ‏"‏‏.‏\hadithno{1053}\hadithtrans{Narrated Fatima bint Al-Mundhir:Asma' bint Abu Bakr said, "I came to `Aisha the wife of the Prophet (ﷺ) during the solar eclipse. The people were standing and offering the prayer and she was also praying too. I asked her, 'What has happened to the people?' She pointed out with her hand towards the sky and said, 'Subhan-Allah'. I said, 'Is there a sign?' She pointed out in the affirmative." Asma' further said, "I too then stood up for the prayer till I fainted and then poured water on my head. When Allah's Messenger (ﷺ) had finished his prayer, he thanked and praised Allah and said, 'I have seen at this place of mine what I have never seen even Paradise and Hell. No doubt, it has been inspired to me that you will be put to trial in the graves like or nearly like the trial of (Masih) Ad-Dajjal. (I do not know which one of the two Asma' said.) (The angels) will come to everyone of you and will ask what do you know about this man (i.e. Muhammad). The believer or a firm believer (I do not know which word Asma' said) will reply, 'He is Muhammad, Allah's Messenger (ﷺ) who came to us with clear evidences and guidance, so we accepted his teachings, believed and followed him.' The angels will then say to him, 'Sleep peacefully as we knew surely that you were a firm believer.' The hypocrite or doubtful person (I do not know which word Asma' said) will say, 'I do not know. I heard the people saying something so I said it (the same)}}
\hadithdefcmd{bukhari}{1054}{حَدَّثَنَا رَبِيعُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا زَائِدَةُ، عَنْ هِشَامٍ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، قَالَتْ لَقَدْ أَمَرَ النَّبِيُّ صلى الله عليه وسلم بِالْعَتَاقَةِ فِي كُسُوفِ الشَّمْسِ‏.‏\hadithno{1054}\hadithtrans{Narrated Asma:No doubt the Prophet (ﷺ) ordered people to manumit slaves during the solar eclipse}}
\hadithdefcmd{bukhari}{1056}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ يَهُودِيَّةً، جَاءَتْ تَسْأَلُهَا فَقَالَتْ أَعَاذَكِ اللَّهُ مِنْ عَذَابِ الْقَبْرِ‏.‏ فَسَأَلَتْ عَائِشَةُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَيُعَذَّبُ النَّاسُ فِي قُبُورِهِمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَائِذًا بِاللَّهِ مِنْ ذَلِكَ‏.‏ ثُمَّ رَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ غَدَاةٍ مَرْكَبًا، فَكَسَفَتِ الشَّمْسُ فَرَجَعَ ضُحًى، فَمَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ ظَهْرَانَىِ الْحُجَرِ، ثُمَّ قَامَ فَصَلَّى، وَقَامَ النَّاسُ وَرَاءَهُ، فَقَامَ قِيَامًا طَوِيلاً، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً، وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ رَفَعَ فَسَجَدَ سُجُودًا طَوِيلاً ثُمَّ قَامَ فَقَامَ قِيَامًا طَوِيلاً، وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ قَامَ قِيَامًا طَوِيلاً، وَهْوَ دُونَ الْقِيَامِ الأَوَّلِ، ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً، وَهْوَ دُونَ الرُّكُوعِ الأَوَّلِ، ثُمَّ سَجَدَ وَهْوَ دُونَ السُّجُودِ الأَوَّلِ، ثُمَّ انْصَرَفَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا شَاءَ اللَّهُ أَنْ يَقُولَ، ثُمَّ أَمَرَهُمْ أَنْ يَتَعَوَّذُوا مِنْ عَذَابِ الْقَبْرِ\hadithno{1056}\hadithtrans{Narrated `Amra bint `Abdur-Rahman:A Jewess came to `Aisha to ask her about something and then she said, "May Allah give you refuge from the punishment of the grave." So `Aisha asked Allah's Messenger (ﷺ), "Would the people be punished in their graves?" Allah's Messenger (ﷺ) asked Allah's refuge from the punishment of the grave (indicating an affirmative reply). Then one day Allah's Messenger (ﷺ) rode (to leave for some place) but the sun eclipsed. He returned on the forenoon and passed through the rear of the dwellings (of his wives) and stood up and started offering the (eclipse) prayer and the people stood behind him. He stood for a long period and then performed a long bowing and then stood straight for a long period which was shorter than that of the first standing, then he performed a prolonged bowing which was shorter than the first bowing, then he raised his head and prostrated for a long time and then stood up (for the second rak`a) for a long while, but the standing was shorter than the standing of the first rak`a. Then he performed a prolonged bowing which was shorter than that of the first one. He then stood up for a long time but shorter than the first, then again performed a long bowing which was shorter than the first and then prostrated for a shorter while than that of the first prostration. Then he finished the prayer and delivered the sermon and) said what Allah wished; and ordered the people to seek refuge with Allah from the punishment of the grave}}
\hadithdefcmd{bukhari}{1057}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، قَالَ حَدَّثَنِي قَيْسٌ، عَنْ أَبِي مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشَّمْسُ وَالْقَمَرُ لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ، وَلَكِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ، فَإِذَا رَأَيْتُمُوهُمَا فَصَلُّوا ‏"‏‏.‏\hadithno{1057}\hadithtrans{Narrated Abu Mas`ud:Allah's Messenger (ﷺ) said, "The sun and the moon do not eclipse because of someone's death or life but they are two signs amongst the signs of Allah, so pray whenever you see them}}
\hadithdefcmd{bukhari}{1058}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، وَهِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَصَلَّى بِالنَّاسِ، فَأَطَالَ الْقِرَاءَةَ، ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ، ثُمَّ رَفَعَ رَأْسَهُ فَأَطَالَ الْقِرَاءَةَ، وَهْىَ دُونَ قِرَاءَتِهِ الأُولَى، ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ دُونَ رُكُوعِهِ الأَوَّلِ، ثُمَّ رَفَعَ رَأْسَهُ فَسَجَدَ سَجْدَتَيْنِ، ثُمَّ قَامَ فَصَنَعَ فِي الرَّكْعَةِ الثَّانِيَةِ مِثْلَ ذَلِكَ، ثُمَّ قَامَ فَقَالَ ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ، وَلَكِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ يُرِيهِمَا عِبَادَهُ، فَإِذَا رَأَيْتُمْ ذَلِكَ فَافْزَعُوا إِلَى الصَّلاَةِ ‏"‏‏.‏\hadithno{1058}\hadithtrans{Narrated `Aisha:In the lifetime of the Prophet (ﷺ) the sun eclipsed and the Prophet (ﷺ) stood up to offer the prayer with the people and recited a long recitation, then he performed a prolonged bowing, and then lifted his head and recited a prolonged recitation which was shorter than the first. Then he performed a prolonged bowing which was shorter than the first and then lifted his head and performed two prostrations. He then stood up for the second rak`a and offered it like the first. Then he stood up and said, "The sun and the moon do not eclipse because of someone's life or death but they are two signs amongst the signs of Allah which He shows to His worshipers. So whenever you see them, make haste for the prayer}}
\hadithdefcmd{bukhari}{1059}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ خَسَفَتِ الشَّمْسُ، فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَزِعًا، يَخْشَى أَنْ تَكُونَ السَّاعَةُ، فَأَتَى الْمَسْجِدَ، فَصَلَّى بِأَطْوَلِ قِيَامٍ وَرُكُوعٍ وَسُجُودٍ رَأَيْتُهُ قَطُّ يَفْعَلُهُ وَقَالَ ‏ "‏ هَذِهِ الآيَاتُ الَّتِي يُرْسِلُ اللَّهُ لاَ تَكُونُ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ، وَلَكِنْ يُخَوِّفُ اللَّهُ بِهِ عِبَادَهُ، فَإِذَا رَأَيْتُمْ شَيْئًا مِنْ ذَلِكَ فَافْزَعُوا إِلَى ذِكْرِهِ وَدُعَائِهِ وَاسْتِغْفَارِهِ ‏"‏‏.‏\hadithno{1059}\hadithtrans{Narrated Abu Musa:The sun eclipsed and the Prophet (ﷺ) got up, being afraid that it might be the Hour (i.e. Day of Judgment). He went to the Mosque and offered the prayer with the longest Qiyam, bowing and prostration that I had ever seen him doing. Then he said, "These signs which Allah sends do not occur because of the life or death of somebody, but Allah makes His worshipers afraid by them. So when you see anything thereof, proceed to remember Allah, invoke Him and ask for His forgiveness}}
\hadithdefcmd{bukhari}{1060}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا زَائِدَةُ، قَالَ حَدَّثَنَا زِيَادُ بْنُ عِلاَقَةَ، قَالَ سَمِعْتُ الْمُغِيرَةَ بْنَ شُعْبَةَ، يَقُولُ انْكَسَفَتِ الشَّمْسُ يَوْمَ مَاتَ إِبْرَاهِيمُ، فَقَالَ النَّاسُ انْكَسَفَتْ لِمَوْتِ إِبْرَاهِيمَ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ، لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ، فَإِذَا رَأَيْتُمُوهُمَا فَادْعُوا اللَّهَ وَصَلُّوا حَتَّى يَنْجَلِيَ ‏"‏‏.‏\hadithno{1060}\hadithtrans{Narrated Al-Mughira bin Shu`ba:On the day of Ibrahim's death, the sun eclipsed and the people said that the eclipse was due to the death of Ibrahim (the son of the Prophet). Allah's Messenger (ﷺ) said, "The sun and the moon are two signs amongst the signs of Allah. They do not eclipse because of someone's death or life. So when you see them, invoke Allah and pray till the eclipse is clear}}
\hadithdefcmd{bukhari}{1061}{وَقَالَ أَبُو أُسَامَةَ حَدَّثَنَا هِشَامٌ، قَالَ أَخْبَرَتْنِي فَاطِمَةُ بِنْتُ الْمُنْذِرِ، عَنْ أَسْمَاءَ، قَالَتْ فَانْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ تَجَلَّتِ الشَّمْسُ فَخَطَبَ، فَحَمِدَ اللَّهَ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏ "‏ أَمَّا بَعْدُ ‏"‏‏.‏\hadithno{1061}\hadithtrans{And this was narrated by Asma' who said, "Allah's Messenger (ﷺ) finished the eclipse prayer and by then the sun (eclipse) had cleared. Then he delivered the Khutba (religious talk) and praised Allah as He deserved and then said Amma ba'du}}
\hadithdefcmd{bukhari}{1062}{حَدَّثَنَا مَحْمُودٌ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ، عَنْ شُعْبَةَ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ ـ رضى الله عنه ـ قَالَ انْكَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى رَكْعَتَيْنِ‏.‏\hadithno{1062}\hadithtrans{Narrated Abu Bakra:In the lifetime of the Prophet (ﷺ) the sun eclipsed and then he offered a two rak`at prayer}}
\hadithdefcmd{bukhari}{1063}{حَدَّثَنَا أَبُو مَعْمَرٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا يُونُسُ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ خَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَخَرَجَ يَجُرُّ رِدَاءَهُ حَتَّى انْتَهَى إِلَى الْمَسْجِدِ، وَثَابَ النَّاسُ إِلَيْهِ فَصَلَّى بِهِمْ رَكْعَتَيْنِ، فَانْجَلَتِ الشَّمْسُ فَقَالَ ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ، وَإِنَّهُمَا لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ، وَإِذَا كَانَ ذَاكَ فَصَلُّوا وَادْعُوا حَتَّى يُكْشَفَ مَا بِكُمْ ‏"‏‏.‏ وَذَاكَ أَنَّ ابْنًا لِلنَّبِيِّ صلى الله عليه وسلم مَاتَ، يُقَالُ لَهُ إِبْرَاهِيمُ، فَقَالَ النَّاسُ فِي ذَاكَ‏.‏\hadithno{1063}\hadithtrans{Narrated Abu Bakra:In the lifetime of Allah's Messenger (ﷺ) the sun eclipsed and he went out dragging his clothes till he reached the Mosque. The people gathered around him and he led them and offered two rak`at. When the sun (eclipse) cleared, he said, "The sun and the moon are two signs amongst the signs of Allah; they do not eclipse because of the death of someone, and so when an eclipse occurs, pray and invoke Allah till the eclipse is over." It happened that a son of the Prophet (ﷺ) called Ibrahim died on that day and the people were talking about that (saying that the eclipse was caused by his death)}}
\hadithdefcmd{bukhari}{1064}{حَدَّثَنَا مَحْمُودٌ، قَالَ حَدَّثَنَا أَبُو أَحْمَدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ يَحْيَى، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى بِهِمْ فِي كُسُوفِ الشَّمْسِ أَرْبَعَ رَكَعَاتٍ فِي سَجْدَتَيْنِ، الأَوَّلُ الأَوَّلُ أَطْوَلُ‏.‏\hadithno{1064}\hadithtrans{Narrated Aisha:The Prophet (ﷺ) led us and performed four bowing in two rak`at during the solar eclipse and the first rak`a was longer}}
\hadithdefcmd{bukhari}{1066}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ أَخْبَرَنَا ابْنُ نَمِرٍ، سَمِعَ ابْنَ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ جَهَرَ النَّبِيُّ صلى الله عليه وسلم فِي صَلاَةِ الْخُسُوفِ بِقِرَاءَتِهِ، فَإِذَا فَرَغَ مِنْ قِرَاءَتِهِ كَبَّرَ فَرَكَعَ، وَإِذَا رَفَعَ مِنَ الرَّكْعَةِ قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ، رَبَّنَا وَلَكَ الْحَمْدُ‏.‏ ثُمَّ يُعَاوِدُ الْقِرَاءَةَ فِي صَلاَةِ الْكُسُوفِ، أَرْبَعَ رَكَعَاتٍ فِي رَكْعَتَيْنِ وَأَرْبَعَ سَجَدَاتٍ‏.‏ وَقَالَ الأَوْزَاعِيُّ وَغَيْرُهُ سَمِعْتُ الزُّهْرِيَّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ الشَّمْسَ، خَسَفَتْ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَعَثَ مُنَادِيًا بِالصَّلاَةُ جَامِعَةٌ، فَتَقَدَّمَ فَصَلَّى أَرْبَعَ رَكَعَاتٍ فِي رَكْعَتَيْنِ وَأَرْبَعَ سَجَدَاتٍ‏.‏ وَأَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ نَمِرٍ سَمِعَ ابْنَ شِهَابٍ مِثْلَهُ‏.‏ قَالَ الزُّهْرِيُّ فَقُلْتُ مَا صَنَعَ أَخُوكَ ذَلِكَ، عَبْدُ اللَّهِ بْنُ الزُّبَيْرِ مَا صَلَّى إِلاَّ رَكْعَتَيْنِ مِثْلَ الصُّبْحِ إِذْ صَلَّى بِالْمَدِينَةِ‏.‏ قَالَ أَجَلْ، إِنَّهُ أَخْطَأَ السُّنَّةَ‏.‏ تَابَعَهُ سُفْيَانُ بْنُ حُسَيْنٍ وَسُلَيْمَانُ بْنُ كَثِيرٍ عَنِ الزُّهْرِيِّ فِي الْجَهْرِ‏.‏\hadithno{1066}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) recited (the Qur'an) aloud during the eclipse prayer and when he had finished the eclipse prayer he said the Takbir and bowed. When he stood straight from bowing he would say "Sami 'allahu liman hamidah Rabbana wa laka l-hamd." And he would again start reciting. In the eclipse prayer there are four bowing and four prostrations in two rak`at. Al-Auza'i and others said that they had heard Az-Zuhri from 'Urwa from `Aisha saying, "In the lifetime of Allah's Messenger (ﷺ) the sun eclipsed, and he made a person to announce: 'Prayer in congregation.' He led the prayer and performed four bowing and four prostrations in two rak`at." Narrated Al-Walid that `Abdur-Rahman bin Namir had informed him that he had heard the same. Ibn Shihab heard the same. Az-Zuhri said, "I asked ('Urwa), 'What did your brother `Abdullah bin Az-Zubair do? He prayed two rak`at (of the eclipse prayer) like the morning prayer, when he offered the (eclipse) prayer in Medina.' 'Urwa replied that he had missed (i.e. did not pray according to) the Prophet's tradition." Sulaiman bin Kathir and Sufyan bin Husain narrated from Az-Zuhri that the prayer for the eclipse used to be offered with loud recitation}}
