% Auto-generated chapter 18 for abudawud
% Hadiths in this chapter: 23

\hadithdefcmd{abudawud}{2862}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ، - يَعْنِي ابْنَ عُمَرَ - عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا حَقُّ امْرِئٍ مُسْلِمٍ لَهُ شَىْءٌ يُوصِي فِيهِ يَبِيتُ لَيْلَتَيْنِ إِلاَّ وَوَصِيَّتُهُ مَكْتُوبَةٌ عِنْدَهُ ‏"‏ ‏.‏\hadithno{2862}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2738) Sahih Muslim (1627)}\hadithtrans{Narrated 'Abdullah bin 'Umar:The Messenger of Allah (ﷺ) as saying: It is the duty of a Muslim man who has something which is to be given as bequest not to have it for two nights without having his will written regarding it}}
\hadithdefcmd{abudawud}{2863}{حَدَّثَنَا مُسَدَّدٌ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ مَا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم دِينَارًا وَلاَ دِرْهَمًا وَلاَ بَعِيرًا وَلاَ شَاةً وَلاَ أَوْصَى بِشَىْءٍ ‏.‏\hadithno{2863}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1635)}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) did not leave dinars, dirhams, camels and goats, nor did he leave will for anything}}
\hadithdefcmd{abudawud}{2864}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَابْنُ أَبِي خَلَفٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ مَرِضَ مَرَضًا - قَالَ ابْنُ أَبِي خَلَفٍ - بِمَكَّةَ - ثُمَّ اتَّفَقَا - أَشْفَى فِيهِ فَعَادَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ لِي مَالاً كَثِيرًا وَلَيْسَ يَرِثُنِي إِلاَّ ابْنَتِي أَفَأَتَصَدَّقُ بِالثُّلُثَيْنِ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قَالَ فَبِالشَّطْرِ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قَالَ فَبِالثُّلُثِ قَالَ ‏"‏ الثُّلُثُ وَالثُّلُثُ كَثِيرٌ إِنَّكَ أَنْ تَتْرُكَ وَرَثَتَكَ أَغْنِيَاءَ خَيْرٌ مِنْ أَنْ تَدَعَهُمْ عَالَةً يَتَكَفَّفُونَ النَّاسَ وَإِنَّكَ لَنْ تُنْفِقَ نَفَقَةً إِلاَّ أُجِرْتَ بِهَا حَتَّى اللُّقْمَةَ تَرْفَعُهَا إِلَى فِي امْرَأَتِكَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ أَتَخَلَّفُ عَنْ هِجْرَتِي قَالَ ‏"‏ إِنَّكَ إِنْ تُخَلَّفْ بَعْدِي فَتَعْمَلْ عَمَلاً صَالِحًا تُرِيدُ بِهِ وَجْهَ اللَّهِ لاَ تَزْدَادُ بِهِ إِلاَّ رِفْعَةً وَدَرَجَةً لَعَلَّكَ أَنْ تُخَلَّفَ حَتَّى يَنْتَفِعَ بِكَ أَقْوَامٌ وَيُضَرَّ بِكَ آخَرُونَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ أَمْضِ لأَصْحَابِي هِجْرَتَهُمْ وَلاَ تَرُدَّهُمْ عَلَى أَعْقَابِهِمْ لَكِنِ الْبَائِسُ سَعْدُ ابْنُ خَوْلَةَ يَرْثِي لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ مَاتَ بِمَكَّةَ ‏"‏ ‏.‏\hadithno{2864}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6373) Sahih Muslim (1628)}\hadithtrans{Narrated 'Amir b. Sa'd:On the authority of his father (Sa'd b. Abi Waqqas): When he (Sa'd) fell ill at Mecca (according to the version of Ibn Abi Kkalaf) - then the agreed version has: which brought him near to death - the Messenger of Allah (ﷺ) went to visit him. He said: Messenger of Allah, I have a large amount of property, and my daughter is my only heir. May I give two-thirds (of my property) as a sadaqah (charity)? He said: No. He asked: Then a half ? He replied: No. He asked: Then one-third ? He replied: (You may will away) a third and third is a lot. To leave your heirs rich is better than to leave them poor begging from people. You will not spend anything, seeking thereby to please Allah, without being rewarded for it, even the mouthful you give your wife. I said: Messenger of Allah, shall I be left behind form immigration (to Medina)? He said: If you remain behind after me and do good works seeking the pleasure of Allah, your rank will be raised and degree increased. Perhaps you will not remain behind, and some people will benefit from you and others will be harmed by you. He then said: O Allah, complete the immigration of my Companions and do not turn them back. But miserable was Sa'd b. Khawlah. The Messenger of Allah (ﷺ) lamented on him as he died at Mecca}}
\hadithdefcmd{abudawud}{2865}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا عُمَارَةُ بْنُ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَجُلٌ لِلنَّبِيِّ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ أَىُّ الصَّدَقَةِ أَفْضَلُ قَالَ ‏ "‏ أَنْ تَصَدَّقَ وَأَنْتَ صَحِيحٌ حَرِيصٌ تَأْمُلُ الْبَقَاءَ وَتَخْشَى الْفَقْرَ وَلاَ تُمْهِلْ حَتَّى إِذَا بَلَغَتِ الْحُلْقُومَ قُلْتَ لِفُلاَنٍ كَذَا وَلِفُلاَنٍ كَذَا وَقَدْ كَانَ لِفُلاَنٍ ‏"‏ ‏.‏\hadithno{2865}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1419) Sahih Muslim (1032)}\hadithtrans{Narrated Abu Hurairah:A man asked the Messenger of Allah (ﷺ): Messenger of Allah, which sadaqah (charity) is the best ? He replied: (The best sadaqah is) that you give something as sadaqah (charity) when you are healthy, greedy, expect survival and fear poverty, and not that you postpone it until your death. and then you say: For so-and-so is such-and-such, and for so-and-so is such-and-such, while it was already for so-and-so}}
\hadithdefcmd{abudawud}{2866}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنِي ابْنُ أَبِي ذِئْبٍ، عَنْ شُرَحْبِيلَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لأَنْ يَتَصَدَّقَ الْمَرْءُ فِي حَيَاتِهِ بِدِرْهَمٍ خَيْرٌ لَهُ مِنْ أَنْ يَتَصَدَّقَ بِمِائَةٍ عِنْدَ مَوْتِهِ ‏"‏ ‏.‏\hadithno{2866}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) said: A man giving a dirham as sadaqah (charity) during his life is better than giving one hundred dirhams as sadaqah (charity) at the moment of his death}}
\hadithdefcmd{abudawud}{2867}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، أَخْبَرَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْحُدَّانِيُّ، حَدَّثَنَا الأَشْعَثُ بْنُ جَابِرٍ، حَدَّثَنِي شَهْرُ بْنُ حَوْشَبٍ، أَنَّ أَبَا هُرَيْرَةَ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الرَّجُلَ لَيَعْمَلُ وَالْمَرْأَةَ بِطَاعَةِ اللَّهِ سِتِّينَ سَنَةً ثُمَّ يَحْضُرُهُمَا الْمَوْتُ فَيُضَارَّانِ فِي الْوَصِيَّةِ فَتَجِبُ لَهُمَا النَّارُ ‏"‏ ‏.‏ قَالَ وَقَرَأَ عَلَىَّ أَبُو هُرَيْرَةَ مِنْ هَا هُنَا ‏\{‏ مِنْ بَعْدِ وَصِيَّةٍ يُوصَى بِهَا أَوْ دَيْنٍ غَيْرَ مُضَارٍّ ‏\}‏ حَتَّى بَلَغَ ‏\{‏ ذَلِكَ الْفَوْزُ الْعَظِيمُ ‏\}‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا - يَعْنِي الأَشْعَثَ بْنَ جَابِرٍ - جَدُّ نَصْرِ بْنِ عَلِيٍّ ‏.‏\hadithno{2867}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: A man or a woman acts in obedience to Allah for sixty years, then when they are about to die they cause injury by their will, so they must go to Hell. Then AbuHurayrah recited: "After a legacy which you bequeath or a debt, causing no injury...that will be the mighty success. Abu Dawud said: Al-Ash'ath b. Jabir is the grandfather of Nasr b. 'Ali}}
\hadithdefcmd{abudawud}{2868}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو عَبْدِ الرَّحْمَنِ الْمُقْرِئُ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ سَالِمِ بْنِ أَبِي سَالِمٍ الْجَيْشَانِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا أَبَا ذَرٍّ إِنِّي أَرَاكَ ضَعِيفًا وَإِنِّي أُحِبُّ لَكَ مَا أُحِبُّ لِنَفْسِي فَلاَ تَأَمَّرَنَّ عَلَى اثْنَيْنِ وَلاَ تَوَلَّيَنَّ مَالَ يَتِيمٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ تَفَرَّدَ بِهِ أَهْلُ مِصْرَ ‏.‏\hadithno{2868}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1826)}\hadithtrans{Narrated Abu Dharr: The Messenger of Allah (ﷺ) said to me: Abu Dharr, I see you weak, and I like for you what I like for myself. Do not be a leader of two (persons), and do not be a guardian of an orphan. Abu Dawud said: This has been narrated only by the people of Egypt}}
\hadithdefcmd{abudawud}{2869}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنِ بْنِ وَاقِدٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، ‏\{‏ إِنْ تَرَكَ خَيْرًا الْوَصِيَّةُ لِلْوَالِدَيْنِ وَالأَقْرَبِينَ ‏\}‏ فَكَانَتِ الْوَصِيَّةُ كَذَلِكَ حَتَّى نَسَخَتْهَا آيَةُ الْمِيرَاثِ ‏.‏\hadithno{2869}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Abbas:The Qur'anic verse goes: "(It is prescribed when death approaches any of you), if he leaves any goods, that he may bequest to parents and next to kin." The bequest was made in this way until the verse of inheritance repealed it}}
\hadithdefcmd{abudawud}{2870}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ، حَدَّثَنَا ابْنُ عَيَّاشٍ، عَنْ شُرَحْبِيلَ بْنِ مُسْلِمٍ، سَمِعْتُ أَبَا أُمَامَةَ، سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ قَدْ أَعْطَى كُلَّ ذِي حَقٍّ حَقَّهُ فَلاَ وَصِيَّةَ لِوَارِثٍ ‏"‏ ‏.‏\hadithno{2870}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuHurayrah: I heard the Messenger of Allah (ﷺ) say: Allah has appointed for everyone who has a right what is due to him, and no bequest must be made to an heir}}
\hadithdefcmd{abudawud}{2871}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ عَطَاءٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَلاَ تَقْرَبُوا مَالَ الْيَتِيمِ إِلاَّ بِالَّتِي هِيَ أَحْسَنُ ‏\}‏ وَ ‏\{‏ إِنَّ الَّذِينَ يَأْكُلُونَ أَمْوَالَ الْيَتَامَى ظُلْمًا ‏\}‏ الآيَةَ انْطَلَقَ مَنْ كَانَ عِنْدَهُ يَتِيمٌ فَعَزَلَ طَعَامَهُ مِنْ طَعَامِهِ وَشَرَابَهُ مِنْ شَرَابِهِ فَجَعَلَ يَفْضُلُ مِنْ طَعَامِهِ فَيُحْبَسُ لَهُ حَتَّى يَأْكُلَهُ أَوْ يَفْسُدَ فَاشْتَدَّ ذَلِكَ عَلَيْهِمْ فَذَكَرُوا ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَيَسْأَلُونَكَ عَنِ الْيَتَامَى قُلْ إِصْلاَحٌ لَهُمْ خَيْرٌ وَإِنْ تُخَالِطُوهُمْ فَإِخْوَانُكُمْ ‏\}‏ فَخَلَطُوا طَعَامَهُمْ بِطَعَامِهِ وَشَرَابَهُمْ بِشَرَابِهِ ‏.‏\hadithno{2871}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: When Allah, Most High, revealed the verses: "Come not nigh to the orphan's property except to improve it". And "Those who unjustly eat up the property of orphans", everyone who had an orphan with him went and separated his food from his (orphan's) food, and his drink from his drink, and began to detain the remaining food which he (the orphan) himself ate or spoiled. This fell heavy on them, and they mentioned this to the Messenger of Allah (ﷺ). So Allah, Most High, revealed the verse: "They ask thee concerning orphans. Say: The best thing to do is what is for their good; if ye mix their affairs with yours, they are your brethren." Then they mixed their food with his food and their drink with his drink}}
\hadithdefcmd{abudawud}{2872}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، أَنَّ خَالِدَ بْنَ الْحَارِثِ، حَدَّثَهُمْ حَدَّثَنَا حُسَيْنٌ، - يَعْنِي الْمُعَلِّمَ - عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنِّي فَقِيرٌ لَيْسَ لِي شَىْءٌ وَلِي يَتِيمٌ ‏.‏ قَالَ فَقَالَ ‏ "‏ كُلْ مِنْ مَالِ يَتِيمِكَ غَيْرَ مُسْرِفٍ وَلاَ مُبَادِرٍ وَلاَ مُتَأَثِّلٍ ‏"‏ ‏.‏\hadithno{2872}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather told that a man came to the Prophet (ﷺ) and said: I am poor, I have nothing (with me), and I have an orphan. He said: Use the property of your orphan without spending it lavishly, hurrying and taking it as your own property}}
\hadithdefcmd{abudawud}{2873}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا يَحْيَى بْنُ مُحَمَّدٍ الْمَدِينِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ خَالِدِ بْنِ سَعِيدِ بْنِ أَبِي مَرْيَمَ، عَنْ أَبِيهِ، عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ رُقَيْشٍ، أَنَّهُ سَمِعَ شُيُوخًا، مِنْ بَنِي عَمْرِو بْنِ عَوْفٍ وَمِنْ خَالِهِ عَبْدِ اللَّهِ بْنِ أَبِي أَحْمَدَ قَالَ قَالَ عَلِيُّ بْنُ أَبِي طَالِبٍ حَفِظْتُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُتْمَ بَعْدَ احْتِلاَمٍ وَلاَ صُمَاتَ يَوْمٍ إِلَى اللَّيْلِ ‏"‏ ‏.‏\hadithno{2873}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: I memorised (a tradition) from the Messenger of Allah (ﷺ): There is no orphanhood after puberty, and there is no silence for the whole day till the night}}
\hadithdefcmd{abudawud}{2874}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ اجْتَنِبُوا السَّبْعَ الْمُوبِقَاتِ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ وَمَا هُنَّ قَالَ ‏"‏ الشِّرْكُ بِاللَّهِ وَالسِّحْرُ وَقَتْلُ النَّفْسِ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ وَأَكْلُ الرِّبَا وَأَكْلُ مَالِ الْيَتِيمِ وَالتَّوَلِّي يَوْمَ الزَّحْفِ وَقَذْفُ الْمُحْصَنَاتِ الْغَافِلاَتِ الْمُؤْمِنَاتِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو الْغَيْثِ سَالِمٌ مَوْلَى ابْنِ مُطِيعٍ ‏.‏\hadithno{2874}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah: The Messenger of Allah (ﷺ) as saying: Refrain from seven (characteristics) which cause destruction. He was asked: What are they, Messenger of Allah ? He replied: To assign partner to Allah, magic, to kill a soul (man) which is prohibited by Allah except for which is due, to take usury, to consume the property of an orphan, to retreat on the day of the battle, and to slander chaste women, indiscreet but believing. Abu Dawud said: The name Abu al-Ghaith is Salim client of Ibn Muti}}
\hadithdefcmd{abudawud}{2875}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ الْجُوزَجَانِيُّ، حَدَّثَنَا مُعَاذُ بْنُ هَانِئٍ، حَدَّثَنَا حَرْبُ بْنُ شَدَّادٍ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ عَبْدِ الْحَمِيدِ بْنِ سِنَانٍ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ أَبِيهِ، أَنَّهُ حَدَّثَهُ - وَكَانَتْ، لَهُ صُحْبَةٌ - أَنَّ رَجُلاً، سَأَلَهُ فَقَالَ يَا رَسُولَ اللَّهِ مَا الْكَبَائِرُ فَقَالَ ‏"‏ هُنَّ تِسْعٌ ‏"‏ ‏.‏ فَذَكَرَ مَعْنَاهُ زَادَ ‏"‏ وَعُقُوقُ الْوَالِدَيْنِ الْمُسْلِمَيْنِ وَاسْتِحْلاَلُ الْبَيْتِ الْحَرَامِ قِبْلَتِكُمْ أَحْيَاءً وَأَمْوَاتًا ‏"‏ ‏.‏\hadithno{2875}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan}\hadithtrans{Umair, A Companion of the Prophet (ﷺ) said:A man asked him (the Prophet): Messenger of Allah, what are the grave sins? He replied: They are nine. He then mentioned the tradition to the same effect. This version adds: "And disobedience to the Muslim parents, and to violate the sacred House, your qiblah (direction of prayer), in your life and after death}}
\hadithdefcmd{abudawud}{2876}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ خَبَّابٍ، قَالَ مُصْعَبُ بْنُ عُمَيْرٍ قُتِلَ يَوْمَ أُحُدٍ وَلَمْ تَكُنْ لَهُ إِلاَّ نَمِرَةٌ كُنَّا إِذَا غَطَّيْنَا بِهَا رَأْسَهُ خَرَجَتْ رِجْلاَهُ وَإِذَا غَطَّيْنَا رِجْلَيْهِ خَرَجَ رَأْسُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَطُّوا بِهَا رَأْسَهُ وَاجْعَلُوا عَلَى رِجْلَيْهِ مِنَ الإِذْخِرِ ‏"‏ ‏.‏\hadithno{2876}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1276) Sahih Muslim (940)}\hadithtrans{Narrated Khabbab:Mus'ab b. 'Umar was killed at the battle of Uhud, and for him only a coarse cloth would be found as shroud. When we covered his head, his feet showed, and when we covered his feet, his head showed. So the Messenger of Allah (ﷺ) said: Cover his head with it (cloth), and put some rushes over his feet}}
\hadithdefcmd{abudawud}{2877}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَطَاءٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، بُرَيْدَةَ أَنَّ امْرَأَةً، أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ كُنْتُ تَصَدَّقْتُ عَلَى أُمِّي بِوَلِيدَةٍ وَإِنَّهَا مَاتَتْ وَتَرَكَتْ تِلْكَ الْوَلِيدَةَ ‏.‏ قَالَ ‏"‏ قَدْ وَجَبَ أَجْرُكِ وَرَجَعَتْ إِلَيْكِ فِي الْمِيرَاثِ ‏"‏ ‏.‏ قَالَتْ وَإِنَّهَا مَاتَتْ وَعَلَيْهَا صَوْمُ شَهْرٍ أَفَيُجْزِئُ - أَوْ يَقْضِي - عَنْهَا أَنْ أَصُومَ عَنْهَا قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَتْ وَإِنَّهَا لَمْ تَحُجَّ أَفَيُجْزِئُ - أَوْ يَقْضِي - عَنْهَا أَنْ أَحُجَّ عَنْهَا قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏\hadithno{2877}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1149)}\hadithtrans{Narrated Buraidah:A woman came to the Messenger of Allah (ﷺ) and said: I donated my slave-girl to my mother, but she died and left the slave-girl. He said: Your reward became due, and she came back to you in inheritance. She said: She died while a month's fasting was due from her. Would it be sufficient or be taken as completed if I fast on her behalf ? He said: Yes. She said: She also did not perform Hajj. Would it be sufficient or be taken completed if I perform (Hajj) on her behalf ? He said: Yes}}
\hadithdefcmd{abudawud}{2878}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ أَصَابَ عُمَرُ أَرْضًا بِخَيْبَرَ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ أَصَبْتُ أَرْضًا لَمْ أُصِبْ مَالاً قَطُّ أَنْفَسَ عِنْدِي مِنْهُ فَكَيْفَ تَأْمُرُنِي بِهِ قَالَ ‏ "‏ إِنْ شِئْتَ حَبَّسْتَ أَصْلَهَا وَتَصَدَّقْتَ بِهَا ‏"‏ ‏.‏ فَتَصَدَّقَ بِهَا عُمَرُ أَنَّهُ لاَ يُبَاعُ أَصْلُهَا وَلاَ يُوهَبُ وَلاَ يُورَثُ لِلْفُقَرَاءِ وَالْقُرْبَى وَالرِّقَابِ وَفِي سَبِيلِ اللَّهِ وَابْنِ السَّبِيلِ - وَزَادَ عَنْ بِشْرٍ - وَالضَّيْفِ - ثُمَّ اتَّفَقُوا - لاَ جُنَاحَ عَلَى مَنْ وَلِيَهَا أَنْ يَأْكُلَ مِنْهَا بِالْمَعْرُوفِ وَيُطْعِمَ صَدِيقًا غَيْرَ مُتَمَوِّلٍ فِيهِ ‏.‏ زَادَ عَنْ بِشْرٍ قَالَ وَقَالَ مُحَمَّدٌ غَيْرَ مُتَأَثِّلٍ مَالاً ‏.‏\hadithno{2878}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2772) Sahih Muslim (1633)}\hadithtrans{Narrated Ibn 'Umar:'Umar got some land in Khaibar, and when to the Prophet (ﷺ) and said: I have acquired land in Khaibar which I consider to be more valuable than any I have acquired ; so what do you command me to do with it ? He replied: If you wish, you may make the property as inalienable possession, and give its produce as sadaqah (charity). So 'Umar gave it as a sadaqah declaring that the property must not be sold, given away, or inherited : (and gave its produce as sadaqah to be devoted) to poor, relatives, the emancipation of slaves, Allah's path, travellers. The narrator Bishr added: "and guests". Then the agreed version goes: No sin being committed by the one who administers it if he eats something from it in a reasonable manner, or gives something to a friend, who does not make his own property. The narrator Bishr added: "(provided) he is not storing-up goods (for himself)}}
\hadithdefcmd{abudawud}{2879}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ صَدَقَةِ، عُمَرَ بْنِ الْخَطَّابِ رضى الله عنه قَالَ نَسَخَهَا لِي عَبْدُ الْحَمِيدِ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ هَذَا مَا كَتَبَ عَبْدُ اللَّهِ عُمَرُ فِي ثَمْغٍ فَقَصَّ مِنْ خَبَرِهِ نَحْوَ حَدِيثِ نَافِعٍ قَالَ غَيْرَ مُتَأَثِّلٍ مَالاً فَمَا عَفَا عَنْهُ مِنْ ثَمَرِهِ فَهُوَ لِلسَّائِلِ وَالْمَحْرُومِ - قَالَ وَسَاقَ الْقِصَّةَ - قَالَ وَإِنْ شَاءَ وَلِيُّ ثَمْغٍ اشْتَرَى مِنْ ثَمَرِهِ رَقِيقًا لِعَمَلِهِ وَكَتَبَ مُعَيْقِيبٌ وَشَهِدَ عَبْدُ اللَّهِ بْنُ الأَرْقَمِ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ هَذَا مَا أَوْصَى بِهِ عَبْدُ اللَّهِ عُمَرُ أَمِيرُ الْمُؤْمِنِينَ إِنْ حَدَثَ بِهِ حَدَثٌ أَنَّ ثَمْغًا وَصِرْمَةَ بْنَ الأَكْوَعِ وَالْعَبْدَ الَّذِي فِيهِ وَالْمِائَةَ سَهْمٍ الَّتِي بِخَيْبَرَ وَرَقِيقَهُ الَّذِي فِيهِ وَالْمِائَةَ الَّتِي أَطْعَمَهُ مُحَمَّدٌ صلى الله عليه وسلم بِالْوَادِي تَلِيهِ حَفْصَةُ مَا عَاشَتْ ثُمَّ يَلِيهِ ذُو الرَّأْىِ مِنْ أَهْلِهَا أَنْ لاَ يُبَاعَ وَلاَ يُشْتَرَى يُنْفِقُهُ حَيْثُ رَأَى مِنَ السَّائِلِ وَالْمَحْرُومِ وَذِي الْقُرْبَى وَلاَ حَرَجَ عَلَى مَنْ وَلِيَهُ إِنْ أَكَلَ أَوْ آكَلَ أَوِ اشْتَرَى رَقِيقًا مِنْهُ ‏.‏\hadithno{2879}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Yahya b. Sa'id:'Abd al-Hamid b. Abd 'Allah b. 'Abd Allah b. 'Umar b. al-Khattab copied to me a document about the religious endowment (waqf) made by 'Umar b. al-Khattab : In the name of Allah, the Compassionate, the Merciful. This is what Allah's servant 'Umar has written about Thamgh. He narrated the tradition like the one transmitted by Nafi'. He added: "provided he is not storing up goods (for himself)". The surplus fruit will be devoted to the beggar and the deprived. He then went on with the tradition, saying: If the man in charge of Thamgh wishes to buy a slave for his work for its fruits (by selling them), he may do so. Mu'iqib penned it and 'Abd Allah b. al-Arqam witnessed it : In the name of Allah, the Compassionate, the Merciful. This is what Allah's servant 'Umar , Commander of Faithful, directed, in case of some incident happens to him (i.e. he dies), that Thamg, Sirmah b. al-Akwa', the servant who is there, the hundred shares in (the land of) Khaibr, the servant who is there and the hundred sahres which Muhammad (ﷺ) had donated to me in the valley (nearly) will remain in the custody of Hafsah during her life, then the men of opinion from her family will be in charge of these (endowments), that these will neither be sold not purchased, spending (its produce) where they think (necessary on the beggar, deprived and relatives). There is no harm to the one in charge (of this endowment) if he eats himself, or feeds, or buys slaves with it}}
\hadithdefcmd{abudawud}{2880}{حَدَّثَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ الْمُؤَذِّنُ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ سُلَيْمَانَ، - يَعْنِي ابْنَ بِلاَلٍ - عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، أُرَاهُ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا مَاتَ الإِنْسَانُ انْقَطَعَ عَنْهُ عَمَلُهُ إِلاَّ مِنْ ثَلاَثَةِ أَشْيَاءَ مِنْ صَدَقَةٍ جَارِيَةٍ أَوْ عِلْمٍ يُنْتَفَعُ بِهِ أَوْ وَلَدٍ صَالِحٍ يَدْعُو لَهُ ‏"‏ ‏.‏\hadithno{2880}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1631)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: When a man dies, his action discontinues from him except three things, namely, perpetual sadaqah (charity), or the knowledge by which benefit is acquired, or a pious child who prays for him}}
\hadithdefcmd{abudawud}{2881}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أُمِّيَ افْتُلِتَتْ نَفْسُهَا وَلَوْلاَ ذَلِكَ لَتَصَدَّقَتْ وَأَعْطَتْ أَفَيُجْزِئُ أَنْ أَتَصَدَّقَ عَنْهَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ نَعَمْ فَتَصَدَّقِي عَنْهَا ‏"‏ ‏.‏\hadithno{2881}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: A woman said: Messenger of Allah, my mother suddenly died; if it had not happened, she would have given sadaqah (charity) and donated (something). Will it suffice if I give sadaqah on her behalf? The Prophet (ﷺ) said: Yes, give sadaqah on her behalf}}
\hadithdefcmd{abudawud}{2882}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا زَكَرِيَّا بْنُ إِسْحَاقَ، أَخْبَرَنَا عَمْرُو بْنُ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمِّي تُوُفِّيَتْ أَفَيَنْفَعُهَا إِنْ تَصَدَّقْتُ عَنْهَا فَقَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَإِنَّ لِي مَخْرَفًا وَإِنِّي أُشْهِدُكَ أَنِّي قَدْ تَصَدَّقْتُ بِهِ عَنْهَا ‏.‏\hadithno{2882}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2770)}\hadithtrans{Narrated Ibn 'Abbas:A man said: Messenger of Allah, my mother has died ; will it benefit her if I give sadaqah on her behalf ? He said: Yes. He said: I have a garden, and I call you to witness that I have given it as sadaqah on her behalf}}
\hadithdefcmd{abudawud}{2883}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ بْنِ مَزْيَدٍ، أَخْبَرَنِي أَبِي، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي حَسَّانُ بْنُ عَطِيَّةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ الْعَاصَ بْنَ وَائِلٍ، أَوْصَى أَنْ يُعْتَقَ، عَنْهُ مِائَةُ رَقَبَةٍ فَأَعْتَقَ ابْنُهُ هِشَامٌ خَمْسِينَ رَقَبَةً فَأَرَادَ ابْنُهُ عَمْرٌو أَنْ يَعْتِقَ عَنْهُ الْخَمْسِينَ الْبَاقِيَةَ فَقَالَ حَتَّى أَسْأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أَبِي أَوْصَى بِعِتْقِ مِائَةِ رَقَبَةٍ وَإِنَّ هِشَامًا أَعْتَقَ عَنْهُ خَمْسِينَ وَبَقِيَتْ عَلَيْهِ خَمْسُونَ رَقَبَةً أَفَأُعْتِقُ عَنْهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّهُ لَوْ كَانَ مُسْلِمًا فَأَعْتَقْتُمْ عَنْهُ أَوْ تَصَدَّقْتُمْ عَنْهُ أَوْ حَجَجْتُمْ عَنْهُ بَلَغَهُ ذَلِكَ ‏"‏ ‏.‏\hadithno{2883}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr b. Suh'aib: On his father's authority, said that his grandfather told that Al-'As ibn Wa'il left his will that a hundred slaves should be emancipated on his behalf. His son Hisham emancipated fifty slaves and his son Amr intended to emancipate the remaining fifty on his behalf, but he said: I should ask first the Messenger of Allah (ﷺ). He, therefore, came to the Prophet (ﷺ) and said: Messenger of Allah, my father left in his will that a hundred slaves should be emancipated on his behalf and Hisham has emancipated fifty on his behalf and fifty remain. Shall I emancipate them on his behalf? The Messenger of Allah (ﷺ) said: Had he been a Muslim and you had emancipated slaves on his behalf, or given sadaqah on his behalf, or performed the pilgrimage, that would have reached him}}
\hadithdefcmd{abudawud}{2884}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَنَّ شُعَيْبَ بْنَ إِسْحَاقَ، حَدَّثَهُمْ عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ أَخْبَرَهُ أَنَّ أَبَاهُ تُوُفِّيَ وَتَرَكَ عَلَيْهِ ثَلاَثِينَ وَسْقًا لِرَجُلٍ مِنْ يَهُودَ فَاسْتَنْظَرَهُ جَابِرٌ فَأَبَى فَكَلَّمَ جَابِرٌ النَّبِيَّ صلى الله عليه وسلم أَنْ يَشْفَعَ لَهُ إِلَيْهِ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَلَّمَ الْيَهُودِيَّ لِيَأْخُذَ ثَمَرَ نَخْلِهِ بِالَّذِي لَهُ عَلَيْهِ فَأَبَى عَلَيْهِ وَكَلَّمَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُنْظِرَهُ فَأَبَى ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{2884}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2396)}\hadithtrans{Narrated Jabir bin ‘Abdullah :That his father died and left a debt of thirty wasqs of a Jew on him. Jabir asked him to defer, but he refused. Jabir then spoke to the Messenger of Allah (ﷺ) asking him to mediate to him on his behalf. The Messenger of Allah (ﷺ) came to the Jew and spoke to him about taking fruit-dates in lieu of the debt that was on him. But he refused. The Messenger of Allah (ﷺ) asked him to defer (the debt) to him, but he refused. He then narrated the rest of the tradition}}
