% Auto-generated chapter 73 for bukhari
% Hadiths in this chapter: 30

\hadithdefcmd{bukhari}{5545}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ زُبَيْدٍ الإِيَامِيِّ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ أَوَّلَ مَا نَبْدَأُ بِهِ فِي يَوْمِنَا هَذَا أَنْ نُصَلِّيَ ثُمَّ نَرْجِعَ فَنَنْحَرَ، مَنْ فَعَلَهُ فَقَدْ أَصَابَ سُنَّتَنَا، وَمَنْ ذَبَحَ قَبْلُ فَإِنَّمَا هُوَ لَحْمٌ قَدَّمَهُ لأَهْلِهِ، لَيْسَ مِنَ النُّسُكِ فِي شَىْءٍ ‏"‏‏.‏ فَقَامَ أَبُو بُرْدَةَ بْنُ نِيَارٍ وَقَدْ ذَبَحَ فَقَالَ إِنَّ عِنْدِي جَذَعَةً‏.‏ فَقَالَ ‏"‏ اذْبَحْهَا وَلَنْ تَجْزِيَ عَنْ أَحَدٍ بَعْدَكَ ‏"‏‏.‏ قَالَ مُطَرِّفٌ عَنْ عَامِرٍ عَنِ الْبَرَاءِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ ذَبَحَ بَعْدَ الصَّلاَةِ تَمَّ نُسُكُهُ، وَأَصَابَ سُنَّةَ الْمُسْلِمِينَ ‏"‏‏.‏\hadithno{5545}\hadithtrans{Narrated Al-Bara:The Prophet (ﷺ) said (on the day of Idal-Adha), "The first thing we will do on this day of ours, is to offer the (`Id) prayer and then return to slaughter the sacrifice. Whoever does so, he acted according to our Sunna (tradition), and whoever slaughtered (the sacrifice) before the prayer, what he offered was just meat he presented to his family, and that will not be considered as Nusak (sacrifice)." (On hearing that) Abu Burda bin Niyar got up, for he had slaughtered the sacrifice before the prayer, and said, "I have got a six month old ram." The Prophet (ﷺ) said, 'Slaughter it (as a sacrifice) but it will not be sufficient for any-one else (as a sacrifice after you). Al-Bara' added: The Prophet (ﷺ) said, "Whoever slaughtered (the sacrifice) after the prayer, he slaughtered it at the right time and followed the tradition of the Muslims}}
\hadithdefcmd{bukhari}{5546}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ ذَبَحَ قَبْلَ الصَّلاَةِ فَإِنَّمَا ذَبَحَ لِنَفْسِهِ، وَمَنْ ذَبَحَ بَعْدَ الصَّلاَةِ فَقَدْ تَمَّ نُسُكُهُ، وَأَصَابَ سُنَّةَ الْمُسْلِمِينَ ‏"‏‏.‏\hadithno{5546}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "Whoever slaughtered the sacrifice before the prayer, he just slaughtered it for himself, and whoever slaughtered it after the prayer, he slaughtered it at the right time and followed the tradition of the Muslims}}
\hadithdefcmd{bukhari}{5547}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ بَعْجَةَ الْجُهَنِيِّ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ قَسَمَ النَّبِيُّ صلى الله عليه وسلم بَيْنَ أَصْحَابِهِ ضَحَايَا، فَصَارَتْ لِعُقْبَةَ جَذَعَةٌ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ صَارَتْ جَذَعَةٌ‏.‏ قَالَ ‏ "‏ ضَحِّ بِهَا ‏"‏‏.‏\hadithno{5547}\hadithtrans{Narrated `Uqba bin 'Amir Al-Juhani:that the Prophet (ﷺ) distributed among his companions some animals for sacrifice (to be slaughtered on `Id-al-Adha). `Uqba's share was a Jadha'a (a six month old goat). `Uqba said, "O Allah's Messenger (ﷺ)! I get in my share of Jadha'a (a six month old ram)." The Prophet (ﷺ) said, "Slaughter it as a sacrifice}}
\hadithdefcmd{bukhari}{5548}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَيْهَا وَحَاضَتْ بِسَرِفَ، قَبْلَ أَنْ تَدْخُلَ مَكَّةَ وَهْىَ تَبْكِي فَقَالَ ‏"‏ مَا لَكِ أَنَفِسْتِ ‏"‏‏.‏ قَالَتْ نَعَمْ‏.‏ قَالَ ‏"‏ إِنَّ هَذَا أَمْرٌ كَتَبَهُ اللَّهُ عَلَى بَنَاتِ آدَمَ، فَاقْضِي مَا يَقْضِي الْحَاجُّ غَيْرَ أَنْ لاَ تَطُوفِي بِالْبَيْتِ ‏"‏‏.‏ فَلَمَّا كُنَّا بِمِنًى أُتِيتُ بِلَحْمِ بَقَرٍ، فَقُلْتُ مَا هَذَا قَالُوا ضَحَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَزْوَاجِهِ بِالْبَقَرِ‏.‏\hadithno{5548}\hadithtrans{Narrated `Aisha:that the Prophet (ﷺ) entered upon her when she had her menses at Sarif before entering Mecca, and she was weeping (because she was afraid that she would not be able to perform the Hajj). The Prophet (ﷺ) said, "What is wrong with you? Have you got your period?" She said, "Yes." He said, "This is a matter Allah has decreed for all the daughters of Adam, so perform all the ceremonies of Hajj like the others, but do not perform the Tawaf around the Ka`ba." `Aisha added: When we were at Mina, beef was brought to me and I asked, "What is this?" They (the people) said, "Allah's Messenger (ﷺ) has slaughtered some cows as sacrifices on behalf of his wives}}
\hadithdefcmd{bukhari}{5549}{حَدَّثَنَا صَدَقَةُ، أَخْبَرَنَا ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ النَّحْرِ ‏ "‏ مَنْ كَانَ ذَبَحَ قَبْلَ الصَّلاَةِ فَلْيُعِدْ ‏"‏‏.‏ فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ هَذَا يَوْمٌ يُشْتَهَى فِيهِ اللَّحْمُ ـ وَذَكَرَ جِيرَانَهُ ـ وَعِنْدِي جَذَعَةٌ خَيْرٌ مِنْ شَاتَىْ لَحْمٍ‏.‏ فَرَخَّصَ لَهُ فِي ذَلِكَ، فَلاَ أَدْرِي أَبَلَغَتِ الرُّخْصَةُ مَنْ سِوَاهُ أَمْ لاَ، ثُمَّ انْكَفَأَ النَّبِيُّ صلى الله عليه وسلم إِلَى كَبْشَيْنِ فَذَبَحَهُمَا، وَقَامَ النَّاسُ إِلَى غُنَيْمَةٍ فَتَوَزَّعُوهَا أَوْ قَالَ فَتَجَزَّعُوهَا‏.‏\hadithno{5549}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said on the day of Nahr, "Whoever has slaughtered his sacrifice before the prayer, should repeat it (slaughter another sacrifice)." A man got up and said, "O Allah's Messenger (ﷺ)! This is a day on which meat is desired." He then mentioned his neighbors saying, "I have a six month old ram which is to me better than the meat of two sheep." The Prophet (ﷺ) allowed him to slaughter it as a sacrifice, but I do not know whether this permission was valid for other than that man or not. The Prophet (ﷺ) then went towards two rams and slaughtered them, and then the people went towards some sheep and distributed them among themselves}}
\hadithdefcmd{bukhari}{5550}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنِ ابْنِ أَبِي بَكْرَةَ، عَنْ أَبِي بَكْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الزَّمَانُ قَدِ اسْتَدَارَ كَهَيْئَتِهِ يَوْمَ خَلَقَ اللَّهُ السَّمَوَاتِ وَالأَرْضَ، السَّنَةُ اثْنَا عَشَرَ شَهْرًا، مِنْهَا أَرْبَعَةٌ حُرُمٌ، ثَلاَثٌ مُتَوَالِيَاتٌ ذُو الْقَعْدَةِ وَذُو الْحِجَّةِ وَالْمُحَرَّمُ، وَرَجَبُ مُضَرَ الَّذِي بَيْنَ جُمَادَى وَشَعْبَانَ، أَىُّ شَهْرٍ هَذَا ‏"‏‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ فَسَكَتَ حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ بِغَيْرِ اسْمِهِ، قَالَ ‏"‏ أَلَيْسَ ذَا الْحِجَّةِ ‏"‏‏.‏ قُلْنَا بَلَى‏.‏ قَالَ ‏"‏ أَىُّ بَلَدٍ هَذَا ‏"‏‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ فَسَكَتَ حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ بِغَيْرِ اسْمِهِ، قَالَ ‏"‏ أَلَيْسَ الْبَلْدَةَ ‏"‏‏.‏ قُلْنَا بَلَى‏.‏ قَالَ ‏"‏ فَأَىُّ يَوْمٍ هَذَا ‏"‏‏.‏ قُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ، فَسَكَتَ حَتَّى ظَنَنَّا أَنَّهُ سَيُسَمِّيهِ بِغَيْرِ اسْمِهِ قَالَ ‏"‏ أَلَيْسَ يَوْمَ النَّحْرِ ‏"‏‏.‏ قُلْنَا بَلَى‏.‏ قَالَ ‏"‏ فَإِنَّ دِمَاءَكُمْ وَأَمْوَالَكُمْ ـ قَالَ مُحَمَّدٌ وَأَحْسِبُهُ قَالَ ـ وَأَعْرَاضَكُمْ عَلَيْكُمْ حَرَامٌ كَحُرْمَةِ يَوْمِكُمْ هَذَا، فِي بَلَدِكُمْ هَذَا فِي شَهْرِكُمْ، وَسَتَلْقَوْنَ رَبَّكُمْ فَيَسْأَلُكُمْ عَنْ أَعْمَالِكُمْ، أَلاَ فَلاَ تَرْجِعُوا بَعْدِي ضُلاَّلاً، يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ، أَلاَ لِيُبَلِّغِ الشَّاهِدُ الْغَائِبَ، فَلَعَلَّ بَعْضَ مَنْ يَبْلُغُهُ أَنْ يَكُونَ أَوْعَى لَهُ مِنْ بَعْضِ مَنْ سَمِعَهُ ـ وَكَانَ مُحَمَّدٌ إِذَا ذَكَرَهُ قَالَ صَدَقَ النَّبِيُّ صلى الله عليه وسلم ثُمَّ قَالَ ـ أَلاَ هَلْ بَلَّغْتُ أَلاَ هَلْ بَلَّغْتُ ‏"‏‏.‏\hadithno{5550}\hadithtrans{Narrated Abu Bakra:The Prophet (ﷺ) said, "Time has come back to its original state which it had on the day Allah created the Heavens and the Earth. The year is twelve months, four of which are sacred, three of them are in succession, namely Dhul-Qa'da, Dhul Hijja and Muharram, (the fourth being) Rajab Mudar which is between Juma'da (ath-thamj and Sha'ban. The Prophet (ﷺ) then asked, "Which month is this?" We said, "Allah and his Apostle know better." He kept silent so long that we thought that he would call it by a name other than its real name. He said, "Isn't it the month of Dhul-Hijja?" We said, "Yes." He said, "Which town is this?" We said, "Allah and His Apostle know better." He kept silent so long that we thought that he would call it t,y a name other than its real name. He said, "isn't it the town (of Mecca)?" We replied, "Yes." He said, "What day is today?" We replied, "Allah and His Apostle know better." He kept silent so long that we thought that he would call it by a name other than its real name. He said, "Isn't it the day of Nahr?" We replied, "Yes." He then said, "Your blood, properties and honor are as sacred to one another as this day of yours in this town of yours in this month of yours. You will meet your Lord, and He will ask you about your deeds. Beware! Do not go astray after me by cutting the necks of each other. It is incumbent upon those who are present to convey this message to those who are absent, for some of those to whom it is conveyed may comprehend it better than some of those who have heard it directly." (Muhammad, the sub-narrator, on mentioning this used to say: The Prophet then said, "No doubt! Haven't I delivered (Allah's) Message (to you)? Haven't I delivered Allah's message (to you)?}}
\hadithdefcmd{bukhari}{5551}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، قَالَ كَانَ عَبْدُ اللَّهِ يَنْحَرُ فِي الْمَنْحَرِ‏.‏ قَالَ عُبَيْدُ اللَّهِ يَعْنِي مَنْحَرَ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{5551}\hadithtrans{Narrated Nafi': 'Abdullah (bin 'Umar) used to slaughter his sacrifice at the slaughtering place (i.e the slaughtering place of the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{5552}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ كَثِيرِ بْنِ فَرْقَدٍ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ ـ رضى الله عنهما ـ أَخْبَرَهُ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَذْبَحُ وَيَنْحَرُ بِالْمُصَلَّى‏.‏\hadithno{5552}\hadithtrans{Ibn 'Umar said, "Allah's Messenger (ﷺ) used to slaughter (camels and sheep, etc.,) as sacrifices at the Musalla}}
\hadithdefcmd{bukhari}{5553}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُضَحِّي بِكَبْشَيْنِ وَأَنَا أُضَحِّي بِكَبْشَيْنِ‏.‏\hadithno{5553}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) used to offer two rams as sacrifices, and I also used to offer two rams}}
\hadithdefcmd{bukhari}{5554}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم انْكَفَأَ إِلَى كَبْشَيْنِ أَقْرَنَيْنِ أَمْلَحَيْنِ فَذَبَحَهُمَا بِيَدِهِ‏.‏ تَابَعَهُ وُهَيْبٌ عَنْ أَيُّوبَ‏.‏ وَقَالَ إِسْمَاعِيلُ وَحَاتِمُ بْنُ وَرْدَانَ عَنْ أَيُّوبَ عَنِ ابْنِ سِيرِينَ عَنْ أَنَسٍ‏.‏\hadithno{5554}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) came towards two horned rams having black and white colors and slaughtered them with his own hands}}
\hadithdefcmd{bukhari}{5555}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ ـ رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم أَعْطَاهُ غَنَمًا يَقْسِمُهَا عَلَى صَحَابَتِهِ ضَحَايَا، فَبَقِيَ عَتُودٌ فَذَكَرَهُ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ ضَحِّ أَنْتَ بِهِ ‏"‏‏.‏\hadithno{5555}\hadithtrans{Narrated `Uqba bin 'Amir:that the Prophet (ﷺ) gave him some sheep to distribute among his companions to slaughter as sacrifices (`Id--al--Adha). A kid goat was left and he told the Prophet (ﷺ) of that whereupon he said to him, "Slaughter it as a sacrifice (on your behalf)}}
\hadithdefcmd{bukhari}{5556}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُطَرِّفٌ، عَنْ عَامِرٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ ـ رضى الله عنهما ـ قَالَ ضَحَّى خَالٌ لِي يُقَالُ لَهُ أَبُو بُرْدَةَ قَبْلَ الصَّلاَةِ، فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ شَاتُكَ شَاةُ لَحْمٍ ‏"‏‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ عِنْدِي دَاجِنًا جَذَعَةً مِنَ الْمَعَزِ‏.‏ قَالَ ‏"‏ اذْبَحْهَا وَلَنْ تَصْلُحَ لِغَيْرِكَ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ مَنْ ذَبَحَ قَبْلَ الصَّلاَةِ فَإِنَّمَا يَذْبَحُ لِنَفْسِهِ، وَمَنْ ذَبَحَ بَعْدَ الصَّلاَةِ فَقَدْ تَمَّ نُسُكُهُ، وَأَصَابَ سُنَّةَ الْمُسْلِمِينَ ‏"‏‏.‏ تَابَعَهُ عُبَيْدَةُ عَنِ الشَّعْبِيِّ وَإِبْرَاهِيمَ‏.‏ وَتَابَعَهُ وَكِيعٌ عَنْ حُرَيْثٍ عَنِ الشَّعْبِيِّ‏.‏ وَقَالَ عَاصِمٌ وَدَاوُدُ عَنِ الشَّعْبِيِّ عِنْدِي عَنَاقُ لَبَنٍ‏.‏ وَقَالَ زُبَيْدٌ وَفِرَاسٌ عَنِ الشَّعْبِيِّ عِنْدِي جَذَعَةٌ‏.‏ وَقَالَ أَبُو الأَحْوَصِ حَدَّثَنَا مَنْصُورٌ عَنَاقٌ جَذَعَةٌ‏.‏ وَقَالَ ابْنُ عَوْنٍ عَنَاقٌ جَذَعٌ، عَنَاقُ لَبَنٍ‏.‏\hadithno{5556}\hadithtrans{Narrated Al-Bara' bin `Azib:An uncle of mine called Abu Burda, slaughtered his sacrifice before the `Id prayer. So Allah's Messenger (ﷺ) said to him, "Your (slaughtered) sheep was just mutton (not a sacrifice)." Abu Burda said, "O Allah's Apostle! I have got a domestic kid goat." The Prophet (ﷺ) said, "Slaughter it (as a sacrifice) but it will not be permissible for anybody other than you" The Prophet (ﷺ) added, "Whoever slaughtered his sacrifice before the (`Id) prayer, he only slaughtered for himself, and whoever slaughtered it after the prayer, he offered his sacrifice properly and followed the tradition of the Muslims}}
\hadithdefcmd{bukhari}{5557}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ، عَنْ أَبِي جُحَيْفَةَ، عَنِ الْبَرَاءِ، قَالَ ذَبَحَ أَبُو بُرْدَةَ قَبْلَ الصَّلاَةِ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَبْدِلْهَا ‏"‏‏.‏ قَالَ لَيْسَ عِنْدِي إِلاَّ جَذَعَةٌ ـ قَالَ شُعْبَةُ وَأَحْسِبُهُ قَالَ ـ هِيَ خَيْرٌ مِنْ مُسِنَّةٍ‏.‏ قَالَ ‏"‏ اجْعَلْهَا مَكَانَهَا، وَلَنْ تَجْزِيَ عَنْ أَحَدٍ بَعْدَكَ ‏"‏‏.‏ وَقَالَ حَاتِمُ بْنُ وَرْدَانَ عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم وَقَالَ عَنَاقٌ جَذَعَةٌ‏.‏\hadithno{5557}\hadithtrans{Narrated Al-Bara':Abu Burda slaughtered (the sacrifice) before the (`Id) prayer whereupon the Prophet (ﷺ) said to him, "Slaughter another sacrifice instead of that." Abu Burda said, "I have nothing except a Jadha'a." (Shu`ba said: Perhaps Abu Burda also said that Jadha'a was better than an old sheep in his opinion.) The Prophet (ﷺ) said, "(Never mind), slaughter it to make up for the other one, but it will not be sufficient for anyone else after you}}
\hadithdefcmd{bukhari}{5558}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، قَالَ ضَحَّى النَّبِيُّ صلى الله عليه وسلم بِكَبْشَيْنِ أَمْلَحَيْنِ، فَرَأَيْتُهُ وَاضِعًا قَدَمَهُ عَلَى صِفَاحِهِمَا يُسَمِّي وَيُكَبِّرُ، فَذَبَحَهُمَا بِيَدِهِ‏.‏\hadithno{5558}\hadithtrans{Narrated Anas:The Prophet (ﷺ) slaughtered two rams, black and white in color (as sacrifices), and I saw him putting his foot on their sides and mentioning Allah's Name and Takbir (Allahu Akbar). Then he slaughtered them with his own hands}}
\hadithdefcmd{bukhari}{5559}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَرِفَ وَأَنَا أَبْكِي، فَقَالَ ‏"‏ مَا لَكِ أَنَفِسْتِ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ هَذَا أَمْرٌ كَتَبَهُ اللَّهُ عَلَى بَنَاتِ آدَمَ اقْضِي مَا يَقْضِي الْحَاجُّ غَيْرَ أَنْ لاَ تَطُوفِي بِالْبَيْتِ ‏"‏‏.‏ وَضَحَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ نِسَائِهِ بِالْبَقَرِ‏.‏\hadithno{5559}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) entered upon me at Sarif while I was weeping (because I was afraid that I would not be able to perform the ,Hajj). He said, "What is wrong with you? Have you got your period?" I replied, "Yes." He said, "This is a matter Allah has decreed for all the daughters of Adam, so perform the ceremonies of the Hajj as the pilgrims do, but do not perform the Tawaf around the Ka`ba." Allah's Messenger (ﷺ) slaughtered some cows as sacrifices on behalf of his wives}}
\hadithdefcmd{bukhari}{5560}{حَدَّثَنَا حَجَّاجُ بْنُ الْمِنْهَالِ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي زُبَيْدٌ، قَالَ سَمِعْتُ الشَّعْبِيَّ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ فَقَالَ ‏"‏ إِنَّ أَوَّلَ مَا نَبْدَأُ مِنْ يَوْمِنَا هَذَا أَنْ نُصَلِّيَ، ثُمَّ نَرْجِعَ فَنَنْحَرَ، فَمَنْ فَعَلَ هَذَا فَقَدْ أَصَابَ سُنَّتَنَا، وَمَنْ نَحَرَ فَإِنَّمَا هُوَ لَحْمٌ يُقَدِّمُهُ لأَهْلِهِ، لَيْسَ مِنَ النُّسُكِ فِي شَىْءٍ ‏"‏‏.‏ فَقَالَ أَبُو بُرْدَةَ يَا رَسُولَ اللَّهِ ذَبَحْتُ قَبْلَ أَنْ أُصَلِّيَ، وَعِنْدِي جَذَعَةٌ خَيْرٌ مِنْ مُسِنَّةٍ‏.‏ فَقَالَ ‏"‏ اجْعَلْهَا مَكَانَهَا، وَلَنْ تَجْزِيَ أَوْ تُوفِيَ عَنْ أَحَدٍ بَعْدَكَ ‏"‏‏.‏\hadithno{5560}\hadithtrans{Narrated Al-Bara':I heard the Prophet (ﷺ) delivering a sermon, and he said (on the Day of `Id-Allah. a), "The first thing we will do on this day of ours is that we will offer the `Id prayer, then we will return and slaughter our sacrifices; and whoever does so, then indeed he has followed our tradition, and whoever slaughtered his sacrifice (before the prayer), what he offered was just meat that he presented to his family, and that was not a sacrifice." Abu Burda got up and said, "O Allah's Messenger (ﷺ)! I slaughtered the sacrifice before the prayer and I have got a Jadha'a which is better than an old sheep." The Prophet (ﷺ) said, "Slaughter it to make up for that, but it will not be sufficient for anybody else after you}}
\hadithdefcmd{bukhari}{5561}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ ذَبَحَ قَبْلَ الصَّلاَةِ فَلْيُعِدْ ‏"‏‏.‏ فَقَالَ رَجُلٌ هَذَا يَوْمٌ يُشْتَهَى فِيهِ اللَّحْمُ ـ وَذَكَرَ مِنْ جِيرَانِهِ فَكَأَنَّ النَّبِيَّ صلى الله عليه وسلم عَذَرَهُ ـ وَعِنْدِي جَذَعَةٌ خَيْرٌ مِنْ شَاتَيْنِ فَرَخَّصَ لَهُ النَّبِيُّ صلى الله عليه وسلم فَلاَ أَدْرِي بَلَغَتِ الرُّخْصَةُ أَمْ لاَ، ثُمَّ انْكَفَأَ إِلَى كَبْشَيْنِ ـ يَعْنِي فَذَبَحَهُمَا ـ ثُمَّ انْكَفَأَ النَّاسُ إِلَى غُنَيْمَةٍ فَذَبَحُوهَا‏.‏\hadithno{5561}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "Whoever slaughtered the sacrifice before the `Id prayer, should repeat it (slaughter another one)." A man said "This is the day on which meat is desired." Then he mentioned the need of his neighbors (for meat) and the Prophet (ﷺ) seemed to accept his excuse. The man said, "I have a Jadha'a which is to me better than two sheep." The Prophet (ﷺ) allowed him (to slaughter it as a sacrifice). But I do not know whether this permission was general for all Muslims or not. The Prophet (ﷺ) then went towards two rams and slaughtered them, and the people went towards their sheep and slaughtered them}}
\hadithdefcmd{bukhari}{5562}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا الأَسْوَدُ بْنُ قَيْسٍ، سَمِعْتُ جُنْدَبَ بْنَ سُفْيَانَ الْبَجَلِيَّ، قَالَ شَهِدْتُ النَّبِيَّ صلى الله عليه وسلم يَوْمَ النَّحْرِ فَقَالَ ‏ "‏ مَنْ ذَبَحَ قَبْلَ أَنْ يُصَلِّيَ فَلْيُعِدْ مَكَانَهَا أُخْرَى، وَمَنْ لَمْ يَذْبَحْ فَلْيَذْبَحْ ‏"‏‏.‏\hadithno{5562}\hadithtrans{Narrated Jundab bin Sufyan Al-Bajali:I witnessed the Prophet (ﷺ) on the Day of Nahr. He said, "Whoever slaughtered the sacrifice before offering the `Id prayer, should slaughter another sacrifice in its place; and whoever has not slaughtered their sacrifice yet, should slaughter now}}
\hadithdefcmd{bukhari}{5563}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ فِرَاسٍ، عَنْ عَامِرٍ، عَنِ الْبَرَاءِ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ، فَقَالَ ‏"‏ مَنْ صَلَّى صَلاَتَنَا وَاسْتَقْبَلَ قِبْلَتَنَا، فَلاَ يَذْبَحْ حَتَّى يَنْصَرِفَ ‏"‏‏.‏ فَقَامَ أَبُو بُرْدَةَ بْنُ نِيَارٍ فَقَالَ يَا رَسُولَ اللَّهِ فَعَلْتُ‏.‏ فَقَالَ ‏"‏ هُوَ شَىْءٌ عَجَّلْتَهُ ‏"‏‏.‏ قَالَ فَإِنَّ عِنْدِي جَذَعَةً هِيَ خَيْرٌ مِنْ مُسِنَّتَيْنِ آذْبَحُهَا قَالَ ‏"‏ نَعَمْ، ثُمَّ لاَ تَجْزِي عَنْ أَحَدٍ بَعْدَكَ ‏"‏‏.‏ قَالَ عَامِرٌ هِيَ خَيْرُ نَسِيكَتِهِ‏.‏\hadithno{5563}\hadithtrans{Narrated Al-Bara':One day Allah's Messenger (ﷺ) offered the `Id prayer and said, "Whoever offers our prayer and faces our Qibla should not slaughter the sacrifice till he finishes the `Id prayer." Abu Burda bin Niyar got up and said, "O Allah's Messenger (ﷺ)! I have already done it. The Prophet (ﷺ) said, "That is something you have done before its due time." Abu Burda said, "I have a Jadha'a which is better than two old sheep; shall I slaughter it?" The Prophet (ﷺ) said, "Yes, but it will not be sufficient for anyone after you}}
\hadithdefcmd{bukhari}{5564}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسٌ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُضَحِّي بِكَبْشَيْنِ أَمْلَحَيْنِ أَقْرَنَيْنِ، وَوَضَعَ رِجْلَهُ عَلَى صَفْحَتِهِمَا، وَيَذْبَحُهُمَا بِيَدِهِ‏.‏\hadithno{5564}\hadithtrans{Narrated Anas:The Prophet (ﷺ) used to offer as sacrifices, two horned rams, black and white in color, and used to put his foot on their sides and slaughter them with his own hands}}
\hadithdefcmd{bukhari}{5565}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ ضَحَّى النَّبِيُّ صلى الله عليه وسلم بِكَبْشَيْنِ أَمْلَحَيْنِ أَقْرَنَيْنِ، ذَبَحَهُمَا بِيَدِهِ، وَسَمَّى وَكَبَّرَ وَوَضَعَ رِجْلَهُ عَلَى صِفَاحِهِمَا‏.‏\hadithno{5565}\hadithtrans{Narrated Anas:The Prophet (ﷺ) offered as sacrifices, two horned rams, black and white in color. He slaughtered them with his own hands and mentioned Allah's Name over them and said Takbir and put his foot on their sides}}
\hadithdefcmd{bukhari}{5566}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا إِسْمَاعِيلُ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، أَنَّهُ أَتَى عَائِشَةَ، فَقَالَ لَهَا يَا أُمَّ الْمُؤْمِنِينَ إِنَّ رَجُلاً يَبْعَثُ بِالْهَدْىِ إِلَى الْكَعْبَةِ، وَيَجْلِسُ فِي الْمِصْرِ، فَيُوصِي أَنْ تُقَلَّدَ بَدَنَتُهُ، فَلاَ يَزَالُ مِنْ ذَلِكَ الْيَوْمِ مُحْرِمًا حَتَّى يَحِلَّ النَّاسُ‏.‏ قَالَ فَسَمِعْتُ تَصْفِيقَهَا مِنْ وَرَاءِ الْحِجَابِ فَقَالَتْ لَقَدْ كُنْتُ أَفْتِلُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَيَبْعَثُ هَدْيَهُ إِلَى الْكَعْبَةِ، فَمَا يَحْرُمُ عَلَيْهِ مِمَّا حَلَّ لِلرِّجَالِ مِنْ أَهْلِهِ، حَتَّى يَرْجِعَ النَّاسُ‏.‏\hadithno{5566}\hadithtrans{Narrated Masruq:that he came to `Aisha and said to her, "O Mother of the Believers! There is a man who sends a Hadi to Ka`ba and stays in his city and requests that his Hadi camel be garlanded while he remains in a state of Ihram from that day till the people finish their Ihram (after completing all the ceremonies of Hajj)" (What do you say about it?) Masruq added, I heard the clapping of her hands behind the curtain. She said, "I used to twist the garlands for the Hadi of Allah's Messenger (ﷺ) and he used to send his Hadi to Ka`ba but he never used to regard as unlawful what was lawful for men to do with their wives till the people returned (from the Hajj)}}
\hadithdefcmd{bukhari}{5567}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو أَخْبَرَنِي عَطَاءٌ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ كُنَّا نَتَزَوَّدُ لُحُومَ الأَضَاحِيِّ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم إِلَى الْمَدِينَةِ، وَقَالَ غَيْرَ مَرَّةٍ لُحُومَ الْهَدْىِ‏.‏\hadithno{5567}\hadithtrans{Narrated Jabir bin `Abdullah:During the lifetime of the Prophet (ﷺ) we used to take with us the meat of the sacrifices (of Id al Adha) to Medina. (The narrator often said. The meat of the Hadi)}}
\hadithdefcmd{bukhari}{5568}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي سُلَيْمَانُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ، أَنَّ ابْنَ خَبَّابٍ، أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا سَعِيدٍ، يُحَدِّثُ أَنَّهُ كَانَ غَائِبًا، فَقَدِمَ فَقُدِّمَ إِلَيْهِ لَحْمٌ‏.‏ قَالَ وَهَذَا مِنْ لَحْمِ ضَحَايَانَا‏.‏ فَقَالَ أَخِّرُوهُ لاَ أَذُوقُهُ‏.‏ قَالَ ثُمَّ قُمْتُ فَخَرَجْتُ حَتَّى آتِيَ أَخِي قَتَادَةَ ـ وَكَانَ أَخَاهُ لأُمِّهِ، وَكَانَ بَدْرِيًّا ـ فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ إِنَّهُ قَدْ حَدَثَ بَعْدَكَ أَمْرٌ‏.‏\hadithno{5568}\hadithtrans{Narrated Abu Sa`id Al-Khudri:that once he was not present (at the time of `Id-al-Adha) and when he came. some meat was presented to him. and the people said (to him), 'This is the meat of our sacrifices" He said. 'Take it away; I shall not taste it. (In his narration) Abu Sa`id added: I got up and went to my brother, Abu Qatada (who was his maternal brother and was one of the warriors of the battle of Badr) and mentioned that to him He Sa`d. 'A new verdict was given in your absence (i.e., meat of sacrifices was allowed to be stored and eaten later on)}}
\hadithdefcmd{bukhari}{5569}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ ضَحَّى مِنْكُمْ فَلاَ يُصْبِحَنَّ بَعْدَ ثَالِثَةٍ وَفِي بَيْتِهِ مِنْهُ شَىْءٌ ‏"‏‏.‏ فَلَمَّا كَانَ الْعَامُ الْمُقْبِلُ قَالُوا يَا رَسُولَ اللَّهِ نَفْعَلُ كَمَا فَعَلْنَا عَامَ الْمَاضِي قَالَ ‏"‏ كُلُوا وَأَطْعِمُوا وَادَّخِرُوا فَإِنَّ ذَلِكَ الْعَامَ كَانَ بِالنَّاسِ جَهْدٌ فَأَرَدْتُ أَنْ تُعِينُوا فِيهَا ‏"‏‏.‏\hadithno{5569}\hadithtrans{Narrated Salama bin Al-Aqua':The Prophet (ﷺ) said, "Whoever has slaughtered a sacrifice should not keep anything of Its meat after three days." When it was the next year the people said, "O Allah's Messenger (ﷺ)! Shall we do as we did last year?" He said, ' Eat of it and feed of it to others and store of it for in that year the people were having a hard time and I wanted you to help (the needy)}}
\hadithdefcmd{bukhari}{5570}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتِ الضَّحِيَّةُ كُنَّا نُمَلِّحُ مِنْهُ، فَنَقْدَمُ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم بِالْمَدِينَةِ فَقَالَ ‏ "‏ لاَ تَأْكُلُوا إِلاَّ ثَلاَثَةَ أَيَّامٍ ‏"‏‏.‏ وَلَيْسَتْ بِعَزِيمَةٍ، وَلَكِنْ أَرَادَ أَنْ يُطْعِمَ مِنْهُ وَاللَّهُ أَعْلَمُ‏.‏\hadithno{5570}\hadithtrans{Narrated `Aisha:We used to salt some of the meat of sacrifice and present it to the Prophet (ﷺ) at Medina. Once he said, "Do not eat (of that meat) for more than three days." That was not a final order, but (that year) he wanted us to feed of it to others, Allah knows better}}
\hadithdefcmd{bukhari}{5571}{حَدَّثَنَا حِبَّانُ بْنُ مُوسَى، أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي أَبُو عُبَيْدٍ، مَوْلَى ابْنِ أَزْهَرَ أَنَّهُ شَهِدَ الْعِيدَ يَوْمَ الأَضْحَى مَعَ عُمَرَ بْنِ الْخَطَّابِ ـ رضى الله عنه ـ فَصَلَّى قَبْلَ الْخُطْبَةِ، ثُمَّ خَطَبَ النَّاسَ فَقَالَ يَا أَيُّهَا النَّاسُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ نَهَاكُمْ عَنْ صِيَامِ هَذَيْنِ الْعِيدَيْنِ، أَمَّا أَحَدُهُمَا فَيَوْمُ فِطْرِكُمْ مِنْ صِيَامِكُمْ وَأَمَّا الآخَرُ فَيَوْمٌ تَأْكُلُونَ نُسُكَكُمْ‏.‏\hadithno{5571}\hadithtrans{Narrated Abu `Ubaid:the freed slave of Ibn Azhar that he witnessed the Day of `Id-al-Adha with `Umar bin Al-Khattab. `Umar offered the `Id prayer before the sermon and then delivered the sermon before the people, saying, "O people! Allah's Messenger (ﷺ) has forbidden you to fast (on the first day of) each of these two 'Ida, for one of them is the Day of breaking your fast, and the other is the one, on which you eat the meat of your sacrifices}}
\hadithdefcmd{bukhari}{5572}{قَالَ أَبُو عُبَيْدٍ ثُمَّ شَهِدْتُ مَعَ عُثْمَانَ بْنِ عَفَّانَ فَكَانَ ذَلِكَ يَوْمَ الْجُمُعَةِ، فَصَلَّى قَبْلَ الْخُطْبَةِ ثُمَّ خَطَبَ فَقَالَ يَا أَيُّهَا النَّاسُ إِنَّ هَذَا يَوْمٌ قَدِ اجْتَمَعَ لَكُمْ فِيهِ عِيدَانِ، فَمَنْ أَحَبَّ أَنْ يَنْتَظِرَ الْجُمُعَةَ مِنْ أَهْلِ الْعَوَالِي فَلْيَنْتَظِرْ، وَمَنْ أَحَبَّ أَنْ يَرْجِعَ فَقَدْ أَذِنْتُ لَهُ‏.‏\hadithno{5572}\hadithtrans{Narrated Abu `Ubaid:(in continuation of above). Then I witnessed the `Id with `Uthman bin `Affan, and that was on a Friday. He offered the prayer before the sermon, saying, "O people! Today you have two 'Its (festivals) together, so whoever of those who live at Al-`Awali (suburbs) would like to wait for the Jumua prayer, he may wait, and whoever would like to return (home) Is granted my permission to do so}}
\hadithdefcmd{bukhari}{5573}{قَالَ أَبُو عُبَيْدٍ ثُمَّ شَهِدْتُهُ مَعَ عَلِيِّ بْنِ أَبِي طَالِبٍ، فَصَلَّى قَبْلَ الْخُطْبَةِ، ثُمَّ خَطَبَ النَّاسَ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَاكُمْ أَنْ تَأْكُلُوا لُحُومَ نُسُكِكُمْ فَوْقَ ثَلاَثٍ‏.‏ وَعَنْ مَعْمَرٍ عَنِ الزُّهْرِيِّ عَنْ أَبِي عُبَيْدٍ نَحْوَهُ‏.‏\hadithno{5573}\hadithtrans{Narrated Abu `Ubaid:(in continuation of above). Then I witnessed (the 'Its) with `Ali bin Abi Talib, and he too offered the `Id prayer before the sermon and then delivered the sermon before the people and said, "Allah's Messenger (ﷺ) has forbidden you to eat the meat of your sacrifices for more than three days}}
\hadithdefcmd{bukhari}{5574}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، عَنِ ابْنِ أَخِي ابْنِ شِهَابٍ، عَنْ عَمِّهِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُوا مِنَ الأَضَاحِيِّ ثَلاَثًا ‏"‏‏.‏ وَكَانَ عَبْدُ اللَّهِ يَأْكُلُ بِالزَّيْتِ حِينَ يَنْفِرُ مِنْ مِنًى، مِنْ أَجْلِ لُحُومِ الْهَدْىِ‏.‏\hadithno{5574}\hadithtrans{Narrated Salim:`Abdullah bin `Umar said, "Allah's Messenger (ﷺ) said, "Eat of the meat of sacrifices (of `Id al Adha) for three days." When `Abdullah departed from Mina, he used to eat (bread with) oil, lest he should eat of the meat of Hadi (which is regarded as unlawful after the three days of the `Id)}}
