% Auto-generated chapter 14 for muslim
% Hadiths in this chapter: 11

\hadithdefcmd{muslim}{2780}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَعْتَكِفُ فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ ‏.‏\hadithno{2780}\hadithtrans{Ibn 'Umar (Allah be pleased with both of them) reported that the Messenger of Allah (ﷺ) used to observe i'tikaf in the last ten days of Ramadan}}
\hadithdefcmd{muslim}{2781}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، أَنَّ نَافِعًا، حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، - رضى الله عنهما - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَعْتَكِفُ الْعَشْرَ الأَوَاخِرَ مِنْ رَمَضَانَ ‏.‏ قَالَ نَافِعٌ وَقَدْ أَرَانِي عَبْدُ اللَّهِ - رضى الله عنه - الْمَكَانَ الَّذِي كَانَ يَعْتَكِفُ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الْمَسْجِدِ ‏.‏\hadithno{2781}\hadithtrans{Abdullah b. Umar (Allah be pleased with both of them) reported that the Messenger of Allah (ﷺ) used to observe i'tikaf in the last ten days of Ramadan. Nafi' said:Abdullah (Allah be pleased with him) showed me the place in the mosque where the Messenger of Allah (ﷺ) used to observe i'tikaf}}
\hadithdefcmd{muslim}{2782}{وَحَدَّثَنَا سَهْلُ بْنُ عُثْمَانَ، حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ السَّكُونِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْتَكِفُ الْعَشْرَ الأَوَاخِرَ مِنْ رَمَضَانَ ‏.‏\hadithno{2782}\hadithtrans{A'isha (Allah be pleased with her) reported that the Messenger of Allah (ﷺ) used to observe i'tikaf in the last ten days of Ramadan}}
\hadithdefcmd{muslim}{2783}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا سَهْلُ بْنُ عُثْمَانَ، أَخْبَرَنَا حَفْصُ بْنُ غِيَاثٍ، جَمِيعًا عَنْ هِشَامٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لَهُمَا - قَالاَ حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْتَكِفُ الْعَشْرَ الأَوَاخِرَ مِنْ رَمَضَانَ ‏.‏\hadithno{2783}\hadithtrans{This hadith has been narrated by 'A'isha (Allah be pleased with her) through another chain of transmitters}}
\hadithdefcmd{muslim}{2784}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَعْتَكِفُ الْعَشْرَ الأَوَاخِرَ مِنْ رَمَضَانَ حَتَّى تَوَفَّاهُ اللَّهُ عَزَّ وَجَلَّ ثُمَّ اعْتَكَفَ أَزْوَاجُهُ مِنْ بَعْدِهِ ‏.‏\hadithno{2784}\hadithtrans{A'isha (Allah be pleased with her) reported that the Messenger of Allah (may peace he upon him) used to observe i'tikif in the last ten days of Ramadan till Allah called him back (to his heavenly home). Then his wives observed i'tikaf after him}}
\hadithdefcmd{muslim}{2785}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَعْتَكِفَ صَلَّى الْفَجْرَ ثُمَّ دَخَلَ مُعْتَكَفَهُ وَإِنَّهُ أَمَرَ بِخِبَائِهِ فَضُرِبَ أَرَادَ الاِعْتِكَافَ فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ فَأَمَرَتْ زَيْنَبُ بِخِبَائِهَا فَضُرِبَ وَأَمَرَ غَيْرُهَا مِنْ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم بِخِبَائِهِ فَضُرِبَ فَلَمَّا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الْفَجْرَ نَظَرَ فَإِذَا الأَخْبِيَةُ فَقَالَ ‏ "‏ آلْبِرَّ تُرِدْنَ ‏"‏ ‏.‏ فَأَمَرَ بِخِبَائِهِ فَقُوِّضَ وَتَرَكَ الاِعْتِكَافَ فِي شَهْرِ رَمَضَانَ حَتَّى اعْتَكَفَ فِي الْعَشْرِ الأَوَّلِ مِنْ شَوَّالٍ ‏.‏\hadithno{2785}\hadithtrans{A'isha (Allah be pleased with her) reported that when the Messenger of Allah (ﷺ) decided to observe i'tikaf, he prayed in the morning and then went to the place of his i'tikaf, and he commanded that a tent should be pitched for him, and it was pitched. He (once) decided to observe i'tikaf in the last ten days of Ramadan. Zainab (the wife of the Holy Prophet) commanded that a tent should be pitched for her. It was pitched accordingly. And some other wives of Allah's Apostle (ﷺ) commanded that tents should be pitched for them too. And they were pitched. When the Messenger of Allah (may peace he upon him) offered the morning prayer, he looked and found (so many) tents. Thereupon he said:What is this virtue that these (ladies) have decided to acquire? He commanded his tent to be struck and abandoned i'tikaf in the month of Ramadan and postponed it to the first ten days of Shawwal}}
\hadithdefcmd{muslim}{2786}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنِي عَمْرُو بْنُ سَوَّادٍ، أَخْبَرَنَا ابْنُ، وَهْبٍ أَخْبَرَنَا عَمْرُو بْنُ الْحَارِثِ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنَا الأَوْزَاعِيُّ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، كُلُّ هَؤُلاَءِ عَنْ يَحْيَى بْنِ، سَعِيدٍ عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمَعْنَى حَدِيثِ أَبِي مُعَاوِيَةَ ‏.‏ وَفِي حَدِيثِ ابْنِ عُيَيْنَةَ وَعَمْرِو بْنِ الْحَارِثِ وَابْنِ إِسْحَاقَ ذِكْرُ عَائِشَةَ وَحَفْصَةَ وَزَيْنَبَ - رضى الله عنهن - أَنَّهُنَّ ضَرَبْنَ الأَخْبِيَةَ لِلاِعْتِكَافِ ‏.‏\hadithno{2786}\hadithtrans{This hadith has been reported through another chain of transmitters, and there it is mentioned that. 'A'isha, Hafsa and Zainab (Allah be pleased with them) pitched the tents for i'tikaf}}
\hadithdefcmd{muslim}{2787}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ إِسْحَاقُ أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنْ أَبِي يَعْفُورٍ، عَنْ مُسْلِمِ بْنِ صُبَيْحٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا دَخَلَ الْعَشْرُ أَحْيَا اللَّيْلَ وَأَيْقَظَ أَهْلَهُ وَجَدَّ وَشَدَّ الْمِئْزَرَ ‏.‏\hadithno{2787}\hadithtrans{A'isha (Allah be pleased with her) reported that when the last ten nights began Allah's Messenger (ﷺ) kept awake at night (for prayer and devotion), wakened his family, and prepared himself to observe prayer (with more vigour)}}
\hadithdefcmd{muslim}{2788}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ كِلاَهُمَا عَنْ عَبْدِ الْوَاحِدِ بْنِ زِيَادٍ، - قَالَ قُتَيْبَةُ حَدَّثَنَا عَبْدُ الْوَاحِدِ، - عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، قَالَ سَمِعْتُ إِبْرَاهِيمَ، يَقُولُ سَمِعْتُ الأَسْوَدَ بْنَ يَزِيدَ، يَقُولُ قَالَتْ عَائِشَةُ رضى الله عنها كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَجْتَهِدُ فِي الْعَشْرِ الأَوَاخِرِ مَا لاَ يَجْتَهِدُ فِي غَيْرِهِ ‏.‏\hadithno{2788}\hadithtrans{A'isha (Allah be pleased with her) reported that Allah's Messenger (ﷺ) used to exert himself in devotion during the last ten nights to a greater extent than at any other time}}
\hadithdefcmd{muslim}{2789}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَإِسْحَاقُ قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، الآخَرَانِ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم صَائِمًا فِي الْعَشْرِ قَطُّ ‏.‏\hadithno{2789}\hadithtrans{A'isha (Allah be pleased with her) reported:I never saw the Messenger of Allah (ﷺ) fasting in the ten days of Dhu'I-Hijja}}
\hadithdefcmd{muslim}{2790}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ الْعَبْدِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَصُمِ الْعَشْرَ ‏.‏\hadithno{2790}\hadithtrans{A'isha (Allah be pleased with her) reported:The Apostle of Allah (ﷺ) did not observe fast in the ten days of Dhul-Hijja}}
