% Auto-generated chapter index for malik
% Source: ara-malik.json
% Total hadiths: 1858
% Chapters: 62

\hadithcollectionname{malik}{Muwatta Malik}

\hadithsectionname{malik}{1}{The Times of Prayer}
\hadithsectionname{malik}{2}{Purity}
\hadithsectionname{malik}{3}{Prayer}
\hadithsectionname{malik}{4}{Forgetfulness in Prayer}
\hadithsectionname{malik}{5}{Jumu'a}
\hadithsectionname{malik}{6}{Prayer in Ramadan}
\hadithsectionname{malik}{7}{Tahajjud}
\hadithsectionname{malik}{8}{Prayer in Congregation}
\hadithsectionname{malik}{9}{Shortening the Prayer}
\hadithsectionname{malik}{10}{The Two 'Ids}
\hadithsectionname{malik}{11}{The Fear Prayer}
\hadithsectionname{malik}{12}{The Eclipse Prayer}
\hadithsectionname{malik}{13}{Asking for Rain}
\hadithsectionname{malik}{14}{The Qibla}
\hadithsectionname{malik}{15}{The Qur'an}
\hadithsectionname{malik}{16}{Burials}
\hadithsectionname{malik}{17}{Zakat}
\hadithsectionname{malik}{18}{Fasting}
\hadithsectionname{malik}{19}{I'tikaf in Ramadan}
\hadithsectionname{malik}{20}{Hajj}
\hadithsectionname{malik}{21}{Jihad}
\hadithsectionname{malik}{22}{Vows and Oaths}
\hadithsectionname{malik}{23}{Sacrificial Animals}
\hadithsectionname{malik}{24}{Slaughtering Animals}
\hadithsectionname{malik}{25}{Game}
\hadithsectionname{malik}{26}{The 'Aqiqa}
\hadithsectionname{malik}{27}{Fara'id}
\hadithsectionname{malik}{28}{Marriage}
\hadithsectionname{malik}{29}{Divorce}
\hadithsectionname{malik}{30}{Suckling}
\hadithsectionname{malik}{31}{Business Transactions}
\hadithsectionname{malik}{32}{Qirad}
\hadithsectionname{malik}{33}{Sharecropping}
\hadithsectionname{malik}{34}{Renting Land}
\hadithsectionname{malik}{35}{Pre-emption in Property}
\hadithsectionname{malik}{36}{Judgements}
\hadithsectionname{malik}{37}{Wills and Testaments}
\hadithsectionname{malik}{38}{Setting Free and Wala'}
\hadithsectionname{malik}{39}{The Mukatab}
\hadithsectionname{malik}{40}{The Mudabbar}
\hadithsectionname{malik}{41}{Hudud}
\hadithsectionname{malik}{42}{Drinks}
\hadithsectionname{malik}{43}{Blood-Money}
\hadithsectionname{malik}{44}{The Oath of Qasama}
\hadithsectionname{malik}{45}{Madina}
\hadithsectionname{malik}{46}{The Decree}
\hadithsectionname{malik}{47}{Good Character}
\hadithsectionname{malik}{48}{Dress}
\hadithsectionname{malik}{49}{The Description of the Prophet, may Allah Bless Him and Grant Him Peace}
\hadithsectionname{malik}{50}{The Evil Eye}
\hadithsectionname{malik}{51}{Hair}
\hadithsectionname{malik}{52}{Visions}
\hadithsectionname{malik}{53}{Greetings}
\hadithsectionname{malik}{54}{General Subjects}
\hadithsectionname{malik}{55}{The Oath of Allegiance}
\hadithsectionname{malik}{56}{Speech}
\hadithsectionname{malik}{57}{Jahannam}
\hadithsectionname{malik}{58}{Sadaqa}
\hadithsectionname{malik}{59}{Knowledge}
\hadithsectionname{malik}{60}{The Supplication of the Unjustly Wronged}
\hadithsectionname{malik}{61}{The Names of the Prophet, may Allah Bless Him and Grant Him Peace}

\hadithsectionrange{malik}{1}{1}{31}
\hadithsectionrange{malik}{2}{32}{145}
\hadithsectionrange{malik}{3}{146}{221}
\hadithsectionrange{malik}{4}{222}{224}
\hadithsectionrange{malik}{5}{225}{245}
\hadithsectionrange{malik}{6}{246}{253}
\hadithsectionrange{malik}{7}{254}{286}
\hadithsectionrange{malik}{8}{287}{325}
\hadithsectionrange{malik}{9}{326}{427}
\hadithsectionrange{malik}{10}{428}{440}
\hadithsectionrange{malik}{11}{441}{444}
\hadithsectionrange{malik}{12}{445}{448}
\hadithsectionrange{malik}{13}{449}{454}
\hadithsectionrange{malik}{14}{455}{469}
\hadithsectionrange{malik}{15}{470}{519}
\hadithsectionrange{malik}{16}{520}{577}
\hadithsectionrange{malik}{17}{578}{629}
\hadithsectionrange{malik}{18}{630}{689}
\hadithsectionrange{malik}{19}{690}{704}
\hadithsectionrange{malik}{20}{705}{957}
\hadithsectionrange{malik}{21}{959}{1008}
\hadithsectionrange{malik}{22}{1009}{1027}
\hadithsectionrange{malik}{23}{1028}{1041}
\hadithsectionrange{malik}{24}{1042}{1051}
\hadithsectionrange{malik}{25}{1052}{1066}
\hadithsectionrange{malik}{26}{1067}{1073}
\hadithsectionrange{malik}{27}{1074}{1089}
\hadithsectionrange{malik}{28}{1091}{1149}
\hadithsectionrange{malik}{29}{1150}{1271}
\hadithsectionrange{malik}{30}{1272}{1289}
\hadithsectionrange{malik}{31}{1290}{1385}
\hadithsectionrange{malik}{32}{1386}{1387}
\hadithsectionrange{malik}{33}{1388}{1389}
\hadithsectionrange{malik}{34}{1390}{1394}
\hadithsectionrange{malik}{35}{1395}{1398}
\hadithsectionrange{malik}{36}{1399}{1454}
\hadithsectionrange{malik}{37}{1455}{1463}
\hadithsectionrange{malik}{38}{1464}{1488}
\hadithsectionrange{malik}{39}{1489}{1496}
\hadithsectionrange{malik}{40}{1497}{1499}
\hadithsectionrange{malik}{41}{1500}{1536}
\hadithsectionrange{malik}{42}{1537}{1551}
\hadithsectionrange{malik}{43}{1552}{1595}
\hadithsectionrange{malik}{44}{1596}{1597}
\hadithsectionrange{malik}{45}{1598}{1622}
\hadithsectionrange{malik}{46}{1623}{1632}
\hadithsectionrange{malik}{47}{1633}{1650}
\hadithsectionrange{malik}{48}{1651}{1670}
\hadithsectionrange{malik}{49}{1671}{1710}
\hadithsectionrange{malik}{50}{1711}{1729}
\hadithsectionrange{malik}{51}{1730}{1746}
\hadithsectionrange{malik}{52}{1747}{1755}
\hadithsectionrange{malik}{53}{1756}{1762}
\hadithsectionrange{malik}{54}{1763}{1807}
\hadithsectionrange{malik}{55}{1808}{1810}
\hadithsectionrange{malik}{56}{1811}{1838}
\hadithsectionrange{malik}{57}{1839}{1840}
\hadithsectionrange{malik}{58}{1841}{1855}
\hadithsectionrange{malik}{59}{1856}{1856}
\hadithsectionrange{malik}{60}{1857}{1857}
\hadithsectionrange{malik}{61}{1858}{1858}

% Chapter index — which .def file to load for each chapter

\hadithchapterfile{malik}{0}{hadithtext-malik-ch00.def}{167}{1748}
\hadithchapterfile{malik}{1}{hadithtext-malik-ch01.def}{1}{31}
\hadithchapterfile{malik}{2}{hadithtext-malik-ch02.def}{32}{145}
\hadithchapterfile{malik}{3}{hadithtext-malik-ch03.def}{146}{221}
\hadithchapterfile{malik}{4}{hadithtext-malik-ch04.def}{222}{224}
\hadithchapterfile{malik}{5}{hadithtext-malik-ch05.def}{225}{245}
\hadithchapterfile{malik}{6}{hadithtext-malik-ch06.def}{246}{253}
\hadithchapterfile{malik}{7}{hadithtext-malik-ch07.def}{254}{286}
\hadithchapterfile{malik}{8}{hadithtext-malik-ch08.def}{287}{325}
\hadithchapterfile{malik}{9}{hadithtext-malik-ch09.def}{326}{427}
\hadithchapterfile{malik}{10}{hadithtext-malik-ch10.def}{428}{440}
\hadithchapterfile{malik}{11}{hadithtext-malik-ch11.def}{441}{444}
\hadithchapterfile{malik}{12}{hadithtext-malik-ch12.def}{445}{448}
\hadithchapterfile{malik}{13}{hadithtext-malik-ch13.def}{449}{454}
\hadithchapterfile{malik}{14}{hadithtext-malik-ch14.def}{455}{469}
\hadithchapterfile{malik}{15}{hadithtext-malik-ch15.def}{470}{519}
\hadithchapterfile{malik}{16}{hadithtext-malik-ch16.def}{520}{577}
\hadithchapterfile{malik}{17}{hadithtext-malik-ch17.def}{578}{629}
\hadithchapterfile{malik}{18}{hadithtext-malik-ch18.def}{630}{689}
\hadithchapterfile{malik}{19}{hadithtext-malik-ch19.def}{690}{704}
\hadithchapterfile{malik}{20}{hadithtext-malik-ch20.def}{705}{957}
\hadithchapterfile{malik}{21}{hadithtext-malik-ch21.def}{959}{1008}
\hadithchapterfile{malik}{22}{hadithtext-malik-ch22.def}{1009}{1027}
\hadithchapterfile{malik}{23}{hadithtext-malik-ch23.def}{1028}{1041}
\hadithchapterfile{malik}{24}{hadithtext-malik-ch24.def}{1042}{1051}
\hadithchapterfile{malik}{25}{hadithtext-malik-ch25.def}{1052}{1066}
\hadithchapterfile{malik}{26}{hadithtext-malik-ch26.def}{1067}{1073}
\hadithchapterfile{malik}{27}{hadithtext-malik-ch27.def}{1074}{1089}
\hadithchapterfile{malik}{28}{hadithtext-malik-ch28.def}{1091}{1149}
\hadithchapterfile{malik}{29}{hadithtext-malik-ch29.def}{1150}{1271}
\hadithchapterfile{malik}{30}{hadithtext-malik-ch30.def}{1272}{1289}
\hadithchapterfile{malik}{31}{hadithtext-malik-ch31.def}{1290}{1385}
\hadithchapterfile{malik}{32}{hadithtext-malik-ch32.def}{1386}{1387}
\hadithchapterfile{malik}{33}{hadithtext-malik-ch33.def}{1388}{1389}
\hadithchapterfile{malik}{34}{hadithtext-malik-ch34.def}{1390}{1394}
\hadithchapterfile{malik}{35}{hadithtext-malik-ch35.def}{1395}{1398}
\hadithchapterfile{malik}{36}{hadithtext-malik-ch36.def}{1399}{1454}
\hadithchapterfile{malik}{37}{hadithtext-malik-ch37.def}{1455}{1463}
\hadithchapterfile{malik}{38}{hadithtext-malik-ch38.def}{1464}{1488}
\hadithchapterfile{malik}{39}{hadithtext-malik-ch39.def}{1489}{1496}
\hadithchapterfile{malik}{40}{hadithtext-malik-ch40.def}{1497}{1499}
\hadithchapterfile{malik}{41}{hadithtext-malik-ch41.def}{1500}{1536}
\hadithchapterfile{malik}{42}{hadithtext-malik-ch42.def}{1537}{1551}
\hadithchapterfile{malik}{43}{hadithtext-malik-ch43.def}{1552}{1595}
\hadithchapterfile{malik}{44}{hadithtext-malik-ch44.def}{1596}{1597}
\hadithchapterfile{malik}{45}{hadithtext-malik-ch45.def}{1598}{1622}
\hadithchapterfile{malik}{46}{hadithtext-malik-ch46.def}{1623}{1632}
\hadithchapterfile{malik}{47}{hadithtext-malik-ch47.def}{1633}{1650}
\hadithchapterfile{malik}{48}{hadithtext-malik-ch48.def}{1651}{1670}
\hadithchapterfile{malik}{49}{hadithtext-malik-ch49.def}{1671}{1710}
\hadithchapterfile{malik}{50}{hadithtext-malik-ch50.def}{1711}{1729}
\hadithchapterfile{malik}{51}{hadithtext-malik-ch51.def}{1730}{1746}
\hadithchapterfile{malik}{52}{hadithtext-malik-ch52.def}{1747}{1755}
\hadithchapterfile{malik}{53}{hadithtext-malik-ch53.def}{1756}{1762}
\hadithchapterfile{malik}{54}{hadithtext-malik-ch54.def}{1763}{1807}
\hadithchapterfile{malik}{55}{hadithtext-malik-ch55.def}{1808}{1810}
\hadithchapterfile{malik}{56}{hadithtext-malik-ch56.def}{1811}{1838}
\hadithchapterfile{malik}{57}{hadithtext-malik-ch57.def}{1839}{1840}
\hadithchapterfile{malik}{58}{hadithtext-malik-ch58.def}{1841}{1855}
\hadithchapterfile{malik}{59}{hadithtext-malik-ch59.def}{1856}{1856}
\hadithchapterfile{malik}{60}{hadithtext-malik-ch60.def}{1857}{1857}
\hadithchapterfile{malik}{61}{hadithtext-malik-ch61.def}{1858}{1858}
