% Auto-generated chapter 49 for bukhari
% Hadiths in this chapter: 41

\hadithdefcmd{bukhari}{2517}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا عَاصِمُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي وَاقِدُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي سَعِيدٌ ابْنُ مَرْجَانَةَ، صَاحِبُ عَلِيِّ بْنِ حُسَيْنٍ قَالَ لِي أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَيُّمَا رَجُلٍ أَعْتَقَ امْرَأً مُسْلِمًا اسْتَنْقَذَ اللَّهُ بِكُلِّ عُضْوٍ مِنْهُ عُضْوًا مِنْهُ مِنَ النَّارِ ‏"‏‏.‏ قَالَ سَعِيدٌ ابْنُ مَرْجَانَةَ فَانْطَلَقْتُ إِلَى عَلِيِّ بْنِ حُسَيْنٍ فَعَمَدَ عَلِيُّ بْنُ حُسَيْنٍ ـ رضى الله عنهما ـ إِلَى عَبْدٍ لَهُ قَدْ أَعْطَاهُ بِهِ عَبْدُ اللَّهِ بْنُ جَعْفَرٍ عَشَرَةَ آلاَفِ دِرْهَمٍ ـ أَوْ أَلْفَ دِينَارٍ ـ فَأَعْتَقَهُ‏.‏\hadithno{2517}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever frees a Muslim slave, Allah will save all the parts of his body from the (Hell) Fire as he has freed the body-parts of the slave." Sa`id bin Marjana said that he narrated that Hadith to `Ali bin Al-Husain and he freed his slave for whom `Abdullah bin Ja`far had offered him ten thousand Dirhams or one-thousand Dinars}}
\hadithdefcmd{bukhari}{2518}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ أَبِي مُرَاوِحٍ، عَنْ أَبِي ذَرٍّ ـ رضى الله عنه ـ قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم أَىُّ الْعَمَلِ أَفْضَلُ، قَالَ ‏"‏ إِيمَانٌ بِاللَّهِ، وَجِهَادٌ فِي سَبِيلِهِ ‏"‏‏.‏ قُلْتُ فَأَىُّ الرِّقَابِ أَفْضَلُ قَالَ ‏"‏ أَغْلاَهَا ثَمَنًا، وَأَنْفَسُهَا عِنْدَ أَهْلِهَا ‏"‏‏.‏ قُلْتُ فَإِنْ لَمْ أَفْعَلْ‏.‏ قَالَ ‏"‏ تُعِينُ صَانِعًا أَوْ تَصْنَعُ لأَخْرَقَ ‏"‏‏.‏ قَالَ فَإِنْ لَمْ أَفْعَلْ‏.‏ قَالَ ‏"‏ تَدَعُ النَّاسَ مِنَ الشَّرِّ، فَإِنَّهَا صَدَقَةٌ تَصَدَّقُ بِهَا عَلَى نَفْسِكَ ‏"‏‏.‏\hadithno{2518}\hadithtrans{Narrated Abu Dhar:I asked the Prophet, "What is the best deed?" He replied, "To believe in Allah and to fight for His Cause." I then asked, "What is the best kind of manumission (of slaves)?" He replied, "The manumission of the most expensive slave and the most beloved by his master." I said, "If I cannot afford to do that?" He said, "Help the weak or do good for a person who cannot work for himself." I said, "If I cannot do that?" He said, "Refrain from harming others for this will be regarded as a charitable deed for your own good}}
\hadithdefcmd{bukhari}{2519}{حَدَّثَنَا مُوسَى بْنُ مَسْعُودٍ، حَدَّثَنَا زَائِدَةُ بْنُ قُدَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ قَالَتْ أَمَرَ النَّبِيُّ صلى الله عليه وسلم بِالْعَتَاقَةِ فِي كُسُوفِ الشَّمْسِ‏.‏ تَابَعَهُ عَلِيٌّ عَنِ الدَّرَاوَرْدِيِّ عَنْ هِشَامٍ‏.‏\hadithno{2519}\hadithtrans{Narrated Asma' bint Abu Bakr:The Prophet (ﷺ) ordered us to free slaves at the time of solar eclipses}}
\hadithdefcmd{bukhari}{2520}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ، حَدَّثَنَا عَثَّامٌ، حَدَّثَنَا هِشَامٌ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ قَالَتْ كُنَّا نُؤْمَرُ عِنْدَ الْخُسُوفِ بِالْعَتَاقَةِ‏.‏\hadithno{2520}\hadithtrans{Narrated Asma' bint Abu Bakr:We were ordered to free slaves at the time of lunar eclipses}}
\hadithdefcmd{bukhari}{2521}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ سَالِمٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ عَبْدًا بَيْنَ اثْنَيْنِ، فَإِنْ كَانَ مُوسِرًا قُوِّمَ عَلَيْهِ ثُمَّ يُعْتَقُ ‏"‏‏.‏\hadithno{2521}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "Whoever manumits a slave owned by two masters, should manumit him completely (not partially) if he is rich after having its price evaluated}}
\hadithdefcmd{bukhari}{2522}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ شِرْكًا لَهُ فِي عَبْدٍ، فَكَانَ لَهُ مَالٌ يَبْلُغُ ثَمَنَ الْعَبْدِ قُوِّمَ الْعَبْدُ قِيمَةَ عَدْلٍ، فَأَعْطَى شُرَكَاءَهُ حِصَصَهُمْ وَعَتَقَ عَلَيْهِ، وَإِلاَّ فَقَدْ عَتَقَ مِنْهُ مَا عَتَقَ ‏"‏‏.‏\hadithno{2522}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Whoever frees his share of a common slave and he has sufficient money to free him completely, should let its price be estimated by a just man and give his partners the price of their shares and manumit the slave; otherwise (i.e. if he has not sufficient money) he manumits the slave partially}}
\hadithdefcmd{bukhari}{2523}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، عَنْ أَبِي أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ شِرْكًا لَهُ فِي مَمْلُوكٍ فَعَلَيْهِ عِتْقُهُ كُلِّهِ، إِنْ كَانَ لَهُ مَالٌ يَبْلُغُ ثَمَنَهُ، فَإِنْ لَمْ يَكُنْ لَهُ يُقَوَّمُ عَلَيْهِ قِيمَةَ عَدْلٍ، فَأُعْتِقَ مِنْهُ مَا أَعْتَقَ ‏"‏‏.‏ حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ، عَنْ عُبَيْدِ اللَّهِ، اخْتَصَرَهُ‏.‏\hadithno{2523}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "Whoever manumits his share of a slave, then it is essential for him to get that slave manumitted' completely as long as he has the money to do so. If he has not sufficient money to pay the price of the other shares (after the price of the slave is evaluated justly), the manumitted manumits the slave partially in proportion to his share. `Ubaidullah narrated as above in brief}}
\hadithdefcmd{bukhari}{2524}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ نَصِيبًا لَهُ فِي مَمْلُوكٍ أَوْ شِرْكًا لَهُ فِي عَبْدٍ، وَكَانَ لَهُ مِنَ الْمَالِ مَا يَبْلُغُ قِيمَتَهُ بِقِيمَةِ الْعَدْلِ، فَهْوَ عَتِيقٌ ‏"‏‏.‏ قَالَ نَافِعٌ وَإِلاَّ فَقَدْ عَتَقَ مِنْهُ مَا عَتَقَ‏.‏ قَالَ أَيُّوبُ لاَ أَدْرِي أَشَىْءٌ قَالَهُ نَافِعٌ، أَوْ شَىْءٌ فِي الْحَدِيثِ‏.‏\hadithno{2524}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "He who manumits his share of a slave and has money sufficient to free the remaining portion of that slave's price (justly estimated) then he should manumit him (by giving the rest of his price to the other co-owners)." Nafi` added, "Otherwise the slave is partially free." Aiyub is not sure whether the last statement was said by Nafi` or it was a part of the Hadith}}
\hadithdefcmd{bukhari}{2525}{حَدَّثَنَا أَحْمَدُ بْنُ مِقْدَامٍ، حَدَّثَنَا الْفُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ كَانَ يُفْتِي فِي الْعَبْدِ أَوِ الأَمَةِ يَكُونُ بَيْنَ شُرَكَاءَ، فَيُعْتِقُ أَحَدُهُمْ نَصِيبَهُ مِنْهُ، يَقُولُ قَدْ وَجَبَ عَلَيْهِ عِتْقُهُ كُلِّهِ، إِذَا كَانَ لِلَّذِي أَعْتَقَ مِنَ الْمَالِ مَا يَبْلُغُ، يُقَوَّمُ مِنْ مَالِهِ قِيمَةَ الْعَدْلِ، وَيُدْفَعُ إِلَى الشُّرَكَاءِ أَنْصِبَاؤُهُمْ، وَيُخَلَّى سَبِيلُ الْمُعْتَقِ‏.‏ يُخْبِرُ ذَلِكَ ابْنُ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَرَوَاهُ اللَّيْثُ وَابْنُ أَبِي ذِئْبٍ وَابْنُ إِسْحَاقَ وَجُوَيْرِيَةُ وَيَحْيَى بْنُ سَعِيدٍ وَإِسْمَاعِيلُ بْنُ أُمَيَّةَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم مُخْتَصَرًا‏.‏\hadithno{2525}\hadithtrans{Narrated Ibn `Umar:That he used to give his verdict regarding the male or female slaves owned by more than one master, one of whom may manumit his share of the slave. Ibn `Umar used to say in such a case, "The manumitted should manumit the slave completely if he has sufficient money to pay the rest of the price of that slave (which is to be justly estimated) and the other shareholders are to take the price of their shares and the slave is freed (released from slavery)." Ibn `Umar narrated this verdict from the Prophet}}
\hadithdefcmd{bukhari}{2526}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي رَجَاءٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، سَمِعْتُ قَتَادَةَ، قَالَ حَدَّثَنِي النَّضْرُ بْنُ أَنَسِ بْنِ مَالِكٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏\{‏مَنْ أَعْتَقَ شَقِيصًا مِنْ عَبْدٍ ‏\}‏\hadithno{2526}\hadithtrans{Narrated Abu Huraira:That the Prophet (ﷺ) said, "Whoever frees his portion of a (common) slave}}
\hadithdefcmd{bukhari}{2527}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ نَصِيبًا أَوْ شَقِيصًا فِي مَمْلُوكٍ، فَخَلاَصُهُ عَلَيْهِ فِي مَالِهِ إِنْ كَانَ لَهُ مَالٌ، وَإِلاَّ قُوِّمَ عَلَيْهِ، فَاسْتُسْعِيَ بِهِ غَيْرَ مَشْقُوقٍ عَلَيْهِ ‏"‏‏.‏ تَابَعَهُ حَجَّاجُ بْنُ حَجَّاجٍ وَأَبَانُ وَمُوسَى بْنُ خَلَفٍ عَنْ قَتَادَةَ‏.‏ اخْتَصَرَهُ شُعْبَةُ‏.‏\hadithno{2527}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever frees his portion of a common slave should free the slave completely by paying the rest of his price from his money if he has enough money; otherwise the price of the slave is to be estimated and the slave is to be helped to work without hardship till he pays the rest of his price}}
\hadithdefcmd{bukhari}{2528}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا مِسْعَرٌ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ تَجَاوَزَ لِي عَنْ أُمَّتِي مَا وَسْوَسَتْ بِهِ صُدُورُهَا، مَا لَمْ تَعْمَلْ أَوْ تَكَلَّمْ ‏"‏‏.‏\hadithno{2528}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah has accepted my invocation to forgive what whispers in the hearts of my followers, unless they put it to action or utter it." (See Hadith No. 657 Vol)}}
\hadithdefcmd{bukhari}{2529}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، عَنْ سُفْيَانَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ عَلْقَمَةَ بْنِ وَقَّاصٍ اللَّيْثِيِّ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الأَعْمَالُ بِالنِّيَّةِ، وَلاِمْرِئٍ مَا نَوَى، فَمَنْ كَانَتْ هِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ، فَهِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ، وَمَنْ كَانَتْ هِجْرَتُهُ لِدُنْيَا يُصِيبُهَا، أَوِ امْرَأَةٍ يَتَزَوَّجُهَا، فَهِجْرَتُهُ إِلَى مَا هَاجَرَ إِلَيْهِ ‏"‏‏.‏\hadithno{2529}\hadithtrans{Narrated `Umar bin Al-Khattab:The Prophet (ﷺ) said, "The (reward of) deeds depend on intentions, and every person will get the reward according to what he intends. So, whoever migrated for Allah and His Apostle, then his migration will be for Allah and His Apostle, and whoever migrated for worldly benefits or for marrying a woman, then his migration will be for what he migrated for." (See Hadith No. 1, Vol)}}
\hadithdefcmd{bukhari}{2530}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، عَنْ مُحَمَّدِ بْنِ بِشْرٍ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ لَمَّا أَقْبَلَ يُرِيدُ الإِسْلاَمَ وَمَعَهُ غُلاَمُهُ، ضَلَّ كُلُّ وَاحِدٍ مِنْهُمَا مِنْ صَاحِبِهِ، فَأَقْبَلَ بَعْدَ ذَلِكَ وَأَبُو هُرَيْرَةَ جَالِسٌ مَعَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا أَبَا هُرَيْرَةَ، هَذَا غُلاَمُكَ قَدْ أَتَاكَ ‏"‏‏.‏ فَقَالَ أَمَا إِنِّي أُشْهِدُكَ أَنَّهُ حُرٌّ‏.‏ قَالَ فَهُوَ حِينَ يَقُولُ يَا لَيْلَةً مِنْ طُولِهَا وَعَنَائِهَا عَلَى أَنَّهَا مِنْ دَارَةِ الْكُفْرِ نَجَّتِ\hadithno{2530}\hadithtrans{Narrated Qais:When Abu Huraira accompanied by his slave set out intending to embrace Islam they lost each other on the way. The slave then came while Abu Huraira was sitting with the Prophet. The Prophet (ﷺ) said, "O Abu Huraira! Your slave has come back." Abu Huraira said, "Indeed, I would like you to witness that I have manumitted him." That happened at the time when Abu Huraira recited (the following poetic verse):-- 'What a long tedious tiresome night! Nevertheless, it has delivered us From the land of Kufr (disbelief)}}
\hadithdefcmd{bukhari}{2531}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ قَيْسٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ لَمَّا قَدِمْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم قُلْتُ فِي الطَّرِيقِ يَا لَيْلَةً مِنْ طُولِهَا وَعَنَائِهَا عَلَى أَنَّهَا مِنْ دَارَةِ الْكُفْرِ نَجَّتِ قَالَ وَأَبَقَ مِنِّي غُلاَمٌ لِي فِي الطَّرِيقِ ـ قَالَ ـ فَلَمَّا قَدِمْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم بَايَعْتُهُ، فَبَيْنَا أَنَا عِنْدَهُ إِذْ طَلَعَ الْغُلاَمُ، فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا أَبَا هُرَيْرَةَ، هَذَا غُلاَمُكَ ‏"‏‏.‏ فَقُلْتُ هُوَ حُرٌّ لِوَجْهِ اللَّهِ‏.‏ فَأَعْتَقْتُهُ‏.‏ لَمْ يَقُلْ أَبُو كُرَيْبٍ عَنْ أَبِي أُسَامَةَ حُرٌّ‏.‏\hadithno{2531}\hadithtrans{Narrated Abu Huraira:On my way to the Prophet (ﷺ) I was reciting:-- 'What a long tedious tiresome night! Nevertheless, it has saved us From the land of Kufr (disbelief).' I had a slave who ran away from me on the way. When I went to the Prophet (ﷺ) and gave the pledge of allegiance for embracing Islam, the slave showed up while I was still with the Prophet (ﷺ) who remarked, "O Abu Huraira! Here is your slave!" I said, "I manumit him for Allah's Sake," and so I freed him}}
\hadithdefcmd{bukhari}{2532}{حَدَّثَنَا شِهَابُ بْنُ عَبَّادٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ حُمَيْدٍ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، قَالَ لَمَّا أَقْبَلَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ وَمَعَهُ غُلاَمُهُ وَهْوَ يَطْلُبُ الإِسْلاَمَ، فَأَضَلَّ أَحَدُهُمَا صَاحِبَهُ بِهَذَا، وَقَالَ أَمَا إِنِّي أُشْهِدُكَ أَنَّهُ لِلَّهِ‏.‏\hadithno{2532}\hadithtrans{Narrated Qais:When Abu Huraira accompanied by his slave came intending to embrace Islam, they lost each other on the way. (When the slave showed up) Abu Huraira said (to the Prophet), "I make you witness that the slave is free for Allah's Cause}}
\hadithdefcmd{bukhari}{2533}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ إِنَّ عُتْبَةَ بْنَ أَبِي وَقَّاصٍ عَهِدَ إِلَى أَخِيهِ سَعْدِ بْنِ أَبِي وَقَّاصٍ أَنْ يَقْبِضَ إِلَيْهِ ابْنَ وَلِيدَةِ زَمْعَةَ، قَالَ عُتْبَةُ إِنَّهُ ابْنِي‏.‏ فَلَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَمَنَ الْفَتْحِ أَخَذَ سَعْدٌ ابْنَ وَلِيدَةِ زَمْعَةَ‏.‏ فَأَقْبَلَ بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَقْبَلَ مَعَهُ بِعَبْدِ بْنِ زَمْعَةَ‏.‏ فَقَالَ سَعْدٌ يَا رَسُولَ اللَّهِ هَذَا ابْنُ أَخِي عَهِدَ إِلَىَّ أَنَّهُ ابْنُهُ‏.‏ فَقَالَ عَبْدُ بْنُ زَمْعَةَ يَا رَسُولَ اللَّهِ هَذَا أَخِي ابْنُ وَلِيدَةِ زَمْعَةَ، وُلِدَ عَلَى فِرَاشِهِ‏.‏ فَنَظَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى ابْنِ وَلِيدَةِ زَمْعَةَ، فَإِذَا هُوَ أَشْبَهُ النَّاسِ بِهِ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هُوَ لَكَ يَا عَبْدُ بْنَ زَمْعَةَ ‏"‏‏.‏ مِنْ أَجْلِ أَنَّهُ وُلِدَ عَلَى فِرَاشِ أَبِيهِ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ احْتَجِبِي مِنْهُ يَا سَوْدَةُ بِنْتَ زَمْعَةَ ‏"‏‏.‏ مِمَّا رَأَى مِنْ شَبَهِهِ بِعُتْبَةَ‏.‏ وَكَانَتْ سَوْدَةُ زَوْجَ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2533}\hadithtrans{Narrated `Aisha:`Utba bin Abi Waqqas authorized his brother Sa`d bin Abi Waqqas to take the son of the slave-girl of Zam`a into his custody, telling him that the boy was his own (illegal) son. When Allah's Messenger (ﷺ) went (to Mecca) at the time of the Conquest, Sa`d took the son of the slave-girl of Zam`a to Allah's Messenger (ﷺ) and also brought 'Abu bin Zam`a with him and said, "O Allah's Messenger (ﷺ)! This is the son of my brother `Utba who authorized me to take him into my custody." 'Abu bin Zam`a said, "O Allah's Messenger (ﷺ)! He is my brother, the son of Zam`a's slave-girl and he was born on his bed." Allah's Messenger (ﷺ) looked at the son of the slave-girl of Zam`a and noticed much resemblance (to `Utba). Allah's Messenger (ﷺ) said, "It is for you, O 'Abu bin Zam`a as he was born on the bed of your father." Allah's Messenger (ﷺ) then told Sauda bint Zam`a to observe veil in the presence of the boy as he noticed the boy's resemblance to `Utba and Sauda was the wife of the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{2534}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ أَعْتَقَ رَجُلٌ مِنَّا عَبْدًا لَهُ عَنْ دُبُرٍ، فَدَعَا النَّبِيُّ صلى الله عليه وسلم بِهِ فَبَاعَهُ‏.‏ قَالَ جَابِرٌ مَاتَ الْغُلاَمُ عَامَ أَوَّلَ‏.‏\hadithno{2534}\hadithtrans{Narrated Jabir bin `Abdullah:A man amongst us declared that his slave would be freed after his death. The Prophet (ﷺ) called for that slave and sold him. The slave died the same year}}
\hadithdefcmd{bukhari}{2535}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الْوَلاَءِ، وَعَنْ هِبَتِهِ‏.‏\hadithno{2535}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) forbade the selling or donating the Wala' of a freed slave}}
\hadithdefcmd{bukhari}{2536}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتِ اشْتَرَيْتُ بَرِيرَةَ فَاشْتَرَطَ أَهْلُهَا وَلاَءَهَا، فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَعْتِقِيهَا، فَإِنَّ الْوَلاَءَ لِمَنْ أَعْطَى الْوَرِقَ ‏"‏‏.‏ فَأَعْتَقْتُهَا، فَدَعَاهَا النَّبِيُّ صلى الله عليه وسلم فَخَيَّرَهَا مِنْ زَوْجِهَا فَقَالَتْ لَوْ أَعْطَانِي كَذَا وَكَذَا مَا ثَبَتُّ عِنْدَهُ‏.‏ فَاخْتَارَتْ نَفْسَهَا‏.‏\hadithno{2536}\hadithtrans{Narrated `Aisha:I bought Barirah but her masters put the condition that her Wala' would be for them. I told the Prophet (ﷺ) about it. He said (to me), "Manumit (free) her as her Wala' will be for the one who pays the price." So, I manumitted (freed) her. The Prophet (ﷺ) called Barirah and gave her the option of either staying with her husband or leaving him. She said, "Even if he gave me so much money, I would not stay with him," and so she preferred her freedom to her husband}}
\hadithdefcmd{bukhari}{2537}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ بْنِ عُقْبَةَ، عَنْ مُوسَى، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي أَنَسٌ ـ رضى الله عنه ـ أَنَّ رِجَالاً، مِنَ الأَنْصَارِ اسْتَأْذَنُوا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالُوا ائْذَنْ فَلْنَتْرُكْ لاِبْنِ أُخْتِنَا عَبَّاسٍ فِدَاءَهُ، فَقَالَ ‏ "‏ لاَ تَدَعُونَ مِنْهُ دِرْهَمًا ‏"‏‏.‏\hadithno{2537}\hadithtrans{Narrated Anas:Some men of the Ansar asked for the permission of Allah's Messenger (ﷺ) and said, "Allow us to give up the ransom from our nephew Al-`Abbas. The Prophet (ﷺ) said (to them), "Do not leave (even) a Dirham (of his ransom)}}
\hadithdefcmd{bukhari}{2538}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، أَخْبَرَنِي أَبِي أَنَّ حَكِيمَ بْنَ حِزَامٍ ـ رضى الله عنه ـ أَعْتَقَ فِي الْجَاهِلِيَّةِ مِائَةَ رَقَبَةٍ، وَحَمَلَ عَلَى مِائَةِ بَعِيرٍ، فَلَمَّا أَسْلَمَ حَمَلَ عَلَى مِائَةِ بَعِيرٍ وَأَعْتَقَ مِائَةَ رَقَبَةٍ، قَالَ فَسَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ، أَرَأَيْتَ أَشْيَاءَ كُنْتُ أَصْنَعُهَا فِي الْجَاهِلِيَّةِ، كُنْتُ أَتَحَنَّثُ بِهَا، يَعْنِي أَتَبَرَّرُ بِهَا، قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَسْلَمْتَ عَلَى مَا سَلَفَ لَكَ مِنْ خَيْرٍ ‏"‏‏.‏\hadithno{2538}\hadithtrans{Narrated Hisham:My father told me that Hakim bin Hizam manumitted one-hundred slaves in the Pre-Islamic period of ignorance and slaughtered one-hundred camels (and distributed them in charity). When he embraced Islam he again slaughtered one-hundred camels and manumitted one-hundred slaves. Hakim said, "I asked Allah's Messenger (ﷺ), 'O Allah's Messenger (ﷺ)! What do you think about some good deeds I used to practice in the Pre-Islamic period of ignorance regarding them as deeds of righteousness?' Allah's Apostle said, "You have embraced Islam along with all those good deeds you did}}
\hadithdefcmd{bukhari}{2540}{حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، قَالَ أَخْبَرَنِي اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، ذَكَرَ عُرْوَةُ أَنَّ مَرْوَانَ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَاهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَامَ حِينَ جَاءَهُ وَفْدُ هَوَازِنَ، فَسَأَلُوهُ أَنْ يَرُدَّ إِلَيْهِمْ أَمْوَالَهُمْ وَسَبْيَهُمْ فَقَالَ ‏"‏ إِنَّ مَعِي مَنْ تَرَوْنَ، وَأَحَبُّ الْحَدِيثِ إِلَىَّ أَصْدَقُهُ، فَاخْتَارُوا إِحْدَى الطَّائِفَتَيْنِ إِمَّا الْمَالَ، وَإِمَّا السَّبْىَ، وَقَدْ كُنْتُ اسْتَأْنَيْتُ بِهِمْ ‏"‏‏.‏ وَكَانَ النَّبِيُّ صلى الله عليه وسلم انْتَظَرَهُمْ بِضْعَ عَشْرَةَ لَيْلَةً حِينَ قَفَلَ مِنَ الطَّائِفِ، فَلَمَّا تَبَيَّنَ لَهُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم غَيْرُ رَادٍّ إِلَيْهِمْ إِلاَّ إِحْدَى الطَّائِفَتَيْنِ قَالُوا فَإِنَّا نَخْتَارُ سَبْيَنَا‏.‏ فَقَامَ النَّبِيُّ صلى الله عليه وسلم فِي النَّاسِ، فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ، ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَإِنَّ إِخْوَانَكُمْ جَاءُونَا تَائِبِينَ، وَإِنِّي رَأَيْتُ أَنْ أَرُدَّ إِلَيْهِمْ سَبْيَهُمْ، فَمَنْ أَحَبَّ مِنْكُمْ أَنْ يُطَيِّبَ ذَلِكَ فَلْيَفْعَلْ، وَمَنْ أَحَبَّ أَنْ يَكُونَ عَلَى حَظِّهِ حَتَّى نُعْطِيَهُ إِيَّاهُ مِنْ أَوَّلِ مَا يُفِيءُ اللَّهُ عَلَيْنَا فَلْيَفْعَلْ ‏"‏‏.‏ فَقَالَ النَّاسُ طَيَّبْنَا ذَلِكَ‏.‏ قَالَ ‏"‏ إِنَّا لاَ نَدْرِي مَنْ أَذِنَ مِنْكُمْ مِمَّنْ لَمْ يَأْذَنْ فَارْجِعُوا حَتَّى يَرْفَعَ إِلَيْنَا عُرَفَاؤُكُمْ أَمْرَكُمْ ‏"‏‏.‏ فَرَجَعَ النَّاسُ، فَكَلَّمَهُمْ عُرَفَاؤُهُمْ، ثُمَّ رَجَعُوا إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرُوهُ أَنَّهُمْ طَيَّبُوا وَأَذِنُوا، فَهَذَا الَّذِي بَلَغَنَا عَنْ سَبْىِ هَوَازِنَ‏.‏ وَقَالَ أَنَسٌ قَالَ عَبَّاسٌ لِلنَّبِيِّ صلى الله عليه وسلم فَادَيْتُ نَفْسِي، وَفَادَيْتُ عَقِيلاً‏.‏\hadithno{2540}\hadithtrans{Narrated Marwan and Al-Miswar bin Makhrama:When the delegates of the tribe of Hawazin came to the Prophet (ﷺ) and they requested him to return their properties and captives. The Prophet (ﷺ) stood up and said to them, "I have other people with me in this matter (as you see) and the most beloved statement to me is the true one; you may choose either the properties or the prisoners as I have delayed their distribution." The Prophet (ﷺ) had waited for them for more than ten days since his arrival from Ta'if. So, when it became evident to them that the Prophet (ﷺ) was not going to return them except one of the two, they said, "We choose our prisoners." The Prophet got up amongst the people and glorified and praised Allah as He deserved and said, "Then after, these brethren of yours have come to us with repentance, and I see it logical to return them the captives. So, whoever amongst you likes to do that as a favor, then he can do it, and whoever of you likes to stick to his share till we recompense him from the very first war booty which Allah will give us, then he can do so (i.e. give up the present captives)." The people unanimously said, "We do that (return the captives) willingly." The Prophet (ﷺ) said, "We do not know which of you has agreed to it and which have not, so go back and let your leaders forward us your decision." So, all the people then went back and discussed the matter with their leaders who returned and informed the Prophet (ﷺ) that all the people had willingly given their consent to return the captives. This is what has reached us about the captives of Hawazin. Narrated Anas that `Abbas said to the Prophet, "I paid for my ransom and `Aqil's ransom}}
\hadithdefcmd{bukhari}{2541}{حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا ابْنُ عَوْنٍ، قَالَ كَتَبْتُ إِلَى نَافِعٍ فَكَتَبَ إِلَىَّ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَغَارَ عَلَى بَنِي الْمُصْطَلِقِ وَهُمْ غَارُّونَ وَأَنْعَامُهُمْ تُسْقَى عَلَى الْمَاءِ، فَقَتَلَ مُقَاتِلَتَهُمْ، وَسَبَى ذَرَارِيَّهُمْ، وَأَصَابَ يَوْمَئِذٍ جُوَيْرِيَةَ‏.‏ حَدَّثَنِي بِهِ عَبْدُ اللَّهِ بْنُ عُمَرَ، وَكَانَ فِي ذَلِكَ الْجَيْشِ‏.‏\hadithno{2541}\hadithtrans{Narrated Ibn `Aun:I wrote a letter to Nafi` and Nafi` wrote in reply to my letter that the Prophet (ﷺ) had suddenly attacked Bani Mustaliq without warning while they were heedless and their cattle were being watered at the places of water. Their fighting men were killed and their women and children were taken as captives; the Prophet (ﷺ) got Juwairiya on that day. Nafi` said that Ibn `Umar had told him the above narration and that Ibn `Umar was in that army}}
\hadithdefcmd{bukhari}{2542}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ ابْنِ مُحَيْرِيزٍ، قَالَ رَأَيْتُ أَبَا سَعِيدٍ ـ رضى الله عنه ـ فَسَأَلْتُهُ فَقَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ بَنِي الْمُصْطَلِقِ فَأَصَبْنَا سَبْيًا مِنْ سَبْىِ الْعَرَبِ، فَاشْتَهَيْنَا النِّسَاءَ فَاشْتَدَّتْ عَلَيْنَا الْعُزْبَةُ وَأَحْبَبْنَا الْعَزْلَ، فَسَأَلْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ مَا عَلَيْكُمْ أَنْ لاَ تَفْعَلُوا، مَا مِنْ نَسَمَةٍ كَائِنَةٍ إِلَى يَوْمِ الْقِيَامَةِ إِلاَّ وَهْىَ كَائِنَةٌ ‏"‏‏.‏\hadithno{2542}\hadithtrans{Narrated Ibn Muhairiz:I saw Abu Sa`id and asked him about coitus interruptus. Abu Sa`id said, "We went with Allah's Apostle, in the Ghazwa of Bani Al-Mustaliq and we captured some of the 'Arabs as captives, and the long separation from our wives was pressing us hard and we wanted to practice coitus interruptus. We asked Allah's Messenger (ﷺ) (whether it was permissible). He said, "It is better for you not to do so. No soul, (that which Allah has) destined to exist, up to the Day of Resurrection, but will definitely come, into existence}}
\hadithdefcmd{bukhari}{2543}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ لاَ أَزَالُ أُحِبُّ بَنِي تَمِيمٍ‏.‏ وَحَدَّثَنِي ابْنُ سَلاَمٍ أَخْبَرَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ عَنِ الْمُغِيرَةِ عَنِ الْحَارِثِ عَنْ أَبِي زُرْعَةَ عَنْ أَبِي هُرَيْرَةَ‏.‏ وَعَنْ عُمَارَةَ عَنْ أَبِي زُرْعَةَ عَنْ أَبِي هُرَيْرَةَ قَالَ مَا زِلْتُ أُحِبُّ بَنِي تَمِيمٍ مُنْذُ ثَلاَثٍ سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ فِيهِمْ، سَمِعْتُهُ يَقُولُ ‏"‏ هُمْ أَشَدُّ أُمَّتِي عَلَى الدَّجَّالِ ‏"‏‏.‏ قَالَ وَجَاءَتْ صَدَقَاتُهُمْ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذِهِ صَدَقَاتُ قَوْمِنَا ‏"‏‏.‏ وَكَانَتْ سَبِيَّةٌ مِنْهُمْ عِنْدَ عَائِشَةَ‏.‏ فَقَالَ ‏"‏ أَعْتِقِيهَا فَإِنَّهَا مِنْ وَلَدِ إِسْمَاعِيلَ ‏"‏‏.‏\hadithno{2543}\hadithtrans{Narrated Abu Huraira:I have loved the people of the tribe of Bani Tamim ever since I heard, three things, Allah's Messenger (ﷺ) said about them. I heard him saying, These people (of the tribe of Bani Tamim) would stand firm against Ad-Dajjal." When the Sadaqat (gifts of charity) from that tribe came, Allah's Messenger (ﷺ) said, "These are the Sadaqat (i.e. charitable gifts) of our folk." `Aisha had a slave-girl from that tribe, and the Prophet (ﷺ) said to `Aisha, "Manumit her as she is a descendant of Ishmael (the Prophet)}}
\hadithdefcmd{bukhari}{2544}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، سَمِعَ مُحَمَّدَ بْنَ فُضَيْلٍ، عَنْ مُطَرِّفٍ، عَنِ الشَّعْبِيِّ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ جَارِيَةٌ فَعَالَهَا، فَأَحْسَنَ إِلَيْهَا ثُمَّ أَعْتَقَهَا وَتَزَوَّجَهَا، كَانَ لَهُ أَجْرَانِ ‏"‏‏.‏\hadithno{2544}\hadithtrans{Narrated Abu Musa:Allah's Messenger (ﷺ) said, "He who has a slave-girl and educates and treats her nicely and then manumits and marries her, will get a double reward}}
\hadithdefcmd{bukhari}{2545}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا وَاصِلٌ الأَحْدَبُ، قَالَ سَمِعْتُ الْمَعْرُورَ بْنَ سُوَيْدٍ، قَالَ رَأَيْتُ أَبَا ذَرٍّ الْغِفَارِيَّ ـ رضى الله عنه ـ وَعَلَيْهِ حُلَّةٌ وَعَلَى غُلاَمِهِ حُلَّةٌ فَسَأَلْنَاهُ عَنْ ذَلِكَ فَقَالَ إِنِّي سَابَبْتُ رَجُلاً فَشَكَانِي إِلَى النَّبِيِّ صلى الله عليه وسلم، فَقَالَ لِيَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَعَيَّرْتَهُ بِأُمِّهِ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ إِخْوَانَكُمْ خَوَلُكُمْ جَعَلَهُمُ اللَّهُ تَحْتَ أَيْدِيكُمْ، فَمَنْ كَانَ أَخُوهُ تَحْتَ يَدِهِ فَلْيُطْعِمْهُ مِمَّا يَأْكُلُ، وَلْيُلْبِسْهُ مِمَّا يَلْبَسُ، وَلاَ تُكَلِّفُوهُمْ مَا يَغْلِبُهُمْ، فَإِنْ كَلَّفْتُمُوهُمْ مَا يَغْلِبُهُمْ فَأَعِينُوهُمْ ‏"‏‏.‏\hadithno{2545}\hadithtrans{Narrated Al-Ma'rur bin Suwaid:I saw Abu Dhar Al-Ghifari wearing a cloak, and his slave, too, was wearing a cloak. We asked him about that (i.e. how both were wearing similar cloaks). He replied, "Once I abused a man and he complained of me to the Prophet (ﷺ) . The Prophet (ﷺ) asked me, 'Did you abuse him by slighting his mother?' He added, 'Your slaves are your brethren upon whom Allah has given you authority. So, if one has one's brethren under one's control, one should feed them with the like of what one eats and clothe them with the like of what one wears. You should not overburden them with what they cannot bear, and if you do so, help them (in their hard job)}}
\hadithdefcmd{bukhari}{2546}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَبْدُ إِذَا نَصَحَ سَيِّدَهُ وَأَحْسَنَ عِبَادَةَ رَبِّهِ كَانَ لَهُ أَجْرُهُ مَرَّتَيْنِ ‏"‏‏.‏\hadithno{2546}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "If a slave is honest and faithful to his master and worships his Lord (Allah) in a perfect manner, he will get a double reward}}
\hadithdefcmd{bukhari}{2547}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ صَالِحٍ، عَنِ الشَّعْبِيِّ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ ـ رضى الله عنه ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَيُّمَا رَجُلٍ كَانَتْ لَهُ جَارِيَةٌ فَأَدَّبَهَا فَأَحْسَنَ تَأْدِيبَهَا، وَأَعْتَقَهَا وَتَزَوَّجَهَا، فَلَهُ أَجْرَانِ، وَأَيُّمَا عَبْدٍ أَدَّى حَقَّ اللَّهِ وَحَقَّ مَوَالِيهِ، فَلَهُ أَجْرَانِ ‏"‏‏.‏\hadithno{2547}\hadithtrans{Narrated Abu Musa Al-Ash`ari:The Prophet (ﷺ) said, "He who has a slave-girl and teaches her good manners and improves her education and then manumits and marries her, will get a double reward; and any slave who observes Allah's right and his master's right will get a double reward}}
\hadithdefcmd{bukhari}{2548}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ قَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِلْعَبْدِ الْمَمْلُوكِ الصَّالِحِ أَجْرَانِ، وَالَّذِي نَفْسِي بِيَدِهِ لَوْلاَ الْجِهَادُ فِي سَبِيلِ اللَّهِ وَالْحَجُّ وَبِرُّ أُمِّي، لأَحْبَبْتُ أَنْ أَمُوتَ وَأَنَا مَمْلُوكٌ ‏"‏‏.‏\hadithno{2548}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "A pious slave gets a double reward." Abu Huraira added: By Him in Whose Hands my soul is but for Jihad (i.e. holy battles), Hajj, and my duty to serve my mother, I would have loved to die as a slave}}
\hadithdefcmd{bukhari}{2549}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الأَعْمَشِ، حَدَّثَنَا أَبُو صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ نِعْمَ مَا لأَحَدِهِمْ يُحْسِنُ عِبَادَةَ رَبِّهِ وَيَنْصَحُ لِسَيِّدِهِ ‏"‏‏.‏\hadithno{2549}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Goodness and comfort are for him who worships his Lord in a perfect manner and serves his master sincerely}}
\hadithdefcmd{bukhari}{2550}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نَصَحَ الْعَبْدُ سَيِّدَهُ، وَأَحْسَنَ عِبَادَةَ رَبِّهِ، كَانَ لَهُ أَجْرُهُ مَرَّتَيْنِ ‏"‏‏.‏\hadithno{2550}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "If a slave serves his Saiyid (i.e. master) sincerely and worships his Lord (Allah) perfectly, he will get a double reward}}
\hadithdefcmd{bukhari}{2551}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَمْلُوكُ الَّذِي يُحْسِنُ عِبَادَةَ رَبِّهِ، وَيُؤَدِّي إِلَى سَيِّدِهِ الَّذِي لَهُ عَلَيْهِ مِنَ الْحَقِّ وَالنَّصِيحَةِ وَالطَّاعَةِ، لَهُ أَجْرَانِ ‏"‏‏.‏\hadithno{2551}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "The Mamluk (slave) who worships his Lord in a perfect manner, and is dutiful, sincere and obedient to his Saiyid (master), will get a double reward}}
\hadithdefcmd{bukhari}{2552}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لاَ يَقُلْ أَحَدُكُمْ أَطْعِمْ رَبَّكَ، وَضِّئْ رَبَّكَ، اسْقِ رَبَّكَ‏.‏ وَلْيَقُلْ سَيِّدِي مَوْلاَىَ‏.‏ وَلاَ يَقُلْ أَحَدُكُمْ عَبْدِي أَمَتِي‏.‏ وَلْيَقُلْ فَتَاىَ وَفَتَاتِي وَغُلاَمِي ‏"‏‏.‏\hadithno{2552}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "You should not say, 'Feed your lord (Rabbaka), help your lord in performing ablution, or give water to your lord, but should say, 'my master (e.g. Feed your master instead of lord etc.) (Saiyidi), or my guardian (Maulai), and one should not say, my slave (Abdi), or my girl-slave (Amati), but should say, my lad (Fatai), my lass (Fatati), and 'my boy (Ghulami)}}
\hadithdefcmd{bukhari}{2553}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ نَصِيبًا لَهُ مِنَ الْعَبْدِ، فَكَانَ لَهُ مِنَ الْمَالِ مَا يَبْلُغُ قِيمَتَهُ، يُقَوَّمُ عَلَيْهِ قِيمَةَ عَدْلٍ، وَأُعْتِقَ مِنْ مَالِهِ، وَإِلاَّ فَقَدْ عَتَقَ مِنْهُ ‏"‏‏.‏\hadithno{2553}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "If one manumits his share of a common slave (Abd), and he has money sufficient to free the remaining portion of the price of the slave (justly estimated), then he should free the slave completely by paying the rest of his price; otherwise the slave is freed partly}}
\hadithdefcmd{bukhari}{2554}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّكُمْ رَاعٍ فَمَسْئُولٌ عَنْ رَعِيَّتِهِ، فَالأَمِيرُ الَّذِي عَلَى النَّاسِ رَاعٍ وَهْوَ مَسْئُولٌ عَنْهُمْ، وَالرَّجُلُ رَاعٍ عَلَى أَهْلِ بَيْتِهِ وَهْوَ مَسْئُولٌ عَنْهُمْ، وَالْمَرْأَةُ رَاعِيَةٌ عَلَى بَيْتِ بَعْلِهَا وَوَلَدِهِ وَهْىَ مَسْئُولَةٌ عَنْهُمْ، وَالْعَبْدُ رَاعٍ عَلَى مَالِ سَيِّدِهِ وَهْوَ مَسْئُولٌ عَنْهُ، أَلاَ فَكُلُّكُمْ رَاعٍ وَكُلُّكُمْ مَسْئُولٌ عَنْ رَعِيَّتِهِ ‏"‏‏.‏\hadithno{2554}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said, "Everyone of you is a guardian and is responsible for his charges. The ruler who has authority over people, is a guardian and is responsible for them, a man is a guardian of his family and is responsible for them; a woman is a guardian of her husband's house and children and is responsible for them; a slave ('Abu) is a guardian of his master's property and is responsible for it; so all of you are guardians and are responsible for your charges}}
\hadithdefcmd{bukhari}{2555}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي عُبَيْدُ اللَّهِ، سَمِعْتُ أَبَا هُرَيْرَةَ، وَزَيْدَ بْنَ خَالِدٍ، رضى الله عنهما عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا زَنَتِ الأَمَةُ فَاجْلِدُوهَا، ثُمَّ إِذَا زَنَتْ فَاجْلِدُوهَا، ثُمَّ إِذَا زَنَتْ فَاجْلِدُوهَا، فِي الثَّالِثَةِ أَوِ الرَّابِعَةِ بِيعُوهَا وَلَوْ بِضَفِيرٍ ‏"‏‏.‏\hadithno{2555}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:The Prophet (ﷺ) said, "If a slave-girl (Ama) commits illegal sexual intercourse, scourge her; if she does it again, scourge her again; if she repeats it, scourge her again." The narrator added that on the third or the fourth offense, the Prophet (ﷺ) said, "Sell her even for a hair rope}}
\hadithdefcmd{bukhari}{2557}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ زِيَادٍ، سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ إِذَا أَتَى أَحَدَكُمْ خَادِمُهُ بِطَعَامِهِ، فَإِنْ لَمْ يُجْلِسْهُ مَعَهُ، فَلْيُنَاوِلْهُ لُقْمَةً أَوْ لُقْمَتَيْنِ أَوْ أُكْلَةً أَوْ أُكْلَتَيْنِ، فَإِنَّهُ وَلِيَ عِلاَجَهُ ‏"‏‏.‏\hadithno{2557}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "When your servant brings your meals to you then if he does not let him sit and share the meals, then he should at least give him a mouthful or two mouthfuls of that meal or a meal or two meals, as he has prepared it}}
\hadithdefcmd{bukhari}{2558}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ كُلُّكُمْ رَاعٍ وَمَسْئُولٌ عَنْ رَعِيَّتِهِ، فَالإِمَامُ رَاعٍ وَمَسْئُولٌ عَنْ رَعِيَّتِهِ، وَالرَّجُلُ فِي أَهْلِهِ رَاعٍ وَهْوَ مَسْئُولٌ عَنْ رَعِيَّتِهِ، وَالْمَرْأَةُ فِي بَيْتِ زَوْجِهَا رَاعِيَةٌ وَهْىَ مَسْئُولَةٌ عَنْ رَعِيَّتِهَا، وَالْخَادِمُ فِي مَالِ سَيِّدِهِ رَاعٍ وَهْوَ مَسْئُولٌ عَنْ رَعِيَّتِهِ ‏"‏‏.‏ قَالَ فَسَمِعْتُ هَؤُلاَءِ مِنَ النَّبِيِّ صلى الله عليه وسلم وَأَحْسِبُ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ وَالرَّجُلُ فِي مَالِ أَبِيهِ رَاعٍ وَمَسْئُولٌ عَنْ رَعِيَّتِهِ، فَكُلُّكُمْ رَاعٍ وَكُلُّكُمْ مَسْئُولٌ عَنْ رَعِيَّتِهِ ‏"‏‏.‏\hadithno{2558}\hadithtrans{Narrated `Abdullah bin `Umar:That he heard Allah's Messenger (ﷺ) saying, "Everyone of you is a guardian and is responsible for his charge; the ruler is a guardian and is responsible for his subjects; the man is a guardian in his family and responsible for his charges; a woman is a guardian of her husband's house and responsible for her charges; and the servant is a guardian of his master's property and is responsible for his charge." I definitely heard the above from the Prophet (ﷺ) and think that the Prophet (ﷺ) also said, "A man is a guardian of his father's property and responsible for his charges; so everyone of you is a guardian and responsible for his charges}}
\hadithdefcmd{bukhari}{2559}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي مَالِكُ بْنُ أَنَسٍ، قَالَ وَأَخْبَرَنِي ابْنُ فُلاَنٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَاتَلَ أَحَدُكُمْ فَلْيَجْتَنِبِ الْوَجْهَ ‏"‏‏.‏\hadithno{2559}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If somebody fights (or beats somebody) then he should avoid the face}}
