% Auto-generated chapter 25 for muslim
% Hadiths in this chapter: 31

\hadithdefcmd{muslim}{4204}{حَدَّثَنَا أَبُو خَيْثَمَةَ، زُهَيْرُ بْنُ حَرْبٍ وَمُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ، عُمَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا حَقُّ امْرِئٍ مُسْلِمٍ لَهُ شَىْءٌ يُرِيدُ أَنْ يُوصِيَ فِيهِ يَبِيتُ لَيْلَتَيْنِ إِلاَّ وَوَصِيَّتُهُ مَكْتُوبَةٌ عِنْدَهُ ‏"‏ ‏.‏\hadithno{4204}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:It is the duty of a Muslim who has something which is to be given as a bequest not to have it for two nights without having his will written down regarding it}}
\hadithdefcmd{muslim}{4205}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنِي أَبِي كِلاَهُمَا، عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُمَا قَالاَ ‏"‏ وَلَهُ شَىْءٌ يُوصِي فِيهِ ‏"‏ ‏.‏ وَلَمْ يَقُولاَ ‏"‏ يُرِيدُ أَنْ يُوصِيَ فِيهِ ‏"‏ ‏.‏\hadithno{4205}\hadithtrans{This hadith has been narrated on the authority of 'Ubaidullah with the same chain of transmitters. but with a slight variation of words}}
\hadithdefcmd{muslim}{4206}{وَحَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا حَمَّادٌ يَعْنِي ابْنَ زَيْدٍ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ، حَرْبٍ حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - كِلاَهُمَا عَنْ أَيُّوبَ، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ اللَّيْثِيُّ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا هِشَامٌ، - يَعْنِي ابْنَ سَعْدٍ - كُلُّهُمْ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ عُبَيْدِ اللَّهِ وَقَالُوا جَمِيعًا ‏"‏ لَهُ شَىْءٌ يُوصِي فِيهِ ‏"‏ ‏.‏ إِلاَّ فِي حَدِيثِ أَيُّوبَ فَإِنَّهُ قَالَ ‏"‏ يُرِيدُ أَنْ يُوصِيَ فِيهِ ‏"‏ ‏.‏ كَرِوَايَةِ يَحْيَى عَنْ عُبَيْدِ اللَّهِ ‏.‏\hadithno{4206}\hadithtrans{A hadith like this have been narrated on the authority of Nafi', who based his narrations of the words of Ibn 'Umar but with a slight variation of words}}
\hadithdefcmd{muslim}{4207}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، - وَهْوَ ابْنُ الْحَارِثِ - عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا حَقُّ امْرِئٍ مُسْلِمٍ لَهُ شَىْءٌ يُوصِي فِيهِ يَبِيتُ ثَلاَثَ لَيَالٍ إِلاَّ وَوَصِيَّتُهُ عِنْدَهُ مَكْتُوبَةٌ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ مَا مَرَّتْ عَلَىَّ لَيْلَةٌ مُنْذُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ذَلِكَ إِلاَّ وَعِنْدِي وَصِيَّتِي ‏.‏\hadithno{4207}\hadithtrans{Salim reported on the authority of his father ('Abdullah b. Umar) that he (his father) had heard Allah's Messenger (ﷺ) as saying:It is not proper for a Muslim who has got something to bequeathe to spend even three nights without having his will written down with him regarding it. 'Abdullah b. 'Umar (Allah be pleased with them) said: Ever since I heard Allah's Messenger (ﷺ) say this I have not spent a night without having my will (written) along with me}}
\hadithdefcmd{muslim}{4208}{وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلٌ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَعَبْدُ بْنُ حُمَيْدٍ قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ عَمْرِو بْنِ الْحَارِثِ ‏.‏\hadithno{4208}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{4209}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ عَادَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ مِنْ وَجَعٍ أَشْفَيْتُ مِنْهُ عَلَى الْمَوْتِ فَقُلْتُ يَا رَسُولَ اللَّهِ بَلَغَنِي مَا تَرَى مِنَ الْوَجَعِ وَأَنَا ذُو مَالٍ وَلاَ يَرِثُنِي إِلاَّ ابْنَةٌ لِي وَاحِدَةٌ أَفَأَتَصَدَّقُ بِثُلُثَىْ مَالِي قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قَالَ قُلْتُ أَفَأَتَصَدَّقُ بِشَطْرِهِ قَالَ ‏"‏ لاَ الثُّلُثُ وَالثُّلُثُ كَثِيرٌ إِنَّكَ أَنْ تَذَرَ وَرَثَتَكَ أَغْنِيَاءَ خَيْرٌ مِنْ أَنْ تَذَرَهُمْ عَالَةً يَتَكَفَّفُونَ النَّاسَ وَلَسْتَ تُنْفِقُ نَفَقَةً تَبْتَغِي بِهَا وَجْهَ اللَّهِ إِلاَّ أُجِرْتَ بِهَا حَتَّى اللُّقْمَةُ تَجْعَلُهَا فِي فِي امْرَأَتِكَ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أُخَلَّفُ بَعْدَ أَصْحَابِي قَالَ ‏"‏ إِنَّكَ لَنْ تُخَلَّفَ فَتَعْمَلَ عَمَلاً تَبْتَغِي بِهِ وَجْهَ اللَّهِ إِلاَّ ازْدَدْتَ بِهِ دَرَجَةً وَرِفْعَةً وَلَعَلَّكَ تُخَلَّفُ حَتَّى يُنْفَعَ بِكَ أَقْوَامٌ وَيُضَرَّ بِكَ آخَرُونَ اللَّهُمَّ أَمْضِ لأَصْحَابِي هِجْرَتَهُمْ وَلاَ تَرُدَّهُمْ عَلَى أَعْقَابِهِمْ لَكِنِ الْبَائِسُ سَعْدُ ابْنُ خَوْلَةَ ‏"‏ ‏.‏ قَالَ رَثَى لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ أَنْ تُوُفِّيَ بِمَكَّةَ ‏.‏\hadithno{4209}\hadithtrans{Amir b. Sa'd reported on the authority of his father (Sa'd b. Abi Waqqas):Allah's Messenger (ﷺ) visited me in my illness which brought me near death in the year of Hajjat-ul-Wada' (Farewell Pilgrimage). I said: Allah's Messenger, you can well see the pain with which I am afflicted and I am a man possessing wealth, and there is none to inherit me except only one daughter. Should I give two-thirds of my property as Sadaqa? He said: No. I said: Should I give half (of my property) as Sadaqa? He said: No. He (further) said: Give one-third (in charity) and that is quite enough. To leave your heirs rich is better than to leave them poor, begging from people; that you would never incur an expense seeking therewith the pleasure of Allah, but you would be rewarded therefor, even for a morsel of food that you put in the mouth of your wife. I said: Allah's Messenger. would I survive my companions? He (the Holy Prophet) said: If you survive them, then do such a deed by means of which you seek the pleasure of Allah, but you would increase in your status (in religion) and prestige; you may survive so that people would benefit from you, and others would be harmed by you. (The Holy Prophet) further said: Allah, complete for my Companions their migration, and not cause them to turn back upon their heels. Sa'd b. Khaula is, however, unfortunate. Allah's Messenger (ﷺ) felt grief for him as he had died in Mecca}}
\hadithdefcmd{muslim}{4210}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ وَعَبْدُ بْنُ حُمَيْدٍ قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{4210}\hadithtrans{This hadith is narrated on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{4211}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ، عَنْ سَعْدِ بْنِ، إِبْرَاهِيمَ عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ سَعْدٍ، قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم عَلَىَّ يَعُودُنِي ‏.‏ فَذَكَرَ بِمَعْنَى حَدِيثِ الزُّهْرِيِّ وَلَمْ يَذْكُرْ قَوْلَ النَّبِيِّ صلى الله عليه وسلم فِي سَعْدِ ابْنِ خَوْلَةَ غَيْرَ أَنَّهُ قَالَ وَكَانَ يَكْرَهُ أَنْ يَمُوتَ بِالأَرْضِ الَّتِي هَاجَرَ مِنْهَا ‏.‏\hadithno{4211}\hadithtrans{Amir b. Sa'd reported from S'ad (b. Abu Waqqas):Allah's Apostle (ﷺ) visited me to inquire after my health, the rest of the hadith is the same as transmitted on the authority of Zuhri, but lie did not make mention of the words of Allah's Apostle (ﷺ) in regard to Sa'd b. Khaula except this that he said:" He (the Holy Prophet) did not like death in the land from which lie had migrated}}
\hadithdefcmd{muslim}{4212}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سِمَاكُ، بْنُ حَرْبٍ حَدَّثَنِي مُصْعَبُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، قَالَ مَرِضْتُ فَأَرْسَلْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقُلْتُ دَعْنِي أَقْسِمْ مَالِي حَيْثُ شِئْتُ فَأَبَى ‏.‏ قُلْتُ فَالنِّصْفُ فَأَبَى ‏.‏ قُلْتُ فَالثُّلُثُ قَالَ فَسَكَتَ بَعْدَ الثُّلُثِ ‏.‏ قَالَ فَكَانَ بَعْدُ الثُّلُثُ جَائِزًا ‏.‏\hadithno{4212}\hadithtrans{Mus'ab b. Sa'd reported on the authority of his father. I was ailing. I sent message to Allah's Apostle (ﷺ) saying:Permit me to give away my property as I like. He refused. I (again) said: (Permit me) to give away half. He (again refused). I (again said): Then one-third. He (the Holy Prophet) observed silence after (I had asked permission to give away) one-third. He (the narrater) said: It was then that endowment of one-third became permissible}}
\hadithdefcmd{muslim}{4213}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ وَلَمْ يَذْكُرْ فَكَانَ بَعْدُ الثُّلُثُ جَائِزًا ‏.‏\hadithno{4213}\hadithtrans{This hadith has been narrated on the authority of Simak with the same chain of transmitters. But he did not mention:" It was then that one-third became permissible}}
\hadithdefcmd{muslim}{4214}{وَحَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ عَبْدِ الْمَلِكِ، بْنِ عُمَيْرٍ عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ عَادَنِي النَّبِيُّ صلى الله عليه وسلم فَقُلْتُ أُوصِي بِمَالِي كُلِّهِ ‏.‏ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قُلْتُ فَالنِّصْفُ ‏.‏ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ فَقُلْتُ أَبِالثُّلُثِ فَقَالَ ‏"‏ نَعَمْ وَالثُّلُثُ كَثِيرٌ ‏"‏ ‏.‏\hadithno{4214}\hadithtrans{Ibn Sa'd reported his father as saying:Allah's Apostle (ﷺ) visited me during my illness. I said: I am willing away the whole of my property. He said: No. I said: Then half? He said: No. I said: Should I will away one-third? He said: Yes, and even one-third is enough}}
\hadithdefcmd{muslim}{4215}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا الثَّقَفِيُّ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنْ عَمْرِو، بْنِ سَعِيدٍ عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ الْحِمْيَرِيِّ، عَنْ ثَلاَثَةٍ، مِنْ وَلَدِ سَعْدٍ كُلُّهُمْ يُحَدِّثُهُ عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَى سَعْدٍ يَعُودُهُ بِمَكَّةَ فَبَكَى قَالَ ‏"‏ مَا يُبْكِيكَ ‏"‏ ‏.‏ فَقَالَ قَدْ خَشِيتُ أَنْ أَمُوتَ بِالأَرْضِ الَّتِي هَاجَرْتُ مِنْهَا كَمَا مَاتَ سَعْدُ ابْنُ خَوْلَةَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ اشْفِ سَعْدًا اللَّهُمَّ اشْفِ سَعْدًا ‏"‏ ‏.‏ ثَلاَثَ مِرَارٍ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ إِنَّ لِي مَالاً كَثِيرًا وَإِنَّمَا يَرِثُنِي ابْنَتِي أَفَأُوصِي بِمَالِي كُلِّهِ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قَالَ فَبِالثُّلُثَيْنِ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قَالَ فَالنِّصْفُ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قَالَ فَالثُّلُثُ قَالَ ‏"‏ الثُّلُثُ وَالثُّلُثُ كَثِيرٌ إِنَّ صَدَقَتَكَ مِنْ مَالِكَ صَدَقَةٌ وَإِنَّ نَفَقَتَكَ عَلَى عِيَالِكَ صَدَقَةٌ وَإِنَّ مَا تَأْكُلُ امْرَأَتُكَ مِنْ مَالِكَ صَدَقَةٌ وَإِنَّكَ أَنْ تَدَعَ أَهْلَكَ بِخَيْرٍ - أَوْ قَالَ بِعَيْشٍ - خَيْرٌ مِنْ أَنْ تَدَعَهُمْ يَتَكَفَّفُونَ النَّاسَ ‏"‏ ‏.‏ وَقَالَ بِيَدِهِ ‏.‏\hadithno{4215}\hadithtrans{Humaid b. 'Abd al-Rahman al-Himyari reported from three of the sons of Sa'd all of whom reported from their father that Allah's Apostle (ﷺ) visited Sa'd as he was ill in Mecca. He (Sa'd) wept. He (the Holy Prophet) said:What makes you weep? He said: I am afraid I may die in the land from where I migrated as Sa'd b. Khaula had died. Thereupon Allah's Apostle (ﷺ) said: O Allah, grant health to Sa'd. O Allah, grant health to Sad. He repeated it three times. He (Sa'd) said: Allah's Messenger, I own a large property and I have only one daughter as my inheritor. Should I not will away the whole of my property? He (the Holy Prophet) said: No. He said: (Should I not will away, ) two-thirds of the property? he (the Holy Prophet) said: No. He (Sa'd) (again) said: (Should I not will away) half (of my property)? He said: No. He (Sa'd) said: Then one-third? Thereupon he (the Holy Prophet) said: (Yes), one-third, and one-third is quite substanial. And what you spend as charity from your property is Sadaqa and flour spending on your family is also Sadaqa, and what your wife eats from your property is also Sadaqa, and that you leave your heirs well off (or he said: prospreous) is better than to leave them (poor and) begging from people. He (the Holy Prophet) pointed this with his hands}}
\hadithdefcmd{muslim}{4216}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الْعَتَكِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ عَمْرِو بْنِ سَعِيدٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ الْحِمْيَرِيِّ، عَنْ ثَلاَثَةٍ، مِنْ وَلَدِ سَعْدٍ قَالُوا مَرِضَ سَعْدٌ بِمَكَّةَ فَأَتَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُهُ ‏.‏ بِنَحْوِ حَدِيثِ الثَّقَفِيِّ ‏.‏\hadithno{4216}\hadithtrans{Humaid b. Abd al-Rahmin al-Himayri reported on the authority of the three of the sons of Sa'd:They said: Sa'd fell ill in Mecca. Allah's Messenger (ﷺ) visited him to inquire after his health. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{4217}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ حُمَيْدِ، بْنِ عَبْدِ الرَّحْمَنِ حَدَّثَنِي ثَلاَثَةٌ، مِنْ وَلَدِ سَعْدِ بْنِ مَالِكٍ كُلُّهُمْ يُحَدِّثُنِيهِ بِمِثْلِ حَدِيثِ صَاحِبِهِ فَقَالَ مَرِضَ سَعْدٌ بِمَكَّةَ فَأَتَاهُ النَّبِيُّ صلى الله عليه وسلم يَعُودُهُ ‏.‏ بِمِثْلِ حَدِيثِ عَمْرِو بْنِ سَعِيدٍ عَنْ حُمَيْدٍ الْحِمْيَرِيِّ ‏.‏\hadithno{4217}\hadithtrans{Humaid b. Abd al-Rahman reported this hadith on the authority of three of Sa'd's sons:Sa'd fell ill in Mecca and Allah's Apostle (ﷺ) visited him. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{4218}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى يَعْنِي ابْنَ يُونُسَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ نُمَيْرٍ، كُلُّهُمْ عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَوْ أَنَّ النَّاسَ، غَضُّوا مِنَ الثُّلُثِ إِلَى الرُّبُعِ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الثُّلُثُ وَالثُّلُثُ كَثِيرٌ ‏"‏ ‏.‏ وَفِي حَدِيثِ وَكِيعٍ ‏"‏ كَبِيرٌ أَوْ كَثِيرٌ ‏"‏ ‏.‏\hadithno{4218}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) said:(I wish) if people would reduce from third to fourth (part for making a will of their property), for Allah's Messenger (ﷺ) said: So far as the third (part) is concerned it is quite substantial. In the hadith transmitted on the authority of Waki (the words are)" large" or" much}}
\hadithdefcmd{muslim}{4219}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، قَالَ لِلنَّبِيِّ صلى الله عليه وسلم إِنَّ أَبِي مَاتَ وَتَرَكَ مَالاً وَلَمْ يُوصِ فَهَلْ يُكَفِّرُ عَنْهُ أَنْ أَتَصَدَّقَ عَنْهُ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏\hadithno{4219}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that a person said to Allah's Apostle (ﷺ):My father died and left behind property without making any will regarding it. Would he be relieved of the burden of his sins if I give sadaqa on his behalf? He (the Holy Prophet) said: Yes}}
\hadithdefcmd{muslim}{4220}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ، أَنَّ رَجُلاً، قَالَ لِلنَّبِيِّ صلى الله عليه وسلم إِنَّ أُمِّيَ افْتُلِتَتْ نَفْسُهَا وَإِنِّي أَظُنُّهَا لَوْ تَكَلَّمَتْ تَصَدَّقَتْ فَلِيَ أَجْرٌ أَنْ أَتَصَدَّقَ عَنْهَا قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏\hadithno{4220}\hadithtrans{A'isha (Allah be pleased with her) reported that a man said to Allah's Apostle (ﷺ):My mother died all of a sudden, and I think if she (could have the opportunity) to speak she would have (made a will) regarding Sadaqa'. Will I be entitled to reward if I give charity on her behalf? He (the Holy Prophet) said: Yes}}
\hadithdefcmd{muslim}{4221}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمِّيَ افْتُلِتَتْ نَفْسُهَا وَلَمْ تُوصِ وَأَظُنُّهَا لَوْ تَكَلَّمَتْ تَصَدَّقَتْ أَفَلَهَا أَجْرٌ إِنْ تَصَدَّقْتُ عَنْهَا قَالَ ‏ "‏ نَعَمْ ‏"‏\hadithno{4221}\hadithtrans{A'isha (Allah be pleased with her) reported that a man came to Allah's Apostle (ﷺ) and said:Allah's Messenger, my mother died all of a sudden without making any will. I think if (she could have the opportunity) to speak she would have made a Sadaqa. Would there be any reward for her if I give charity on her behalf? He (the Holy Prophet) said: Yes}}
\hadithdefcmd{muslim}{4222}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنِي الْحَكَمُ بْنُ مُوسَى، حَدَّثَنَا شُعَيْبُ، بْنُ إِسْحَاقَ ح وَحَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامَ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا رَوْحٌ، - وَهُوَ ابْنُ الْقَاسِمِ - ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، كُلُّهُمْ عَنْ هِشَامِ بْنِ عُرْوَةَ، بِهَذَا الإِسْنَادِ أَمَّا أَبُو أُسَامَةَ وَرَوْحٌ فَفِي حَدِيثِهِمَا فَهَلْ لِي أَجْرٌ كَمَا قَالَ يَحْيَى بْنُ سَعِيدٍ ‏.‏ وَأَمَّا شُعَيْبٌ وَجَعْفَرٌ فَفِي حَدِيثِهِمَا أَفَلَهَا أَجْرٌ كَرِوَايَةِ ابْنِ بِشْرٍ ‏.‏\hadithno{4222}\hadithtrans{This hadith has been narrated on the authority of Hisham b. 'Urwa with the same chain of transmitters}}
\hadithdefcmd{muslim}{4223}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، - يَعْنِي ابْنَ سَعِيدٍ - وَابْنُ حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - هُوَ ابْنُ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا مَاتَ الإِنْسَانُ انْقَطَعَ عَنْهُ عَمَلُهُ إِلاَّ مِنْ ثَلاَثَةٍ إِلاَّ مِنْ صَدَقَةٍ جَارِيَةٍ أَوْ عِلْمٍ يُنْتَفَعُ بِهِ أَوْ وَلَدٍ صَالِحٍ يَدْعُو لَهُ ‏"‏ ‏.‏\hadithno{4223}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:When a man dies, his acts come to an end, but three, recurring charity, or knowledge (by which people) benefit, or a pious son, who prays for him (for the deceased)}}
\hadithdefcmd{muslim}{4224}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا سُلَيْمُ بْنُ أَخْضَرَ، عَنِ ابْنِ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ أَصَابَ عُمَرُ أَرْضًا بِخَيْبَرَ فَأَتَى النَّبِيَّ صلى الله عليه وسلم يَسْتَأْمِرُهُ فِيهَا فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَصَبْتُ أَرْضًا بِخَيْبَرَ لَمْ أُصِبْ مَالاً قَطُّ هُوَ أَنْفَسُ عِنْدِي مِنْهُ فَمَا تَأْمُرُنِي بِهِ قَالَ ‏ "‏ إِنْ شِئْتَ حَبَسْتَ أَصْلَهَا وَتَصَدَّقْتَ بِهَا ‏"‏ ‏.‏ قَالَ فَتَصَدَّقَ بِهَا عُمَرُ أَنَّهُ لاَ يُبَاعُ أَصْلُهَا وَلاَ يُبْتَاعُ وَلاَ يُورَثُ وَلاَ يُوهَبُ ‏.‏ قَالَ فَتَصَدَّقَ عُمَرُ فِي الْفُقَرَاءِ وَفِي الْقُرْبَى وَفِي الرِّقَابِ وَفِي سَبِيلِ اللَّهِ وَابْنِ السَّبِيلِ وَالضَّيْفِ لاَ جُنَاحَ عَلَى مَنْ وَلِيَهَا أَنْ يَأْكُلَ مِنْهَا بِالْمَعْرُوفِ أَوْ يُطْعِمَ صَدِيقًا غَيْرَ مُتَمَوِّلٍ فِيهِ ‏.‏ قَالَ فَحَدَّثْتُ بِهَذَا الْحَدِيثِ مُحَمَّدًا فَلَمَّا بَلَغْتُ هَذَا الْمَكَانَ غَيْرَ مُتَمَوِّلٍ فِيهِ ‏.‏ قَالَ مُحَمَّدٌ غَيْرَ مُتَأَثِّلٍ مَالاً ‏.‏ قَالَ ابْنُ عَوْنٍ وَأَنْبَأَنِي مَنْ قَرَأَ هَذَا الْكِتَابَ أَنَّ فِيهِ غَيْرَ مُتَأَثِّلٍ مَالاً ‏.‏\hadithno{4224}\hadithtrans{Ibn Umar reported:Umar acquired a land at Khaibar. He came to Allah's Apostle (ﷺ) and sought his advice in regard to it. He said: Allah's Messenger, I have acquired land in Khaibar. I have never acquired property more valuable for me than this, so what do you command me to do with it? Thereupon he (Allah's Apostle) said: If you like, you may keep the corpus intact and give its produce as Sadaqa. So 'Umar gave it as Sadaqa declaring that property must not be sold or inherited or given away as gift. And Umar devoted it to the poor, to the nearest kin, and to the emancipation of slaves, aired in the way of Allah and guests. There is no sin for one, who administers it if he eats something from it in a reasonable manner, or if he feeds his friends and does not hoard up goods (for himself). He (the narrator) said: I narrated this hadith to Muhammad, but as I reached the (words)" without hoarding (for himself) out of it." he (Muhammad' said:" without storing the property with a view to becoming rich." Ibn 'Aun said: He who read this book (pertaining to Waqf) informed me that in it (the words are)" without storing the property with a view to becoming rich}}
\hadithdefcmd{muslim}{4225}{حَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، ح وَحَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا أَزْهَرُ السَّمَّانُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، كُلُّهُمْ عَنِ ابْنِ عَوْنٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّ حَدِيثَ ابْنِ أَبِي زَائِدَةَ وَأَزْهَرَ انْتَهَى عِنْدَ قَوْلِهِ ‏ "‏ أَوْ يُطْعِمَ صَدِيقًا غَيْرَ مُتَمَوِّلٍ فِيهِ ‏"‏ ‏.‏ وَلَمْ يُذْكَرْ مَا بَعْدَهُ ‏.‏ وَحَدِيثُ ابْنِ أَبِي عَدِيٍّ فِيهِ مَا ذَكَرَ سُلَيْمٌ قَوْلُهُ فَحَدَّثْتُ بِهَذَا الْحَدِيثِ مُحَمَّدًا ‏.‏ إِلَى آخِرِهِ ‏.‏\hadithno{4225}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Aun with the same chain of transmitters up to the words:" Or he may feed the friend withoiut hoarding from it" and he made no mention of what follows}}
\hadithdefcmd{muslim}{4226}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عُمَرُ بْنُ سَعْدٍ عَنْ سُفْيَانَ، عَنِ ابْنِ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، قَالَ أَصَبْتُ أَرْضًا مِنْ أَرْضِ خَيْبَرَ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ أَصَبْتُ أَرْضًا لَمْ أُصِبْ مَالاً أَحَبَّ إِلَىَّ وَلاَ أَنْفَسَ عِنْدِي مِنْهَا ‏.‏ وَسَاقَ الْحَدِيثَ بِمِثْلِ حَدِيثِهِمْ وَلَمْ يَذْكُرْ فَحَدَّثْتُ مُحَمَّدًا وَمَا بَعْدَهُ ‏.‏\hadithno{4226}\hadithtrans{Umar reported:I acquired land from the lands of Khaibar. I came to Allah's Messenger (ﷺ) and said: I have acquired a piece of land. Never have I acquired land more loved by me and more cherished by me than this. The rest of the hadith is the same, but he made no mention of this:" I narrated it to Muhammad" and what follows}}
\hadithdefcmd{muslim}{4227}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مَالِكِ بْنِ مِغْوَلٍ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى هَلْ أَوْصَى رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ لاَ ‏.‏ قُلْتُ فَلِمَ كُتِبَ عَلَى الْمُسْلِمِينَ الْوَصِيَّةُ أَوْ فَلِمَ أُمِرُوا بِالْوَصِيَّةِ قَالَ أَوْصَى بِكِتَابِ اللَّهِ عَزَّ وَجَلَّ ‏.‏\hadithno{4227}\hadithtrans{Talha b. Musarrif reported:I asked 'Abdullah b. Abu Aufa whether Allah's Messenger (ﷺ) had made any will (in regard to his property). He said: NO. I said: Then why has making of will been made necessary for the Muslims, or why were they commanded to make will? Thereupon he said: He made the will according to the Book of Allah, the Exalted and Majestic}}
\hadithdefcmd{muslim}{4228}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، كِلاَهُمَا عَنْ مَالِكِ بْنِ مِغْوَلٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّ فِي حَدِيثِ وَكِيعٍ قُلْتُ فَكَيْفَ أُمِرَ النَّاسُ بِالْوَصِيَّةِ وَفِي حَدِيثِ ابْنِ نُمَيْرٍ قُلْتُ كَيْفَ كُتِبَ عَلَى الْمُسْلِمِينَ الْوَصِيَّةُ\hadithno{4228}\hadithtrans{This hadith has been narrated on the authority of Malik b. Mighwal with the same chain of transmitters but with a slight variation of words. In the hadith related by Waki (the words are)" I said:How the people have been ordered about the will" ; and in the hadith of Ibn Numair (the words are):" How the will has been prescribed for the Muslims}}
\hadithdefcmd{muslim}{4229}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي وَأَبُو مُعَاوِيَةَ قَالاَ حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ مَا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم دِينَارًا وَلاَ دِرْهَمًا وَلاَ شَاةً وَلاَ بَعِيرًا وَلاَ أَوْصَى بِشَىْءٍ ‏.‏\hadithno{4229}\hadithtrans{A'isha reported:Allah's Messenger (ﷺ) left neither dinar nor dirham (wealth in the form of cash), nor goats (and sheep), nor camels. And he made no will about anything (in regard to his material possessions, as he had none)}}
\hadithdefcmd{muslim}{4230}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، كُلُّهُمْ عَنْ جَرِيرٍ، ح وَحَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى، - وَهُوَ ابْنُ يُونُسَ - جَمِيعًا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏\hadithno{4230}\hadithtrans{This hadith has been narrated on the authority of A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{4231}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ - وَاللَّفْظُ لِيَحْيَى - قَالَ أَخْبَرَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنِ ابْنِ عَوْنٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، قَالَ ذَكَرُوا عِنْدَ عَائِشَةَ أَنَّ عَلِيًّا كَانَ وَصِيًّا فَقَالَتْ مَتَى أَوْصَى إِلَيْهِ فَقَدْ كُنْتُ مُسْنِدَتَهُ إِلَى صَدْرِي - أَوْ قَالَتْ حَجْرِي - فَدَعَا بِالطَّسْتِ فَلَقَدِ انْخَنَثَ فِي حَجْرِي وَمَا شَعَرْتُ أَنَّهُ مَاتَ فَمَتَى أَوْصَى إِلَيْهِ\hadithno{4231}\hadithtrans{Aswad b. Yazid reported:It was mentioned before A'isha that will had been made (by the Holy Prophet) in favour of 'Ali (as the Prophet's first caliph), whereupon she said: When did he make will in his favour? I had been providing support to him (to the Holy Prophet) with my chest (or with my lap). He asked for a tray, when he fell in my lap (relaxing his body), and I did not realise that he had breathed his last. When did he make any will in his ('Ali's) favour?}}
\hadithdefcmd{muslim}{4232}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ - وَاللَّفْظُ لِسَعِيدٍ - قَالُوا حَدَّثَنَا سُفْيَانُ، عَنْ سُلَيْمَانَ الأَحْوَلِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قَالَ ابْنُ عَبَّاسٍ يَوْمُ الْخَمِيسِ وَمَا يَوْمُ الْخَمِيسِ ثُمَّ بَكَى حَتَّى بَلَّ دَمْعُهُ الْحَصَى ‏.‏ فَقُلْتُ يَا ابْنَ عَبَّاسٍ وَمَا يَوْمُ الْخَمِيسِ قَالَ اشْتَدَّ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَجَعُهُ ‏.‏ فَقَالَ ‏"‏ ائْتُونِي أَكْتُبْ لَكُمْ كِتَابًا لاَ تَضِلُّوا بَعْدِي ‏"‏ ‏.‏ فَتَنَازَعُوا وَمَا يَنْبَغِي عِنْدَ نَبِيٍّ تَنَازُعٌ ‏.‏ وَقَالُوا مَا شَأْنُهُ أَهَجَرَ اسْتَفْهِمُوهُ ‏.‏ قَالَ ‏"‏ دَعُونِي فَالَّذِي أَنَا فِيهِ خَيْرٌ أُوصِيكُمْ بِثَلاَثٍ أَخْرِجُوا الْمُشْرِكِينَ مِنْ جَزِيرَةِ الْعَرَبِ وَأَجِيزُوا الْوَفْدَ بِنَحْوِ مَا كُنْتُ أُجِيزُهُمْ ‏"‏ ‏.‏ قَالَ وَسَكَتَ عَنِ الثَّالِثَةِ أَوْ قَالَهَا فَأُنْسِيتُهَا ‏.‏ قَالَ أَبُو إِسْحَاقَ إِبْرَاهِيمُ حَدَّثَنَا الْحَسَنُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا سُفْيَانُ، بِهَذَا الْحَدِيثِ\hadithno{4232}\hadithtrans{Sa'id b. Jubair reported that Ibn 'Abbas said:Thursday, (and then said): What is this Thursday? He then wept so much that his tears moistened the pebbles. I said: Ibn 'Abbas, what is (significant) about Thursday? He (Ibn 'Abbas) said: The illness of Allah's Messenger (ﷺ) took a serious turn (on this day), and he said: Come to me, so that I should write for you a document that you may not go astray after me. They (the Companions around him) disputed, and it is not meet to dispute in the presence of the Apostle. They said: How is lie (Allah's Apostle)? Has he lost his consciousness? Try to learn from him (this point). He (the Holy Prophet) said: Leave me. I am better in the state (than the one in which you are engaged). I make a will about three things: Turn out the polytheists from the territory of Arabia; show hospitality to the (foreign) delegations as I used to show them hospitality. He (the narrator) said: He (Ibn Abbas) kept silent on the third point, or he (the narrator) said: But I forgot that. This hadith was mentioned through another chain}}
\hadithdefcmd{muslim}{4233}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا وَكِيعٌ، عَنْ مَالِكِ بْنِ مِغْوَلٍ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ يَوْمُ الْخَمِيسِ وَمَا يَوْمُ الْخَمِيسِ ‏.‏ ثُمَّ جَعَلَ تَسِيلُ دُمُوعُهُ حَتَّى رَأَيْتُ عَلَى خَدَّيْهِ كَأَنَّهَا نِظَامُ اللُّؤْلُؤِ ‏.‏ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ائْتُونِي بِالْكَتِفِ وَالدَّوَاةِ - أَوِ اللَّوْحِ وَالدَّوَاةِ - أَكْتُبْ لَكُمْ كِتَابًا لَنْ تَضِلُّوا بَعْدَهُ أَبَدًا ‏"‏ ‏.‏ فَقَالُوا إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَهْجُرُ ‏.‏\hadithno{4233}\hadithtrans{Sa'id b. Jubair reported from Ibn Abbas that he said:Thursday, and what about Thursday? Then tears began to flow until I saw them on his cheeks as it they were the strings of pearls. He (the narrator) said that Allah's Messenger (ﷺ) said: Bring me a shoulder blade and ink-pot (or tablet and inkpot), so that I write for you a document (by following which) you would never go astray. They said: Allah's Messenger (may peace upon him) is in the state of unconsciousness}}
\hadithdefcmd{muslim}{4234}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، - قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، - أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا حُضِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَفِي الْبَيْتِ رِجَالٌ فِيهِمْ عُمَرُ بْنُ الْخَطَّابِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلُمَّ أَكْتُبْ لَكُمْ كِتَابًا لاَ تَضِلُّونَ بَعْدَهُ ‏"‏ ‏.‏ فَقَالَ عُمَرُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ غَلَبَ عَلَيْهِ الْوَجَعُ وَعِنْدَكُمُ الْقُرْآنُ حَسْبُنَا كِتَابُ اللَّهِ ‏.‏ فَاخْتَلَفَ أَهْلُ الْبَيْتِ فَاخْتَصَمُوا فَمِنْهُمْ مَنْ يَقُولُ قَرِّبُوا يَكْتُبْ لَكُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم كِتَابًا لَنْ تَضِلُّوا بَعْدَهُ ‏.‏ وَمِنْهُمْ مَنْ يَقُولُ مَا قَالَ عُمَرُ ‏.‏ فَلَمَّا أَكْثَرُوا اللَّغْوَ وَالاِخْتِلاَفَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قُومُوا ‏"‏ ‏.‏ قَالَ عُبَيْدُ اللَّهِ فَكَانَ ابْنُ عَبَّاسٍ يَقُولُ إِنَّ الرَّزِيَّةَ كُلَّ الرَّزِيَّةِ مَا حَالَ بَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَبَيْنَ أَنْ يَكْتُبَ لَهُمْ ذَلِكَ الْكِتَابَ مِنِ اخْتِلاَفِهِمْ وَلَغَطِهِمْ ‏.‏\hadithno{4234}\hadithtrans{Ibn Abbas reported:When Allah's Messenger (ﷺ) was about to leave this world, there were persons (around him) in his house, 'Umar b. al-Kbattab being one of them. Allah's Apostle (ﷺ) said: Come, I may write for you a document; you would not go astray after that. Thereupon Umar said: Verily Allah's Messenger (ﷺ) is deeply afflicted with pain. You have the Qur'an with you. The Book of Allah is sufficient for us. Those who were present in the house differed. Some of them said: Bring him (the writing material) so that Allah's Messenger (ﷺ) may write a document for you and you would never go astray after him And some among them said what 'Umar had (already) said. When they indulged in nonsense and began to dispute in the presence of Allah's Messenger (ﷺ), he said: Get up (and go away) 'Ubaidullah said: Ibn Abbas used to say: There was a heavy loss, indeed a heavy loss, that, due to their dispute and noise. Allah's Messenger (ﷺ) could not write (or dictate) the document for them}}
