% Auto-generated chapter 51 for muslim
% Hadiths in this chapter: 21

\hadithdefcmd{muslim}{7024}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا أَبُو إِسْحَاقَ، أَنَّهُ سَمِعَ زَيْدَ بْنَ أَرْقَمَ، يَقُولُ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ أَصَابَ النَّاسَ فِيهِ شِدَّةٌ فَقَالَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ لأَصْحَابِهِ لاَ تُنْفِقُوا عَلَى مَنْ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى يَنْفَضُّوا مِنْ حَوْلِهِ ‏.‏ قَالَ زُهَيْرٌ وَهِيَ قِرَاءَةُ مَنْ خَفَضَ حَوْلَهُ ‏.‏ وَقَالَ لَئِنْ رَجَعْنَا إِلَى الْمَدِينَةِ لَيُخْرِجَنَّ الأَعَزُّ مِنْهَا الأَذَلَّ - قَالَ - فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرْتُهُ بِذَلِكَ فَأَرْسَلَ إِلَى عَبْدِ اللَّهِ بْنِ أُبَىٍّ فَسَأَلَهُ فَاجْتَهَدَ يَمِينَهُ مَا فَعَلَ فَقَالَ كَذَبَ زَيْدٌ رَسُولَ اللَّهِ صلى الله عليه وسلم - قَالَ - فَوَقَعَ فِي نَفْسِي مِمَّا قَالُوهُ شِدَّةٌ حَتَّى أَنْزَلَ اللَّهُ تَصْدِيقِي ‏\{‏ إِذَا جَاءَكَ الْمُنَافِقُونَ‏\}‏ قَالَ ثُمَّ دَعَاهُمُ النَّبِيُّ صلى الله عليه وسلم لِيَسْتَغْفِرَ لَهُمْ - قَالَ - فَلَوَّوْا رُءُوسَهُمْ ‏.‏ وَقَوْلُهُ ‏\{‏ كَأَنَّهُمْ خُشُبٌ مُسَنَّدَةٌ‏\}‏ وَقَالَ كَانُوا رِجَالاً أَجْمَلَ شَىْءٍ ‏.‏\hadithno{7024}\hadithtrans{Zaid b. Arqam reported:We set out on a journey along with Allah's Messenger (ﷺ) in which we faced many hardships. 'Abdullah b. Ubayy said to his friends: Do not give what you have in your possession to those who are with Allah's Messenger (ﷺ) until they desert him. Zubair said: That is the reciting of that person who recited as min haulahu (from around him) and the other reciting is man haulahia (who are around him). And in this case when we would return to Medina the honourable would drive out the meaner therefrom (lxiv. 8). I came to Allah's Apostle (ﷺ) and informed him about that and he sent someone to 'Abdullah b. Ubayy and he asked him whether he had said that or not. He took an oath to the fact that he had not done that and told that it was Zaid who had stated a lie to Allah's Messenger (ﷺ). Zaid said: I was much perturbed because of this until this verse was revealed attesting my truth:" When the hypocrites come" (lxiii. 1). Allah's Apostle (ﷺ) then called them in order to seek forgiveness for them, but they turned away their heads as if they were hooks of wood fixed in the wall (lxiii. 4), and they were in fact apparently good-looking persons}}
\hadithdefcmd{muslim}{7025}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَأَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، - وَاللَّفْظُ لاِبْنِ أَبِي شَيْبَةَ - قَالَ ابْنُ عَبْدَةَ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ أَتَى النَّبِيُّ صلى الله عليه وسلم قَبْرَ عَبْدِ اللَّهِ بْنِ أُبَىٍّ فَأَخْرَجَهُ مِنْ قَبْرِهِ فَوَضَعَهُ عَلَى رُكْبَتَيْهِ وَنَفَثَ عَلَيْهِ مِنْ رِيقِهِ وَأَلْبَسَهُ قَمِيصَهُ فَاللَّهُ أَعْلَمُ ‏.‏\hadithno{7025}\hadithtrans{Jabir reported Allah's Apostle (ﷺ) came to the grave of 'Abdullah b. Ubayy, brought him out from that, placed him on his knee and put his saliva in his mouth and shrouded him in his own shirt and Allah knows best}}
\hadithdefcmd{muslim}{7026}{حَدَّثَنِي أَحْمَدُ بْنُ يُوسُفَ الأَزْدِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ جَاءَ النَّبِيُّ صلى الله عليه وسلم إِلَى عَبْدِ اللَّهِ بْنِ أُبَىٍّ بَعْدَ مَا أُدْخِلَ حُفْرَتَهُ ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ سُفْيَانَ ‏.‏\hadithno{7026}\hadithtrans{Jabir b. 'Abdullah reported that Allah's Messenger (ﷺ) came to the grave of 'Abdullah b. Ubayy as he was placed in that. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{7027}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ لَمَّا تُوُفِّيَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ ابْنُ سَلُولَ جَاءَ ابْنُهُ عَبْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ أَنْ يُعْطِيَهُ قَمِيصَهُ يُكَفِّنُ فِيهِ أَبَاهُ فَأَعْطَاهُ ثُمَّ سَأَلَهُ أَنْ يُصَلِّيَ عَلَيْهِ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِيُصَلِّيَ عَلَيْهِ فَقَامَ عُمَرُ فَأَخَذَ بِثَوْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَتُصَلِّي عَلَيْهِ وَقَدْ نَهَاكَ اللَّهُ أَنْ تُصَلِّيَ عَلَيْهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا خَيَّرَنِي اللَّهُ فَقَالَ اسْتَغْفِرْ لَهُمْ أَوْ لاَ تَسْتَغْفِرْ لَهُمْ إِنْ تَسْتَغْفِرْ لَهُمْ سَبْعِينَ مَرَّةً وَسَأَزِيدُهُ عَلَى سَبْعِينَ ‏"‏ ‏.‏ قَالَ إِنَّهُ مُنَافِقٌ ‏.‏ فَصَلَّى عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَلاَ تُصَلِّ عَلَى أَحَدٍ مِنْهُمْ مَاتَ أَبَدًا وَلاَ تَقُمْ عَلَى قَبْرِهِ‏\}‏\hadithno{7027}\hadithtrans{Ibn 'Umar reported that when 'Abdullah b. Ubayy b. Salul died. His son 'Abdullah b. 'Abdullah (b. Ubayy) came to Allah's Messenger (ﷺ) and begged him that he should give him his shirt which he would use as a coffin for his father, he gave him that. He then begged that he should conduct funeral prayer for him. Allah's Messenger (ﷺ) had hardly got up to observe the prayer for him that 'Umar stood up and caught hold of the garment of Allah's Messenger (ﷺ) and said:Allah's Messenger, are you going to conduct prayer for this man, whereas Allah has forbidden you to offer prayer for him? Thereupon Allah's Messenger (ﷺ) said: Allah has given me an option as He has said:" You may beg pardon for them or you may not beg pardon for them, and even if you beg pardon for them, seventy times" (ix. 80), and I am going to make an addition to the seventy. He was a hypocrite and Allah's Messenger (ﷺ) offered prayer for him and Allah, the Exalted and Glorious, revealed this verse:" Do not offer prayer for any one of them at all and do not stand upon their graves for (offering prayer over them)" (ix)}}
\hadithdefcmd{muslim}{7028}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ نَحْوَهُ وَزَادَ قَالَ فَتَرَكَ الصَّلاَةَ عَلَيْهِمْ ‏.‏\hadithno{7028}\hadithtrans{This hadith has been narrated on the authority of 'Abdullah with the same chain of transmitters but with this addition:" He then abandoned offering (funeral) prayer for them}}
\hadithdefcmd{muslim}{7029}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ أَبِي، مَعْمَرٍ عَنِ ابْنِ مَسْعُودٍ، قَالَ اجْتَمَعَ عِنْدَ الْبَيْتِ ثَلاَثَةُ نَفَرٍ قُرَشِيَّانِ وَثَقَفِيٌّ أَوْ ثَقَفِيَّانِ وَقُرَشِيٌّ قَلِيلٌ فِقْهُ قُلُوبِهِمْ كَثِيرٌ شَحْمُ بُطُونِهِمْ فَقَالَ أَحَدُهُمْ أَتَرَوْنَ اللَّهَ يَسْمَعُ مَا نَقُولُ وَقَالَ الآخَرُ يَسْمَعُ إِنْ جَهَرْنَا وَلاَ يَسْمَعُ إِنْ أَخْفَيْنَا وَقَالَ الآخَرُ إِنْ كَانَ يَسْمَعُ إِذَا جَهَرْنَا فَهُوَ يَسْمَعُ إِذَا أَخْفَيْنَا ‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَمَا كُنْتُمْ تَسْتَتِرُونَ أَنْ يَشْهَدَ عَلَيْكُمْ سَمْعُكُمْ وَلاَ أَبْصَارُكُمْ وَلاَ جُلُودُكُمْ‏\}‏ الآيَةَ ‏.‏\hadithno{7029}\hadithtrans{Ibn Mas'ud reported that there gathered near the House three persons amongst whom two were Quraishi and one was a Thaqafi or two were Thaqafis and one was a Quraishi. They lacked understanding but wore more flesh. One of them said:Do you think that Allah hears as we speak? The other one said: He does hear when we speak loudly and He does not hear when we speak in undertones, and still the other one said: If He listens when we speak loudly, He also listens when we speak in undertones. It was on this occasion that this verse was revealed:" You did not conceal yourselves lest your ears, your eyes and your skins would stand witness against you" (xli)}}
\hadithdefcmd{muslim}{7030}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي سُلَيْمَانُ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ وَهْبِ بْنِ رَبِيعَةَ، عَنْ عَبْدِ اللَّهِ، ح وَقَالَ حَدَّثَنَا يَحْيَى، حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي مَنْصُورٌ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ، بِنَحْوِهِ ‏.‏\hadithno{7030}\hadithtrans{This hadith has been narrated on the authority of 'Abdullah through another chain of transmitters}}
\hadithdefcmd{muslim}{7031}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، - وَهُوَ ابْنُ ثَابِتٍ - قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ يَزِيدَ، يُحَدِّثُ عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ إِلَى أُحُدٍ فَرَجَعَ نَاسٌ مِمَّنْ كَانَ مَعَهُ فَكَانَ أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم فِيهِمْ فِرْقَتَيْنِ قَالَ بَعْضُهُمْ نَقْتُلُهُمْ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ ‏.‏ فَنَزَلَتْ ‏\{‏ فَمَا لَكُمْ فِي الْمُنَافِقِينَ فِئَتَيْنِ‏\}‏\hadithno{7031}\hadithtrans{Zaid b. Thabit reported that Allah's Apostle (ﷺ) set out for Uhud. Some of those persons who were with them came back. The Companions of Allah's Apostle (ﷺ) were divided in two groups. One group said:We would kill them, and the other one said: No, this should not be done, and it was on this occasion that this verse was revealed:" Why should you, then, be two parties in relation to hypocrites?" (iv)}}
\hadithdefcmd{muslim}{7032}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، ح وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ، حَدَّثَنَا غُنْدَرٌ، كِلاَهُمَا عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{7032}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{7033}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَمُحَمَّدُ بْنُ سَهْلٍ التَّمِيمِيُّ، قَالاَ حَدَّثَنَا ابْنُ أَبِي، مَرْيَمَ أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ، الْخُدْرِيِّ أَنَّ رِجَالاً، مِنَ الْمُنَافِقِينَ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانُوا إِذَا خَرَجَ النَّبِيُّ صلى الله عليه وسلم إِلَى الْغَزْوِ تَخَلَّفُوا عَنْهُ وَفَرِحُوا بِمَقْعَدِهِمْ خِلاَفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِذَا قَدِمَ النَّبِيُّ صلى الله عليه وسلم اعْتَذَرُوا إِلَيْهِ وَحَلَفُوا وَأَحَبُّوا أَنْ يُحْمَدُوا بِمَا لَمْ يَفْعَلُوا فَنَزَلَتْ ‏\{‏ لاَ تَحْسَبَنَّ الَّذِينَ يَفْرَحُونَ بِمَا أَتَوْا وَيُحِبُّونَ أَنْ يُحْمَدُوا بِمَا لَمْ يَفْعَلُوا فَلاَ تَحْسَبَنَّهُمْ بِمَفَازَةٍ مِنَ الْعَذَابِ‏\}‏\hadithno{7033}\hadithtrans{Abu Sa'id Khudri reported that during the lifetime of Allah's Messenger (ﷺ) the hypocrites behaved in this way that when Allah's Apostle (ﷺ) set out for a battle, they kept themselves behind, and they became happy that they had managed to sit in the house contrary to (the act of) Allah's Messenger (ﷺ), and when Allah's Apostle (may peace he upon him) came back, they put forward excuses and took oath and wished that people should laud them for the deeds which they had not done. It was on this occasion that this verse was revealed:" Think not that those who exult in what they have done, and love to be praised for what they have not done-think not them to be safe from the chastisement; and for them is a painful chastisement" (iii)}}
\hadithdefcmd{muslim}{7034}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا حَجَّاجُ، بْنُ مُحَمَّدٍ عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي ابْنُ أَبِي مُلَيْكَةَ، أَنَّ حُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَخْبَرَهُ أَنَّ مَرْوَانَ قَالَ اذْهَبْ يَا رَافِعُ - لِبَوَّابِهِ - إِلَى ابْنِ عَبَّاسٍ فَقُلْ لَئِنْ كَانَ كُلُّ امْرِئٍ مِنَّا فَرِحَ بِمَا أَتَى وَأَحَبَّ أَنْ يُحْمَدَ بِمَا لَمْ يَفْعَلْ مُعَذَّبًا لَنُعَذَّبَنَّ أَجْمَعُونَ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ مَا لَكُمْ وَلِهَذِهِ الآيَةِ إِنَّمَا أُنْزِلَتْ هَذِهِ الآيَةُ فِي أَهْلِ الْكِتَابِ ‏.‏ ثُمَّ تَلاَ ابْنُ عَبَّاسٍ ‏\{‏ وَإِذْ أَخَذَ اللَّهُ مِيثَاقَ الَّذِينَ أُوتُوا الْكِتَابَ لَتُبَيِّنُنَّهُ لِلنَّاسِ وَلاَ تَكْتُمُونَهُ‏\}‏ هَذِهِ الآيَةَ وَتَلاَ ابْنُ عَبَّاسٍ ‏\{‏ لاَ تَحْسَبَنَّ الَّذِينَ يَفْرَحُونَ بِمَا أَتَوْا وَيُحِبُّونَ أَنْ يُحْمَدُوا بِمَا لَمْ يَفْعَلُوا‏\}‏ وَقَالَ ابْنُ عَبَّاسٍ سَأَلَهُمُ النَّبِيُّ صلى الله عليه وسلم عَنْ شَىْءٍ فَكَتَمُوهُ إِيَّاهُ وَأَخْبَرُوهُ بِغَيْرِهِ فَخَرَجُوا قَدْ أَرَوْهُ أَنْ قَدْ أَخْبَرُوهُ بِمَا سَأَلَهُمْ عَنْهُ وَاسْتَحْمَدُوا بِذَلِكَ إِلَيْهِ وَفَرِحُوا بِمَا أَتَوْا مِنْ كِتْمَانِهِمْ إِيَّاهُ مَا سَأَلَهُمْ عَنْهُ ‏.‏\hadithno{7034}\hadithtrans{Humaid b. 'Abd al-Rahman b. 'Auf reported that Marwan said to Rafi', his chamberlain, that he should go to Ibn 'Abbas and ask him:If every one of us be punished for his being happy upon his deed and for his being praised for what he has not done, nobody would be saved from the torment. Ibn 'Abbas said: What you have to do with this verse? It has been in fact revealed in connection with the people of the Book." Then Ibn Abbas recited this verse:" When Allah took a covenant from those who had been given the Book: You shall explain it to people and shall not conceal this" (iii. 186), and then Ibn 'Abbas recited this verse:" Think not that those who exult in what they have done and love to be praised for what they have not done" (iii. 186). Ibn 'Abbas (further) said: Allah's Apostle (ﷺ) asked them about something and then they concealed that and they told him something else and they went out and they thought that they had informed him as lie had asked them and they felt happy of what they had concealed}}
\hadithdefcmd{muslim}{7035}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا شُعْبَةُ بْنُ الْحَجَّاجِ، عَنْ قَتَادَةَ، عَنْ أَبِي نَضْرَةَ، عَنْ قَيْسٍ، قَالَ قُلْتُ لِعَمَّارٍ أَرَأَيْتُمْ صَنِيعَكُمْ هَذَا الَّذِي صَنَعْتُمْ فِي أَمْرِ عَلِيٍّ أَرَأْيًا رَأَيْتُمُوهُ أَوْ شَيْئًا عَهِدَهُ إِلَيْكُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ مَا عَهِدَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم شَيْئًا لَمْ يَعْهَدْهُ إِلَى النَّاسِ كَافَّةً وَلَكِنْ حُذَيْفَةُ أَخْبَرَنِي عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ فِي أَصْحَابِي اثْنَا عَشَرَ مُنَافِقًا فِيهِمْ ثَمَانِيَةٌ لاَ يَدْخُلُونَ الْجَنَّةَ حَتَّى يَلِجَ الْجَمَلُ فِي سَمِّ الْخِيَاطِ ثَمَانِيَةٌ مِنْهُمْ تَكْفِيكَهُمُ الدُّبَيْلَةُ وَأَرْبَعَةٌ ‏"‏ ‏.‏ لَمْ أَحْفَظْ مَا قَالَ شُعْبَةُ فِيهِمْ ‏.‏\hadithno{7035}\hadithtrans{Qais reported:I said to 'Ammar: What is your opinion about that which you have done in case (of your siding with Hadrat 'Ali)? Is it your personal opinion or something you got from Allah's Messenger (ﷺ)? 'Ammar said: We have got nothing from Allah's Messenger (ﷺ) which people at large did not get, but Hudhaifa told me that Allah's Apostle (ﷺ) had especially told him amongst his Companion, that there would be twelve hypocrites out of whom eight would not get into Paradise, until a camel would be able to pass through the needle hole. The ulcer would be itself sufficient (to kill) eight. So far as four are concerned, I do not remember what Shu'ba said about them}}
\hadithdefcmd{muslim}{7036}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي نَضْرَةَ، عَنْ قَيْسِ بْنِ عُبَادٍ، قَالَ قُلْنَا لِعَمَّارٍ أَرَأَيْتَ قِتَالَكُمْ أَرَأْيًا رَأَيْتُمُوهُ فَإِنَّ الرَّأْىَ يُخْطِئُ وَيُصِيبُ أَوْ عَهْدًا عَهِدَهُ إِلَيْكُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ مَا عَهِدَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم شَيْئًا لَمْ يَعْهَدْهُ إِلَى النَّاسِ كَافَّةً ‏.‏ وَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ فِي أُمَّتِي ‏"‏ ‏.‏ قَالَ شُعْبَةُ وَأَحْسِبُهُ قَالَ حَدَّثَنِي حُذَيْفَةُ ‏.‏ وَقَالَ غُنْدَرٌ أُرَاهُ قَالَ ‏"‏ فِي أُمَّتِي اثْنَا عَشَرَ مُنَافِقًا لاَ يَدْخُلُونَ الْجَنَّةَ وَلاَ يَجِدُونَ رِيحَهَا حَتَّى يَلِجَ الْجَمَلُ فِي سَمِّ الْخِيَاطِ ثَمَانِيَةٌ مِنْهُمْ تَكْفِيكَهُمُ الدُّبَيْلَةُ سِرَاجٌ مِنَ النَّارِ يَظْهَرُ فِي أَكْتَافِهِمْ حَتَّى يَنْجُمَ مِنْ صُدُورِهِمْ ‏"‏ ‏.‏\hadithno{7036}\hadithtrans{Qais b. 'Ubad reported:We said to 'Ammar: Was your fighting (on the side of 'Ali in the Battle of Siffin) a matter of your own choice or you got its hints from Allah's Messenger (ﷺ) for it, is likely for one to err in one's own discretion or was it because of any covenant that Allah's Messenger (ﷺ) got from you? He said: It was not because of any covenant that Allah's Messenger (ﷺ) got from us which he did get from other people, and he further said that Allah's Messenger (ﷺ) said:" In my Ummah." And I think that Hudhaifa reported to me and according to Ghundar (the words are) that he said: In my Ummah, there would be twelve hypocrites and they would not be admitted to Paradise and they would not smell its odour, until the camel would pass through a needle's hole. Dubaila (ulcer) would be enough to (torment them) -a kind of flame of Fire which would appear in their shoulders and it would protrude from their chest}}
\hadithdefcmd{muslim}{7037}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا أَبُو أَحْمَدَ الْكُوفِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ جُمَيْعٍ، حَدَّثَنَا أَبُو الطُّفَيْلِ، قَالَ كَانَ بَيْنَ رَجُلٍ مِنْ أَهْلِ الْعَقَبَةِ وَبَيْنَ حُذَيْفَةَ بَعْضُ مَا يَكُونُ بَيْنَ النَّاسِ فَقَالَ أَنْشُدُكَ بِاللَّهِ كَمْ كَانَ أَصْحَابُ الْعَقَبَةِ قَالَ فَقَالَ لَهُ الْقَوْمُ أَخْبِرْهُ إِذْ سَأَلَكَ قَالَ كُنَّا نُخْبَرُ أَنَّهُمْ أَرْبَعَةَ عَشَرَ فَإِنْ كُنْتَ مِنْهُمْ فَقَدْ كَانَ الْقَوْمُ خَمْسَةَ عَشَرَ وَأَشْهَدُ بِاللَّهِ أَنَّ اثْنَىْ عَشَرَ مِنْهُمْ حَرْبٌ لِلَّهِ وَلِرَسُولِهِ فِي الْحَيَاةِ الدُّنْيَا وَيَوْمَ يَقُومُ الأَشْهَادُ وَعَذَرَ ثَلاَثَةً قَالُوا مَا سَمِعْنَا مُنَادِيَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ عَلِمْنَا بِمَا أَرَادَ الْقَوْمُ ‏.‏ وَقَدْ كَانَ فِي حَرَّةٍ فَمَشَى فَقَالَ ‏ "‏ إِنَّ الْمَاءَ قَلِيلٌ فَلاَ يَسْبِقُنِي إِلَيْهِ أَحَدٌ ‏"‏ ‏.‏ فَوَجَدَ قَوْمًا قَدْ سَبَقُوهُ فَلَعَنَهُمْ يَوْمَئِذٍ ‏.‏\hadithno{7037}\hadithtrans{Abu Tufail reported that there was a dispute between Hudhaifa and one from the people of Aqaba as it happens amongst people. He said:I adjure you by Allah to tell me as to how many people from Aqaba were. The people said to him (Hudhaifa) to inform him as he had asked. We have been informed that they were fourteen and If you are to be counted amongst them, then they would be fifteen and I state by Allah that twelve amongst them were the enemies of Allah and of His Messenger (ﷺ) in this world. The rest of the three put forward this excuse: We did not hear the announcement of Allah's Messenger (ﷺ) and we were not aware of the intention of the people as he (the Holy Prophet) had been in the hot atmosphere. He (the Holy Prophet) then said: The water is small in quantity (at the next station). So nobody should go ahead of me, but he found people who had gone ahead of him and he cursed them on that day}}
\hadithdefcmd{muslim}{7038}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ يَصْعَدُ الثَّنِيَّةَ ثَنِيَّةَ الْمُرَارِ فَإِنَّهُ يُحَطُّ عَنْهُ مَا حُطَّ عَنْ بَنِي إِسْرَائِيلَ ‏"‏ ‏.‏ قَالَ فَكَانَ أَوَّلَ مَنْ صَعِدَهَا خَيْلُنَا خَيْلُ بَنِي الْخَزْرَجِ ثُمَّ تَتَامَّ النَّاسُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَكُلُّكُمْ مَغْفُورٌ لَهُ إِلاَّ صَاحِبَ الْجَمَلِ الأَحْمَرِ ‏"‏ ‏.‏ فَأَتَيْنَاهُ فَقُلْنَا لَهُ تَعَالَ يَسْتَغْفِرْ لَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ وَاللَّهِ لأَنْ أَجِدَ ضَالَّتِي أَحَبُّ إِلَىَّ مِنْ أَنْ يَسْتَغْفِرَ لِي صَاحِبُكُمْ ‏.‏ قَالَ وَكَانَ رَجُلٌ يَنْشُدُ ضَالَّةً لَهُ ‏.‏\hadithno{7038}\hadithtrans{Jabir b. Abdullah reported that Allah's Messenger (ﷺ) said:He who climbed this hill, the hill of Murar, his sins would be obliterated as were obliterated the sins of Bani Isra'il. So the first to take their horses were the people of Banu Khazraj. Then there was a ceaseless flow of persons and Allah's Messenger (ﷺ) said to them: All of you are those who have been pardoned except the owner of a red camel. We came to him and said to him: You also come on, so that Allah's Messenger (ﷺ) may seek forgiveness for you. But he said: By Allah, so far as I am concerned, the finding of something lost is dearer to me than seeking of forgiveness for me by your companion (the Holy Prophet), and he remained busy in finding out his lost thing}}
\hadithdefcmd{muslim}{7039}{وَحَدَّثَنَاهُ يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا قُرَّةُ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يَصْعَدُ ثَنِيَّةَ الْمُرَارِ أَوِ الْمَرَارِ ‏"‏ ‏.‏ بِمِثْلِ حَدِيثِ مُعَاذٍ غَيْرَ أَنَّهُ قَالَ وَإِذَا هُوَ أَعْرَابِيٌّ جَاءَ يَنْشُدُ ضَالَّةً لَهُ ‏.‏\hadithno{7039}\hadithtrans{Jabir b. Abdullah reported Allah's Messenger (ﷺ) as saying:He who would climb this hill of Murar. The rest of the hadith is the same but with this variation that it was a desert Arab who was finding out his lost thing}}
\hadithdefcmd{muslim}{7040}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو النَّضْرِ، حَدَّثَنَا سُلَيْمَانُ، - وَهُوَ ابْنُ الْمُغِيرَةِ - عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ مِنَّا رَجُلٌ مِنْ بَنِي النَّجَّارِ قَدْ قَرَأَ الْبَقَرَةَ وَآلَ عِمْرَانَ وَكَانَ يَكْتُبُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَانْطَلَقَ هَارِبًا حَتَّى لَحِقَ بِأَهْلِ الْكِتَابِ - قَالَ - فَرَفَعُوهُ قَالُوا هَذَا قَدْ كَانَ يَكْتُبُ لِمُحَمَّدٍ فَأُعْجِبُوا بِهِ فَمَا لَبِثَ أَنْ قَصَمَ اللَّهُ عُنُقَهُ فِيهِمْ فَحَفَرُوا لَهُ فَوَارَوْهُ فَأَصْبَحَتِ الأَرْضُ قَدْ نَبَذَتْهُ عَلَى وَجْهِهَا ثُمَّ عَادُوا فَحَفَرُوا لَهُ فَوَارَوْهُ فَأَصْبَحَتِ الأَرْضُ قَدْ نَبَذَتْهُ عَلَى وَجْهِهَا ثُمَّ عَادُوا فَحَفَرُوا لَهُ فَوَارَوْهُ فَأَصْبَحَتِ الأَرْضُ قَدْ نَبَذَتْهُ عَلَى وَجْهِهَا فَتَرَكُوهُ مَنْبُوذًا ‏.‏\hadithno{7040}\hadithtrans{Anas b. Malik reported:There was a person amongst us who belonged to the tribe of Bani Najjar and he recited Sura al-Baqarah and Surat Al-i-'Imran and he used to transcribe for Allah's Messenger (ﷺ). He ran away as a rebel and joined the People of the Book. They gave it much importance and said: He is the person who used to transcribe for Muhammad and they were much pleased with him. Time rolled on that Allah caused his death. They dug the grave and buried him therein, but they found to their surprise that the earth had thrown him out over the surface. They again dug the grave for him and buried him but the earth again threw him out upon the surface. They again dug the grave for him and buried him but the earth again threw him out upon the surface. At last they left him unburied}}
\hadithdefcmd{muslim}{7041}{حَدَّثَنِي أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا حَفْصٌ، - يَعْنِي ابْنَ غِيَاثٍ - عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدِمَ مِنْ سَفَرٍ فَلَمَّا كَانَ قُرْبَ الْمَدِينَةِ هَاجَتْ رِيحٌ شَدِيدَةٌ تَكَادُ أَنْ تَدْفِنَ الرَّاكِبَ فَزَعَمَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بُعِثَتْ هَذِهِ الرِّيحُ لِمَوْتِ مُنَافِقٍ ‏"‏ ‏.‏ فَلَمَّا قَدِمَ الْمَدِينَةَ فَإِذَا مُنَافِقٌ عَظِيمٌ مِنَ الْمُنَافِقِينَ قَدْ مَاتَ ‏.‏\hadithno{7041}\hadithtrans{Jabir reported that Allah's Messenger (ﷺ) came back from a journey and as he was near Medina, there was such a violent gale that the mountain seemed to be pressed. Allah's Messenger (ﷺ) said:This wind has perhaps been made to blow for the death of a hypocrite, and as he reached Medina a notorious hypocrite from amongst the hypocrites had died}}
\hadithdefcmd{muslim}{7042}{حَدَّثَنِي عَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا أَبُو مُحَمَّدٍ النَّضْرُ بْنُ مُحَمَّدِ بْنِ، مُوسَى الْيَمَامِيُّ حَدَّثَنَا عِكْرِمَةُ، حَدَّثَنَا إِيَاسٌ، حَدَّثَنِي أَبِي قَالَ، عُدْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم رَجُلاً مَوْعُوكًا - قَالَ - فَوَضَعْتُ يَدِي عَلَيْهِ فَقُلْتُ وَاللَّهِ مَا رَأَيْتُ كَالْيَوْمِ رَجُلاً أَشَدَّ حَرًّا ‏.‏ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ أُخْبِرُكُمْ بِأَشَدَّ حَرًّا مِنْهُ يَوْمَ الْقِيَامَةِ هَذَيْنِكَ الرَّجُلَيْنِ الرَّاكِبَيْنِ الْمُقَفِّيَيْنِ ‏"‏ ‏.‏ لِرَجُلَيْنِ حِينَئِذٍ مِنْ أَصْحَابِهِ ‏.‏\hadithno{7042}\hadithtrans{Iyas reported on the authority of his father:We went along with Allah's Messenger (ﷺ) to visit a person suffering from fever. When I placed my hand upon him, I said: By Allah, I have never seen, till this day, a person running higher temperature than he. Thereupon Allah's Apostle (ﷺ), turning his face to his companions, said: May I not inform you of a severer temperature than this which these two persons would run on the Day of Resurrection? And they were two hypocrites riding upon the camel turning their back towards (the Muslims)}}
\hadithdefcmd{muslim}{7043}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي الثَّقَفِيَّ - حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الْمُنَافِقِ كَمَثَلِ الشَّاةِ الْعَائِرَةِ بَيْنَ الْغَنَمَيْنِ تَعِيرُ إِلَى هَذِهِ مَرَّةً وَإِلَى هَذِهِ مَرَّةً ‏"‏ ‏.‏\hadithno{7043}\hadithtrans{Ibn Umar reported Allah's Apostle (ﷺ) as saying:The similitude of a hypocrite is that of a sheep which roams aimlessly between two flocks. She goes to one at one time and to the other at another time}}
\hadithdefcmd{muslim}{7044}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ تَكِرُّ فِي هَذِهِ مَرَّةً وَفِي هَذِهِ مَرَّةً ‏"‏ ‏.‏\hadithno{7044}\hadithtrans{Ibn Umar reported Allah's Apostle (ﷺ) saying like this but with this change of words:" She sometimes finds a way in one flock and then in another flock}}
