% Auto-generated chapter 58 for bukhari
% Hadiths in this chapter: 30

\hadithdefcmd{bukhari}{3157}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ عَمْرًا، قَالَ كُنْتُ جَالِسًا مَعَ جَابِرِ بْنِ زَيْدٍ وَعَمْرِو بْنِ أَوْسٍ، فَحَدَّثَهُمَا بَجَالَةُ، سَنَةَ سَبْعِينَ ـ عَامَ حَجَّ مُصْعَبُ بْنُ الزُّبَيْرِ بِأَهْلِ الْبَصْرَةِ ـ عِنْدَ دَرَجِ زَمْزَمَ قَالَ كُنْتُ كَاتِبًا لِجَزْءِ بْنِ مُعَاوِيَةَ عَمِّ الأَحْنَفِ، فَأَتَانَا كِتَابُ عُمَرَ بْنِ الْخَطَّابِ قَبْلَ مَوْتِهِ بِسَنَةٍ فَرِّقُوا بَيْنَ كُلِّ ذِي مَحْرَمٍ مِنَ الْمَجُوسِ‏.‏ وَلَمْ يَكُنْ عُمَرُ أَخَذَ الْجِزْيَةَ مِنَ الْمَجُوسِ‏.‏ حَتَّى شَهِدَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَخَذَهَا مِنْ مَجُوسِ هَجَرٍ‏.‏\hadithno{3157}\hadithtrans{Narrated `Amr bin Dinar:I was sitting with Jabir bin Zaid and `Amr bin Aus, and Bajala was narrating to them in 70 A.H. the year when Mus`ab bin Az-Zubair was the leader of the pilgrims of Basra. We were sitting at the steps of Zamzam well and Bajala said, "I was the clerk of Juz bin Muawiya, Al-Ahnaf's paternal uncle. A letter came from `Umar bin Al-Khattab one year before his death; and it was read:-- "Cancel every marriage contracted among the Magians between relatives of close kinship (marriages that are regarded illegal in Islam: a relative of this sort being called Dhu-Mahram.)" `Umar did not take the Jizya from the Magian infidels till `Abdur-Rahman bin `Auf testified that Allah's Messenger (ﷺ) had taken the Jizya from the Magians of Hajar}}
\hadithdefcmd{bukhari}{3158}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، أَنَّهُ أَخْبَرَهُ أَنَّ عَمْرَو بْنَ عَوْفٍ الأَنْصَارِيَّ وَهْوَ حَلِيفٌ لِبَنِي عَامِرِ بْنِ لُؤَىٍّ وَكَانَ شَهِدَ بَدْرًا أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ أَبَا عُبَيْدَةَ بْنَ الْجَرَّاحِ إِلَى الْبَحْرَيْنِ يَأْتِي بِجِزْيَتِهَا، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم هُوَ صَالَحَ أَهْلَ الْبَحْرَيْنِ وَأَمَّرَ عَلَيْهِمُ الْعَلاَءَ بْنَ الْحَضْرَمِيِّ، فَقَدِمَ أَبُو عُبَيْدَةَ بِمَالٍ مِنَ الْبَحْرَيْنِ، فَسَمِعَتِ الأَنْصَارُ بِقُدُومِ أَبِي عُبَيْدَةَ فَوَافَتْ صَلاَةَ الصُّبْحِ مَعَ النَّبِيِّ صلى الله عليه وسلم، فَلَمَّا صَلَّى بِهِمِ الْفَجْرَ انْصَرَفَ، فَتَعَرَّضُوا لَهُ، فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ رَآهُمْ وَقَالَ ‏"‏ أَظُنُّكُمْ قَدْ سَمِعْتُمْ أَنَّ أَبَا عُبَيْدَةَ قَدْ جَاءَ بِشَىْءٍ ‏"‏‏.‏ قَالُوا أَجَلْ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَأَبْشِرُوا وَأَمِّلُوا مَا يَسُرُّكُمْ، فَوَاللَّهِ لاَ الْفَقْرَ أَخْشَى عَلَيْكُمْ، وَلَكِنْ أَخْشَى عَلَيْكُمْ أَنْ تُبْسَطَ عَلَيْكُمُ الدُّنْيَا كَمَا بُسِطَتْ عَلَى مَنْ كَانَ قَبْلَكُمْ، فَتَنَافَسُوهَا كَمَا تَنَافَسُوهَا وَتُهْلِكَكُمْ كَمَا أَهْلَكَتْهُمْ ‏"‏‏.‏\hadithno{3158}\hadithtrans{Narrated `Amr bin `Auf Al-Ansari:(who was an ally of Bani `Amr bin Lu'ai and one of those who had taken part in (the Ghazwa of) Badr): Allah's Messenger (ﷺ) sent Abu 'Ubaida bin Al-Jarreh to Bahrain to collect the Jizya. Allah's Messenger (ﷺ) had established peace with the people of Bahrain and appointed Al-`Ala' bin Al-Hadrami as their governor. When Abu 'Ubaida came from Bahrain with the money, the Ansar heard of Abu 'Ubaida's arrival which coincided with the time of the morning prayer with the Prophet. When Allah's Messenger (ﷺ) led them in the morning prayer and finished, the Ansar approached him, and he looked at them and smiled on seeing them and said, "I feel that you have heard that Abu. 'Ubaida has brought something?" They said, "Yes, O Allah's Messenger (ﷺ)' He said, "Rejoice and hope for what will please you! By Allah, I am not afraid of your poverty but I am afraid that you will lead a life of luxury as past nations did, whereupon you will compete with each other for it, as they competed for it, and it will destroy you as it destroyed them}}
\hadithdefcmd{bukhari}{3160}{حَدَّثَنَا الْفَضْلُ بْنُ يَعْقُوبَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الرَّقِّيُّ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، حَدَّثَنَا سَعِيدُ بْنُ عُبَيْدِ اللَّهِ الثَّقَفِيُّ، حَدَّثَنَا بَكْرُ بْنُ عَبْدِ اللَّهِ الْمُزَنِيُّ، وَزِيَادُ بْنُ جُبَيْرٍ، عَنْ جُبَيْرِ بْنِ حَيَّةَ، قَالَ بَعَثَ عُمَرُ النَّاسَ فِي أَفْنَاءِ الأَمْصَارِ يُقَاتِلُونَ الْمُشْرِكِينَ، فَأَسْلَمَ الْهُرْمُزَانُ فَقَالَ إِنِّي مُسْتَشِيرُكَ فِي مَغَازِيَّ هَذِهِ‏.‏ قَالَ نَعَمْ، مَثَلُهَا وَمَثَلُ مَنْ فِيهَا مِنَ النَّاسِ مِنْ عَدُوِّ الْمُسْلِمِينَ مَثَلُ طَائِرٍ لَهُ رَأْسٌ وَلَهُ جَنَاحَانِ وَلَهُ رِجْلاَنِ، فَإِنْ كُسِرَ أَحَدُ الْجَنَاحَيْنِ نَهَضَتِ الرِّجْلاَنِ بِجَنَاحٍ وَالرَّأْسُ، فَإِنْ كُسِرَ الْجَنَاحُ الآخَرُ نَهَضَتِ الرِّجْلاَنِ وَالرَّأْسُ، وَإِنْ شُدِخَ الرَّأْسُ ذَهَبَتِ الرِّجْلاَنِ وَالْجَنَاحَانِ وَالرَّأْسُ، فَالرَّأْسُ كِسْرَى، وَالْجَنَاحُ قَيْصَرُ، وَالْجَنَاحُ الآخَرُ فَارِسُ، فَمُرِ الْمُسْلِمِينَ فَلْيَنْفِرُوا إِلَى كِسْرَى‏.‏ وَقَالَ بَكْرٌ وَزِيَادٌ جَمِيعًا عَنْ جُبَيْرِ بْنِ حَيَّةَ قَالَ فَنَدَبَنَا عُمَرُ وَاسْتَعْمَلَ عَلَيْنَا النُّعْمَانَ بْنَ مُقَرِّنٍ، حَتَّى إِذَا كُنَّا بِأَرْضِ الْعَدُوِّ، وَخَرَجَ عَلَيْنَا عَامِلُ كِسْرَى فِي أَرْبَعِينَ أَلْفًا، فَقَامَ تُرْجُمَانٌ فَقَالَ لِيُكَلِّمْنِي رَجُلٌ مِنْكُمْ‏.‏ فَقَالَ الْمُغِيرَةُ سَلْ عَمَّا شِئْتَ‏.‏ قَالَ مَا أَنْتُمْ قَالَ نَحْنُ أُنَاسٌ مِنَ الْعَرَبِ كُنَّا فِي شَقَاءٍ شَدِيدٍ وَبَلاَءٍ شَدِيدٍ، نَمَصُّ الْجِلْدَ وَالنَّوَى مِنَ الْجُوعِ، وَنَلْبَسُ الْوَبَرَ وَالشَّعَرَ، وَنَعْبُدُ الشَّجَرَ وَالْحَجَرَ، فَبَيْنَا نَحْنُ كَذَلِكَ، إِذْ بَعَثَ رَبُّ السَّمَوَاتِ وَرَبُّ الأَرَضِينَ تَعَالَى ذِكْرُهُ وَجَلَّتْ عَظَمَتُهُ إِلَيْنَا نَبِيًّا مِنْ أَنْفُسِنَا، نَعْرِفُ أَبَاهُ وَأُمَّهُ، فَأَمَرَنَا نَبِيُّنَا رَسُولُ رَبِّنَا صلى الله عليه وسلم أَنْ نَقَاتِلَكُمْ حَتَّى تَعْبُدُوا اللَّهَ وَحْدَهُ أَوْ تُؤَدُّوا الْجِزْيَةَ، وَأَخْبَرَنَا نَبِيُّنَا صلى الله عليه وسلم عَنْ رِسَالَةِ رَبِّنَا أَنَّهُ مَنْ قُتِلَ مِنَّا صَارَ إِلَى الْجَنَّةِ فِي نَعِيمٍ لَمْ يَرَ مِثْلَهَا قَطُّ، وَمَنْ بَقِيَ مِنَّا مَلَكَ رِقَابَكُمْ‏.‏ فَقَالَ النُّعْمَانُ رُبَّمَا أَشْهَدَكَ اللَّهُ مِثْلَهَا مَعَ النَّبِيِّ صلى الله عليه وسلم فَلَمْ يُنَدِّمْكَ وَلَمْ يُخْزِكَ، وَلَكِنِّي شَهِدْتُ الْقِتَالَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا لَمْ يُقَاتِلْ فِي أَوَّلِ النَّهَارِ انْتَظَرَ حَتَّى تَهُبَّ الأَرْوَاحُ وَتَحْضُرَ الصَّلَوَاتُ‏.‏\hadithno{3160}\hadithtrans{Narrated Jubair bin Haiya:`Umar sent the Muslims to the great countries to fight the pagans. When Al-Hurmuzan embraced Islam, `Umar said to him. "I would like to consult you regarding these countries which I intend to invade." Al-Hurmuzan said, "Yes, the example of these countries and their inhabitants who are the enemies. of the Muslims, is like a bird with a head, two wings and two legs; If one of its wings got broken, it would get up over its two legs, with one wing and the head; and if the other wing got broken, it would get up with two legs and a head, but if its head got destroyed, then the two legs, two wings and the head would become useless. The head stands for Khosrau, and one wing stands for Caesar and the other wing stands for Faris. So, order the Muslims to go towards Khosrau." So, `Umar sent us (to Khosrau) appointing An-Nu`man bin Muqrin as our commander. When we reached the land of the enemy, the representative of Khosrau came out with forty-thousand warriors, and an interpreter got up saying, "Let one of you talk to me!" Al-Mughira replied, "Ask whatever you wish." The other asked, "Who are you?" Al-Mughira replied, "We are some people from the Arabs; we led a hard, miserable, disastrous life: we used to suck the hides and the date stones from hunger; we used to wear clothes made up of fur of camels and hair of goats, and to worship trees and stones. While we were in this state, the Lord of the Heavens and the Earths, Elevated is His Remembrance and Majestic is His Highness, sent to us from among ourselves a Prophet whose father and mother are known to us. Our Prophet, the Messenger of our Lord, has ordered us to fight you till you worship Allah Alone or give Jizya (i.e. tribute); and our Prophet has informed us that our Lord says:-- "Whoever amongst us is killed (i.e. martyred), shall go to Paradise to lead such a luxurious life as he has never seen, and whoever amongst us remains alive, shall become your master." (Al-Mughira, then blamed An-Nu`man for delaying the attack and) An-Nu' man said to Al-Mughira, "If you had participated in a similar battle, in the company of Allah's Messenger (ﷺ) he would not have blamed you for waiting, nor would he have disgraced you. But I accompanied Allah's Apostle in many battles and it was his custom that if he did not fight early by daytime, he would wait till the wind had started blowing and the time for the prayer was due (i.e. after midday)}}
\hadithdefcmd{bukhari}{3161}{حَدَّثَنَا سَهْلُ بْنُ بَكَّارٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ عَبَّاسٍ السَّاعِدِيِّ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ غَزَوْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم تَبُوكَ، وَأَهْدَى مَلِكُ أَيْلَةَ لِلنَّبِيِّ صلى الله عليه وسلم بَغْلَةً بَيْضَاءَ، وَكَسَاهُ بُرْدًا، وَكَتَبَ لَهُ بِبَحْرِهِمْ‏.‏\hadithno{3161}\hadithtrans{Narrated Abu Humaid As-Saidi:We accompanied the Prophet (ﷺ) in the Ghazwa of Tabuk and the king of 'Aila presented a white mule and a cloak as a gift to the Prophet. And the Prophet (ﷺ) wrote to him a peace treaty allowing him to keep authority over his country}}
\hadithdefcmd{bukhari}{3162}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا أَبُو جَمْرَةَ، قَالَ سَمِعْتُ جُوَيْرِيَةَ بْنَ قُدَامَةَ التَّمِيمِيَّ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ قُلْنَا أَوْصِنَا يَا أَمِيرَ الْمُؤْمِنِينَ‏.‏ قَالَ أُوصِيكُمْ بِذِمَّةِ اللَّهِ، فَإِنَّهُ ذِمَّةُ نَبِيِّكُمْ، وَرِزْقُ عِيَالِكُمْ‏.‏\hadithno{3162}\hadithtrans{Narrated Juwairiya bin Qudama at-Tamimi:We said to `Umar bin Al-Khattab, "O Chief of the believers! Advise us." He said, "I advise you to fulfill Allah's Covenant (made with the Dhimmis) as it is the convention of your Prophet and the source of the livelihood of your dependents (i.e. the taxes from the Dhimmis)}}
\hadithdefcmd{bukhari}{3163}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ قَالَ دَعَا النَّبِيُّ صلى الله عليه وسلم الأَنْصَارَ لِيَكْتُبَ لَهُمْ بِالْبَحْرَيْنِ فَقَالُوا لاَ وَاللَّهِ حَتَّى تَكْتُبَ لإِخْوَانِنَا مِنْ قُرَيْشٍ بِمِثْلِهَا‏.‏ فَقَالَ ذَاكَ لَهُمْ مَا شَاءَ اللَّهُ عَلَى ذَلِكَ يَقُولُونَ لَهُ قَالَ ‏ "‏ فَإِنَّكُمْ سَتَرَوْنَ بَعْدِي أُثْرَةً، فَاصْبِرُوا حَتَّى تَلْقَوْنِي ‏عَلَى الْحَوْضِ"‏‏.‏\hadithno{3163}\hadithtrans{Narrated Yahya bin Sa`id:Once the Prophet (ﷺ) called the Ansar in order to grant them part of the land of Bahrain. On that they said, "No! By Allah, we will not accept it unless you grant a similar thing to our Quraishi brothers as well." He said, "That will be their's if Allah wishes." But when the Ansar persisted in their request, he said, "After me you will see others given preference over you in this respect (in which case) you should be patient till you meet me at the Tank (of Al-Kauthar)}}
\hadithdefcmd{bukhari}{3165}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، قَالَ أَخْبَرَنِي رَوْحُ بْنُ الْقَاسِمِ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ لِي ‏"‏ لَوْ قَدْ جَاءَنَا مَالُ الْبَحْرَيْنِ قَدْ أَعْطَيْتُكَ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏‏.‏ فَلَمَّا قُبِضَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَجَاءَ مَالُ الْبَحْرَيْنِ قَالَ أَبُو بَكْرٍ مَنْ كَانَتْ لَهُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم عِدَةٌ فَلْيَأْتِنِي‏.‏ فَأَتَيْتُهُ فَقُلْتُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ كَانَ قَالَ لِي ‏"‏ لَوْ قَدْ جَاءَنَا مَالُ الْبَحْرَيْنِ لأَعْطَيْتُكَ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏‏.‏ فَقَالَ لِي احْثُهْ‏.‏ فَحَثَوْتُ حَثْيَةً فَقَالَ لِي عُدَّهَا‏.‏ فَعَدَدْتُهَا فَإِذَا هِيَ خَمْسُمِائَةٍ، فَأَعْطَانِي أَلْفًا وَخَمْسَمِائَةٍ‏.‏ وَقَالَ إِبْرَاهِيمُ بْنُ طَهْمَانَ عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِمَالٍ مِنَ الْبَحْرَيْنِ فَقَالَ ‏"‏ انْثُرُوهُ فِي الْمَسْجِدِ ‏"‏ فَكَانَ أَكْثَرَ مَالٍ أُتِيَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذْ جَاءَهُ الْعَبَّاسُ فَقَالَ يَا رَسُولَ اللَّهِ، أَعْطِنِي إِنِّي فَادَيْتُ نَفْسِي وَفَادَيْتُ عَقِيلاً‏.‏ قَالَ ‏"‏ خُذْ ‏"‏‏.‏ فَحَثَا فِي ثَوْبِهِ، ثُمَّ ذَهَبَ يُقِلُّهُ، فَلَمْ يَسْتَطِعْ‏.‏ فَقَالَ أْمُرْ بَعْضَهُمْ يَرْفَعْهُ إِلَىَّ‏.‏ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قَالَ فَارْفَعْهُ أَنْتَ عَلَىَّ‏.‏ قَالَ ‏"‏ لاَ ‏"‏‏.‏ فَنَثَرَ مِنْهُ، ثُمَّ ذَهَبَ يُقِلُّهُ فَلَمْ يَرْفَعْهُ‏.‏ فَقَالَ أْمُرْ بَعْضَهُمْ يَرْفَعْهُ عَلَىَّ‏.‏ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قَالَ فَارْفَعْهُ أَنْتَ عَلَىَّ‏.‏ قَالَ ‏"‏ لاَ ‏"‏‏.‏ فَنَثَرَ ثُمَّ احْتَمَلَهُ عَلَى كَاهِلِهِ ثُمَّ انْطَلَقَ، فَمَا زَالَ يُتْبِعُهُ بَصَرَهُ حَتَّى خَفِيَ عَلَيْنَا عَجَبًا مِنْ حِرْصِهِ، فَمَا قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَثَمَّ مِنْهَا دِرْهَمٌ‏.‏\hadithno{3165}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) once said to me, "If the revenue of Bahrain came, I would give you this much and this much." When Allah's Messenger (ﷺ) had died, the revenue of Bahrain came, and Abu Bakr announced, " Let whoever was promised something by Allah's Messenger (ﷺ) come to me." So, I went to Abu Bakr and said, "Allah's Messenger (ﷺ) said to me, 'If the revenue of Bahrain came, I would give you this much and this. much." On that Abu Bakr said to me, "Scoop (money) with both your hands." I scooped money with both my hands and Abu Bakr asked me to count it. I counted it and it was five-hundred (gold pieces). The total amount he gave me was one thousand and five hundred (gold pieces.) Narrated Anas: Money from Bahrain was brought to the Prophet (ﷺ) . He said, "Spread it in the Mosque." It was the biggest amount that had ever been brought to Allah's Messenger (ﷺ) . In the meantime Al-`Abbas came to him and said, "O Allah's Messenger (ﷺ)! Give me, for I gave the ransom of myself and `Aqil." The Prophet said (to him), "Take." He scooped money with both hands and poured it in his garment and tried to lift it, but he could not and appealed to the Prophet, "Will you order someone to help me in lifting it?" The Prophet (ﷺ) said, "No." Then Al-`Abbas said, "Then will you yourself help me carry it?" The Prophet (ﷺ) said, "No." Then Al `Abbas threw away some of the money, but even then he was not able to lift it, and so he again requested the Prophet (ﷺ) "Will you order someone to help me carry it?" The Prophet said, "No." Then Al-`Abbas said, "Then will you yourself yelp me carry it?" The Prophet (ﷺ) said, 'No." So, Al-`Abbas threw away some more money and lifted it on his shoulder and went away. The Prophet (ﷺ) kept on looking at him with astonishment at his greediness till he went out of our sight. Allah's Messenger (ﷺ) did not get up from there till not a single Dirham remained from that money}}
\hadithdefcmd{bukhari}{3166}{حَدَّثَنَا قَيْسُ بْنُ حَفْصٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الْحَسَنُ بْنُ عَمْرٍو، حَدَّثَنَا مُجَاهِدٌ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَتَلَ مُعَاهَدًا لَمْ يَرَحْ رَائِحَةَ الْجَنَّةِ، وَإِنَّ رِيحَهَا تُوجَدُ مِنْ مَسِيرَةِ أَرْبَعِينَ عَامًا ‏"‏‏.‏\hadithno{3166}\hadithtrans{Narrated `Abdullah bin `Amr:The Prophet (ﷺ) said, "Whoever killed a person having a treaty with the Muslims, shall not smell the smell of Paradise though its smell is perceived from a distance of forty years}}
\hadithdefcmd{bukhari}{3167}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي سَعِيدٌ الْمَقْبُرِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ بَيْنَمَا نَحْنُ فِي الْمَسْجِدِ خَرَجَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ انْطَلِقُوا إِلَى يَهُودَ ‏"‏‏.‏ فَخَرَجْنَا حَتَّى جِئْنَا بَيْتَ الْمِدْرَاسِ فَقَالَ ‏"‏ أَسْلِمُوا تَسْلَمُوا، وَاعْلَمُوا أَنَّ الأَرْضَ لِلَّهِ وَرَسُولِهِ، وَإِنِّي أُرِيدُ أَنْ أُجْلِيَكُمْ مِنْ هَذِهِ الأَرْضِ، فَمَنْ يَجِدْ مِنْكُمْ بِمَالِهِ شَيْئًا فَلْيَبِعْهُ، وَإِلاَّ فَاعْلَمُوا أَنَّ الأَرْضَ لِلَّهِ وَرَسُولِهِ ‏"‏‏.‏\hadithno{3167}\hadithtrans{Narrated Abu Huraira:While we were in the Mosque, the Prophet (ﷺ) came out and said, "Let us go to the Jews" We went out till we reached Bait-ul-Midras. He said to them, "If you embrace Islam, you will be safe. You should know that the earth belongs to Allah and His Apostle, and I want to expel you from this land. So, if anyone amongst you owns some property, he is permitted to sell it, otherwise you should know that the Earth belongs to Allah and His Apostle}}
\hadithdefcmd{bukhari}{3168}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ سُلَيْمَانَ الأَحْوَلِ، سَمِعَ سَعِيدَ بْنَ جُبَيْرٍ، سَمِعَ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ يَوْمُ الْخَمِيسِ، وَمَا يَوْمُ الْخَمِيسِ ثُمَّ بَكَى حَتَّى بَلَّ دَمْعُهُ الْحَصَى‏.‏ قُلْتُ يَا أَبَا عَبَّاسٍ، مَا يَوْمُ الْخَمِيسِ قَالَ اشْتَدَّ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَجَعُهُ فَقَالَ ‏"‏ ائْتُونِي بِكَتِفٍ أَكْتُبْ لَكُمْ كِتَابًا لاَ تَضِلُّوا بَعْدَهُ أَبَدًا ‏"‏‏.‏ فَتَنَازَعُوا وَلاَ يَنْبَغِي عِنْدَ نَبِيٍّ تَنَازُعٌ فَقَالُوا مَا لَهُ أَهَجَرَ اسْتَفْهِمُوهُ‏.‏ فَقَالَ ‏"‏ ذَرُونِي، فَالَّذِي أَنَا فِيهِ خَيْرٌ مِمَّا تَدْعُونِي إِلَيْهِ ـ فَأَمَرَهُمْ بِثَلاَثٍ قَالَ ـ أَخْرِجُوا الْمُشْرِكِينَ مِنْ جَزِيرَةِ الْعَرَبِ، وَأَجِيزُوا الْوَفْدَ بِنَحْوِ مَا كُنْتُ أُجِيزُهُمْ ‏"‏‏.‏ وَالثَّالِثَةُ خَيْرٌ، إِمَّا أَنْ سَكَتَ عَنْهَا، وَإِمَّا أَنْ قَالَهَا فَنَسِيتُهَا‏.‏ قَالَ سُفْيَانُ هَذَا مِنْ قَوْلِ سُلَيْمَانَ‏.‏\hadithno{3168}\hadithtrans{Narrated Sa`id bin Jubair:that he heard Ibn `Abbas saying, "Thursday! And you know not what Thursday is? After that Ibn `Abbas wept till the stones on the ground were soaked with his tears. On that I asked Ibn `Abbas, "What is (about) Thursday?" He said, "When the condition (i.e. health) of Allah's Messenger (ﷺ) deteriorated, he said, 'Bring me a bone of scapula, so that I may write something for you after which you will never go astray.'The people differed in their opinions although it was improper to differ in front of a prophet, They said, 'What is wrong with him? Do you think he is delirious? Ask him (to understand). The Prophet (ﷺ) replied, 'Leave me as I am in a better state than what you are asking me to do.' Then the Prophet (ﷺ) ordered them to do three things saying, 'Turn out all the pagans from the Arabian Peninsula, show respect to all foreign delegates by giving them gifts as I used to do.' " The sub-narrator added, "The third order was something beneficial which either Ibn `Abbas did not mention or he mentioned but I forgot}}
\hadithdefcmd{bukhari}{3169}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي سَعِيدٌ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ لَمَّا فُتِحَتْ خَيْبَرُ أُهْدِيَتْ لِلنَّبِيِّ صلى الله عليه وسلم شَاةٌ فِيهَا سُمٌّ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اجْمَعُوا إِلَىَّ مَنْ كَانَ هَا هُنَا مِنْ يَهُودَ ‏"‏‏.‏ فَجُمِعُوا لَهُ فَقَالَ ‏"‏ إِنِّي سَائِلُكُمْ عَنْ شَىْءٍ فَهَلْ أَنْتُمْ صَادِقِيَّ عَنْهُ ‏"‏‏.‏ فَقَالُوا نَعَمْ‏.‏ قَالَ لَهُمُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ أَبُوكُمْ ‏"‏‏.‏ قَالُوا فُلاَنٌ‏.‏ فَقَالَ ‏"‏ كَذَبْتُمْ، بَلْ أَبُوكُمْ فُلاَنٌ ‏"‏‏.‏ قَالُوا صَدَقْتَ‏.‏ قَالَ ‏"‏ فَهَلْ أَنْتُمْ صَادِقِيَّ عَنْ شَىْءٍ إِنْ سَأَلْتُ عَنْهُ ‏"‏ فَقَالُوا نَعَمْ يَا أَبَا الْقَاسِمِ، وَإِنْ كَذَبْنَا عَرَفْتَ كَذِبَنَا كَمَا عَرَفْتَهُ فِي أَبِينَا‏.‏ فَقَالَ لَهُمْ ‏"‏ مَنْ أَهْلُ النَّارِ ‏"‏‏.‏ قَالُوا نَكُونُ فِيهَا يَسِيرًا ثُمَّ تَخْلُفُونَا فِيهَا‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اخْسَئُوا فِيهَا، وَاللَّهِ لاَ نَخْلُفُكُمْ فِيهَا أَبَدًا ـ ثُمَّ قَالَ ـ هَلْ أَنْتُمْ صَادِقِيَّ عَنْ شَىْءٍ إِنْ سَأَلْتُكُمْ عَنْهُ ‏"‏‏.‏ فَقَالُوا نَعَمْ يَا أَبَا الْقَاسِمِ‏.‏ قَالَ ‏"‏ هَلْ جَعَلْتُمْ فِي هَذِهِ الشَّاةِ سُمًّا ‏"‏‏.‏ قَالُوا نَعَمْ‏.‏ قَالَ ‏"‏ مَا حَمَلَكُمْ عَلَى ذَلِكَ ‏"‏‏.‏ قَالُوا أَرَدْنَا إِنْ كُنْتَ كَاذِبًا نَسْتَرِيحُ، وَإِنْ كُنْتَ نَبِيًّا لَمْ يَضُرَّكَ‏.‏\hadithno{3169}\hadithtrans{Narrated Abu Huraira:When Khaibar was conquered, a roasted poisoned sheep was presented to the Prophet (ﷺ) as a gift (by the Jews). The Prophet (ﷺ) ordered, "Let all the Jews who have been here, be assembled before me." The Jews were collected and the Prophet (ﷺ) said (to them), "I am going to ask you a question. Will you tell the truth?" They said, "Yes." The Prophet (ﷺ) asked, "Who is your father?" They replied, "So-and-so." He said, "You have told a lie; your father is so-and-so." They said, "You are right." He said, "Will you now tell me the truth, if I ask you about something?" They replied, "Yes, O Abu Al-Qasim; and if we should tell a lie, you can realize our lie as you have done regarding our father." On that he asked, "Who are the people of the (Hell) Fire?" They said, "We shall remain in the (Hell) Fire for a short period, and after that you will replace us." The Prophet (ﷺ) said, "You may be cursed and humiliated in it! By Allah, we shall never replace you in it." Then he asked, "Will you now tell me the truth if I ask you a question?" They said, "Yes, O Abu Al-Qasim." He asked, "Have you poisoned this sheep?" They said, "Yes." He asked, "What made you do so?" They said, "We wanted to know if you were a liar in which case we would get rid of you, and if you are a prophet then the poison would not harm you}}
\hadithdefcmd{bukhari}{3170}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا ثَابِتُ بْنُ يَزِيدَ، حَدَّثَنَا عَاصِمٌ، قَالَ سَأَلْتُ أَنَسًا ـ رضى الله عنه ـ عَنِ الْقُنُوتِ‏.‏ قَالَ قَبْلَ الرُّكُوعِ‏.‏ فَقُلْتُ إِنَّ فُلاَنًا يَزْعُمُ أَنَّكَ قُلْتَ بَعْدَ الرُّكُوعِ، فَقَالَ كَذَبَ‏.‏ ثُمَّ حَدَّثَنَا عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَنَتَ شَهْرًا بَعْدَ الرُّكُوعِ يَدْعُو عَلَى أَحْيَاءٍ مِنْ بَنِي سُلَيْمٍ ـ قَالَ ـ بَعَثَ أَرْبَعِينَ أَوْ سَبْعِينَ ـ يَشُكُّ فِيهِ ـ مِنَ الْقُرَّاءِ إِلَى أُنَاسٍ مِنَ الْمُشْرِكِينَ، فَعَرَضَ لَهُمْ هَؤُلاَءِ فَقَتَلُوهُمْ، وَكَانَ بَيْنَهُمْ وَبَيْنَ النَّبِيِّ صلى الله عليه وسلم عَهْدٌ، فَمَا رَأَيْتُهُ وَجَدَ عَلَى أَحَدٍ مَا وَجَدَ عَلَيْهِمْ‏.‏\hadithno{3170}\hadithtrans{Narrated `Asim:I asked Anas about the Qunut (i.e. invocation in the prayer). Anas said, "It should be recited before bowing." I said, "So-and-so claims that you say that it should be recited after bowing." He replied, "He is mistaken." Then Anas narrated to us that the Prophet (ﷺ) invoked evil on the tribe of Bani-Sulaim for one month after bowing. ' Anas Further said, "The Prophet (ﷺ) had sent 40 or 70 Qaris (i.e. men well versed in the knowledge of the Qur'an) to some pagans, but the latter struggled with them and martyred them, although there was a peace pact between them and the Prophet (ﷺ) I had never seen the Prophet so sorry and worried about anybody as he was about them (i.e. the Qaris)}}
\hadithdefcmd{bukhari}{3171}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ أَنَّ أَبَا مُرَّةَ، مَوْلَى أُمِّ هَانِئٍ ابْنَةِ أَبِي طَالِبٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ أُمَّ هَانِئٍ ابْنَةَ أَبِي طَالِبٍ، تَقُولُ ذَهَبْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ فَوَجَدْتُهُ يَغْتَسِلُ، وَفَاطِمَةُ ابْنَتُهُ تَسْتُرُهُ، فَسَلَّمْتُ عَلَيْهِ فَقَالَ ‏"‏ مَنْ هَذِهِ ‏"‏‏.‏ فَقُلْتُ أَنَا أُمُّ هَانِئٍ بِنْتُ أَبِي طَالِبٍ‏.‏ فَقَالَ ‏"‏ مَرْحَبًا بِأُمِّ هَانِئٍ ‏"‏‏.‏ فَلَمَّا فَرَغَ مِنْ غُسْلِهِ قَامَ، فَصَلَّى ثَمَانَ رَكَعَاتٍ مُلْتَحِفًا فِي ثَوْبٍ وَاحِدٍ، فَقُلْتُ يَا رَسُولَ اللَّهِ، زَعَمَ ابْنُ أُمِّي عَلِيٌّ أَنَّهُ قَاتِلٌ رَجُلاً قَدْ أَجَرْتُهُ فُلاَنُ بْنُ هُبَيْرَةَ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ أَجَرْنَا مَنْ أَجَرْتِ يَا أُمَّ هَانِئٍ ‏"‏‏.‏ قَالَتْ أُمُّ هَانِئٍ وَذَلِكَ ضُحًى‏.‏\hadithno{3171}\hadithtrans{Narrated Um Hani:the daughter of Abu Talib: I went to Allah's Messenger (ﷺ) on the day of the conquest of Mecca and found him taking a bath, and his daughter Fatima was screening him. I greeted him and he asked, "Who is that?" I said, "I, Um Hani bint Abi Talib." He said, "Welcome, O Um Hani." When he had finished his bath, he stood up and offered eight rak`at while dressed in one garment. I said, "O Allah's Messenger (ﷺ)! My brother `Ali has declared that he will kill a man to whom I have granted asylum. The man is so and-so bin Hubaira." Allah's Messenger (ﷺ) said, "O Um Hani! We will grant asylum to the one whom you have granted asylum." (Um Hani said, "That (visit) took place in the Duha (i.e. forenoon)}}
\hadithdefcmd{bukhari}{3172}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، قَالَ خَطَبَنَا عَلِيٌّ فَقَالَ مَا عِنْدَنَا كِتَابٌ نَقْرَؤُهُ إِلاَّ كِتَابُ اللَّهِ، وَمَا فِي هَذِهِ الصَّحِيفَةِ فَقَالَ فِيهَا الْجِرَاحَاتُ وَأَسْنَانُ الإِبِلِ، وَالْمَدِينَةُ حَرَمٌ مَا بَيْنَ عَيْرٍ إِلَى كَذَا، فَمَنْ أَحْدَثَ فِيهَا حَدَثًا أَوْ آوَى فِيهَا مُحْدِثًا، فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ، لاَ يُقْبَلُ مِنْهُ صَرْفٌ وَلاَ عَدْلٌ، وَمَنْ تَوَلَّى غَيْرَ مَوَالِيهِ فَعَلَيْهِ مِثْلُ ذَلِكَ، وَذِمَّةُ الْمُسْلِمِينَ وَاحِدَةٌ، فَمَنْ أَخْفَرَ مُسْلِمًا فَعَلَيْهِ مِثْلُ ذَلِكَ‏.‏\hadithno{3172}\hadithtrans{Narrated Ibrahim at-Tamimi's father:`Ali delivered a sermon saying, "We have no book to read except the Book of Allah and what is written in this paper which contains verdicts regarding (retaliation for) wounds, the ages of the camels (given as Zakat or as blood money) and the fact that Medina is a sanctuary in between Air mountain to so-and-so (mountain). So, whoever innovates in it an heresy or commits a sin or gives shelter in it, to such an innovator will incur the Curse of Allah, the angels and all the people, and none of his compulsory or optional good deeds of worship will be accepted. And whoever (freed slave) takes as his master (i.e. befriends) other than his real masters will incur the same (Curse). And the asylum granted by any Muslim is to be secured by all the other Muslims, and whoever betrays a Muslim in this respect will incur the same (Curse)}}
\hadithdefcmd{bukhari}{3173}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ ـ هُوَ ابْنُ الْمُفَضَّلِ ـ حَدَّثَنَا يَحْيَى، عَنْ بُشَيْرِ بْنِ يَسَارٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، قَالَ انْطَلَقَ عَبْدُ اللَّهِ بْنُ سَهْلٍ وَمُحَيِّصَةُ بْنُ مَسْعُودِ بْنِ زَيْدٍ إِلَى خَيْبَرَ، وَهْىَ يَوْمَئِذٍ صُلْحٌ، فَتَفَرَّقَا، فَأَتَى مُحَيِّصَةُ إِلَى عَبْدِ اللَّهِ بْنِ سَهْلٍ وَهْوَ يَتَشَحَّطُ فِي دَمٍ قَتِيلاً، فَدَفَنَهُ ثُمَّ قَدِمَ الْمَدِينَةَ، فَانْطَلَقَ عَبْدُ الرَّحْمَنِ بْنُ سَهْلٍ وَمُحَيِّصَةُ وَحُوَيِّصَةُ ابْنَا مَسْعُودٍ إِلَى النَّبِيِّ صلى الله عليه وسلم، فَذَهَبَ عَبْدُ الرَّحْمَنِ يَتَكَلَّمُ فَقَالَ ‏"‏ كَبِّرْ كَبِّرْ ‏"‏‏.‏ وَهْوَ أَحْدَثُ الْقَوْمِ، فَسَكَتَ فَتَكَلَّمَا فَقَالَ ‏"‏ أَتَحْلِفُونَ وَتَسْتَحِقُّونَ قَاتِلَكُمْ أَوْ صَاحِبَكُمْ ‏"‏‏.‏ قَالُوا وَكَيْفَ نَحْلِفُ وَلَمْ نَشْهَدْ وَلَمْ نَرَ قَالَ ‏"‏ فَتُبْرِيكُمْ يَهُودُ بِخَمْسِينَ ‏"‏‏.‏ فَقَالُوا كَيْفَ نَأْخُذُ أَيْمَانَ قَوْمٍ كُفَّارٍ فَعَقَلَهُ النَّبِيُّ صلى الله عليه وسلم مِنْ عِنْدِهِ‏.‏\hadithno{3173}\hadithtrans{Narrated Sahl bin Abi Hathma:`Abdullah bin Sahl and Muhaiyisa bin Mas`ud bin Zaid set out to Khaibar, the inhabitants of which had a peace treaty with the Muslims at that time. They parted and later on Muhaiyisa came upon `Abdullah bin Sahl and found him murdered agitating in his blood. He buried him and returned to Medina. `Abdur Rahman bin Sahl, Muhaiyisa and Huwaiyisa, the sons of Mas`ud came to the Prophet (ﷺ) and `Abdur Rahman intended to talk, but the Prophet (ﷺ) said (to him), "Let the eldest of you speak." as `Abdur-Rahman was the youngest:. `Abdur-Rahman kept silent and the other two spoke. The Prophet (ﷺ) said, "If you swear as to who has committed the murder, you will have the right to take your right from the murderer." They said, "How should we swear if we did not witness the murder or see the murderer?" The Prophet (ﷺ) said, "Then the Jews can clear themselves from the charge by taking Alaska (an oath taken by men that it was not they who committed the murder)." The!y said, "How should we believe in the oaths of infidels?" So, the Prophet (ﷺ) himself paid the blood money (of `Abdullah). (See Hadith No. 36 Vol)}}
\hadithdefcmd{bukhari}{3174}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ أَخْبَرَهُ أَنَّ أَبَا سُفْيَانَ بْنَ حَرْبٍ أَخْبَرَهُ أَنَّ هِرَقْلَ أَرْسَلَ إِلَيْهِ فِي رَكْبٍ مِنْ قُرَيْشٍ كَانُوا تِجَارًا بِالشَّأْمِ فِي الْمُدَّةِ الَّتِي مَادَّ فِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَا سُفْيَانَ فِي كُفَّارِ قُرَيْشٍ‏.‏\hadithno{3174}\hadithtrans{Narrated ' `Abdullah bin `Abbas:That Abu Sufyan bin Harb Informed him that Heraclius called him and the members of a caravan from Quraish who had gone to Sham as traders, during the truce which Allah's Messenger (ﷺ) had concluded with Abu Sufyan and the Quraish infidels}}
\hadithdefcmd{bukhari}{3175}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، حَدَّثَنَا هِشَامٌ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُحِرَ حَتَّى كَانَ يُخَيَّلُ إِلَيْهِ أَنَّهُ صَنَعَ شَيْئًا وَلَمْ يَصْنَعْهُ‏.‏\hadithno{3175}\hadithtrans{Narrated Aisha:Once the Prophet (ﷺ) was bewitched so that he began to imagine that he had done a thing which in fact he had not done}}
\hadithdefcmd{bukhari}{3176}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْعَلاَءِ بْنِ زَبْرٍ، قَالَ سَمِعْتُ بُسْرَ بْنَ عُبَيْدِ اللَّهِ، أَنَّهُ سَمِعَ أَبَا إِدْرِيسَ، قَالَ سَمِعْتُ عَوْفَ بْنَ مَالِكٍ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ، وَهْوَ فِي قُبَّةٍ مِنْ أَدَمٍ فَقَالَ ‏ "‏ اعْدُدْ سِتًّا بَيْنَ يَدَىِ السَّاعَةِ، مَوْتِي، ثُمَّ فَتْحُ بَيْتِ الْمَقْدِسِ، ثُمَّ مُوتَانٌ يَأْخُذُ فِيكُمْ كَقُعَاصِ الْغَنَمِ، ثُمَّ اسْتِفَاضَةُ الْمَالِ حَتَّى يُعْطَى الرَّجُلُ مِائَةَ دِينَارٍ فَيَظَلُّ سَاخِطًا، ثُمَّ فِتْنَةٌ لاَ يَبْقَى بَيْتٌ مِنَ الْعَرَبِ إِلاَّ دَخَلَتْهُ، ثُمَّ هُدْنَةٌ تَكُونُ بَيْنَكُمْ وَبَيْنَ بَنِي الأَصْفَرِ فَيَغْدِرُونَ، فَيَأْتُونَكُمْ تَحْتَ ثَمَانِينَ غَايَةً، تَحْتَ كُلِّ غَايَةٍ اثْنَا عَشَرَ أَلْفًا ‏"‏‏.‏\hadithno{3176}\hadithtrans{Narrated `Auf bin Malik:I went to the Prophet (ﷺ) during the Ghazwa of Tabuk while he was sitting in a leather tent. He said, "Count six signs that indicate the approach of the Hour: my death, the conquest of Jerusalem, a plague that will afflict you (and kill you in great numbers) as the plague that afflicts sheep, the increase of wealth to such an extent that even if one is given one hundred Dinars, he will not be satisfied; then an affliction which no Arab house will escape, and then a truce between you and Bani Al-Asfar (i.e. the Byzantines) who will betray you and attack you under eighty flags. Under each flag will be twelve thousand soldiers}}
\hadithdefcmd{bukhari}{3177}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ بَعَثَنِي أَبُو بَكْرٍ ـ رضى الله عنه ـ فِيمَنْ يُؤَذِّنُ يَوْمَ النَّحْرِ بِمِنًى لاَ يَحُجُّ بَعْدَ الْعَامِ مُشْرِكٌ، وَلاَ يَطُوفُ بِالْبَيْتِ عُرْيَانٌ‏.‏ وَيَوْمُ الْحَجِّ الأَكْبَرِ يَوْمُ النَّحْرِ، وَإِنَّمَا قِيلَ الأَكْبَرُ مِنْ أَجْلِ قَوْلِ النَّاسِ الْحَجُّ الأَصْغَرُ‏.‏ فَنَبَذَ أَبُو بَكْرٍ إِلَى النَّاسِ فِي ذَلِكَ الْعَامِ، فَلَمْ يَحُجَّ عَامَ حَجَّةِ الْوَدَاعِ الَّذِي حَجَّ فِيهِ النَّبِيُّ صلى الله عليه وسلم مُشْرِكٌ‏.‏\hadithno{3177}\hadithtrans{Narrated Abu Huraira:Abu Bakr, on the day of Nahr (i.e. slaughtering of animals for sacrifice), sent me in the company of others to make this announcement: "After this year, no pagan will be allowed to perform the Hajj, and none will be allowed to perform the Tawaf of the Ka`ba undressed." And the day of Al-Hajj-ul-Akbar is the day of Nahr, and its called Al-Akbar because the people call the `Umra Al-Hajj-ul-Asghar (i.e. the minor Hajj). Abu Bakr threw back the pagans' covenant that year, and therefore, no pagan performed the Hajj in the year of Hajj-ul-Wada` of the Prophets}}
\hadithdefcmd{bukhari}{3178}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَرْبَعُ خِلاَلٍ مَنْ كُنَّ فِيهِ كَانَ مُنَافِقًا خَالِصًا مَنْ إِذَا حَدَّثَ كَذَبَ، وَإِذَا وَعَدَ أَخْلَفَ، وَإِذَا عَاهَدَ غَدَرَ وَإِذَا خَاصَمَ فَجَرَ، وَمَنْ كَانَتْ فِيهِ خَصْلَةٌ مِنْهُنَّ كَانَتْ فِيهِ خَصْلَةٌ مِنَ النِّفَاقِ حَتَّى يَدَعَهَا ‏"‏‏.‏\hadithno{3178}\hadithtrans{Narrated `Abdullah bin `Amr:Allah's Messenger (ﷺ) said, "Whoever has (the following) four characteristics will be a pure hypocrite: "If he speaks, he tells a lie; if he gives a promise, he breaks it, if he makes a covenant he proves treacherous; and if he quarrels, he behaves in a very imprudent evil insulting manner (unjust). And whoever has one of these characteristics, has one characteristic of a hypocrite, unless he gives it up}}
\hadithdefcmd{bukhari}{3179}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ مَا كَتَبْنَا عَنِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ الْقُرْآنَ، وَمَا فِي هَذِهِ الصَّحِيفَةِ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْمَدِينَةُ حَرَامٌ مَا بَيْنَ عَائِرٍ إِلَى كَذَا، فَمَنْ أَحْدَثَ حَدَثًا، أَوْ آوَى مُحْدِثًا، فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ، لاَ يُقْبَلُ مِنْهُ عَدْلٌ وَلاَ صَرْفٌ، وَذِمَّةُ الْمُسْلِمِينَ وَاحِدَةٌ يَسْعَى بِهَا أَدْنَاهُمْ‏.‏ فَمَنْ أَخْفَرَ مُسْلِمًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ، لاَ يُقْبَلُ مِنْهُ صَرْفٌ وَلاَ عَدْلٌ، وَمَنْ وَالَى قَوْمًا بِغَيْرِ إِذْنِ مَوَالِيهِ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ، لاَ يُقْبَلُ مِنْهُ صَرْفٌ وَلاَ عَدْلٌ ‏"‏‏.‏\hadithno{3179}\hadithtrans{Narrated `Ali:We did not, write anything from the Prophet (ﷺ) except the Qur'an and what is written in this paper, (wherein) the Prophet (ﷺ) said, "Medina is a sanctuary from (the mountain of) Air to so and-so, therefore, whoever innovates (in it) an heresy or commits a sin, or gives shelter to such an innovator, will incur the Curse of Allah. the angels and all the people; and none of his compulsory or optional good deeds of worship will be accepted And the asylum granted by any Muslim Is to be secured by all the Muslims even if it is granted by one of the lowest social status among them. And whoever betrays a Muslim in this respect will incur the Curse of Allah, the angels and all the people, and his compulsory and optional good deeds of worship will not be accepted. And any freed slave who will take as masters (befriends) people other than his own real masters who freed him without taking the permission of the latter, will incur the Curse of Allah, the angels and all the people, and his compulsory and optional good deeds of worship will not be accepted}}
\hadithdefcmd{bukhari}{3180}{قَالَ أَبُو مُوسَى حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا إِسْحَاقُ بْنُ سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ كَيْفَ أَنْتُمْ إِذَا لَمْ تَجْتَبُوا دِينَارًا وَلاَ دِرْهَمًا فَقِيلَ لَهُ وَكَيْفَ تَرَى ذَلِكَ كَائِنًا يَا أَبَا هُرَيْرَةَ قَالَ إِيْ وَالَّذِي نَفْسُ أَبِي هُرَيْرَةَ بِيَدِهِ عَنْ قَوْلِ الصَّادِقِ الْمَصْدُوقِ‏.‏ قَالُوا عَمَّ ذَاكَ قَالَ تُنْتَهَكُ ذِمَّةُ اللَّهِ وَذِمَّةُ رَسُولِهِ صلى الله عليه وسلم، فَيَشُدُّ اللَّهُ عَزَّ وَجَلَّ قُلُوبَ أَهْلِ الذِّمَّةِ، فَيَمْنَعُونَ مَا فِي أَيْدِيهِمْ‏.‏\hadithno{3180}\hadithtrans{Narrated Sa`id:Abu Huraira once said (to the people), "What will your state be when you can get no Dinar or Dirham (i.e. taxes from the Dhimmis)?" on that someone asked him, "What makes you know that this state will take place, O Abu Huraira?" He said, "By Him in Whose Hands Abu Huraira's life is, I know it through the statement of the true and truly inspired one (i.e. the Prophet)." The people asked, "What does the Statement say?" He replied, "Allah and His Apostle's asylum granted to Dhimmis, i.e. non-Muslims living in a Muslim territory) will be outraged, and so Allah will make the hearts of these Dhimmis so daring that they will refuse to pay the Jizya they will be supposed to pay}}
\hadithdefcmd{bukhari}{3181}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا أَبُو حَمْزَةَ، قَالَ سَمِعْتُ الأَعْمَشَ، قَالَ سَأَلْتُ أَبَا وَائِلٍ شَهِدْتَ صِفِّينَ قَالَ نَعَمْ، فَسَمِعْتُ سَهْلَ بْنَ حُنَيْفٍ، يَقُولُ اتَّهِمُوا رَأْيَكُمْ، رَأَيْتُنِي يَوْمَ أَبِي جَنْدَلٍ وَلَوْ أَسْتَطِيعُ أَنْ أَرُدَّ، أَمْرَ النَّبِيِّ صلى الله عليه وسلم لَرَدَدْتُهُ، وَمَا وَضَعْنَا أَسْيَافَنَا عَلَى عَوَاتِقِنَا لأَمْرٍ يُفْظِعُنَا إِلاَّ أَسْهَلْنَ بِنَا إِلَى أَمْرٍ، نَعْرِفُهُ غَيْرِ أَمْرِنَا هَذَا‏.‏\hadithno{3181}\hadithtrans{Narrated Al-A`mash:I asked Abu Wail, "Did you take part in the battle of Siffin?" He said, 'Yes, and I heard Sahl bin Hunaif (when he was blamed for lack of zeal for fighting) saying, "You'd better blame your wrong opinions. I wish you had seen me on the day of Abu Jandal. If I had the courage to disobey the Prophet's orders, I would have done so. We had kept out swords on our necks and shoulders, for a thing which frightened us. And we did so, we found it easier for us, except in the case of the above battle (of ours)}}
\hadithdefcmd{bukhari}{3182}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا يَزِيدُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ أَبِيهِ، حَدَّثَنَا حَبِيبُ بْنُ أَبِي ثَابِتٍ، قَالَ حَدَّثَنِي أَبُو وَائِلٍ، قَالَ كُنَّا بِصِفِّينَ فَقَامَ سَهْلُ بْنُ حُنَيْفٍ فَقَالَ أَيُّهَا النَّاسُ اتَّهِمُوا أَنْفُسَكُمْ فَإِنَّا كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ الْحُدَيْبِيَةِ، وَلَوْ نَرَى قِتَالاً لَقَاتَلْنَا، فَجَاءَ عُمَرُ بْنُ الْخَطَّابِ فَقَالَ يَا رَسُولَ اللَّهِ، أَلَسْنَا عَلَى الْحَقِّ وَهُمْ عَلَى الْبَاطِلِ فَقَالَ ‏"‏ بَلَى ‏"‏‏.‏ فَقَالَ أَلَيْسَ قَتْلاَنَا فِي الْجَنَّةِ وَقَتْلاَهُمْ فِي النَّارِ قَالَ ‏"‏ بَلَى ‏"‏‏.‏ قَالَ فَعَلَى مَا نُعْطِي الدَّنِيَّةَ فِي دِينِنَا أَنَرْجِعُ وَلَمَّا يَحْكُمِ اللَّهُ بَيْنَنَا وَبَيْنَهُمْ فَقَالَ ‏"‏ ابْنَ الْخَطَّابِ، إِنِّي رَسُولُ اللَّهِ، وَلَنْ يُضَيِّعَنِي اللَّهُ أَبَدًا ‏"‏‏.‏ فَانْطَلَقَ عُمَرُ إِلَى أَبِي بَكْرٍ فَقَالَ لَهُ مِثْلَ مَا قَالَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنَّهُ رَسُولُ اللَّهِ، وَلَنْ يُضَيِّعَهُ اللَّهُ أَبَدًا‏.‏ فَنَزَلَتْ سُورَةُ الْفَتْحِ، فَقَرَأَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى عُمَرَ إِلَى آخِرِهَا‏.‏ فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ، أَوَفَتْحٌ هُوَ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏\hadithno{3182}\hadithtrans{Narrated Abu Wail:We were in Siffin and Sahl bin Hunaif got up and said, "O people! Blame yourselves! We were with the Prophet (ﷺ) on the day of Hudaibiya, and if we had been called to fight, we would have fought. But `Umar bin Al-Khattab came and said, 'O Allah's Messenger (ﷺ)! Aren't we in the right and our opponents in the wrong?' Allah's Messenger (ﷺ) said, 'Yes.' `Umar said, 'Aren't our killed persons in Paradise and their's in Hell?' He said, 'Yes.' `Umar said, 'Then why should we accept hard terms in matters concerning our religion? Shall we return before Allah judges between us and them?' Allah's Messenger (ﷺ) said, 'O Ibn Al- Khattab! I am the Messenger of Allah and Allah will never degrade me. Then `Umar went to Abu Bakr and told him the same as he had told the Prophet. On that Abu Bakr said (to `Umar). 'He is the Messenger of Allah and Allah will never degrade him.' Then Surat-al-Fath (i.e. Victory) was revealed and Allah's Messenger (ﷺ) recited it to the end in front of `Umar. On that `Umar asked, 'O Allah's Messenger (ﷺ)! Was it (i.e. the Hudaibiya Treaty) a victory?' Allah's Messenger (ﷺ) said, "Yes}}
\hadithdefcmd{bukhari}{3183}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ ابْنَةِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ قَالَتْ قَدِمَتْ عَلَىَّ أُمِّي وَهْىَ مُشْرِكَةٌ فِي عَهْدِ قُرَيْشٍ، إِذْ عَاهَدُوا رَسُولَ اللَّهِ صلى الله عليه وسلم وَمُدَّتِهِمْ، مَعَ أَبِيهَا، فَاسْتَفْتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ، إِنَّ أُمِّي قَدِمَتْ عَلَىَّ، وَهْىَ رَاغِبَةٌ، أَفَأَصِلُهَا قَالَ ‏ "‏ نَعَمْ، صِلِيهَا ‏"‏‏.‏\hadithno{3183}\hadithtrans{Narrated Asma 'bint Abi Bakr:During the period of the peace treaty of Quraish with Allah's Messenger (ﷺ), my mother, accompanied by her father, came to visit me, and she was a pagan. I consulted Allah's Messenger (ﷺ), "O Allah's Messenger (ﷺ)! My mother has come to me and she desires to receive a reward from me, shall I keep good relation with her?" He said, "Yes, keep good relation with her}}
\hadithdefcmd{bukhari}{3184}{حَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ، حَدَّثَنَا شُرَيْحُ بْنُ مَسْلَمَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ يُوسُفَ بْنِ أَبِي إِسْحَاقَ، قَالَ حَدَّثَنِي أَبِي، عَنْ أَبِي إِسْحَاقَ، قَالَ حَدَّثَنِي الْبَرَاءُ ـ رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا أَرَادَ أَنْ يَعْتَمِرَ أَرْسَلَ إِلَى أَهْلِ مَكَّةَ يَسْتَأْذِنُهُمْ لِيَدْخُلَ مَكَّةَ، فَاشْتَرَطُوا عَلَيْهِ أَنْ لاَ يُقِيمَ بِهَا إِلاَّ ثَلاَثَ لَيَالٍ، وَلاَ يَدْخُلَهَا إِلاَّ بِجُلُبَّانِ السِّلاَحِ، وَلاَ يَدْعُوَ مِنْهُمْ أَحَدًا، قَالَ فَأَخَذَ يَكْتُبُ الشَّرْطَ بَيْنَهُمْ عَلِيُّ بْنُ أَبِي طَالِبٍ، فَكَتَبَ هَذَا مَا قَاضَى عَلَيْهِ مُحَمَّدٌ رَسُولُ اللَّهِ‏.‏ فَقَالُوا لَوْ عَلِمْنَا أَنَّكَ رَسُولُ اللَّهِ لَمْ نَمْنَعْكَ وَلَبَايَعْنَاكَ، وَلَكِنِ اكْتُبْ هَذَا مَا قَاضَى عَلَيْهِ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ‏.‏ فَقَالَ ‏"‏ أَنَا وَاللَّهِ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ وَأَنَا وَاللَّهِ رَسُولُ اللَّهِ ‏"‏‏.‏ قَالَ وَكَانَ لاَ يَكْتُبُ قَالَ فَقَالَ لِعَلِيٍّ ‏"‏ امْحُ رَسُولَ اللَّهِ ‏"‏‏.‏ فَقَالَ عَلِيٌّ وَاللَّهِ لاَ أَمْحَاهُ أَبَدًا‏.‏ قَالَ ‏"‏ فَأَرِنِيهِ ‏"‏‏.‏ قَالَ فَأَرَاهُ إِيَّاهُ، فَمَحَاهُ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ، فَلَمَّا دَخَلَ وَمَضَى الأَيَّامُ أَتَوْا عَلِيًّا فَقَالُوا مُرْ صَاحِبَكَ فَلْيَرْتَحِلْ‏.‏ فَذَكَرَ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ نَعَمْ ‏"‏ ثُمَّ ارْتَحَلَ‏.‏\hadithno{3184}\hadithtrans{Narrated Al-Bara:When the Prophet (ﷺ) intended to perform the `Umra he sent a person to the people of Mecca asking their permission to enter Mecca. They stipulated that he would not stay for more than three days and would not enter it except with sheathed arms and would not preach (Islam) to any of them. So `Ali bin Abi- Talib started writing the treaty between them. He wrote, "This is what Muhammad, Apostle of Allah has agreed to." The (Meccans) said, "If we knew that you (Muhammad) are the Messenger of Allah, then we would not have prevented you and would have followed you. But write, 'This is what Muhammad bin `Abdullah has agreed to..' " On that Allah's Messenger (ﷺ) said, "By Allah, I am Muhammad bin `Abdullah, and, by Allah, I am Apostle of 'Allah." Allah's Messenger (ﷺ) used not to write; so he asked `Ali to erase the expression of Apostle of Allah. On that `Ali said, "By Allah I will never erase it." Allah's Apostle said (to `Ali), "Let me see the paper." When `Ali showed him the paper, the Prophet (ﷺ) erased the expression with his own hand. When Allah's Messenger (ﷺ) had entered Mecca and three days had elapsed, the Meccans came to `Ali and said, "Let your friend (i.e. the Prophet) quit Mecca." `Ali informed Allah's Messenger (ﷺ) about it and Allah's Messenger (ﷺ) said, "Yes," and then he departed}}
\hadithdefcmd{bukhari}{3185}{حَدَّثَنَا عَبْدَانُ بْنُ عُثْمَانَ، قَالَ أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ بَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم سَاجِدٌ وَحَوْلَهُ نَاسٌ مِنْ قُرَيْشٍ مِنَ الْمُشْرِكِينَ إِذْ جَاءَ عُقْبَةُ بْنُ أَبِي مُعَيْطٍ بِسَلَى جَزُورٍ، فَقَذَفَهُ عَلَى ظَهْرِ النَّبِيِّ صلى الله عليه وسلم فَلَمْ يَرْفَعْ رَأْسَهُ حَتَّى جَاءَتْ فَاطِمَةُ ـ عَلَيْهَا السَّلاَمُ ـ فَأَخَذَتْ مِنْ ظَهْرِهِ، وَدَعَتْ عَلَى مَنْ صَنَعَ ذَلِكَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ عَلَيْكَ الْمَلأَ مِنْ قُرَيْشٍ، اللَّهُمَّ عَلَيْكَ أَبَا جَهْلِ بْنَ هِشَامٍ، وَعُتْبَةَ بْنَ رَبِيعَةَ، وَشَيْبَةَ بْنَ رَبِيعَةَ، وَعُقْبَةَ بْنَ أَبِي مُعَيْطٍ، وَأُمَيَّةَ بْنَ خَلَفٍ ـ أَوْ أُبَىَّ بْنَ خَلَفٍ ‏"‏‏.‏ فَلَقَدْ رَأَيْتُهُمْ قُتِلُوا يَوْمَ بَدْرٍ، فَأُلْقُوا فِي بِئْرٍ، غَيْرَ أُمَيَّةَ أَوْ أُبَىٍّ، فَإِنَّهُ كَانَ رَجُلاً ضَخْمًا، فَلَمَّا جَرُّوهُ تَقَطَّعَتْ أَوْصَالُهُ قَبْلَ أَنْ يُلْقَى فِي الْبِئْرِ‏.‏\hadithno{3185}\hadithtrans{Narrated `Abdullah:While the Prophet (ﷺ) was in the state of prostration, surrounded by a group of people from Quraish pagans. `Uqba bin Abi Mu'ait came and brought the intestines of a camel and threw them on the back of the Prophet (ﷺ) . The Prophet (ﷺ) did not raise his head from prostration till Fatima (i.e. his daughter) came and removed those intestines from his back, and invoked evil on whoever had done (the evil deed). The Prophet (ﷺ) said, "O Allah! Destroy the chiefs of Quraish, O Allah! Destroy Abu Jahl bin Hisham, `Utba bin Rabi`a, Shaiba bin Rabi`a, `Uqba bin Abi Mu'ait, Umaiya bin Khalaf (or Ubai bin Khalaf)." Later on I saw all of them killed during the battle of Badr and their bodies were thrown into a well except the body of Umaiya or Ubai, because he was a fat person, and when he was pulled, the parts of his body got separated before he was thrown into the well}}
\hadithdefcmd{bukhari}{3186}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ‏.‏وَعَنْ ثَابِتٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لِكُلِّ غَادِرٍ لِوَاءٌ يَوْمَ الْقِيَامَةِ ـ قَالَ أَحَدُهُمَا يُنْصَبُ وَقَالَ الآخَرُ ـ يُرَى يَوْمَ الْقِيَامَةِ يُعْرَفُ بِهِ ‏"‏‏.‏\hadithno{3186}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, ''Every betrayer will have a flag on the Day of Resurrection" One of the two subnarrators said that the flag would be fixed, and the other said that it would be shown on the Day of Resurrection, so that the betrayer might be recognized by it}}
\hadithdefcmd{bukhari}{3188}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لِكُلِّ غَادِرٍ لِوَاءٌ يُنْصَبُ لِغَدْرَتِهِ ‏"‏‏.‏\hadithno{3188}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "Every betrayer will have a flag which will be fixed on the Day of Resurrection, and the flag's prominence will be made in order to show the betrayal he committed}}
\hadithdefcmd{bukhari}{3189}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ فَتْحِ مَكَّةَ ‏"‏ لاَ هِجْرَةَ وَلَكِنْ جِهَادٌ وَنِيَّةٌ، وَإِذَا اسْتُنْفِرْتُمْ فَانْفِرُوا ‏"‏‏.‏ وَقَالَ يَوْمَ فَتْحِ مَكَّةَ ‏"‏ إِنَّ هَذَا الْبَلَدَ حَرَّمَهُ اللَّهُ يَوْمَ خَلَقَ السَّمَوَاتِ وَالأَرْضَ، فَهْوَ حَرَامٌ بِحُرْمَةِ اللَّهِ إِلَى يَوْمِ الْقِيَامَةِ، وَإِنَّهُ لَمْ يَحِلَّ الْقِتَالُ فِيهِ لأَحَدٍ قَبْلِي، وَلَمْ يَحِلَّ لِي إِلاَّ سَاعَةً مِنْ نَهَارٍ، فَهْوَ حَرَامٌ بِحُرْمَةِ اللَّهِ إِلَى يَوْمِ الْقِيَامَةِ، لاَ يُعْضَدُ شَوْكُهُ، وَلاَ يُنَفَّرُ صَيْدُهُ، وَلاَ يَلْتَقِطُ لُقَطَتَهُ إِلاَّ مَنْ عَرَّفَهَا، وَلاَ يُخْتَلَى خَلاَهُ ‏"‏‏.‏ فَقَالَ الْعَبَّاسُ يَا رَسُولَ اللَّهِ إِلاَّ الإِذْخِرَ، فَإِنَّهُ لِقَيْنِهِمْ وَلِبُيُوتِهِمْ‏.‏ قَالَ ‏"‏ إِلاَّ الإِذْخِرَ ‏"‏‏.‏\hadithno{3189}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) said on the day of the conquest of Mecca, "There is no migration now, but there is Jihad (i.e.. holy battle) and good intentions. And when you are called for Jihad, you should come out at once" Allah's Messenger (ﷺ) also said, on the day of the conquest of Mecca, "Allah has made this town a sanctuary since the day He created the Heavens and the Earth. So, it is a sanctuary by Allah's Decree till the Day of Resurrection. Fighting in it was not legal for anyone before me, and it was made legal for me only for an hour by daytime. So, it (i.e. Mecca) is a sanctuary by Allah's Decree till the Day of Resurrection. Its thorny bushes should not be cut, and its game should not be chased, its fallen property (i.e. Luqata) should not be picked up except by one who will announce it publicly; and its grass should not be uprooted," On that Al-`Abbas said, "O Allah's Messenger (ﷺ)! Except the Idhkhir, because it is used by the goldsmiths and by the people for their houses." On that the Prophet (ﷺ) said, "Except the Idhkhir}}
