% Auto-generated chapter 23 for muslim
% Hadiths in this chapter: 23

\hadithdefcmd{muslim}{4140}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ - وَاللَّفْظُ لِيَحْيَى - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ، حُسَيْنٍ عَنْ عَمْرِو بْنِ عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَرِثُ الْمُسْلِمُ الْكَافِرَ وَلاَ يَرِثُ الْكَافِرُ الْمُسْلِمَ ‏"‏ ‏.‏\hadithno{4140}\hadithtrans{Usama b. Zaid reported Allah's Messenger (ﷺ) as saying:A Muslim is not entitled to inherit from a non-Muslim, and a non-Muslim is not entitled to inherit from a Muslim}}
\hadithdefcmd{muslim}{4141}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، - وَهُوَ النَّرْسِيُّ - حَدَّثَنَا وُهَيْبٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلْحِقُوا الْفَرَائِضَ بِأَهْلِهَا فَمَا بَقِيَ فَهُوَ لأَوْلَى رَجُلٍ ذَكَرٍ ‏"‏ ‏.‏\hadithno{4141}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:Give the shares to those who are entitled to them, and what remains over goes to the nearest male heir}}
\hadithdefcmd{muslim}{4142}{حَدَّثَنَا أُمَيَّةُ بْنُ بِسْطَامَ الْعَيْشِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا رَوْحُ بْنُ الْقَاسِمِ، عَنْ عَبْدِ اللَّهِ بْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَلْحِقُوا الْفَرَائِضَ بِأَهْلِهَا فَمَا تَرَكَتِ الْفَرَائِضُ فَلأَوْلَى رَجُلٍ ذَكَرٍ ‏"‏ ‏.‏\hadithno{4142}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:Give the shares to those who are entitled to them, and what is left from those wno are entitled to it goes to the nearest male heir}}
\hadithdefcmd{muslim}{4143}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَاللَّفْظُ لاِبْنِ رَافِعٍ - قَالَ إِسْحَاقُ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْسِمُوا الْمَالَ بَيْنَ أَهْلِ الْفَرَائِضِ عَلَى كِتَابِ اللَّهِ فَمَا تَرَكَتِ الْفَرَائِضُ فَلأَوْلَى رَجُلٍ ذَكَرٍ ‏"‏ ‏.‏\hadithno{4143}\hadithtrans{Tawus reported on the authority of Ibn Abbas (Allah be pleased with them) narrating that Allah's Messenger (ﷺ) said:Distribute the property amongst Ahl al-Fara'id, according to the Book of Allah, and what is left out of them goes to the nearest male heir}}
\hadithdefcmd{muslim}{4144}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ الْعَلاَءِ أَبُو كُرَيْبٍ الْهَمْدَانِيُّ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ يَحْيَى، بْنِ أَيُّوبَ عَنِ ابْنِ طَاوُسٍ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ وُهَيْبٍ وَرَوْحِ بْنِ الْقَاسِمِ ‏.‏\hadithno{4144}\hadithtrans{There is another chain of Tawus reporting like the reports that were mentioned before the previous hadith chain through Tawus (the chains of Wuhaib and Rowh bin Qasim)}}
\hadithdefcmd{muslim}{4145}{حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدِ بْنِ بُكَيْرٍ النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ، الْمُنْكَدِرِ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ مَرِضْتُ فَأَتَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ يَعُودَانِي مَاشِيَيْنِ فَأُغْمِيَ عَلَىَّ فَتَوَضَّأَ ثُمَّ صَبَّ عَلَىَّ مِنْ وَضُوئِهِ فَأَفَقْتُ قُلْتُ يَا رَسُولَ اللَّهِ كَيْفَ أَقْضِي فِي مَالِي فَلَمْ يَرُدَّ عَلَىَّ شَيْئًا حَتَّى نَزَلَتْ آيَةُ الْمِيرَاثِ ‏\{‏ يَسْتَفْتُونَكَ قُلِ اللَّهُ يُفْتِيكُمْ فِي الْكَلاَلَةِ‏\}‏\hadithno{4145}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:I fell sick and there came to me on foot Allah's Messenger (ﷺ) and Abu Bakr for inquiring after my health. I fainted. He (the Holy Prophet) performed ablution and then sprinkled over me the water of his ablution. I felt some relief and said: Allah's Messenger, how should I decide about my property? He said nothing to me in response until this verse pertaining to the law of inheritance was revealed:" They ask you for a decision; say: Allah gives you a decision concerning the person who has neither parents nor children" (iv)}}
\hadithdefcmd{muslim}{4146}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي ابْنُ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ عَادَنِي النَّبِيُّ صلى الله عليه وسلم وَأَبُو بَكْرٍ فِي بَنِي سَلَمَةَ يَمْشِيَانِ فَوَجَدَنِي لاَ أَعْقِلُ فَدَعَا بِمَاءٍ فَتَوَضَّأَ ثُمَّ رَشَّ عَلَىَّ مِنْهُ فَأَفَقْتُ فَقُلْتُ كَيْفَ أَصْنَعُ فِي مَالِي يَا رَسُولَ اللَّهِ فَنَزَلَتْ ‏\{‏يُوصِيكُمُ اللَّهُ فِي أَوْلاَدِكُمْ لِلذَّكَرِ مِثْلُ حَظِّ الأُنْثَيَيْنِ‏\}‏\hadithno{4146}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with him) reported:Allah's Apostle (ﷺ) and Abi Bakr (Allah be pleased with him) visited me on foot in Banu Salama, and found me unconscious. He (the Holy Prophet) called for water and performed ablution and sprinkled out of it (the water) over me. I felt relieved. I said: Allah's Messenger, what should I do with my property? And this verse was revealed:" Allah enjoins you concerning your children: for the male is equal of the portion of two females}}
\hadithdefcmd{muslim}{4147}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ الْمُنْكَدِرِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ عَادَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا مَرِيضٌ وَمَعَهُ أَبُو بَكْرٍ مَاشِيَيْنِ فَوَجَدَنِي قَدْ أُغْمِيَ عَلَىَّ فَتَوَضَّأَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَبَّ عَلَىَّ مِنْ وَضُوئِهِ فَأَفَقْتُ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ كَيْفَ أَصْنَعُ فِي مَالِي فَلَمْ يَرُدَّ عَلَىَّ شَيْئًا حَتَّى نَزَلَتْ آيَةُ الْمِيرَاثِ ‏.‏\hadithno{4147}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:While I had been ill Allah's Messenger (ﷺ) visited me and Abu akr (Allah be pleased with him) was with him, and they both came walking on foot. He (the Holy Prophet) found me unconscious. Allahs Messenger (ﷺ) performed ablution and then sprinkled over me the water of his ablution. I felt relieved regained my consciousness) and found Allah's Messenger (ﷺ) there. I said: Allah's Messenger, what should I do with my property? He gave me no reply until the verse (iv. 177) relating to the law of inheritance was revealed}}
\hadithdefcmd{muslim}{4148}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي مُحَمَّدُ بْنُ الْمُنْكَدِرِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا مَرِيضٌ لاَ أَعْقِلُ فَتَوَضَّأَ فَصَبُّوا عَلَىَّ مِنْ وَضُوئِهِ فَعَقَلْتُ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّمَا يَرِثُنِي كَلاَلَةٌ ‏.‏ فَنَزَلَتْ آيَةُ الْمِيرَاثِ ‏.‏ فَقُلْتُ لِمُحَمَّدِ بْنِ الْمُنْكَدِرِ ‏\{‏ يَسْتَفْتُونَكَ قُلِ اللَّهُ يُفْتِيكُمْ فِي الْكَلاَلَةِ‏\}‏ قَالَ هَكَذَا أُنْزِلَتْ\hadithno{4148}\hadithtrans{Jabir b. Abdullah (Allah be pleased with him) reported:Whilo I was ill Allah's Messenger (ﷺ) came to me and found me unconscious. He (the Holy Prophet) performed ablution, and sprinkled over me the water of his ablution. I regained my consciousness and said: Allah's Messenger, my case of inheritance is that of Kalala. Then the verse pertaining to the inheritance ( of Kalala) was revealed. I (one of the narrators) said: I said to Muhammad b. Munkadir: (Do you mean this verse)" They ask you; say: Allah gives you decision in regard to Kalala" (iv. 177)? He said: Yes, it was thus revealed}}
\hadithdefcmd{muslim}{4149}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، وَأَبُو عَامِرٍ الْعَقَدِيُّ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، كُلُّهُمْ عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ ‏.‏ فِي حَدِيثِ وَهْبِ بْنِ جَرِيرٍ فَنَزَلَتْ آيَةُ الْفَرَائِضِ ‏.‏ وَفِي حَدِيثِ النَّضْرِ وَالْعَقَدِيِّ فَنَزَلَتْ آيَةُ الْفَرْضِ ‏.‏ وَلَيْسَ فِي رِوَايَةِ أَحَدٍ مِنْهُمْ قَوْلُ شُعْبَةَ لاِبْنِ الْمُنْكَدِرِ ‏.‏\hadithno{4149}\hadithtrans{This hadith is transmitted on the authority of Shu'ba but with a slight variation of words}}
\hadithdefcmd{muslim}{4150}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ، أَبِي طَلْحَةَ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، خَطَبَ يَوْمَ جُمُعَةٍ فَذَكَرَ نَبِيَّ اللَّهِ صلى الله عليه وسلم وَذَكَرَ أَبَا بَكْرٍ ثُمَّ قَالَ إِنِّي لاَ أَدَعُ بَعْدِي شَيْئًا أَهَمَّ عِنْدِي مِنَ الْكَلاَلَةِ مَا رَاجَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي شَىْءٍ مَا رَاجَعْتُهُ فِي الْكَلاَلَةِ وَمَا أَغْلَظَ لِي فِي شَىْءٍ مَا أَغْلَظَ لِي فِيهِ حَتَّى طَعَنَ بِإِصْبَعِهِ فِي صَدْرِي وَقَالَ ‏ "‏ يَا عُمَرُ أَلاَ تَكْفِيكَ آيَةُ الصَّيْفِ الَّتِي فِي آخِرِ سُورَةِ النِّسَاءِ ‏"‏ ‏.‏ وَإِنِّي إِنْ أَعِشْ أَقْضِ فِيهَا بِقَضِيَّةٍ يَقْضِي بِهَا مَنْ يَقْرَأُ الْقُرْآنَ وَمَنْ لاَ يَقْرَأُ الْقُرْآنَ ‏.‏\hadithno{4150}\hadithtrans{Abu Talha reported:'Umar b. al-Khattab (Allah be pleased with him) delivered a sermon on Friday and made a mention of Allah's Apostle (ﷺ) and he also made a mention of Abu Bakr (Allah be pleased with him) and then said: I do not leave behind me any problem more difficult than that of Kalala. I did not refer to Allah's Messenger (ﷺ) more repeatedly than in case of the problem of Kalala, and he (the Holy Prophet) never showed more annoyance to me than in regard to this problem, so much so that he struck my chest with his fingers and said: 'Umar, does the verse revealed in summer season, at the end of Sura al-Nisa' not suffice you? Hadrat 'Umar (then) said: If I live I would give such verdict about (Kalala) that everyone would be able to decide whether he reads the Qur'an or he does not}}
\hadithdefcmd{muslim}{4151}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ، رَافِعٍ عَنْ شَبَابَةَ بْنِ سَوَّارٍ، عَنْ شُعْبَةَ، كِلاَهُمَا عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{4151}\hadithtrans{This hadith has been narrated on the authority of Qatada with the same chain of transmitters}}
\hadithdefcmd{muslim}{4152}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي خَالِدٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ آخِرُ آيَةٍ أُنْزِلَتْ مِنَ الْقُرْآنِ ‏\{‏ يَسْتَفْتُونَكَ قُلِ اللَّهُ يُفْتِيكُمْ فِي الْكَلاَلَةِ‏\}‏\hadithno{4152}\hadithtrans{Al-Bara' (Allah be pleased with him) reported that the last verse revealed in the Holy Qur'an is:" They ask thee for a religious verdict; say: Allah gives you a religious verdict about Kalala (the person who has neither parents nor children)" (iv)}}
\hadithdefcmd{muslim}{4153}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ، يَقُولُ آخِرُ آيَةٍ أُنْزِلَتْ آيَةُ الْكَلاَلَةِ وَآخِرُ سُورَةٍ أُنْزِلَتْ بَرَاءَةُ ‏.‏\hadithno{4153}\hadithtrans{Abu Ishaq said that he heard al-Bara' b. 'Azib (Allah be pleased with him say:The last verse revealed (in the Holy Quran) is that pertaining to Kalala, and the last sura revealed is Sura al-Bara'at}}
\hadithdefcmd{muslim}{4154}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا عِيسَى، - وَهُوَ ابْنُ يُونُسَ - حَدَّثَنَا زَكَرِيَّاءُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، أَنَّ آخِرَ، سُورَةٍ أُنْزِلَتْ تَامَّةً سُورَةُ التَّوْبَةِ وَأَنَّ آخِرَ آيَةٍ أُنْزِلَتْ آيَةُ الْكَلاَلَةِ ‏.‏\hadithno{4154}\hadithtrans{Abu Ishaq said that he heard al-Bara' b. 'Azib (Allah be pleased with him) say:The last complete sura revealed (in the Holy Qur'an) is Sura Tauba (i e. al-Bara'at, ix.), and the last verse revealed is that pertaining to Kalala}}
\hadithdefcmd{muslim}{4155}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ آدَمَ - حَدَّثَنَا عَمَّارٌ، - وَهُوَ ابْنُ رُزَيْقٍ - عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ آخِرُ سُورَةٍ أُنْزِلَتْ كَامِلَةً ‏.‏\hadithno{4155}\hadithtrans{Aba Ishaq reported this hadith on the authority of al-Bara' (Allah be pleased with him) with a slight variation of words, viz. the last sura that was revealed complete}}
\hadithdefcmd{muslim}{4156}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا مَالِكُ بْنُ مِغْوَلٍ، عَنْ أَبِي، السَّفَرِ عَنِ الْبَرَاءِ، قَالَ آخِرُ آيَةٍ أُنْزِلَتْ يَسْتَفْتُونَكَ ‏.‏\hadithno{4156}\hadithtrans{Al-Bara' (Allah be pleased with him) reported that the last verse revealed was:" They ask of thee religious verdict.." (iv)}}
\hadithdefcmd{muslim}{4157}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا أَبُو صَفْوَانَ الأُمَوِيُّ، عَنْ يُونُسَ الأَيْلِيِّ، ح وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ، شِهَابٍ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُؤْتَى بِالرَّجُلِ الْمَيِّتِ عَلَيْهِ الدَّيْنُ فَيَسْأَلُ ‏"‏ هَلْ تَرَكَ لِدَيْنِهِ مِنْ قَضَاءٍ ‏"‏ ‏.‏ فَإِنْ حُدِّثَ أَنَّهُ تَرَكَ وَفَاءً صَلَّى عَلَيْهِ وَإِلاَّ قَالَ ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ ‏"‏ ‏.‏ فَلَمَّا فَتَحَ اللَّهُ عَلَيْهِ الْفُتُوحَ قَالَ ‏"‏ أَنَا أَوْلَى بِالْمُؤْمِنِينَ مِنْ أَنْفُسِهِمْ فَمَنْ تُوُفِّيَ وَعَلَيْهِ دَيْنٌ فَعَلَىَّ قَضَاؤُهُ وَمَنْ تَرَكَ مَالاً فَهُوَ لِوَرَثَتِهِ ‏"‏ ‏.‏\hadithno{4157}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that when the body of a dead person having burden of debt upon him was brought to Allah's Messenger (ﷺ) he would ask whether he had left property enough to clear off his debt, and if the property left had been sufficient for that (purpose), he observed funeral prayer for him, otherwise he said (to his companions):You observe prayer for your companion. But when Allah opened the gateways of victory for him, he said: I am nearer to the believers than themselves, so if anyone dies leaving a debt, its payment is my responsibility, and if anyone leaves a property, it goes to his heirs}}
\hadithdefcmd{muslim}{4158}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلٌ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَخِي ابْنِ شِهَابٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ هَذَا الْحَدِيثَ ‏.‏\hadithno{4158}\hadithtrans{This hadith has been narrated on the authority of al-Zuhri through another chain of transmitters}}
\hadithdefcmd{muslim}{4159}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا شَبَابَةُ، قَالَ حَدَّثَنِي وَرْقَاءُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ إِنْ عَلَى الأَرْضِ مِنْ مُؤْمِنٍ إِلاَّ أَنَا أَوْلَى النَّاسِ بِهِ فَأَيُّكُمْ مَا تَرَكَ دَيْنًا أَوْ ضَيَاعًا فَأَنَا مَوْلاَهُ وَأَيُّكُمْ تَرَكَ مَالاً فَإِلَى الْعَصَبَةِ مَنْ كَانَ ‏"‏ ‏.‏\hadithno{4159}\hadithtrans{Abn Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) having said this:By Him in Whose Hand is the life of Muhammad, there is no believer on the earth with whom I am not the nearest among all the people. He who amongst you (dies) and leaves a debt, I am there to pay it, and he who amongst you (dies) leaving behind children I am there to look after them. And he who amongst You leaves behind property, that is for the inheritor whoever he is}}
\hadithdefcmd{muslim}{4160}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا أَوْلَى النَّاسِ بِالْمُؤْمِنِينَ فِي كِتَابِ اللَّهِ عَزَّ وَجَلَّ فَأَيُّكُمْ مَا تَرَكَ دَيْنًا أَوْ ضَيْعَةً فَادْعُونِي فَأَنَا وَلِيُّهُ وَأَيُّكُمْ مَا تَرَكَ مَالاً فَلْيُؤْثَرْ بِمَالِهِ عَصَبَتُهُ مَنْ كَانَ ‏"‏ ‏.‏\hadithno{4160}\hadithtrans{Hammam b. Munabbih reported:This is what Abu Huraira (Allah be pleased with him) narrated to us from Allah's Messenger (may peace he upon him). And he narrated many ahadith, and one was this: Allah's Messenger (may peace be upon him said: I am, according to the Book of Allah, the Exalted and Majestic, nearest to the believers of all the human beings. So whoever amongst you dies in debt or leaves behind destitute children, you should call me (for help) ), for I am his guardian. And who amongst you leaves property, his inheritor is entitled to get it, whoever he is}}
\hadithdefcmd{muslim}{4161}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، أَنَّهُ سَمِعَ أَبَا حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ تَرَكَ مَالاً فَلِلْوَرَثَةِ وَمَنْ تَرَكَ كَلاًّ فَإِلَيْنَا ‏"‏ ‏.‏\hadithno{4161}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:He who leaves property, that is for the inheritors; and he who leaves behind destitute children, then it is my responsibility (to look after them)}}
\hadithdefcmd{muslim}{4162}{وَحَدَّثَنِيهِ أَبُو بَكْرِ بْنُ نَافِعٍ، حَدَّثَنَا غُنْدَرٌ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ، الرَّحْمَنِ - يَعْنِي ابْنَ مَهْدِيٍّ - قَالاَ حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ ‏.‏ غَيْرَ أَنَّ فِي، حَدِيثِ غُنْدَرٍ ‏ "‏ وَمَنْ تَرَكَ كَلاًّ وَلِيتُهُ ‏"‏ ‏.‏\hadithno{4162}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters}}
