% Auto-generated chapter 26 for ibnmajah
% Hadiths in this chapter: 42

\hadithdefcmd{ibnmajah}{3120}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنِي أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يُضَحِّي بِكَبْشَيْنِ أَمْلَحَيْنِ أَقْرَنَيْنِ وَيُسَمِّي وَيُكَبِّرُ وَلَقَدْ رَأَيْتُهُ يَذْبَحُ بِيَدِهِ وَاضِعًا قَدَمَهُ عَلَى صِفَاحِهِمَا ‏.‏\hadithno{3120}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik:“The Messenger of Allah (ﷺ) used to sacrifice two horned, black-and-white rams and he would say the Name of Allah and pronounce His greatness. I saw him slaughtering them with his own hand, putting his foot on their sides.”}}
\hadithdefcmd{ibnmajah}{3121}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي عَيَّاشٍ الزُّرَقِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ ضَحَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمَ عِيدٍ بِكَبْشَيْنِ فَقَالَ حِينَ وَجَّهَهُمَا ‏ "‏ إِنِّي وَجَّهْتُ وَجْهِيَ لِلَّذِي فَطَرَ السَّمَوَاتِ وَالأَرْضَ حَنِيفًا وَمَا أَنَا مِنَ الْمُشْرِكِينَ إِنَّ صَلاَتِي وَنُسُكِي وَمَحْيَاىَ وَمَمَاتِي لِلَّهِ رَبِّ الْعَالَمِينَ لاَ شَرِيكَ لَهُ وَبِذَلِكَ أُمِرْتُ وَأَنَا أَوَّلُ الْمُسْلِمِينَ اللَّهُمَّ مِنْكَ وَلَكَ عَنْ مُحَمَّدٍ وَأُمَّتِهِ ‏"‏ ‏.‏\hadithno{3121}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) sacrificed two rams on the Day of ‘Eid. When he turned them to face towards the prayer direction he said: ‘Verily, I have turned my face towards Him Who has created the heavens and the earth, as a monotheist, and I am not of the polytheists. Verily, my prayer, my sacrifice, my living, and my dying are for Allah, the Lord of all that exists. He has no partner. And of this I have been commanded, and I am the first of the Muslims. [6:79,162-163] O Allah, from You to You, on behalf of Muhammad and his nation.’”}}
\hadithdefcmd{ibnmajah}{3122}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، وَعَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ إِذَا أَرَادَ أَنْ يُضَحِّيَ اشْتَرَى كَبْشَيْنِ عَظِيمَيْنِ سَمِينَيْنِ أَقْرَنَيْنِ أَمْلَحَيْنِ مَوْجُوءَيْنِ فَذَبَحَ أَحَدَهُمَا عَنْ أُمَّتِهِ لِمَنْ شَهِدَ لِلَّهِ بِالتَّوْحِيدِ وَشَهِدَ لَهُ بِالْبَلاَغِ وَذَبَحَ الآخَرَ عَنْ مُحَمَّدٍ وَعَنْ آلِ مُحَمَّدٍ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{3122}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Aishah and Abu Hurairah that when the Messenger of Allah (ﷺ) wanted to offer a sacrifice, he brought two large, fat, horned, black-and-white, castrated rams. He slaughtered one on behalf of his nation, for whoever testified to Allah with monotheism and that he had conveyed (the Message), and he slaughtered the other on behalf of Muhammad and the family of Muhammad (ﷺ)}}
\hadithdefcmd{ibnmajah}{3123}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَيَّاشٍ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ كَانَ لَهُ سَعَةٌ وَلَمْ يُضَحِّ فَلاَ يَقْرَبَنَّ مُصَلاَّنَا ‏"‏ ‏.‏\hadithno{3123}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever can afford it, but does not offer a sacrifice, let him not come near our prayer place.”}}
\hadithdefcmd{ibnmajah}{3124}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ سَأَلْتُ ابْنَ عُمَرَ عَنِ الضَّحَايَا، أَوَاجِبَةٌ هِيَ قَالَ ضَحَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَالْمُسْلِمُونَ مِنْ بَعْدِهِ وَجَرَتْ بِهِ السُّنَّةُ ‏.‏ حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا الْحَجَّاجُ بْنُ أَرْطَاةَ، حَدَّثَنَا جَبَلَةُ بْنُ سُحَيْمٍ، قَالَ سَأَلْتُ ابْنَ عُمَرَ ‏.‏ فَذَكَرَ مِثْلَهُ سَوَاءً ‏.‏\hadithno{3124}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Muhammad bin Sirin said:“I asked Ibn ‘Umar about sacrifices and whether they are obligatory. He said: ‘The Messenger of Allah (ﷺ) and the Muslims after him offered sacrifices, and this is the Sunnah.’” Another chain reports exactly the same}}
\hadithdefcmd{ibnmajah}{3125}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، عَنِ ابْنِ عَوْنٍ، قَالَ أَنْبَأَنَا أَبُو رَمْلَةَ، عَنْ مِخْنَفِ بْنِ سُلَيْمٍ، قَالَ كُنَّا وُقُوفًا عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِعَرَفَةَ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ إِنَّ عَلَى كُلِّ أَهْلِ بَيْتٍ فِي كُلِّ عَامٍ أُضْحِيَّةً وَعَتِيرَةً ‏"‏ ‏.‏ أَتَدْرُونَ مَا الْعَتِيرَةُ هِيَ الَّتِي يُسَمِّيهَا النَّاسُ الرَّجَبِيَّةَ ‏.‏\hadithno{3125}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Mikhnaf bin Sulaim said:“We were standing with the Prophet (ﷺ) at ‘Arafat and he said: ‘O people, each family, each year, must offer Udhiyah and ‘Atirah.’}}
\hadithdefcmd{ibnmajah}{3126}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ، حَدَّثَنِي أَبُو الْمُثَنَّى، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا عَمِلَ ابْنُ آدَمَ يَوْمَ النَّحْرِ عَمَلاً أَحَبَّ إِلَى اللَّهِ عَزَّ وَجَلَّ مِنْ هِرَاقَةِ دَمٍ وَإِنَّهُ لَيَأْتِي يَوْمَ الْقِيَامَةِ بِقُرُونِهَا وَأَظْلاَفِهَا وَأَشْعَارِهَا وَإِنَّ الدَّمَ لَيَقَعُ مِنَ اللَّهِ عَزَّ وَجَلَّ بِمَكَانٍ قَبْلَ أَنْ يَقَعَ عَلَى الأَرْضِ فَطِيبُوا بِهَا نَفْسًا ‏"‏ ‏.‏\hadithno{3126}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ’Aishah that the Prophet (ﷺ) said:“The son of Adam does not do any deed on the Day of Sacrifice that is dearer to Allah than shedding blood. It will come on the Day of Resurrection with its horns and cloven hoofs and hair. Its blood is accepted by Allah before it reaches the ground. So be content when you do it.”}}
\hadithdefcmd{ibnmajah}{3127}{حَدَّثَنَا مُحَمَّدُ بْنُ خَلَفٍ الْعَسْقَلاَنِيُّ، حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا سَلاَّمُ بْنُ مِسْكِينٍ، حَدَّثَنَا عَائِذُ اللَّهِ، عَنْ أَبِي دَاوُدَ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ قَالَ أَصْحَابُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ يَا رَسُولَ اللَّهِ مَا هَذِهِ الأَضَاحِيُّ قَالَ ‏"‏ سُنَّةُ أَبِيكُمْ إِبْرَاهِيمَ ‏"‏ ‏.‏ قَالُوا فَمَا لَنَا فِيهَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ بِكُلِّ شَعَرَةٍ حَسَنَةٌ ‏"‏ ‏.‏ قَالُوا فَالصُّوفُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ بِكُلِّ شَعَرَةٍ مِنَ الصُّوفِ حَسَنَةٌ ‏"‏ ‏.‏\hadithno{3127}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Zaid bin Arqam said:“The Companions of the Messenger of Allah (ﷺ) said: ‘O Messenger of Allah, what are these sacrifices?’ He said: ‘The Sunnah of your father Ibrahim.’ They said: ‘What is there for us in them, O Messenger of Allah?’ He said: ‘For every hair, one merit.’ They said: ‘What about wool, O Messenger of Allah?’ He said: ‘For every hair of wool, one merit.’”}}
\hadithdefcmd{ibnmajah}{3128}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ، قَالَ ضَحَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِكَبْشٍ أَقْرَنَ فَحِيلٍ يَأْكُلُ فِي سَوَادٍ وَيَمْشِي فِي سَوَادٍ وَيَنْظُرُ فِي سَوَادٍ ‏.‏\hadithno{3128}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa’eed said:“The Messenger of Allah (ﷺ) sacrificed a horned, defectless ram with a black stomach, black feet and black around its eyes.”}}
\hadithdefcmd{ibnmajah}{3129}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، أَخْبَرَنِي سَعِيدُ بْنُ عَبْدِ الْعَزِيزِ، حَدَّثَنَا يُونُسُ بْنُ مَيْسَرَةَ بْنِ حَلْبَسٍ، قَالَ خَرَجْنَا مَعَ أَبِي سَعِيدٍ الزُّرَقِيِّ - صَاحِبِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ - إِلَى شِرَاءِ الضَّحَايَا ‏.‏ قَالَ يُونُسُ فَأَشَارَ أَبُو سَعِيدٍ إِلَى كَبْشٍ أَدْغَمَ لَيْسَ بِالْمُرْتَفِعِ وَلاَ الْمُتَّضِعِ فِي جِسْمِهِ فَقَالَ لِي اشْتَرِ لِي هَذَا ‏.‏ كَأَنَّهُ شَبَّهَهُ بِكَبْشِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{3129}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Yunus bin Maisarah bin Halbas said:“I went out with Abu Sa’eed Az- Zuraqi, the Companion of the Messenger of Allah (ﷺ), to buy animals or sacrifice.” Yunus said: “Abu Sa’eed pointed to a ram that had some blackness around its ears and jaw, and was neither too big nor too small, and said to me: ‘Buy this one for them, as it seems to resemble the ram of the Messenger of Allah (ﷺ).’”}}
\hadithdefcmd{ibnmajah}{3130}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا أَبُو عَائِذٍ، أَنَّهُ سَمِعَ سُلَيْمَ بْنَ عَامِرٍ، يُحَدِّثُ عَنْ أَبِي أُمَامَةَ الْبَاهِلِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ خَيْرُ الْكَفَنِ الْحُلَّةُ وَخَيْرُ الضَّحَايَا الْكَبْشُ الأَقْرَنُ ‏"‏ ‏.‏\hadithno{3130}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Umamah Al-Bahili that the Messenger of Allah (ﷺ) said:“The best of shrouds is a two piece Najrani garment and the best of sacrifices is a horned ram.”}}
\hadithdefcmd{ibnmajah}{3131}{حَدَّثَنَا هَدِيَّةُ بْنُ عَبْدِ الْوَهَّابِ، أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، أَنْبَأَنَا الْحُسَيْنُ بْنُ وَاقِدٍ، عَنْ عِلْبَاءَ بْنِ أَحْمَرَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي سَفَرٍ فَحَضَرَ الأَضْحَى فَاشْتَرَكْنَا فِي الْجَزُورِ عَنْ عَشَرَةٍ وَالَبَقَرَةِ عَنْ سَبْعَةٍ ‏.‏\hadithno{3131}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{it was narrated that Ibn ‘Abbas said:“We were with the Messenger of Allah (ﷺ) on a journey, and the (day of) Al-Adha came. We (sacrificed) one camel on behalf of ten (people) and one cow on behalf of seven.”}}
\hadithdefcmd{ibnmajah}{3132}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَحَرْنَا بِالْحُدَيْبِيَةِ مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ الْبَدَنَةَ عَنْ سَبْعَةٍ وَالْبَقَرَةَ عَنْ سَبْعَةٍ ‏.‏\hadithno{3132}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:“We offered sacrifices at Al- Hudaibiyah with the Prophet (ﷺ), a camel on behalf of seven (people) and a cow on behalf of seven.”}}
\hadithdefcmd{ibnmajah}{3133}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ذَبَحَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَمَّنِ اعْتَمَرَ مِنْ نِسَائِهِ فِي حَجَّةِ الْوَدَاعِ بَقَرَةً بَيْنَهُنَّ ‏.‏\hadithno{3133}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) slaughtered a cow on behalf of all his wives who had performed ‘Umrah, during the Farewell Pilgrimage.”}}
\hadithdefcmd{ibnmajah}{3134}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ أَبِي حَاضِرٍ الأَزْدِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَلَّتِ الإِبِلُ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَأَمَرَهُمْ أَنْ يَنْحَرُوا الْبَقَرَ ‏.‏\hadithno{3134}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn ‘Abbas said:“Camels became scarce at the time of the Messenger of Allah (ﷺ), so he commanded them to sacrifice cows.”}}
\hadithdefcmd{ibnmajah}{3135}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ أَبُو طَاهِرٍ، أَنْبَأَنَا ابْنُ وَهْبٍ، أَنْبَأَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَحَرَ عَنْ آلِ مُحَمَّدٍ ـ صلى الله عليه وسلم ـ فِي حَجَّةِ الْوَدَاعِ بَقَرَةً وَاحِدَةً ‏.‏\hadithno{3135}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) sacrificed one cow during the Farewell Pilgrimage on behalf of the family of Muhammad (ﷺ)}}
\hadithdefcmd{ibnmajah}{3136}{حَدَّثَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ الْبُرْسَانِيُّ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ قَالَ عَطَاءٌ الْخُرَاسَانِيُّ عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ أَتَاهُ رَجُلٌ فَقَالَ إِنَّ عَلَىَّ بَدَنَةً وَأَنَا مُوسِرٌ بِهَا وَلاَ أَجِدُهَا فَأَشْتَرِيَهَا ‏.‏ فَأَمَرَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ أَنْ يَبْتَاعَ سَبْعَ شِيَاهٍ فَيَذْبَحَهُنَّ ‏.‏\hadithno{3136}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that a man came to the Prophet (ﷺ) and said:“I have to offer a sacrifice and I can afford it, but I cannot find (a camel) to buy.” The Prophet (ﷺ) told him to buy seven sheep and slaughter them}}
\hadithdefcmd{ibnmajah}{3137}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا الْمُحَارِبِيُّ، وَعَبْدُ الرَّحِيمِ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، وَحَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَنَحْنُ بِذِي الْحُلَيْفَةِ مِنْ تِهَامَةَ فَأَصَبْنَا إِبِلاً وَغَنَمًا فَعَجِلَ الْقَوْمُ فَأَغْلَيْنَا الْقُدُورَ قَبْلَ أَنْ تُقْسَمَ فَأَتَانَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَأَمَرَ بِهَا فَأُكْفِئَتْ ثُمَّ عَدَلَ الْجَزُورَ بِعَشَرَةٍ مِنَ الْغَنَمِ ‏.‏\hadithno{3137}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Rafi’ bin Khadij said:“We were with the Messenger of Allah (ﷺ) in Dhul-Hulaifah in (the land of) Tihamah. We acquired sheep and camels and the people hastened to put cooking pots on the fires before they had been distributed. The Messenger of Allah (ﷺ) came to us and ordered that they be overturned,* then he made one camel equivalent to ten sheep.”}}
\hadithdefcmd{ibnmajah}{3138}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَعْطَاهُ غَنَمًا فَقَسَمَهَا عَلَى أَصْحَابِهِ ضَحَايَا فَبَقِيَ عَتُودٌ فَذَكَرَهُ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ ضَحِّ بِهِ أَنْتَ ‏"‏ ‏.‏\hadithno{3138}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Uqbah bin ‘Amir Al-Juhani that the Messenger of Allah (ﷺ) gave him some sheep, and he distributed them among his Companions to be sacrificed. There remained an ‘Atud.* He mentioned that to the Messenger of Allah (ﷺ) and he said:“You sacrifice it yourself.”}}
\hadithdefcmd{ibnmajah}{3139}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي يَحْيَى، - مَوْلَى الأَسْلَمِيِّينَ - عَنْ أُمِّهِ، قَالَتْ حَدَّثَتْنِي أُمُّ بِلاَلٍ بِنْتُ هِلاَلٍ، عَنْ أَبِيهَا، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ يَجُوزُ الْجَذَعُ مِنَ الضَّأْنِ أُضْحِيَّةً ‏"‏ ‏.‏\hadithno{3139}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{Umm Bilal bint Hilal narrated from her father that the Messenger of Allah (ﷺ) said:“It is permissible to offer a Jadha’a* among sheep as a sacrifice.”}}
\hadithdefcmd{ibnmajah}{3140}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا الثَّوْرِيُّ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، قَالَ كُنَّا مَعَ رَجُلٍ مِنْ أَصْحَابِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ يُقَالُ لَهُ مُجَاشِعٌ مِنْ بَنِي سُلَيْمٍ فَعَزَّتِ الْغَنَمُ فَأَمَرَ مُنَادِيًا فَنَادَى أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَقُولُ ‏ "‏ إِنَّ الْجَذَعَ يُوفِي مِمَّا تُوفِي مِنْهُ الثَّنِيَّةُ ‏"‏ ‏.‏\hadithno{3140}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Asim bin Kulaib that his father said:“We were with a man from among the Companions of the Messenger of Allah (ﷺ) who was called Mujashi’, from Banu Sulaim, and sheep became scarce. He ordered a caller to call out that the Messenger of Allah (ﷺ) used to say: ‘A Jadha’a suffices for whatever a two-year-old sheep suffices.’”}}
\hadithdefcmd{ibnmajah}{3141}{حَدَّثَنَا هَارُونُ بْنُ حَيَّانَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ، أَنْبَأَنَا زُهَيْرٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَذْبَحُوا إِلاَّ مُسِنَّةً إِلاَّ أَنْ يَعْسُرَ عَلَيْكُمْ فَتَذْبَحُوا جَذَعَةً مِنَ الضَّأْنِ ‏"‏ ‏.‏\hadithno{3141}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:‘Do not slaughter anything but a Musinnah,* unless there is none available, in which case you can slaughter a Jadha’a among sheep.”}}
\hadithdefcmd{ibnmajah}{3142}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ شُرَيْحِ بْنِ النُّعْمَانِ، عَنْ عَلِيٍّ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يُضَحَّى بِمُقَابَلَةٍ أَوْ مُدَابَرَةٍ أَوْ شَرْقَاءَ أَوْ خَرْقَاءَ أَوْ جَدْعَاءَ ‏.‏\hadithno{3142}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali said:“The Messenger of Allah (ﷺ) forbade sacrificing the Muqabalah, the Mudabarah, the Sharqa’, the Kharqa’ and the Jad’a’.”}}
\hadithdefcmd{ibnmajah}{3143}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ حُجَيَّةَ بْنِ عَدِيٍّ، عَنْ عَلِيٍّ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ نَسْتَشْرِفَ الْعَيْنَ وَالأُذُنَ ‏.‏\hadithno{3143}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Ali said:“The Messenger of Allah (ﷺ) commanded us to examine the eyes and ears.”}}
\hadithdefcmd{ibnmajah}{3144}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الرَّحْمَنِ، وَأَبُو دَاوُدَ وَابْنُ أَبِي عَدِيٍّ وَأَبُو الْوَلِيدِ قَالُوا حَدَّثَنَا شُعْبَةُ، سَمِعْتُ سُلَيْمَانَ بْنَ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ عُبَيْدَ بْنَ فَيْرُوزَ، قَالَ قُلْتُ لِلْبَرَاءِ بْنِ عَازِبٍ حَدِّثْنِي بِمَا، كَرِهَ أَوْ نَهَى عَنْهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِنَ الأَضَاحِيِّ ‏.‏ فَقَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ هَكَذَا بِيَدِهِ وَيَدِي أَقْصَرُ مِنْ يَدِهِ ‏ "‏ أَرْبَعٌ لاَ تُجْزِئُ فِي الأَضَاحِيِّ الْعَوْرَاءُ الْبَيِّنُ عَوَرُهَا وَالْمَرِيضَةُ الْبَيِّنُ مَرَضُهَا وَالْعَرْجَاءُ الْبَيِّنُ ظَلْعُهَا وَالْكَسِيرَةُ الَّتِي لاَ تُنْقِي ‏"‏ ‏.‏ قَالَ فَإِنِّي أَكْرَهُ أَنْ يَكُونَ نَقْصٌ فِي الأُذُنِ ‏.‏ قَالَ فَمَا كَرِهْتَ مِنْهُ فَدَعْهُ وَلاَ تُحَرِّمْهُ عَلَى أَحَدٍ ‏.‏\hadithno{3144}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Sulaiman bin ‘Abdur-Rahman said:“I heard ‘Ubaid bin Fairuz say: ‘I said to Bara’ bin ‘Azib: “Tell us of the sacrificial animals that the Messenger of Allah (ﷺ) disliked or forbade.” He said: “Allah’s Messenger (ﷺ) said like this with his hand. And my hand is shorter than his hand:* ‘There are four that will not be accepted as sacrifices: The one-eyed animal that is obviously blind in one eye; the sick animal that is obviously sick; the lame animal with an obvious limp; and the animal that is so emaciated that it is as if there is no marrow in its bones.’” He said:** “And I dislike that the animal should have some fault in its ears.” He said: “What you dislike, forget about it and do not make it forbidden to anyone.”}}
\hadithdefcmd{ibnmajah}{3145}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، أَنَّهُ ذَكَرَ أَنَّهُ سَمِعَ جُرَىَّ بْنَ كُلَيْبٍ، يُحَدِّثُ أَنَّهُ سَمِعَ عَلِيًّا، يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى أَنْ يُضَحَّى بِأَعْضَبِ الْقَرْنِ وَالأُذُنِ ‏.‏\hadithno{3145}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Qatadah that he said that he heard Juray bin Kulaib narrate that he heard ‘Ali narrate that the Messenger of Allah (ﷺ) forbade sacrificing animals with broken horns and ears}}
\hadithdefcmd{ibnmajah}{3146}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ أَبُو بَكْرٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنِ الثَّوْرِيِّ، عَنْ جَابِرِ بْنِ يَزِيدَ، عَنْ مُحَمَّدِ بْنِ قَرَظَةَ الأَنْصَارِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ ابْتَعْنَا كَبْشًا نُضَحِّي بِهِ فَأَصَابَ الذِّئْبُ مِنْ أَلْيَتِهِ أَوْ أُذُنِهِ فَسَأَلْنَا النَّبِيَّ ـ صلى الله عليه وسلم ـ فَأَمَرَنَا أَنْ نُضَحِّيَ بِهِ ‏.‏\hadithno{3146}\hadithgrade{Al-Albani: Very Daif Isnaad; Muhammad Fouad Abd al-Baqi: Very Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“We bought a ram for sacrifice, then a wolf tore some flesh from its rump and ears. We asked the Prophet (ﷺ) and he told us to offer it as a sacrifice.”}}
\hadithdefcmd{ibnmajah}{3147}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنِي الضَّحَّاكُ بْنُ عُثْمَانَ، عَنْ عُمَارَةَ بْنِ عَبْدِ اللَّهِ بْنِ صَيَّادٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، قَالَ سَأَلْتُ أَبَا أَيُّوبَ الأَنْصَارِيَّ كَيْفَ كَانَتِ الضَّحَايَا فِيكُمْ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ كَانَ الرَّجُلُ فِي عَهْدِ النَّبِيِّ ـ صلى الله عليه وسلم ـ يُضَحِّي بِالشَّاةِ عَنْهُ وَعَنْ أَهْلِ بَيْتِهِ فَيَأْكُلُونَ وَيُطْعِمُونَ ثُمَّ تَبَاهَى النَّاسُ فَصَارَ كَمَا تَرَى ‏.‏\hadithno{3147}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Ata’ bin Yasar said:“I asked Abu Ayyub Al- Ansari: ‘How were sacrifices offered among you at the time of the Messenger of Allah (ﷺ)?’ He said: ‘At the time of the Prophet (ﷺ), a man would sacrifice a sheep on behalf of himself and the members of his household, and they would eat some of it and give some to others. Then people started to compete and it because as you see (nowadays).’”}}
\hadithdefcmd{ibnmajah}{3148}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، وَمُحَمَّدُ بْنُ يُوسُفَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، جَمِيعًا عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ بَيَانٍ، عَنِ الشَّعْبِيِّ، عَنْ أَبِي سَرِيحَةَ، قَالَ حَمَلَنِي أَهْلِي عَلَى الْجَفَاءِ بَعْدَمَا عَلِمْتُ مِنَ السُّنَّةِ كَانَ أَهْلُ الْبَيْتِ يُضَحُّونَ بِالشَّاةِ وَالشَّاتَيْنِ وَالآنَ يُبَخِّلُنَا جِيرَانُنَا ‏.‏\hadithno{3148}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Fouad Abd al-Baqi: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sarihah said:“My family started to put pressure on me after I came to know the Sunnah. People used to sacrifice one or two sheep, but now our neighbors call us stingy.”}}
\hadithdefcmd{ibnmajah}{3149}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ الْحَمَّالُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا دَخَلَ الْعَشْرُ وَأَرَادَ أَحَدُكُمْ أَنْ يُضَحِّيَ فَلاَ يَمَسَّ مِنْ شَعَرِهِ وَلاَ بَشَرِهِ شَيْئًا ‏"‏ ‏.‏\hadithno{3149}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Umm Salamah that the Prophet (ﷺ) said:“When the ten days (of Dhul-Hijjah) begin, and one of you wants to offer a sacrifice, let him not remove anything from his hair or skin.”}}
\hadithdefcmd{ibnmajah}{3150}{حَدَّثَنَا حَاتِمُ بْنُ بَكْرٍ الضَّبِّيُّ أَبُو عَمْرٍو، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ الْبُرْسَانِيُّ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ سَعِيدِ بْنِ يَزِيدَ بْنِ إِبْرَاهِيمَ، حَدَّثَنَا أَبُو قُتَيْبَةَ، وَيَحْيَى بْنُ كَثِيرٍ، قَالُوا حَدَّثَنَا شُعْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ عَمْرِو بْنِ مُسْلِمٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ رَأَى مِنْكُمْ هِلاَلَ ذِي الْحِجَّةِ فَأَرَادَ أَنْ يُضَحِّيَ فَلاَ يَقْرَبَنَّ لَهُ شَعَرًا وَلاَ ظُفْرًا ‏"‏ ‏.‏\hadithno{3150}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Umm Salamah that the Messenger of Allah (ﷺ) said:“Whoever among you sees the new crescent of Dhul-Hijjah and wants to offer a sacrifice, let him not take anything from his hair or nails.”}}
\hadithdefcmd{ibnmajah}{3151}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، ذَبَحَ يَوْمَ النَّحْرِ قَبْلَ الصَّلاَةِ فَأَمَرَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ أَنْ يُعِيدَ ‏.‏\hadithno{3151}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that a man slaughtered on the Day of Sacrifice, (meaning) before the ‘Eid prayer, and the Prophet (ﷺ) ordered him to do it again}}
\hadithdefcmd{ibnmajah}{3152}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ جُنْدَبٍ الْبَجَلِيِّ، أَنَّهُ سَمِعَهُ يَقُولُ شَهِدْتُ الأَضْحَى مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَذَبَحَ أُنَاسٌ قَبْلَ الصَّلاَةِ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ كَانَ ذَبَحَ مِنْكُمْ قَبْلَ الصَّلاَةِ فَلْيُعِدْ أُضْحِيَّتَهُ وَمَنْ لاَ فَلْيَذْبَحْ عَلَى اسْمِ اللَّهِ ‏"‏ ‏.‏\hadithno{3152}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Aswad bin Qais that he heard Jundub Al-Bajali say:“I was present on Adha day with the Messenger of Allah (ﷺ), and some people slaughtered before the prayer. The Prophet (ﷺ) said: ‘Whoever among you has slaughtered before the prayer, let him repeat his sacrifice, and whoever has not, let him offer his sacrifice in the Name of Allah.’”}}
\hadithdefcmd{ibnmajah}{3153}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عُوَيْمِرِ بْنِ أَشْقَرَ، أَنَّهُ ذَبَحَ قَبْلَ الصَّلاَةِ فَذَكَرَهُ لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ أَعِدْ أُضْحِيَّتَكَ ‏"‏ ‏.‏\hadithno{3153}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Uwaimir bin Ashqar that he slaughtered before the prayer, and he mentioned that to the Prophet (ﷺ) who said:“Repeat your sacrifice.”}}
\hadithdefcmd{ibnmajah}{3154}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي زَيْدٍ، - قَالَ أَبُو بَكْرٍ وَقَالَ غَيْرُ عَبْدِ الأَعْلَى عَنْ عَمْرِو بْنِ بُجْدَانَ، عَنْ أَبِي زَيْدٍ، - ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى أَبُو مُوسَى، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا أَبِي، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ عَمْرِو بْنِ بُجْدَانَ، عَنْ أَبِي زَيْدٍ الأَنْصَارِيِّ، قَالَ مَرَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِدَارٍ مِنْ دُورِ الأَنْصَارِ فَوَجَدَ رِيحَ قُتَارٍ فَقَالَ ‏"‏ مَنْ هَذَا الَّذِي ذَبَحَ ‏"‏ ‏.‏ فَخَرَجَ إِلَيْهِ رَجُلٌ مِنَّا فَقَالَ أَنَا يَا رَسُولَ اللَّهِ ذَبَحْتُ قَبْلَ أَنْ أُصَلِّيَ لأُطْعِمَ أَهْلِي وَجِيرَانِي ‏.‏ فَأَمَرَهُ أَنْ يُعِيدَ ‏.‏ فَقَالَ لاَ وَاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ مَا عِنْدِي إِلاَّ جَذَعٌ أَوْ حَمَلٌ مِنَ الضَّأْنِ ‏.‏ قَالَ ‏"‏ اذْبَحْهَا وَلَنْ تُجْزِئَ جَذَعَةٌ عَنْ أَحَدٍ بَعْدَكَ ‏"‏ ‏.‏\hadithno{3154}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Zaid Al-Ansari said:“The Messenger of Allah (ﷺ) passed by one of the houses of the Ansar and noticed the smell of a cooking pot. He said: ‘Who is this who has slaughtered?’ A man from among us came out and said: ‘It is me, O Messenger of Allah, I slaughtered before the prayer so that I could feed my family and neighbors.’ He commanded him to repeat it. He said: ‘No, by the One besides Whom there is none worthy of worship, I do not have anything but a one-year-old sheep or a lamb.’ He (ﷺ) said: ‘Sacrifice it, but a one-year-old sheep will not do for anyone after you.’”}}
\hadithdefcmd{ibnmajah}{3155}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَذْبَحُ أُضْحِيَّتَهُ بِيَدِهِ وَاضِعًا قَدَمَهُ عَلَى صِفَاحِهَا ‏.‏\hadithno{3155}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:“I saw the Messenger of Allah (ﷺ) slaughter his sacrifice with his own hand, placing his foot on its side.”}}
\hadithdefcmd{ibnmajah}{3156}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَعْدِ بْنِ عَمَّارِ بْنِ سَعْدٍ، مُؤَذِّنِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حَدَّثَنِي أَبِي عَنْ أَبِيهِ عَنْ جَدِّهِ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ ذَبَحَ أُضْحِيَّتَهُ عِنْدَ طَرَفِ الزُّقَاقِ طَرِيقِ بَنِي زُرَيْقٍ بِيَدِهِ بِشَفْرَةٍ ‏.‏\hadithno{3156}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Abdur-Rahman bin Sa’d bin ‘Ammar bin Sa’d, the Mu’adhdhin of the Messenger of Allah (ﷺ), told us:“My father told me, from my grandfather, that the Messenger of Allah (ﷺ) slaughtered his sacrifice at the side of an alley, on the road of Banu Zuraiq, with his own hand, using a blade.”}}
\hadithdefcmd{ibnmajah}{3157}{حَدَّثَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ الْبُرْسَانِيُّ، أَنْبَأَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي الْحَسَنُ بْنُ مُسْلِمٍ، أَنَّ مُجَاهِدًا، أَخْبَرَهُ أَنَّ عَبْدَ الرَّحْمَنِ بْنَ أَبِي لَيْلَى أَخْبَرَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَمَرَهُ أَنْ يَقْسِمَ بُدْنَهُ كُلَّهَا لُحُومَهَا وَجُلُودَهَا وَجِلاَلَهَا لِلْمَسَاكِينِ ‏.‏\hadithno{3157}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Agreed Upon}\hadithtrans{‘Ali bin Abu Talib narrated that the Messenger of Allah (ﷺ) commanded him to distribute the entire sacrificial camel – its meat, skin and covers – among the poor}}
\hadithdefcmd{ibnmajah}{3158}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَمَرَ مِنْ كُلِّ جَزُورٍ بِبَضْعَةٍ فَجُعِلَتْ فِي قِدْرٍ فَأَكَلُوا مِنَ اللَّحْمِ وَحَسَوْا مِنَ الْمَرَقِ ‏.‏\hadithno{3158}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) ordered that a piece from every camel that had been slaughtered be brought and placed in a pot, then they ate from its meat and drank some of the broth}}
\hadithdefcmd{ibnmajah}{3159}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَابِسٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ إِنَّمَا نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ لُحُومِ الأَضَاحِيِّ لِجَهْدِ النَّاسِ ثُمَّ رَخَّصَ فِيهَا ‏.‏\hadithno{3159}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) only forbade storing the meat of the sacrifices because the people were facing hardship. Then later he permitted that.”}}
\hadithdefcmd{ibnmajah}{3160}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي الْمَلِيحِ، عَنْ نُبَيْشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كُنْتُ نَهَيْتُكُمْ عَنْ لُحُومِ الأَضَاحِيِّ فَوْقَ ثَلاَثَةِ أَيَّامٍ فَكُلُوا وَادَّخِرُوا ‏"‏ ‏.‏\hadithno{3160}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Nubaishah that the Messenger of Allah (ﷺ) said:“I used to forbid you to store the meat of the sacrifices for more than three days, but (now) eat some and store some.”}}
\hadithdefcmd{ibnmajah}{3161}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا أُسَامَةُ بْنُ زَيْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ كَانَ يَذْبَحُ بِالْمُصَلَّى ‏.‏\hadithno{3161}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) used to slaughter at the prayer place (of the ‘Eid congregation)}}
