% Auto-generated chapter 31 for tirmidhi
% Hadiths in this chapter: 8

\hadithdefcmd{tirmidhi}{2125}{حَدَّثَنَا بُنْدَارٌ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، أَنَّهَا أَرَادَتْ أَنْ تَشْتَرِيَ، بَرِيرَةَ فَاشْتَرَطُوا الْوَلاَءَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْوَلاَءُ لِمَنْ أَعْطَى الثَّمَنَ أَوْ لِمَنْ وَلِيَ النِّعْمَةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَبِي هُرَيْرَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{2125}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Aishah narrated that she wanted to buy Barrirah but (her owners) stipulated that they should have her Wala', so the Prophet (s.a.w) said:"The Wala' is for the one who gives the price, or for the one who grants the favor." [Abu 'Eisa said:] There are narrations on this topic from Ibn 'Umar and Abu Hurairah. This Hadith is Hasan Sahih, and this is acted upon according to the people of knowledge}}
\hadithdefcmd{tirmidhi}{2126}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْوَلاَءِ وَعَنْ هِبَتِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ دِينَارٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ بَيْعِ الْوَلاَءِ وَعَنْ هِبَتِهِ وَقَدْ رَوَاهُ شُعْبَةُ وَسُفْيَانُ الثَّوْرِيُّ وَمَالِكُ بْنُ أَنَسٍ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ ‏.‏ وَيُرْوَى عَنْ شُعْبَةَ قَالَ لَوَدِدْتُ أَنَّ عَبْدَ اللَّهِ بْنَ دِينَارٍ حِينَ حَدَّثَ بِهَذَا الْحَدِيثِ أَذِنَ لِي حَتَّى كُنْتُ أَقُومُ إِلَيْهِ فَأُقَبِّلُ رَأْسَهُ ‏.‏ وَرَوَى يَحْيَى بْنُ سُلَيْمٍ هَذَا الْحَدِيثَ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَهُوَ وَهَمٌ وَهِمَ فِيهِ يَحْيَى بْنُ سُلَيْمٍ وَالصَّحِيحُ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ هَكَذَا رَوَاهُ غَيْرُ وَاحِدٍ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى وَتَفَرَّدَ عَبْدُ اللَّهِ بْنُ دِينَارٍ بِهَذَا الْحَدِيثِ ‏.‏\hadithno{2126}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin 'Umar narrated that : the Messenger of Allah (ﷺ) prohibited selling the Wala' and [from] conferring it. [Abu 'Eisa said:] This Hadith is Hasan Sahih. We do not know of it except as a narration of 'Abdullah bin Dinar from Ibn 'Umar from the Prophet (ﷺ). Shu'bah, Sufyan Ath-Thawri, and Malik bin Anas (also) reported it from 'Abdullah bin Dinar. It has been related that Shu'bah said: "I so wished that 'Abdullah bin Dinar would permit me when he narrated this Hadith that I stand-up, so that I kiss his head." And Yahya bin Sulaim reported this Hadith from 'Ubaidullah bin 'Umar from Nafi', from Ibn 'Umar from the Prophet (ﷺ). But this is mistaken, Yahya bin Sulaim erred in it, what is correct is: "From 'Ubaidullah bin 'Umar, from 'Abdullah bin Dinar, from Ibn 'Umar from the Prophet (ﷺ). This is how it is reported by more than one narrator from 'Ubaidullah bin 'Umar. [Abu 'Eisa said:] And 'Abdullah bin Dinar is alone with this Hadith}}
\hadithdefcmd{tirmidhi}{2127}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، قَالَ خَطَبَنَا عَلِيٌّ فَقَالَ مَنْ زَعَمَ أَنَّ عِنْدَنَا شَيْئًا نَقْرَؤُهُ إِلاَّ كِتَابَ اللَّهِ وَهَذِهِ الصَّحِيفَةَ صَحِيفَةٌ فِيهَا أَسْنَانُ الإِبِلِ وَأَشْيَاءُ مِنَ الْجِرَاحَاتِ فَقَدْ كَذَبَ وَقَالَ فِيهَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَدِينَةُ حَرَامٌ مَا بَيْنَ عَيْرٍ إِلَى ثَوْرٍ فَمَنْ أَحْدَثَ فِيهَا حَدَثًا أَوْ آوَى مُحْدِثًا فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يَقْبَلُ اللَّهُ مِنْهُ يَوْمَ الْقِيَامَةِ صَرْفًا وَلاَ عَدْلاً وَمَنِ ادَّعَى إِلَى غَيْرِ أَبِيهِ أَوْ تَوَلَّى غَيْرَ مَوَالِيهِ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يُقْبَلُ مِنْهُ صَرْفٌ وَلاَ عَدْلٌ وَذِمَّةُ الْمُسْلِمِينَ وَاحِدَةٌ يَسْعَى بِهَا أَدْنَاهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عَلِيٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى بَعْضُهُمْ عَنِ الأَعْمَشِ عَنْ إِبْرَاهِيمَ التَّيْمِيِّ عَنِ الْحَارِثِ بْنِ سُوَيْدٍ عَنْ عَلِيٍّ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عَلِيٍّ عَنْ النَّبِيِّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ\hadithno{2127}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibrahim At-Taimi narrated from his father: "'Ali delivered a Khutbah for us in which he said: 'Whoever claims that we have some book to read other than Allah's Book and this paper, which include camel's ages and things related to (relatiation for) wounds, then he has lied." And he said in it: "Al-Madinah is sacred, what is between 'Air to Thawr, so whoever introduces in it any innovation or shelters an innovator then upon him is the curse of Allah, the angels, and all people. On the Day of Judgment, Allah will not accept his compulsory nor optional good deeds. And whoever claims someone else to be his father, or claims Wala' for someone other than his Mawali, then upon him is the curse of Allah, the angels, and the people; his compulsory and optional good deeds shall not be accepted. The covenants of the Muslims are one, it covers the rest of them. [Abu 'Eisa said:] This Hadith is Hasan Sahih. Some of them reported it similarly from Al-A'mash, from Ibrahim At-Taimi, from Al-Harith bin Suwaid from 'Ali. [Abu 'Eisa said:] It has been reported through more than one route from 'Ali [from the Prophet (ﷺ]}}
\hadithdefcmd{tirmidhi}{2128}{حَدَّثَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ بْنِ عَبْدِ الْجَبَّارِ الْعَطَّارُ، وَسَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ مِنْ بَنِي فَزَارَةَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ امْرَأَتِي وَلَدَتْ غُلاَمًا أَسْوَدَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلْ لَكَ مِنْ إِبِلٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَمَا أَلْوَانُهَا ‏"‏ ‏.‏ قَالَ حُمْرٌ ‏.‏ قَالَ ‏"‏ فَهَلْ فِيهَا أَوْرَقُ ‏"‏ ‏.‏ قَالَ نَعَمْ إِنَّ فِيهَا لَوُرْقًا ‏.‏ قَالَ ‏"‏ أَنَّى أَتَاهَا ذَلِكَ ‏"‏ ‏.‏ قَالَ لَعَلَّ عِرْقًا نَزَعَهَا ‏.‏ قَالَ ‏"‏ فَهَذَا لَعَلَّ عِرْقًا نَزَعَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2128}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated : "that a man from [Banu] Fazarah came to the Prophet (ﷺ) and said: 'O Messenger of Allah (ﷺ)! My wife gave birth to black boy." So the Prophet (s.a.w) said: "[Do you have any camels?]" He said: 'Yes." He said: "Then what are their colors?" He said: "Red." He said: "Is there a gray one among them?" He said: "Yes, there is a grey one among them." He said: "From where does that come?" He said: "Perhaps it is hereditary." He said: "Then in the same way, perhaps it is his heredity." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{2129}{\hadithno{2129}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{2130}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ الْبَصْرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَوَاءٍ، حَدَّثَنَا أَبُو مَعْشَرٍ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تَهَادَوْا فَإِنَّ الْهَدِيَّةَ تُذْهِبُ وَحَرَ الصَّدْرِ وَلاَ تَحْقِرَنَّ جَارَةٌ لِجَارَتِهَا وَلَوْ شِقَّ فِرْسِنِ شَاةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأَبُو مَعْشَرٍ اسْمُهُ نَجِيحٌ مَوْلَى بَنِي هَاشِمٍ وَقَدْ تَكَلَّمَ فِيهِ بَعْضُ أَهْلِ الْعِلْمِ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{2130}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Prophet (s.a.w) said:"Give gifts, for indeed the gift removes bad feelings from the chest. And let the neighbor not look down upon (the gift of) her neighbor, even if it be the lower shanks of sheep." [Abu 'Eisa said:] This Hadith is Gharib from this route. Abu Ma'shar's name is Najih, the freed slave of Banu Hisham. Some of the people of knowledge criticized him due to his poor memory}}
\hadithdefcmd{tirmidhi}{2131}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، حَدَّثَنَا حُسَيْنٌ الْمُكْتِبُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الَّذِي يُعْطِي الْعَطِيَّةَ ثُمَّ يَرْجِعُ فِيهَا كَالْكَلْبِ أَكَلَ حَتَّى إِذَا شَبِعَ قَاءَ ثُمَّ عَادَ فَرَجَعَ فِي قَيْئِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏\hadithno{2131}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn 'Umar narrated that the Messenger of Allah (S.A.W)said:"The parable of the one who gives a gift, and then takes it back, is that of a dog who eats until he is full, and vomits, then he returns to [take back] his vomit." [Abu 'Eisa said:] There are narrations on this topic from Ibn 'Abbas and 'Abdullah bin 'Amr}}
\hadithdefcmd{tirmidhi}{2132}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، حَدَّثَنِي طَاوُسٌ، عَنِ ابْنِ عُمَرَ، وَابْنِ، عَبَّاسٍ يَرْفَعَانِ الْحَدِيثَ قَالَ ‏ "‏ لاَ يَحِلُّ لِلرَّجُلِ أَنْ يُعْطِيَ عَطِيَّةً ثُمَّ يَرْجِعَ فِيهَا إِلاَّ الْوَالِدَ فِيمَا يُعْطِي وَلَدَهُ وَمَثَلُ الَّذِي يُعْطِي الْعَطِيَّةَ ثُمَّ يَرْجِعُ فِيهَا كَمَثَلِ الْكَلْبِ أَكَلَ حَتَّى إِذَا شَبِعَ قَاءَ ثُمَّ عَادَ فِي قَيْئِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ الشَّافِعِيُّ لاَ يَحِلُّ لِمَنْ وَهَبَ هِبَةً أَنْ يَرْجِعَ فِيهَا إِلاَّ الْوَالِدَ فَلَهُ أَنْ يَرْجِعَ فِيمَا أَعْطَى وَلَدَهُ ‏.‏ وَاحْتَجَّ بِهَذَا الْحَدِيثِ ‏\hadithno{2132}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn 'Umar and Ibn 'Abbas narrated the Marfu Hadith:"It is not lawful for a man to give a gift and then take it back, except in the case of the father with what he gave to his son. And the parable of the one who gives a gift, and then takes it back, is that of a dog who eats until he is full, and vomits, then he returns to his vomit." [Abu 'Eisa said:] This Hadith is Hasan Sahih. Ash-Shafi'i said: "It is not lawful for one who confers something to take it back, except in the case of the father. He may take back what he gave his son" and he used this Hadith as proof}}
