% Auto-generated chapter 12 for malik
% Hadiths in this chapter: 4

\hadithdefcmd{malik}{445}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ خَسَفَتِ الشَّمْسُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالنَّاسِ فَقَامَ فَأَطَالَ الْقِيَامَ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ قَامَ فَأَطَالَ الْقِيَامَ وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ رَفَعَ فَسَجَدَ ثُمَّ فَعَلَ فِي الرَّكْعَةِ الآخِرَةِ مِثْلَ ذَلِكَ ثُمَّ انْصَرَفَ وَقَدْ تَجَلَّتِ الشَّمْسُ فَخَطَبَ النَّاسَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا رَأَيْتُمْ ذَلِكَ فَادْعُوا اللَّهَ وَكَبِّرُوا وَتَصَدَّقُوا - ثُمَّ قَالَ - يَا أُمَّةَ مُحَمَّدٍ وَاللَّهِ مَا مِنْ أَحَدٍ أَغْيَرَ مِنَ اللَّهِ أَنْ يَزْنِيَ عَبْدُهُ أَوْ تَزْنِيَ أَمَتُهُ يَا أُمَّةَ مُحَمَّدٍ وَاللَّهِ لَوْ تَعْلَمُونَ مَا أَعْلَمُ لَضَحِكْتُمْ قَلِيلاً وَلَبَكَيْتُمْ كَثِيرًا ‏"‏ ‏.‏\hadithno{445}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "There was an eclipse of the sun in the time of the Messenger of Allah, may Allah bless him and grant him peace, and the Messenger of Allah, may Allah bless him and grant him peace, led the people in prayer. He stood, and did so for a long time. Then he went into ruku, and made the ruku long. Then he stood again, and did so for a long time, though not as long as the first time. Then he went into ruku, and made the ruku long, though not as long as thefirst time. Then he rose, and went down into sajda. He then did the same in the second raka, and by the time he had finished the sun had appeared. He then gave a khutba to the people, in which he praised Allah and then said, 'The sun and the moon are two of Allah's signs. They do not eclipse for anyone's death nor for anyone's life. When you see an eclipse, call on Allah and say, "Allah is greater" and give sadaqa.' Then he said, 'O community of Muhammad! ByAllah, there is no-one more jealous than Allah of a male or female slave of his who commits adultery. O community of Muhammad! By Allah, if you knew what I knew, you would laugh little and weep much}}
\hadithdefcmd{malik}{446}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ قَالَ خَسَفَتِ الشَّمْسُ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ مَعَهُ فَقَامَ قِيَامًا طَوِيلاً نَحْوًا مِنْ سُورَةِ الْبَقَرَةِ - قَالَ - ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ سَجَدَ ثُمَّ قَامَ قِيَامًا طَوِيلاً وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهُو دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ سَجَدَ ثُمَّ انْصَرَفَ وَقَدْ تَجَلَّتِ الشَّمْسُ فَقَالَ ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا رَأَيْتُمْ ذَلِكَ فَاذْكُرُوا اللَّهَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ رَأَيْنَاكَ تَنَاوَلْتَ شَيْئًا فِي مَقَامِكَ هَذَا ثُمَّ رَأَيْنَاكَ تَكَعْكَعْتَ ‏.‏ فَقَالَ ‏"‏ إِنِّي رَأَيْتُ الْجَنَّةَ فَتَنَاوَلْتُ مِنْهَا عُنْقُودًا وَلَوْ أَخَذْتُهُ لأَكَلْتُمْ مِنْهُ مَا بَقِيَتِ الدُّنْيَا وَرَأَيْتُ النَّارَ فَلَمْ أَرَ كَالْيَوْمِ مَنْظَرًا قَطُّ أَفْظَعَ وَرَأَيْتُ أَكْثَرَ أَهْلِهَا النِّسَاءَ ‏"‏ ‏.‏ قَالُوا لِمَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لِكُفْرِهِنَّ ‏"‏ ‏.‏ قِيلَ أَيَكْفُرْنَ بِاللَّهِ ‏.‏ قَالَ ‏"‏ وَيَكْفُرْنَ الْعَشِيرَ وَيَكْفُرْنَ الإِحْسَانَ لَوْ أَحْسَنْتَ إِلَى إِحْدَاهُنَّ الدَّهْرَ كُلَّهُ ثُمَّ رَأَتْ مِنْكَ شَيْئًا قَالَتْ مَا رَأَيْتُ مِنْكَ خَيْرًا قَطُّ ‏"‏ ‏.‏\hadithno{446}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar that Abdullah ibn Abbas said, "There was an eclipse of the sun and the Messenger of Allah, may Allah bless him and grant him peace, prayed, and the people prayed with him. He stood for a long time, nearly as long as (it takes to recite) Surat al-Baqara (Sura 2), and then went into ruku for a long time. Then he rose and stood for a long time, though less than the first time.Then he went into ruku for a long time, though less than the first time. Then he went down into sajda. Then he stood for a long time, though less than the first time. Then he went into ruku for a long time, though less than the first time. Then he rose and stood for a long time, though less than the firsttime. Then he went into ruku for a long time, though less than the first time. Then he went down into sajda, and by the time he had finished the sun had appeared. Then he said, 'The sun and the moon are two of Allah's signs. They do not eclipse for anyone's death nor for anyone's life. When you see an eclipse, remember Allah.' They said, 'Messenger of Allah, we saw you reach out for something while you were standing here and then we saw you withdraw.' He said, 'I saw the Garden and I reached out for a bunch of grapes from it, and if I had taken it you would have been able to eat from it for as long as this world lasted. Then I saw the Fire - and I have never seen anything more hideous than what I saw today - and I saw that most of its people were women.' They said, 'Why, Messenger of Allah?' He said, 'Because of their ungratefulness (kufr).' Someone said, 'Are they ungrateful toAllah?' He said, 'They are ungrateful to their husbands and they are ungrateful for good behaviour (towards them) . Even if you were to behave well towards one of them for a whole lifetime and then she were to see you do something (that she did not like) she would say that she had never seen anything good from you}}
\hadithdefcmd{malik}{447}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ يَهُودِيَّةً جَاءَتْ تَسْأَلُهَا فَقَالَتْ أَعَاذَكِ اللَّهُ مِنْ عَذَابِ الْقَبْرِ ‏.‏ فَسَأَلَتْ عَائِشَةُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَيُعَذَّبُ النَّاسُ فِي قُبُورِهِمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَائِذًا بِاللَّهِ مِنْ ذَلِكَ ثُمَّ رَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ غَدَاةٍ مَرْكَبًا فَخَسَفَتِ الشَّمْسُ فَرَجَعَ ضُحًى فَمَرَّ بَيْنَ ظَهْرَانَىِ الْحُجَرِ ثُمَّ قَامَ يُصَلِّي وَقَامَ النَّاسُ وَرَاءَهُ فَقَامَ قِيَامًا طَوِيلاً ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ رَفَعَ فَسَجَدَ ثُمَّ قَامَ قِيَامًا طَوِيلاً وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ رَفَعَ ثُمَّ سَجَدَ ثُمَّ انْصَرَفَ فَقَالَ مَا شَاءَ اللَّهُ أَنْ يَقُولَ ثُمَّ أَمَرَهُمْ أَنْ يَتَعَوَّذُوا مِنْ عَذَابِ الْقَبْرِ ‏.‏\hadithno{447}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from 'Amra bint Abd ar-Rahman from A'isha, the wife of the Prophet, may Allah bless him and grant him peace, that a jewish woman came to beg from her and said, "May Allah give you refuge from the punishment of the grave." So A'isha asked the Messenger of Allah, may Allah bless him and grant him peace, "Are people punished in their graves?", and the Messenger of Allah, may Allah bless him and grant him peace, took refuge in Allah from that. Then one morning the Messenger of Allah, may Allah bless him and grant him peace, went out on a journey and there was an eclipse of the sun, and he returned in the late morning and passed through his apartments. Then he stood and prayed, and the people stood behind him. He stood for a long time, and then went into ruku for a long time. Then he rose and stood for a long time, though less than the first time, and then went into ruku for a long time, though less than the first time. Then he rose, and went down into sajda. Then he stood for a long time, though less than the time before, and then went into ruku for a long time, though less than the time before. Then he rose and stood for a long time, though less than the time before, and then went into ruku for a long time, though less than the time before. Then he rose, and went down into sajda. When he had finished he said what Allah willed him to say, and then he told them to seek protection for themselves from the punishment of the grave}}
\hadithdefcmd{malik}{448}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ الصِّدِّيقِ، أَنَّهَا قَالَتْ أَتَيْتُ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم حِينَ خَسَفَتِ الشَّمْسُ فَإِذَا النَّاسُ قِيَامٌ يُصَلُّونَ وَإِذَا هِيَ قَائِمَةٌ تُصَلِّي فَقُلْتُ مَا لِلنَّاسِ فَأَشَارَتْ بِيَدِهَا نَحْوَ السَّمَاءِ وَقَالَتْ سُبْحَانَ اللَّهِ ‏.‏ فَقُلْتُ آيَةٌ فَأَشَارَتْ بِرَأْسِهَا أَنْ نَعَمْ ‏.‏ قَالَتْ فَقُمْتُ حَتَّى تَجَلاَّنِي الْغَشْىُ وَجَعَلْتُ أَصُبُّ فَوْقَ رَأْسِي الْمَاءَ فَحَمِدَ اللَّهَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏ "‏ مَا مِنْ شَىْءٍ كُنْتُ لَمْ أَرَهُ إِلاَّ قَدْ رَأَيْتُهُ فِي مَقَامِي هَذَا حَتَّى الْجَنَّةُ وَالنَّارُ وَلَقَدْ أُوحِيَ إِلَىَّ أَنَّكُمْ تُفْتَنُونَ فِي الْقُبُورِ مِثْلَ - أَوْ قَرِيبًا - مِنْ فِتْنَةِ الدَّجَّالِ - لاَ أَدْرِي أَيَّتَهُمَا قَالَتْ أَسْمَاءُ - يُؤْتَى أَحَدُكُمْ فَيُقَالُ لَهُ مَا عِلْمُكَ بِهَذَا الرَّجُلِ فَأَمَّا الْمُؤْمِنُ - أَوِ الْمُوقِنُ لاَ أَدْرِي أَىَّ ذَلِكَ قَالَتْ أَسْمَاءُ - فَيَقُولُ هُوَ مُحَمَّدٌ رَسُولُ اللَّهِ جَاءَنَا بِالْبَيِّنَاتِ وَالْهُدَى فَأَجَبْنَا وَآمَنَّا وَاتَّبَعْنَا فَيُقَالُ لَهُ نَمْ صَالِحًا قَدْ عَلِمْنَا إِنْ كُنْتَ لَمُؤْمِنًا وَأَمَّا الْمُنَافِقُ - أَوِ الْمُرْتَابُ لاَ أَدْرِي أَيَّتَهُمَا قَالَتْ أَسْمَاءُ - فَيَقُولُ لاَ أَدْرِي سَمِعْتُ النَّاسَ يَقُولُونَ شَيْئًا فَقُلْتُهُ ‏"‏ ‏.‏\hadithno{448}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from Fatima bint al Mundhir that Asma bint Abi Bakr as-Siddiq said, "I went to A'isha, the wife of the Prophet, may Allah bless him and grant him peace, during an eclipse of the sun, and everybody was standing in prayer, and she too was standing praying. I said, 'What is everybody doing?' She pointed towards the sky with her hand and said, 'Glory be to Allah.' I said, 'A sign?' She nodded 'Yes' with her head." She continued, "I stood until I had almost fainted, and I began to pour water over my head. The Messenger of Allah, may Allah bless him and grant him peace, praised Allah and spoke well of Him, and then said, 'There is nothing which I had previously not seen beforehand that I have not now seen while standing - even the Garden and the Fire. It has been revealed to me that you will be tried in your graves with a trial, like, or near to, the trial of the Dajjal (I do not know which one Asma said). Every one of you will have someone who comes to him and asks him, 'What do you know about this man?' A mumin, or one who has certainty (muqin) (I do not know which one Asma said), will say, 'He is Muhammad, the Messenger of Allah, may Allah bless him and grant him peace, who came to us with clear proofs and guidance, and we answered and believed and followed.' He will then be told, 'Sleep in a good state. We know now that you were a mumin.' A hypocrite, however, or one who has doubts (l do not know which one Asma said), will say, 'I do not know, I heard everybody saying something and I said it}}
