% Auto-generated chapter 94 for bukhari
% Hadiths in this chapter: 20

\hadithdefcmd{bukhari}{7226}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، حَدَّثَنِي اللَّيْثُ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، وَسَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَوْلاَ أَنَّ رِجَالاً يَكْرَهُونَ أَنْ يَتَخَلَّفُوا بَعْدِي وَلاَ أَجِدُ مَا أَحْمِلُهُمْ مَا تَخَلَّفْتُ، لَوَدِدْتُ أَنِّي أُقْتَلُ فِي سَبِيلِ اللَّهِ، ثُمَّ أُحْيَا ثُمَّ أُقْتَلُ، ثُمَّ أُحْيَا ثُمَّ أُقْتَلُ، ثُمَّ أُحْيَا ثُمَّ أُقْتَلُ ‏"‏‏.‏\hadithno{7226}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "By Him in Whose Hands my life is! Were it not for some men who dislike to be left behind and for whom I do not have means of conveyance, I would not stay away (from any Holy Battle). I would love to be martyred in Allah's Cause and come to life and then get, martyred and then come to life and then get martyred and then get resurrected and then get martyred}}
\hadithdefcmd{bukhari}{7227}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ وَدِدْتُ أَنِّي لأُقَاتِلُ فِي سَبِيلِ اللَّهِ فَأُقْتَلُ ثُمَّ أُحْيَا ثُمَّ أُقْتَلُ، ثُمَّ أُحْيَا، ثُمَّ أُقْتَلُ، ثُمَّ أُحْيَا، ثُمَّ أُقْتَلُ، ثُمَّ أُحْيَا ‏"‏‏.‏ فَكَانَ أَبُو هُرَيْرَةَ يَقُولُهُنَّ ثَلاَثًا أَشْهَدُ بِاللَّهِ‏.‏\hadithno{7227}\hadithtrans{Narrated Al-A'raj:Abu Huraira said, Allah's Messenger (ﷺ) said, "By Him in Whose Hand my life is, I would love to fight in Allah's Cause and then get martyred and then resurrected (come to life) and then get martyred and then resurrected (come to life) and then get martyred, and then resurrected (come to life) and then get martyred and then resurrected (come to life)." Abu Huraira used to repeat those words three times and I testify to it with Allah's Oath}}
\hadithdefcmd{bukhari}{7228}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، سَمِعَ أَبَا هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ كَانَ عِنْدِي أُحُدٌ ذَهَبًا، لأَحْبَبْتُ أَنْ لاَ يَأْتِيَ ثَلاَثٌ وَعِنْدِي مِنْهُ دِينَارٌ، لَيْسَ شَىْءٌ أُرْصِدُهُ فِي دَيْنٍ عَلَىَّ أَجِدُ مَنْ يَقْبَلُهُ ‏"‏‏.‏\hadithno{7228}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If I had gold equal to the mountain of Uhud, I would love that, before three days had passed, not a single Dinar thereof remained with me if I found somebody to accept it excluding some amount that I would keep for the payment of my debts}}
\hadithdefcmd{bukhari}{7229}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُرْوَةُ، أَنَّ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوِ اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ مَا سُقْتُ الْهَدْىَ، وَلَحَلَلْتُ مَعَ النَّاسِ حِينَ حَلُّوا ‏"‏‏.‏\hadithno{7229}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said, "If I had formerly known what I came to know recently, I would not have driven the Hadi with me and would have finished the state of Ihram along with the people when they finished it}}
\hadithdefcmd{bukhari}{7230}{حَدَّثَنَا الْحَسَنُ بْنُ عُمَرَ، حَدَّثَنَا يَزِيدُ، عَنْ حَبِيبٍ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَبَّيْنَا بِالْحَجِّ وَقَدِمْنَا مَكَّةَ لأَرْبَعٍ خَلَوْنَ مِنْ ذِي الْحِجَّةِ، فَأَمَرَنَا النَّبِيُّ صلى الله عليه وسلم أَنْ نَطُوفَ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ، وَأَنْ نَجْعَلَهَا عُمْرَةً وَلْنَحِلَّ، إِلاَّ مَنْ كَانَ مَعَهُ هَدْىٌ قَالَ وَلَمْ يَكُنْ مَعَ أَحَدٍ مِنَّا هَدْىٌ غَيْرَ النَّبِيِّ صلى الله عليه وسلم وَطَلْحَةَ، وَجَاءَ عَلِيٌّ مِنَ الْيَمَنِ مَعَهُ الْهَدْىُ فَقَالَ أَهْلَلْتُ بِمَا أَهَلَّ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالُوا نَنْطَلِقُ إِلَى مِنًى وَذَكَرُ أَحَدِنَا يَقْطُرُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي لَوِ اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ مَا أَهْدَيْتُ، وَلَوْلاَ أَنَّ مَعِي الْهَدْىَ لَحَلَلْتُ ‏"‏‏.‏ قَالَ وَلَقِيَهُ سُرَاقَةُ وَهْوَ يَرْمِي جَمْرَةَ الْعَقَبَةِ فَقَالَ يَا رَسُولَ اللَّهِ أَلَنَا هَذِهِ خَاصَّةً قَالَ ‏"‏ لاَ بَلْ لأَبَدٍ ‏"‏‏.‏ قَالَ وَكَانَتْ عَائِشَةُ قَدِمَتْ مَكَّةَ وَهْىَ حَائِضٌ، فَأَمَرَهَا النَّبِيُّ صلى الله عليه وسلم أَنْ تَنْسُكَ الْمَنَاسِكَ كُلَّهَا، غَيْرَ أَنَّهَا لاَ تَطُوفُ وَلاَ تُصَلِّي حَتَّى تَطْهُرَ، فَلَمَّا نَزَلُوا الْبَطْحَاءَ قَالَتْ عَائِشَةُ يَا رَسُولَ اللَّهِ أَتَنْطَلِقُونَ بِحَجَّةٍ وَعُمْرَةٍ وَأَنْطَلِقُ بِحَجَّةٍ‏.‏ قَالَ ثُمَّ أَمَرَ عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ الصِّدِّيقِ أَنْ يَنْطَلِقَ مَعَهَا إِلَى التَّنْعِيمِ، فَاعْتَمَرَتْ عُمْرَةً فِي ذِي الْحَجَّةِ بَعْدَ أَيَّامِ الْحَجِّ‏.‏\hadithno{7230}\hadithtrans{Narrated Jabir bin `Abdullah:We were in the company of Allah's Messenger (ﷺ) and we assumed the state of Ihram of Hajj and arrived at Mecca on the fourth of Dhul-Hijja. The Prophet (ﷺ) ordered us to perform the Tawaf around the Ka`ba and (Sa`i) between As-Safa and Al-Marwa and use our Ihram just for `Umra, and finish the state of Ihram unless we had our Hadi with us. None of us had the Hadi with him except the Prophet (ﷺ) and Talha. `Ali came from Yemen and brought the Hadi with him. `Ali said, 'I had assumed the state of Ihram with the same intention as that with which Allah's Messenger (ﷺ) had assumed it. The people said, "How can we proceed to Mina and our male organs are dribbling?" Allah's Messenger (ﷺ) said, "If I had formerly known what I came to know latterly, I would not have brought the Hadi, and had there been no Hadi with me, I would have finished my Ihram." Suraqa (bin Malik) met the Prophet (ﷺ) while he was throwing pebbles at the Jamrat-Al-`Aqaba, and asked, "O Allah's Messenger (ﷺ)! Is this (permitted) for us only?" The Prophet (ﷺ) replied. "No, it is forever" `Aisha had arrived at Mecca while she was menstruating, therefore the Prophet (ﷺ) ordered her to perform all the ceremonies of Hajj except the Tawaf around the Ka`ba, and not to perform her prayers unless and until she became clean . When they encamped at Al-Batha, `Aisha said, "O Allah's Messenger (ﷺ)! You are proceeding after performing both Hajj and `Umra while I am proceeding with Hajj only?" So the Prophet (ﷺ) ordered `Abdur-Rahman bin Abu Bakr As-Siddiq to go with her to at-Tan`im, and so she performed the `Umra in Dhul-Hijja after the days of the Hajj}}
\hadithdefcmd{bukhari}{7231}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَامِرِ بْنِ رَبِيعَةَ، قَالَ قَالَتْ عَائِشَةُ أَرِقَ النَّبِيُّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَقَالَ ‏"‏ لَيْتَ رَجُلاً صَالِحًا مِنْ أَصْحَابِي يَحْرُسُنِي اللَّيْلَةَ ‏"‏‏.‏ إِذْ سَمِعْنَا صَوْتَ السِّلاَحِ قَالَ ‏"‏ مَنْ هَذَا ‏"‏‏.‏ قِيلَ سَعْدٌ يَا رَسُولَ اللَّهِ جِئْتُ أَحْرُسُكَ‏.‏ فَنَامَ النَّبِيُّ صلى الله عليه وسلم حَتَّى سَمِعْنَا غَطِيطَهُ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ وَقَالَتْ عَائِشَةُ قَالَ بِلاَلٌ أَلاَ لَيْتَ شِعْرِي هَلْ أَبِيتَنَّ لَيْلَةً بِوَادٍ وَحَوْلِي إِذْخِرٌ وَجَلِيلُ فَأَخْبَرْتُ النَّبِيَّ صلى الله عليه وسلم‏.‏\hadithno{7231}\hadithtrans{Narrated Aisha:One night the Prophet (ﷺ) was unable to sleep and said, "Would that a righteous man from my companions guarded me tonight." Suddenly we heard the clatter of arms, whereupon the Prophet (ﷺ) said, "Who is it?" It was said, "I am Sa`d, O Allah's Messenger (ﷺ)! I have come to guard you." The Prophet (ﷺ) then slept so soundly that we heard him snoring. Abu `Abdullah said: `Aisha said: Bilal said, "Would that I but stayed overnight in a valley with Idhkhir and Jalil (two kinds of grass) around me (i.e., in Mecca)." Then I told that to the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{7232}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَحَاسُدَ إِلاَّ فِي اثْنَتَيْنِ رَجُلٌ آتَاهُ اللَّهُ الْقُرْآنَ، فَهْوَ يَتْلُوهُ آنَاءَ اللَّيْلِ وَالنَّهَارِ يَقُولُ لَوْ أُوتِيتُ مِثْلَ مَا أُوتِيَ هَذَا لَفَعَلْتُ كَمَا يَفْعَلُ، وَرَجُلٌ آتَاهُ اللَّهُ مَالاً يُنْفِقُهُ فِي حَقِّهِ فَيَقُولُ لَوْ أُوتِيتُ مِثْلَ مَا أُوتِيَ لَفَعَلْتُ كَمَا يَفْعَلُ ‏"‏‏.‏ حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، بِهَذَا‏.‏\hadithno{7232}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Not to wish to be the like except of two men. A man whom Allah has given the (knowledge of the) Qur'an and he recites it during the hours of night and day and the one who wishes says: If I were given the same as this (man) has been given, I would do what he does, and a man whom Allah has given wealth and he spends it in the just and right way, in which case the one who wishes says, 'If I were given the same as he has been given, I would do what he does.' " (See Hadith 5025 and)}}
\hadithdefcmd{bukhari}{7233}{حَدَّثَنَا حَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَاصِمٍ، عَنِ النَّضْرِ بْنِ أَنَسٍ، قَالَ قَالَ أَنَسٌ ـ رضى الله عنه ـ لَوْلاَ أَنِّي سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَتَمَنَّوُا الْمَوْتَ ‏"‏ لَتَمَنَّيْتُ‏.‏\hadithno{7233}\hadithtrans{Narrated Anas:If I had not heard the Prophet (ﷺ) saying, "You should not long for death," I would have longed (for it)}}
\hadithdefcmd{bukhari}{7234}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا عَبْدَةُ، عَنِ ابْنِ أَبِي خَالِدٍ، عَنْ قَيْسٍ، قَالَ أَتَيْنَا خَبَّابَ بْنَ الأَرَتِّ نَعُودُهُ وَقَدِ اكْتَوَى سَبْعًا فَقَالَ لَوْلاَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَانَا أَنْ نَدْعُوَ بِالْمَوْتِ لَدَعَوْتُ بِهِ‏.‏\hadithno{7234}\hadithtrans{Narrated Qais:We went to pay a visit to Khabbab bin Al-Art and he had got himself branded at seven spots over his body. He said, "If Allah's Messenger (ﷺ) had not forbidden us to invoke Allah for death, I would have invoked for it}}
\hadithdefcmd{bukhari}{7235}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي عُبَيْدٍ ـ اسْمُهُ سَعْدُ بْنُ عُبَيْدٍ مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ أَزْهَرَ ـ عَنْ أَبِي هُرَيْرَةَ ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَتَمَنَّى أَحَدُكُمُ الْمَوْتَ إِمَّا مُحْسِنًا فَلَعَلَّهُ يَزْدَادُ، وَإِمَّا مُسِيئًا فَلَعَلَّهُ يَسْتَعْتِبُ ‏"‏‏.‏\hadithno{7235}\hadithtrans{Narrated Sa`d bin Ubaid:(the Maula of `Abdur-Rahman bin Azhar) Allah's Messenger (ﷺ) said, "None of you should long for death, for if he is a good man, he may increase his good deeds, and if he is an evil-doer, he may stop the evil deeds and repent}}
\hadithdefcmd{bukhari}{7236}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَنْقُلُ مَعَنَا التُّرَابَ يَوْمَ الأَحْزَابِ، وَلَقَدْ رَأَيْتُهُ وَارَى التُّرَابُ بَيَاضَ بَطْنِهِ يَقُولُ ‏ "‏ لَوْلاَ أَنْتَ مَا اهْتَدَيْنَا نَحْنُ، وَلاَ تَصَدَّقْنَا وَلاَ صَلَّيْنَا، فَأَنْزِلَنْ سَكِينَةً عَلَيْنَا، إِنَّ الأُلَى وَرُبَّمَا قَالَ الْمَلاَ قَدْ بَغَوْا عَلَيْنَا، إِذَا أَرَادُوا فِتْنَةً أَبَيْنَا ‏"‏ أَبَيْنَا يَرْفَعُ بِهَا صَوْتَهُ‏.‏\hadithno{7236}\hadithtrans{Narrated Al-Bara' bin `Azib:The Prophet (ﷺ) was carrying earth with us on the day of the battle of Al-Ahzab (confederates) and I saw that the dust was covering the whiteness of his `Abdomen, and he (the Prophet (ﷺ) ) was saying, "(O Allah) ! Without You, we would not have been guided, nor would we have given in charity, nor would we have prayed. So (O Allah!) please send tranquility (Sakina) upon us as they, (the chiefs of the enemy tribes) have rebelled against us. And if they intend affliction (i.e. want to frighten us and fight against us) then we would not (flee but withstand them). And the Prophet (ﷺ) used to raise his voice with it. (See Hadith No. 430 and 432, Vol)}}
\hadithdefcmd{bukhari}{7237}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمٍ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ ـ وَكَانَ كَاتِبًا لَهُ ـ قَالَ كَتَبَ إِلَيْهِ عَبْدُ اللَّهِ بْنُ أَبِي أَوْفَى فَقَرَأْتُهُ فَإِذَا فِيهِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَتَمَنَّوْا لِقَاءَ الْعَدُوِّ، وَسَلُوا اللَّهَ الْعَافِيَةَ ‏"‏‏.‏\hadithno{7237}\hadithtrans{Narrated `Abdullah bin Abi `Aufa:Allah's Messenger (ﷺ) said, "Do not long for meeting your enemy, and ask Allah for safety (from all sorts of evil)." (See Hadith No. 266, Vol)}}
\hadithdefcmd{bukhari}{7238}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، قَالَ ذَكَرَ ابْنُ عَبَّاسٍ الْمُتَلاَعِنَيْنِ فَقَالَ عَبْدُ اللَّهِ بْنُ شَدَّادٍ أَهِيَ الَّتِي قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كُنْتُ رَاجِمًا امْرَأَةً مِنْ غَيْرِ بَيِّنَةٍ ‏"‏‏.‏ قَالَ لاَ، تِلْكَ امْرَأَةٌ أَعْلَنَتْ‏.‏\hadithno{7238}\hadithtrans{Narrated Al-Qasim bin Muhammad:Ibn `Abbas mentioned the case of a couple on whom the judgment of Lian has been passed. `Abdullah bin Shaddad said, "Was that the lady in whose case the Prophet (ﷺ) said, "If I were to stone a lady to death without a proof (against her)?' "Ibn `Abbas said, "No! That was concerned with a woman who though being a Muslim used to arouse suspicion by her outright misbehavior." (See Hadith No. 230, Vol)}}
\hadithdefcmd{bukhari}{7239}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو حَدَّثَنَا عَطَاءٌ، قَالَ أَعْتَمَ النَّبِيُّ صلى الله عليه وسلم بِالْعِشَاءِ فَخَرَجَ عُمَرُ فَقَالَ الصَّلاَةَ يَا رَسُولَ اللَّهِ، رَقَدَ النِّسَاءُ وَالصِّبْيَانُ، فَخَرَجَ وَرَأْسُهُ يَقْطُرُ يَقُولُ ‏"‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي ـ أَوْ عَلَى النَّاسِ، وَقَالَ سُفْيَانُ أَيْضًا، عَلَى أُمَّتِي ـ لأَمَرْتُهُمْ بِالصَّلاَةِ هَذِهِ السَّاعَةَ ‏"‏‏.‏ قَالَ ابْنُ جُرَيْجٍ عَنْ عَطَاءٍ عَنِ ابْنِ عَبَّاسٍ أَخَّرَ النَّبِيُّ صلى الله عليه وسلم هَذِهِ الصَّلاَةَ فَجَاءَ عُمَرُ فَقَالَ يَا رَسُولَ اللَّهِ رَقَدَ النِّسَاءُ وَالْوِلْدَانُ‏.‏ فَخَرَجَ وَهْوَ يَمْسَحُ الْمَاءَ عَنْ شِقِّهِ يَقُولُ ‏"‏ إِنَّهُ لَلْوَقْتُ، لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي ‏"‏‏.‏ وَقَالَ عَمْرٌو حَدَّثَنَا عَطَاءٌ لَيْسَ فِيهِ ابْنُ عَبَّاسٍ أَمَّا عَمْرٌو فَقَالَ رَأْسُهُ يَقْطُرُ‏.‏ وَقَالَ ابْنُ جُرَيْجٍ يَمْسَحُ الْمَاءَ عَنْ شِقِّهِ‏.‏ وَقَالَ عَمْرٌو لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي‏.‏ وَقَالَ ابْنُ جُرَيْجٍ إِنَّهُ لَلْوَقْتُ، لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي‏.‏ وَقَالَ إِبْرَاهِيمُ بْنُ الْمُنْذِرِ حَدَّثَنَا مَعْنٌ، حَدَّثَنِي مُحَمَّدُ بْنُ مُسْلِمٍ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{7239}\hadithtrans{Narrated 'Ata:One night the Prophet (ﷺ) delayed the `Isha' prayer whereupon `Umar went to him and said, "The prayer, O Allah's Messenger (ﷺ)! The women and children had slept." The Prophet (ﷺ) came out with water dropping from his head, and said, "Were I not afraid that it would be hard for my followers (or for the people), I would order them to pray `Isha prayer at this time." (Various versions of this Hadith are given by the narrators with slight differences in expression but not in content)}}
\hadithdefcmd{bukhari}{7240}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ، سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ بِالسِّوَاكِ ‏"‏‏.‏\hadithno{7240}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Were I not afraid that it would be hard on my followers, I would order them to use the siwak (as obligatory, for cleaning the teeth)}}
\hadithdefcmd{bukhari}{7241}{حَدَّثَنَا عَيَّاشُ بْنُ الْوَلِيدِ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا حُمَيْدٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، رضى الله عنه قَالَ وَاصَلَ النَّبِيُّ صلى الله عليه وسلم آخِرَ الشَّهْرِ، وَوَاصَلَ أُنَاسٌ، مِنَ النَّاسِ فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لَوْ مُدَّ بِيَ الشَّهْرُ لَوَاصَلْتُ وِصَالاً يَدَعُ الْمُتَعَمِّقُونَ تَعَمُّقَهُمْ، إِنِّي لَسْتُ مِثْلَكُمْ، إِنِّي أَظَلُّ يُطْعِمُنِي رَبِّي وَيَسْقِينِ ‏"‏‏.‏ تَابَعَهُ سُلَيْمَانُ بْنُ مُغِيرَةَ عَنْ ثَابِتٍ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{7241}\hadithtrans{Narrated Anas:The Prophet (ﷺ) fasted Al-Wisal on the last days of the month. Some people did the same, and when the news reached the Prophet (ﷺ) he said, "If the month had been prolonged for me, then I would have fasted Wisal for such a long time that the most exaggerating ones among you would have given up their exaggeration. I am not like you; my Lord always makes me eat and drink}}
\hadithdefcmd{bukhari}{7242}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، وَقَالَ اللَّيْثُ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، أَخْبَرَهُ أَنَّ أَبَا هُرَيْرَةَ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْوِصَالِ، قَالُوا فَإِنَّكَ تُوَاصِلُ‏.‏ قَالَ ‏"‏ أَيُّكُمْ مِثْلِي، إِنِّي أَبِيتُ يُطْعِمُنِي رَبِّي وَيَسْقِينِ ‏"‏‏.‏ فَلَمَّا أَبَوْا أَنْ يَنْتَهُوا وَاصَلَ بِهِمْ يَوْمًا ثُمَّ يَوْمًا ثُمَّ رَأَوُا الْهِلاَلَ فَقَالَ ‏"‏ لَوْ تَأَخَّرَ لَزِدْتُكُمْ ‏"‏‏.‏ كَالْمُنَكِّلِ لَهُمْ‏.‏\hadithno{7242}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) forbade Al-Wisal. The people said (to him), "But you fast Al-`Wisal," He said, "Who among you is like me? When I sleep (at night), my Lord makes me eat and drink. But when the people refused to give up Al-Wisal, he fasted Al-Wisal along with them for two days and then they saw the crescent whereupon the Prophet (ﷺ) said, "If the crescent had not appeared I would have fasted for a longer period," as if he intended to punish them herewith}}
\hadithdefcmd{bukhari}{7243}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا أَشْعَثُ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَائِشَةَ، قَالَتْ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنِ الْجَدْرِ أَمِنَ الْبَيْتِ هُوَ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ قُلْتُ فَمَا لَهُمْ لَمْ يُدْخِلُوهُ فِي الْبَيْتِ قَالَ ‏"‏ إِنَّ قَوْمَكِ قَصَّرَتْ بِهِمُ النَّفَقَةُ ‏"‏‏.‏ قُلْتُ فَمَا شَأْنُ بَابِهِ مُرْتَفِعًا قَالَ ‏"‏ فَعَلَ ذَاكِ قَوْمُكِ، لِيُدْخِلُوا مَنْ شَاءُوا، وَيَمْنَعُوا مَنْ شَاءُوا، لَوْلاَ أَنَّ قَوْمَكِ حَدِيثٌ عَهْدُهُمْ بِالْجَاهِلِيَّةِ، فَأَخَافُ أَنْ تُنْكِرَ قُلُوبُهُمْ أَنْ أُدْخِلَ الْجَدْرَ فِي الْبَيْتِ، وَأَنْ أُلْصِقَ بَابَهُ فِي الأَرْضِ ‏"‏‏.‏\hadithno{7243}\hadithtrans{Narrated `Aisha:I asked the Prophet (ﷺ) about the wall (outside the Ka`ba). "Is it regarded as part of the Ka`ba?" He replied, "Yes." I said, "Then why didn't the people include it in the Ka`ba?" He said, "(Because) your people ran short of money." I asked, "Then why is its gate so high?" He replied, ''Your people did so in order to admit to it whom they would and forbid whom they would. Were your people not still close to the period of ignorance, and were I not afraid that their hearts might deny my action, then surely I would include the wall in the Ka`ba and make its gate touch the ground}}
\hadithdefcmd{bukhari}{7244}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْلاَ الْهِجْرَةُ لَكُنْتُ امْرَأً مِنَ الأَنْصَارِ، وَلَوْ سَلَكَ النَّاسُ وَادِيًا وَسَلَكَتِ الأَنْصَارُ وَادِيًا ـ أَوْ شِعْبًا ـ لَسَلَكْتُ وَادِيَ الأَنْصَارِ أَوْ شِعْبَ الأَنْصَارِ ‏"‏‏.‏\hadithno{7244}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "But for the emigration, I would have been one of the Ansar: and if the people took their way in a valley (or a mountain pass), I would take the Ansar's valley or the mountain pass}}
\hadithdefcmd{bukhari}{7245}{حَدَّثَنَا مُوسَى، حَدَّثَنَا وُهَيْبٌ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْلاَ الْهِجْرَةُ لَكُنْتُ امْرَأً مِنَ الأَنْصَارِ، وَلَوْ سَلَكَ النَّاسُ وَادِيًا أَوْ شِعْبًا، لَسَلَكْتُ وَادِيَ الأَنْصَارِ وَشِعْبَهَا ‏"‏‏.‏ تَابَعَهُ أَبُو التَّيَّاحِ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الشِّعْبِ‏.‏\hadithno{7245}\hadithtrans{Narrated `Abdullah bin Zaid:The Prophet (ﷺ) said, "But for the emigration, I would have been one of the Ansar; and if the people took their way in a valley (or a mountain pass), I would take Ansar's valley or their mountain pass}}
