% Auto-generated chapter 4 for nasai
% Hadiths in this chapter: 53

\hadithdefcmd{nasai}{396}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ بُكَيْرٍ، أَنَّ أَبَا السَّائِبِ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏‏ "‏‏ لاَ يَغْتَسِلْ أَحَدُكُمْ فِي الْمَاءِ الدَّائِمِ وَهُوَ جُنُبٌ ‏‏"‏‏ ‏‏.‏‏\hadithno{396}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'None of you should perform ghusl in standing water while he is Junub}}
\hadithdefcmd{nasai}{397}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ حَدَّثَنَا حِبَّانُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏‏ "‏‏ لاَ يَبُولَنَّ الرَّجُلُ فِي الْمَاءِ الدَّائِمِ ثُمَّ يَغْتَسِلُ مِنْهُ أَوْ يَتَوَضَّأُ ‏‏"‏‏ ‏‏.‏‏\hadithno{397}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"None of you should urinate into standing water and then perform Ghusl or Wudu' with it}}
\hadithdefcmd{nasai}{398}{أَخْبَرَنَا أَحْمَدُ بْنُ صَالِحٍ الْبَغْدَادِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي ابْنُ عَجْلاَنَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يُبَالَ فِي الْمَاءِ الدَّائِمِ ثُمَّ يُغْتَسَلَ فِيهِ مِنَ الْجَنَابَةِ ‏‏.‏‏\hadithno{398}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) forbade urinating into standing water and then performing Ghusl from Janabah in it}}
\hadithdefcmd{nasai}{399}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ سُفْيَانَ، عَنْ أَبِي الزِّنَادِ، عَنْ مُوسَى بْنِ أَبِي عُثْمَانَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يُبَالَ فِي الْمَاءِ الرَّاكِدِ ثُمَّ يُغْتَسَلَ مِنْهُ ‏‏.‏‏\hadithno{399}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) forbade urinating into standing water then performing Ghusl with it}}
\hadithdefcmd{nasai}{400}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لاَ يَبُولَنَّ أَحَدُكُمْ فِي الْمَاءِ الدَّائِمِ الَّذِي لاَ يَجْرِي ثُمَّ يَغْتَسِلُ مِنْهُ ‏‏.‏‏ قَالَ سُفْيَانُ قَالُوا لِهِشَامٍ - يَعْنِي ابْنَ حَسَّانَ - أَنَّ أَيُّوبَ إِنَّمَا يَنْتَهِي بِهَذَا الْحَدِيثِ إِلَى أَبِي هُرَيْرَةَ فَقَالَ إِنَّ أَيُّوبَ لَوِ اسْتَطَاعَ أَنْ لاَ يَرْفَعَ حَدِيثًا لَمْ يَرْفَعْهُ ‏‏.‏‏\hadithno{400}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"None of you should urinate into standing water which does not flow and then perform Ghusl with it." (One of the narrators) Sufyan said: "They said to Hisham - meaning Ibn Hassan - 'Ayyub only attributed this Hadith to Abu Hurairah?' So he said: 'If Ayyub is not able to raise up a narration then he does not raise it.'" [1] [1] That is, he narrated it from Abu Hurairah, rather than from him from the Prophet (ﷺ) while others narrated it in Marfu' form or "raised" to the Prophet (ﷺ) And perhaps by: "If he is able to not raise it" he means: "If he is not able to raise it." And Allah knows best}}
\hadithdefcmd{nasai}{401}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَطَاءٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏‏ "‏‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلاَ يَدْخُلِ الْحَمَّامَ إِلاَّ بِمِئْزَرٍ ‏‏"‏‏ ‏‏.‏‏\hadithno{401}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir that the Prophet (ﷺ) said:"Whoever believes in Allah and the Last Day, let him not enter a bath house except wearing an Izar (waist wrap)}}
\hadithdefcmd{nasai}{402}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَجْزَأَةَ بْنِ زَاهِرٍ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَدْعُو ‏‏ "‏‏ اللَّهُمَّ طَهِّرْنِي مِنَ الذُّنُوبِ وَالْخَطَايَا اللَّهُمَّ نَقِّنِي مِنْهَا كَمَا يُنَقَّى الثَّوْبُ الأَبْيَضُ مِنَ الدَّنَسِ اللَّهُمَّ طَهِّرْنِي بِالثَّلْجِ وَالْبَرَدِ وَالْمَاءِ الْبَارِدِ ‏‏"‏‏ ‏‏.‏‏\hadithno{402}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin Abi Awfa narrated that the Prophet (ﷺ) would supplicate:"Allahumma tahhirni min adh-dhunub wal-khataya. Allahumma naqqini minha kama yunaqqa ath-thawb al-abyad min ad-danas, Allahumma tahhirni bith-thalji wal-barad wal-ma' al-barid (O Allah, purify me of sin and error, O Allah cleanse me of it as a white garment is cleansed of dirt, O Allah purify me with snow and hail and cold water)}}
\hadithdefcmd{nasai}{403}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ مُحَمَّدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَزِيدَ، عَنْ رُقْبَةَ، عَنْ مَجْزَأَةَ الأَسْلَمِيِّ، عَنِ ابْنِ أَبِي أَوْفَى، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏‏ "‏‏ اللَّهُمَّ طَهِّرْنِي بِالثَّلْجِ وَالْبَرَدِ وَالْمَاءِ الْبَارِدِ اللَّهُمَّ طَهِّرْنِي مِنَ الذُّنُوبِ كَمَا يُطَهَّرُ الثَّوْبُ الأَبْيَضُ مِنَ الدَّنَسِ ‏‏"‏‏ ‏‏.‏‏\hadithno{403}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Abi Awfa said:"The Prophet (ﷺ) used to say: 'Allahumma tahhirni bith-thalji wal-barad wal-ma' al-barid, Allahumma tahhirni min adh-dhunub kama yutahhar ath-thawb al-abyad min ad-danas (O Allah, purify me with snow and hail and cold water, O Allah, purify me of sin as a white garment is cleansed of dirt)}}
\hadithdefcmd{nasai}{404}{أَخْبَرَنَا شُعَيْبُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَيْسٍ، قَالَ سَأَلْتُ عَائِشَةَ كَيْفَ كَانَ نَوْمُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْجَنَابَةِ أَيَغْتَسِلُ قَبْلَ أَنْ يَنَامَ أَوْ يَنَامُ قَبْلَ أَنْ يَغْتَسِلَ قَالَتْ كُلُّ ذَلِكَ قَدْ كَانَ يَفْعَلُ رُبَّمَا اغْتَسَلَ فَنَامَ وَرُبَّمَا تَوَضَّأَ فَنَامَ ‏‏.‏‏\hadithno{404}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah bin Abi Qais said:"I asked 'Aishah: 'How did the Messenger of Allah (ﷺ) sleep while he was Junub? Did he perform Ghusl before sleeping or sleep before performing Ghusl?' She said: 'He did both. Sometimes he would perform Ghusl then sleep, and sometimes he would perform Wudu' then sleep}}
\hadithdefcmd{nasai}{405}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ بُرْدٍ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ غُضَيْفِ بْنِ الْحَارِثِ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ فَسَأَلْتُهَا فَقُلْتُ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْتَسِلُ مِنْ أَوَّلِ اللَّيْلِ أَوْ مِنْ آخِرِهِ قَالَتْ كُلُّ ذَلِكَ كَانَ رُبَّمَا اغْتَسَلَ مِنْ أَوَّلِهِ وَرُبَّمَا اغْتَسَلَ مِنْ آخِرِهِ ‏‏.‏‏ قُلْتُ الْحَمْدُ لِلَّهِ الَّذِي جَعَلَ فِي الأَمْرِ سَعَةً ‏‏.‏‏\hadithno{405}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ghudaif bin Al-Harith said:"I entered upon 'Aishah and asked her: 'Did the Messenger of Allah (ﷺ) perform Ghusl at the beginning of the night or at the end?' She said: 'Both. Sometimes he performed Ghusl at the beginning and sometimes at the end.' I said: 'Praise be to Allah who has made the matter flexible}}
\hadithdefcmd{nasai}{406}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا النُّفَيْلِيُّ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ يَعْلَى، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً يَغْتَسِلُ بِالْبَرَازِ فَصَعِدَ الْمِنْبَرَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَقَالَ ‏‏ "‏‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ حَلِيمٌ حَيِيٌّ سِتِّيرٌ يُحِبُّ الْحَيَاءَ وَالسَّتْرَ فَإِذَا اغْتَسَلَ أَحَدُكُمْ فَلْيَسْتَتِرْ ‏‏"‏‏ ‏‏.‏‏\hadithno{406}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ya'la that the Messenger of Allah (ﷺ) saw a man performing Ghusl in an open place, so he ascended the Minbar and praised and glorified Allah, then he said:'Allah, the Mighty and Sublime, is forbearing, modest and concealing, and He loves modesty and concealment. When any one of you performs Ghusl, let him conceal himself}}
\hadithdefcmd{nasai}{407}{أَخْبَرَنَا أَبُو بَكْرِ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، قَالَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ يَعْلَى، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏‏ "‏‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ سِتِّيرٌ فَإِذَا أَرَادَ أَحَدُكُمْ أَنْ يَغْتَسِلَ فَلْيَتَوَارَ بِشَىْءٍ ‏‏"‏‏ ‏‏.‏‏\hadithno{407}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Safwan bin Ya'la that his father said:"The Messenger of Allah (ﷺ) said: 'Allah loves concealment, so when any one of you performs Ghusl let him conceal himself with something}}
\hadithdefcmd{nasai}{408}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبِيدَةُ، عَنِ الأَعْمَشِ، عَنْ سَالِمٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، قَالَتْ وَضَعْتُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم مَاءً - قَالَتْ - فَسَتَرْتُهُ فَذَكَرَتِ الْغُسْلَ قَالَتْ ثُمَّ أَتَيْتُهُ بِخِرْقَةٍ فَلَمْ يُرِدْهَا ‏‏.‏‏\hadithno{408}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Maimunah said:"I put some water out for the Messenger of Allah (ﷺ), then I concealed him" - and she mentioned how he performed Ghusl, then she said: "Then I brought him a cloth (a towel) but he did not want it}}
\hadithdefcmd{nasai}{409}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصِ بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏‏ "‏‏ بَيْنَمَا أَيُّوبُ عَلَيْهِ الصَّلاَةُ وَالسَّلاَمُ يَغْتَسِلُ عُرْيَانًا خَرَّ عَلَيْهِ جَرَادٌ مِنْ ذَهَبٍ فَجَعَلَ يَحْثِي فِي ثَوْبِهِ قَالَ فَنَادَاهُ رَبُّهُ عَزَّ وَجَلَّ يَا أَيُّوبُ أَلَمْ أَكُنْ أَغْنَيْتُكَ قَالَ بَلَى يَا رَبِّ وَلَكِنْ لاَ غِنَى بِي عَنْ بَرَكَاتِكَ ‏‏"‏‏ ‏‏.‏‏\hadithno{409}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'While Ayyub, peace be upon him, was bathing naked, locusts of gold landed on him and he started to collect them in his garment. Then his Lord called him (saying): "O Ayyub, did I not make you rich?" he said: "Yes, O Lord, but I cannot do without Your blessing}}
\hadithdefcmd{nasai}{410}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا بْنِ دِينَارٍ، قَالَ حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ بْنِ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْتَسِلُ فِي الإِنَاءِ وَهُوَ الْفَرَقُ وَكُنْتُ أَغْتَسِلُ أَنَا وَهُوَ مِنْ إِنَاءٍ وَاحِدٍ ‏‏.‏‏\hadithno{410}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) used to perform Ghusl from a vessel which was the size of a Faraq [1] and he and I used to perform Ghusl from a single vessel." [1] See No}}
\hadithdefcmd{nasai}{411}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ هِشَامٍ، ح وَأَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَغْتَسِلُ وَأَنَا مِنْ إِنَاءٍ وَاحِدٍ نَغْتَرِفُ مِنْهُ جَمِيعًا ‏‏.‏‏ وَقَالَ سُوَيْدٌ قَالَتْ كُنْتُ أَنَا ‏‏.‏‏\hadithno{411}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah (ﷺ) used to perform Ghusl, he and I from a single vessel, both of us scooping water from it}}
\hadithdefcmd{nasai}{412}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، قَالَ سَمِعْتُ الْقَاسِمَ، يُحَدِّثُ عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ مِنَ الْجَنَابَةِ ‏‏.‏‏\hadithno{412}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdur-Rahman bin Al-Qasim said:"I heard Al-Qasim narrating that 'Aishah said: 'I used to perform Ghusl - the Messenger of Allah (ﷺ) and I - from a single vessel for Janabah}}
\hadithdefcmd{nasai}{413}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ لَقَدْ رَأَيْتُنِي أُنَازِعُ رَسُولَ اللَّهِ صلى الله عليه وسلم الإِنَاءَ أَغْتَسِلُ أَنَا وَهُوَ مِنْهُ ‏‏.‏‏\hadithno{413}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"I remember competing over the vessel [1] with the Messenger of Allah (ﷺ), when he and I were performing Ghusl from it." [1] See the following narration and no}}
\hadithdefcmd{nasai}{414}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ، ح وَأَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ عَاصِمٍ، عَنْ مُعَاذَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ أُبَادِرُهُ وَيُبَادِرُنِي حَتَّى يَقُولَ ‏‏ "‏‏ دَعِي لِي ‏‏"‏‏ ‏‏.‏‏ وَأَقُولَ أَنَا دَعْ لِي ‏‏.‏‏ قَالَ سُوَيْدٌ يُبَادِرُنِي وَأُبَادِرُهُ فَأَقُولُ دَعْ لِي دَعْ لِي ‏‏.‏‏\hadithno{414}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"I used to perform Ghusl - the Messenger of Allah (ﷺ) and I - from one vessel. He would compete with me and I would with him (to take the water) until he would say: 'Leave me some,' and I would say, 'Leave me some}}
\hadithdefcmd{nasai}{415}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ مُحَمَّدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى بْنِ أَعْيَنَ، قَالَ حَدَّثَنَا أَبِي، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، قَالَ حَدَّثَتْنِي أُمُّ هَانِئٍ، أَنَّهَا دَخَلَتْ عَلَى النَّبِيِّ صلى الله عليه وسلم يَوْمَ فَتْحِ مَكَّةَ وَهُوَ يَغْتَسِلُ قَدْ سَتَرَتْهُ بِثَوْبٍ دُونَهُ فِي قَصْعَةٍ فِيهَا أَثَرُ الْعَجِينِ ‏‏.‏‏ قَالَتْ فَصَلَّى الضُّحَى فَمَا أَدْرِي كَمْ صَلَّى حِينَ قَضَى غُسْلَهُ ‏‏.‏‏\hadithno{415}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Umm Hani' narrated that she entered upon the Prophet (ﷺ) on the day of the Conquest of Makkah, when he was performing Ghusl - while a garment was screening him - from a vessel in which were traces of dough. She said:He prayed Ad-Duha - but I do not know how many Rak'ahs he prayed - after he finished Ghusl}}
\hadithdefcmd{nasai}{416}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ إِبْرَاهِيمَ بْنِ طَهْمَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، أَنَّ عَائِشَةَ، قَالَتْ لَقَدْ رَأَيْتُنِي أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ هَذَا فَإِذَا تَوْرٌ مَوْضُوعٌ مِثْلُ الصَّاعِ أَوْ دُونَهُ فَنَشْرَعُ فِيهِ جَمِيعًا فَأُفِيضُ عَلَى رَأْسِي بِيَدَىَّ ثَلاَثَ مَرَّاتٍ وَمَا أَنْقُضُ لِي شَعْرًا ‏‏.‏‏\hadithno{416}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah said:"I remember performing Ghusl - myself and the Messenger of Allah (ﷺ), from this" - a vessel like a Sa' or smaller. "We both started taking water from it and I poured water over my head with my hand, three times, without undoing any of my hair}}
\hadithdefcmd{nasai}{417}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ وَكِيعٍ، عَنْ مِسْعَرٍ، وَسُفْيَانَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ لأَنْ أُصْبِحَ مُطَّلِيًا بِقَطِرَانٍ أَحَبُّ إِلَىَّ مِنْ أَنْ أُصْبِحَ مُحْرِمًا أَنْضَخُ طِيبًا ‏‏.‏‏ فَدَخَلْتُ عَلَى عَائِشَةَ فَأَخْبَرْتُهَا بِقَوْلِهِ فَقَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَطَافَ عَلَى نِسَائِهِ ثُمَّ أَصْبَحَ مُحْرِمًا ‏‏.‏‏\hadithno{417}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibrahim bin Muhammad bin Al-Muntashir that his father said:"I heard Ibn 'Umar say: 'I would rather wake up in the morning covered in tar than wake up and enter Ihram with the smell of perfume coming from me.' I entered upon 'Aishah and told her what he had said, and she said: 'I put perfume on the Messenger of Allah (ﷺ) and he went round to all his wives, then in the morning he entered Ihram}}
\hadithdefcmd{nasai}{418}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ سَالِمٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، قَالَتْ تَوَضَّأَ رَسُولُ اللَّهِ صلى الله عليه وسلم وُضُوءَهُ لِلصَّلاَةِ غَيْرَ رِجْلَيْهِ وَغَسَلَ فَرْجَهُ وَمَا أَصَابَهُ ثُمَّ أَفَاضَ عَلَيْهِ الْمَاءَ ثُمَّ نَحَّى رِجْلَيْهِ فَغَسَلَهُمَا ‏‏.‏‏ قَالَتْ هَذِهِ غِسْلَةٌ لِلْجَنَابَةِ ‏‏.‏‏\hadithno{418}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Maimunah said:"The Messenger of Allah (ﷺ) performed Wudu' as for prayer, but did not wash his feet, and he washed his private part and whatever had got onto it, then he poured water over himself, then he moved his feet and washed them." She said: "This is Ghusl from Janabah}}
\hadithdefcmd{nasai}{419}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ بِنْتِ الْحَارِثِ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ يَبْدَأُ فَيَغْسِلُ يَدَيْهِ ثُمَّ يُفْرِغُ بِيَمِينِهِ عَلَى شِمَالِهِ فَيَغْسِلُ فَرْجَهُ ثُمَّ يَضْرِبُ بِيَدِهِ عَلَى الأَرْضِ ثُمَّ يَمْسَحُهَا ثُمَّ يَغْسِلُهَا ثُمَّ يَتَوَضَّأُ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ يُفْرِغُ عَلَى رَأْسِهِ وَعَلَى سَائِرِ جَسَدِهِ ثُمَّ يَتَنَحَّى فَيَغْسِلُ رِجْلَيْهِ ‏‏.‏‏\hadithno{419}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Maimunah bint Al-Harith, the wife of the Prophet (ﷺ), said:"When the Messenger of Allah (ﷺ) performed Ghusl from Janabah, he would start by washing his hands, then he would pour water with his right hand onto his left and wash his private part, then he would strike his hand on the ground then wipe it then wash it. Then he would perform Wudu' as for prayer, then he would pour water on his head and all of his body. Then he would move and wash his feet}}
\hadithdefcmd{nasai}{420}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ غَسَلَ يَدَيْهِ ثُمَّ تَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ اغْتَسَلَ ثُمَّ يُخَلِّلُ بِيَدِهِ شَعْرَهُ حَتَّى إِذَا ظَنَّ أَنَّهُ قَدْ أَرْوَى بَشَرَتَهُ أَفَاضَ عَلَيْهِ الْمَاءَ ثَلاَثَ مَرَّاتٍ ثُمَّ غَسَلَ سَائِرَ جَسَدِهِ ‏.‏\hadithno{420}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"When the Messenger of Allah (ﷺ) performed Ghusl from Janabah, he would wash his hands, then perform Wudu' as for prayer, then he would perform Ghusl, then run his fingers through his hair to be sure that the water pour water over his head three times, then wash the rest of his body}}
\hadithdefcmd{nasai}{421}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ شُعْبَةَ، عَنِ الأَشْعَثِ بْنِ أَبِي الشَّعْثَاءِ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُحِبُّ التَّيَمُّنَ مَا اسْتَطَاعَ فِي طُهُورِهِ وَتَنَعُّلِهِ وَتَرَجُّلِهِ وَقَالَ بِوَاسِطٍ فِي شَأْنِهِ كُلِّهِ ‏.‏\hadithno{421}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Prophet (ﷺ) used to like to start with the right as much as he could when purifying himself, putting on sandals and combing his hair" - and he (the narrator) said in Wasit (a place in Iraq): "And in all his affairs}}
\hadithdefcmd{nasai}{422}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ بْنِ خَالِدٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، - هُوَ ابْنُ سَمَاعَةَ - قَالَ أَنْبَأَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، وَعَنْ عَمْرِو بْنِ سَعْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْغُسْلِ مِنَ الْجَنَابَةِ وَاتَّسَقَتِ الأَحَادِيثُ عَلَى هَذَا يَبْدَأُ فَيُفْرِغُ عَلَى يَدِهِ الْيُمْنَى مَرَّتَيْنِ أَوْ ثَلاَثًا ثُمَّ يُدْخِلُ يَدَهُ الْيُمْنَى فِي الإِنَاءِ فَيَصُبُّ بِهَا عَلَى فَرْجِهِ وَيَدُهُ الْيُسْرَى عَلَى فَرْجِهِ فَيَغْسِلُ مَا هُنَالِكَ حَتَّى يُنْقِيَهُ ثُمَّ يَضَعُ يَدَهُ الْيُسْرَى عَلَى التُّرَابِ إِنْ شَاءَ ثُمَّ يَصُبُّ عَلَى يَدِهِ الْيُسْرَى حَتَّى يُنْقِيَهَا ثُمَّ يَغْسِلُ يَدَيْهِ ثَلاَثًا وَيَسْتَنْشِقُ وَيُمَضْمِضُ وَيَغْسِلُ وَجْهَهُ وَذِرَاعَيْهِ ثَلاَثًا ثَلاَثًا حَتَّى إِذَا بَلَغَ رَأْسَهُ لَمْ يَمْسَحْ وَأَفْرَغَ عَلَيْهِ الْمَاءَ فَهَكَذَا كَانَ غُسْلُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِيمَا ذُكِرَ ‏.‏\hadithno{422}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Salamah from 'Aishah, and, from 'Amr bin Sa'd, from Nafi', from Ibn 'Umar:That 'Umar asked the Messenger of Allah (ﷺ) about Ghusl from Janabah - and the narrations agree on this - that one should start by pouring water on the right hand two or three times, then put the right hand into the vessel and pour water with it onto the private parts, with the left hand on the private parts to wash off whatever is there, until it is clean; then put the left hand on the dust if one wants to, then pour water over the left hand until it is clean; then wash the hands three times, (sniff water into the nose) and rinse the mouth, and wash the face and forearms, three times each until when reaching the head, he does not wipe the head, rather he pours water over it. This is how the Messenger of Allah (ﷺ) performed Ghusl according to what was mentioned}}
\hadithdefcmd{nasai}{423}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ غَسَلَ يَدَيْهِ ثُمَّ تَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ يُخَلِّلُ رَأْسَهُ بِأَصَابِعِهِ حَتَّى إِذَا خُيِّلَ إِلَيْهِ أَنَّهُ قَدِ اسْتَبْرَأَ الْبَشَرَةَ غَرَفَ عَلَى رَأْسِهِ ثَلاَثًا ثُمَّ غَسَلَ سَائِرَ جَسَدِهِ ‏.‏\hadithno{423}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"When the Messenger of Allah (ﷺ0 performed Ghusl from Janabah, he would wash his hands, then perform Wudu' as for prayer, then run his fingers through his hair until he was sure the water had reached the scalp, then he would pour water over his head three times, then wash the rest of his body)}}
\hadithdefcmd{nasai}{424}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، عَنْ حَنْظَلَةَ بْنِ أَبِي سُفْيَانَ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ دَعَا بِشَىْءٍ نَحْوِ الْحِلاَبِ فَأَخَذَ بِكَفِّهِ بَدَأَ بِشِقِّ رَأْسِهِ الأَيْمَنِ ثُمَّ الأَيْسَرِ ثُمَّ أَخَذَ بِكَفَّيْهِ فَقَالَ بِهِمَا عَلَى رَأْسِهِ ‏.‏\hadithno{424}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"When the Messenger of Allah (ﷺ) performed Ghusl from Janabah, he would call for something like a vessel used for milking a she-camel, then he would take (some water) in his hand and start with the right side of his head, then the left, then take (some water) in his hands and start pouring it on his head}}
\hadithdefcmd{nasai}{425}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، عَنْ يَحْيَى، عَنْ شُعْبَةَ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، ح وَأَنْبَأَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ سُلَيْمَانَ بْنَ صُرَدٍ، يُحَدِّثُ عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم ذُكِرَ عِنْدَهُ الْغُسْلُ فَقَالَ ‏ "‏ أَمَّا أَنَا فَأُفْرِغُ عَلَى رَأْسِي ثَلاَثًا ‏"‏ ‏.‏ لَفْظُ سُوَيْدٍ ‏.‏\hadithno{425}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jubair bin Mut'im that mention of Ghusl was made in the presence of the Prophet (ﷺ) and he said:"As for me, I pour water on my head three times}}
\hadithdefcmd{nasai}{426}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ مُخَوَّلٍ، عَنْ أَبِي جَعْفَرٍ، عَنْ جَابِرٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اغْتَسَلَ أَفْرَغَ عَلَى رَأْسِهِ ثَلاَثًا ‏.‏\hadithno{426}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jabir said:"When the Messenger of Allah (ﷺ) performed Ghusl, he would pour water on his head three times}}
\hadithdefcmd{nasai}{427}{أَخْبَرَنَا الْحَسَنُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا عَفَّانُ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا مَنْصُورُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّهِ، صَفِيَّةَ بِنْتِ شَيْبَةَ عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، سَأَلَتِ النَّبِيَّ صلى الله عليه وسلم قَالَتْ يَا رَسُولَ اللَّهِ كَيْفَ أَغْتَسِلُ عِنْدَ الطُّهُورِ قَالَ ‏"‏ خُذِي فِرْصَةً مُمَسَّكَةً فَتَوَضَّئِي بِهَا ‏"‏ ‏.‏ قَالَتْ كَيْفَ أَتَوَضَّأُ بِهَا قَالَ ‏"‏ تَوَضَّئِي بِهَا ‏"‏ ‏.‏ قَالَتْ كَيْفَ أَتَوَضَّأُ بِهَا قَالَتْ ثُمَّ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَبَّحَ وَأَعْرَضَ عَنْهَا فَفَطِنَتْ عَائِشَةُ لِمَا يُرِيدُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَتْ فَأَخَذْتُهَا وَجَبَذْتُهَا إِلَىَّ فَأَخْبَرْتُهَا بِمَا يُرِيدُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{427}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah:"A woman asked the Prophet (ﷺ): 'O Messenger of Allah, how should I perform Ghusl when I become pure?' He said: 'Take a piece of cotton wool scented with musk and clean yourself with it.' She said: 'How should I clean myself with it?' He said: 'Clean yourself with it.' She said: "How should I clean myself with it?' The Messenger of Allah (ﷺ) said: 'Subhan Allah!' and turned away from her." 'Aishah understood what the Messenger of Allah (ﷺ) meant, and said: "So I pulled her toward me and told her what the Messenger of Allah (ﷺ) meant}}
\hadithdefcmd{nasai}{428}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتِ اغْتَسَلَ النَّبِيُّ صلى الله عليه وسلم مِنَ الْجَنَابَةِ فَغَسَلَ فَرْجَهُ وَدَلَكَ يَدَهُ بِالأَرْضِ أَوِ الْحَائِطِ ثُمَّ تَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ أَفَاضَ عَلَى رَأْسِهِ وَسَائِرِ جَسَدِهِ ‏.‏\hadithno{428}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Maimunah, the wife of the Prophet (ﷺ), said:"The Prophet (ﷺ) performed Ghusl from Janabah; he washed his private part then rubbed his hand on the ground or the wall, then he performed Wudu' as for prayer, then he poured water over his head and the rest of his body}}
\hadithdefcmd{nasai}{429}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لَهُ - قَالُوا حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، أَتَيْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ فَسَأَلْنَاهُ عَنْ حَجَّةِ الْوَدَاعِ، فَحَدَّثَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ لِخَمْسٍ بَقِينَ مِنْ ذِي الْقَعْدَةِ ‏.‏ وَخَرَجْنَا مَعَهُ حَتَّى إِذَا أَتَى ذَا الْحُلَيْفَةِ وَلَدَتْ أَسْمَاءُ بِنْتُ عُمَيْسٍ مُحَمَّدَ بْنَ أَبِي بَكْرٍ فَأَرْسَلَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم كَيْفَ أَصْنَعُ فَقَالَ ‏ "‏ اغْتَسِلِي ثُمَّ اسْتَثْفِرِي ثُمَّ أَهِلِّي ‏"‏ ‏.‏\hadithno{429}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ja'far bin Muhammad said:"My father told me: 'We came to Jabir bin 'Abdullah and asked him about the Hajj of the Prophet (ﷺ). He narrated; "The Messenger of Allah (ﷺ) set out when there were five (days) remaining in Dhul-Qa'dah, and we set out with him. When he came to Dhul-Hulaifah, Asma' bint 'Umais gave birth to Muhammad bin Abi Bakr. She sent word to the Messenger of Allah (ﷺ) asking what he should do. He said: 'Perform Ghusl, bind yourself with a cloth then begin (the Talbiyah for Ihram)}}
\hadithdefcmd{nasai}{430}{أَخْبَرَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ، قَالَ حَدَّثَنَا أَبِي، حَدَّثَنَا حَسَنٌ، عَنْ أَبِي إِسْحَاقَ، ح وَأَنْبَأَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يَتَوَضَّأُ بَعْدَ الْغُسْلِ ‏.‏\hadithno{430}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) would not perform Wudu' after Ghusl}}
\hadithdefcmd{nasai}{431}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ بِشْرٍ، - وَهُوَ ابْنُ الْمُفَضَّلِ - قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، قَالَ قَالَتْ عَائِشَةُ كُنْتُ أُطَيِّبُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَيَطُوفُ عَلَى نِسَائِهِ ثُمَّ يُصْبِحُ مُحْرِمًا يَنْضَخُ طِيبًا ‏.‏\hadithno{431}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah said:"I used to put perfume on the Messenger of Allah (ﷺ) and he would go around to all his wives, then enter Ihram in the morning with the smell of perfume coming from him}}
\hadithdefcmd{nasai}{432}{أَخْبَرَنَا الْحَسَنُ بْنُ إِسْمَاعِيلَ بْنِ سُلَيْمَانَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا سَيَّارٌ، عَنْ يَزِيدَ الْفَقِيرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُعْطِيتُ خَمْسًا لَمْ يُعْطَهُنَّ أَحَدٌ قَبْلِي نُصِرْتُ بِالرُّعْبِ مَسِيرَةَ شَهْرٍ وَجُعِلَتْ لِيَ الأَرْضُ مَسْجِدًا وَطَهُورًا فَأَيْنَمَا أَدْرَكَ الرَّجُلَ مِنْ أُمَّتِي الصَّلاَةُ يُصَلِّي وَأُعْطِيتُ الشَّفَاعَةَ وَلَمْ يُعْطَ نَبِيٌّ قَبْلِي وَبُعِثْتُ إِلَى النَّاسِ كَافَّةً وَكَانَ النَّبِيُّ يُبْعَثُ إِلَى قَوْمِهِ خَاصَّةً ‏"‏ ‏.‏\hadithno{432}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"The Messenger of Allah (ﷺ) said: 'I have been given five things that were not given to anyone before me: I have been supported with fear being struck into the hearts of my enemy for a distance of one month's travel; the earth has been made a place of prostration and a means of purification for me, so wherever a man of my Ummah is when the time for prayer comes, let him pray; I have been given the intercession which was not given to any Prophet before me; and I have been sent to all of mankind whereas the Prophets before me were sent to their own people}}
\hadithdefcmd{nasai}{433}{أَخْبَرَنَا مُسْلِمُ بْنُ عَمْرِو بْنِ مُسْلِمٍ، قَالَ حَدَّثَنِي ابْنُ نَافِعٍ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، عَنْ بَكْرِ بْنِ سَوَادَةَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ، أَنَّ رَجُلَيْنِ، تَيَمَّمَا وَصَلَّيَا ثُمَّ وَجَدَا مَاءً فِي الْوَقْتِ فَتَوَضَّأَ أَحَدُهُمَا وَعَادَ لِصَلاَتِهِ مَا كَانَ فِي الْوَقْتِ وَلَمْ يُعِدِ الآخَرُ فَسَأَلاَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ لِلَّذِي لَمْ يُعِدْ ‏"‏ أَصَبْتَ السُّنَّةَ وَأَجْزَأَتْكَ صَلاَتُكَ ‏"‏ ‏.‏ وَقَالَ لِلآخَرِ ‏"‏ أَمَّا أَنْتَ فَلَكَ مِثْلُ سَهْمِ جَمْعٍ ‏"‏ ‏.‏\hadithno{433}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Sa'eed that two men performed Tayammum and prayed, then they found water when there was still time left for prayer. One of them performed Wudu' and repeated the prayer, and the other did not. They asked the Prophet (ﷺ) about that and he said to the one who did not repeat the prayer:"You followed the Sunnah and your prayer is acceptable." And he said to the other: "And you will have something like the reward of two prayers}}
\hadithdefcmd{nasai}{434}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ لَيْثِ بْنِ سَعْدٍ، قَالَ حَدَّثَنِي عَمِيرَةُ، وَغَيْرُهُ، عَنْ بَكْرِ بْنِ سَوَادَةَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ رَجُلَيْنِ، وَسَاقَ الْحَدِيثَ، ‏.‏\hadithno{434}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Ata' bin Yasar that two men - and he quoted the Hadith}}
\hadithdefcmd{nasai}{434p2}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، أَنْبَأَنَا أُمَيَّةُ بْنُ خَالِدٍ، حَدَّثَنَا شُعْبَةُ، أَنَّ مُخَارِقًا، أَخْبَرَهُمْ عَنْ طَارِقِ بْنِ شِهَابٍ، أَنَّ رَجُلاً، أَجْنَبَ فَلَمْ يُصَلِّ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ ‏"‏ أَصَبْتَ ‏"‏ ‏.‏ فَأَجْنَبَ رَجُلٌ آخَرُ فَتَيَمَّمَ وَصَلَّى فَأَتَاهُ فَقَالَ نَحْوًا مِمَّا قَالَ لِلآخَرِ يَعْنِي ‏"‏ أَصَبْتَ ‏"‏ ‏.‏\hadithno{434.2}\hadithtrans{It was narrated from Tariq bin Shaihab that a man became Junub and did not pray. He came to the Prophet (ﷺ) and told him about that, and he said:"You did the right thing." Then another man became Junub so he performed Tayammum and prayed. He came (to the Prophet (ﷺ)) who said to him what he had said to the other man- meaning, "You did the right thing}}
\hadithdefcmd{nasai}{435}{أَخْبَرَنَا عَلِيُّ بْنُ مَيْمُونٍ، قَالَ حَدَّثَنَا مَخْلَدُ بْنُ يَزِيدَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ تَذَاكَرَ عَلِيٌّ وَالْمِقْدَادُ وَعَمَّارٌ فَقَالَ عَلِيٌّ إِنِّي امْرَؤٌ مَذَّاءٌ وَإِنِّي أَسْتَحِي أَنْ أَسْأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم لِمَكَانِ ابْنَتِهِ مِنِّي فَيَسْأَلُهُ أَحَدُكُمَا فَذَكَرَ لِي أَنَّ أَحَدَهُمَا وَنَسِيتُهُ سَأَلَهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ ذَاكَ الْمَذْىُ إِذَا وَجَدَهُ أَحَدُكُمْ فَلْيَغْسِلْ ذَلِكَ مِنْهُ وَلْيَتَوَضَّأْ وُضُوءَهُ لِلصَّلاَةِ أَوْ كَوُضُوءِ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{435}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"Ali, Al-Miqdad and 'Ammar were talking. 'Ali said: 'I am a man who emits a lot of Madhi but I am too shy to ask the Messenger of Allah (ﷺ) about that because of his daughter's position with me, so let one of you ask him.' He told me that one of them - but I forgot who - asked him, and the Prophet (ﷺ) said: 'That is Madhi. If any one of you notices that, let him wash it off himself and perform Wudu' as for prayer or similar to the Wudu' of prayer}}
\hadithdefcmd{nasai}{436}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ قَالَ: حَدَّثَنَا عَبِيدَةُ قَالَ: حَدَّثَنَا سُلَيْمَانُ الأَعْمَشُ عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ عَنْ عَلِيٍّ رَضِيَ اللَّهُ عَنْهُ قَالَ: كُنْتُ رَجُلاً مَذَّاءً فَأَمَرْتُ رَجُلاً فَسَأَلَ النَّبِيَّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ فَقَالَ: «فِيهِ الْوُضُوءُ»\hadithno{436}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ali, may Allah be please with him, said:"I was a man who emotted a great deal of Madhi. I told a man to ask the Prophet (ﷺ) (about that) and he said: 'Wudu' (is required) for that}}
\hadithdefcmd{nasai}{437}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي سُلَيْمَانُ الأَعْمَشُ، قَالَ سَمِعْتُ مُنْذِرًا، عَنْ مُحَمَّدِ بْنِ عَلِيٍّ، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ اسْتَحْيَيْتُ أَنْ أَسْأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْمَذْىِ مِنْ أَجْلِ فَاطِمَةَ فَأَمَرْتُ الْمِقْدَادَ فَسَأَلَهُ فَقَالَ ‏ "‏ فِيهِ الْوُضُوءُ ‏"‏ ‏.‏\hadithno{437}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Ali said:"I felt too shy to ask the Messenger of Allah (ﷺ) about Madhi because of Fatimah, so I told Al-Miqdad to ask him, and he said: 'Wudu' (is required) for that}}
\hadithdefcmd{nasai}{438}{أَخْبَرَنَا أَحْمَدُ بْنُ عِيسَى عَنِ ابْنِ وَهْبٍ وَذَكَرَ كَلِمَةً مَعْنَاهَا أَخْبَرَنِي مَخْرَمَةُ بْنُ بُكَيْرٍ عَنْ أَبِيهِ عَنْ سُلَيْمَانَ بْنِ يَسَارٍ عَنِ ابْنِ عَبَّاسٍ قَالَ: قَالَ عَلِيٌّ رَضِيَ اللَّهُ عَنْهُ أَرْسَلْتُ الْمِقْدَادَ إِلَى رَسُولِ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ يَسْأَلُهُ عَنِ الْمَذْيِ فَقَالَ: «تَوَضَّأْ وَانْضَحْ فَرْجَكَ». قَالَ أَبُو عَبْدِ الرَّحْمَنِ: مَخْرَمَةُ لَمْ يَسْمَعْ مِنْ أَبِيهِ شَيْئًا\hadithno{438}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ali said:"I sent Al-Miqdad to the Messenger of Allah (ﷺ) to ask him about Madhi, and he said: 'Perform Wudu' and sprinkle water over your private part.'" Abu 'Abdur-Rahman said: Makhramah (one of the narrators) did not hear anything from his father}}
\hadithdefcmd{nasai}{439}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ لَيْثِ بْنِ سَعْدٍ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، قَالَ أَرْسَلَ عَلِيُّ بْنُ أَبِي طَالِبٍ - رضى الله عنه - الْمِقْدَادَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَسْأَلُهُ عَنِ الرَّجُلِ يَجِدُ الْمَذْىَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَغْسِلُ ذَكَرَهُ ثُمَّ لْيَتَوَضَّأْ ‏"‏ ‏.‏\hadithno{439}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Sulaiman bin Yasar said:"Ali bin Abi Talib sent Al-Miqdad to the Messenger of Allah (ﷺ) to ask him about a man who notices Madhi. The Messenger of Allah (ﷺ) said: 'Let him wash his penis then perform Wudu}}
\hadithdefcmd{nasai}{440}{أَخْبَرَنَا عُتْبَةُ بْنُ عَبْدِ اللَّهِ، قَالَ قُرِئَ عَلَى مَالِكٍ وَأَنَا أَسْمَعُ، عَنْ أَبِي النَّضْرِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنِ الْمِقْدَادِ بْنِ الأَسْوَدِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، رضى الله عنه أَمَرَهُ أَنْ يَسْأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الرَّجُلِ إِذَا دَنَا مِنَ الْمَرْأَةِ فَخَرَجَ مِنْهُ الْمَذْىُ فَإِنَّ عِنْدِي ابْنَتَهُ وَأَنَا أَسْتَحْيِي أَنْ أَسْأَلَهُ ‏.‏ فَسَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ إِذَا وَجَدَ أَحَدُكُمْ ذَلِكَ فَلْيَنْضَحْ فَرْجَهُ وَلْيَتَوَضَّأْ وُضُوءَهُ لِلصَّلاَةِ ‏"‏ ‏.‏\hadithno{440}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Al-Miqdad bin Al-Aswad thatt 'Ali bin Abi Talib, peace be upon him, told him to ask the Messenger of Allah (ﷺ) about a man who gets close to a woman and Madhi comes out of him. (He said:) "For his daughter is (married) to me and I feel too shy to ask him." So he asked the Messenger of Allah (ﷺ) about that and he said: "If any one of you notices that let him sprinkle water on his private parts and perform Wudu' as for prayer}}
\hadithdefcmd{nasai}{441}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ مُسْلِمٍ الزُّهْرِيُّ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا قَامَ أَحَدُكُمْ مِنَ اللَّيْلِ فَلاَ يُدْخِلْ يَدَهُ فِي الإِنَاءِ حَتَّى يُفْرِغَ عَلَيْهَا مَرَّتَيْنِ أَوْ ثَلاَثًا فَإِنَّ أَحَدَكُمْ لاَ يَدْرِي أَيْنَ بَاتَتْ يَدُهُ ‏"‏ ‏.‏\hadithno{441}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah said:"The Messenger of Allah (ﷺ) said: 'When any one of you gets up after (sleeping) at night, let him not put his hand into the vessel until he has poured water on it two or three times, for none of you knows where his hand spent the night}}
\hadithdefcmd{nasai}{442}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا دَاوُدُ، عَنْ عَمْرٍو، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَقُمْتُ عَنْ يَسَارِهِ فَجَعَلَنِي عَنْ يَمِينِهِ فَصَلَّى ثُمَّ اضْطَجَعَ وَرَقَدَ فَجَاءَهُ الْمُؤَذِّنُ فَصَلَّى وَلَمْ يَتَوَضَّأْ مُخْتَصَرٌ ‏.‏\hadithno{442}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"I prayed with the Prophet (ﷺ) one night, and I stood on his left, but he made me stand on his right, and he prayed. Then he reclined on his side and took a nap, then the Mu'adhdhin came to him and he prayed, and did not perform Wudu}}
\hadithdefcmd{nasai}{443}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ الطُّفَاوِيُّ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نَعَسَ أَحَدُكُمْ فِي صَلاَتِهِ فَلْيَنْصَرِفْ وَلْيَرْقُدْ ‏"‏ ‏.‏\hadithno{443}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas that the Messenger of Allah (ﷺ) said:"If anyone of you feels drowsy during his Salah, let him go and take a nap}}
\hadithdefcmd{nasai}{444}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ، - يَعْنِي ابْنَ أَبِي بَكْرٍ - قَالَ عَلَى أَثَرِهِ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَلَمْ أُتْقِنْهُ عَنْ عُرْوَةَ، عَنْ بُسْرَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ مَسَّ فَرْجَهُ فَلْيَتَوَضَّأْ ‏"‏ ‏.‏\hadithno{444}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Busrah said:"The Messenger of Allah (ﷺ) said: 'Whoever touches his private part, let him perform Wudu}}
\hadithdefcmd{nasai}{445}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَوَاءٍ، عَنْ شُعْبَةَ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ بُسْرَةَ بِنْتِ صَفْوَانَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَفْضَى أَحَدُكُمْ بِيَدِهِ إِلَى فَرْجِهِ فَلْيَتَوَضَّأْ ‏"‏ ‏.‏\hadithno{445}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Busrah bint Safwan that the Prophet (ﷺ) said:"If any one of you touches his private part with his hand, let him perform Wudu}}
\hadithdefcmd{nasai}{446}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ مَرْوَانَ بْنِ الْحَكَمِ، أَنَّهُ قَالَ الْوُضُوءُ مِنْ مَسِّ الذَّكَرِ فَقَالَ مَرْوَانُ أَخْبَرَتْنِيهِ بُسْرَةُ بِنْتُ صَفْوَانَ ‏.‏ فَأَرْسَلَ عُرْوَةُ قَالَتْ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا يُتَوَضَّأُ مِنْهُ فَقَالَ ‏ "‏ مِنْ مَسِّ الذَّكَرِ ‏"‏ ‏.‏\hadithno{446}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Marwan bin Al-Hakam said that one should perform Wudu' after touching one's penis. Marwan said:"Busrah bint Safwan told me that." 'Urwah sent someone to check that, and she said: "The Messenger of Allah (ﷺ) mentioned what Wudu' is done for, and said: 'Touching the penis}}
\hadithdefcmd{nasai}{447}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، قَالَ أَخْبَرَنِي أَبِي، عَنْ بُسْرَةَ بِنْتِ صَفْوَانَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ مَسَّ ذَكَرَهُ فَلاَ يُصَلِّي حَتَّى يَتَوَضَّأَ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هِشَامُ بْنُ عُرْوَةَ لَمْ يَسْمَعْ مِنْ أَبِيهِ هَذَا الْحَدِيثَ وَاللَّهُ سُبْحَانَهُ وَتَعَالَى أَعْلَمُ ‏.‏\hadithno{447}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Busrah bin Safwan that the Prophet (ﷺ) said:"Whoever touches his penis, he should not perform Salah until he performs Wudu'." Abu 'Abdur-Rahman (An-Nasa'i) said: Hisham bin 'Urwah did not hear this Hadith from his father}}
