% Auto-generated chapter 57 for malik
% Hadiths in this chapter: 2

\hadithdefcmd{malik}{1839}{حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ نَارُ بَنِي آدَمَ الَّتِي يُوقِدُونَ جُزْءٌ مِنْ سَبْعِينَ جُزْءًا مِنْ نَارِ جَهَنَّمَ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ إِنْ كَانَتْ لَكَافِيَةً ‏.‏ قَالَ ‏"‏ إِنَّهَا فُضِّلَتْ عَلَيْهَا بِتِسْعَةٍ وَسِتِّينَ جُزْءًا ‏"‏ ‏.‏\hadithno{1839}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "The fire of the children of Adam which they kindle is a seventieth part of the fire of Jahannam." They said, "Messenger of Allah, this fire is certainly enough." He said, "That fire is sixty- nine times greater}}
\hadithdefcmd{malik}{1840}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَمِّهِ أَبِي سُهَيْلِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ أَتُرَوْنَهَا حَمْرَاءَ كَنَارِكُمْ هَذِهِ لَهِيَ أَسْوَدُ مِنَ الْقَارِ ‏"‏ ‏.‏ وَالْقَارُ الزِّفْتُ ‏.‏\hadithno{1840}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from his paternal uncle Abu Suhayl ibn Malik from his father that Abu Hurayra said, "Do you think that it is red like this fire of yours? It is blacker than tar}}
