% Auto-generated chapter 18 for tirmidhi
% Hadiths in this chapter: 29

\hadithdefcmd{tirmidhi}{1464}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا الْحَجَّاجُ، عَنْ مَكْحُولٍ، عَنْ أَبِي ثَعْلَبَةَ، وَالْحَجَّاجُ، عَنِ الْوَلِيدِ بْنِ أَبِي مَالِكٍ، عَنْ عَائِذِ اللَّهِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ أَبَا ثَعْلَبَةَ الْخُشَنِيَّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا أَهْلُ صَيْدٍ ‏.‏ قَالَ ‏"‏ إِذَا أَرْسَلْتَ كَلْبَكَ وَذَكَرْتَ اسْمَ اللَّهِ عَلَيْهِ فَأَمْسَكَ عَلَيْكَ فَكُلْ ‏"‏ ‏.‏ قُلْتُ وَإِنْ قَتَلَ قَالَ ‏"‏ وَإِنْ قَتَلَ ‏"‏ ‏.‏ قُلْتُ إِنَّا أَهْلُ رَمْىٍ ‏.‏ قَالَ ‏"‏ مَا رَدَّتْ عَلَيْكَ قَوْسُكَ فَكُلْ ‏"‏ ‏.‏ قَالَ قُلْتُ إِنَّا أَهْلُ سَفَرٍ نَمُرُّ بِالْيَهُودِ وَالنَّصَارَى وَالْمَجُوسِ فَلاَ نَجِدُ غَيْرَ آنِيَتِهِمْ ‏.‏ قَالَ ‏"‏ فَإِنْ لَمْ تَجِدُوا غَيْرَهَا فَاغْسِلُوهَا بِالْمَاءِ ثُمَّ كُلُوا فِيهَا وَاشْرَبُوا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَدِيِّ بْنِ حَاتِمٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعَائِذُ اللَّهِ بْنُ عَبْدِ اللَّهِ هُوَ أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ وَاسْمُ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ جُرْثُومٌ وَيُقَالُ جُرْثُمُ بْنُ نَاشِرٍ وَيُقَالُ ابْنُ قَيْسٍ ‏.‏\hadithno{1464}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Tha'labah Al-Khushani:"I said: 'O Messenger of Allah! We are a people who hunt.' He said: 'If you send your dog and you mentioned the Name of Allah upon it, and he catches something for you, then eat it.' I said: 'Even if he kills it?' He said: 'Even if he kills it.' I said: 'We are a people who shoot (at game).' He said: 'What you catch with your bow, then eat it.'" He said: "Then I said:'Indeed we are a people who travel. We come across Jews, Christians, and Zoroastrians, and we do not find vessels other than theirs.' He said: 'If you do not find other than them, then wash them with water, then eat and drink from it}}
\hadithdefcmd{tirmidhi}{1465}{\hadithno{1465}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1466}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا شَرِيكٌ، عَنِ الْحَجَّاجِ، عَنِ الْقَاسِمِ بْنِ أَبِي بَزَّةَ، عَنْ سُلَيْمَانَ الْيَشْكُرِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نُهِينَا عَنْ صَيْدِ، كَلْبِ الْمَجُوسِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ لاَ يُرَخِّصُونَ فِي صَيْدِ كَلْبِ الْمَجُوسِ ‏.‏ وَالْقَاسِمُ بْنُ أَبِي بَزَّةَ هُوَ الْقَاسِمُ بْنُ نَافِعٍ الْمَكِّيُّ ‏.‏\hadithno{1466}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir bin 'Abdullah:"We have been forbidden from the game caught by a Zoroastrian's dog}}
\hadithdefcmd{tirmidhi}{1467}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، وَهَنَّادٌ، وَأَبُو عَمَّارٍ قَالُوا حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ مُجَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ صَيْدِ الْبَازِي فَقَالَ ‏"‏ مَا أَمْسَكَ عَلَيْكَ فَكُلْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُجَالِدٍ عَنِ الشَّعْبِيِّ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ لاَ يَرَوْنَ بِصَيْدِ الْبُزَاةِ وَالصُّقُورِ بَأْسًا ‏.‏ وَقَالَ مُجَاهِدٌ الْبُزَاةُ هُوَ الطَّيْرُ الَّذِي يُصَادُ بِهِ مِنَ الْجَوَارِحِ الَّتِي قَالَ اللَّهُ تَعَالَى‏:‏ ‏(‏وَمَا عَلَّمْتُمْ مِنَ الْجَوَارِحِ ‏)‏ فَسَّرَ الْكِلاَبَ وَالطَّيْرَ الَّذِي يُصَادُ بِهِ ‏.‏ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ فِي صَيْدِ الْبَازِي وَإِنْ أَكَلَ مِنْهُ وَقَالُوا إِنَّمَا تَعْلِيمُهُ إِجَابَتُهُ ‏.‏ وَكَرِهَهُ بَعْضُهُمْ وَالْفُقَهَاءُ أَكْثَرُهُمْ قَالُوا يَأْكُلُ وَإِنْ أَكَلَ مِنْهُ ‏.‏\hadithno{1467}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Adi bin Hatim:"I asked the Messenger of Allah (ﷺ) about the game caught by a falcon. So he said: 'What it catches for you, then eat it}}
\hadithdefcmd{tirmidhi}{1468}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، يُحَدِّثُ عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَرْمِي الصَّيْدَ فَأَجِدُ فِيهِ مِنَ الْغَدِ سَهْمِي قَالَ ‏ "‏ إِذَا عَلِمْتَ أَنَّ سَهْمَكَ قَتَلَهُ وَلَمْ تَرَ فِيهِ أَثَرَ سَبُعٍ فَكُلْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ وَرَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ أَبِي بِشْرٍ وَعَبْدِ الْمَلِكِ بْنِ مَيْسَرَةَ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنْ عَدِيِّ بْنِ حَاتِمٍ وَكِلاَ الْحَدِيثَيْنِ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ ‏.‏\hadithno{1468}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Adi bin Hatim:"I said: 'O Messenger of Allah! I shoot some game and then find my arrow in it the next day.' He said: 'If you know that your arrow killed it, and you dont see any marks of predators, then eat it}}
\hadithdefcmd{tirmidhi}{1469}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنِي عَاصِمٌ الأَحْوَلُ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّيْدِ فَقَالَ ‏ "‏ إِذَا رَمَيْتَ بِسَهْمِكَ فَاذْكُرِ اسْمَ اللَّهِ فَإِنْ وَجَدْتَهُ قَدْ قَتَلَ فَكُلْ إِلاَّ أَنْ تَجِدَهُ قَدْ وَقَعَ فِي مَاءٍ فَلاَ تَأْكُلْ فَإِنَّكَ لاَ تَدْرِي الْمَاءُ قَتَلَهُ أَوْ سَهْمُكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1469}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Adi bin Hatim:"I asked the Messenger of Allah (ﷺ) about hunting, so he said: 'Mention Allah's Name when you shoot your arrow. Then, if you find it dead, eat from it, unless you found that it has fallen in (some body of) water. Then do not eat it, for you do not know if the water killed it, or your arrow}}
\hadithdefcmd{tirmidhi}{1470}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ مُجَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ صَيْدِ الْكَلْبِ الْمُعَلَّمِ قَالَ ‏"‏ إِذَا أَرْسَلْتَ كَلْبَكَ الْمُعَلَّمَ وَذَكَرْتَ اسْمَ اللَّهِ فَكُلْ مَا أَمْسَكَ عَلَيْكَ فَإِنْ أَكَلَ فَلاَ تَأْكُلْ فَإِنَّمَا أَمْسَكَ عَلَى نَفْسِهِ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ خَالَطَتْ كِلاَبَنَا كِلاَبٌ أُخَرُ قَالَ ‏"‏ إِنَّمَا ذَكَرْتَ اسْمَ اللَّهِ عَلَى كَلْبِكَ وَلَمْ تَذْكُرْ عَلَى غَيْرِهِ ‏"‏ ‏.‏ قَالَ سُفْيَانُ أَكْرَهُ لَهُ أَكْلَهُ ‏.‏ قَالَ أَبُو عِيسَى وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ فِي الصَّيْدِ وَالذَّبِيحَةِ إِذَا وَقَعَا فِي الْمَاءِ أَنْ لاَ يَأْكُلَ ‏.‏ وَقَالَ بَعْضُهُمْ فِي الذَّبِيحَةِ إِذَا قُطِعَ الْحُلْقُومُ فَوَقَعَ فِي الْمَاءِ فَمَاتَ فِيهِ فَإِنَّهُ يُؤْكَلُ وَهُوَ قَوْلُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي الْكَلْبِ إِذَا أَكَلَ مِنَ الصَّيْدِ فَقَالَ أَكْثَرُ أَهْلِ الْعِلْمِ إِذَا أَكَلَ الْكَلْبُ مِنْهُ فَلاَ تَأْكُلْ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ وَعَبْدِ اللَّهِ بْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ فِي الأَكْلِ مِنْهُ وَإِنْ أَكَلَ الْكَلْبُ مِنْهُ ‏.‏\hadithno{1470}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Adi bin Hatim:"I asked the Messenger of Allah (ﷺ) about the game caught by a trained dog. He said: 'If you mention the Name of Allah when you send your trained dog, then eat from what it catches for you. But if it eats from it, then do not eat it, for he only caught it for himself.' I said: 'O Messenger of Allah! What do you say about when our dogs get mixed with other dogs.' He said: 'You only mentioned the Name of Allah over your dog, you did not mention it over the others.'" Sufyan said: "He disliked for him to eat it}}
\hadithdefcmd{tirmidhi}{1471}{\hadithno{1471}\hadithgrade{Bashar Awad Maarouf: Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1472}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الْقُطَعِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَجُلاً، مِنْ قَوْمِهِ صَادَ أَرْنَبًا أَوِ اثْنَيْنِ فَذَبَحَهُمَا بِمَرْوَةٍ فَتَعَلَّقَهُمَا حَتَّى لَقِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ فَأَمَرَهُ بِأَكْلِهِمَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ مُحَمَّدِ بْنِ صَفْوَانَ وَرَافِعٍ وَعَدِيِّ بْنِ حَاتِمٍ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ أَنْ يُذَكِّيَ بِمَرْوَةٍ وَلَمْ يَرَوْا بِأَكْلِ الأَرْنَبِ بَأْسًا وَهُوَ قَوْلُ أَكْثَرِ أَهْلِ الْعِلْمِ وَقَدْ كَرِهَ بَعْضُهُمْ أَكْلَ الأَرْنَبِ ‏.‏ وَقَدِ اخْتَلَفَ أَصْحَابُ الشَّعْبِيِّ فِي رِوَايَةِ هَذَا الْحَدِيثِ فَرَوَى دَاوُدُ بْنُ أَبِي هِنْدٍ عَنِ الشَّعْبِيِّ عَنْ مُحَمَّدِ بْنِ صَفْوَانَ ‏.‏ وَرَوَى عَاصِمٌ الأَحْوَلُ عَنِ الشَّعْبِيِّ عَنْ صَفْوَانَ بْنِ مُحَمَّدٍ أَوْ مُحَمَّدِ بْنِ صَفْوَانَ ‏.‏ وَمُحَمَّدُ بْنُ صَفْوَانَ أَصَحُّ ‏.‏ وَرَوَى جَابِرٌ الْجُعْفِيُّ عَنِ الشَّعْبِيِّ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ نَحْوَ حَدِيثِ قَتَادَةَ عَنِ الشَّعْبِيِّ وَيُحْتَمَلُ أَنَّ رِوَايَةَ الشَّعْبِيِّ عَنْهُمَا ‏.‏ قَالَ مُحَمَّدٌ حَدِيثُ الشَّعْبِيِّ عَنْ جَابِرٍ غَيْرُ مَحْفُوظٍ ‏.‏\hadithno{1472}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Jabir bin 'Abdullah:That a man from his people hunted a rabbit or two and slaughtered them with Marwah. Then he hung them up until he met the Messenger of Allah (ﷺ), so he asked him about that, and he (ﷺ) told him to eat them}}
\hadithdefcmd{tirmidhi}{1473}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ أَبِي أَيُّوبَ الأَفْرِيقِيِّ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَكْلِ الْمُجَثَّمَةِ وَهِيَ الَّتِي تُصْبَرُ بِالنَّبْلِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عِرْبَاضِ بْنِ سَارِيَةَ وَأَنَسٍ وَابْنِ عُمَرَ وَابْنِ عَبَّاسٍ وَجَابِرٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي الدَّرْدَاءِ حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{1473}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Ad-Darda':"The Messenger of Allah (ﷺ) prohibited eating the Mujath-thamah, and it is what is trapped and killed by arrows}}
\hadithdefcmd{tirmidhi}{1474}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ وَهْبٍ أَبِي خَالِدٍ، قَالَ حَدَّثَتْنِي أُمُّ حَبِيبَةَ بِنْتُ الْعِرْبَاضِ، وَهُوَ ابْنُ سَارِيَةَ عَنْ أَبِيهَا، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى يَوْمَ خَيْبَرَ عَنْ لُحُومِ كُلِّ ذِي نَابٍ مِنَ السَّبُعِ وَعَنْ كُلِّ ذِي مِخْلَبٍ مِنَ الطَّيْرِ وَعَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ وَعَنِ الْمُجَثَّمَةِ وَعَنِ الْخَلِيسَةِ وَأَنْ تُوطَأَ الْحَبَالَى حَتَّى يَضَعْنَ مَا فِي بُطُونِهِنَّ ‏.‏ قَالَ مُحَمَّدُ بْنُ يَحْيَى سُئِلَ أَبُو عَاصِمٍ عَنِ الْمُجَثَّمَةِ قَالَ أَنْ يُنْصَبَ الطَّيْرُ أَوِ الشَّىْءُ فَيُرْمَى ‏.‏ وَسُئِلَ عَنِ الْخَلِيسَةِ فَقَالَ الذِّئْبُ أَوِ السَّبُعُ يُدْرِكُهُ الرَّجُلُ فَيَأْخُذُهُ مِنْهُ فَيَمُوتُ فِي يَدِهِ قَبْلَ أَنْ يُذَكِّيَهَا ‏.‏\hadithno{1474}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Habibah bint Al-'Irbad:From her father: "On the day of Khaibar, the Messenger of Allah (ﷺ) prohibited eating the meat of every predator that has canine teeth, the meat of every bird that has talons, the meat of the domestic donkey, the Mujath-thamah, the Khalisah, and from having relations with a pregnant slave until she gives birth to what is in her womb." Muhammad bin Yahya said: "Abu 'Asim was asked about Mujath-thamah and he said: "To ensnare a bird or something and then shoot it." He was asked about Khalisah, so he said: "(Prey) that a man finds with a wolf or a predator, then he takes it from him but it dies in his hand before it can be slaughtered}}
\hadithdefcmd{tirmidhi}{1475}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنِ الثَّوْرِيِّ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُتَّخَذَ شَيْءٌ فِيهِ الرُّوحُ غَرَضًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{1475}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn 'Abbas:"The Messenger of Allah (ﷺ) prohibited taking a living thing as a shooting target}}
\hadithdefcmd{tirmidhi}{1476}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ مُجَالِدٍ، ح قَالَ وَحَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ مُجَالِدٍ، عَنْ أَبِي الْوَدَّاكِ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ ذَكَاةُ الْجَنِينِ ذَكَاةُ أُمِّهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَأَبِي أُمَامَةَ وَأَبِي الدَّرْدَاءِ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ أَبِي سَعِيدٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَأَبُو الْوَدَّاكِ اسْمُهُ جَبْرُ بْنُ نَوْفٍ ‏.‏\hadithno{1476}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Sa'eed:That the Prophet (ﷺ) said: "Slaughtering the fetus is (achieved by) the slaughtering of its mother}}
\hadithdefcmd{tirmidhi}{1477}{\hadithno{1477}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1478}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو النَّضْرِ، هَاشِمُ بْنُ الْقَاسِمِ حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ، قَالَ حَرَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم - يَعْنِي يَوْمَ خَيْبَرَ - الْحُمُرَ الإِنْسِيَّةَ وَلُحُومَ الْبِغَالِ وَكُلَّ ذِي نَابٍ مِنَ السِّبَاعِ وَذِي مِخْلَبٍ مِنَ الطَّيْرِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعِرْبَاضِ بْنِ سَارِيَةَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{1478}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Jabir:"On the Day of Khaibar, the Messenger of Allah (ﷺ) prohibited eating domesticated donkeys, the meat of mules, every predator that possesses canine teeth, and every bird that possesses talons}}
\hadithdefcmd{tirmidhi}{1479}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَرَّمَ كُلَّ ذِي نَابٍ مِنَ السِّبَاعِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَهُوَ قَوْلُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1479}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:"The Prophet (ﷺ) prohibited every predator that possesses canine teeth}}
\hadithdefcmd{tirmidhi}{1480}{\hadithno{1480}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1481}{حَدَّثَنَا هَنَّادٌ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، ح وَقَالَ أَحْمَدُ بْنُ مَنِيعٍ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَبِي الْعُشَرَاءِ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَمَا تَكُونُ الذَّكَاةُ إِلاَّ فِي الْحَلْقِ وَاللَّبَّةِ قَالَ ‏ "‏ لَوْ طَعَنْتَ فِي فَخِذِهَا لأَجْزَأَ عَنْكَ ‏"‏ ‏.‏ قَالَ أَحْمَدُ بْنُ مَنِيعٍ قَالَ يَزِيدُ بْنُ هَارُونَ هَذَا فِي الضَّرُورَةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ رَافِعِ بْنِ خَدِيجٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيِبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ حَمَّادِ بْنِ سَلَمَةَ ‏.‏ وَلاَ نَعْرِفُ لأَبِي الْعُشَرَاءِ عَنْ أَبِيهِ غَيْرَ هَذَا الْحَدِيثِ وَاخْتَلَفُوا فِي اسْمِ أَبِي الْعُشَرَاءِ فَقَالَ بَعْضُهُمُ اسْمُهُ أُسَامَةُ بْنُ قِهْطِمٍ وَيُقَالُ اسْمُهُ يَسَارُ بْنُ بَرْزٍ وَيُقَالُ ابْنُ بَلْزٍ وَيُقَالُ اسْمُهُ عُطَارِدٌ نُسِبَ إِلَى جَدِّهِ ‏.‏\hadithno{1481}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Al-'Ushara':From his father that he said: "I said: 'O Messenger of Allah! Is there no slaughtering except upon the neck and the throat ?' He said: 'If you stab its thigh it would be accepted to you}}
\hadithdefcmd{tirmidhi}{1482}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَتَلَ وَزَغَةً بِالضَّرْبَةِ الأُولَى كَانَ لَهُ كَذَا وَكَذَا حَسَنَةً فَإِنْ قَتَلَهَا فِي الضَّرْبَةِ الثَّانِيَةِ كَانَ لَهُ كَذَا وَكَذَا حَسَنَةً فَإِنْ قَتَلَهَا فِي الضَّرْبَةِ الثَّالِثَةِ كَانَ لَهُ كَذَا وَكَذَا حَسَنَةً ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَسَعْدٍ وَعَائِشَةَ وَأُمِّ شَرِيكٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1482}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Hurairah:That the Messenger of Allah (ﷺ) said: "Whoever kills a gecko in one strike, he has such and such reward, and if he kills it on the second strike, he will have such and such reward, and if he kills it on the third strike, then he has such and such reward}}
\hadithdefcmd{tirmidhi}{1483}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْتُلُوا الْحَيَّاتِ وَاقْتُلُوا ذَا الطُّفْيَتَيْنِ وَالأَبْتَرَ فَإِنَّهُمَا يَلْتَمِسَانِ الْبَصَرَ وَيُسْقِطَانِ الْحَبَلَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَعَائِشَةَ وَأَبِي هُرَيْرَةَ وَسَهْلِ بْنِ سَعْدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ ابْنِ عُمَرَ عَنْ أَبِي لُبَابَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى بَعْدَ ذَلِكَ عَنْ قَتْلِ حَيَّاتِ الْبُيُوتِ وَهِيَ الْعَوَامِرُ وَيُرْوَى عَنِ ابْنِ عُمَرَ عَنْ زَيْدِ بْنِ الْخَطَّابِ أَيْضًا ‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ إِنَّمَا يُكْرَهُ مِنْ قَتْلِ الْحَيَّاتِ قَتْلُ الْحَيَّةِ الَّتِي تَكُونُ دَقِيقَةً كَأَنَّهَا فِضَّةٌ وَلاَ تَلْتَوِي فِي مِشْيَتِهَا ‏.‏\hadithno{1483}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar:That the Messenger of Allah (ﷺ) said: "Kill snakes and kill Dhut-Tufyatain and Al-Abtar, because they blind the sight and cause abortions of fetuses}}
\hadithdefcmd{tirmidhi}{1484}{\hadithno{1484}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1485}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، حَدَّثَنَا ابْنُ أَبِي لَيْلَى، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، قَالَ قَالَ أَبُو لَيْلَى قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا ظَهَرَتِ الْحَيَّةُ فِي الْمَسْكَنِ فَقُولُوا لَهَا إِنَّا نَسْأَلُكِ بِعَهْدِ نُوحٍ وَبِعَهْدِ سُلَيْمَانَ بْنِ دَاوُدَ أَنْ لاَ تُؤْذِينَا فَإِنْ عَادَتْ فَاقْتُلُوهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ ثَابِتٍ الْبُنَانِيِّ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ ابْنِ أَبِي لَيْلَى ‏.‏\hadithno{1485}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Laila:That the Messenger of Allah (ﷺ) said: "When a snake appears in your dwellings then say to it: We ask you - by covenant of Nuh, and by the covenant of Sulaiman bin Dawud - that you do not harm us.' If it returns, then kill it}}
\hadithdefcmd{tirmidhi}{1486}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا مَنْصُورُ بْنُ زَاذَانَ، وَيُونُسُ بْنُ عُبَيْدٍ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْلاَ أَنَّ الْكِلاَبَ أُمَّةٌ مِنَ الأُمَمِ لأَمَرْتُ بِقَتْلِهَا كُلِّهَا فَاقْتُلُوا مِنْهَا كُلَّ أَسْوَدَ بَهِيمٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَجَابِرٍ وَأَبِي رَافِعٍ وَأَبِي أَيُّوبَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَيُرْوَى فِي بَعْضِ الْحَدِيثِ ‏"‏ أَنَّ الْكَلْبَ الأَسْوَدَ الْبَهِيمَ شَيْطَانٌ ‏"‏ ‏.‏ وَالْكَلْبُ الأَسْوَدُ الْبَهِيمُ الَّذِي لاَ يَكُونُ فِيهِ شَيْءٌ مِنَ الْبَيَاضِ ‏.‏ وَقَدْ كَرِهَ بَعْضُ أَهْلِ الْعِلْمِ صَيْدَ الْكَلْبِ الأَسْوَدِ الْبَهِيمِ ‏.‏\hadithno{1486}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdullah bin Mughaffal:That the Messenger of Allah (ﷺ) said: "If it were not that dogs were part of a nation among the nations, then I would order to that all of them be killed. So kill every one of them that is all black}}
\hadithdefcmd{tirmidhi}{1487}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنِ اقْتَنَى كَلْبًا لَيْسَ بِضَارٍ وَلاَ كَلْبَ مَاشِيَةٍ نَقَصَ مِنْ أَجْرِهِ كُلَّ يَوْمٍ قِيرَاطَانِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ وَأَبِي هُرَيْرَةَ وَسُفْيَانَ بْنِ أَبِي زُهَيْرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ أَوْ كَلْبَ زَرْعٍ ‏"‏ ‏.‏\hadithno{1487}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar:That the Messenger of Allah (ﷺ) said: "Whoever keeps a dog" - or: "acquires a dog" - "neither of hunting nor to guard livestock, then two Qirat are deducted from his reward, daily}}
\hadithdefcmd{tirmidhi}{1488}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِقَتْلِ الْكِلاَبِ إِلاَّ كَلْبَ صَيْدٍ أَوْ كَلْبَ مَاشِيَةٍ ‏.‏ قَالَ قِيلَ لَهُ إِنَّ أَبَا هُرَيْرَةَ كَانَ يَقُولُ أَوْ كَلْبَ زَرْعٍ ‏.‏ فَقَالَ إِنَّ أَبَا هُرَيْرَةَ لَهُ زَرْعٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1488}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Ibn 'Umar:"The Messenger of Allah (ﷺ) ordered killing dogs, except for the hunting dog, or the dog that guards livestock." It was said to him: "Abu Hurairah would say: 'or a farm dog' so he (Ibn 'Umar) said: "Abu Hurairah had a farm}}
\hadithdefcmd{tirmidhi}{1489}{حَدَّثَنَا عُبَيْدُ بْنُ أَسْبَاطِ بْنِ مُحَمَّدٍ الْقُرَشِيُّ، حَدَّثَنَا أَبِي، عَنِ الأَعْمَشِ، عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ إِنِّي لَمِمَّنْ يَرْفَعُ أَغْصَانَ الشَّجَرَةِ عَنْ وَجْهِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يَخْطُبُ فَقَالَ ‏ "‏ لَوْلاَ أَنَّ الْكِلاَبَ أُمَّةٌ مِنَ الأُمَمِ لأَمَرْتُ بِقَتْلِهَا فَاقْتُلُوا مِنْهَا كُلَّ أَسْوَدَ بَهِيمٍ وَمَا مِنْ أَهْلِ بَيْتٍ يَرْتَبِطُونَ كَلْبًا إِلاَّ نَقَصَ مِنْ عَمَلِهِمْ كُلَّ يَوْمٍ قِيرَاطٌ إِلاَّ كَلْبَ صَيْدٍ أَوْ كَلْبَ حَرْثٍ أَوْ كَلْبَ غَنَمٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنِ الْحَسَنِ عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1489}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Abdullah bin Mughaffal:"I was one of those who held up the branches from the tree away from the face of the Messenger of Allah (ﷺ) while he was delivering the Khutbah saying: 'If it were not that dogs were a nation among nations, then I would order that they be killed. So kill every one among them that is all black. There is one inhabiting a home in which they keep a dog but their deeds are decreased by one Qirat every day - except for a hunting dog, or a farm dog, or a sheep dog}}
\hadithdefcmd{tirmidhi}{1490}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَغَيْرُ، وَاحِدٍ، قَالُوا أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اتَّخَذَ كَلْبًا إِلاَّ كَلْبَ مَاشِيَةٍ أَوْ صَيْدٍ أَوْ زَرْعٍ انْتَقَصَ مِنْ أَجْرِهِ كُلَّ يَوْمٍ قِيرَاطٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَيُرْوَى عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ أَنَّهُ رَخَّصَ فِي إِمْسَاكِ الْكَلْبِ وَإِنْ كَانَ لِلرَّجُلِ شَاةٌ وَاحِدَةٌ ‏.‏ حَدَّثَنَا بِذَلِكَ إِسْحَاقُ بْنُ مَنْصُورٍ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ عَنِ ابْنِ جُرَيْجٍ عَنْ عَطَاءٍ بِهَذَا ‏.‏\hadithno{1490}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:That the Messenger of Allah (ﷺ) said: "Whoever acquires a dog - with the exception of a dog to guard livestock, a hunting dog, or a farm dog - each day a Qirat is deducted from his reward}}
\hadithdefcmd{tirmidhi}{1491}{\hadithno{1491}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1492}{\hadithno{1492}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{}}
