% Auto-generated chapter index for ibnmajah
% Source: ara-ibnmajah.json
% Total hadiths: 4343
% Chapters: 38

\hadithcollectionname{ibnmajah}{Sunan Ibn Majah}

\hadithsectionname{ibnmajah}{0}{The Book of the Sunnah}
\hadithsectionname{ibnmajah}{1}{The Book of Purification and its Sunnah}
\hadithsectionname{ibnmajah}{2}{The Book of the Prayer}
\hadithsectionname{ibnmajah}{3}{The Book of the Adhan and the Sunnah Regarding It}
\hadithsectionname{ibnmajah}{4}{The Book On The Mosques And The Congregations}
\hadithsectionname{ibnmajah}{5}{Establishing the Prayer and the Sunnah Regarding Them}
\hadithsectionname{ibnmajah}{6}{Chapters Regarding Funerals}
\hadithsectionname{ibnmajah}{7}{Fasting}
\hadithsectionname{ibnmajah}{8}{The Chapters Regarding Zakat}
\hadithsectionname{ibnmajah}{9}{The Chapters on Marriage}
\hadithsectionname{ibnmajah}{10}{The Chapters on Divorce}
\hadithsectionname{ibnmajah}{11}{The Chapters on Expiation}
\hadithsectionname{ibnmajah}{12}{The Chapters on Business Transactions}
\hadithsectionname{ibnmajah}{13}{The Chapters on Rulings}
\hadithsectionname{ibnmajah}{14}{The Chapters on Gifts}
\hadithsectionname{ibnmajah}{15}{The Chapters on Charity}
\hadithsectionname{ibnmajah}{16}{The Chapters on Pawning}
\hadithsectionname{ibnmajah}{17}{The Chapters on Pre-emption}
\hadithsectionname{ibnmajah}{18}{The Chapters on Lost Property}
\hadithsectionname{ibnmajah}{19}{The Chapters on Manumission (of Slaves)}
\hadithsectionname{ibnmajah}{20}{The Chapters on Legal Punishments}
\hadithsectionname{ibnmajah}{21}{The Chapters on Blood Money}
\hadithsectionname{ibnmajah}{22}{The Chapters on Wills}
\hadithsectionname{ibnmajah}{23}{Chapters on Shares of Inheritance}
\hadithsectionname{ibnmajah}{24}{The Chapters on Jihad}
\hadithsectionname{ibnmajah}{25}{Chapters on Hajj Rituals}
\hadithsectionname{ibnmajah}{26}{Chapters on Sacrifices}
\hadithsectionname{ibnmajah}{27}{Chapters on Slaughtering}
\hadithsectionname{ibnmajah}{28}{Chapters on Hunting}
\hadithsectionname{ibnmajah}{29}{ Chapters on Food}
\hadithsectionname{ibnmajah}{30}{Chapters on Drinks}
\hadithsectionname{ibnmajah}{31}{Chapters on Medicine}
\hadithsectionname{ibnmajah}{32}{Chapters on Dress}
\hadithsectionname{ibnmajah}{33}{Etiquette}
\hadithsectionname{ibnmajah}{34}{Supplication}
\hadithsectionname{ibnmajah}{35}{Interpretation of Dreams}
\hadithsectionname{ibnmajah}{36}{Tribulations}
\hadithsectionname{ibnmajah}{37}{Zuhd}

\hadithsectionrange{ibnmajah}{0}{1}{266}
\hadithsectionrange{ibnmajah}{1}{267}{666}
\hadithsectionrange{ibnmajah}{2}{667}{705}
\hadithsectionrange{ibnmajah}{3}{706}{734}
\hadithsectionrange{ibnmajah}{4}{735}{802}
\hadithsectionrange{ibnmajah}{5}{803}{1432}
\hadithsectionrange{ibnmajah}{6}{1433}{1637}
\hadithsectionrange{ibnmajah}{7}{1638}{1782}
\hadithsectionrange{ibnmajah}{8}{1783}{1844}
\hadithsectionrange{ibnmajah}{9}{1845}{2015}
\hadithsectionrange{ibnmajah}{10}{2016}{2477}
\hadithsectionrange{ibnmajah}{11}{2090}{2136}
\hadithsectionrange{ibnmajah}{12}{2137}{2307}
\hadithsectionrange{ibnmajah}{13}{2308}{2374}
\hadithsectionrange{ibnmajah}{14}{2375}{2389}
\hadithsectionrange{ibnmajah}{15}{2390}{2528}
\hadithsectionrange{ibnmajah}{16}{2436}{2491}
\hadithsectionrange{ibnmajah}{17}{2492}{2501}
\hadithsectionrange{ibnmajah}{18}{2502}{2511}
\hadithsectionrange{ibnmajah}{19}{2512}{2532}
\hadithsectionrange{ibnmajah}{20}{2533}{2614}
\hadithsectionrange{ibnmajah}{21}{2615}{2694}
\hadithsectionrange{ibnmajah}{22}{2695}{2718}
\hadithsectionrange{ibnmajah}{23}{2719}{2752}
\hadithsectionrange{ibnmajah}{24}{2753}{2881}
\hadithsectionrange{ibnmajah}{25}{2882}{3119}
\hadithsectionrange{ibnmajah}{26}{3120}{3161}
\hadithsectionrange{ibnmajah}{27}{3162}{3199}
\hadithsectionrange{ibnmajah}{28}{3200}{3250}
\hadithsectionrange{ibnmajah}{29}{3251}{3370}
\hadithsectionrange{ibnmajah}{30}{3371}{3435}
\hadithsectionrange{ibnmajah}{31}{3436}{3549}
\hadithsectionrange{ibnmajah}{32}{3550}{3656}
\hadithsectionrange{ibnmajah}{33}{3657}{3826}
\hadithsectionrange{ibnmajah}{34}{3827}{3892}
\hadithsectionrange{ibnmajah}{35}{3893}{3926}
\hadithsectionrange{ibnmajah}{36}{3927}{4099}
\hadithsectionrange{ibnmajah}{37}{4100}{4341}

% Chapter index — which .def file to load for each chapter

\hadithchapterfile{ibnmajah}{0}{hadithtext-ibnmajah-ch00.def}{1}{266}
\hadithchapterfile{ibnmajah}{1}{hadithtext-ibnmajah-ch01.def}{267}{666}
\hadithchapterfile{ibnmajah}{2}{hadithtext-ibnmajah-ch02.def}{667}{705}
\hadithchapterfile{ibnmajah}{3}{hadithtext-ibnmajah-ch03.def}{706}{734}
\hadithchapterfile{ibnmajah}{4}{hadithtext-ibnmajah-ch04.def}{735}{802}
\hadithchapterfile{ibnmajah}{5}{hadithtext-ibnmajah-ch05.def}{803}{1432}
\hadithchapterfile{ibnmajah}{6}{hadithtext-ibnmajah-ch06.def}{1433}{1637}
\hadithchapterfile{ibnmajah}{7}{hadithtext-ibnmajah-ch07.def}{1638}{1782}
\hadithchapterfile{ibnmajah}{8}{hadithtext-ibnmajah-ch08.def}{1783}{1844}
\hadithchapterfile{ibnmajah}{9}{hadithtext-ibnmajah-ch09.def}{1845}{2015}
\hadithchapterfile{ibnmajah}{10}{hadithtext-ibnmajah-ch10.def}{2016}{2477}
\hadithchapterfile{ibnmajah}{11}{hadithtext-ibnmajah-ch11.def}{2090}{2136}
\hadithchapterfile{ibnmajah}{12}{hadithtext-ibnmajah-ch12.def}{2137}{2307}
\hadithchapterfile{ibnmajah}{13}{hadithtext-ibnmajah-ch13.def}{2308}{2374}
\hadithchapterfile{ibnmajah}{14}{hadithtext-ibnmajah-ch14.def}{2375}{2389}
\hadithchapterfile{ibnmajah}{15}{hadithtext-ibnmajah-ch15.def}{2390}{2528}
\hadithchapterfile{ibnmajah}{16}{hadithtext-ibnmajah-ch16.def}{2436}{2491}
\hadithchapterfile{ibnmajah}{17}{hadithtext-ibnmajah-ch17.def}{2492}{2501}
\hadithchapterfile{ibnmajah}{18}{hadithtext-ibnmajah-ch18.def}{2502}{2511}
\hadithchapterfile{ibnmajah}{19}{hadithtext-ibnmajah-ch19.def}{2512}{2532}
\hadithchapterfile{ibnmajah}{20}{hadithtext-ibnmajah-ch20.def}{2533}{2614}
\hadithchapterfile{ibnmajah}{21}{hadithtext-ibnmajah-ch21.def}{2615}{2694}
\hadithchapterfile{ibnmajah}{22}{hadithtext-ibnmajah-ch22.def}{2695}{2718}
\hadithchapterfile{ibnmajah}{23}{hadithtext-ibnmajah-ch23.def}{2719}{2752}
\hadithchapterfile{ibnmajah}{24}{hadithtext-ibnmajah-ch24.def}{2753}{2881}
\hadithchapterfile{ibnmajah}{25}{hadithtext-ibnmajah-ch25.def}{2882}{3119}
\hadithchapterfile{ibnmajah}{26}{hadithtext-ibnmajah-ch26.def}{3120}{3161}
\hadithchapterfile{ibnmajah}{27}{hadithtext-ibnmajah-ch27.def}{3162}{3199}
\hadithchapterfile{ibnmajah}{28}{hadithtext-ibnmajah-ch28.def}{3200}{3250}
\hadithchapterfile{ibnmajah}{29}{hadithtext-ibnmajah-ch29.def}{3251}{3370}
\hadithchapterfile{ibnmajah}{30}{hadithtext-ibnmajah-ch30.def}{3371}{3435}
\hadithchapterfile{ibnmajah}{31}{hadithtext-ibnmajah-ch31.def}{3436}{3549}
\hadithchapterfile{ibnmajah}{32}{hadithtext-ibnmajah-ch32.def}{3550}{3656}
\hadithchapterfile{ibnmajah}{33}{hadithtext-ibnmajah-ch33.def}{3657}{3826}
\hadithchapterfile{ibnmajah}{34}{hadithtext-ibnmajah-ch34.def}{3827}{3892}
\hadithchapterfile{ibnmajah}{35}{hadithtext-ibnmajah-ch35.def}{3893}{3926}
\hadithchapterfile{ibnmajah}{36}{hadithtext-ibnmajah-ch36.def}{3927}{4099}
\hadithchapterfile{ibnmajah}{37}{hadithtext-ibnmajah-ch37.def}{4100}{4341}
