% Auto-generated chapter 17 for ibnmajah
% Hadiths in this chapter: 10

\hadithdefcmd{ibnmajah}{2492}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ نَخْلٌ أَوْ أَرْضٌ فَلاَ يَبِيعُهَا حَتَّى يَعْرِضَهَا عَلَى شَرِيكِهِ ‏"‏ ‏.‏\hadithno{2492}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jabir said:“The Messenger of Allah (ﷺ) said: 'Whoever has a date-palm tree or land, should not sell it until he has offered it to his partner.' ”}}
\hadithdefcmd{ibnmajah}{2493}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، وَالْعَلاَءُ بْنُ سَالِمٍ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا شَرِيكٌ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَأَرَادَ بَيْعَهَا فَلْيَعْرِضْهَا عَلَى جَارِهِ ‏"‏ ‏.‏\hadithno{2493}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Abbas that the Prophet (ﷺ) said:“Whoever has land and wants to sell it, let him offer it to his neighbor.”}}
\hadithdefcmd{ibnmajah}{2494}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمٌ، أَنْبَأَنَا عَبْدُ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْجَارُ أَحَقُّ بِشُفْعَةِ جَارِهِ يَنْتَظِرُ بِهَا إِنْ كَانَ غَائِبًا إِذَا كَانَ طَرِيقُهُمَا وَاحِدًا ‏"‏ ‏.‏\hadithno{2494}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“The neighbor has more right to preemption of his neighbor, so let him wait for him even if he is absent, if they share a path.”}}
\hadithdefcmd{ibnmajah}{2495}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنْ أَبِي رَافِعٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الْجَارُ أَحَقُّ بِسَقَبِهِ ‏"‏ ‏.‏\hadithno{2495}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Rafi' that the Prophet (ﷺ) said:“The neighbor has more right to property that is near.”}}
\hadithdefcmd{ibnmajah}{2496}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ عَمْرِو بْنِ الشَّرِيدِ بْنِ سُوَيْدٍ، عَنْ أَبِيهِ الشَّرِيدِ بْنِ سُوَيْدٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَرْضٌ لَيْسَ فِيهَا لأَحَدٍ قِسْمٌ وَلاَ شِرْكٌ إِلاَّ الْجِوَارُ ‏.‏ قَالَ ‏ "‏ الْجَارُ أَحَقُّ بِسَقَبِهِ ‏"‏ ‏.‏\hadithno{2496}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Sharid bin Suwaid said:“I said: 'O Messenger of Allah, (what do you think of) land owned by only one person but this land has neighbors?' He said: 'The neighbor has more right to property that is near.' ”}}
\hadithdefcmd{ibnmajah}{2497}{\hadithno{2497}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih}\hadithtrans{}}
\hadithdefcmd{ibnmajah}{2498}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنْ أَبِي رَافِعٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشَّرِيكُ أَحَقُّ بِسَقَبِهِ مَا كَانَ ‏"‏ ‏.‏\hadithno{2498}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Rafi' that the Messenger of Allah (ﷺ) said:“The partner has more right to what is near him, so long as he is still a partner.”}}
\hadithdefcmd{ibnmajah}{2499}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ إِنَّمَا جَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الشُّفْعَةَ فِي كُلِّ مَا لَمْ يُقْسَمْ فَإِذَا وَقَعَتِ الْحُدُودُ وَصُرِّفَتِ الطُّرُقُ فَلاَ شُفْعَةَ ‏"‏ ‏.‏\hadithno{2499}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Jabir bin Abdullah that:the Messenger of Allah (ﷺ) ruled that preemption takes effect in all cases where land has not been divided. But if the boundaries have been set and the roads laid out, then there is no preemption.”}}
\hadithdefcmd{ibnmajah}{2500}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْحَارِثِ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْبَيْلَمَانِيِّ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشُّفْعَةُ كَحَلِّ الْعِقَالِ ‏"‏ ‏.‏\hadithno{2500}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:“Preemption is like undoing the `Iqal.”}}
\hadithdefcmd{ibnmajah}{2501}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ الْحَارِثِ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْبَيْلَمَانِيِّ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ شُفْعَةَ لِشَرِيكٍ عَلَى شَرِيكٍ إِذَا سَبَقَهُ بِالشِّرَاءِ وَلاَ لِصَغِيرٍ وَلاَ لِغَائِبٍ ‏"‏ ‏.‏\hadithno{2501}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:“There is no preemption for a partner when his co-partner has beaten him to it (in another deal before), not for a minor nor one who is absent.”}}
