% Auto-generated chapter 11 for bukhari
% Hadiths in this chapter: 65

\hadithdefcmd{bukhari}{876}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، قَالَ حَدَّثَنَا أَبُو الزِّنَادِ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ هُرْمُزَ الأَعْرَجَ، مَوْلَى رَبِيعَةَ بْنِ الْحَارِثِ حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ نَحْنُ الآخِرُونَ السَّابِقُونَ يَوْمَ الْقِيَامَةِ، بَيْدَ أَنَّهُمْ أُوتُوا الْكِتَابَ مِنْ قَبْلِنَا، ثُمَّ هَذَا يَوْمُهُمُ الَّذِي فُرِضَ عَلَيْهِمْ فَاخْتَلَفُوا فِيهِ، فَهَدَانَا اللَّهُ، فَالنَّاسُ لَنَا فِيهِ تَبَعٌ، الْيَهُودُ غَدًا وَالنَّصَارَى بَعْدَ غَدٍ ‏"‏‏.‏\hadithno{876}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "We (Muslims) are the last (to come) but (will be) the foremost on the Day of Resurrection though the former nations were given the Holy Scriptures before us. And this was their day (Friday) the celebration of which was made compulsory for them but they differed about it. So Allah gave us the guidance for it (Friday) and all the other people are behind us in this respect: the Jews' (holy day is) tomorrow (i.e. Saturday) and the Christians' (is) the day after tomorrow (i.e. Sunday)}}
\hadithdefcmd{bukhari}{877}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا جَاءَ أَحَدُكُمُ الْجُمُعَةَ فَلْيَغْتَسِلْ ‏"‏‏.‏\hadithno{877}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "Anyone of you attending the Friday (prayers) should take a bath}}
\hadithdefcmd{bukhari}{878}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ، قَالَ أَخْبَرَنَا جُوَيْرِيَةُ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، بَيْنَمَا هُوَ قَائِمٌ فِي الْخُطْبَةِ يَوْمَ الْجُمُعَةِ إِذْ دَخَلَ رَجُلٌ مِنَ الْمُهَاجِرِينَ الأَوَّلِينَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فَنَادَاهُ عُمَرُ أَيَّةُ سَاعَةٍ هَذِهِ قَالَ إِنِّي شُغِلْتُ فَلَمْ أَنْقَلِبْ إِلَى أَهْلِي حَتَّى سَمِعْتُ التَّأْذِينَ، فَلَمْ أَزِدْ أَنْ تَوَضَّأْتُ‏.‏ فَقَالَ وَالْوُضُوءُ أَيْضًا وَقَدْ عَلِمْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْمُرُ بِالْغُسْلِ‏.‏\hadithno{878}\hadithtrans{Narrated Ibn `Umar:While `Umar bin Al-Khattab was standing and delivering the sermon on a Friday, one of the companions of the Prophet, who was one of the foremost Muhajirs (emigrants) came. `Umar said to him, "What is the time now?" He replied, "I was busy and could not go back to my house till I heard the Adhan. I did not perform more than the ablution." Thereupon `Umar said to him, "Did you perform only the ablution although you know that Allah's Messenger (ﷺ) used to order us to take a bath (on Fridays)?}}
\hadithdefcmd{bukhari}{879}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ غُسْلُ يَوْمِ الْجُمُعَةِ وَاجِبٌ عَلَى كُلِّ مُحْتَلِمٍ ‏"‏‏.‏\hadithno{879}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "The taking of a bath on Friday is compulsory for every male (Muslim) who has attained the age of puberty}}
\hadithdefcmd{bukhari}{880}{حَدَّثَنَا عَلِيٌّ، قَالَ حَدَّثَنَا حَرَمِيُّ بْنُ عُمَارَةَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بَكْرِ بْنِ الْمُنْكَدِرِ، قَالَ حَدَّثَنِي عَمْرُو بْنُ سُلَيْمٍ الأَنْصَارِيُّ، قَالَ أَشْهَدُ عَلَى أَبِي سَعِيدٍ قَالَ أَشْهَدُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْغُسْلُ يَوْمَ الْجُمُعَةِ وَاجِبٌ عَلَى كُلِّ مُحْتَلِمٍ، وَأَنْ يَسْتَنَّ وَأَنْ يَمَسَّ طِيبًا إِنْ وَجَدَ ‏"‏‏.‏ قَالَ عَمْرٌو أَمَّا الْغُسْلُ فَأَشْهَدُ أَنَّهُ وَاجِبٌ، وَأَمَّا الاِسْتِنَانُ وَالطِّيبُ فَاللَّهُ أَعْلَمُ أَوَاجِبٌ هُوَ أَمْ لاَ، وَلَكِنْ هَكَذَا فِي الْحَدِيثِ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ هُوَ أَخُو مُحَمَّدِ بْنِ الْمُنْكَدِرِ وَلَمْ يُسَمَّ أَبُو بَكْرٍ هَذَا‏.‏ رَوَاهُ عَنْهُ بُكَيْرُ بْنُ الأَشَجِّ وَسَعِيدُ بْنُ أَبِي هِلاَلٍ وَعِدَّةٌ‏.‏ وَكَانَ مُحَمَّدُ بْنُ الْمُنْكَدِرِ يُكْنَى بِأَبِي بَكْرٍ وَأَبِي عَبْدِ اللَّهِ‏.‏\hadithno{880}\hadithtrans{Narrated Abu Sa`id:I testify that Allah's Messenger (ﷺ) said, "The taking of a bath on Friday is compulsory for every male Muslim who has attained the age of puberty and (also) the cleaning of his teeth with Siwak, and the using of perfume if it is available." `Amr (a sub-narrator) said, "I confirm that the taking of a bath is compulsory, but as for the Siwak and the using of perfume, Allah knows better whether it is obligatory or not, but according to the Hadith it is as above}}
\hadithdefcmd{bukhari}{881}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اغْتَسَلَ يَوْمَ الْجُمُعَةِ غُسْلَ الْجَنَابَةِ ثُمَّ رَاحَ فَكَأَنَّمَا قَرَّبَ بَدَنَةً، وَمَنْ رَاحَ فِي السَّاعَةِ الثَّانِيَةِ فَكَأَنَّمَا قَرَّبَ بَقَرَةً، وَمَنْ رَاحَ فِي السَّاعَةِ الثَّالِثَةِ فَكَأَنَّمَا قَرَّبَ كَبْشًا أَقْرَنَ، وَمَنْ رَاحَ فِي السَّاعَةِ الرَّابِعَةِ فَكَأَنَّمَا قَرَّبَ دَجَاجَةً، وَمَنْ رَاحَ فِي السَّاعَةِ الْخَامِسَةِ فَكَأَنَّمَا قَرَّبَ بَيْضَةً، فَإِذَا خَرَجَ الإِمَامُ حَضَرَتِ الْمَلاَئِكَةُ يَسْتَمِعُونَ الذِّكْرَ ‏"‏‏.‏\hadithno{881}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Any person who takes a bath on Friday like the bath of Janaba and then goes for the prayer (in the first hour i.e. early), it is as if he had sacrificed a camel (in Allah's cause); and whoever goes in the second hour it is as if he had sacrificed a cow; and whoever goes in the third hour, then it is as if he had sacrificed a horned ram; and if one goes in the fourth hour, then it is as if he had sacrificed a hen; and whoever goes in the fifth hour then it is as if he had offered an egg. When the Imam comes out (i.e. starts delivering the Khutba), the angels present themselves to listen to the Khutba}}
\hadithdefcmd{bukhari}{882}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ عُمَرَ ـ رضى الله عنه ـ بَيْنَمَا هُوَ يَخْطُبُ يَوْمَ الْجُمُعَةِ إِذْ دَخَلَ رَجُلٌ فَقَالَ عُمَرُ لِمَ تَحْتَبِسُونَ عَنِ الصَّلاَةِ فَقَالَ الرَّجُلُ مَا هُوَ إِلاَّ سَمِعْتُ النِّدَاءَ تَوَضَّأْتُ‏.‏ فَقَالَ أَلَمْ تَسْمَعُوا النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَاحَ أَحَدُكُمْ إِلَى الْجُمُعَةِ فَلْيَغْتَسِلْ ‏"‏‏.‏\hadithno{882}\hadithtrans{Narrated Abu Huraira:While `Umar (bin Al-Khattab) was delivering the Khutba on a Friday, a man entered (the mosque). `Umar asked him, "What has detained you from the prayer?" The man said, "It was only that when I heard the Adhan I performed ablution (for the prayer)." On that `Umar said, "Did you not hear the Prophet saying: 'Anyone of you going out for the Jumua prayer should take a bath'?}}
\hadithdefcmd{bukhari}{883}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، قَالَ أَخْبَرَنِي أَبِي، عَنِ ابْنِ وَدِيعَةَ، عَنْ سَلْمَانَ الْفَارِسِيِّ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَغْتَسِلُ رَجُلٌ يَوْمَ الْجُمُعَةِ، وَيَتَطَهَّرُ مَا اسْتَطَاعَ مِنْ طُهْرٍ، وَيَدَّهِنُ مِنْ دُهْنِهِ، أَوْ يَمَسُّ مِنْ طِيبِ بَيْتِهِ ثُمَّ يَخْرُجُ، فَلاَ يُفَرِّقُ بَيْنَ اثْنَيْنِ، ثُمَّ يُصَلِّي مَا كُتِبَ لَهُ، ثُمَّ يُنْصِتُ إِذَا تَكَلَّمَ الإِمَامُ، إِلاَّ غُفِرَ لَهُ مَا بَيْنَهُ وَبَيْنَ الْجُمُعَةِ الأُخْرَى ‏"‏‏.‏\hadithno{883}\hadithtrans{Narrated Salman-Al-Farsi:The Prophet (ﷺ) said, "Whoever takes a bath on Friday, purifies himself as much as he can, then uses his (hair) oil or perfumes himself with the scent of his house, then proceeds (for the Jumua prayer) and does not separate two persons sitting together (in the mosque), then prays as much as (Allah has) written for him and then remains silent while the Imam is delivering the Khutba, his sins in-between the present and the last Friday would be forgiven}}
\hadithdefcmd{bukhari}{884}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ طَاوُسٌ قُلْتُ لاِبْنِ عَبَّاسٍ ذَكَرُوا أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ اغْتَسِلُوا يَوْمَ الْجُمُعَةِ وَاغْسِلُوا رُءُوسَكُمْ وَإِنْ لَمْ تَكُونُوا جُنُبًا، وَأَصِيبُوا مِنَ الطِّيبِ ‏"‏‏.‏ قَالَ ابْنُ عَبَّاسٍ أَمَّا الْغُسْلُ فَنَعَمْ، وَأَمَّا الطِّيبُ فَلاَ أَدْرِي‏.‏\hadithno{884}\hadithtrans{Narrated Tawus:I said to Ibn `Abbas, "The people are narrating that the Prophet (ﷺ) said, 'Take a bath on Friday and wash your heads (i.e. take a thorough bath) even though you were not Junub and use perfume'." On that Ibn `Abbas replied, "I know about the bath, (i.e. it is essential) but I do not know about the perfume (i.e. whether it is essential or not)}}
\hadithdefcmd{bukhari}{885}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، قَالَ أَخْبَرَنَا هِشَامٌ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي إِبْرَاهِيمُ بْنُ مَيْسَرَةَ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّهُ ذَكَرَ قَوْلَ النَّبِيِّ صلى الله عليه وسلم فِي الْغُسْلِ يَوْمَ الْجُمُعَةِ فَقُلْتُ لاِبْنِ عَبَّاسٍ أَيَمَسُّ طِيبًا أَوْ دُهْنًا إِنْ كَانَ عِنْدَ أَهْلِهِ فَقَالَ لاَ أَعْلَمُهُ‏.‏\hadithno{885}\hadithtrans{Narrated Tawus:Ibn `Abbas mentioned the statement of the Prophet (ﷺ) regarding the taking of a bath on Friday and then I asked him whether the Prophet (ﷺ) had ordered perfume or (hair) oil to be used if they could be found in one's house. He (Ibn `Abbas) replied that he did not know about it}}
\hadithdefcmd{bukhari}{886}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، رَأَى حُلَّةَ سِيَرَاءَ عِنْدَ باب الْمَسْجِدِ فَقَالَ يَا رَسُولَ اللَّهِ، لَوِ اشْتَرَيْتَ هَذِهِ فَلَبِسْتَهَا يَوْمَ الْجُمُعَةِ وَلِلْوَفْدِ إِذَا قَدِمُوا عَلَيْكَ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا يَلْبَسُ هَذِهِ مَنْ لاَ خَلاَقَ لَهُ فِي الآخِرَةِ ‏"‏‏.‏ ثُمَّ جَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْهَا حُلَلٌ، فَأَعْطَى عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ مِنْهَا حُلَّةً فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ، كَسَوْتَنِيهَا وَقَدْ قُلْتَ فِي حُلَّةِ عُطَارِدٍ مَا قُلْتَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي لَمْ أَكْسُكَهَا لِتَلْبَسَهَا ‏"‏‏.‏ فَكَسَاهَا عُمَرُ بْنُ الْخَطَّابِ ـ رضى الله عنه ـ أَخًا لَهُ بِمَكَّةَ مُشْرِكًا‏.‏\hadithno{886}\hadithtrans{Narrated `Abdullah bin `Umar:`Umar bin Al-Khattab saw a silken cloak (being sold) at the gate of the Mosque and said to Allah's Apostle, "I wish you would buy this to wear on Fridays and also on occasions of the arrivals of the delegations." Allah's Messenger (ﷺ) replied, "This will be worn by a person who will have no share (reward) in the Hereafter." Later on similar cloaks were given to Allah's Messenger (ﷺ) and he gave one of them to `Umar bin Al-Khattab. On that `Umar said, "O Allah's Messenger (ﷺ)! You have given me this cloak although on the cloak of Atarid (a cloak merchant who was selling that silken cloak at the gate of the mosque) you passed such and such a remark." Allah's Messenger (ﷺ) replied, "I have not given you this to wear". And so `Umar bin Al-Khattab gave it to his pagan brother in Mecca to wear}}
\hadithdefcmd{bukhari}{887}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي ـ أَوْ عَلَى النَّاسِ ـ لأَمَرْتُهُمْ بِالسِّوَاكِ مَعَ كُلِّ صَلاَةٍ ‏"‏‏.‏\hadithno{887}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If I had not found it hard for my followers or the people, I would have ordered them to clean their teeth with Siwak for every prayer}}
\hadithdefcmd{bukhari}{888}{حَدَّثَنَا أَبُو مَعْمَرٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ الْحَبْحَابِ، حَدَّثَنَا أَنَسٌ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَكْثَرْتُ عَلَيْكُمْ فِي السِّوَاكِ ‏"‏‏.‏\hadithno{888}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) said, "I have told you repeatedly to use the Siwak. (The Prophet (ﷺ) put emphasis on the use of the Siwak}}
\hadithdefcmd{bukhari}{889}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، قَالَ أَخْبَرَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، وَحُصَيْنٍ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا قَامَ مِنَ اللَّيْلِ يَشُوصُ فَاهُ‏.‏\hadithno{889}\hadithtrans{Narrated Hudhaifa:When the Prophet (ﷺ) got up at night (for the night prayer), he used to clean his mouth}}
\hadithdefcmd{bukhari}{890}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، قَالَ قَالَ هِشَامُ بْنُ عُرْوَةَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ دَخَلَ عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرٍ، وَمَعَهُ سِوَاكٌ يَسْتَنُّ بِهِ، فَنَظَرَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ لَهُ أَعْطِنِي هَذَا السِّوَاكَ يَا عَبْدَ الرَّحْمَنِ‏.‏ فَأَعْطَانِيهِ فَقَصَمْتُهُ ثُمَّ مَضَغْتُهُ، فَأَعْطَيْتُهُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَاسْتَنَّ بِهِ وَهْوَ مُسْتَسْنِدٌ إِلَى صَدْرِي‏.‏\hadithno{890}\hadithtrans{Narrated `Aisha:`Abdur-Rahman bin Abi Bakr came holding a Siwak with which he was cleaning his teeth. Allah's Apostle looked at him. I requested `Abdur-Rahman to give the Siwak to me and after he gave it to me I divided it, chewed it and gave it to Allah's Messenger (ﷺ). Then he cleaned his teeth with it and (at that time) he was resting against my chest}}
\hadithdefcmd{bukhari}{891}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ ـ هُوَ ابْنُ هُرْمُزَ ـ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ فِي الْجُمُعَةِ فِي صَلاَةِ الْفَجْرِ ‏\{‏الم * تَنْزِيلُ‏\}‏ السَّجْدَةَ وَ‏\{‏هَلْ أَتَى عَلَى الإِنْسَانِ‏\}‏\hadithno{891}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) used to recite the following in the Fajr prayer of Friday, "Alif, Lam, Mim, Tanzil" (Suratas- Sajda \#32) and "Hal-ata-ala-l-Insani" (i.e. Surah-Ad-Dahr)}}
\hadithdefcmd{bukhari}{892}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ أَبِي جَمْرَةَ الضُّبَعِيِّ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ إِنَّ أَوَّلَ جُمُعَةٍ جُمِّعَتْ بَعْدَ جُمُعَةٍ فِي مَسْجِدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي مَسْجِدِ عَبْدِ الْقَيْسِ بِجُوَاثَى مِنَ الْبَحْرَيْنِ‏.‏\hadithno{892}\hadithtrans{Narrated Ibn `Abbas:The first Jumua prayer which was offered after a Jumua prayer offered at the mosque of Allah's Apostle took place in the mosque of the tribe of `Abdul Qais at Jawathi in Bahrain}}
\hadithdefcmd{bukhari}{893}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنَا سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ كُلُّكُمْ رَاعٍ ‏"‏‏.‏ وَزَادَ اللَّيْثُ قَالَ يُونُسُ كَتَبَ رُزَيْقُ بْنُ حُكَيْمٍ إِلَى ابْنِ شِهَابٍ ـ وَأَنَا مَعَهُ يَوْمَئِذٍ بِوَادِي الْقُرَى ـ هَلْ تَرَى أَنْ أُجَمِّعَ‏.‏ وَرُزَيْقٌ عَامِلٌ عَلَى أَرْضٍ يَعْمَلُهَا، وَفِيهَا جَمَاعَةٌ مِنَ السُّودَانِ وَغَيْرِهِمْ، وَرُزَيْقٌ يَوْمَئِذٍ عَلَى أَيْلَةَ، فَكَتَبَ ابْنُ شِهَابٍ ـ وَأَنَا أَسْمَعُ ـ يَأْمُرُهُ أَنْ يُجَمِّعَ، يُخْبِرُهُ أَنَّ سَالِمًا حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ كُلُّكُمْ رَاعٍ، وَكُلُّكُمْ مَسْئُولٌ عَنْ رَعِيَّتِهِ، الإِمَامُ رَاعٍ وَمَسْئُولٌ عَنْ رَعِيَّتِهِ، وَالرَّجُلُ رَاعٍ فِي أَهْلِهِ وَهْوَ مَسْئُولٌ عَنْ رَعِيَّتِهِ، وَالْمَرْأَةُ رَاعِيَةٌ فِي بَيْتِ زَوْجِهَا وَمَسْئُولَةٌ عَنْ رَعِيَّتِهَا، وَالْخَادِمُ رَاعٍ فِي مَالِ سَيِّدِهِ وَمَسْئُولٌ عَنْ رَعِيَّتِهِ ـ قَالَ وَحَسِبْتُ أَنْ قَدْ قَالَ ـ وَالرَّجُلُ رَاعٍ فِي مَالِ أَبِيهِ وَمَسْئُولٌ عَنْ رَعِيَّتِهِ وَكُلُّكُمْ رَاعٍ وَمَسْئُولٌ عَنْ رَعِيَّتِهِ ‏"‏‏.‏\hadithno{893}\hadithtrans{Narrated Ibn `Umar:I heard Allah's Messenger (ﷺ) saying, "All of you are Guardians." Yunus said: Ruzaiq bin Hukaim wrote to Ibn Shihab while I was with him at Wadi-al-Qura saying, "Shall I lead the Jumua prayer?" Ruzaiq was working on the land (i.e. farming) and there was a group of Sudanese people and some others with him; Ruzaiq was then the Governor of Aila. Ibn Shihab wrote (to Ruzaiq) ordering him to lead the Jumua prayer and telling him that Salim told him that `Abdullah bin `Umar had said, "I heard Allah's Apostle saying, 'All of you are guardians and responsible for your wards and the things under your care. The Imam (i.e. ruler) is the guardian of his subjects and is responsible for them and a man is the guardian of his family and is responsible for them. A woman is the guardian of her husband's house and is responsible for it. A servant is the guardian of his master's belongings and is responsible for them.' I thought that he also said, 'A man is the guardian of his father's property and is responsible for it. All of you are guardians and responsible for your wards and the things under your care}}
\hadithdefcmd{bukhari}{894}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ جَاءَ مِنْكُمُ الْجُمُعَةَ فَلْيَغْتَسِلْ ‏"‏‏.‏\hadithno{894}\hadithtrans{Narrated `Abdullah bin `Umar:I heard Allah's Messenger (ﷺ) saying, "Anyone of you coming for the Jumua prayer should take a bath}}
\hadithdefcmd{bukhari}{895}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ غُسْلُ يَوْمِ الْجُمُعَةِ وَاجِبٌ عَلَى كُلِّ مُحْتَلِمٍ ‏"‏‏.‏\hadithno{895}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "The taking of a bath on Friday is compulsory for every Muslim who has attained the age of puberty}}
\hadithdefcmd{bukhari}{897}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَحْنُ الآخِرُونَ السَّابِقُونَ يَوْمَ الْقِيَامَةِ، أُوتُوا الْكِتَابَ مِنْ قَبْلِنَا، وَأُوتِينَاهُ مِنْ بَعْدِهِمْ، فَهَذَا الْيَوْمُ الَّذِي اخْتَلَفُوا فِيهِ فَهَدَانَا اللَّهُ، فَغَدًا لِلْيَهُودِ وَبَعْدَ غَدٍ لِلنَّصَارَى ‏"‏‏.‏ فَسَكَتَ‏.‏ ثُمَّ قَالَ ‏"‏ حَقٌّ عَلَى كُلِّ مُسْلِمٍ أَنْ يَغْتَسِلَ فِي كُلِّ سَبْعَةِ أَيَّامٍ يَوْمًا يَغْسِلُ فِيهِ رَأْسَهُ وَجَسَدَهُ ‏"‏‏.‏	ثُمَّ قَالَ ‏"‏ حَقٌّ عَلَى كُلِّ مُسْلِمٍ أَنْ يَغْتَسِلَ فِي كُلِّ سَبْعَةِ أَيَّامٍ يَوْمًا يَغْسِلُ فِيهِ رَأْسَهُ وَجَسَدَهُ ‏"‏‏.‏\hadithno{897}\hadithtrans{Narrated Abu Huraira: Allah's Messenger (ﷺ) said "We are the last (to come amongst the nations) but (will be) the foremost on the Day of Resurrection. They were given the Holy Scripture before us and we were given the Quran after them. And this was the day (Friday) about which they differed and Allah gave us the guidance (for that). So tomorrow (i.e. Saturday) is the Jews' (day), and the day after tomorrow (i.e. Sunday) is the Christians'." The Prophet (ﷺ) remained silent (for a while) and then said, "It is obligatory for every Muslim that he should take a bath once in seven days, when he should wash his head and body}}
\hadithdefcmd{bukhari}{898}{رَوَاهُ أَبَانُ بْنُ صَالِحٍ عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لِلَّهِ تَعَالَى عَلَى كُلِّ مُسْلِمٍ حَقٌّ أَنْ يَغْتَسِلَ فِي كُلِّ سَبْعَةِ أَيَّامٍ يَوْمًا ‏"‏‏.‏\hadithno{898}\hadithtrans{Narrated Abu Huraira through different narrators that the Prophet (ﷺ) said, "It is Allah's right on every Muslim that he should take a bath (at least) once in seven days}}
\hadithdefcmd{bukhari}{899}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا وَرْقَاءُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ ائْذَنُوا لِلنِّسَاءِ بِاللَّيْلِ إِلَى الْمَسَاجِدِ ‏"‏‏.‏\hadithno{899}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "Allow women to go to the Mosques at night}}
\hadithdefcmd{bukhari}{900}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَتِ امْرَأَةٌ لِعُمَرَ تَشْهَدُ صَلاَةَ الصُّبْحِ وَالْعِشَاءِ فِي الْجَمَاعَةِ فِي الْمَسْجِدِ، فَقِيلَ لَهَا لِمَ تَخْرُجِينَ وَقَدْ تَعْلَمِينَ أَنَّ عُمَرَ يَكْرَهُ ذَلِكَ وَيَغَارُ قَالَتْ وَمَا يَمْنَعُهُ أَنْ يَنْهَانِي قَالَ يَمْنَعُهُ قَوْلُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَمْنَعُوا إِمَاءَ اللَّهِ مَسَاجِدَ اللَّهِ ‏"‏‏.‏\hadithno{900}\hadithtrans{Narrated Ibn `Umar:One of the wives of `Umar (bin Al-Khattab) used to offer the Fajr and the `Isha' prayer in congregation in the Mosque. She was asked why she had come out for the prayer as she knew that `Umar disliked it, and he has great ghaira (self-respect). She replied, "What prevents him from stopping me from this act?" The other replied, "The statement of Allah's Messenger (ﷺ) : 'Do not stop Allah's women-slaves from going to Allah's Mosques' prevents him}}
\hadithdefcmd{bukhari}{901}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ أَخْبَرَنِي عَبْدُ الْحَمِيدِ، صَاحِبُ الزِّيَادِيِّ قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْحَارِثِ ابْنُ عَمِّ، مُحَمَّدِ بْنِ سِيرِينَ قَالَ ابْنُ عَبَّاسٍ لِمُؤَذِّنِهِ فِي يَوْمٍ مَطِيرٍ إِذَا قُلْتَ أَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ‏.‏ فَلاَ تَقُلْ حَىَّ عَلَى الصَّلاَةِ‏.‏ قُلْ صَلُّوا فِي بُيُوتِكُمْ‏.‏ فَكَأَنَّ النَّاسَ اسْتَنْكَرُوا، قَالَ فَعَلَهُ مَنْ هُوَ خَيْرٌ مِنِّي، إِنَّ الْجُمُعَةَ عَزْمَةٌ، وَإِنِّي كَرِهْتُ أَنْ أُخْرِجَكُمْ، فَتَمْشُونَ فِي الطِّينِ وَالدَّحْضِ‏.‏\hadithno{901}\hadithtrans{Narrated Muhammad bin Seereen:On a rainy day Ibn `Abbas said to his Mu'adh-dhin, "After saying, 'Ash-hadu anna Muhammadan Rasulullah' (I testify that Muhammad is Allah's Messenger (ﷺ)), do not say 'Haiya 'Alas-Salat' (come for the prayer) but say 'Pray in your houses'." (The man did so). But the people disliked it. Ibn `Abbas said, "It was done by one who was much better than I (i.e. the Prophet (ﷺ) ). No doubt, the Jumua prayer is compulsory but I dislike to put you to task by bringing you out walking in mud and slush}}
\hadithdefcmd{bukhari}{902}{حَدَّثَنَا أَحْمَدُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، أَنَّ مُحَمَّدَ بْنَ جَعْفَرِ بْنِ الزُّبَيْرِ، حَدَّثَهُ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ النَّاسُ يَنْتَابُونَ يَوْمَ الْجُمُعَةِ مِنْ مَنَازِلِهِمْ وَالْعَوَالِي، فَيَأْتُونَ فِي الْغُبَارِ، يُصِيبُهُمُ الْغُبَارُ وَالْعَرَقُ، فَيَخْرُجُ مِنْهُمُ الْعَرَقُ، فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم إِنْسَانٌ مِنْهُمْ وَهْوَ عِنْدِي، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَوْ أَنَّكُمْ تَطَهَّرْتُمْ لِيَوْمِكُمْ هَذَا ‏"‏‏.‏\hadithno{902}\hadithtrans{Narrated Aisha:(the wife of the Prophet) The people used to come from their abodes and from Al-`Awali (i.e. outskirts of Medina up to a distance of four miles or more from Medina). They used to pass through dust and used to be drenched with sweat and covered with dust; so sweat used to trickle from them. One of them came to Allah's Messenger (ﷺ) who was in my house. The Prophet (ﷺ) said to him, "I wish that you keep yourself clean on this day of yours (i.e. take a bath)}}
\hadithdefcmd{bukhari}{903}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ، أَنَّهُ سَأَلَ عَمْرَةَ عَنِ الْغُسْلِ، يَوْمَ الْجُمُعَةِ فَقَالَتْ قَالَتْ عَائِشَةُ ـ رضى الله عنها ـ كَانَ النَّاسُ مَهَنَةَ أَنْفُسِهِمْ، وَكَانُوا إِذَا رَاحُوا إِلَى الْجُمُعَةِ رَاحُوا فِي هَيْئَتِهِمْ فَقِيلَ لَهُمْ لَوِ اغْتَسَلْتُمْ‏.‏\hadithno{903}\hadithtrans{Narrated Yahya bin Sa`id:I asked `Amra about taking a bath on Fridays. She replied, " Aisha said, 'The people used to work (for their livelihood) and whenever they went for the Jumua prayer, they used to go to the mosque in the same shape as they had been in work. So they were asked to take a bath on Friday}}
\hadithdefcmd{bukhari}{904}{حَدَّثَنَا سُرَيْجُ بْنُ النُّعْمَانِ، قَالَ حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ عُثْمَانَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عُثْمَانَ التَّيْمِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي الْجُمُعَةَ حِينَ تَمِيلُ الشَّمْسُ‏.‏\hadithno{904}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) used to offer the Jumua prayer immediately after midday}}
\hadithdefcmd{bukhari}{905}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ كُنَّا نُبَكِّرُ بِالْجُمُعَةِ، وَنَقِيلُ بَعْدَ الْجُمُعَةِ‏.‏\hadithno{905}\hadithtrans{Narrated Anas bin Malik:We used to offer the Jumua prayer early and then have an afternoon nap}}
\hadithdefcmd{bukhari}{906}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، قَالَ حَدَّثَنَا حَرَمِيُّ بْنُ عُمَارَةَ، قَالَ حَدَّثَنَا أَبُو خَلْدَةَ ـ هُوَ خَالِدُ بْنُ دِينَارٍ ـ قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا اشْتَدَّ الْبَرْدُ بَكَّرَ بِالصَّلاَةِ، وَإِذَا اشْتَدَّ الْحَرُّ أَبْرَدَ بِالصَّلاَةِ، يَعْنِي الْجُمُعَةَ‏.‏ قَالَ يُونُسُ بْنُ بُكَيْرٍ أَخْبَرَنَا أَبُو خَلْدَةَ فَقَالَ بِالصَّلاَةِ، وَلَمْ يَذْكُرِ الْجُمُعَةَ‏.‏ وَقَالَ بِشْرُ بْنُ ثَابِتٍ حَدَّثَنَا أَبُو خَلْدَةَ قَالَ صَلَّى بِنَا أَمِيرٌ الْجُمُعَةَ ثُمَّ قَالَ لأَنَسٍ ـ رضى الله عنه ـ كَيْفَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي الظُّهْرَ\hadithno{906}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) used to offer the prayer earlier if it was very cold; and if it was very hot he used to delay the prayer, i.e. the Jumua prayer}}
\hadithdefcmd{bukhari}{907}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ أَبِي مَرْيَمَ، قَالَ حَدَّثَنَا عَبَايَةُ بْنُ رِفَاعَةَ، قَالَ أَدْرَكَنِي أَبُو عَبْسٍ وَأَنَا أَذْهَبُ، إِلَى الْجُمُعَةِ فَقَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ اغْبَرَّتْ قَدَمَاهُ فِي سَبِيلِ اللَّهِ حَرَّمَهُ اللَّهُ عَلَى النَّارِ ‏"‏‏.‏\hadithno{907}\hadithtrans{Narrated Abu `Abs:I heard the Prophet (ﷺ) saying, "Anyone whose feet are covered with dust in Allah's cause, shall be saved by Allah from the Hell-Fire}}
\hadithdefcmd{bukhari}{908}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، قَالَ الزُّهْرِيُّ عَنْ سَعِيدٍ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَحَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ تَأْتُوهَا تَسْعَوْنَ، وَأْتُوهَا تَمْشُونَ عَلَيْكُمُ السَّكِينَةُ، فَمَا أَدْرَكْتُمْ فَصَلُّوا، وَمَا فَاتَكُمْ فَأَتِمُّوا ‏"‏‏.‏\hadithno{908}\hadithtrans{Narrated Abu Huraira:heard Allah's Messenger (ﷺ) saying, "If the prayer is started do not run for it but just walk for it calmly and pray whatever you get, and complete whatever is missed}}
\hadithdefcmd{bukhari}{909}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنِي أَبُو قُتَيْبَةَ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ ـ لاَ أَعْلَمُهُ إِلاَّ عَنْ أَبِيهِ ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُوا حَتَّى تَرَوْنِي، وَعَلَيْكُمُ السَّكِينَةُ ‏"‏‏.‏\hadithno{909}\hadithtrans{Narrated `Abdullah bin Abi Qatada on the authority of his father:The Prophet (ﷺ) said, "Do not stand up (for prayer) unless you see me, and observe calmness and solemnity}}
\hadithdefcmd{bukhari}{910}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنِ ابْنِ وَدِيعَةَ، عَنْ سَلْمَانَ الْفَارِسِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اغْتَسَلَ يَوْمَ الْجُمُعَةِ، وَتَطَهَّرَ بِمَا اسْتَطَاعَ مِنْ طُهْرٍ، ثُمَّ ادَّهَنَ أَوْ مَسَّ مِنْ طِيبٍ، ثُمَّ رَاحَ فَلَمْ يُفَرِّقْ بَيْنَ اثْنَيْنِ، فَصَلَّى مَا كُتِبَ لَهُ، ثُمَّ إِذَا خَرَجَ الإِمَامُ أَنْصَتَ، غُفِرَ لَهُ مَا بَيْنَهُ وَبَيْنَ الْجُمُعَةِ الأُخْرَى ‏"‏‏.‏\hadithno{910}\hadithtrans{Narrated Salman Al-Farsi:Allah's Messenger (ﷺ) said, "Anyone who takes a bath on Friday and cleans himself as much as he can and puts oil (on his hair) or scents himself; and then proceeds for the prayer and does not force his way between two persons (assembled in the mosque for the Friday prayer), and prays as much as is written for him and remains quiet when the Imam delivers the Khutba, all his sins in between the present and the last Friday will be forgiven}}
\hadithdefcmd{bukhari}{911}{حَدَّثَنَا مُحَمَّدٌ، قَالَ أَخْبَرَنَا مَخْلَدُ بْنُ يَزِيدَ، قَالَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ سَمِعْتُ نَافِعًا، يَقُولُ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ يُقِيمَ الرَّجُلُ أَخَاهُ مِنْ مَقْعَدِهِ وَيَجْلِسَ فِيهِ‏.‏ قُلْتُ لِنَافِعٍ الْجُمُعَةَ قَالَ الْجُمُعَةَ وَغَيْرَهَا‏.‏\hadithno{911}\hadithtrans{Narrated Ibn Juraij:I heard Nafi' saying, "Ibn `Umar, said, 'The Prophet (ﷺ) forbade that a man should make another man to get up to sit in his place' ". I said to Nafi`, 'Is it for Jumua prayer only?' He replied, "For Jumua prayer and any other (prayer)}}
\hadithdefcmd{bukhari}{912}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنِ السَّائِبِ بْنِ يَزِيدَ، قَالَ كَانَ النِّدَاءُ يَوْمَ الْجُمُعَةِ أَوَّلُهُ إِذَا جَلَسَ الإِمَامُ عَلَى الْمِنْبَرِ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ ـ رضى الله عنهما ـ فَلَمَّا كَانَ عُثْمَانُ ـ رضى الله عنه ـ وَكَثُرَ النَّاسُ زَادَ النِّدَاءَ الثَّالِثَ عَلَى الزَّوْرَاءِ‏.‏\hadithno{912}\hadithtrans{Narrated As-Saib bin Yazid:In the lifetime of the Prophet, Abu Bakr and `Umar, the Adhan for the Jumua prayer used to be pronounced when the Imam sat on the pulpit. But during the Caliphate of `Uthman when the Muslims increased in number, a third Adhan at Az-Zaura' was added. Abu `Abdullah said, "Az-Zaura' is a place in the market of Medina}}
\hadithdefcmd{bukhari}{913}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ الْمَاجِشُونُ، عَنِ الزُّهْرِيِّ، عَنِ السَّائِبِ بْنِ يَزِيدَ، أَنَّ الَّذِي، زَادَ التَّأْذِينَ الثَّالِثَ يَوْمَ الْجُمُعَةِ عُثْمَانُ بْنُ عَفَّانَ ـ رضى الله عنه ـ حِينَ كَثُرَ أَهْلُ الْمَدِينَةِ، وَلَمْ يَكُنْ لِلنَّبِيِّ صلى الله عليه وسلم مُؤَذِّنٌ غَيْرَ وَاحِدٍ، وَكَانَ التَّأْذِينُ يَوْمَ الْجُمُعَةِ حِينَ يَجْلِسُ الإِمَامُ، يَعْنِي عَلَى الْمِنْبَرِ‏.‏\hadithno{913}\hadithtrans{Narrated As-Saib bin Yazid:The person who increased the number of Adhans for the Jumua prayers to three was `Uthman bin `Affan and it was when the number of the (Muslim) people of Medina had increased. In the lifetime of the Prophet (ﷺ) there was only one Mu'adh-dhin and the Adhan used to be pronounced only after the Imam had taken his seat (i.e. on the pulpit)}}
\hadithdefcmd{bukhari}{914}{حَدَّثَنَا ابْنُ مُقَاتِلٍ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا أَبُو بَكْرِ بْنُ عُثْمَانَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، قَالَ سَمِعْتُ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ،، وَهُوَ جَالِسٌ عَلَى الْمِنْبَرِ، أَذَّنَ الْمُؤَذِّنُ قَالَ اللَّهُ أَكْبَرُ اللَّهُ أَكْبَرُ‏.‏ قَالَ مُعَاوِيَةُ اللَّهُ أَكْبَرُ اللَّهُ أَكْبَرُ‏.‏ قَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ فَقَالَ مُعَاوِيَةُ وَأَنَا‏.‏ فَقَالَ أَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ‏.‏ فَقَالَ مُعَاوِيَةُ وَأَنَا‏.‏ فَلَمَّا أَنْ قَضَى التَّأْذِينَ قَالَ يَا أَيُّهَا النَّاسُ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى هَذَا الْمَجْلِسِ حِينَ أَذَّنَ الْمُؤَذِّنُ يَقُولُ مَا سَمِعْتُمْ مِنِّي مِنْ مَقَالَتِي‏.‏\hadithno{914}\hadithtrans{Narrated Abu Umama bin Sahl bin Hunaif:I heard Muawiya bin Abi Sufyan (repeating the statements of the Adhan) while he was sitting on the pulpit. When the Mu'adh-dhin pronounced the Adhan saying, "Allahu-Akbar, Allahu Akbar", Muawiya said: "Allah Akbar, Allahu Akbar." And when the Mu'adh-dhin said, "Ash-hadu an la ilaha illal-lah (I testify that none has the right to be worshipped but Allah)", Muawiya said, "And (so do) I". When he said, "Ash-hadu anna Muhammadan Rasulullah" (I testify that Muhammad is Allah's Apostle), Muawiya said, "And (so do) I". When the Adhan was finished, Muawiya said, "O people, when the Mu'adh-dhin pronounced the Adhan I heard Allah's Messenger (ﷺ) on this very pulpit saying what you have just heard me saying}}
\hadithdefcmd{bukhari}{915}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ السَّائِبَ بْنَ يَزِيدَ، أَخْبَرَهُ أَنَّ التَّأْذِينَ الثَّانِيَ يَوْمَ الْجُمُعَةِ أَمَرَ بِهِ عُثْمَانُ حِينَ كَثُرَ أَهْلُ الْمَسْجِدِ، وَكَانَ التَّأْذِينُ يَوْمَ الْجُمُعَةِ حِينَ يَجْلِسُ الإِمَامُ‏.‏\hadithno{915}\hadithtrans{Narrated As-Sa'ib bin Yazid:`Uthman bin `Affan introduced the second Adhan on Fridays when the number of the people in the mosque increased. Previously the Adhan on Fridays used to be pronounced only after the Imam had taken his seat (on the pulpit)}}
\hadithdefcmd{bukhari}{916}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ سَمِعْتُ السَّائِبَ بْنَ يَزِيدَ، يَقُولُ إِنَّ الأَذَانَ يَوْمَ الْجُمُعَةِ كَانَ أَوَّلُهُ حِينَ يَجْلِسُ الإِمَامُ يَوْمَ الْجُمُعَةِ عَلَى الْمِنْبَرِ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ ـ رضى الله عنهما ـ فَلَمَّا كَانَ فِي خِلاَفَةِ عُثْمَانَ ـ رضى الله عنه ـ وَكَثُرُوا، أَمَرَ عُثْمَانُ يَوْمَ الْجُمُعَةِ بِالأَذَانِ الثَّالِثِ، فَأُذِّنَ بِهِ عَلَى الزَّوْرَاءِ، فَثَبَتَ الأَمْرُ عَلَى ذَلِكَ‏.‏\hadithno{916}\hadithtrans{Narrated Az-Zuhri:I heard As-Saib bin Yazid, saying, "In the lifetime of Allah's Messenger (ﷺ), and Abu Bakr and `Umar, the Adhan for the Jumua prayer used to be pronounced after the Imam had taken his seat on the pulpit. But when the people increased in number during the caliphate of `Uthman, he introduced a third Adhan (on Friday for the Jumua prayer) and it was pronounced at Az-Zaura' and that new state of affairs remained so in the succeeding years}}
\hadithdefcmd{bukhari}{917}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدٍ الْقَارِيُّ الْقُرَشِيُّ الإِسْكَنْدَرَانِيُّ، قَالَ حَدَّثَنَا أَبُو حَازِمِ بْنُ دِينَارٍ، أَنَّ رِجَالاً، أَتَوْا سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ، وَقَدِ امْتَرَوْا فِي الْمِنْبَرِ مِمَّ عُودُهُ فَسَأَلُوهُ عَنْ ذَلِكَ فَقَالَ وَاللَّهِ إِنِّي لأَعْرِفُ مِمَّا هُوَ، وَلَقَدْ رَأَيْتُهُ أَوَّلَ يَوْمٍ وُضِعَ، وَأَوَّلَ يَوْمٍ جَلَسَ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى فُلاَنَةَ ـ امْرَأَةٍ قَدْ سَمَّاهَا سَهْلٌ ـ ‏"‏ مُرِي غُلاَمَكِ النَّجَّارَ أَنْ يَعْمَلَ لِي أَعْوَادًا أَجْلِسُ عَلَيْهِنَّ إِذَا كَلَّمْتُ النَّاسَ ‏"‏‏.‏ فَأَمَرَتْهُ فَعَمِلَهَا مِنْ طَرْفَاءِ الْغَابَةِ ثُمَّ جَاءَ بِهَا، فَأَرْسَلَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَرَ بِهَا فَوُضِعَتْ هَا هُنَا، ثُمَّ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى عَلَيْهَا، وَكَبَّرَ وَهْوَ عَلَيْهَا، ثُمَّ رَكَعَ وَهْوَ عَلَيْهَا، ثُمَّ نَزَلَ الْقَهْقَرَى فَسَجَدَ فِي أَصْلِ الْمِنْبَرِ ثُمَّ عَادَ، فَلَمَّا فَرَغَ أَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏"‏ أَيُّهَا النَّاسُ إِنَّمَا صَنَعْتُ هَذَا لِتَأْتَمُّوا وَلِتَعَلَّمُوا صَلاَتِي ‏"‏‏.‏\hadithno{917}\hadithtrans{Narrated Abu Hazim bin Dinar:Some people went to Sahl bin Sa`d As-Sa`idi and told him that they had different opinions regarding the wood of the pulpit. They asked him about it and he said, "By Allah, I know of what wood the pulpit was made, and no doubt I saw it on the very first day when Allah's Messenger (ﷺ) took his seat on it. Allah's Messenger (ﷺ) sent for such and such an Ansari woman (and Sahl mentioned her name) and said to her, 'Order your slave-carpenter to prepare for me some pieces of wood (i.e. pulpit) on which I may sit at the time of addressing the people.' So she ordered her slave-carpenter and he made it from the tamarisk of the forest and brought it (to the woman). The woman sent that (pulpit) to Allah's Messenger (ﷺ) who ordered it to be placed here. Then I saw Allah's Messenger (ﷺ) praying on it and then bowed on it. Then he stepped back, got down and prostrated on the ground near the foot of the pulpit and again ascended the pulpit. After finishing the prayer he faced the people and said, 'I have done this so that you may follow me and learn the way I pray}}
\hadithdefcmd{bukhari}{918}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ أَخْبَرَنِي يَحْيَى بْنُ سَعِيدٍ، قَالَ أَخْبَرَنِي ابْنُ أَنَسٍ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ كَانَ جِذْعٌ يَقُومُ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم فَلَمَّا وُضِعَ لَهُ الْمِنْبَرُ سَمِعْنَا لِلْجِذْعِ مِثْلَ أَصْوَاتِ الْعِشَارِ حَتَّى نَزَلَ النَّبِيُّ صلى الله عليه وسلم فَوَضَعَ يَدَهُ عَلَيْهِ‏.‏ قَالَ سُلَيْمَانُ عَنْ يَحْيَى أَخْبَرَنِي حَفْصُ بْنُ عُبَيْدِ اللَّهِ بْنِ أَنَسٍ أَنَّهُ سَمِعَ جَابِرًا‏.‏\hadithno{918}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) used to stand by a stem of a date-palm tree (while delivering a sermon). When the pulpit was placed for him we heard that stem crying like a pregnant she-camel till the Prophet (ﷺ) got down from the pulpit and placed his hand over it}}
\hadithdefcmd{bukhari}{919}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ عَلَى الْمِنْبَرِ فَقَالَ ‏ "‏ مَنْ جَاءَ إِلَى الْجُمُعَةِ فَلْيَغْتَسِلْ ‏"‏‏.‏\hadithno{919}\hadithtrans{Narrated Salim:My father said , "I heard the Prophet (ﷺ) delivering the Khutba on the pulpit and he said, 'Whoever comes for the Jumua prayer should take a bath (before coming)}}
\hadithdefcmd{bukhari}{920}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ قَائِمًا ثُمَّ يَقْعُدُ ثُمَّ يَقُومُ، كَمَا تَفْعَلُونَ الآنَ‏.‏\hadithno{920}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) used to deliver the Khutba while standing and then he would sit, then stand again as you do now-a-days}}
\hadithdefcmd{bukhari}{921}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ هِلاَلِ بْنِ أَبِي مَيْمُونَةَ، حَدَّثَنَا عَطَاءُ بْنُ يَسَارٍ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، قَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم جَلَسَ ذَاتَ يَوْمٍ عَلَى الْمِنْبَرِ وَجَلَسْنَا حَوْلَهُ‏.‏\hadithno{921}\hadithtrans{Narrated Abu Sa`id Al-Khudri:One day the Prophet (ﷺ) sat on the pulpit and we sat around him}}
\hadithdefcmd{bukhari}{922}{وَقَالَ مَحْمُودٌ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، قَالَ أَخْبَرَتْنِي فَاطِمَةُ بِنْتُ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ دَخَلْتُ عَلَى عَائِشَةَ ـ رضى الله عنها ـ وَالنَّاسُ يُصَلُّونَ قُلْتُ مَا شَأْنُ النَّاسِ فَأَشَارَتْ بِرَأْسِهَا إِلَى السَّمَاءِ‏.‏ فَقُلْتُ آيَةٌ فَأَشَارَتْ بِرَأْسِهَا أَىْ نَعَمْ‏.‏ قَالَتْ فَأَطَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم جِدًّا حَتَّى تَجَلاَّنِي الْغَشْىُ وَإِلَى جَنْبِي قِرْبَةٌ فِيهَا مَاءٌ فَفَتَحْتُهَا فَجَعَلْتُ أَصُبُّ مِنْهَا عَلَى رَأْسِي، فَانْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ تَجَلَّتِ الشَّمْسُ، فَخَطَبَ النَّاسَ، وَحَمِدَ اللَّهَ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ ‏"‏‏.‏ قَالَتْ وَلَغِطَ نِسْوَةٌ مِنَ الأَنْصَارِ، فَانْكَفَأْتُ إِلَيْهِنَّ لأُسَكِّتَهُنَّ فَقُلْتُ لِعَائِشَةَ مَا قَالَ قَالَتْ قَالَ ‏"‏ مَا مِنْ شَىْءٍ لَمْ أَكُنْ أُرِيتُهُ إِلاَّ قَدْ رَأَيْتُهُ فِي مَقَامِي هَذَا حَتَّى الْجَنَّةَ وَالنَّارَ، وَإِنَّهُ قَدْ أُوحِيَ إِلَىَّ أَنَّكُمْ تُفْتَنُونَ فِي الْقُبُورِ مِثْلَ ـ أَوْ قَرِيبَ مِنْ ـ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ، يُؤْتَى أَحَدُكُمْ، فَيُقَالُ لَهُ مَا عِلْمُكَ بِهَذَا الرَّجُلِ فَأَمَّا الْمُؤْمِنُ ـ أَوْ قَالَ الْمُوقِنُ شَكَّ هِشَامٌ ـ فَيَقُولُ هُوَ رَسُولُ اللَّهِ، هُوَ مُحَمَّدٌ صلى الله عليه وسلم جَاءَنَا بِالْبَيِّنَاتِ وَالْهُدَى فَآمَنَّا وَأَجَبْنَا وَاتَّبَعْنَا وَصَدَّقْنَا‏.‏ فَيُقَالُ لَهُ نَمْ صَالِحًا، قَدْ كُنَّا نَعْلَمُ إِنْ كُنْتَ لَتُؤْمِنُ بِهِ‏.‏ وَأَمَّا الْمُنَافِقُ ـ أَوْ قَالَ الْمُرْتَابُ شَكَّ هِشَامٌ ـ فَيُقَالُ لَهُ مَا عِلْمُكَ بِهَذَا الرَّجُلِ فَيَقُولُ لاَ أَدْرِي، سَمِعْتُ النَّاسَ يَقُولُونَ شَيْئًا فَقُلْتُهُ ‏"‏‏.‏ قَالَ هِشَامٌ فَلَقَدْ قَالَتْ لِي فَاطِمَةُ فَأَوْعَيْتُهُ، غَيْرَ أَنَّهَا ذَكَرَتْ مَا يُغَلِّظُ عَلَيْهِ‏.‏\hadithno{922}\hadithtrans{Narrated Fatima bint Al-Mundhir:Asma' bint Abi Bakr As-Siddiq said, "I went to 'Aishah and the people were offering Salat. I asked her, 'What is wrong with the people ?' She pointed towards the sky with her head. I asked her, 'Is there a sign ?' 'Aishah nodded with her head meaning 'Yes'." Asma' added, "Allah's Messenger (ﷺ) prolonged the Salat to such an extent that I fainted. There was a waterskin by my side and I opened it and poured some water on my head. When Allah's Messenger (ﷺ) finished Salat, and the solar eclipse had cleared, the Prophet (ﷺ) addressed the people and praised Allah as He deserves and said, 'Amma ba'du'." Asma' further said, "Some Ansari women started talking, so I turned to them in order to make them quiet. I asked 'Aishah what the Prophet (ﷺ) had said. 'Aishah said: 'He said, 'I have seen things at this place of mine which were never shown to me before; (I have seen) even Paradise and Hell. And, no doubt it has been revealed to me that you (people) will be put in trial in your graves like or nearly like the trial of Masih Ad-Dajjal. (The angels) will come to everyone of you and ask him, 'What do you know about this man (Prophet Muhammad (ﷺ)) ?" The faithful believer or firm believer (Hisham was in doubt which word the Prophet (ﷺ) used), will say, 'He is Allah's Messenger (ﷺ) and he is Muhammad (ﷺ) who came to us with clear evidences and guidance. So we believed him, accepted his teachings and followed and trusted his teaching.' Then the angels will tell him to sleep (in peace) as they have come to know that he was a believer. But the hypocrite or a doubtful person (Hisham is not sure as to which word the Prophet (ﷺ) used), will be asked what he knew about this man (Prophet Muhammed (ﷺ)). He will say, 'I do not know but I heard the people saying something (about him) so I said the same' " Hisham added, "Fatima told me that she remembered that narration completely by heart except that she said about the hypocrite or a doubtful person that he will be punished severely}}
\hadithdefcmd{bukhari}{923}{حَدَّثَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ جَرِيرِ بْنِ حَازِمٍ، قَالَ سَمِعْتُ الْحَسَنَ، يَقُولُ حَدَّثَنَا عَمْرُو بْنُ تَغْلِبَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِمَالٍ أَوْ سَبْىٍ فَقَسَمَهُ، فَأَعْطَى رِجَالاً وَتَرَكَ رِجَالاً فَبَلَغَهُ أَنَّ الَّذِينَ تَرَكَ عَتَبُوا، فَحَمِدَ اللَّهَ ثُمَّ أَثْنَى عَلَيْهِ، ثُمَّ قَالَ ‏ "‏ أَمَّا بَعْدُ، فَوَاللَّهِ إِنِّي لأُعْطِي الرَّجُلَ، وَأَدَعُ الرَّجُلَ، وَالَّذِي أَدَعُ أَحَبُّ إِلَىَّ مِنَ الَّذِي أُعْطِي وَلَكِنْ أُعْطِي أَقْوَامًا لِمَا أَرَى فِي قُلُوبِهِمْ مِنَ الْجَزَعِ وَالْهَلَعِ، وَأَكِلُ أَقْوَامًا إِلَى مَا جَعَلَ اللَّهُ فِي قُلُوبِهِمْ مِنَ الْغِنَى وَالْخَيْرِ، فِيهِمْ عَمْرُو بْنُ تَغْلِبَ ‏"‏‏.‏ فَوَاللَّهِ مَا أُحِبُّ أَنَّ لِي بِكَلِمَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم حُمْرَ النَّعَمِ‏.‏ تَابَعَهُ يُونُسُ‏.‏\hadithno{923}\hadithtrans{Narrated `Amr bin Taghlib:Some property or something was brought to Allah's Messenger (ﷺ) and he distributed it. He gave to some men and ignored the others. Later he got the news of his being admonished by those whom he had ignored. So he glorified and praised Allah and said, "Amma ba'du. By Allah, I may give to a man and ignore another, although the one whom I ignore is more beloved to me than the one whom I give. But I give to some people as I feel that they have no patience and no contentment in their hearts and I leave those who are patient and self-content with the goodness and wealth which Allah has put into their hearts and `Amr bin Taghlib is one of them." `Amr added, By Allah! Those words of Allah's Apostle are more beloved to me than the best red camels}}
\hadithdefcmd{bukhari}{924}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ ذَاتَ لَيْلَةٍ مِنْ جَوْفِ اللَّيْلِ، فَصَلَّى فِي الْمَسْجِدِ، فَصَلَّى رِجَالٌ بِصَلاَتِهِ فَأَصْبَحَ النَّاسُ فَتَحَدَّثُوا، فَاجْتَمَعَ أَكْثَرُ مِنْهُمْ فَصَلَّوْا مَعَهُ، فَأَصْبَحَ النَّاسُ فَتَحَدَّثُوا فَكَثُرَ أَهْلُ الْمَسْجِدِ مِنَ اللَّيْلَةِ الثَّالِثَةِ، فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّوْا بِصَلاَتِهِ، فَلَمَّا كَانَتِ اللَّيْلَةُ الرَّابِعَةُ عَجَزَ الْمَسْجِدُ عَنْ أَهْلِهِ حَتَّى خَرَجَ لِصَلاَةِ الصُّبْحِ، فَلَمَّا قَضَى الْفَجْرَ أَقْبَلَ عَلَى النَّاسِ، فَتَشَهَّدَ ثُمَّ قَالَ ‏ "‏ أَمَّا بَعْدُ فَإِنَّهُ لَمْ يَخْفَ عَلَىَّ مَكَانُكُمْ، لَكِنِّي خَشِيتُ أَنْ تُفْرَضَ عَلَيْكُمْ فَتَعْجِزُوا عَنْهَا ‏"‏‏.‏ تَابَعَهُ يُونُسُ‏.‏\hadithno{924}\hadithtrans{Narrated Aisha:Once in the middle of the night Allah's Messenger (ﷺ) went out and prayed in the mosque and some men prayed with him. The next morning the people spoke about it and so more people gathered and prayed with him (in the second night). They circulated the news in the morning, and so, on the third night the number of people increased greatly. Allah's Messenger (ﷺ) came out and they prayed behind him. On the fourth night the mosque was overwhelmed by the people till it could not accommodate them. Allah's Messenger (ﷺ) came out only for the Fajr prayer and when he finished the prayer, he faced the people and recited "Tashah-hud" (I testify that none has the right to be worshipped but Allah and that Muhammad is His Apostle), and then said, "Amma ba'du. Verily your presence (in the mosque at night) was not hidden from me, but I was afraid that this prayer (Prayer of Tahajjud) might be made compulsory and you might not be able to carry it out}}
\hadithdefcmd{bukhari}{925}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، أَنَّهُ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ عَشِيَّةً بَعْدَ الصَّلاَةِ، فَتَشَهَّدَ وَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ ‏"‏‏.‏ تَابَعَهُ أَبُو مُعَاوِيَةَ وَأَبُو أُسَامَةَ عَنْ هِشَامٍ عَنْ أَبِيهِ عَنْ أَبِي حُمَيْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أَمَّا بَعْدُ ‏"‏‏.‏ تَابَعَهُ الْعَدَنِيُّ عَنْ سُفْيَانَ فِي أَمَّا بَعْدُ‏.‏\hadithno{925}\hadithtrans{Narrated Abu Hummaid As-Sa`idi:One night Allah's Messenger (ﷺ) stood up after the prayer and recited "Tashah-hud" and then praised Allah as He deserved and said, "Amma ba'du}}
\hadithdefcmd{bukhari}{926}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنٍ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَمِعْتُهُ حِينَ تَشَهَّدَ يَقُولُ ‏ "‏ أَمَّا بَعْدُ ‏"‏‏.‏ تَابَعَهُ الزُّبَيْدِيُّ عَنِ الزُّهْرِيِّ‏.‏\hadithno{926}\hadithtrans{Narrated Al-Miswar bin Makhrama:Once Allah's Messenger (ﷺ) got up for delivering the Khutba and I heard him after "Tashah-hud" saying "Amma ba'du}}
\hadithdefcmd{bukhari}{927}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبَانَ، قَالَ حَدَّثَنَا ابْنُ الْغَسِيلِ، قَالَ حَدَّثَنَا عِكْرِمَةُ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ صَعِدَ النَّبِيُّ صلى الله عليه وسلم الْمِنْبَرَ وَكَانَ آخِرَ مَجْلِسٍ جَلَسَهُ مُتَعَطِّفًا مِلْحَفَةً عَلَى مَنْكِبَيْهِ، قَدْ عَصَبَ رَأْسَهُ بِعِصَابَةٍ دَسِمَةٍ، فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ أَيُّهَا النَّاسُ إِلَىَّ ‏"‏‏.‏ فَثَابُوا إِلَيْهِ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ، فَإِنَّ هَذَا الْحَىَّ مِنَ الأَنْصَارِ يَقِلُّونَ، وَيَكْثُرُ النَّاسُ، فَمَنْ وَلِيَ شَيْئًا مِنْ أُمَّةِ مُحَمَّدٍ صلى الله عليه وسلم فَاسْتَطَاعَ أَنْ يَضُرَّ فِيهِ أَحَدًا أَوْ يَنْفَعَ فِيهِ أَحَدًا، فَلْيَقْبَلْ مِنْ مُحْسِنِهِمْ، وَيَتَجَاوَزْ عَنْ مُسِيِّهِمْ ‏"‏‏.‏\hadithno{927}\hadithtrans{Narrated Ibn `Abbas:Once the Prophet (ﷺ) ascended the pulpit and it was the last gathering in which he took part. He was covering his shoulder with a big cloak and binding his head with an oily bandage. He glorified and praised Allah and said, "O people! Come to me." So the people came and gathered around him and he then said, "Amma ba'du." "From now onward the Ansar will decrease and other people will increase. So anybody who becomes a ruler of the followers of Muhammad and has the power to harm or benefit people then he should accept the good from the benevolent amongst them (Ansar) and overlook the faults of their wrong-doers}}
\hadithdefcmd{bukhari}{928}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ خُطْبَتَيْنِ يَقْعُدُ بَيْنَهُمَا‏.‏\hadithno{928}\hadithtrans{Narrated `Abdullah Ibn `Umar:The Prophet (ﷺ) used to deliver two Khutbas and sit in between them}}
\hadithdefcmd{bukhari}{929}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي عَبْدِ اللَّهِ الأَغَرِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ يَوْمُ الْجُمُعَةِ، وَقَفَتِ الْمَلاَئِكَةُ عَلَى باب الْمَسْجِدِ يَكْتُبُونَ الأَوَّلَ فَالأَوَّلَ، وَمَثَلُ الْمُهَجِّرِ كَمَثَلِ الَّذِي يُهْدِي بَدَنَةً، ثُمَّ كَالَّذِي يُهْدِي بَقَرَةً، ثُمَّ كَبْشًا، ثُمَّ دَجَاجَةً، ثُمَّ بَيْضَةً، فَإِذَا خَرَجَ الإِمَامُ طَوَوْا صُحُفَهُمْ، وَيَسْتَمِعُونَ الذِّكْرَ ‏"‏‏.‏\hadithno{929}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "When it is a Friday, the angels stand at the gate of the mosque and keep on writing the names of the persons coming to the mosque in succession according to their arrivals. The example of the one who enters the mosque in the earliest hour is that of one offering a camel (in sacrifice). The one coming next is like one offering a cow and then a ram and then a chicken and then an egg respectively. When the Imam comes out (for Jumua prayer) they (i.e. angels) fold their papers and listen to the Khutba}}
\hadithdefcmd{bukhari}{930}{حَدَّثَنَا أَبُو النُّعْمَانِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ جَاءَ رَجُلٌ وَالنَّبِيُّ صلى الله عليه وسلم يَخْطُبُ النَّاسَ يَوْمَ الْجُمُعَةِ فَقَالَ ‏"‏ أَصَلَّيْتَ يَا فُلاَنُ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ قُمْ فَارْكَعْ ‏"‏‏.‏\hadithno{930}\hadithtrans{Narrated Jabir bin `Abdullah:A person entered the mosque while the Prophet (ﷺ) was delivering the Khutba on a Friday. The Prophet (ﷺ) said to him, "Have you prayed?" The man replied in the negative. The Prophet (ﷺ) said, "Get up and pray two rak`at}}
\hadithdefcmd{bukhari}{931}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعَ جَابِرًا، قَالَ دَخَلَ رَجُلٌ يَوْمَ الْجُمُعَةِ وَالنَّبِيُّ صلى الله عليه وسلم يَخْطُبُ فَقَالَ ‏"‏ أَصَلَّيْتَ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ فَصَلِّ رَكْعَتَيْنِ ‏"‏‏.‏\hadithno{931}\hadithtrans{Narrated Jabir:A man entered the Mosque while the Prophet (ﷺ) was delivering the Khutba. The Prophet (ﷺ) said to him, "Have you prayed?" The man replied in the negative. The Prophet (ﷺ) said, "Pray two rak`at}}
\hadithdefcmd{bukhari}{932}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ،‏.‏ وَعَنْ يُونُسَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ بَيْنَمَا النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ يَوْمَ الْجُمُعَةِ إِذْ قَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ، هَلَكَ الْكُرَاعُ، وَهَلَكَ الشَّاءُ، فَادْعُ اللَّهَ أَنْ يَسْقِيَنَا‏.‏ فَمَدَّ يَدَيْهِ وَدَعَا‏.‏\hadithno{932}\hadithtrans{Narrated Anas:While the Prophet (ﷺ) was delivering the Khutba on a Friday, a man stood up and said, "O, Allah's Apostle! The livestock and the sheep are dying, so pray to Allah for rain." So he (the Prophet) raised both his hands and invoked Allah (for it)}}
\hadithdefcmd{bukhari}{933}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنَا أَبُو عَمْرٍو، قَالَ حَدَّثَنِي إِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَصَابَتِ النَّاسَ سَنَةٌ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَبَيْنَا النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ فِي يَوْمِ جُمُعَةٍ قَامَ أَعْرَابِيٌّ فَقَالَ يَا رَسُولَ اللَّهِ هَلَكَ الْمَالُ وَجَاعَ الْعِيَالُ، فَادْعُ اللَّهَ لَنَا‏.‏ فَرَفَعَ يَدَيْهِ، وَمَا نَرَى فِي السَّمَاءِ قَزَعَةً، فَوَالَّذِي نَفْسِي بِيَدِهِ مَا وَضَعَهَا حَتَّى ثَارَ السَّحَابُ أَمْثَالَ الْجِبَالِ، ثُمَّ لَمْ يَنْزِلْ عَنْ مِنْبَرِهِ حَتَّى رَأَيْتُ الْمَطَرَ يَتَحَادَرُ عَلَى لِحْيَتِهِ صلى الله عليه وسلم فَمُطِرْنَا يَوْمَنَا ذَلِكَ، وَمِنَ الْغَدِ، وَبَعْدَ الْغَدِ وَالَّذِي يَلِيهِ، حَتَّى الْجُمُعَةِ الأُخْرَى، وَقَامَ ذَلِكَ الأَعْرَابِيُّ ـ أَوْ قَالَ غَيْرُهُ ـ فَقَالَ يَا رَسُولَ اللَّهِ، تَهَدَّمَ الْبِنَاءُ وَغَرِقَ الْمَالُ، فَادْعُ اللَّهَ لَنَا‏.‏ فَرَفَعَ يَدَيْهِ، فَقَالَ ‏ "‏ اللَّهُمَّ حَوَالَيْنَا، وَلاَ عَلَيْنَا ‏"‏‏.‏ فَمَا يُشِيرُ بِيَدِهِ إِلَى نَاحِيَةٍ مِنَ السَّحَابِ إِلاَّ انْفَرَجَتْ، وَصَارَتِ الْمَدِينَةُ مِثْلَ الْجَوْبَةِ، وَسَالَ الْوَادِي قَنَاةُ شَهْرًا، وَلَمْ يَجِئْ أَحَدٌ مِنْ نَاحِيَةٍ إِلاَّ حَدَّثَ بِالْجَوْدِ‏.‏\hadithno{933}\hadithtrans{Narrated Anas bin Malik:Once in the lifetime of the Prophet (ﷺ) the people were afflicted with drought (famine). While the Prophet (ﷺ) was delivering the Khutba on a Friday, a Bedouin stood up and said, "O, Allah's Messenger (ﷺ)! Our possessions are being destroyed and the children are hungry; Please invoke Allah (for rain)". So the Prophet (ﷺ) raised his hands. At that time there was not a trace of cloud in the sky. By Him in Whose Hands my soul is as soon as he lowered his hands, clouds gathered like mountains, and before he got down from the pulpit, I saw the rain falling on the beard of the Prophet. It rained that day, the next day, the third day, the fourth day till the next Friday. The same Bedouin or another man stood up and said, "O Allah's Messenger (ﷺ)! The houses have collapsed, our possessions and livestock have been drowned; Please invoke Allah (to protect us)". So the Prophet (ﷺ) raised both his hands and said, "O Allah! Round about us and not on us". So, in whatever direction he pointed with his hands, the clouds dispersed and cleared away, and Medina's (sky) became clear as a hole in between the clouds. The valley of Qanat remained flooded, for one month, none came from outside but talked about the abundant rain}}
\hadithdefcmd{bukhari}{934}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قُلْتَ لِصَاحِبِكَ يَوْمَ الْجُمُعَةِ أَنْصِتْ‏.‏ وَالإِمَامُ يَخْطُبُ فَقَدْ لَغَوْتَ ‏"‏‏.‏\hadithno{934}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When the Imam is delivering the Khutba, and you ask your companion to keep quiet and listen, then no doubt you have done an evil act}}
\hadithdefcmd{bukhari}{935}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ يَوْمَ الْجُمُعَةِ فَقَالَ ‏ "‏ فِيهِ سَاعَةٌ لاَ يُوَافِقُهَا عَبْدٌ مُسْلِمٌ، وَهْوَ قَائِمٌ يُصَلِّي، يَسْأَلُ اللَّهَ تَعَالَى شَيْئًا إِلاَّ أَعْطَاهُ إِيَّاهُ ‏"‏‏.‏ وَأَشَارَ بِيَدِهِ يُقَلِّلُهَا‏.‏\hadithno{935}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) talked about Friday and said, "There is an hour (opportune time) on Friday and if a Muslim gets it while praying and asks something from Allah, then Allah will definitely meet his demand." And he (the Prophet) pointed out the shortness of that time with his hands}}
\hadithdefcmd{bukhari}{936}{حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، قَالَ حَدَّثَنَا زَائِدَةُ، عَنْ حُصَيْنٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، قَالَ حَدَّثَنَا جَابِرُ بْنُ عَبْدِ اللَّهِ، قَالَ بَيْنَمَا نَحْنُ نُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم إِذْ أَقْبَلَتْ عِيرٌ تَحْمِلُ طَعَامًا، فَالْتَفَتُوا إِلَيْهَا حَتَّى مَا بَقِيَ مَعَ النَّبِيِّ صلى الله عليه وسلم إِلاَّ اثْنَا عَشَرَ رَجُلاً، فَنَزَلَتْ هَذِهِ الآيَةُ ‏\{‏وَإِذَا رَأَوْا تِجَارَةً أَوْ لَهْوًا انْفَضُّوا إِلَيْهَا وَتَرَكُوكَ قَائِمًا‏\}‏\hadithno{936}\hadithtrans{Narrated Jabir bin `Abdullah:While we were praying (Jumua Khutba \& prayer) with the Prophet (ﷺ), some camels loaded with food, arrived (from Sham). The people diverted their attention towards the camels (and left the mosque), and only twelve persons remained with the Prophet. So this verse was revealed: "But when they see Some bargain or some amusement, They disperse headlong to it, And leave you standing}}
\hadithdefcmd{bukhari}{937}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي قَبْلَ الظُّهْرِ رَكْعَتَيْنِ، وَبَعْدَهَا رَكْعَتَيْنِ، وَبَعْدَ الْمَغْرِبِ رَكْعَتَيْنِ فِي بَيْتِهِ، وَبَعْدَ الْعِشَاءِ رَكْعَتَيْنِ وَكَانَ لاَ يُصَلِّي بَعْدَ الْجُمُعَةِ حَتَّى يَنْصَرِفَ فَيُصَلِّي رَكْعَتَيْنِ‏.‏\hadithno{937}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) used to pray two rak`at before the Zuhr prayer and two rak`at after it. He also used to pray two rak`at after the Maghrib prayer in his house, and two rak`at after the `Isha' prayer. He never prayed after Jumua prayer till he departed (from the Mosque), and then he would pray two rak`at at home}}
\hadithdefcmd{bukhari}{938}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، قَالَ حَدَّثَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلٍ، قَالَ كَانَتْ فِينَا امْرَأَةٌ تَجْعَلُ عَلَى أَرْبِعَاءَ فِي مَزْرَعَةٍ لَهَا سِلْقًا، فَكَانَتْ إِذَا كَانَ يَوْمُ جُمُعَةٍ تَنْزِعُ أُصُولَ السِّلْقِ فَتَجْعَلُهُ فِي قِدْرٍ، ثُمَّ تَجْعَلُ عَلَيْهِ قَبْضَةً مِنْ شَعِيرٍ تَطْحَنُهَا، فَتَكُونُ أُصُولُ السِّلْقِ عَرْقَهُ، وَكُنَّا نَنْصَرِفُ مِنْ صَلاَةِ الْجُمُعَةِ فَنُسَلِّمُ عَلَيْهَا، فَتُقَرِّبُ ذَلِكَ الطَّعَامَ إِلَيْنَا فَنَلْعَقُهُ، وَكُنَّا نَتَمَنَّى يَوْمَ الْجُمُعَةِ لِطَعَامِهَا ذَلِكَ‏.‏\hadithno{938}\hadithtrans{Narrated Sahl bin Sa`d:There was a woman amongst us who had a farm and she used to sow Silq (a kind of vegetable) on the edges of streams in her farm. On Fridays she used to pull out the Silq from its roots and put the roots in a utensil. Then she would put a handful of powdered barley over it and cook it. The roots of the Silq were a substitute for meat. After finishing the Jumua prayer we used to greet her and she would give us that food which we would eat with our hands, and because of that meal, we used to look forward to Friday}}
\hadithdefcmd{bukhari}{939}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، قَالَ حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلٍ، بِهَذَا وَقَالَ مَا كُنَّا نَقِيلُ وَلاَ نَتَغَدَّى إِلاَّ بَعْدَ الْجُمُعَةِ‏.‏\hadithno{939}\hadithtrans{Narrated Sahl:As above with the addition: We never had an afternoon nap nor meals except after offering the Jumua prayer}}
\hadithdefcmd{bukhari}{940}{حَدَّثَنَا مُحَمَّدُ بْنُ عُقْبَةَ الشَّيْبَانِيُّ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ حُمَيْدٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ كُنَّا نُبَكِّرُ إِلَى الْجُمُعَةِ ثُمَّ نَقِيلُ‏.‏\hadithno{940}\hadithtrans{Narrated Anas:We used to offer the Jumua prayer early and then have the afternoon nap}}
\hadithdefcmd{bukhari}{941}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، قَالَ حَدَّثَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلٍ، قَالَ كُنَّا نُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم الْجُمُعَةَ ثُمَّ تَكُونُ الْقَائِلَةُ‏.‏\hadithno{941}\hadithtrans{Narrated Sahl:We used to offer the Jumua prayer with the Prophet (ﷺ) and then take the afternoon nap}}
