% Auto-generated chapter 23 for malik
% Hadiths in this chapter: 13

\hadithdefcmd{malik}{1028}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ عُبَيْدِ بْنِ فَيْرُوزَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ مَاذَا يُتَّقَى مِنَ الضَّحَايَا فَأَشَارَ بِيَدِهِ وَقَالَ ‏"‏ أَرْبَعًا ‏"‏ ‏.‏ وَكَانَ الْبَرَاءُ يُشِيرُ بِيَدِهِ وَيَقُولُ يَدِي أَقْصَرُ مِنْ يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ الْعَرْجَاءُ الْبَيِّنُ ظَلْعُهَا وَالْعَوْرَاءُ الْبَيِّنُ عَوَرُهَا وَالْمَرِيضَةُ الْبَيِّنُ مَرَضُهَا وَالْعَجْفَاءُ الَّتِي لاَ تُنْقِي ‏"‏ ‏.‏\hadithno{1028}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Amr ibn al-Harith from Ubayd ibn Fayruz from al-Bara ibn Azib that the Messenger of Allah, may Allah bless him and grant him peace, was asked what animals should be avoided as sacrifices. He indicated with his hand and said, "Four." Al-Bara pointed with his hand and said, "My hand is shorter than the hand of the Messenger of Allah, may Allah bless him and grant him peace. A lame animal whose lameness is evident, a one-eyed animal which is clearly one-eyed, an animal which is clearly ill, and an emaciated animal with no fat on it}}
\hadithdefcmd{malik}{1029}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَتَّقِي مِنَ الضَّحَايَا وَالْبُدْنِ الَّتِي لَمْ تُسِنَّ وَالَّتِي نَقَصَ مِنْ خَلْقِهَا ‏.‏ قَالَ مَالِكٌ وَهَذَا أَحَبُّ مَا سَمِعْتُ إِلَىَّ ‏.‏\hadithno{1029}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar would guard against animals and camels which were young or had physical defects as sacrifices. Malik said, "That is what I like best of what I have heard}}
\hadithdefcmd{malik}{1030}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، ضَحَّى مَرَّةً بِالْمَدِينَةِ ‏.‏ قَالَ نَافِعٌ فَأَمَرَنِي أَنْ أَشْتَرِيَ لَهُ كَبْشًا فَحِيلاً أَقْرَنَ ثُمَّ أَذْبَحَهُ يَوْمَ الأَضْحَى فِي مُصَلَّى النَّاسِ ‏.‏ قَالَ نَافِعٌ فَفَعَلْتُ ثُمَّ حُمِلَ إِلَى عَبْدِ اللَّهِ بْنِ عُمَرَ فَحَلَقَ رَأْسَهُ حِينَ ذُبِحَ الْكَبْشُ وَكَانَ مَرِيضًا لَمْ يَشْهَدِ الْعِيدَ مَعَ النَّاسِ ‏.‏ قَالَ نَافِعٌ وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ يَقُولُ لَيْسَ حِلاَقُ الرَّأْسِ بِوَاجِبٍ عَلَى مَنْ ضَحَّى ‏.‏ وَقَدْ فَعَلَهُ ابْنُ عُمَرَ ‏.‏\hadithno{1030}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that one time Abdullah ibn Umar wanted to sacrifice an animal at Madina. Nafi said, "He told me to buy him an excellent horned ram, then to sacrifice it on the Day of Sacrifice in the place where the people prayed." Nafi continued, "I did so and when the ram was sacrificed, it was carried to Abdullah ibn Umar who shaved his head. He was ill, and did not attend the Id with the people." Nafi added, "Abdullah ibn Umar used to say, 'Shaving the head is not obligatory for someone who sacrifices an animal.' Ibn Umar would do so however}}
\hadithdefcmd{malik}{1031}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، أَنَّ أَبَا بُرْدَةَ بْنَ نِيَارٍ، ذَبَحَ ضَحِيَّتَهُ قَبْلَ أَنْ يَذْبَحَ، رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الأَضْحَى فَزَعَمَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَهُ أَنْ يَعُودَ بِضَحِيَّةٍ أُخْرَى ‏.‏ قَالَ أَبُو بُرْدَةَ لاَ أَجِدُ إِلاَّ جَذَعًا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏ "‏ وَإِنْ لَمْ تَجِدْ إِلاَّ جَذَعًا فَاذْبَحْ ‏"‏ ‏.‏\hadithno{1031}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{ahya related to me from Malik from Yahya ibn Said from Bushayr ibn Yasar that Abu Burda ibn Niyar sacrificed an animal before the Messenger of Allah, may Allah bless him and grant him peace, sacrificed on the Day of Sacrifice. He asserted that the Messenger of Allah, may Allah bless him and grant him peace, ordered him to sacrifice another animal, and he, Abu Burda, said, "What if I can only find an animal less than one year old, Messenger of Allah?" He had said, "If you can only find a young animal, then sacrifice it}}
\hadithdefcmd{malik}{1032}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، أَنَّ عُوَيْمِرَ بْنَ أَشْقَرَ، ذَبَحَ ضَحِيَّتَهُ قَبْلَ أَنْ يَغْدُوَ، يَوْمَ الأَضْحَى وَأَنَّهُ ذَكَرَ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَأَمَرَهُ أَنْ يَعُودَ بِضَحِيَّةٍ أُخْرَى ‏.‏\hadithno{1032}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Abbad ibn Tamin that one time Uwaymir ibn Ashqar sacrificed his animal before the prayer on the morning of the Day of Sacrifice, and he mentioned that the Messenger of Allah, may Allah bless him and grant him peace, had ordered him to sacrifice another animal}}
\hadithdefcmd{malik}{1033}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ أَكْلِ لُحُومِ الضَّحَايَا بَعْدَ ثَلاَثَةِ أَيَّامٍ ثُمَّ قَالَ بَعْدُ ‏ "‏ كُلُوا وَتَصَدَّقُوا وَتَزَوَّدُوا وَادَّخِرُوا ‏"‏ ‏.‏\hadithno{1033}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zubayr al-Makki from Jabir ibn Abdullah that the Messenger of Allah, may Allah bless him and grant him peace, forbade that the meat from sacrificial animals be eaten after three days. Then later he said, "Eat, give sadaqa, provide for yourselves and store up}}
\hadithdefcmd{malik}{1034}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ وَاقِدٍ، أَنَّهُ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَكْلِ لُحُومِ الضَّحَايَا بَعْدَ ثَلاَثَةِ أَيَّامٍ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ فَذَكَرْتُ ذَلِكَ لِعَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ فَقَالَتْ صَدَقَ سَمِعْتُ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ دَفَّ نَاسٌ مِنْ أَهْلِ الْبَادِيَةِ حَضْرَةَ الأَضْحَى فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ادَّخِرُوا لِثَلاَثٍ وَتَصَدَّقُوا بِمَا بَقِيَ ‏"‏ ‏.‏ قَالَتْ فَلَمَّا كَانَ بَعْدَ ذَلِكَ قِيلَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم لَقَدْ كَانَ النَّاسُ يَنْتَفِعُونَ بِضَحَايَاهُمْ وَيَجْمِلُونَ مِنْهَا الْوَدَكَ وَيَتَّخِذُونَ مِنْهَا الأَسْقِيَةَ فَقَالَ رَسُولُ اللَّهِ ‏"‏ وَمَا ذَلِكَ ‏"‏ ‏.‏ أَوْ كَمَا قَالَ ‏.‏ قَالُوا نَهَيْتَ عَنْ لُحُومِ الضَّحَايَا بَعْدَ ثَلاَثٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا نَهَيْتُكُمْ مِنْ أَجْلِ الدَّافَّةِ الَّتِي دَفَّتْ عَلَيْكُمْ فَكُلُوا وَتَصَدَّقُوا وَادَّخِرُوا ‏"‏ ‏.‏\hadithno{1034}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr that Abdullah ibn Waqid said, "The Messengerof Allah, may Allah bless him and grant him peace, forbade eating the meat from sacrificial animals after three days." Abdullah ibn Abi Bakr said, "I mentioned that to Amra bint Abd ar-Rahman, and she affirmed that he had spoken the truth as she had heard A'isha, the wife of the Prophet, may Allah bless him and grant him peace, say, 'Some people from the desert came at the time of the sacrifice in the time of the Messenger of Allah, may Allah bless him and grant him peace, so the Messenger of Allah, may Allah bless him and grant him peace, said, 'Store up for three days, and give what is left over as sadaqa.' " She said that afterwards some one said to the Messenger of Allah, may Allah bless him and grant him peace, that people had been accustomed to make use of their sacrificial animals, melting the fat and curing the skins. The Messenger of Allah, may Allah bless him and grant him peace, said, "What about that?" They said, "You have forbidden the meat of sacrificial animals after three days." The Messenger of Allah, may Allah bless him and grant him peace, said, "I only forbade you for the sake of the people who were coming to you. Eat, give sadaqa and store up." By these people, he meant the poor people who were coming to Madina}}
\hadithdefcmd{malik}{1035}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ قَدِمَ مِنْ سَفَرٍ فَقَدَّمَ إِلَيْهِ أَهْلُهُ لَحْمًا ‏.‏ فَقَالَ انْظُرُوا أَنْ يَكُونَ هَذَا مِنْ لُحُومِ الأَضْحَى ‏.‏ فَقَالُوا هُوَ مِنْهَا ‏.‏ فَقَالَ أَبُو سَعِيدٍ أَلَمْ يَكُنْ رَسُولُ اللَّهِ صلى الله عليه وسلم نَهَى عَنْهَا فَقَالُوا إِنَّهُ قَدْ كَانَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بَعْدَكَ أَمْرٌ ‏.‏ فَخَرَجَ أَبُو سَعِيدٍ فَسَأَلَ عَنْ ذَلِكَ فَأُخْبِرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ نَهَيْتُكُمْ عَنْ لُحُومِ الأَضْحَى بَعْدَ ثَلاَثٍ فَكُلُوا وَتَصَدَّقُوا وَادَّخِرُوا وَنَهَيْتُكُمْ عَنْ الاِنْتِبَاذِ فَانْتَبِذُوا وَكُلُّ مُسْكِرٍ حَرَامٌ وَنَهَيْتُكُمْ عَنْ زِيَارَةِ الْقُبُورِ فَزُورُوهَا وَلاَ تَقُولُوا هُجْرًا ‏"‏ ‏.‏ يَعْنِي لاَ تَقُولُوا سُوءًا ‏.‏\hadithno{1035}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Rabia ibn Abi Abd ar-Rahman that Abu Said alKhudri returned from a journey and his family gave him some meat. He asked whether it was meat from the sacrifice. They replied that it was. Abu Said said, "Didn't the Messenger of Allah, may Allah bless him and grant him peace, forbid that?" They said, "There has been a new command from the Messenger of Allah, may Allah bless him and grant him peace, since you went away." Abu Said went out and made enquiries about it and was told that the Messenger of Allah, may Allah bless him and grant him peace, had said,"I forbade you before to eat meat of the sacrifice after three days, but now eat, give sadaqa and store up. I forbade you before to make nabidh (by soaking raisins or dates in water), but now make nabidh, but remember every intoxicant is haram .I forbade you to visit graves, but now visit them, and do not use bad language}}
\hadithdefcmd{malik}{1036}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ قَالَ نَحَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ الْحُدَيْبِيَةِ الْبَدَنَةَ عَنْ سَبْعَةٍ وَالْبَقَرَةَ عَنْ سَبْعَةٍ ‏.‏\hadithno{1036}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zubayr al-Makki that Jabir ibn Abdullah said, "We sacrificed with the Messenger of Allah, may Allah bless him and grant him peace, in the year of Hudaybiya, a camel between seven people, and a cow between seven people}}
\hadithdefcmd{malik}{1037}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عُمَارَةَ بْنِ صَيَّادٍ، أَنَّ عَطَاءَ بْنَ يَسَارٍ، أَخْبَرَهُ أَنَّ أَبَا أَيُّوبَ الأَنْصَارِيَّ أَخْبَرَهُ قَالَ كُنَّا نُضَحِّي بِالشَّاةِ الْوَاحِدَةِ يَذْبَحُهَا الرَّجُلُ عَنْهُ وَعَنْ أَهْلِ بَيْتِهِ ثُمَّ تَبَاهَى النَّاسُ بَعْدُ فَصَارَتْ مُبَاهَاةً ‏.‏\hadithno{1037}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Umara ibn Yasar that Ata ibn Yasar told him that Abu Ayyub al-Ansari had told him, "We used to sacrifice one sheep, and a man sacrificed for himself and his family. Then later on people began to compete with each other and it became boasting." Malik said, "The best that I have heard about a single camel, cow or sheep, is that a man should sacrifice a camel for himself and his family. He sacrifices a cow or sheep which he owns for his family, and shares with them in it. It is disapproved for a group of people to buy a camel, cow or sheep, to share for the ritual and sacrifices, each man giving a share of its price, and taking a share of its meat. We have heard the tradition that people do not share in the ritual. However, it may be that the people of one household can share}}
\hadithdefcmd{malik}{1038}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ مَا نَحَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْهُ وَعَنْ أَهْلِ بَيْتِهِ إِلاَّ بَدَنَةً وَاحِدَةً أَوْ بَقَرَةً وَاحِدَةً ‏.‏ قَالَ مَالِكٌ لاَ أَدْرِي أَيَّتَهُمَا قَالَ ابْنُ شِهَابٍ ‏.‏\hadithno{1038}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that Ibn Shihab said, "The Messenger of Allah, may Allah bless him and grant him peace, only sacrificed one camel or one cow for himself and his family." Malik said, "I do not know which of them Ibn Shihab said}}
\hadithdefcmd{malik}{1039}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ الأَضْحَى يَوْمَانِ بَعْدَ يَوْمِ الأَضْحَى ‏.‏ وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، مِثْلُ ذَلِكَ ‏\hadithno{1039}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "The sacrifice can be done up to two days after the Day of Sacrifice." Yahya related to me from Malik that he had heard the same from Ali ibn Abi Talib}}
\hadithdefcmd{malik}{1041}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، لَمْ يَكُنْ يُضَحِّي عَمَّا فِي بَطْنِ الْمَرْأَةِ ‏.‏ قَالَ مَالِكٌ الضَّحِيَّةُ سُنَّةٌ وَلَيْسَتْ بِوَاجِبَةٍ وَلاَ أُحِبُّ لأَحَدٍ مِمَّنْ قَوِيَ عَلَى ثَمَنِهَا أَنْ يَتْرُكَهَا ‏.‏\hadithno{1041}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar did not sacrifice for the child in the womb. Malik said, "The sacrifice is sunna, and it is not obligatory. I prefer that anyone who has the price of the animal should not abandon it}}
