% Auto-generated chapter 19 for muslim
% Hadiths in this chapter: 27

\hadithdefcmd{muslim}{3743}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، أَنَّ سَهْلَ بْنَ سَعْدٍ، السَّاعِدِيَّ أَخْبَرَهُ أَنَّ عُوَيْمِرًا الْعَجْلاَنِيَّ جَاءَ إِلَى عَاصِمِ بْنِ عَدِيٍّ الأَنْصَارِيِّ فَقَالَ لَهُ أَرَأَيْتَ يَا عَاصِمُ لَوْ أَنَّ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً أَيَقْتُلُهُ فَتَقْتُلُونَهُ أَمْ كَيْفَ يَفْعَلُ فَسَلْ لِي عَنْ ذَلِكَ يَا عَاصِمُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَسَأَلَ عَاصِمٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فَكَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسَائِلَ وَعَابَهَا حَتَّى كَبُرَ عَلَى عَاصِمٍ مَا سَمِعَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَجَعَ عَاصِمٌ إِلَى أَهْلِهِ جَاءَهُ عُوَيْمِرٌ فَقَالَ يَا عَاصِمُ مَاذَا قَالَ لَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ عَاصِمٌ لِعُوَيْمِرٍ لَمْ تَأْتِنِي بِخَيْرٍ قَدْ كَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسْأَلَةَ الَّتِي سَأَلْتُهُ عَنْهَا ‏.‏ قَالَ عُوَيْمِرٌ وَاللَّهِ لاَ أَنْتَهِي حَتَّى أَسْأَلَهُ عَنْهَا ‏.‏ فَأَقْبَلَ عُوَيْمِرٌ حَتَّى أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم وَسَطَ النَّاسِ فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً أَيَقْتُلُهُ فَتَقْتُلُونَهُ أَمْ كَيْفَ يَفْعَلُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ نَزَلَ فِيكَ وَفِي صَاحِبَتِكَ فَاذْهَبْ فَأْتِ بِهَا ‏"‏ ‏.‏ قَالَ سَهْلٌ فَتَلاَعَنَا وَأَنَا مَعَ النَّاسِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا فَرَغَا قَالَ عُوَيْمِرٌ كَذَبْتُ عَلَيْهَا يَا رَسُولَ اللَّهِ إِنْ أَمْسَكْتُهَا ‏.‏ فَطَلَّقَهَا ثَلاَثًا قَبْلَ أَنْ يَأْمُرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ ابْنُ شِهَابٍ فَكَانَتْ سُنَّةَ الْمُتَلاَعِنَيْنِ ‏.‏\hadithno{3743}\hadithtrans{Sahl b. Sa'd al-Sa'idi reported that'Uwaimir al-'Ajlani came to 'Asim b. 'Adi al-Ansari and said to him. Tell me about a person who finds a man with his wife; should he kill him, and be killed In retaliation; or how should he act? 'Asim, ask for me (religious verdict about it) from Allah's Messenger (ﷺ). So 'Asim asked Allah's Messenger (ﷺ) and he did not like this question and he disapproved of it so much that'Asim felt aggrieved at what he had heard from Allah's Messenger (ﷺ). When 'Asim came back to his family, 'Uwaimir came to him and said:'Asim, what did Allah's Messenger (ﷺ) say to you? 'Asim said to 'Uwaimir: You did not bring something good. Allah's Messenger (ﷺ) did not like this religious verdict that I sought from him. 'Uwaimir said: By Allah, I will not rest until I have asked him about it. 'Uwaimir proceeded until he came to Allah's Messenger (ﷺ) as he was sitting amidst people, and said: Messenger of Allah, tell me about a person who found a man with his wife. Should he kill him, and then you would kill him, or how should he act? Thereupon Allah's Messenger (ﷺ) said: (Verses) have been revealed concerning you and your wife; so go and bring her. Sahl said that they both invoked curses (and further said): I was along with people in the company of Allah's Messenger (ﷺ). And when they had finished, Uwaimir said: Allah's Messenger, I shall have told a lie against her if I keep her (now). So he divorced her with three pronouncements before Allah's Messenger (ﷺ) had commanded him. Ibn Shihab said: Subsequently that was the practice of invokers of curses (al Mutala'inain)}}
\hadithdefcmd{muslim}{3744}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَهْلُ بْنُ سَعْدٍ الأَنْصَارِيُّ، أَنَّ عُوَيْمِرًا الأَنْصَارِيَّ، مِنْ بَنِي الْعَجْلاَنِ أَتَى عَاصِمَ بْنَ عَدِيٍّ ‏.‏ وَسَاقَ الْحَدِيثَ بِمِثْلِ حَدِيثِ مَالِكٍ وَأَدْرَجَ فِي الْحَدِيثِ قَوْلَهُ وَكَانَ فِرَاقُهُ إِيَّاهَا بَعْدُ سُنَّةً فِي الْمُتَلاَعِنَيْنِ ‏.‏ وَزَادَ فِيهِ قَالَ سَهْلٌ فَكَانَتْ حَامِلاً فَكَانَ ابْنُهَا يُدْعَى إِلَى أُمِّهِ ‏.‏ ثُمَّ جَرَتِ السُّنَّةُ أَنَّهُ يَرِثُهَا وَتَرِثُ مِنْهُ مَا فَرَضَ اللَّهُ لَهَا ‏.‏\hadithno{3744}\hadithtrans{Sahl b. Sa'd reported.. 'Uwaimir al-Ansari (Allah be pleased with him) from Banu'l-'Ajlan came to 'Asim b. 'Adi (Allah be pleased with him) the remaining part of the hadith is the same and it was also reecorded in it:" And subsequebtly the separation became the practice of al-Mutala'inain." And this addition was also made:" She was pregnant and her son was ascribed to her, and it became customary that such (a son) would inherit her and she would inherit him in the share prescribed by Allah for her}}
\hadithdefcmd{muslim}{3745}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي ابْنُ شِهَابٍ، عَنِ الْمُتَلاَعِنَيْنِ، وَعَنِ السُّنَّةِ، فِيهِمَا عَنْ حَدِيثِ، سَهْلِ بْنِ سَعْدٍ أَخِي بَنِي سَاعِدَةَ أَنَّ رَجُلاً، مِنَ الأَنْصَارِ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً وَذَكَرَ الْحَدِيثَ بِقِصَّتِهِ ‏.‏ وَزَادَ فِيهِ فَتَلاَعَنَا فِي الْمَسْجِدِ وَأَنَا شَاهِدٌ ‏.‏ وَقَالَ فِي الْحَدِيثِ فَطَلَّقَهَا ثَلاَثًا قَبْلَ أَنْ يَأْمُرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَفَارَقَهَا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ ذَاكُمُ التَّفْرِيقُ بَيْنَ كُلِّ مُتَلاَعِنَيْنِ ‏"‏ ‏.‏\hadithno{3745}\hadithtrans{Ibn Shihab narrated about the invokers of curses and the practice of (li'an) based on the authority of Sahl b. Sa'd, of the tribe of Sa'ida. that a person from the Ansar came to Allah's Apostle (ﷺ) and said:Allah's Messenger, tell me about the person who found a man with his wife. The remaining part of the hadith is the same (but) with this addition: They invoked curses in the mosque and I was present there. And he narrated in the hadith: He divorced her with three pronouncements before Allah's Messenger (ﷺ) commanded him (to get separation). He separated from her in the presence of Allah's Apostle (ﷺ), whereupon he said: There is a separation between the invokers of curses}}
\hadithdefcmd{muslim}{3746}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، عَنْ سَعِيدِ بْنِ، جُبَيْرٍ قَالَ سُئِلْتُ عَنِ الْمُتَلاَعِنَيْنِ، فِي إِمْرَةِ مُصْعَبٍ أَيُفَرَّقُ بَيْنَهُمَا قَالَ فَمَا دَرَيْتُ مَا أَقُولُ فَمَضَيْتُ إِلَى مَنْزِلِ ابْنِ عُمَرَ بِمَكَّةَ فَقُلْتُ لِلْغُلاَمِ اسْتَأْذِنْ لِي ‏.‏ قَالَ إِنَّهُ قَائِلٌ فَسَمِعَ صَوْتِي ‏.‏ قَالَ ابْنُ جُبَيْرٍ قُلْتُ نَعَمْ ‏.‏ قَالَ ادْخُلْ فَوَاللَّهِ مَا جَاءَ بِكَ هَذِهِ السَّاعَةَ إِلاَّ حَاجَةٌ فَدَخَلْتُ فَإِذَا هُوَ مُفْتَرِشٌ بَرْذَعَةً مُتَوَسِّدٌ وِسَادَةً حَشْوُهَا لِيفٌ قُلْتُ أَبَا عَبْدِ الرَّحْمَنِ الْمُتَلاَعِنَانِ أَيُفَرَّقُ بَيْنَهُمَا قَالَ سُبْحَانَ اللَّهِ نَعَمْ إِنَّ أَوَّلَ مَنْ سَأَلَ عَنْ ذَلِكَ فُلاَنُ بْنُ فُلاَنٍ قَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ أَنْ لَوْ وَجَدَ أَحَدُنَا امْرَأَتَهُ عَلَى فَاحِشَةٍ كَيْفَ يَصْنَعُ إِنْ تَكَلَّمَ تَكَلَّمَ بِأَمْرٍ عَظِيمٍ ‏.‏ وَإِنْ سَكَتَ سَكَتَ عَلَى مِثْلِ ذَلِكَ قَالَ فَسَكَتَ النَّبِيُّ صلى الله عليه وسلم فَلَمْ يُجِبْهُ فَلَمَّا كَانَ بَعْدَ ذَلِكَ أَتَاهُ فَقَالَ إِنَّ الَّذِي سَأَلْتُكَ عَنْهُ قَدِ ابْتُلِيتُ بِهِ ‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ هَؤُلاَءِ الآيَاتِ فِي سُورَةِ النُّورِ ‏\{‏ وَالَّذِينَ يَرْمُونَ أَزْوَاجَهُمْ‏\}‏ فَتَلاَهُنَّ عَلَيْهِ وَوَعَظَهُ وَذَكَّرَهُ وَأَخْبَرَهُ أَنَّ عَذَابَ الدُّنْيَا أَهْوَنُ مِنْ عَذَابِ الآخِرَةِ قَالَ لاَ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا كَذَبْتُ عَلَيْهَا ‏.‏ ثُمَّ دَعَاهَا فَوَعَظَهَا وَذَكَّرَهَا وَأَخْبَرَهَا أَنَّ عَذَابَ الدُّنْيَا أَهْوَنُ مِنْ عَذَابِ الآخِرَةِ ‏.‏ قَالَتْ لاَ وَالَّذِي بَعَثَكَ بِالْحَقِّ إِنَّهُ لَكَاذِبٌ فَبَدَأَ بِالرَّجُلِ فَشَهِدَ أَرْبَعَ شَهَادَاتٍ بِاللَّهِ إِنَّهُ لَمِنَ الصَّادِقِينَ وَالْخَامِسَةُ أَنَّ لَعْنَةَ اللَّهِ عَلَيْهِ إِنْ كَانَ مِنَ الْكَاذِبِينَ ثُمَّ ثَنَّى بِالْمَرْأَةِ فَشَهِدَتْ أَرْبَعَ شَهَادَاتٍ بِاللَّهِ إِنَّهُ لَمِنَ الْكَاذِبِينَ وَالْخَامِسَةُ أَنَّ غَضَبَ اللَّهِ عَلَيْهَا إِنْ كَانَ مِنَ الصَّادِقِينَ ثُمَّ فَرَّقَ بَيْنَهُمَا.‏\hadithno{3746}\hadithtrans{Sa'id b Jubair reported:I was asked about the invokers of curses during the reign of Mus'ab (b. Zubair) whether they could separate (themselves by this process). He said: I did not understand what to say. So I went to the house of Ibn 'Umar (Allah be pleased with them) in Mecca. I said to his servant: Seek permission for Me. He said that he (Ibn 'Umar) had been taking rest. He (Ibn 'Umar) heard my voice. and said: Are you Ibn Jubair? I said: Yes. He'said: Come in. By Allah, it must be some (great) need which has brought you here at this Hour. So I got in and found him lying on a blanket reclining against a pillow stuffed with fibres of date-palm. I said: O Abu'Abd al-Rahman, should there be separation between the invokers of curses? He said: Hallowed be Allah, yes, The first one who asked about it was so and so. he said: Messenger of Allah, tell me If one of us finds his wife committing adultery: what should he do? If he talks, that is something great, and if he keeps quiet that is also (something great) (which he cannot afford to do). Allah's Prophet (ﷺ) kept quiet (or some time). After some time he (that very person) came to him (Allah's Messenger) and said: I have been involved in that very cage about which I had asked you Allah the Exalted and Majestic then revealed (these) verses of Surah Nur:" Those who accuse their wives" (verse 6), and he (the Holy Prophet) recited them to him and admonished him, and exhorted him and informed him that the torment of the world is less painful than the torment of the Hereafter. He said: No, by Him Who sent you with Truth, I did not tell a lie against her. He (the Holy Prophet) then called her (the wife of that person who had accused her) and admonished her, and exhorted her, and informed her that the torment of this world is less painful than the torment of the Hereafter. She said: No, by Him Who sent thee with Truth, he is a liar. (it was) the man who started the swearing of oath and he swore in the name of Allah four times that he was among the truthful. and at the fifth turn he said: Let there be curse of Allah upon him if he were among the liars. Then the woman was called and she swore four times in the name of Allah that he (her husband) was among the liars, and at the fifth time (she said): Let there be curse upon her if he were among the truthful. He (the Holy Prophet) then effected separation between the two}}
\hadithdefcmd{muslim}{3747}{وَحَدَّثَنِيهِ عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ، أَبِي سُلَيْمَانَ قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، قَالَ سُئِلْتُ عَنِ الْمُتَلاَعِنَيْنِ، زَمَنَ مُصْعَبِ بْنِ الزُّبَيْرِ فَلَمْ أَدْرِ مَا أَقُولُ فَأَتَيْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ فَقُلْتُ أَرَأَيْتَ الْمُتَلاَعِنَيْنِ أَيُفَرَّقُ بَيْنَهُمَا ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ ابْنِ نُمَيْرٍ ‏.‏\hadithno{3747}\hadithtrans{A hadith like this is narrated by Ibn Numair with a slight variation of words}}
\hadithdefcmd{muslim}{3748}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ - وَاللَّفْظُ لِيَحْيَى - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ سَعِيدِ بْنِ، جُبَيْرٍ عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلْمُتَلاَعِنَيْنِ ‏"‏ حِسَابُكُمَا عَلَى اللَّهِ أَحَدُكُمَا كَاذِبٌ لاَ سَبِيلَ لَكَ عَلَيْهَا ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ مَالِي قَالَ ‏"‏ لاَ مَالَ لَكَ إِنْ كُنْتَ صَدَقْتَ عَلَيْهَا فَهْوَ بِمَا اسْتَحْلَلْتَ مِنْ فَرْجِهَا وَإِنْ كُنْتَ كَذَبْتَ عَلَيْهَا فَذَاكَ أَبْعَدُ لَكَ مِنْهَا ‏"‏ ‏.‏ قَالَ زُهَيْرٌ فِي رِوَايَتِهِ حَدَّثَنَا سُفْيَانُ عَنْ عَمْرٍو سَمِعَ سَعِيدَ بْنَ جُبَيْرٍ يَقُولُ سَمِعْتُ ابْنَ عُمَرَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3748}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) saying to the invokers of curse:Your account is with Allah. One of you must be a liar. You have now no right over this woman. He said: Messenger of Allah, what about my wealth (dower that I paid her at the time of marriage)? He said: You have no claim to wealth. If you tell the truth, it (dower) is the recompense for your having had the right to intercourse with her, and if you tell a lie against her, it is still more remote from you than she is. Zuhair said in his narration: Sufyan reported to us on the authority of 'Amr that he had heard Sa'id b Jubair saying: I heard Ibn Umar (Allah be pleased with them) saying that Allah's Messenger (ﷺ) had said it}}
\hadithdefcmd{muslim}{3749}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، قَالَ فَرَّقَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَخَوَىْ بَنِي الْعَجْلاَنِ وَقَالَ ‏ "‏ اللَّهُ يَعْلَمُ أَنَّ أَحَدَكُمَا كَاذِبٌ فَهَلْ مِنْكُمَا تَائِبٌ ‏"‏ ‏.‏\hadithno{3749}\hadithtrans{Ibn 'Umar (Allah be pleased with them) said that Allah's Messenger (ﷺ) effected separation between the two members of Banu al-'Ajlan, and said:Allah knows that one of you is a liar. Is there one to repent among you?}}
\hadithdefcmd{muslim}{3750}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، سَمِعَ سَعِيدَ بْنَ جُبَيْرٍ، قَالَ سَأَلْتُ ابْنَ عُمَرَ عَنِ اللِّعَانِ، ‏.‏ فَذَكَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{3750}\hadithtrans{Sa'id b. Jubair reported:I asked Ibn 'Umar (Allah be pleased with them) about invoking curse (li'an), and he narrated Similarly from Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{3751}{وَحَدَّثَنَا أَبُو غَسَّانَ الْمِسْمَعِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لِلْمِسْمَعِيِّ وَابْنِ الْمُثَنَّى - قَالُوا حَدَّثَنَا مُعَاذٌ، - وَهُوَ ابْنُ هِشَامٍ - قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ عَزْرَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ لَمْ يُفَرِّقِ الْمُصْعَبُ بَيْنَ الْمُتَلاَعِنَيْنِ ‏.‏ قَالَ سَعِيدٌ فَذُكِرَ ذَلِكَ لِعَبْدِ اللَّهِ بْنِ عُمَرَ ‏.‏ فَقَالَ فَرَّقَ نَبِيُّ اللَّهِ صلى الله عليه وسلم بَيْنَ أَخَوَىْ بَنِي الْعَجْلاَنِ ‏.‏\hadithno{3751}\hadithtrans{Sa'id b. Jubair reported that Mus'ab b. Zubair did not effect separation between the Mutala'inain (invokers of curses). Sa'id said:It was mentioned to 'Abdullah b. Umar (Allah be pleased with them) and he said: Allah's Apostle (ﷺ) effected separation between the two members of Banu al-'Ajlan}}
\hadithdefcmd{muslim}{3752}{وَحَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا يَحْيَى، بْنُ يَحْيَى - وَاللَّفْظُ لَهُ - قَالَ قُلْتُ لِمَالِكٍ حَدَّثَكَ نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، لاَعَنَ امْرَأَتَهُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَفَرَّقَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَهُمَا وَأَلْحَقَ الْوَلَدَ بِأُمِّهِ قَالَ نَعَمْ ‏.‏\hadithno{3752}\hadithtrans{Nafi' reported on the authority of Ibn Umar (Allah be pleased with them) that a person invoked curse on the wife during the lifetime of Allah s Messenger (ﷺ), so he effected separation between them and traced the lineage of the son to his mother}}
\hadithdefcmd{muslim}{3753}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ لاَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ رَجُلٍ مِنَ الأَنْصَارِ وَامْرَأَتِهِ وَفَرَّقَ بَيْنَهُمَا ‏.‏\hadithno{3753}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported:Allah's Messenger (ﷺ) asked a person from the Anger and his wife to invoke curse (upon one another in order to testify to their truthfulness), and then effected separation between them}}
\hadithdefcmd{muslim}{3754}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{3754}\hadithtrans{A hadith like this has been narrated on the authority of 'Ubaidulah with the same chain of transmitters}}
\hadithdefcmd{muslim}{3755}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ إِنَّا لَيْلَةَ الْجُمُعَةِ فِي الْمَسْجِدِ إِذْ جَاءَ رَجُلٌ مِنَ الأَنْصَارِ فَقَالَ لَوْ أَنَّ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً فَتَكَلَّمَ جَلَدْتُمُوهُ أَوْ قَتَلَ قَتَلْتُمُوهُ وَإِنْ سَكَتَ سَكَتَ عَلَى غَيْظٍ وَاللَّهِ لأَسْأَلَنَّ عَنْهُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَلَمَّا كَانَ مِنَ الْغَدِ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ فَقَالَ لَوْ أَنَّ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً فَتَكَلَّمَ جَلَدْتُمُوهُ أَوْ قَتَلَ قَتَلْتُمُوهُ أَوْ سَكَتَ سَكَتَ عَلَى غَيْظٍ ‏.‏ فَقَالَ ‏"‏ اللَّهُمَّ افْتَحْ ‏"‏ ‏.‏ وَجَعَلَ يَدْعُو فَنَزَلَتْ آيَةُ اللِّعَانِ ‏\{‏ وَالَّذِينَ يَرْمُونَ أَزْوَاجَهُمْ وَلَمْ يَكُنْ لَهُمْ شُهَدَاءُ إِلاَّ أَنْفُسُهُمْ‏\}‏ هَذِهِ الآيَاتُ فَابْتُلِيَ بِهِ ذَلِكَ الرَّجُلُ مِنْ بَيْنِ النَّاسِ فَجَاءَ هُوَ وَامْرَأَتُهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَتَلاَعَنَا فَشَهِدَ الرَّجُلُ أَرْبَعَ شَهَادَاتٍ بِاللَّهِ إِنَّهُ لَمِنَ الصَّادِقِينَ ثُمَّ لَعَنَ الْخَامِسَةَ أَنَّ لَعْنَةَ اللَّهِ عَلَيْهِ إِنْ كَانَ مِنَ الْكَاذِبِينَ فَذَهَبَتْ لِتَلْعَنَ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَهْ ‏"‏ ‏.‏ فَأَبَتْ فَلَعَنَتْ فَلَمَّا أَدْبَرَا قَالَ ‏"‏ لَعَلَّهَا أَنْ تَجِيءَ بِهِ أَسْوَدَ جَعْدًا ‏"‏ ‏.‏ فَجَاءَتْ بِهِ أَسْوَدَ جَعْدًا‏.‏\hadithno{3755}\hadithtrans{Abdullah reported:We were on the night of Friday staying in the mosque when a person from the Ansar came there and said: If a person finds hiswoman along with a man, and he speaks about it, you would lash him, and if he kills, you will kill him, and if he keeps quiet he shall have to consume anger. By Allah, I will definitely ask about him from Allah's Mescenger (ﷺ). On the following day he came to Allah's Messenger (ﷺ) and asked him thus: If a man were to find with his wife a man and if he were to talk about it, you would lash him; and if he killed, you would kill him, and if he were to keep quiet. he would consume anger, whereupon he (the Holy Prophet) said: Allah, solve (this problem), and he began to supplicate (before Him), and then the verses pertaining to li'an were revealed:" Those who accuse their wives and have no witnesses except themselves" (xxiv. 6). The person was then put to test according to these verses in the presence of the people. There came he and his wife in the presence of Allah's Messenger (ﷺ), and they invoked curses (in order to testify their claim). The man swore four times in the name of Allah that he was one of the truthful and then invoked curse for the fifth time saying: Let there be curse of Allah upon him if he were among the liars. Then she began to invoke curse. Allah's Messenger (ﷺ) said to her: just wait (and curse after considering over it), but she refused and invoked curse and when she turned away, he (Allah's Apostle) said: It seems that this woman shall give birth to a curly-haired black child, And so she did gave birth to a curly-haired black child}}
\hadithdefcmd{muslim}{3756}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ، أَبِي شَيْبَةَ حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، جَمِيعًا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{3756}\hadithtrans{A hadith like this is narrated on the authority of A'mash}}
\hadithdefcmd{muslim}{3757}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ وَأَنَا أُرَى، أَنَّ عِنْدَهُ، مِنْهُ عِلْمًا ‏.‏ فَقَالَ إِنَّ هِلاَلَ بْنَ أُمَيَّةَ قَذَفَ امْرَأَتَهُ بِشَرِيكِ ابْنِ سَحْمَاءَ وَكَانَ أَخَا الْبَرَاءِ بْنِ مَالِكٍ لأُمِّهِ وَكَانَ أَوَّلَ رَجُلٍ لاَعَنَ فِي الإِسْلاَمِ - قَالَ - فَلاَعَنَهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَبْصِرُوهَا فَإِنْ جَاءَتْ بِهِ أَبْيَضَ سَبِطًا قَضِيءَ الْعَيْنَيْنِ فَهُوَ لِهِلاَلِ بْنِ أُمَيَّةَ وَإِنْ جَاءَتْ بِهِ أَكْحَلَ جَعْدًا حَمْشَ السَّاقَيْنِ فَهُوَ لِشَرِيكِ ابْنِ سَحْمَاءَ ‏"‏ ‏.‏ قَالَ فَأُنْبِئْتُ أَنَّهَا جَاءَتْ بِهِ أَكْحَلَ جَعْدًا حَمْشَ السَّاقَيْنِ ‏.‏\hadithno{3757}\hadithtrans{Muhammad (one of the narrators) reported:I asked Anas b. Malik (Allah be pleased with him) knowing that he had a knowledge of (the case of li'an). He said: Hilal b. Umayya (Allah be pleased with him) accused his wife with the charge of fornication with Sharik b. Sahma, the brother of al-Bara'b Malik from the side of his mother. And he was the first person who invoked curse (li'an) in Islam. He in fact invoked curse upon her. Allah's Messenger (ﷺ) said: See to her if she gives birth to a white-complexioned child having dark hair and bright eyes; he must be the son of Hilal b. Umayya; and if she gives birth to a child with dark eyelids, curly hair and lean shanks, he must be the offspring of Sharik b. Sahma. He said: I was informed that she gave birth to a child having dark eyelids, curly hair and lean shanks}}
\hadithdefcmd{muslim}{3758}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، وَعِيسَى بْنُ حَمَّادٍ الْمِصْرِيَّانِ، - وَاللَّفْظُ لاِبْنِ رُمْحٍ - قَالاَ أَخْبَرَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنِ الْقَاسِمِ، بْنِ مُحَمَّدٍ عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ ذُكِرَ التَّلاَعُنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ عَاصِمُ بْنُ عَدِيٍّ فِي ذَلِكَ قَوْلاً ثُمَّ انْصَرَفَ فَأَتَاهُ رَجُلٌ مِنْ قَوْمِهِ يَشْكُو إِلَيْهِ أَنَّهُ وَجَدَ مَعَ أَهْلِهِ رَجُلاً ‏.‏ فَقَالَ عَاصِمٌ مَا ابْتُلِيتُ بِهَذَا إِلاَّ لِقَوْلِي فَذَهَبَ بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ بِالَّذِي وَجَدَ عَلَيْهِ امْرَأَتَهُ وَكَانَ ذَلِكَ الرَّجُلُ مُصْفَرًّا قَلِيلَ اللَّحْمِ سَبِطَ الشَّعَرِ وَكَانَ الَّذِي ادَّعَى عَلَيْهِ أَنَّهُ وَجَدَ عِنْدَ أَهْلِهِ خَدْلاً آدَمَ كَثِيرَ اللَّحْمِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ بَيِّنْ ‏"‏ ‏.‏ فَوَضَعَتْ شَبِيهًا بِالرَّجُلِ الَّذِي ذَكَرَ زَوْجُهَا أَنَّهُ وَجَدَهُ عِنْدَهَا فَلاَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَهُمَا فَقَالَ رَجُلٌ لاِبْنِ عَبَّاسٍ فِي الْمَجْلِسِ أَهِيَ الَّتِي قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ رَجَمْتُ أَحَدًا بِغَيْرِ بَيِّنَةٍ رَجَمْتُ هَذِهِ ‏"‏ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ لاَ تِلْكَ امْرَأَةٌ كَانَتْ تُظْهِرُ فِي الإِسْلاَمِ السُّوءَ ‏.‏\hadithno{3758}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported:Mention was made of li'an in the presence of Allah's Messenger (ﷺ). And Asim b. 'Adi passed a remark about it and then turned away, and a man of his tribe came to him complaining that he had found a man with his wife, whereupon 'Asim said: I have been taken by my words. He took him to Allah's Messenger (ﷺ) and told him about the man whom he had found with his wife and this man was a lean, yellow-coloured man with lank hair, and the person who was accused of committing adultery with her (his wife) had fleshy shanks, with wheat complexion and heavy bulk. Allah's Messenger (ﷺ) said: O Allah, make (this case) manifest. And as she gave birth to a child, whose face resembled that person about whom her husband had made mention that he had found her with, and Allah's Messenger (may peace be, upon him) had asked them to invoke curses. A person said to Ibn 'Abbas (Allah be pleased with him): Is she (that woman) about whom Allah's Messenger (may peace be upen him) (said):" If I were to stone anybody without evidence, I would have stoned her"? Ibn 'Abbas (Allah be pleased with him) said: No, it is not she. That woman was one who openly spread evil in society}}
\hadithdefcmd{muslim}{3759}{وَحَدَّثَنِيهِ أَحْمَدُ بْنُ يُوسُفَ الأَزْدِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، حَدَّثَنِي سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ يَحْيَى، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ ذُكِرَ الْمُتَلاَعِنَانِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ اللَّيْثِ وَزَادَ فِيهِ بَعْدَ قَوْلِهِ كَثِيرَ اللَّحْمِ قَالَ جَعْدًا قَطَطًا ‏.‏\hadithno{3759}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Abbas (Allah be pleased with them) through another chain of transmitters with the addition of these words:'With flesh, and curly tangled hair}}
\hadithdefcmd{muslim}{3760}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لِعَمْرٍو - قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ، عُيَيْنَةَ عَنْ أَبِي الزِّنَادِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ شَدَّادٍ وَذُكِرَ الْمُتَلاَعِنَانِ عِنْدَ ابْنِ عَبَّاسٍ فَقَالَ ابْنُ شَدَّادٍ أَهُمَا اللَّذَانِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَوْ كُنْتُ رَاجِمًا أَحَدًا بِغَيْرِ بَيِّنَةٍ لَرَجَمْتُهَا ‏"‏ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ لاَ تِلْكَ امْرَأَةٌ أَعْلَنَتْ ‏.‏ قَالَ ابْنُ أَبِي عُمَرَ فِي رِوَايَتِهِ عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ ‏.‏\hadithno{3760}\hadithtrans{Abdullah b Shaddad reported that mention was made about the invokers of curses before Ibn 'Abbas (Allah be pleased with them). Ibn Shaddad said:Are these the two about whom Allah's Apostle (ﷺ) said." If I were to stone one without evidence, I would have definitely stoned her"? Ibn Abbas (Allah be pleased with them) said: She is not this woman; but she is the one who (committed adultery) openly}}
\hadithdefcmd{muslim}{3761}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ سَعْدَ بْنَ عُبَادَةَ الأَنْصَارِيَّ، قَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ الرَّجُلَ يَجِدُ مَعَ امْرَأَتِهِ رَجُلاً أَيَقْتُلُهُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ ‏"‏ ‏.‏ قَالَ سَعْدٌ بَلَى وَالَّذِي أَكْرَمَكَ بِالْحَقِّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اسْمَعُوا إِلَى مَا يَقُولُ سَيِّدُكُمْ ‏"‏.‏\hadithno{3761}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Sa'd b. 'Ubada al-Ansari said:Messenger of Allah, tell me if a man finds his wife with another person, should he kill him? Allah's Messenger (ﷺ) said: No. Sa'd said: Why not? I swear by Him Who has honored you with the Truth. There upon Allah's Messenger (ﷺ) said: Listen to what your chief says}}
\hadithdefcmd{muslim}{3762}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنِي إِسْحَاقُ بْنُ عِيسَى، حَدَّثَنَا مَالِكٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ سَعْدَ بْنَ عُبَادَةَ، قَالَ يَا رَسُولَ اللَّهِ إِنْ وَجَدْتُ مَعَ امْرَأَتِي رَجُلاً أَأُمْهِلُهُ حَتَّى آتِيَ بِأَرْبَعَةِ شُهَدَاءَ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏\hadithno{3762}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Sa'd b. Ubada (Allah be pleased with him) said:Messenger of Allah, if I were to find with my wife a man, should I wait until I bring four witnesses? He said: Yes}}
\hadithdefcmd{muslim}{3763}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، حَدَّثَنِي سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ سَعْدُ بْنُ عُبَادَةَ يَا رَسُولَ اللَّهِ لَوْ وَجَدْتُ مَعَ أَهْلِي رَجُلاً لَمْ أَمَسَّهُ حَتَّى آتِيَ بِأَرْبَعَةِ شُهَدَاءَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ كَلاَّ وَالَّذِي بَعَثَكَ بِالْحَقِّ إِنْ كُنْتُ لأُعَاجِلُهُ بِالسَّيْفِ قَبْلَ ذَلِكَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اسْمَعُوا إِلَى مَا يَقُولُ سَيِّدُكُمْ إِنَّهُ لَغَيُورٌ وَأَنَا أَغْيَرُ مِنْهُ وَاللَّهُ أَغْيَرُ مِنِّي ‏"‏ ‏.‏\hadithno{3763}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Sa'd b. Ubada (Allah be pleased with him) said:Messenger of Allah, if I were to find with my wife a man, should I not touch him before bringing four witnesses? Allah's Messenger (ﷺ) said: Yes. He said: By no means. By Him Who has sent you with the Truth, I would hasten with my sword to him before that. Allah's Messenger (ﷺ) said: Listen to what your chief says. He is jealous of his honour, I am more jealous than he (is) and God is more jealous than I}}
\hadithdefcmd{muslim}{3764}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، وَأَبُو كَامِلٍ فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ - وَاللَّفْظُ لأَبِي كَامِلٍ - قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ وَرَّادٍ، - كَاتِبِ الْمُغِيرَةِ - عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ قَالَ سَعْدُ بْنُ عُبَادَةَ لَوْ رَأَيْتُ رَجُلاً مَعَ امْرَأَتِي لَضَرَبْتُهُ بِالسَّيْفِ غَيْرَ مُصْفِحٍ عَنْهُ ‏.‏ فَبَلَغَ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَتَعْجَبُونَ مِنْ غَيْرَةِ سَعْدٍ فَوَاللَّهِ لأَنَا أَغْيَرُ مِنْهُ وَاللَّهُ أَغْيَرُ مِنِّي مِنْ أَجْلِ غَيْرَةِ اللَّهِ حَرَّمَ الْفَوَاحِشَ مَا ظَهَرَ مِنْهَا وَمَا بَطَنَ وَلاَ شَخْصَ أَغْيَرُ مِنَ اللَّهِ وَلاَ شَخْصَ أَحَبُّ إِلَيْهِ الْعُذْرُ مِنَ اللَّهِ مِنْ أَجْلِ ذَلِكَ بَعَثَ اللَّهُ الْمُرْسَلِينَ مُبَشِّرِينَ وَمُنْذِرِينَ وَلاَ شَخْصَ أَحَبُّ إِلَيْهِ الْمِدْحَةُ مِنَ اللَّهِ مِنْ أَجْلِ ذَلِكَ وَعَدَ اللَّهُ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{3764}\hadithtrans{AI-Mughira b. Shu'ba (Allah be pleased with him) reported that Sa'd b. 'Ubada (Allah be pleased with him) said:If I were to see a man with my wife, I would have struck him with the sword, and not with the flat part (side) of it. When Allah's Messenger (ﷺ) heard of that, he said: Are you surprised at Sa'd's jealousy of his honour? By Allah, I am more jealous of my honour than he, and Allah is more jealous than I. Because of His jealousy Allah has prohibited abomination, both open and secret And no person is more jealous of his honour than Allah, and no persons, is more fond of accepting an excuse than Allah, on account of which He has sent messengers, announcers of glad tidings and warners; and no one is more fond of praise than Allah on account of which Allah has promised Paradise}}
\hadithdefcmd{muslim}{3765}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ عَبْدِ الْمَلِكِ، بْنِ عُمَيْرٍ بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏ وَقَالَ غَيْرَ مُصْفِحٍ ‏.‏ وَلَمْ يَقُلْ عَنْهُ ‏.‏\hadithno{3765}\hadithtrans{A hadith like this has been transmitted on the authority, of 'Abd al-Malik b. Umair with the same chain of narraters but with a slight change of words}}
\hadithdefcmd{muslim}{3766}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَزُهَيْرُ بْنُ حَرْبٍ - وَاللَّفْظُ لِقُتَيْبَةَ - قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ مِنْ بَنِي فَزَارَةَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنَّ امْرَأَتِي وَلَدَتْ غُلاَمًا أَسْوَدَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلْ لَكَ مِنْ إِبِلٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَمَا أَلْوَانُهَا ‏"‏ ‏.‏ قَالَ حُمْرٌ ‏.‏ قَالَ ‏"‏ هَلْ فِيهَا مِنْ أَوْرَقَ ‏"‏ ‏.‏ قَالَ إِنَّ فِيهَا لَوُرْقًا ‏.‏ قَالَ ‏"‏ فَأَنَّى أَتَاهَا ذَلِكَ ‏"‏ ‏.‏ قَالَ عَسَى أَنْ يَكُونَ نَزَعَهُ عِرْقٌ ‏.‏ قَالَ ‏"‏ وَهَذَا عَسَى أَنْ يَكُونَ نَزَعَهُ عِرْقٌ ‏"‏ ‏.‏\hadithno{3766}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:There came a person to the Prophet (may peace he upon him) ) from Banu Fazara and said: My wife has given birth to a child who is black, whereupon Allah's Apostle (ﷺ) said: Have you any camels? He said: Yes. He again said: What is this colour? He said: They are red. He said: Is there a dusky one among them? He said: Yes, there are dusky ones among them He said: How has it come about? He said: It is perhaps the strain to which it has reverted, whereupon he (the Holy Prophet) said: It is perhaps the strain to which he (the child) has reverted}}
\hadithdefcmd{muslim}{3767}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ ابْنُ رَافِعٍ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنَا ابْنُ رَافِعٍ، حَدَّثَنَا ابْنُ، أَبِي فُدَيْكٍ أَخْبَرَنَا ابْنُ أَبِي ذِئْبٍ، جَمِيعًا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ ابْنِ عُيَيْنَةَ ‏.‏ غَيْرَ أَنَّ فِي، حَدِيثِ مَعْمَرٍ فَقَالَ يَا رَسُولَ اللَّهِ وَلَدَتِ امْرَأَتِي غُلاَمًا أَسْوَدَ وَهُوَ حِينَئِذٍ يُعَرِّضُ بِأَنْ يَنْفِيَهُ ‏.‏ وَزَادَ فِي آخِرِ الْحَدِيثِ وَلَمْ يُرَخِّصْ لَهُ فِي الاِنْتِفَاءِ مِنْهُ ‏.‏\hadithno{3767}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters. In the hadith transmitted on the authority of Ma'mar, the (words are):" Messenger of Allah, my wife has given birth to a dark-complexioned boy, and he at that time was intending to disown him." And this addition has been made at the end of the hadith:" He (the Holy Prophet) did not permit him to disown him}}
\hadithdefcmd{muslim}{3768}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، - وَاللَّفْظُ لِحَرْمَلَةَ - قَالاَ أَخْبَرَنَا ابْنُ، وَهْبٍ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّصلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ امْرَأَتِي وَلَدَتْ غُلاَمًا أَسْوَدَ وَإِنِّي أَنْكَرْتُهُ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلْ لَكَ مِنْ إِبِلٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ مَا أَلْوَانُهَا ‏"‏ ‏.‏ قَالَ حُمْرٌ ‏.‏ قَالَ ‏"‏ فَهَلْ فِيهَا مِنْ أَوْرَقَ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَأَنَّى هُوَ ‏"‏ ‏.‏ قَالَ لَعَلَّهُ يَا رَسُولَ اللَّهِ يَكُونُ نَزَعَهُ عِرْقٌ لَهُ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَهَذَا لَعَلَّهُ يَكُونُ نَزَعَهُ عِرْقٌ لَهُ ‏"‏ ‏.‏\hadithno{3768}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:A desert Arab came to Allah's Messenger (ﷺ) and said: My wife has given birth to a dark-complexioned child and I have disowned him. Thereupon Allah's Apostle (ﷺ) said: Have you any camels? He said: Yes. He said: What is their colour? He said? They are red. He said: Is there anyone dusky among them? He said: Yes. Allah's Messenger (ﷺ) said: How has it come about? He said: Messenger of Allah, it is perhaps due to the strain to which it has reverted, whereupon the Prophet (ﷺ) said: It (the birth) of the black child may be due to the strain to which he (the child) might have reverted}}
\hadithdefcmd{muslim}{3769}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا حُجَيْنٌ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ بَلَغَنَا أَنَّ أَبَا هُرَيْرَةَ، كَانَ يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِنَحْوِ حَدِيثِهِمْ‏.‏\hadithno{3769}\hadithtrans{A hadith like this has been narrated on the authority of Abu Huraira (Allah be pleased with him) through another chain of transmitters}}
