% Auto-generated chapter 6 for malik
% Hadiths in this chapter: 8

\hadithdefcmd{malik}{246}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى فِي الْمَسْجِدِ ذَاتَ لَيْلَةٍ فَصَلَّى بِصَلاَتِهِ نَاسٌ ثُمَّ صَلَّى اللَّيْلَةَ الْقَابِلَةَ فَكَثُرَ النَّاسُ ثُمَّ اجْتَمَعُوا مِنَ اللَّيْلَةِ الثَّالِثَةِ أَوِ الرَّابِعَةِ فَلَمْ يَخْرُجْ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا أَصْبَحَ قَالَ ‏ "‏ قَدْ رَأَيْتُ الَّذِي صَنَعْتُمْ وَلَمْ يَمْنَعْنِي مِنَ الْخُرُوجِ إِلَيْكُمْ إِلاَّ أَنِّي خَشِيتُ أَنْ تُفْرَضَ عَلَيْكُمْ ‏"‏ ‏.‏ وَذَلِكَ فِي رَمَضَانَ ‏.‏\hadithno{246}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Urwa ibn az- Zubayr from A'isha, the wife of the Prophet, may Allah bless him and grant him peace, that the Messenger of Allah, may Allah bless him and grant him peace, prayed in the mosque one night and people prayed behind him. Then he prayed the next night and there were more people. Then they gathered on the third or fourth night and the Messenger of Allah, may Allah bless him and grant him peace, did not come out to them. In the morning, he said, "I saw what you were doing and the only thing that prevented me from coming out to you was that I feared that it would become obligatory (fard) for you." This happened in Ramadan}}
\hadithdefcmd{malik}{247}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُرَغِّبُ فِي قِيَامِ رَمَضَانَ مِنْ غَيْرِ أَنْ يَأْمُرَ بِعَزِيمَةٍ فَيَقُولُ ‏ "‏ مَنْ قَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ فَتُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالأَمْرُ عَلَى ذَلِكَ ثُمَّ كَانَ الأَمْرُ عَلَى ذَلِكَ فِي خِلاَفَةِ أَبِي بَكْرٍ وَصَدْرًا مِنْ خِلاَفَةِ عُمَرَ بْنِ الْخَطَّابِ ‏.‏\hadithno{247}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Abu Salama ibn Abd ar-Rahman ibn Awf from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, used to exhort people to watch the night in prayer in Ramadan but never ordered it definitely. He used to say, "Whoever watches the night in prayer in Ramadan with trust and expectancy, will be forgiven all his previous wrong actions." Ibn Shihab said, "The Messenger of Allah, may Allah bless him and grant him peace, died while that was still the custom, and it continued to be the custom in the caliphate of Abu Bakr and at the beginning of the caliphate of Umar ibn al-Khattab}}
\hadithdefcmd{malik}{248}{حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدٍ الْقَارِيِّ، أَنَّهُ قَالَ خَرَجْتُ مَعَ عُمَرَ بْنِ الْخَطَّابِ فِي رَمَضَانَ إِلَى الْمَسْجِدِ فَإِذَا النَّاسُ أَوْزَاعٌ مُتَفَرِّقُونَ يُصَلِّي الرَّجُلُ لِنَفْسِهِ وَيُصَلِّي الرَّجُلُ فَيُصَلِّي بِصَلاَتِهِ الرَّهْطُ فَقَالَ عُمَرُ وَاللَّهِ إِنِّي لأَرَانِي لَوْ جَمَعْتُ هَؤُلاَءِ عَلَى قَارِئٍ وَاحِدٍ لَكَانَ أَمْثَلَ ‏.‏ فَجَمَعَهُمْ عَلَى أُبَىِّ بْنِ كَعْبٍ - قَالَ - ثُمَّ خَرَجْتُ مَعَهُ لَيْلَةً أُخْرَى وَالنَّاسُ يُصَلُّونَ بِصَلاَةِ قَارِئِهِمْ فَقَالَ عُمَرُ نِعْمَتِ الْبِدْعَةُ هَذِهِ وَالَّتِي تَنَامُونَ عَنْهَا أَفْضَلُ مِنَ الَّتِي تَقُومُونَ ‏.‏ يَعْنِي آخِرَ اللَّيْلِ وَكَانَ النَّاسُ يَقُومُونَ أَوَّلَهُ ‏.‏\hadithno{248}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Ibn Shihab from Urwa ibn az-Zubayr that Abd ar-Rahman ibn Abd al-Qari said, "I went out with Umar ibn alKhattab in Ramadan to the mosque and the people there were spread out in groups. Some men were praying by themselves, whilst others were praying in small groups. Umar said, 'By Allah! It would be better in my opinion if these people gathered behind one reciter.' So he gathered them behind Ubayy ibn Kab. Then I went out with him another night and the people were praying behind their Qur'an reciter. Umar said, 'How excellent this new way is, but what you miss while you are asleep is better than what you watch in prayer.' He meant the end of the night, and people used to watch the beginning of the night in prayer}}
\hadithdefcmd{malik}{249}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ يُوسُفَ، عَنِ السَّائِبِ بْنِ يَزِيدَ، أَنَّهُ قَالَ أَمَرَ عُمَرُ بْنُ الْخَطَّابِ أُبَىَّ بْنَ كَعْبٍ وَتَمِيمًا الدَّارِيَّ أَنْ يَقُومَا، لِلنَّاسِ بِإِحْدَى عَشْرَةَ رَكْعَةً قَالَ وَقَدْ كَانَ الْقَارِئُ يَقْرَأُ بِالْمِئِينَ حَتَّى كُنَّا نَعْتَمِدُ عَلَى الْعِصِيِّ مِنْ طُولِ الْقِيَامِ وَمَا كُنَّا نَنْصَرِفُ إِلاَّ فِي فُرُوعِ الْفَجْرِ ‏.‏\hadithno{249}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Muhammad ibn Yusuf that as- Sa'ib ibn Yazid said, "Umar ibn al-Khattab ordered Ubayy ibn Kab and Tamim ad-Dari to watch the night in prayer with the people for eleven rakas.The reciterof the Qur'an would recite the Mi'in (a group of medium-sized suras) until we would be leaning on our staffs from having stood so long in prayer. And we would not leave until the approach of dawn}}
\hadithdefcmd{malik}{250}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ رُومَانَ، أَنَّهُ قَالَ كَانَ النَّاسُ يَقُومُونَ فِي زَمَانِ عُمَرَ بْنِ الْخَطَّابِ فِي رَمَضَانَ بِثَلاَثٍ وَعِشْرِينَ رَكْعَةً ‏.‏\hadithno{250}\hadithgrade{Salim al-Hilali: Mauquf Munkar}\hadithtrans{Yahya related to me from Malik that Yazid ibn Ruman said, "The people used to watch the night in prayer during Ramadan for twenty- three rakas in the time of Umar ibn al-Khattab}}
\hadithdefcmd{malik}{251}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، أَنَّهُ سَمِعَ الأَعْرَجَ، يَقُولُ مَا أَدْرَكْتُ النَّاسَ إِلاَّ وَهُمْ يَلْعَنُونَ الْكَفَرَةَ فِي رَمَضَانَ ‏.‏ قَالَ وَكَانَ الْقَارِئُ يَقْرَأُ سُورَةَ الْبَقَرَةِ فِي ثَمَانِ رَكَعَاتٍ فَإِذَا قَامَ بِهَا فِي اثْنَتَىْ عَشْرَةَ رَكْعَةً رَأَى النَّاسُ أَنَّهُ قَدْ خَفَّفَ ‏.‏\hadithno{251}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Da'ud ibn al-Husayn that he heard al-Araj say, "I never saw the people in Ramadan, but that they were cursing the disbelievers." He added, "The reciter of Qur'an used to recite surat al-Baqara in eight rakas and if he did it in twelve rakas the people would think that he had made it easy}}
\hadithdefcmd{malik}{252}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، قَالَ سَمِعْتُ أَبِي يَقُولُ، كُنَّا نَنْصَرِفُ فِي رَمَضَانَ فَنَسْتَعْجِلُ الْخَدَمَ بِالطَّعَامِ مَخَافَةَ الْفَجْرِ ‏.‏\hadithno{252}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Abdullah ibn Abi Bakr said, "I heard my father say, 'We finished praying in Ramadan and the servants hurried with the food, fearing the approach of dawn}}
\hadithdefcmd{malik}{253}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ ذَكْوَانَ أَبَا عَمْرٍو، - وَكَانَ عَبْدًا لِعَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَأَعْتَقَتْهُ عَنْ دُبُرٍ مِنْهَا - كَانَ يَقُومُ يَقْرَأُ لَهَا فِي رَمَضَانَ ‏.‏\hadithno{253}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that Dhakwan Abu Amr (a slave belonging to A'isha, the wife of the Prophet, may Allah bless him and grant him peace, who was freed by her after her death) used to stand in prayer and recite for her in Ramadan}}
