% Auto-generated chapter 84 for bukhari
% Hadiths in this chapter: 15

\hadithdefcmd{bukhari}{6708}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو شِهَابٍ، عَنِ ابْنِ عَوْنٍ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، قَالَ أَتَيْتُهُ يَعْنِي النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ ادْنُ ‏"‏‏.‏ فَدَنَوْتُ فَقَالَ ‏"‏ أَيُؤْذِيكَ هَوَامُّكَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ فِدْيَةٌ مِنْ صِيَامٍ أَوْ صَدَقَةٍ أَوْ نُسُكٍ ‏"‏‏.‏ وَأَخْبَرَنِي ابْنُ عَوْنٍ عَنْ أَيُّوبَ قَالَ صِيَامُ ثَلاَثَةِ أَيَّامٍ، وَالنُّسُكُ شَاةٌ، وَالْمَسَاكِينُ سِتَّةٌ‏.‏\hadithno{6708}\hadithtrans{Narrated Ka`b bin 'Ujra:I came to the Prophet (ﷺ) and he said to me, "Come near." So I went near to him and he said, "Are your lice troubling you?" I replied, "Yes." He said, "(Shave your head and) make expiation in the form of fasting, Sadaqa (giving in charity), or offering a sacrifice." (The sub-narrator) Aiyub said, "Fasting should be for three days, and the Nusuk (sacrifice) is to be a sheep, and the Sadaqa is to be given to six poor persons}}
\hadithdefcmd{bukhari}{6709}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، قَالَ سَمِعْتُهُ مِنْ، فِيهِ عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ هَلَكْتُ‏.‏ قَالَ ‏"‏ مَا شَأْنُكَ ‏"‏‏.‏ قَالَ وَقَعْتُ عَلَى امْرَأَتِي فِي رَمَضَانَ‏.‏ قَالَ ‏"‏ تَسْتَطِيعُ تُعْتِقُ رَقَبَةً ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ فَهَلْ تَسْتَطِيعُ أَنْ تَصُومَ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ فَهَلْ تَسْتَطِيعُ أَنْ تُطْعِمَ سِتِّينَ مِسْكِينًا ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ اجْلِسْ ‏"‏‏.‏ فَجَلَسَ فَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِعَرَقٍ فِيهِ تَمْرٌ ـ وَالْعَرَقُ الْمِكْتَلُ الضَّخْمُ ـ قَالَ ‏"‏ خُذْ هَذَا، فَتَصَدَّقْ بِهِ ‏"‏‏.‏ قَالَ أَعَلَى أَفْقَرَ مِنَّا، فَضَحِكَ النَّبِيُّ صلى الله عليه وسلم حَتَّى بَدَتْ نَوَاجِذُهُ قَالَ ‏"‏ أَطْعِمْهُ عِيَالَكَ ‏"‏‏.‏\hadithno{6709}\hadithtrans{Narrated Abu Huraira:A man came to the Prophet (ﷺ) and said, "I am ruined!" The Prophet (ﷺ) said, "What is the matter with you?" He said, "I had sexual relation with my wife (while I was fasting) in Ramadan." The Prophet (ﷺ) said, "Have you got enough to manumit a slave?" He said, "No." The Prophet (ﷺ) said, "Can you fast for two successive months?" The man said, "No." The Prophet (ﷺ) said, "Can you feed sixty poor persons?" The man said, "No." Then the Prophet (ﷺ) said to him, "Sit down," and he sat down. Afterwards an 'Irq, i.e., a big basket containing dates was brought to the Prophet (ﷺ) and the Prophet (ﷺ) said to him, "Take this and give it in charity." The man said, "To poorer people than we?" On that, the Prophet (ﷺ) smiled till his premolar teeth became visible, and then told him, "Feed your family with it." (See Hadith No. 157, Vol)}}
\hadithdefcmd{bukhari}{6710}{حَدَّثَنَا مُحَمَّدُ بْنُ مَحْبُوبٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ هَلَكْتُ‏.‏ فَقَالَ ‏"‏ وَمَا ذَاكَ ‏"‏‏.‏ قَالَ وَقَعْتُ بِأَهْلِي فِي رَمَضَانَ‏.‏ قَالَ ‏"‏ تَجِدُ رَقَبَةً ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ هَلْ تَسْتَطِيعُ أَنْ تَصُومَ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ فَتَسْتَطِيعُ أَنْ تُطْعِمَ سِتِّينَ مِسْكِينًا ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ فَجَاءَ رَجُلٌ مِنَ الأَنْصَارِ بِعَرَقٍ ـ وَالْعَرَقُ الْمِكْتَلُ فِيهِ تَمْرٌ ـ فَقَالَ ‏"‏ اذْهَبْ بِهَذَا، فَتَصَدَّقْ بِهِ ‏"‏‏.‏ قَالَ عَلَى أَحْوَجَ مِنَّا يَا رَسُولَ اللَّهِ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا بَيْنَ لاَبَتَيْهَا أَهْلُ بَيْتٍ أَحْوَجُ مِنَّا‏.‏ ثُمَّ قَالَ ‏"‏ اذْهَبْ، فَأَطْعِمْهُ أَهْلَكَ ‏"‏‏.‏\hadithno{6710}\hadithtrans{Narrated Abu Huraira:A man came to Allah's Messenger (ﷺ) and said, "I am ruined!" The Prophet (ﷺ) said to him, "What is the matter?" He said, "I have done a sexual relation with my wife (while fasting) in Ramadan." The Prophet said to him?" "Can you afford to manumit a slave?" He said, "No." The Prophet (ﷺ) said, "Can you fast for two successive months?" He said, "No." The Prophet (ﷺ) said, "Can you feed sixty poor persons?" He said, "No." Then an Ansari man came with an Irq (a big basket full of dates). The Prophet said (to the man), "Take this (basket) and give it in charity." That man said, "To poorer people than we, O Allah's Messenger (ﷺ)? By Him Who has sent you with the Truth! There is no house in between the two mountains (of the city of Medina) poorer than we." So the Prophet (ﷺ) said (to him), "Go and feed it to your family}}
\hadithdefcmd{bukhari}{6711}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ هَلَكْتُ‏.‏ قَالَ ‏"‏ وَمَا شَأْنُكَ ‏"‏‏.‏ قَالَ وَقَعْتُ عَلَى امْرَأَتِي فِي رَمَضَانَ‏.‏ قَالَ ‏"‏ هَلْ تَجِدُ مَا تُعْتِقُ رَقَبَةً ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ فَهَلْ تَسْتَطِيعُ أَنْ تَصُومَ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ فَهَلْ تَسْتَطِيعُ أَنْ تُطْعِمَ سِتِّينَ مِسْكِينًا ‏"‏‏.‏ قَالَ لاَ أَجِدُ‏.‏ فَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِعَرَقٍ فِيهِ تَمْرٌ فَقَالَ ‏"‏ خُذْ هَذَا فَتَصَدَّقْ بِهِ ‏"‏‏.‏ فَقَالَ أَعَلَى أَفْقَرَ مِنَّا مَا بَيْنَ لاَبَتَيْهَا أَفْقَرُ مِنَّا‏.‏ ثُمَّ قَالَ ‏"‏ خُذْهُ فَأَطْعِمْهُ أَهْلَكَ ‏"‏‏.‏\hadithno{6711}\hadithtrans{Narrated Abu Huraira:A man came to the Prophets and said, "I am ruined!" The Prophet (ﷺ) said, "What is the matter with you?" He said, "I have done a sexual relation with my wife (while fasting) in Ramadan" The Prophet (ﷺ) said to him, "Can you afford to manumit a slave?" He said, "No." The Prophet (ﷺ) said, "Can you fast for two successive months?" He said, "No." The Prophet (ﷺ) said, "Can you feed sixty poor persons?" He said, "I have nothing." Later on an Irq (big basket) containing dates was given to the Prophet, and the Prophet (ﷺ) said (to him), "Take this basket and give it in charity." The man said, "To poorer people than we? Indeed, there is nobody between its (i.e., Medina's) two mountains who is poorer than we." The Prophet then said, "Take it and feed your family with it}}
\hadithdefcmd{bukhari}{6712}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْقَاسِمُ بْنُ مَالِكٍ الْمُزَنِيُّ، حَدَّثَنَا الْجُعَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنِ السَّائِبِ بْنِ يَزِيدَ، قَالَ كَانَ الصَّاعُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم مُدًّا وَثُلُثًا بِمُدِّكُمُ الْيَوْمَ فَزِيدَ فِيهِ فِي زَمَنِ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ‏.‏\hadithno{6712}\hadithtrans{Narrated Al-Ju'aid bin `Abdur-Rahman:As-Sa'ib bin Yazid said, "The Sa' at the time of the Prophet (ﷺ) was equal to one Mudd plus one-third of a Mudd of your time, and then it was increased in the time of Caliph `Umar bin `Abdul `Aziz}}
\hadithdefcmd{bukhari}{6713}{حَدَّثَنَا مُنْذِرُ بْنُ الْوَلِيدِ الْجَارُودِيُّ، حَدَّثَنَا أَبُو قُتَيْبَةَ ـ وَهْوَ سَلْمٌ ـ حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، قَالَ كَانَ ابْنُ عُمَرَ يُعْطِي زَكَاةَ رَمَضَانَ بِمُدِّ النَّبِيِّ صلى الله عليه وسلم الْمُدِّ الأَوَّلِ، وَفِي كَفَّارَةِ الْيَمِينِ بِمُدِّ النَّبِيِّ صلى الله عليه وسلم‏.‏ قَالَ أَبُو قُتَيْبَةَ قَالَ لَنَا مَالِكٌ مُدُّنَا أَعْظَمُ مِنْ مُدِّكُمْ وَلاَ نَرَى الْفَضْلَ إِلاَّ فِي مُدِّ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ لِي مَالِكٌ لَوْ جَاءَكُمْ أَمِيرٌ فَضَرَبَ مُدًّا أَصْغَرَ مِنْ مُدِّ النَّبِيِّ صلى الله عليه وسلم بِأَىِّ شَىْءٍ كُنْتُمْ تُعْطُونَ قُلْتُ كُنَّا نُعْطِي بِمُدِّ النَّبِيِّ صلى الله عليه وسلم قَالَ أَفَلاَ تَرَى أَنَّ الأَمْرَ إِنَّمَا يَعُودُ إِلَى مُدِّ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6713}\hadithtrans{Narrated Nafi`:Ibn `Umar used to give the Zakat of Ramadan (Zakat-al-Fitr) according to the Mudd of the Prophet, the first Mudd, and he also used to give things for expiation for oaths according to the Mudd of the Prophet. Abu Qutaiba said, "Malik said to us, 'Our Mudd (i.e., of Medina) is better than yours and we do not see any superiority except in the Mudd of the Prophet!' Malik further said, to me, 'If a ruler came to you and fixed a Mudd smaller than the one of the Prophet, by what Mudd would you measure what you give (for expiation or Zakat-al-Fitr?' I replied, 'We would give it according to the Mudd of the Prophet' On that, Malik said, 'Then, don't you see that we have to revert to the Mudd of the Prophet ultimately?)}}
\hadithdefcmd{bukhari}{6714}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ بَارِكْ لَهُمْ فِي مِكْيَالِهِمْ وَصَاعِهِمْ وَمُدِّهِمْ ‏"‏‏.‏\hadithno{6714}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "O Allah! Bestow Your Blessings on their measures, Sa' and Mudd (i.e., of the people of Medina)}}
\hadithdefcmd{bukhari}{6715}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ أَبِي غَسَّانَ، مُحَمَّدِ بْنِ مُطَرِّفٍ عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ سَعِيدٍ ابْنِ مَرْجَانَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ رَقَبَةً مُسْلِمَةً، أَعْتَقَ اللَّهُ بِكُلِّ عُضْوٍ مِنْهُ عُضْوًا مِنَ النَّارِ، حَتَّى فَرْجَهُ بِفَرْجِهِ ‏"‏‏.‏\hadithno{6715}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If somebody manumits a Muslim slave, Allah will save from the Fire every part of his body for freeing the corresponding parts of the slave's body, even his private parts will be saved from the Fire) because of freeing the slave's private parts}}
\hadithdefcmd{bukhari}{6716}{حَدَّثَنَا أَبُو النُّعْمَانِ، أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرٍو، عَنْ جَابِرٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ دَبَّرَ مَمْلُوكًا لَهُ، وَلَمْ يَكُنْ لَهُ مَالٌ غَيْرُهُ فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ مَنْ يَشْتَرِيهِ مِنِّي ‏"‏‏.‏ فَاشْتَرَاهُ نُعَيْمُ بْنُ النَّحَّامِ بِثَمَانِمِائَةِ دِرْهَمٍ، فَسَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ يَقُولُ عَبْدًا قِبْطِيًّا مَاتَ عَامَ أَوَّلَ‏.‏\hadithno{6716}\hadithtrans{Narrated `Amr:Jabir said: An Ansari man made his slave a Mudabbar and he had no other property than him. When the Prophet (ﷺ) heard of that, he said (to his companions), "Who wants to buy him (i.e., the slave) for me?" Nu'aim bin An-Nahham bought him for eight hundred Dirhams. I heard Jabir saying, "That was a coptic slave who died in the same year}}
\hadithdefcmd{bukhari}{6717}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، أَنَّهَا أَرَادَتْ أَنْ تَشْتَرِيَ، بَرِيرَةَ فَاشْتَرَطُوا عَلَيْهَا الْوَلاَءَ، فَذَكَرَتْ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ اشْتَرِيهَا إِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏\hadithno{6717}\hadithtrans{Narrated `Aisha:that she intended to buy Barira (a slave girl) and her masters stipulated that they would have her Wala'. When `Aisha mentioned that to the Prophet (ﷺ) ; he said, "Buy her, for the Wala' is for the one who manumits}}
\hadithdefcmd{bukhari}{6718}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادٌ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي رَهْطٍ مِنَ الأَشْعَرِيِّينَ أَسْتَحْمِلُهُ فَقَالَ ‏"‏ وَاللَّهِ لاَ أَحْمِلُكُمْ، مَا عِنْدِي مَا أَحْمِلُكُمْ ‏"‏‏.‏ ثُمَّ لَبِثْنَا مَا شَاءَ اللَّهُ، فَأُتِيَ بِإِبِلٍ فَأَمَرَ لَنَا بِثَلاَثَةِ ذَوْدٍ، فَلَمَّا انْطَلَقْنَا قَالَ بَعْضُنَا لِبَعْضٍ لاَ يُبَارِكُ اللَّهُ لَنَا، أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم نَسْتَحْمِلُهُ فَحَلَفَ أَنْ لاَ يَحْمِلَنَا فَحَمَلَنَا‏.‏ فَقَالَ أَبُو مُوسَى فَأَتَيْنَا النَّبِيَّ صلى الله عليه وسلم فَذَكَرْنَا ذَلِكَ لَهُ فَقَالَ ‏"‏ مَا أَنَا حَمَلْتُكُمْ بَلِ اللَّهُ حَمَلَكُمْ، إِنِّي وَاللَّهِ إِنْ شَاءَ اللَّهُ لاَ أَحْلِفُ عَلَى يَمِينٍ فَأَرَى غَيْرَهَا خَيْرًا مِنْهَا، إِلاَّ كَفَّرْتُ عَنْ يَمِينِي، وَأَتَيْتُ الَّذِي هُوَ خَيْرٌ وَكَفَّرْتُ ‏"‏‏.‏\hadithno{6718}\hadithtrans{Narrated Abu Musa Al-Ash`ari:I went to Allah's Messenger (ﷺ) along with a group of people from (the tribe of) Al-Ash`ari, asking for mounts. The Prophet (ﷺ) said, "By Allah, I will not give you anything to ride, and I have nothing to mount you on." We stayed there as long as Allah wished, and after that, some camels were brought to the Prophet and he ordered that we be given three camels. When we set out, some of us said to others, "Allah will not bless us, as we all went to Allah's Messenger (ﷺ) asking him for mounts, and although he had sworn that he would not give us mounts, he did give us." So we returned to the Prophet; and mentioned that to him. He said, "I have not provided you with mounts, but Allah has. By Allah, Allah willing, if I ever take an oath, and then see that another is better than the first, I make expiation for my (dissolved) oath, and do what is better and make expiation}}
\hadithdefcmd{bukhari}{6719}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادٌ، وَقَالَ، ‏"‏ إِلاَّ كَفَّرْتُ يَمِينِي، وَأَتَيْتُ الَّذِي هُوَ خَيْرٌ ‏"‏‏.‏ أَوْ ‏"‏ أَتَيْتُ الَّذِي هُوَ خَيْرٌ، وَكَفَّرْتُ ‏"‏‏.‏\hadithno{6719}\hadithtrans{Narrated Hammad:the same narration above (i.e. 709), "I make expiation for my dissolved oath, and I do what is better, or do what is better and make expiation}}
\hadithdefcmd{bukhari}{6720}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ حُجَيْرٍ، عَنْ طَاوُسٍ، سَمِعَ أَبَا هُرَيْرَةَ، قَالَ قَالَ سُلَيْمَانُ لأَطُوفَنَّ اللَّيْلَةَ عَلَى تِسْعِينَ امْرَأَةً، كُلٌّ تَلِدُ غُلاَمًا يُقَاتِلُ فِي سَبِيلِ اللَّهِ‏.‏ فَقَالَ لَهُ صَاحِبُهُ ـ قَالَ سُفْيَانُ يَعْنِي الْمَلَكَ ـ قُلْ إِنْ شَاءَ اللَّهُ‏.‏ فَنَسِيَ، فَطَافَ بِهِنَّ، فَلَمْ تَأْتِ امْرَأَةٌ مِنْهُنَّ بِوَلَدٍ، إِلاَّ وَاحِدَةٌ بِشِقِّ غُلاَمٍ‏.‏ فَقَالَ أَبُو هُرَيْرَةَ يَرْوِيهِ قَالَ ‏"‏ لَوْ قَالَ إِنْ شَاءَ اللَّهُ، لَمْ يَحْنَثْ وَكَانَ دَرَكًا فِي حَاجَتِهِ ‏"‏‏.‏ وَقَالَ مَرَّةً قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوِ اسْتَثْنَى ‏"‏‏.‏ وَحَدَّثَنَا أَبُو الزِّنَادِ عَنِ الأَعْرَجِ مِثْلَ حَدِيثِ أَبِي هُرَيْرَةَ‏.‏\hadithno{6720}\hadithtrans{Narrated Abu Huraira:(The Prophet) Solomon said, "Tonight I will sleep with (my) ninety wives, each of whom will get a male child who will fight for Allah's Cause." On that, his companion (Sufyan said that his companion was an angel) said to him, "Say, "If Allah will (Allah willing)." But Solomon forgot (to say it). He slept with all his wives, but none of the women gave birth to a child, except one who gave birth to a halfboy. Abu Huraira added: The Prophet (ﷺ) said, "If Solomon had said, "If Allah will" (Allah willing), he would not have been unsuccessful in his action, and would have attained what he had desired." Once Abu Huraira added: Allah's Apostle said, "If he had accepted}}
\hadithdefcmd{bukhari}{6721}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنِ الْقَاسِمِ التَّمِيمِيِّ، عَنْ زَهْدَمٍ الْجَرْمِيِّ، قَالَ كُنَّا عِنْدَ أَبِي مُوسَى وَكَانَ بَيْنَنَا وَبَيْنَ هَذَا الْحَىِّ مِنْ جَرْمٍ إِخَاءٌ وَمَعْرُوفٌ ـ قَالَ ـ فَقُدِّمَ طَعَامٌ ـ قَالَ ـ وَقُدِّمَ فِي طَعَامِهِ لَحْمُ دَجَاجٍ ـ قَالَ ـ وَفِي الْقَوْمِ رَجُلٌ مِنْ بَنِي تَيْمِ اللَّهِ أَحْمَرُ كَأَنَّهُ مَوْلًى ـ قَالَ ـ فَلَمْ يَدْنُ فَقَالَ لَهُ أَبُو مُوسَى ادْنُ، فَإِنِّي قَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْكُلُ مِنْهُ‏.‏ قَالَ إِنِّي رَأَيْتُهُ يَأْكُلُ شَيْئًا قَذِرْتُهُ، فَحَلَفْتُ أَنْ لاَ أَطْعَمَهُ أَبَدًا‏.‏ فَقَالَ ادْنُ أُخْبِرْكَ عَنْ ذَلِكَ، أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فِي رَهْطٍ مِنَ الأَشْعَرِيِّينَ أَسْتَحْمِلُهُ، وَهْوَ يُقْسِمُ نَعَمًا مِنْ نَعَمِ الصَّدَقَةِ ـ قَالَ أَيُّوبُ أَحْسِبُهُ قَالَ وَهْوَ غَضْبَانُ ـ قَالَ ‏"‏ وَاللَّهِ لاَ أَحْمِلُكُمْ، وَمَا عِنْدِي مَا أَحْمِلُكُمْ ‏"‏‏.‏ قَالَ فَانْطَلَقْنَا فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِنَهْبِ إِبِلٍ، فَقِيلَ أَيْنَ هَؤُلاَءِ الأَشْعَرِيُّونَ فَأَتَيْنَا فَأَمَرَ لَنَا بِخَمْسِ ذَوْدٍ غُرِّ الذُّرَى، قَالَ فَانْدَفَعْنَا فَقُلْتُ لأَصْحَابِي أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم نَسْتَحْمِلُهُ، فَحَلَفَ أَنْ لاَ يَحْمِلَنَا، ثُمَّ أَرْسَلَ إِلَيْنَا فَحَمَلَنَا، نَسِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمِينَهُ، وَاللَّهِ لَئِنْ تَغَفَّلْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم يَمِينَهُ لاَ نُفْلِحُ أَبَدًا، ارْجِعُوا بِنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَلْنُذَكِّرْهُ يَمِينَهُ‏.‏ فَرَجَعْنَا فَقُلْنَا يَا رَسُولَ اللَّهِ أَتَيْنَاكَ نَسْتَحْمِلُكَ، فَحَلَفْتَ أَنْ لاَ تَحْمِلَنَا ثُمَّ حَمَلْتَنَا فَظَنَنَّا ـ أَوْ فَعَرَفْنَا ـ أَنَّكَ نَسِيتَ يَمِينَكَ‏.‏ قَالَ ‏"‏ انْطَلِقُوا، فَإِنَّمَا حَمَلَكُمُ اللَّهُ، إِنِّي وَاللَّهِ إِنْ شَاءَ اللَّهُ لاَ أَحْلِفُ عَلَى يَمِينٍ، فَأَرَى غَيْرَهَا خَيْرًا مِنْهَا، إِلاَّ أَتَيْتُ الَّذِي هُوَ خَيْرٌ وَتَحَلَّلْتُهَا ‏"‏‏.‏ تَابَعَهُ حَمَّادُ بْنُ زَيْدٍ عَنْ أَيُّوبَ عَنْ أَبِي قِلاَبَةَ وَالْقَاسِمِ بْنِ عَاصِمٍ الْكُلَيْبِيِّ‏.‏ حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، وَالْقَاسِمِ التَّمِيمِيِّ عَنْ زَهْدَمٍ، بِهَذَا‏.‏ حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، عَنِ الْقَاسِمِ، عَنْ زَهْدَمٍ، بِهَذَا‏.‏\hadithno{6721}\hadithtrans{Narrated Zahdam al-Jarmi:We were sitting with Abu Musa Al-Ash'sari, and as there were ties of friendship and mutual favors between us and his tribe. His meal was presented before him and there was chicken meat in it. Among those who were present there was a man from Bani Taimillah having a red complexion as a non-Arab freed slave, and that man did not approach the meal. Abu Musa said to him, "Come along! I have seen Allah's Messenger (ﷺ) eating of that (i.e., chicken)." The man said, "I have seen it (chickens) eating something I regarded as dirty, and so I have taken an oath that I shall not eat (its meat) chicken." Abu Musa said, "Come along! I will inform you about it (i.e., your oath). Once we went to Allah's Messenger (ﷺ) in company with a group of Ash'airiyin, asking him for mounts while he was distributing some camels from the camels of Zakat. (Aiyub said, "I think he said that the Prophet was in an angry mood at the time.") The Prophet (ﷺ) said, 'By Allah! I will not give you mounts, and I have nothing to mount you on.' After we had left, some camels of booty were brought to Allah's Apostle and he said, "Where are those Ash`ariyin? Where are those Ash`ariyin?" So we went (to him) and he gave us five very fat good-looking camels. We mounted them and went away, and then I said to my companions, 'We went to Allah's Messenger (ﷺ) to give us mounts, but he took an oath that he would not give us mounts, and then later on he sent for us and gave us mounts, perhaps Allah's Messenger (ﷺ) forgot his oath. By Allah, we will never be successful, for we have taken advantage of the fact that Allah's Messenger (ﷺ) forgot to fulfill his oath. So let us return to Allah's Messenger (ﷺ) to remind him of his oath.' We returned and said, 'O Allah's Messenger (ﷺ)! We came to you and asked you for mounts, but you took an oath that you would not give us mounts) but later on you gave us mounts, and we thought or considered that you have forgotten your oath.' The Prophet (ﷺ) said, 'Depart, for Allah has given you Mounts. By Allah, Allah willing, if I take an oath and then later find another thing better than that, I do what is better, and make expiation for the oath.' " (two other narrations through Zahdam as above)}}
\hadithdefcmd{bukhari}{6722}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ بْنِ فَارِسٍ، أَخْبَرَنَا ابْنُ عَوْنٍ، عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَسْأَلِ الإِمَارَةَ، فَإِنَّكَ إِنْ أُعْطِيتَهَا عَنْ غَيْرِ مَسْأَلَةٍ أُعِنْتَ عَلَيْهَا، وَإِنْ أُعْطِيتَهَا عَنْ مَسْأَلَةٍ وُكِلْتَ إِلَيْهَا، وَإِذَا حَلَفْتَ عَلَى يَمِينٍ فَرَأَيْتَ غَيْرَهَا خَيْرًا مِنْهَا، فَأْتِ الَّذِي هُوَ خَيْرٌ، وَكَفِّرْ عَنْ يَمِينِكَ ‏"‏‏.‏ تَابَعَهُ أَشْهَلُ عَنِ ابْنِ عَوْنٍ‏.‏ وَتَابَعَهُ يُونُسُ وَسِمَاكُ بْنُ عَطِيَّةَ وَسِمَاكُ بْنُ حَرْبٍ وَحُمَيْدٌ وَقَتَادَةُ وَمَنْصُورٌ وَهِشَامٌ وَالرَّبِيعُ‏.‏\hadithno{6722}\hadithtrans{Narrated `Abdur-Rahman bin Samura:Allah's Messenger (ﷺ) said, "(O `Abdur-Rahman!) Do not seek to be a ruler, for, if you are given the authority of ruling without your asking for it, then Allah will help you; but if you are given it by your asking, then you will be held responsible for it (i.e. Allah will not help you ) . And if you take an oath to do something and later on find another thing, better than that, then do what is better and make expiation for (the dissolution of) your oath}}
