% Auto-generated chapter 44 for malik
% Hadiths in this chapter: 2

\hadithdefcmd{malik}{1596}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي لَيْلَى بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ سَهْلٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، أَنَّهُ أَخْبَرَهُ رِجَالٌ، مِنْ كُبَرَاءِ قَوْمِهِ أَنَّ عَبْدَ، اللَّهِ بْنَ سَهْلٍ وَمُحَيِّصَةَ خَرَجَا إِلَى خَيْبَرَ مِنْ جَهْدٍ أَصَابَهُمْ فَأُتِيَ مُحَيِّصَةُ فَأُخْبِرَ أَنَّ عَبْدَ اللَّهِ بْنَ سَهْلٍ قَدْ قُتِلَ وَطُرِحَ فِي فَقِيرِ بِئْرٍ أَوْ عَيْنٍ فَأَتَى يَهُودَ فَقَالَ أَنْتُمْ وَاللَّهِ قَتَلْتُمُوهُ ‏.‏ فَقَالُوا وَاللَّهِ مَا قَتَلْنَاهُ ‏.‏ فَأَقْبَلَ حَتَّى قَدِمَ عَلَى قَوْمِهِ فَذَكَرَ لَهُمْ ذَلِكَ ثُمَّ أَقْبَلَ هُوَ وَأَخُوهُ حُوَيِّصَةُ وَهُوَ أَكْبَرُ مِنْهُ وَعَبْدُ الرَّحْمَنِ فَذَهَبَ مُحَيِّصَةُ لِيَتَكَلَّمَ وَهُوَ الَّذِي كَانَ بِخَيْبَرَ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَبِّرْ كَبِّرْ ‏"‏ يُرِيدُ السِّنَّ فَتَكَلَّمَ حُوَيِّصَةُ ثُمَّ تَكَلَّمَ مُحَيِّصَةُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِمَّا أَنْ يَدُوا صَاحِبَكُمْ وَإِمَّا أَنْ يُؤْذِنُوا بِحَرْبٍ ‏"‏ ‏.‏ فَكَتَبَ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ذَلِكَ فَكَتَبُوا إِنَّا وَاللَّهِ مَا قَتَلْنَاهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِحُوَيِّصَةَ وَمُحَيِّصَةَ وَعَبْدِ الرَّحْمَنِ ‏"‏ أَتَحْلِفُونَ وَتَسْتَحِقُّونَ دَمَ صَاحِبِكُمْ ‏"‏ ‏.‏ فَقَالُوا لاَ ‏.‏ قَالَ ‏"‏ أَفَتَحْلِفُ لَكُمْ يَهُودُ ‏"‏ قَالُوا لَيْسُوا بِمُسْلِمِينَ ‏.‏ فَوَدَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ عِنْدِهِ فَبَعَثَ إِلَيْهِمْ بِمِائَةِ نَاقَةٍ حَتَّى أُدْخِلَتْ عَلَيْهِمُ الدَّارَ ‏.‏ قَالَ سَهْلٌ لَقَدْ رَكَضَتْنِي مِنْهَا نَاقَةٌ حَمْرَاءُ ‏.‏\hadithno{1596}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu Layla ibn Abdullah ibn Abd ar-Rahman ibn Sahl from Sahl ibn Abi Hathma that some of the great men of his people informed him that Abdullah ibn Sahl and Muhayyisa went out to Khaybar because extreme poverty had overtaken them. Muhayyisa returned and said that Abdullah ibn Sahl had been killed and thrown in a shallow well or spring. The jews came and he said, "By Allah! You have killed him." They said, "By Allah! We have not killed him!" Then he made for his people and mentioned that to them. Then he, his brother Huwayyisa, who was older than him, and Abd ar-Rahman, set out. Muhayyisa began to speak, as he had been at Khaybar. The Messenger of Allah, may Allah bless him and grant him peace, said to him, "The greater first, the greater first," meaning in age. So Huwayyisa spoke and then Muhayyisa spoke. The Messenger of Allah, may Allah bless him and grant him peace, said, "Either they pay your companion's blood-money or we will declare war against them." The Messenger of Allah, may Allah bless him and grant him peace, wrote that to them and they wrote, "By Allah, we did not kill him!" The Messenger of Allah, may Allah bless him and grant him peace, said to Huwayyisa, Muhayyisa, and Abd ar-Rahman, "Do you swear and claim the blood of your companion?" They said, "No." He said, "Shall the jews swear to you?" They said, "But they are not muslims." The Messenger of Allah, may Allah bless him and grant him peace, gave blood-money from his own property, and sent them one hundred camels to their house. Sahl added, "A red camel among them kicked me}}
\hadithdefcmd{malik}{1597}{\hadithno{1597}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{}}
