% Auto-generated chapter 36 for bukhari
% Hadiths in this chapter: 3

\hadithdefcmd{bukhari}{2257}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالشُّفْعَةِ فِي كُلِّ مَا لَمْ يُقْسَمْ، فَإِذَا وَقَعَتِ الْحُدُودُ وَصُرِّفَتِ الطُّرُقُ فَلاَ شُفْعَةَ‏.‏\hadithno{2257}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) gave a verdict regarding Shuf'a in every undivided joint thing (property). But if the limits are defined (or demarcated) or the ways and streets are fixed, then there is no pre-emption}}
\hadithdefcmd{bukhari}{2258}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي إِبْرَاهِيمُ بْنُ مَيْسَرَةَ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، قَالَ وَقَفْتُ عَلَى سَعْدِ بْنِ أَبِي وَقَّاصٍ، فَجَاءَ الْمِسْوَرُ بْنُ مَخْرَمَةَ فَوَضَعَ يَدَهُ عَلَى إِحْدَى مَنْكِبَىَّ إِذْ جَاءَ أَبُو رَافِعٍ مَوْلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا سَعْدُ ابْتَعْ مِنِّي بَيْتَىَّ فِي دَارِكَ‏.‏ فَقَالَ سَعْدٌ وَاللَّهِ مَا أَبْتَاعُهُمَا‏.‏ فَقَالَ الْمِسْوَرُ وَاللَّهِ لَتَبْتَاعَنَّهُمَا‏.‏ فَقَالَ سَعْدٌ وَاللَّهِ لاَ أَزِيدُكَ عَلَى أَرْبَعَةِ آلاَفٍ، مُنَجَّمَةٍ أَوْ مُقَطَّعَةٍ‏.‏ قَالَ أَبُو رَافِعٍ لَقَدْ أُعْطِيتُ بِهَا خَمْسَمِائَةِ دِينَارٍ، وَلَوْلاَ أَنِّي سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْجَارُ أَحَقُّ بِسَقَبِهِ ‏"‏‏.‏ مَا أَعْطَيْتُكَهَا بِأَرْبَعَةِ آلاَفٍ، وَأَنَا أُعْطَى بِهَا خَمْسَمِائَةِ دِينَارٍ‏.‏ فَأَعْطَاهَا إِيَّاهُ‏.‏\hadithno{2258}\hadithtrans{Narrated `Amr bin Ash-Sharid:While I was standing with Sa`d bin Abi Waqqas, Al-Miswar bin Makhrama came and put his hand on my shoulder. Meanwhile Abu Rafi`, the freed slave of the Prophet (ﷺ) came and asked Sa`d to buy from him the (two) dwellings which were in his house. Sa`d said, "By Allah I will not buy them." Al- Miswar said, "By Allah, you shall buy them." Sa`d replied, "By Allah, I will not pay more than four thousand (Dirhams) by installments." Abu Rafi` said, "I have been offered five hundred Dinars (for it) and had I not heard the Prophet (ﷺ) saying, 'The neighbor has more right than anyone else because of his nearness, I would not give them to you for four-thousand (Dirhams) while I am offered five-hundred Dinars (one Dinar equals ten Dirhams) for them." So, he sold it to Sa`d}}
\hadithdefcmd{bukhari}{2259}{حَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنِي عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا أَبُو عِمْرَانَ، قَالَ سَمِعْتُ طَلْحَةَ بْنَ عَبْدِ اللَّهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قُلْتُ يَا رَسُولَ اللَّهِ، إِنَّ لِي جَارَيْنِ، فَإِلَى أَيِّهِمَا أُهْدِي قَالَ ‏ "‏ إِلَى أَقْرَبِهِمَا مِنْكِ بَابًا ‏"‏‏.‏\hadithno{2259}\hadithtrans{Narrated Aisha:I said, "O Allah's Messenger (ﷺ)! I have two neighbors and would like to know to which of them I should give presents." He replied, "To the one whose door is nearer to you}}
