% Auto-generated chapter 19 for bukhari
% Hadiths in this chapter: 63

\hadithdefcmd{bukhari}{1120}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ أَبِي مُسْلِمٍ، عَنْ طَاوُسٍ، سَمِعَ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا قَامَ مِنَ اللَّيْلِ يَتَهَجَّدُ قَالَ ‏"‏ اللَّهُمَّ لَكَ الْحَمْدُ أَنْتَ قَيِّمُ السَّمَوَاتِ وَالأَرْضِ وَمَنْ فِيهِنَّ وَلَكَ الْحَمْدُ، لَكَ مُلْكُ السَّمَوَاتِ وَالأَرْضِ وَمَنْ فِيهِنَّ، وَلَكَ الْحَمْدُ أَنْتَ نُورُ السَّمَوَاتِ وَالأَرْضِ، وَلَكَ الْحَمْدُ أَنْتَ الْحَقُّ، وَوَعْدُكَ الْحَقُّ، وَلِقَاؤُكَ حَقٌّ، وَقَوْلُكَ حَقٌّ، وَالْجَنَّةُ حَقٌّ، وَالنَّارُ حَقٌّ، وَالنَّبِيُّونَ حَقٌّ، وَمُحَمَّدٌ صلى الله عليه وسلم حَقٌّ، وَالسَّاعَةُ حَقٌّ، اللَّهُمَّ لَكَ أَسْلَمْتُ، وَبِكَ آمَنْتُ وَعَلَيْكَ تَوَكَّلْتُ، وَإِلَيْكَ أَنَبْتُ، وَبِكَ خَاصَمْتُ، وَإِلَيْكَ حَاكَمْتُ، فَاغْفِرْ لِي مَا قَدَّمْتُ وَمَا أَخَّرْتُ، وَمَا أَسْرَرْتُ وَمَا أَعْلَنْتُ، أَنْتَ الْمُقَدِّمُ وَأَنْتَ الْمُؤَخِّرُ، لاَ إِلَهَ إِلاَّ أَنْتَ ـ أَوْ لاَ إِلَهَ غَيْرُكَ ـ ‏"‏‏.‏ قَالَ سُفْيَانُ وَزَادَ عَبْدُ الْكَرِيمِ أَبُو أُمَيَّةَ ‏"‏ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏"‏‏.‏ قَالَ سُفْيَانُ قَالَ سُلَيْمَانُ بْنُ أَبِي مُسْلِمٍ سَمِعَهُ مِنْ طَاوُسٍ عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1120}\hadithtrans{Narrated Ibn `Abbas:When the Prophet (ﷺ) got up at night to offer the Tahajjud prayer, he used to say: Allahumma lakal-hamd. Anta qaiyyimus-samawati wal-ard wa man fihinna. Walakal-hamd, Laka mulkus-samawati wal-ard wa man fihinna. Walakal-hamd, anta nurus-samawati wal-ard. Wa lakal-hamd, anta-l-haq wa wa'duka-lhaq, wa liqa'uka Haq, wa qauluka Haq, wal-jannatu Han wan-naru Haq wannabiyuna Haq. Wa Muhammadun, sallal-lahu'alaihi wasallam, Haq, was-sa'atu Haq. Allahumma aslamtu Laka wabika amantu, wa 'Alaika tawakkaltu, wa ilaika anabtu wa bika khasamtu, wa ilaika hakamtu faghfir li ma qaddamtu wama akh-khartu wama as-rartu wama'a lantu, anta-l-muqaddim wa anta-l-mu akh-khir, la ilaha illa anta (or la ilaha ghairuka). (O Allah! All the praises are for you, You are the Holder of the Heavens and the Earth, And whatever is in them. All the praises are for You; You have the possession of the Heavens and the Earth And whatever is in them. All the praises are for You; You are the Light of the Heavens and the Earth And all the praises are for You; You are the King of the Heavens and the Earth; And all the praises are for You; You are the Truth and Your Promise is the truth, And to meet You is true, Your Word is the truth And Paradise is true And Hell is true And all the Prophets (Peace be upon them) are true; And Muhammad is true, And the Day of Resurrection is true. O Allah ! I surrender (my will) to You; I believe in You and depend on You. And repent to You, And with Your help I argue (with my opponents, the non-believers) And I take You as a judge (to judge between us). Please forgive me my previous And future sins; And whatever I concealed or revealed And You are the One who make (some people) forward And (some) backward. There is none to be worshipped but you . Sufyan said that `Abdul Karim Abu Umaiya added to the above, 'Wala haula Wala quwata illa billah' (There is neither might nor power except with Allah)}}
\hadithdefcmd{bukhari}{1122}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ أَخْبَرَنَا مَعْمَرٌ،‏.‏ وَحَدَّثَنِي مَحْمُودٌ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ كَانَ الرَّجُلُ فِي حَيَاةِ النَّبِيِّ صلى الله عليه وسلم إِذَا رَأَى رُؤْيَا قَصَّهَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَتَمَنَّيْتُ أَنْ أَرَى رُؤْيَا فَأَقُصَّهَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَكُنْتُ غُلاَمًا شَابًّا، وَكُنْتُ أَنَامُ فِي الْمَسْجِدِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَأَيْتُ فِي النَّوْمِ كَأَنَّ مَلَكَيْنِ أَخَذَانِي فَذَهَبَا بِي إِلَى النَّارِ فَإِذَا هِيَ مَطْوِيَّةٌ كَطَىِّ الْبِئْرِ، وَإِذَا لَهَا قَرْنَانِ، وَإِذَا فِيهَا أُنَاسٌ قَدْ عَرَفْتُهُمْ فَجَعَلْتُ أَقُولُ أَعُوذُ بِاللَّهِ مِنَ النَّارِ ـ قَالَ ـ فَلَقِيَنَا مَلَكٌ آخَرُ فَقَالَ لِي لَمْ تُرَعْ‏.‏ فَقَصَصْتُهَا عَلَى حَفْصَةَ فَقَصَّتْهَا حَفْصَةُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ نِعْمَ الرَّجُلُ عَبْدُ اللَّهِ، لَوْ كَانَ يُصَلِّي مِنَ اللَّيْلِ ‏"‏‏.‏ فَكَانَ بَعْدُ لاَ يَنَامُ مِنَ اللَّيْلِ إِلاَّ قَلِيلاً‏.‏\hadithno{1122}\hadithtrans{Narrated Salim's father:In the lifetime of the Prophet (ﷺ) whosoever saw a dream would narrate it to Allah's Messenger (ﷺ). I had a wish of seeing a dream to narrate it to Allah's Messenger (ﷺ) I was a grown up boy and used to sleep in the Mosque in the lifetime of the Prophet. I saw in the dream that two angels caught hold of me and took me to the Fire which was built all round like a built well and had two poles in it and the people in it were known to me. I started saying, "I seek refuge with Allah from the Fire." Then I met another angel who told me not to be afraid. I narrated the dream to Hafsa who told it to Allah's Messenger (ﷺ). The Prophet said, "Abdullah is a good man. I wish he prayed Tahajjud." After that `Abdullah (i.e. Salim's father) used to sleep but a little at night}}
\hadithdefcmd{bukhari}{1123}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُرْوَةُ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي إِحْدَى عَشْرَةَ رَكْعَةً، كَانَتْ تِلْكَ صَلاَتَهُ، يَسْجُدُ السَّجْدَةَ مِنْ ذَلِكَ قَدْرَ مَا يَقْرَأُ أَحَدُكُمْ خَمْسِينَ آيَةً قَبْلَ أَنْ يَرْفَعَ رَأْسَهُ، وَيَرْكَعُ رَكْعَتَيْنِ قَبْلَ صَلاَةِ الْفَجْرِ، ثُمَّ يَضْطَجِعُ عَلَى شِقِّهِ الأَيْمَنِ حَتَّى يَأْتِيَهُ الْمُنَادِي لِلصَّلاَةِ‏.‏\hadithno{1123}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to offer eleven rak`at and that was his prayer. He used to prolong the prostration to such an extent that one could recite fifty verses (of the Qur'an) before he would lift his head. He used to pray two rak`at (Sunna) before the Fajr prayer and then used to lie down on his right side till the call-maker came and informed him about the prayer}}
\hadithdefcmd{bukhari}{1124}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَسْوَدِ، قَالَ سَمِعْتُ جُنْدَبًا، يَقُولُ اشْتَكَى النَّبِيُّ صلى الله عليه وسلم فَلَمْ يَقُمْ لَيْلَةً أَوْ لَيْلَتَيْنِ‏.‏\hadithno{1124}\hadithtrans{Narrated Jundab:The Prophet (ﷺ) became sick and did not get up (for Tahajjud prayer) for a night or two}}
\hadithdefcmd{bukhari}{1125}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، قَالَ أَخْبَرَنَا سُفْيَانُ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ جُنْدَبِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ احْتَبَسَ جِبْرِيلُ صلى الله عليه وسلم عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتِ امْرَأَةٌ مِنْ قُرَيْشٍ أَبْطَأَ عَلَيْهِ شَيْطَانُهُ‏.‏ فَنَزَلَتْ ‏\{‏وَالضُّحَى * وَاللَّيْلِ إِذَا سَجَى * مَا وَدَّعَكَ رَبُّكَ وَمَا قَلَى‏\}‏\hadithno{1125}\hadithtrans{Narrated Jundab bin `Abdullah:Gabriel did not come to the Prophet (for some time) and so one of the Quraish women said, "His Satan has deserted him." So came the Divine Revelation: "By the forenoon And by the night When it is still! Your Lord (O Muhammad) has neither Forsaken you Nor hated you}}
\hadithdefcmd{bukhari}{1126}{حَدَّثَنَا ابْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ هِنْدٍ بِنْتِ الْحَارِثِ، عَنْ أُمِّ سَلَمَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم اسْتَيْقَظَ لَيْلَةً فَقَالَ ‏ "‏ سُبْحَانَ اللَّهِ مَاذَا أُنْزِلَ اللَّيْلَةَ مِنَ الْفِتْنَةِ، مَاذَا أُنْزِلَ مِنَ الْخَزَائِنِ مَنْ يُوقِظُ صَوَاحِبَ الْحُجُرَاتِ، يَا رُبَّ كَاسِيَةٍ فِي الدُّنْيَا عَارِيَةٍ فِي الآخِرَةِ ‏"‏‏.‏\hadithno{1126}\hadithtrans{Narrated Um Salama:One night the Prophet (ﷺ) got up and said, "Subhan Allah! How many afflictions Allah has revealed tonight and how many treasures have been sent down (disclosed). Go and wake the sleeping lady occupants of these dwellings up (for prayers), perhaps a well dressed in this world may be naked in the Hereafter}}
\hadithdefcmd{bukhari}{1127}{\{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عَلِيُّ بْنُ حُسَيْنٍ، أَنَّ حُسَيْنَ بْنَ عَلِيٍّ، أَخْبَرَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَرَقَهُ وَفَاطِمَةَ بِنْتَ النَّبِيِّ ـ عَلَيْهِ السَّلاَمُ ـ لَيْلَةً فَقَالَ ‏"‏ أَلاَ تُصَلِّيَانِ ‏"‏‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ، أَنْفُسُنَا بِيَدِ اللَّهِ، فَإِذَا شَاءَ أَنْ يَبْعَثَنَا بَعَثَنَا‏.‏ فَانْصَرَفَ حِينَ قُلْنَا ذَلِكَ وَلَمْ يَرْجِعْ إِلَىَّ شَيْئًا‏.‏ ثُمَّ سَمِعْتُهُ وَهْوَ مُوَلٍّ يَضْرِبُ فَخِذَهُ وَهْوَ يَقُولُ ‏"‏وَكَانَ الإِنْسَانُ أَكْثَرَ شَىْءٍ جَدَلاً‏\}‏‏"‏‏.‏\hadithno{1127}\hadithtrans{Narrated `Ali bin Abi Talib:One night Allah's Messenger (ﷺ) came to me and Fatima, the daughter of the Prophet (ﷺ) and asked, "Won't you pray (at night)?" I said, "O Allah's Messenger (ﷺ)! Our souls are in the hands of Allah and if He wants us to get up He will make us get up." When I said that, he left us without saying anything and I heard that he was hitting his thigh and saying, "But man is more quarrelsome than anything}}
\hadithdefcmd{bukhari}{1128}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيَدَعُ الْعَمَلَ وَهْوَ يُحِبُّ أَنْ يَعْمَلَ بِهِ خَشْيَةَ أَنْ يَعْمَلَ بِهِ النَّاسُ فَيُفْرَضَ عَلَيْهِمْ، وَمَا سَبَّحَ رَسُولُ اللَّهِ صلى الله عليه وسلم سُبْحَةَ الضُّحَى قَطُّ، وَإِنِّي لأُسَبِّحُهَا‏.‏\hadithno{1128}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to give up a good deed, although he loved to do it, for fear that people might act on it and it might be made compulsory for them. The Prophet (ﷺ) never prayed the Duha prayer, but I offer it}}
\hadithdefcmd{bukhari}{1129}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ ـ رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى ذَاتَ لَيْلَةٍ فِي الْمَسْجِدِ فَصَلَّى بِصَلاَتِهِ نَاسٌ، ثُمَّ صَلَّى مِنَ الْقَابِلَةِ فَكَثُرَ النَّاسُ، ثُمَّ اجْتَمَعُوا مِنَ اللَّيْلَةِ الثَّالِثَةِ أَوِ الرَّابِعَةِ، فَلَمْ يَخْرُجْ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم، فَلَمَّا أَصْبَحَ قَالَ ‏ "‏ قَدْ رَأَيْتُ الَّذِي صَنَعْتُمْ وَلَمْ يَمْنَعْنِي مِنَ الْخُرُوجِ إِلَيْكُمْ إِلاَّ أَنِّي خَشِيتُ أَنْ تُفْرَضَ عَلَيْكُمْ ‏"‏، وَذَلِكَ فِي رَمَضَانَ‏.‏\hadithno{1129}\hadithtrans{Narrated `Aisha the mother of the faithful believers:One night Allah's Messenger (ﷺ) offered the prayer in the Mosque and the people followed him. The next night he also offered the prayer and too many people gathered. On the third and the fourth nights more people gathered, but Allah's Messenger (ﷺ) did not come out to them. In the morning he said, "I saw what you were doing and nothing but the fear that it (i.e. the prayer) might be enjoined on you, stopped me from coming to you." And that happened in the month of Ramadan}}
\hadithdefcmd{bukhari}{1130}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا مِسْعَرٌ، عَنْ زِيَادٍ، قَالَ سَمِعْتُ الْمُغِيرَةَ ـ رضى الله عنه ـ يَقُولُ إِنْ كَانَ النَّبِيُّ صلى الله عليه وسلم لَيَقُومُ لِيُصَلِّيَ حَتَّى تَرِمُ قَدَمَاهُ أَوْ سَاقَاهُ، فَيُقَالُ لَهُ فَيَقُولُ ‏ "‏ أَفَلاَ أَكُونُ عَبْدًا شَكُورًا ‏"‏‏.‏\hadithno{1130}\hadithtrans{Narrated Al-Mughira:The Prophet (ﷺ) used to stand (in the prayer) or pray till both his feet or legs swelled. He was asked why (he offered such an unbearable prayer) and he said, "Should I not be a thankful slave?}}
\hadithdefcmd{bukhari}{1131}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، أَنَّ عَمْرَو بْنَ أَوْسٍ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُ ‏ "‏ أَحَبُّ الصَّلاَةِ إِلَى اللَّهِ صَلاَةُ دَاوُدَ ـ عَلَيْهِ السَّلاَمُ ـ وَأَحَبُّ الصِّيَامِ إِلَى اللَّهِ صِيَامُ دَاوُدَ، وَكَانَ يَنَامُ نِصْفَ اللَّيْلِ وَيَقُومُ ثُلُثَهُ وَيَنَامُ سُدُسَهُ، وَيَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا ‏"‏‏.‏\hadithno{1131}\hadithtrans{Narrated `Abdullah bin `Amr bin Al-`As:Allah's Messenger (ﷺ) told me, "The most beloved prayer to Allah is that of David and the most beloved fasts to Allah are those of David. He used to sleep for half of the night and then pray for one third of the night and again sleep for its sixth part and used to fast on alternate days}}
\hadithdefcmd{bukhari}{1132}{حَدَّثَنِي عَبْدَانُ، قَالَ أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، عَنْ أَشْعَثَ، سَمِعْتُ أَبِي قَالَ، سَمِعْتُ مَسْرُوقًا، قَالَ سَأَلْتُ عَائِشَةَ ـ رضى الله عنها ـ أَىُّ الْعَمَلِ كَانَ أَحَبَّ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَتِ الدَّائِمُ‏.‏ قُلْتُ مَتَى كَانَ يَقُومُ قَالَتْ يَقُومُ إِذَا سَمِعَ الصَّارِخَ‏\hadithno{1132}\hadithtrans{Narrated Masruq:I asked `Aisha which deed was most loved by the Prophet. She said, "A deed done continuously." I further asked, "When did he used to get up (in the night for the prayer)." She said, "He used to get up on hearing the crowing of a cock}}
\hadithdefcmd{bukhari}{1132p2}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ قَالَ أَخْبَرَنَا أَبُو الأَحْوَصِ عَنِ الأَشْعَثِ قَالَ إِذَا سَمِعَ الصَّارِخَ قَامَ فَصَلَّى‏\hadithno{1132.2}\hadithtrans{Narrated Al-Ashath:He (the Prophet (ﷺ) ) used to get up for the prayer on hearing the crowing of a cock}}
\hadithdefcmd{bukhari}{1133}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، قَالَ ذَكَرَ أَبِي عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا أَلْفَاهُ السَّحَرُ عِنْدِي إِلاَّ نَائِمًا‏.‏ تَعْنِي النَّبِيَّ صلى الله عليه وسلم‏.‏\hadithno{1133}\hadithtrans{Narrated `Aisha:In my house he (Prophet (ﷺ) ) never passed the last hours of the night but sleeping}}
\hadithdefcmd{bukhari}{1134}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا رَوْحٌ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم وَزَيْدَ بْنَ ثَابِتٍ ـ رضى الله عنه ـ تَسَحَّرَا، فَلَمَّا فَرَغَا مِنْ سَحُورِهِمَا قَامَ نَبِيُّ اللَّهِ صلى الله عليه وسلم إِلَى الصَّلاَةِ فَصَلَّى‏.‏ قُلْنَا لأَنَسٍ كَمْ كَانَ بَيْنَ فَرَاغِهِمَا مِنْ سَحُورِهِمَا وَدُخُولِهِمَا فِي الصَّلاَةِ قَالَ كَقَدْرِ مَا يَقْرَأُ الرَّجُلُ خَمْسِينَ آيَةً‏.‏\hadithno{1134}\hadithtrans{Narrated Qatada:Anas bin Malik said, "The Prophet (ﷺ) and Zaid bin Thabit took their Suhur together. When they finished it, the Prophet (ﷺ) stood for the (Fajr) prayer and offered it." We asked Anas, "What was the interval between their finishing the Suhur and the starting of the morning prayer?" Anas replied, "It was equal to the time taken by a person in reciting fifty verses of the Qur'an}}
\hadithdefcmd{bukhari}{1135}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم لَيْلَةً، فَلَمْ يَزَلْ قَائِمًا حَتَّى هَمَمْتُ بِأَمْرِ سَوْءٍ‏.‏ قُلْنَا وَمَا هَمَمْتَ قَالَ هَمَمْتَ أَنْ أَقْعُدَ وَأَذَرَ النَّبِيَّ صلى الله عليه وسلم‏.‏\hadithno{1135}\hadithtrans{Narrated Abu-Wail:`Abdullah said, "One night I offered the Tahajjud prayer with the Prophet (ﷺ) and he kept on standing till an ill-thought came to me." We said, "What was the ill-thought?" He said, "It was to sit down and leave the Prophet (standing)}}
\hadithdefcmd{bukhari}{1136}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ حُصَيْنٍ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا قَامَ لِلتَّهَجُّدِ مِنَ اللَّيْلِ يَشُوصُ فَاهُ بِالسِّوَاكِ‏.‏\hadithno{1136}\hadithtrans{Narrated Hudhaifa:Whenever the Prophet (ﷺ) got up for Tahajjud prayer he used to clean his mouth (and teeth) with Siwak}}
\hadithdefcmd{bukhari}{1137}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ إِنَّ رَجُلاً قَالَ يَا رَسُولَ اللَّهِ، كَيْفَ صَلاَةُ اللَّيْلِ قَالَ ‏ "‏ مَثْنَى مَثْنَى، فَإِذَا خِفْتَ الصُّبْحَ فَأَوْتِرْ بِوَاحِدَةٍ ‏"‏‏.‏\hadithno{1137}\hadithtrans{Narrated `Abdullah bin `Umar:A man said, "O Allah's Messenger (ﷺ)! How is the prayer of the night?" He said, "Two rak`at followed by two rak`at and so on, and when you apprehend the approaching dawn, offer one rak`a as witr}}
\hadithdefcmd{bukhari}{1138}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، قَالَ حَدَّثَنِي أَبُو جَمْرَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ صَلاَةُ النَّبِيِّ صلى الله عليه وسلم ثَلاَثَ عَشْرَةَ رَكْعَةً‏.‏ يَعْنِي بِاللَّيْلِ‏.‏\hadithno{1138}\hadithtrans{Narrated Ibn `Abbas:The prayer of the Prophet (ﷺ) used to be of thirteen rak`at, i.e. of the night prayer}}
\hadithdefcmd{bukhari}{1139}{حَدَّثَنَا إِسْحَاقُ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، قَالَ أَخْبَرَنَا إِسْرَائِيلُ، عَنْ أَبِي حَصِينٍ، عَنْ يَحْيَى بْنِ وَثَّابٍ، عَنْ مَسْرُوقٍ، قَالَ سَأَلْتُ عَائِشَةَ ـ رضى الله عنها ـ عَنْ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِاللَّيْلِ‏.‏ فَقَالَتْ سَبْعٌ وَتِسْعٌ وَإِحْدَى عَشْرَةَ سِوَى رَكْعَتَىِ الْفَجْرِ‏.‏\hadithno{1139}\hadithtrans{Narrated Masruq:I asked Aisha about the night prayer of Allah's Messenger (ﷺ) and she said, "It was seven, nine or eleven rak`at besides the two rak`at of the Fajr prayer (i.e. Sunna)}}
\hadithdefcmd{bukhari}{1140}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، قَالَ أَخْبَرَنَا حَنْظَلَةُ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ ثَلاَثَ عَشْرَةَ رَكْعَةً مِنْهَا الْوِتْرُ وَرَكْعَتَا الْفَجْرِ‏.‏\hadithno{1140}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to offer thirteen rak`at of the night prayer and that included the witr and two rak`at (Sunna) of the Fajr prayer}}
\hadithdefcmd{bukhari}{1141}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، أَنَّهُ سَمِعَ أَنَسًا ـ رضى الله عنه ـ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُفْطِرُ مِنَ الشَّهْرِ حَتَّى نَظُنَّ أَنْ لاَ يَصُومَ مِنْهُ، وَيَصُومُ حَتَّى نَظُنَّ أَنْ لاَ يُفْطِرَ مِنْهُ شَيْئًا، وَكَانَ لاَ تَشَاءُ أَنْ تَرَاهُ مِنَ اللَّيْلِ مُصَلِّيًا إِلاَّ رَأَيْتَهُ وَلاَ نَائِمًا إِلاَّ رَأَيْتَهُ‏.‏ تَابَعَهُ سُلَيْمَانُ وَأَبُو خَالِدٍ الأَحْمَرُ عَنْ حُمَيْدٍ‏.‏\hadithno{1141}\hadithtrans{Narrated Anas bin Malik:Sometimes Allah's Messenger (ﷺ) would not fast (for so many days) that we thought that he would not fast that month and he sometimes used to fast (for so many days) that we thought he would not leave fasting throughout that month and (as regards his prayer and sleep at night), if you wanted to see him praying at night, you could see him praying and if you wanted to see him sleeping, you could see him sleeping}}
\hadithdefcmd{bukhari}{1142}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَعْقِدُ الشَّيْطَانُ عَلَى قَافِيَةِ رَأْسِ أَحَدِكُمْ إِذَا هُوَ نَامَ ثَلاَثَ عُقَدٍ، يَضْرِبُ كُلَّ عُقْدَةٍ عَلَيْكَ لَيْلٌ طَوِيلٌ فَارْقُدْ، فَإِنِ اسْتَيْقَظَ فَذَكَرَ اللَّهَ انْحَلَّتْ عُقْدَةٌ، فَإِنْ تَوَضَّأَ انْحَلَّتْ عُقْدَةٌ، فَإِنْ صَلَّى انْحَلَّتْ عُقْدَةٌ فَأَصْبَحَ نَشِيطًا طَيِّبَ النَّفْسِ، وَإِلاَّ أَصْبَحَ خَبِيثَ النَّفْسِ كَسْلاَنَ ‏"‏‏.‏\hadithno{1142}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Satan puts three knots at the back of the head of any of you if he is asleep. On every knot he reads and exhales the following words, 'The night is long, so stay asleep.' When one wakes up and remembers Allah, one knot is undone; and when one performs ablution, the second knot is undone, and when one prays the third knot is undone and one gets up energetic with a good heart in the morning; otherwise one gets up lazy and with a mischievous heart}}
\hadithdefcmd{bukhari}{1143}{حَدَّثَنَا مُؤَمَّلُ بْنُ هِشَامٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا عَوْفٌ، قَالَ حَدَّثَنَا أَبُو رَجَاءٍ، قَالَ حَدَّثَنَا سَمُرَةُ بْنُ جُنْدَبٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الرُّؤْيَا قَالَ ‏ "‏ أَمَّا الَّذِي يُثْلَغُ رَأْسُهُ بِالْحَجَرِ فَإِنَّهُ يَأْخُذُ الْقُرْآنَ فَيَرْفِضُهُ وَيَنَامُ عَنِ الصَّلاَةِ الْمَكْتُوبَةِ ‏"‏‏.‏\hadithno{1143}\hadithtrans{Narrated Samura bin Jundab:The Prophet (ﷺ) said in his narration of a dream that he saw, "He whose head was being crushed with a stone was one who learnt the Qur'an but never acted on it, and slept ignoring the compulsory prayers}}
\hadithdefcmd{bukhari}{1144}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، قَالَ حَدَّثَنَا مَنْصُورٌ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ ذُكِرَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم رَجُلٌ فَقِيلَ مَا زَالَ نَائِمًا حَتَّى أَصْبَحَ مَا قَامَ إِلَى الصَّلاَةِ‏.‏ فَقَالَ ‏ "‏ بَالَ الشَّيْطَانُ فِي أُذُنِهِ ‏"‏‏.‏\hadithno{1144}\hadithtrans{Narrated `Abdullah:A person was mentioned before the Prophet (ﷺ) and he was told that he had kept on sleeping till morning and had not got up for the prayer. The Prophet (ﷺ) said, "Satan urinated in his ears}}
\hadithdefcmd{bukhari}{1145}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، وَأَبِي عَبْدِ اللَّهِ الأَغَرِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَنْزِلُ رَبُّنَا تَبَارَكَ وَتَعَالَى كُلَّ لَيْلَةٍ إِلَى السَّمَاءِ الدُّنْيَا حِينَ يَبْقَى ثُلُثُ اللَّيْلِ الآخِرُ يَقُولُ مَنْ يَدْعُونِي فَأَسْتَجِيبَ لَهُ مَنْ يَسْأَلُنِي فَأُعْطِيَهُ مَنْ يَسْتَغْفِرُنِي فَأَغْفِرَ لَهُ ‏"‏‏.‏\hadithno{1145}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Our Lord, the Blessed, the Superior, comes every night down on the nearest Heaven to us when the last third of the night remains, saying: "Is there anyone to invoke Me, so that I may respond to invocation? Is there anyone to ask Me, so that I may grant him his request? Is there anyone seeking My forgiveness, so that I may forgive him?}}
\hadithdefcmd{bukhari}{1146}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ،‏.‏ وَحَدَّثَنِي سُلَيْمَانُ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، قَالَ سَأَلْتُ عَائِشَةَ ـ رضى الله عنها ـ كَيْفَ صَلاَةُ النَّبِيِّ صلى الله عليه وسلم بِاللَّيْلِ قَالَتْ كَانَ يَنَامُ أَوَّلَهُ وَيَقُومُ آخِرَهُ، فَيُصَلِّي ثُمَّ يَرْجِعُ إِلَى فِرَاشِهِ، فَإِذَا أَذَّنَ الْمُؤَذِّنُ وَثَبَ، فَإِنْ كَانَ بِهِ حَاجَةٌ اغْتَسَلَ، وَإِلاَّ تَوَضَّأَ وَخَرَجَ‏.‏\hadithno{1146}\hadithtrans{Narrated Al-Aswad:I asked `Aisha "How is the night prayer of the Prophet?" She replied, "He used to sleep early at night, and get up in its last part to pray, and then return to his bed. When the Mu'adh-dhin pronounced the Adhan, he would get up. If he was in need of a bath he would take it; otherwise he would perform ablution and then go out (for the prayer)}}
\hadithdefcmd{bukhari}{1147}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، سَأَلَ عَائِشَةَ ـ رضى الله عنها ـ كَيْفَ كَانَتْ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَمَضَانَ فَقَالَتْ مَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَزِيدُ فِي رَمَضَانَ وَلاَ فِي غَيْرِهِ عَلَى إِحْدَى عَشْرَةَ رَكْعَةً، يُصَلِّي أَرْبَعًا فَلاَ تَسَلْ عَنْ حُسْنِهِنَّ وَطُولِهِنَّ، ثُمَّ يُصَلِّي أَرْبَعًا فَلاَ تَسَلْ عَنْ حُسْنِهِنَّ وَطُولِهِنَّ، ثُمَّ يُصَلِّي ثَلاَثًا، قَالَتْ عَائِشَةُ فَقُلْتُ يَا رَسُولَ اللَّهِ أَتَنَامُ قَبْلَ أَنْ تُوتِرَ‏.‏ فَقَالَ ‏ "‏ يَا عَائِشَةُ، إِنَّ عَيْنَىَّ تَنَامَانِ وَلاَ يَنَامُ قَلْبِي ‏"‏‏.‏\hadithno{1147}\hadithtrans{Narrated Abu Salma bin `Abdur Rahman:I asked `Aisha, "How is the prayer of Allah's Messenger (ﷺ) during the month of Ramadan." She said, "Allah's Messenger (ﷺ) never exceeded eleven rak`at in Ramadan or in other months; he used to offer four rak`at-- do not ask me about their beauty and length, then four rak`at, do not ask me about their beauty and length, and then three rak`at." Aisha further said, "I said, 'O Allah's Messenger (ﷺ)! Do you sleep before offering the witr prayer?' He replied, 'O `Aisha! My eyes sleep but my heart remains awake}}
\hadithdefcmd{bukhari}{1148}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ فِي شَىْءٍ مِنْ صَلاَةِ اللَّيْلِ جَالِسًا، حَتَّى إِذَا كَبِرَ قَرَأَ جَالِسًا، فَإِذَا بَقِيَ عَلَيْهِ مِنَ السُّورَةِ ثَلاَثُونَ أَوْ أَرْبَعُونَ آيَةً قَامَ فَقَرَأَهُنَّ ثُمَّ رَكَعَ‏.‏\hadithno{1148}\hadithtrans{Narrated `Aisha:I did not see the Prophet (ﷺ) reciting (the Qur'an) in the night prayer while sitting except when he became old; when he used to recite while sitting, and when thirty or forty verses remained from the Sura, he would get up and recite them and then bow}}
\hadithdefcmd{bukhari}{1149}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ أَبِي حَيَّانَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِبِلاَلٍ عِنْدَ صَلاَةِ الْفَجْرِ ‏ "‏ يَا بِلاَلُ حَدِّثْنِي بِأَرْجَى عَمَلٍ عَمِلْتَهُ فِي الإِسْلاَمِ، فَإِنِّي سَمِعْتُ دَفَّ نَعْلَيْكَ بَيْنَ يَدَىَّ فِي الْجَنَّةِ ‏"‏‏.‏ قَالَ مَا عَمِلْتُ عَمَلاً أَرْجَى عِنْدِي أَنِّي لَمْ أَتَطَهَّرْ طُهُورًا فِي سَاعَةِ لَيْلٍ أَوْ نَهَارٍ إِلاَّ صَلَّيْتُ بِذَلِكَ الطُّهُورِ مَا كُتِبَ لِي أَنْ أُصَلِّيَ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ دَفَّ نَعْلَيْكَ يَعْنِي تَحْرِيكَ‏.‏\hadithno{1149}\hadithtrans{Narrated Abu Huraira:At the time of the Fajr prayer the Prophet (ﷺ) asked Bilal, "Tell me of the best deed you did after embracing Islam, for I heard your footsteps in front of me in Paradise." Bilal replied, "I did not do anything worth mentioning except that whenever I performed ablution during the day or night, I prayed after that ablution as much as was written for me}}
\hadithdefcmd{bukhari}{1150}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم فَإِذَا حَبْلٌ مَمْدُودٌ بَيْنَ السَّارِيَتَيْنِ فَقَالَ ‏"‏ مَا هَذَا الْحَبْلُ ‏"‏‏.‏ قَالُوا هَذَا حَبْلٌ لِزَيْنَبَ فَإِذَا فَتَرَتْ تَعَلَّقَتْ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ، حُلُّوهُ، لِيُصَلِّ أَحَدُكُمْ نَشَاطَهُ، فَإِذَا فَتَرَ فَلْيَقْعُدْ ‏"‏‏.‏\hadithno{1150}\hadithtrans{Narrated Anas bin Malik Once the Prophet (ﷺ) entered the Mosque and saw a rope hanging in between its two pillars. He said, "What is this rope?" The people said, "This rope is for Zainab who, when she feels tired, holds it (to keep standing for the prayer.)" The Prophet (ﷺ) said, "Don't use it. Remove the rope. You should pray as long as you feel active, and when you get tired, sit down}}
\hadithdefcmd{bukhari}{1151}{قَالَ وَقَالَ عَبْدُ اللَّهِ بْنِ مَسْلَمَةَ عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَتْ عِنْدِي امْرَأَةٌ مِنْ بَنِي أَسَدٍ فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَنْ هَذِهِ ‏"‏‏.‏ قُلْتُ فُلاَنَةُ لاَ تَنَامُ بِاللَّيْلِ‏.‏ فَذُكِرَ مِنْ صَلاَتِهَا فَقَالَ ‏"‏ مَهْ عَلَيْكُمْ مَا تُطِيقُونَ مِنَ الأَعْمَالِ، فَإِنَّ اللَّهَ لاَ يَمَلُّ حَتَّى تَمَلُّوا ‏"‏‏.‏\hadithno{1151}\hadithtrans{Narrated 'Aisha: A woman from the tribe of Bani Asad was sitting with me and Allah's Apostle (ﷺ) came to my house and said, "Who is this?" I said, "(She is) So and so. She does not sleep at night because she is engaged in prayer." The Prophet (ﷺ) said disapprovingly: Do (good) deeds which is within your capacity as Allah never gets tired of giving rewards till you get tired of doing good deeds}}
\hadithdefcmd{bukhari}{1152}{حَدَّثَنَا عَبَّاسُ بْنُ الْحُسَيْنِ، حَدَّثَنَا مُبَشِّرٌ، عَنِ الأَوْزَاعِيِّ،‏.‏ وَحَدَّثَنِي مُحَمَّدُ بْنُ مُقَاتِلٍ أَبُو الْحَسَنِ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ الْعَاصِ ـ رضى الله عنهما ـ قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا عَبْدَ اللَّهِ، لاَ تَكُنْ مِثْلَ فُلاَنٍ، كَانَ يَقُومُ اللَّيْلَ فَتَرَكَ قِيَامَ اللَّيْلِ ‏"‏‏.‏ وَقَالَ هِشَامٌ حَدَّثَنَا ابْنُ أَبِي الْعِشْرِينَ، حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى، عَنْ عُمَرَ بْنِ الْحَكَمِ بْنِ ثَوْبَانَ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ، مِثْلَهُ‏.‏ وَتَابَعَهُ عَمْرُو بْنُ أَبِي سَلَمَةَ عَنِ الأَوْزَاعِيِّ،‏.‏\hadithno{1152}\hadithtrans{Narrated `Abdullah bin `Amr bin Al-`As:Allah's Messenger (ﷺ) said to me, "O `Abdullah! Do not be like so and so who used to pray at night and then stopped the night prayer}}
\hadithdefcmd{bukhari}{1153}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ أَبِي الْعَبَّاسِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو ـ رضى الله عنهما ـ قَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَلَمْ أُخْبَرْ أَنَّكَ تَقُومُ اللَّيْلَ وَتَصُومُ النَّهَارَ ‏"‏ قُلْتُ إِنِّي أَفْعَلُ ذَلِكَ‏.‏ قَالَ ‏"‏ فَإِنَّكَ إِذَا فَعَلْتَ ذَلِكَ هَجَمَتْ عَيْنُكَ وَنَفِهَتْ نَفْسُكَ، وَإِنَّ لِنَفْسِكَ حَقٌّ، وَلأَهْلِكَ حَقٌّ، فَصُمْ وَأَفْطِرْ، وَقُمْ وَنَمْ ‏"‏‏.‏\hadithno{1153}\hadithtrans{Narrated 'Abdullah bin 'Amr:Once Allah's Messenger (ﷺ) said to me, "I have been informed that you offer Salat (prayer) all the night and observe Saum (fast) during the day." I said, "(Yes) I do so." He said, "If you do so, your eye sight will become weak and you will become weak. No doubt, your body has right on you, and your family has right on you, so observe Saum (for some days) and do not observe it (for some days), offer Salat (for sometime) and then sleep}}
\hadithdefcmd{bukhari}{1154}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي عُمَيْرُ بْنُ هَانِئٍ، قَالَ حَدَّثَنِي جُنَادَةُ بْنُ أَبِي أُمَيَّةَ، حَدَّثَنِي عُبَادَةُ بْنُ الصَّامِتِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَعَارَّ مِنَ اللَّيْلِ فَقَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ، لَهُ الْمُلْكُ، وَلَهُ الْحَمْدُ، وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ‏.‏ الْحَمْدُ لِلَّهِ، وَسُبْحَانَ اللَّهِ، وَلاَ إِلَهَ إِلاَّ اللَّهُ، وَاللَّهُ أَكْبَرُ، وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ‏.‏ ثُمَّ قَالَ اللَّهُمَّ اغْفِرْ لِي‏.‏ أَوْ دَعَا اسْتُجِيبَ، فَإِنْ تَوَضَّأَ وَصَلَّى قُبِلَتْ صَلاَتُهُ ‏"‏‏.‏\hadithno{1154}\hadithtrans{Narrated 'Ubada bin As-Samit:The Prophet (ﷺ) said, "Whoever gets up at night and says: -- 'La ilaha il-lallah Wahdahu la Sharika lahu Lahu-lmulk, waLahu-l-hamd wahuwa 'ala kullishai'in Qadir. Al hamdu lil-lahi wa subhanal-lahi wa la-ilaha il-lal-lah wa-l-lahu akbar wa la hawla Wala Quwata il-la-bil-lah.' (None has the right to be worshipped but Allah. He is the Only One and has no partners . For Him is the Kingdom and all the praises are due for Him. He is Omnipotent. All the praises are for Allah. All the glories are for Allah. And none has the right to be worshipped but Allah, And Allah is Great And there is neither Might nor Power Except with Allah). And then says: -- Allahumma, Ighfir li (O Allah! Forgive me). Or invokes (Allah), he will be responded to and if he performs ablution (and prays), his prayer will be accepted}}
\hadithdefcmd{bukhari}{1155}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي الْهَيْثَمُ بْنُ أَبِي سِنَانٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ وَهُوَ يَقْصُصُ فِي قَصَصِهِ وَهُوَ يَذْكُرُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِنَّ أَخًا لَكُمْ لاَ يَقُولُ الرَّفَثَ‏.‏ يَعْنِي بِذَلِكَ عَبْدَ اللَّهِ بْنَ رَوَاحَةَ وَفِينَا رَسُولُ اللَّهِ يَتْلُو كِتَابَهُ إِذَا انْشَقَّ مَعْرُوفٌ مِنَ الْفَجْرِ سَاطِعُ أَرَانَا الْهُدَى بَعْدَ الْعَمَى فَقُلُوبُنَا بِهِ مُوقِنَاتٌ أَنَّ مَا قَالَ وَاقِعُ يَبِيتُ يُجَافِي جَنْبَهُ عَنْ فِرَاشِهِ إِذَا اسْتَثْقَلَتْ بِالْمُشْرِكِينَ الْمَضَاجِعُ تَابَعَهُ عُقَيْلٌ‏.‏ وَقَالَ الزُّبَيْدِيُّ أَخْبَرَنِي الزُّهْرِيُّ عَنْ سَعِيدٍ وَالأَعْرَجِ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه‏.‏\hadithno{1155}\hadithtrans{Narrated Abu Huraira:That once Allah's Messenger (ﷺ) said, "Your brother, i.e. `Abdullah bin Rawaha does not say obscene (referring to his verses): Amongst us is Allah's Messenger (ﷺ), who recites His Book when it dawns. He showed us the guidance, after we were blind. We believe that whatever he says will come true. And he spends his nights in such a way as his sides do not touch his bed. While the pagans were deeply asleep}}
\hadithdefcmd{bukhari}{1158}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما قَالَ رَأَيْتُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم كَأَنَّ بِيَدِي قِطْعَةَ إِسْتَبْرَقٍ، فَكَأَنِّي لاَ أُرِيدُ مَكَانًا مِنَ الْجَنَّةِ إِلاَّ طَارَتْ إِلَيْهِ، وَرَأَيْتُ كَأَنَّ اثْنَيْنِ أَتَيَانِي أَرَادَا أَنْ يَذْهَبَا بِي إِلَى النَّارِ فَتَلَقَّاهُمَا مَلَكٌ فَقَالَ لَمْ تُرَعْ خَلِّيَا عَنْهُ‏.‏ فَقَصَّتْ حَفْصَةُ عَلَى النَّبِيِّ صلى الله عليه وسلم إِحْدَى رُؤْيَاىَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ نِعْمَ الرَّجُلُ عَبْدُ اللَّهِ لَوْ كَانَ يُصَلِّي مِنَ اللَّيْلِ ‏"‏‏.‏ فَكَانَ عَبْدُ اللَّهِ ـ رضى الله عنه ـ يُصَلِّي مِنَ اللَّيْلِ‏.‏ وَكَانُوا لاَ يَزَالُونَ يَقُصُّونَ عَلَى النَّبِيِّ صلى الله عليه وسلم الرُّؤْيَا أَنَّهَا فِي اللَّيْلَةِ السَّابِعَةِ مِنَ الْعَشْرِ الأَوَاخِرِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَرَى رُؤْيَاكُمْ قَدْ تَوَاطَتْ فِي الْعَشْرِ الأَوَاخِرِ، فَمَنْ كَانَ مُتَحَرِّيْهَا فَلْيَتَحَرَّهَا مِنَ الْعَشْرِ الأَوَاخِرِ ‏"‏‏.‏\hadithno{1158}\hadithtrans{Narrated Nafi`:Ibn `Umar said, "In the lifetime of the Prophet (ﷺ) I dreamt that a piece of silk cloth was in my hand and it flew with me to whichever part of Paradise I wanted. I also saw as if two persons (i.e. angels) came to me and wanted to take me to Hell. Then an angel met us and told me not to be afraid. He then told them to leave me. Hafsa narrated one of my dreams to the Prophet (ﷺ) and the Prophet (ﷺ) said, "Abdullah is a good man. Would that he offer the night prayer (Tahajjud)!" So after that day `Abdullah (bin `Umar) started offering Tahajjud. The companions of the Prophet (ﷺ) used to tell him their dreams that (Laila-tul-Qadr) was on the 27th of the month of Ramadan. The Prophet (ﷺ) said, "I see that your dreams agree on the last ten nights of Ramadan and so whoever is in search of it should seek it in the last ten nights of Ramadan}}
\hadithdefcmd{bukhari}{1159}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا سَعِيدٌ ـ هُوَ ابْنُ أَبِي أَيُّوبَ ـ قَالَ حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ صَلَّى النَّبِيُّ صلى الله عليه وسلم الْعِشَاءَ ثُمَّ صَلَّى ثَمَانَ رَكَعَاتٍ وَرَكْعَتَيْنِ جَالِسًا وَرَكْعَتَيْنِ بَيْنَ النِّدَاءَيْنِ، وَلَمْ يَكُنْ يَدَعُهُمَا أَبَدًا‏.‏\hadithno{1159}\hadithtrans{Narrated `Aisha;:Allah's Messenger (ﷺ) offered the `Isha' prayer (and then got up at the Tahajjud time) and offered eight rak`at and then offered two rak`at while sitting. He then offered two rak`at in between the Adhan and Iqama (of the Fajr prayer) and he never missed them}}
\hadithdefcmd{bukhari}{1160}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، قَالَ حَدَّثَنِي أَبُو الأَسْوَدِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا صَلَّى رَكْعَتَىِ الْفَجْرِ اضْطَجَعَ عَلَى شِقِّهِ الأَيْمَنِ‏.‏\hadithno{1160}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to lie down on his right side, after offering two rak`at (Sunna) of the Fajr prayer}}
\hadithdefcmd{bukhari}{1161}{حَدَّثَنَا بِشْرُ بْنُ الْحَكَمِ، حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي سَالِمٌ أَبُو النَّضْرِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا صَلَّى ‏\{‏سُنَّةَ الْفَجْرِ‏\}‏ فَإِنْ كُنْتُ مُسْتَيْقِظَةً حَدَّثَنِي وَإِلاَّ اضْطَجَعَ حَتَّى يُؤْذَنَ بِالصَّلاَةِ‏.‏\hadithno{1161}\hadithtrans{Narrated `Aisha:After offering the Sunna of the Fajr prayer, the Prophet (ﷺ) used to talk to me, if I happened to be awake; otherwise he would lie down till the Iqama call was proclaimed (for the Fajr prayer)}}
\hadithdefcmd{bukhari}{1162}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ أَبُو النَّضْرِ عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي رَكْعَتَيْنِ فَإِنْ كُنْتُ مُسْتَيْقِظَةً حَدَّثَنِي وَإِلاَّ اضْطَجَعَ‏.‏ قُلْتُ لِسُفْيَانَ فَإِنَّ بَعْضَهُمْ يَرْوِيهِ رَكْعَتَىِ الْفَجْرِ‏.‏ قَالَ سُفْيَانُ هُوَ ذَاكَ‏.‏\hadithno{1162}\hadithtrans{Narrated `Aisha:After offering the two rak`at (Sunna) the Prophet (ﷺ) used to talk to me, if I happened to be awake; otherwise he would lie down}}
\hadithdefcmd{bukhari}{1163}{حَدَّثَنَا بَيَانُ بْنُ عَمْرٍو، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَمْ يَكُنِ النَّبِيُّ صلى الله عليه وسلم عَلَى شَىْءٍ مِنَ النَّوَافِلِ أَشَدَّ مِنْهُ تَعَاهُدًا عَلَى رَكْعَتَىِ الْفَجْرِ‏.‏\hadithno{1163}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) was never more regular and particular in offering any Nawafil than the two rak`at (Sunna) of the Fajr prayer}}
\hadithdefcmd{bukhari}{1164}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِاللَّيْلِ ثَلاَثَ عَشْرَةَ رَكْعَةً، ثُمَّ يُصَلِّي إِذَا سَمِعَ النِّدَاءَ بِالصُّبْحِ رَكْعَتَيْنِ خَفِيفَتَيْنِ‏.‏\hadithno{1164}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to offer thirteen rak`at in the night prayer and on hearing the Adhan for the morning prayer, he used to offer two light rak`at}}
\hadithdefcmd{bukhari}{1165}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَمَّتِهِ، عَمْرَةَ عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم ح وَحَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ حَدَّثَنَا زُهَيْرٌ حَدَّثَنَا يَحْيَى ـ هُوَ ابْنُ سَعِيدٍ ـ عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ عَمْرَةَ عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُخَفِّفُ الرَّكْعَتَيْنِ اللَّتَيْنِ قَبْلَ صَلاَةِ الصُّبْحِ حَتَّى إِنِّي لأَقُولُ هَلْ قَرَأَ بِأُمِّ الْكِتَابِ\hadithno{1165}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to make the two rak`at before the Fajr prayer so light that I would wonder whether he recited Al-Fatiha (or not)}}
\hadithdefcmd{bukhari}{1166}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الْمَوَالِي، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُنَا الاِسْتِخَارَةَ فِي الأُمُورِ كَمَا يُعَلِّمُنَا السُّورَةَ مِنَ الْقُرْآنِ يَقُولُ ‏ "‏ إِذَا هَمَّ أَحَدُكُمْ بِالأَمْرِ فَلْيَرْكَعْ رَكْعَتَيْنِ مِنْ غَيْرِ الْفَرِيضَةِ ثُمَّ لِيَقُلِ اللَّهُمَّ إِنِّي أَسْتَخِيرُكَ بِعِلْمِكَ وَأَسْتَقْدِرُكَ بِقُدْرَتِكَ، وَأَسْأَلُكَ مِنْ فَضْلِكَ الْعَظِيمِ، فَإِنَّكَ تَقْدِرُ وَلاَ أَقْدِرُ وَتَعْلَمُ وَلاَ أَعْلَمُ وَأَنْتَ عَلاَّمُ الْغُيُوبِ، اللَّهُمَّ إِنْ كُنْتَ تَعْلَمُ أَنَّ هَذَا الأَمْرَ خَيْرٌ لِي فِي دِينِي وَمَعَاشِي وَعَاقِبَةِ أَمْرِي ـ أَوْ قَالَ عَاجِلِ أَمْرِي وَآجِلِهِ ـ فَاقْدُرْهُ لِي وَيَسِّرْهُ لِي ثُمَّ بَارِكْ لِي فِيهِ، وَإِنْ كُنْتَ تَعْلَمُ أَنَّ هَذَا الأَمْرَ شَرٌّ لِي فِي دِينِي وَمَعَاشِي وَعَاقِبَةِ أَمْرِي ـ أَوْ قَالَ فِي عَاجِلِ أَمْرِي وَآجِلِهِ ـ فَاصْرِفْهُ عَنِّي وَاصْرِفْنِي عَنْهُ، وَاقْدُرْ لِي الْخَيْرَ حَيْثُ كَانَ ثُمَّ أَرْضِنِي بِهِ ـ قَالَ ـ وَيُسَمِّي حَاجَتَهُ ‏"‏‏.‏\hadithno{1166}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) used to teach us the way of doing Istikhara (Istikhara means to ask Allah to guide one to the right sort of action concerning any job or a deed), in all matters as he taught us the Suras of the Qur'an. He said, "If anyone of you thinks of doing any job he should offer a two rak`at prayer other than the compulsory ones and say (after the prayer): -- 'Allahumma inni astakhiruka bi'ilmika, Wa astaqdiruka bi-qudratika, Wa as'alaka min fadlika Al-`azlm Fa-innaka taqdiru Wala aqdiru, Wa ta'lamu Wala a'lamu, Wa anta 'allamu l-ghuyub. Allahumma, in kunta ta'lam anna hadha-lamra Khairun li fi dini wa ma'ashi wa'aqibati `Amri (or 'ajili `Amri wa'ajilihi) Faqdirhu wa yas-sirhu li thumma barik li Fihi, Wa in kunta ta'lamu anna hadha-lamra shar-run li fi dini wa ma'ashi wa'aqibati `Amri (or fi'ajili `Amri wa ajilihi) Fasrifhu anni was-rifni anhu. Waqdir li al-khaira haithu kana Thumma ardini bihi.' (O Allah! I ask guidance from Your knowledge, And Power from Your Might and I ask for Your great blessings. You are capable and I am not. You know and I do not and You know the unseen. O Allah! If You know that this job is good for my religion and my subsistence and in my Hereafter--(or said: If it is better for my present and later needs)--Then You ordain it for me and make it easy for me to get, And then bless me in it, and if You know that this job is harmful to me In my religion and subsistence and in the Hereafter--(or said: If it is worse for my present and later needs)--Then keep it away from me and let me be away from it. And ordain for me whatever is good for me, And make me satisfied with it). The Prophet (ﷺ) added that then the person should name (mention) his need}}
\hadithdefcmd{bukhari}{1167}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدٍ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، سَمِعَ أَبَا قَتَادَةَ بْنَ رِبْعِيٍّ الأَنْصَارِيّ َ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا دَخَلَ أَحَدُكُمُ الْمَسْجِدَ فَلاَ يَجْلِسْ حَتَّى يُصَلِّيَ رَكْعَتَيْنِ ‏"‏‏.‏\hadithno{1167}\hadithtrans{Narrated Abu Qatada bin Rabi Al-Ansari:The Prophet (ﷺ) said, "If anyone of you enters a Mosque, he should not sit until he has offered a two-rak`at prayer}}
\hadithdefcmd{bukhari}{1168}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ صَلَّى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَتَيْنِ ثُمَّ انْصَرَفَ‏.‏\hadithno{1168}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) led us and offered a two rak`at prayer and then went away}}
\hadithdefcmd{bukhari}{1169}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَالِمٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم رَكْعَتَيْنِ قَبْلَ الظُّهْرِ، وَرَكْعَتَيْنِ بَعْدَ الظُّهْرِ، وَرَكْعَتَيْنِ بَعْدَ الْجُمُعَةِ، وَرَكْعَتَيْنِ بَعْدَ الْمَغْرِبِ، وَرَكْعَتَيْنِ بَعْدَ الْعِشَاءِ‏.‏\hadithno{1169}\hadithtrans{Narrated `Abdullah bin `Umar:I offered with Allah's Messenger (ﷺ) a two rak`at prayer before the Zuhr prayer and two rak`at after the Zuhr prayer, two rak`at after Jumua, Maghrib and `Isha' prayers}}
\hadithdefcmd{bukhari}{1170}{حَدَّثَنَا آدَمُ، قَالَ أَخْبَرَنَا شُعْبَةُ، أَخْبَرَنَا عَمْرُو بْنُ دِينَارٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ يَخْطُبُ ‏ "‏ إِذَا جَاءَ أَحَدُكُمْ وَالإِمَامُ يَخْطُبُ ـ أَوْ قَدْ خَرَجَ ـ فَلْيُصَلِّ رَكْعَتَيْنِ ‏"‏‏.‏\hadithno{1170}\hadithtrans{Narrated Jabir bin `Abdullah:While delivering a sermon, Allah's Messenger (ﷺ) said, "If anyone of you comes while the Imam is delivering the sermon or has come out for it, he should offer a two rak`at prayer}}
\hadithdefcmd{bukhari}{1171}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سَيْفُ بْنُ سُلَيْمَانَ الْمَكِّيُّ، سَمِعْتُ مُجَاهِدًا، يَقُولُ أُتِيَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ فِي مَنْزِلِهِ فَقِيلَ لَهُ هَذَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَدْ دَخَلَ الْكَعْبَةَ قَالَ فَأَقْبَلْتُ فَأَجِدُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ خَرَجَ، وَأَجِدُ بِلاَلاً عِنْدَ الْبَابِ قَائِمًا فَقُلْتُ يَا بِلاَلُ، صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْكَعْبَةِ قَالَ نَعَمْ‏.‏ قُلْتُ فَأَيْنَ قَالَ بَيْنَ هَاتَيْنِ الأُسْطُوَانَتَيْنِ‏.‏ ثُمَّ خَرَجَ فَصَلَّى رَكْعَتَيْنِ فِي وَجْهِ الْكَعْبَةِ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ قَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ أَوْصَانِي النَّبِيُّ صلى الله عليه وسلم بِرَكْعَتَىِ الضُّحَى‏.‏ وَقَالَ عِتْبَانُ غَدَا عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ ـ رضى الله عنه ـ بَعْدَ مَا امْتَدَّ النَّهَارُ وَصَفَفْنَا وَرَاءَهُ فَرَكَعَ رَكْعَتَيْنِ‏.‏\hadithno{1171}\hadithtrans{Narrated Mujahid:Somebody came to the house of Ibn `Umar and told him that Allah's Messenger (ﷺ) had entered the Ka`ba. Ibn `Umar said, "I went in front of the Ka`ba and found that Allah's Messenger (ﷺ) had come out of the Ka`ba and I saw Bilal standing by the side of the gate of the Ka`ba. I said, 'O Bilal! Has Allah's Apostle (ﷺ) prayed inside the Ka`ba?' Bilal replied in the affirmative. I said, 'Where (did he pray)?' He replied, '(He prayed) Between these two pillars and then he came out and offered a two rak`at prayer in front of the Ka`ba.' " Abu `Abdullah said: Abu Huraira said, "The Prophet (ﷺ) advised me to offer two rak`at of Duha prayer (prayer to be offered after sunrise and before midday). " Itban (bin Malik) said, "Allah's Messenger (ﷺ) and Abu Bakr, came to me after sunrise and we aligned behind the Prophet (ﷺ) and offered two rak`at}}
\hadithdefcmd{bukhari}{1173}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنَا نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم سَجْدَتَيْنِ قَبْلَ الظُّهْرِ، وَسَجْدَتَيْنِ بَعْدَ الظُّهْرِ، وَسَجْدَتَيْنِ بَعْدَ الْمَغْرِبِ، وَسَجْدَتَيْنِ بَعْدَ الْعِشَاءِ، وَسَجْدَتَيْنِ بَعْدَ الْجُمُعَةِ، فَأَمَّا الْمَغْرِبُ وَالْعِشَاءُ فَفِي بَيْتِهِ‏.‏ قَالَ ابْنُ أَبِي الزِّنَادِ عَنْ مُوسَى بْنِ عُقْبَةَ عَنْ نَافِعٍ بَعْدَ الْعِشَاءِ فِي أَهْلِهِ‏.‏ تَابَعَهُ كَثِيرُ بْنُ فَرْقَدٍ وَأَيُّوبُ عَنْ نَافِعٍ‏.‏ وَحَدَّثَتْنِي أُخْتِي، حَفْصَةُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي سَجْدَتَيْنِ خَفِيفَتَيْنِ بَعْدَ مَا يَطْلُعُ الْفَجْرُ، وَكَانَتْ سَاعَةً لاَ أَدْخُلُ عَلَى النَّبِيِّ صلى الله عليه وسلم فِيهَا‏.‏ تَابَعَهُ كَثِيرُ بْنُ فَرْقَدٍ وَأَيُّوبُ عَنْ نَافِعٍ‏.‏ وَقَالَ ابْنُ أَبِي الزِّنَادِ عَنْ مُوسَى بْنِ عُقْبَةَ عَنْ نَافِعٍ بَعْدَ الْعِشَاءِ فِي أَهْلِهِ‏.‏\hadithno{1173}\hadithtrans{Narrated Ibn `Umar:I offered with the Prophet (ﷺ) two rak`at before the Zuhr and two rak`at after the Zuhr prayer; two rak`at after Maghrib, `Isha' and the Jumua prayers. Those of the Maghrib and `Isha' were offered in his house. My sister Hafsa told me that the Prophet (ﷺ) used to offer two light rak`at after dawn and it was the time when I never went to the Prophet}}
\hadithdefcmd{bukhari}{1174}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ سَمِعْتُ أَبَا الشَّعْثَاءِ، جَابِرًا قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنه ـ قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثَمَانِيًا جَمِيعًا وَسَبْعًا جَمِيعًا‏.‏ قُلْتُ يَا أَبَا الشَّعْثَاءِ أَظُنُّهُ أَخَّرَ الظُّهْرَ وَعَجَّلَ الْعَصْرَ وَعَجَّلَ الْعِشَاءَ وَأَخَّرَ الْمَغْرِبَ‏.‏ قَالَ وَأَنَا أَظُنُّهُ‏.‏\hadithno{1174}\hadithtrans{Narrated `Amr:I heard Abu Ash-sha'tha' Jabir saying, "I heard Ibn `Abbas saying, 'I offered with Allah's Messenger (ﷺ) eight rak`at (of Zuhr and `Asr prayers) together and seven rak`at (the Maghrib and the `Isha' prayers) together.' " I said, "O Abu Ash-shatha! I think he must have prayed the Zuhr late and the `Asr early; the `Isha early and the Maghrib late." Abu Ash-sha'tha' said, "I also think so." (See Hadith No. 518 Vol)}}
\hadithdefcmd{bukhari}{1175}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ تَوْبَةَ، عَنْ مُوَرِّقٍ، قَالَ قُلْتُ لاِبْنِ عُمَرَ ـ رضى الله عنهما ـ أَتُصَلِّي الضُّحَى قَالَ لاَ‏.‏ قُلْتُ فَعُمَرُ‏.‏ قَالَ لاَ‏.‏ قُلْتُ فَأَبُو بَكْرٍ‏.‏ قَالَ لاَ‏.‏ قُلْتُ فَالنَّبِيُّ صلى الله عليه وسلم قَالَ لاَ إِخَالُهُ‏.‏\hadithno{1175}\hadithtrans{Narrated Muwarriq:I asked Ibn `Umar "Do you offer the Duha prayer?" He replied in the negative. I further asked, "Did `Umar use to pray it?" He (Ibn `Umar) replied in the negative. I again asked, "Did Abu Bakr use to pray it?" He replied in the negative. I again asked, "Did the Prophet (ﷺ) use to pray it?" Ibn `Umar replied, "I don't think he did}}
\hadithdefcmd{bukhari}{1176}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَمْرُو بْنُ مُرَّةَ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ أَبِي لَيْلَى، يَقُولُ مَا حَدَّثَنَا أَحَدٌ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم يُصَلِّي الضُّحَى غَيْرَ أُمِّ هَانِئٍ فَإِنَّهَا قَالَتْ إِنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ بَيْتَهَا يَوْمَ فَتْحِ مَكَّةَ فَاغْتَسَلَ وَصَلَّى ثَمَانِيَ رَكَعَاتٍ فَلَمْ أَرَ صَلاَةً قَطُّ أَخَفَّ مِنْهَا، غَيْرَ أَنَّهُ يُتِمُّ الرُّكُوعَ وَالسُّجُودَ‏.‏\hadithno{1176}\hadithtrans{Narrated `Abdur Rahman bin Abi Laila:Only Um Hani narrated to me that she had seen the Prophet (ﷺ) offering the Duha prayer. She said, "On the day of the conquest of Mecca, the Prophet (ﷺ) entered my house, took a bath and offered eight rak`at (of Duha prayers. I had never seen the Prophet (ﷺ) offering such a light prayer but he performed bowing and prostrations perfectly}}
\hadithdefcmd{bukhari}{1177}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم سَبَّحَ سُبْحَةَ الضُّحَى، وَإِنِّي لأُسَبِّحُهَا‏.‏\hadithno{1177}\hadithtrans{Narrated `Aisha:I never saw the Prophet (ﷺ) offering the Duha prayer but I always offer it}}
\hadithdefcmd{bukhari}{1178}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا شُعْبَةُ، حَدَّثَنَا عَبَّاسٌ الْجُرَيْرِيُّ ـ هُوَ ابْنُ فَرُّوخَ ـ عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ أَوْصَانِي خَلِيلِي بِثَلاَثٍ لاَ أَدَعُهُنَّ حَتَّى أَمُوتَ صَوْمِ ثَلاَثَةِ أَيَّامٍ مِنْ كُلِّ شَهْرٍ، وَصَلاَةِ الضُّحَى، وَنَوْمٍ عَلَى وِتْرٍ‏.‏\hadithno{1178}\hadithtrans{Narrated Abu Huraira:My friend (the Prophet) advised me to do three things and I shall not leave them till I die, these are: To fast three days every month, to offer the Duha prayer, and to offer witr before sleeping}}
\hadithdefcmd{bukhari}{1179}{حَدَّثَنَا عَلِيُّ بْنُ الْجَعْدِ، أَخْبَرَنَا شُعْبَةُ، عَنْ أَنَسِ بْنِ سِيرِينَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ الأَنْصَارِيَّ، قَالَ قَالَ رَجُلٌ مِنَ الأَنْصَارِ ـ وَكَانَ ضَخْمًا ـ لِلنَّبِيِّ صلى الله عليه وسلم إِنِّي لاَ أَسْتَطِيعُ الصَّلاَةَ مَعَكَ‏.‏ فَصَنَعَ لِلنَّبِيِّ صلى الله عليه وسلم طَعَامًا، فَدَعَاهُ إِلَى بَيْتِهِ، وَنَضَحَ لَهُ طَرَفَ حَصِيرٍ بِمَاءٍ فَصَلَّى عَلَيْهِ رَكْعَتَيْنِ‏.‏ وَقَالَ فُلاَنُ بْنُ فُلاَنِ بْنِ جَارُودٍ لأَنَسٍ ـ رضى الله عنه ـ أَكَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي الضُّحَى فَقَالَ مَا رَأَيْتُهُ صَلَّى غَيْرَ ذَلِكَ الْيَوْمِ‏.‏\hadithno{1179}\hadithtrans{Narrated Anas bin Sirin: I heard Anas bin Malik al-Ansari saying, "An Ansari man, who was very fat, said to the Prophet, 'I am unable to present myself for the prayer with you.' He prepared a meal for the Prophet (ﷺ) and invited him to his house. He washed one side of a mat with water and the Prophet (ﷺ) offered two Rakat on it." So and so, the son of so and so, the son of Al-Jarud asked Anas, "Did the Prophet (ﷺ) use to offer the Duha prayer?" Anas replied, "I never saw him praying (the Duha prayer) except on that day}}
\hadithdefcmd{bukhari}{1181}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ حَفِظْتُ مِنَ النَّبِيِّ صلى الله عليه وسلم عَشْرَ رَكَعَاتٍ رَكْعَتَيْنِ قَبْلَ الظُّهْرِ، وَرَكْعَتَيْنِ بَعْدَهَا، وَرَكْعَتَيْنِ بَعْدَ الْمَغْرِبِ فِي بَيْتِهِ، وَرَكْعَتَيْنِ بَعْدَ الْعِشَاءِ فِي بَيْتِهِ، وَرَكْعَتَيْنِ قَبْلَ صَلاَةِ الصُّبْحِ، وَكَانَتْ سَاعَةً لاَ يُدْخَلُ عَلَى النَّبِيِّ صلى الله عليه وسلم فِيهَا‏.‏ حَدَّثَتْنِي حَفْصَةُ، أَنَّهُ كَانَ إِذَا أَذَّنَ الْمُؤَذِّنُ وَطَلَعَ الْفَجْرُ صَلَّى رَكْعَتَيْنِ‏.‏\hadithno{1181}\hadithtrans{Narrated Ibn 'Umar: I remember ten Rakat of Nawafil from the Prophet, two Rakat before the Zuhr prayer and two after it; two Rakat after Maghrib prayer in his house, and two Rakat after 'Isha' prayer in his house, and two Rakat before the Fajr prayer and at that time nobody would enter the house of the Prophet. Hafsa told me that the Prophet (ﷺ) used to offer two Rakat after the call maker had made the Adhan and the day had dawned}}
\hadithdefcmd{bukhari}{1182}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لاَ يَدَعُ أَرْبَعًا قَبْلَ الظُّهْرِ وَرَكْعَتَيْنِ قَبْلَ الْغَدَاةِ‏.‏ تَابَعَهُ ابْنُ أَبِي عَدِيٍّ وَعَمْرٌو عَنْ شُعْبَةَ‏.‏\hadithno{1182}\hadithtrans{Narrated Aisha:The Prophet (ﷺ) never missed four rak`at before the Zuhr prayer and two rak`at before the Fajr prayer}}
\hadithdefcmd{bukhari}{1183}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنِ الْحُسَيْنِ، عَنِ ابْنِ بُرَيْدَةَ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ الْمُزَنِيُّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ صَلُّوا قَبْلَ صَلاَةِ الْمَغْرِبِ ‏"‏‏.‏ ـ قَالَ فِي الثَّالِثَةِ ـ لِمَنْ شَاءَ كَرَاهِيَةَ أَنْ يَتَّخِذَهَا النَّاسُ سُنَّةً‏.‏\hadithno{1183}\hadithtrans{Narrated `Abdullah Al-Muzani:The Prophet (ﷺ) said, "Pray before the Maghrib (compulsory) prayer." He (said it thrice) and in the third time, he said, "Whoever wants to offer it can do so." He said so because he did not like the people to take it as a tradition}}
\hadithdefcmd{bukhari}{1184}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، قَالَ سَمِعْتُ مَرْثَدَ بْنَ عَبْدِ اللَّهِ الْيَزَنِيَّ، قَالَ أَتَيْتُ عُقْبَةَ بْنَ عَامِرٍ الْجُهَنِيَّ فَقُلْتُ أَلاَ أُعْجِبُكَ مِنْ أَبِي تَمِيمٍ يَرْكَعُ رَكْعَتَيْنِ قَبْلَ صَلاَةِ الْمَغْرِبِ‏.‏ فَقَالَ عُقْبَةُ إِنَّا كُنَّا نَفْعَلُهُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ قُلْتُ فَمَا يَمْنَعُكَ الآنَ قَالَ الشُّغْلُ‏.‏\hadithno{1184}\hadithtrans{Narrated Marthad bin `Abdullah Al-Yazani:I went to `Uqba bin 'Amir Al-Juhani and said, "Is it not surprising that Abi Tamim offers two rak`at before the Maghrib prayer?" `Uqba said, "We used to do so in the lifetime of Allah's Messenger (ﷺ)." I asked him, "What prevents you from offering it now?" He replied, "Business}}
\hadithdefcmd{bukhari}{1185}{حَدَّثَنِي إِسْحَاقُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي مَحْمُودُ بْنُ الرَّبِيعِ الأَنْصَارِيُّ، أَنَّهُ عَقَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم، وَعَقَلَ مَجَّةً مَجَّهَا فِي وَجْهِهِ مِنْ بِئْرٍ كَانَتْ فِي دَارِهِمْ‏.‏ فَزَعَمَ مَحْمُودٌ أَنَّهُ سَمِعَ عِتْبَانَ بْنَ مَالِكٍ الأَنْصَارِيّ َ ـ رضى الله عنه ـ وَكَانَ مِمَّنْ شَهِدَ بَدْرًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ كُنْتُ أُصَلِّي لِقَوْمِي بِبَنِي سَالِمٍ، وَكَانَ يَحُولُ بَيْنِي وَبَيْنَهُمْ وَادٍ إِذَا جَاءَتِ الأَمْطَارُ فَيَشُقُّ عَلَىَّ اجْتِيَازُهُ قِبَلَ مَسْجِدِهِمْ، فَجِئْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ لَهُ إِنِّي أَنْكَرْتُ بَصَرِي، وَإِنَّ الْوَادِيَ الَّذِي بَيْنِي وَبَيْنَ قَوْمِي يَسِيلُ إِذَا جَاءَتِ الأَمْطَارُ فَيَشُقُّ عَلَىَّ اجْتِيَازُهُ، فَوَدِدْتُ أَنَّكَ تَأْتِي فَتُصَلِّي مِنْ بَيْتِي مَكَانًا أَتَّخِذُهُ مُصَلًّى‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَأَفْعَلُ ‏"‏‏.‏ فَغَدَا عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ ـ رضى الله عنه ـ بَعْدَ مَا اشْتَدَّ النَّهَارُ فَاسْتَأْذَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَذِنْتُ لَهُ فَلَمْ يَجْلِسْ حَتَّى قَالَ ‏"‏ أَيْنَ تُحِبُّ أَنْ أُصَلِّيَ مِنْ بَيْتِكَ ‏"‏‏.‏ فَأَشَرْتُ لَهُ إِلَى الْمَكَانِ الَّذِي أُحِبُّ أَنْ أُصَلِّيَ فِيهِ، فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَكَبَّرَ وَصَفَفْنَا وَرَاءَهُ، فَصَلَّى رَكْعَتَيْنِ، ثُمَّ سَلَّمَ وَسَلَّمْنَا حِينَ سَلَّمَ، فَحَبَسْتُهُ عَلَى خَزِيرٍ يُصْنَعُ لَهُ فَسَمِعَ أَهْلُ الدَّارِ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي بَيْتِي فَثَابَ رِجَالٌ مِنْهُمْ حَتَّى كَثُرَ الرِّجَالُ فِي الْبَيْتِ‏.‏ فَقَالَ رَجُلٌ مِنْهُمْ مَا فَعَلَ مَالِكٌ لاَ أَرَاهُ‏.‏ فَقَالَ رَجُلٌ مِنْهُمْ ذَاكَ مُنَافِقٌ لاَ يُحِبُّ اللَّهَ وَرَسُولَهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَقُلْ ذَاكَ أَلاَ تَرَاهُ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ يَبْتَغِي بِذَلِكَ وَجْهَ اللَّهِ ‏"‏‏.‏ فَقَالَ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ أَمَّا نَحْنُ فَوَاللَّهِ لاَ نَرَى وُدَّهُ وَلاَ حَدِيثَهُ إِلاَّ إِلَى الْمُنَافِقِينَ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِنَّ اللَّهَ قَدْ حَرَّمَ عَلَى النَّارِ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ يَبْتَغِي بِذَلِكَ وَجْهَ اللَّهِ ‏"‏‏.‏ قَالَ مَحْمُودٌ فَحَدَّثْتُهَا قَوْمًا فِيهِمْ أَبُو أَيُّوبَ صَاحِبُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَتِهِ الَّتِي تُوُفِّيَ فِيهَا وَيَزِيدُ بْنُ مُعَاوِيَةَ عَلَيْهِمْ بِأَرْضِ الرُّومِ، فَأَنْكَرَهَا عَلَىَّ أَبُو أَيُّوبَ قَالَ وَاللَّهِ مَا أَظُنُّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ مَا قُلْتَ قَطُّ‏.‏ فَكَبُرَ ذَلِكَ عَلَىَّ فَجَعَلْتُ لِلَّهِ عَلَىَّ إِنْ سَلَّمَنِي حَتَّى أَقْفُلَ مِنْ غَزْوَتِي أَنْ أَسْأَلَ عَنْهَا عِتْبَانَ بْنَ مَالِكٍ ـ رضى الله عنه ـ إِنْ وَجَدْتُهُ حَيًّا فِي مَسْجِدِ قَوْمِهِ، فَقَفَلْتُ فَأَهْلَلْتُ بِحَجَّةٍ أَوْ بِعُمْرَةٍ، ثُمَّ سِرْتُ حَتَّى قَدِمْتُ الْمَدِينَةَ فَأَتَيْتُ بَنِي سَالِمٍ، فَإِذَا عِتْبَانُ شَيْخٌ أَعْمَى يُصَلِّي لِقَوْمِهِ فَلَمَّا سَلَّمَ مِنَ الصَّلاَةِ سَلَّمْتُ عَلَيْهِ وَأَخْبَرْتُهُ مَنْ أَنَا، ثُمَّ سَأَلْتُهُ عَنْ ذَلِكَ الْحَدِيثِ فَحَدَّثَنِيهِ كَمَا حَدَّثَنِيهِ أَوَّلَ مَرَّةٍ‏.‏\hadithno{1185}\hadithtrans{Narrated Mahmud bin Ar-rabi' Al-Ansari:that he remembered Allah's Messenger (ﷺ) and he also remembered a mouthful of water which he had thrown on his face, after taking it from a well that was in their house. Mahmud said that he had heard `Itban bin Malik, who was present with Allah's Messenger (ﷺ) in the battle of Badr saying, "I used to lead my people at Bani Salim in the prayer and there was a valley between me and those people. Whenever it rained it used to be difficult for me to cross it to go to their mosque. So I went to Allah's Messenger (ﷺ) and said, 'I have weak eyesight and the valley between me and my people flows during the rainy season and it becomes difficult for me to cross it; I wish you would come to my house and pray at a place so that I could take that place as a praying place.' Allah's Messenger (ﷺ) said, 'I will do so.' So Allah's Messenger (ﷺ) and Abu Bakr came to my house in the (next) morning after the sun had risen high. Allah's Messenger (ﷺ) asked my permission to let him in and I admitted him. He did not sit before saying, 'Where do you want us to offer the prayer in your house?' I pointed to the place where I wanted him to pray. So Allah's Messenger (ﷺ) stood up for the prayer and started the prayer with Takbir and we aligned in rows behind him; and he offered two rak`at, and finished them with Taslim, and we also performed Taslim with him. I detained him for a meal called "Khazir" which I had prepared for him.--("Khazir" is a special type of dish prepared from barley flour and meat soup)-- When the neighbors got the news that Allah's Messenger (ﷺ) was in my house, they poured in till there were a great number of men in the house. One of them said, 'What is wrong with Malik, for I do not see him?' One of them replied, 'He is a hypocrite and does not love Allah and His Apostle.' On that Allah's Apostle said, 'Don't say this. Haven't you seen that he said, 'None has the right to be worshipped but Allah for Allah's sake only.' The man replied, 'Allah and His Apostle know better; but by Allah, we never saw him but helping and talking with the hypocrites.' Allah's Messenger (ﷺ) replied, 'No doubt, whoever says. None has the right to be worshipped but Allah, and by that he wants the pleasures of Allah, then Allah will save him from Hell." Mahmud added, "I told the above narration to some people, one of whom was Abu Aiyub, the companion of Allah's Messenger (ﷺ) in the battle in which he (Abu Aiyub) died and Yazid bin Mu'awiya was their leader in Roman Territory. Abu Aiyub denounced the narration and said, 'I doubt that Allah's Messenger (ﷺ) ever said what you have said.' I felt that too much, and I vowed to Allah that if I remained alive in that holy battle, I would (go to Medina and) ask `Itban bin Malik if he was still living in the mosque of his people. So when he returned, I assumed Ihram for Hajj or `Umra and then I proceeded on till I reached Medina. I went to Bani Salim and `Itban bin Malik, who was by then an old blind man, was leading his people in the prayer. When he finished the prayer, I greeted him and introduced myself to him and then asked him about that narration. He told that narration again in the same manner as he had narrated it the first time}}
\hadithdefcmd{bukhari}{1187}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، وَعُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اجْعَلُوا فى بُيُوتِكُمْ مِنْ صَلاَتِكُمْ وَلاَ تَتَّخِذُوهَا قُبُورًا ‏"‏‏.‏ تَابَعَهُ عَبْدُ الْوَهَّابِ عَنْ أَيُّوبَ‏.‏\hadithno{1187}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "Offer some of your prayers in your houses and do not make them graves}}
