% Auto-generated chapter 20 for tirmidhi
% Hadiths in this chapter: 24

\hadithdefcmd{tirmidhi}{1524}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو صَفْوَانَ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةٍ وَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَجَابِرٍ وَعِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ يَصِحُّ لأَنَّ الزُّهْرِيَّ لَمْ يَسْمَعْ هَذَا الْحَدِيثَ مِنْ أَبِي سَلَمَةَ ‏.‏ قَالَ سَمِعْتُ مُحَمَّدًا يَقُولُ رَوَى غَيْرُ وَاحِدٍ مِنْهُمْ مُوسَى بْنُ عُقْبَةَ وَابْنُ أَبِي عَتِيقٍ عَنِ الزُّهْرِيِّ عَنْ سُلَيْمَانَ بْنِ أَرْقَمَ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ عَنْ أَبِي سَلَمَةَ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ مُحَمَّدٌ وَالْحَدِيثُ هُوَ هَذَا ‏.‏\hadithno{1524}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Aishah:That the Messenger of Allah (ﷺ) said: "There is no vowing for disobedience, and its atonement is the atonement of an oath}}
\hadithdefcmd{tirmidhi}{1525}{حَدَّثَنَا أَبُو إِسْمَاعِيلَ التِّرْمِذِيُّ، - وَاسْمُهُ مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ يُوسُفَ حَدَّثَنَا أَيُّوبُ بْنُ سُلَيْمَانَ بْنِ بِلاَلٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي أُوَيْسٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، وَمُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي عَتِيقٍ، عَنِ الزُّهْرِيِّ، عَنْ سُلَيْمَانَ بْنِ أَرْقَمَ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نَذْرَ فِي مَعْصِيَةِ اللَّهِ وَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَهُوَ أَصَحُّ مِنْ حَدِيثِ أَبِي صَفْوَانَ عَنْ يُونُسَ ‏.‏ وَأَبُو صَفْوَانَ هُوَ مَكِّيٌّ وَاسْمُهُ عَبْدُ اللَّهِ بْنُ سَعِيدِ بْنِ عَبْدِ الْمَلِكِ بْنِ مَرْوَانَ وَقَدْ رَوَى عَنْهُ الْحُمَيْدِيُّ وَغَيْرُ وَاحِدٍ مِنْ جِلَّةِ أَهْلِ الْحَدِيثِ ‏.‏ وَقَالَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ لاَ نَذْرَ فِي مَعْصِيَةِ اللَّهِ وَكَفَّارَتُهُ كَفَّارَةُ يَمِينٍ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ وَاحْتَجَّا بِحَدِيثِ الزُّهْرِيِّ عَنْ أَبِي سَلَمَةَ عَنْ عَائِشَةَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ لاَ نَذْرَ فِي مَعْصِيَةٍ وَلاَ كَفَّارَةَ فِي ذَلِكَ ‏.‏ وَهُوَ قَوْلُ مَالِكٍ وَالشَّافِعِيِّ ‏.‏\hadithno{1525}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated 'Aishah:That the Prophet (ﷺ) said: "There is no vowing in disobedience to Allah, and its atonement is the atonement of an oath}}
\hadithdefcmd{tirmidhi}{1526}{\hadithno{1526}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1527}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ ثَابِتِ بْنِ الضَّحَّاكِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ عَلَى الْعَبْدِ نَذْرٌ فِيمَا لاَ يَمْلِكُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَعِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1527}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Thabit bin Adh-Dahhak:That the Prophet (ﷺ) said: "It is not for a person to vow about that over which he has no control}}
\hadithdefcmd{tirmidhi}{1528}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، حَدَّثَنِي مُحَمَّدٌ، مَوْلَى الْمُغِيرَةِ بْنِ شُعْبَةَ حَدَّثَنِي كَعْبُ بْنُ عَلْقَمَةَ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَفَّارَةُ النَّذْرِ إِذَا لَمْ يُسَمَّ كَفَّارَةُ يَمِينٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{1528}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Uqbah bin 'Amir:That the Messenger of Allah (ﷺ) said: "The atonement of a vow when it is not specified is the atonement of an oath}}
\hadithdefcmd{tirmidhi}{1529}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ يُونُسَ، هُوَ ابْنُ عُبَيْدٍ حَدَّثَنَا الْحَسَنُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا عَبْدَ الرَّحْمَنِ لاَ تَسْأَلِ الإِمَارَةَ فَإِنَّكَ إِنْ أَتَتْكَ عَنْ مَسْأَلَةٍ وُكِلْتَ إِلَيْهَا وَإِنْ أَتَتْكَ عَنْ غَيْرِ مَسْأَلَةٍ أُعِنْتَ عَلَيْهَا وَإِذَا حَلَفْتَ عَلَى يَمِينٍ فَرَأَيْتَ غَيْرَهَا خَيْرًا مِنْهَا فَائْتِ الَّذِي هُوَ خَيْرٌ وَلْتُكَفِّرْ عَنْ يَمِينِكَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَجَابِرٍ وَعَدِيِّ بْنِ حَاتِمٍ وَأَبِي الدَّرْدَاءِ وَأَنَسٍ وَعَائِشَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي هُرَيْرَةَ وَأُمِّ سَلَمَةَ وَأَبِي مُوسَى ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1529}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdur-Rahman bin Samurah:That the Messenger of Allah (ﷺ) said: "O 'Abdur-Rahman! Do not ask for a position of leadership, for if you receive it due to asking, you will be left alone with it, and if you receive it without asking, then you will be aided in it. And if you take an oath and you see that something else is better than it, then do what is better, and make an atonement for your oath}}
\hadithdefcmd{tirmidhi}{1530}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَرَأَى غَيْرَهَا خَيْرًا مِنْهَا فَلْيُكَفِّرْ عَنْ يَمِينِهِ وَلْيَفْعَلْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ الْكَفَّارَةَ قَبْلَ الْحِنْثِ تُجْزِئُ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لاَ يُكَفِّرُ إِلاَّ بَعْدَ الْحِنْثِ ‏.‏ قَالَ سُفْيَانُ الثَّوْرِيُّ إِنْ كَفَّرَ بَعْدَ الْحِنْثِ أَحَبُّ إِلَىَّ وَإِنْ كَفَّرَ قَبْلَ الْحِنْثِ أَجْزَأَهُ ‏.‏\hadithno{1530}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah:That the Prophet (ﷺ) said: "Whoever takes an oath, and then he sees that something else is better than it, then he should make atonement for his oath and then do it}}
\hadithdefcmd{tirmidhi}{1531}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنِي أَبِي وَحَمَّادُ بْنُ سَلَمَةَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَقَالَ إِنْ شَاءَ اللَّهُ فَقَدِ اسْتَثْنَى فَلاَ حِنْثَ عَلَيْهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَاهُ عُبَيْدُ اللَّهِ بْنُ عُمَرَ وَغَيْرُهُ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ مَوْقُوفًا ‏.‏ وَهَكَذَا رُوِيَ عَنْ سَالِمٍ عَنِ ابْنِ عُمَرَ رضى الله عنهما مَوْقُوفًا ‏.‏ وَلاَ نَعْلَمُ أَحَدًا رَفَعَهُ غَيْرَ أَيُّوبَ السَّخْتِيَانِيِّ وَقَالَ إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ وَكَانَ أَيُّوبُ أَحْيَانًا يَرْفَعُهُ وَأَحْيَانًا لاَ يَرْفَعُهُ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ الاِسْتِثْنَاءَ إِذَا كَانَ مَوْصُولاً بِالْيَمِينِ فَلاَ حِنْثَ عَلَيْهِ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالأَوْزَاعِيِّ وَمَالِكِ بْنِ أَنَسٍ وَعَبْدِ اللَّهِ بْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1531}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn 'Umar:That the Messenger of Allah (ﷺ) said: "Whoever swears about an oath and says: 'If Allah wills (Insha Allah), then there is no breaking of the oath against him}}
\hadithdefcmd{tirmidhi}{1532}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ فَقَالَ إِنْ شَاءَ اللَّهُ لَمْ يَحْنَثْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى سَأَلْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ عَنْ هَذَا فَقَالَ هَذَا حَدِيثٌ خَطَأٌ أَخْطَأَ فِيهِ عَبْدُ الرَّزَّاقِ اخْتَصَرَهُ مِنْ حَدِيثِ مَعْمَرٍ عَنِ ابْنِ طَاوُسٍ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ سُلَيْمَانَ بْنَ دَاوُدَ قَالَ لأَطُوفَنَّ اللَّيْلَةَ عَلَى سَبْعِينَ امْرَأَةً تَلِدُ كُلُّ امْرَأَةٍ غُلاَمًا ‏.‏ فَطَافَ عَلَيْهِنَّ فَلَمْ تَلِدِ امْرَأَةٌ مِنْهُنَّ إِلاَّ امْرَأَةٌ نِصْفَ غُلاَمٍ ‏"‏ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ قَالَ إِنْ شَاءَ اللَّهُ لَكَانَ كَمَا قَالَ ‏"‏ ‏.‏ هَكَذَا رُوِيَ عَنْ عَبْدِ الرَّزَّاقِ عَنْ مَعْمَرٍ عَنِ ابْنِ طَاوُسٍ عَنْ أَبِيهِ هَذَا الْحَدِيثُ بِطُولِهِ وَقَالَ ‏"‏ سَبْعِينَ امْرَأَةً ‏"‏ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ قَالَ سُلَيْمَانُ بْنُ دَاوُدَ لأَطُوفَنَّ اللَّيْلَةَ عَلَى مِائَةِ امْرَأَةٍ ‏"‏ ‏.‏\hadithno{1532}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah:That the Messenger of Allah (ﷺ) said: "Whoever swears [about an oath] and says: 'If Allah wills (Insha Allah), then he will not have broken it}}
\hadithdefcmd{tirmidhi}{1533}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، سَمِعَ النَّبِيُّ صلى الله عليه وسلم عُمَرَ وَهُوَ يَقُولُ وَأَبِي وَأَبِي فَقَالَ ‏ "‏ أَلاَ إِنَّ اللَّهَ يَنْهَاكُمْ أَنْ تَحْلِفُوا بِآبَائِكُمْ ‏"‏ ‏.‏ فَقَالَ عُمَرُ فَوَاللَّهِ مَا حَلَفْتُ بِهِ بَعْدَ ذَلِكَ ذَاكِرًا وَلاَ آثِرًا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ ثَابِتِ بْنِ الضَّحَّاكِ وَابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ وَقُتَيْلَةَ وَعَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ أَبُو عِيسَى قَالَ أَبُو عُبَيْدٍ مَعْنَى قَوْلِهِ وَلاَ آثِرًا ‏.‏ أَىْ لَمْ آثُرْهُ عَنْ غَيْرِي يَقُولُ لَمْ أَذْكُرْهُ عَنْ غَيْرِي ‏.‏\hadithno{1533}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Salim:From his father (Ibn 'Umar) that the Prophet (ﷺ) heard 'Umar saying: "By my father, By my father!" So he said: "Verily Allah prohibits you from swearing by your father." So 'Umar said: "By Allah I did not swear by him after that, neither intentionally nor in narrating}}
\hadithdefcmd{tirmidhi}{1534}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَدْرَكَ عُمَرَ وَهُوَ فِي رَكْبٍ وَهُوَ يَحْلِفُ بِأَبِيهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يَنْهَاكُمْ أَنْ تَحْلِفُوا بِآبَائِكُمْ لِيَحْلِفْ حَالِفٌ بِاللَّهِ أَوْ لِيَسْكُتْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1534}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar:That the Messenger of Allah (ﷺ) came across 'Umar while he was on his mount, and he was swearing by his father. So the Messenger of Allah (ﷺ) said: "Verily Allah prohibits you from swearing by your fathers. So let the one who swears, swear by Allah, or be silent}}
\hadithdefcmd{tirmidhi}{1535}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، أَنَّ ابْنَ عُمَرَ، سَمِعَ رَجُلاً، يَقُولُ لاَ وَالْكَعْبَةِ ‏.‏ فَقَالَ ابْنُ عُمَرَ لاَ يُحْلَفُ بِغَيْرِ اللَّهِ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ حَلَفَ بِغَيْرِ اللَّهِ فَقَدْ كَفَرَ أَوْ أَشْرَكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَفُسِّرَ هَذَا الْحَدِيثُ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ أَنَّ قَوْلَهُ ‏"‏ فَقَدْ كَفَرَ أَوْ أَشْرَكَ ‏"‏ عَلَى التَّغْلِيظِ ‏.‏ وَالْحُجَّةُ فِي ذَلِكَ حَدِيثُ ابْنِ عُمَرَ أَنَّ النَّبِيَّ صلى الله عليه وسلم سَمِعَ عُمَرَ يَقُولُ وَأَبِي وَأَبِي ‏.‏ فَقَالَ ‏"‏ أَلاَ إِنَّ اللَّهَ يَنْهَاكُمْ أَنْ تَحْلِفُوا بِآبَائِكُمْ ‏"‏ ‏.‏ وَحَدِيثُ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ مَنْ قَالَ فِي حَلِفِهِ وَاللاَّتِ وَالْعُزَّى فَلْيَقُلْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا مِثْلُ مَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ إِنَّ الرِّيَاءَ شِرْكٌ ‏"‏ ‏.‏ وَقَدْ فَسَّرَ بَعْضُ أَهْلِ الْعِلْمِ هَذِهِ الآيَة ‏:‏ ‏(‏ وَمَنْ كَانَ يَرْجُو لِقَاءَ رَبِّهِ فَلْيَعْمَلْ عَمَلاً صَالِحًا ‏)‏ الآيَةَ قَالَ لاَ يُرَائِي ‏.‏\hadithno{1535}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Sa'd bin 'Ubaidah:That Ibn 'Umar heard a man saying: "No by the Ka'bah" so Ibn 'Umar said: "Nothing is sworn by other than Allah, for I heard the Messenger of Allah (ﷺ) say: 'Whoever swears by other than Allah, he has committed disbelief or shirk}}
\hadithdefcmd{tirmidhi}{1536}{حَدَّثَنَا عَبْدُ الْقُدُّوسِ بْنُ مُحَمَّدٍ الْعَطَّارُ الْبَصْرِيُّ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، عَنْ عِمْرَانَ الْقَطَّانِ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ نَذَرَتِ امْرَأَةٌ أَنْ تَمْشِيَ، إِلَى بَيْتِ اللَّهِ فَسُئِلَ نَبِيُّ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ إِنَّ اللَّهَ لَغَنِيٌّ عَنْ مَشْيِهَا مُرُوهَا فَلْتَرْكَبْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعُقْبَةَ بْنِ عَامِرٍ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَقَالُوا إِذَا نَذَرَتِ امْرَأَةٌ أَنْ تَمْشِيَ فَلْتَرْكَبْ وَلْتُهْدِ شَاةً ‏.‏\hadithno{1536}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas:"A Woman vowed to walk to the House of Allah, so the Prophet (ﷺ) asked about that, and he said: 'Verily Allah is in no need of her walking, order her to ride}}
\hadithdefcmd{tirmidhi}{1537}{\hadithno{1537}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1538}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَنْذِرُوا فَإِنَّ النَّذْرَ لاَ يُغْنِي مِنَ الْقَدَرِ شَيْئًا وَإِنَّمَا يُسْتَخْرَجُ بِهِ مِنَ الْبَخِيلِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ كَرِهُوا النَّذْرَ ‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ مَعْنَى الْكَرَاهِيَةِ فِي النَّذْرِ فِي الطَّاعَةِ وَالْمَعْصِيَةِ وَإِنْ نَذَرَ الرَّجُلُ بِالطَّاعَةِ فَوَفَّى بِهِ فَلَهُ فِيهِ أَجْرٌ وَيُكْرَهُ لَهُ النَّذْرُ ‏.‏\hadithno{1538}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Hurairah:That the Messenger of Allah (ﷺ) said: "Do not vow, for the vows does not prevent what is decreed at all, and it only causes the miser to spend (of his wealth)}}
\hadithdefcmd{tirmidhi}{1539}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ نَذَرْتُ أَنْ أَعْتَكِفَ لَيْلَةً فِي الْمَسْجِدِ الْحَرَامِ فِي الْجَاهِلِيَّةِ ‏.‏ قَالَ ‏ "‏ أَوْفِ بِنَذْرِكَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا الْحَدِيثِ قَالُوا إِذَا أَسْلَمَ الرَّجُلُ وَعَلَيْهِ نَذْرُ طَاعَةٍ فَلْيَفِ بِهِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ لاَ اعْتِكَافَ إِلاَّ بِصَوْمٍ ‏.‏ وَقَالَ آخَرُونَ مِنْ أَهْلِ الْعِلْمِ لَيْسَ عَلَى الْمُعْتَكِفِ صَوْمٌ إِلاَّ أَنْ يُوجِبَ عَلَى نَفْسِهِ صَوْمًا ‏.‏ وَاحْتَجُّوا بِحَدِيثِ عُمَرَ أَنَّهُ نَذَرَ أَنْ يَعْتَكِفَ لَيْلَةً فِي الْجَاهِلِيَّةِ فَأَمَرَهُ النَّبِيُّ صلى الله عليه وسلم بِالْوَفَاءِ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1539}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Umar:"I said:'O Messenger of Allah! I had vowed to perform I'tikaf in Al-Masjid Al-Haram for a night during the era of Jahiliyyah.' He said: 'Fulfill your vow}}
\hadithdefcmd{tirmidhi}{1540}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، وَعَبْدُ اللَّهِ بْنُ جَعْفَرٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ كَثِيرًا مَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَحْلِفُ بِهَذِهِ الْيَمِينِ ‏ "‏ لاَ وَمُقَلِّبِ الْقُلُوبِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1540}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Salim bin 'Abdullah:From this father (Ibn Umar) who said: "The Messenger of Allah (ﷺ) often would swear with this oath: 'No! By the Changer of the Hearts}}
\hadithdefcmd{tirmidhi}{1541}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ الْهَادِ، عَنْ عُمَرَ بْنِ عَلِيِّ بْنِ الْحُسَيْنِ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَنْ سَعِيدِ ابْنِ مَرْجَانَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَعْتَقَ رَقَبَةً مُؤْمِنَةً أَعْتَقَ اللَّهُ مِنْهُ بِكُلِّ عُضْوٍ مِنْهُ عُضْوًا مِنَ النَّارِ حَتَّى يُعْتِقَ فَرْجَهُ بِفَرْجِهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَعَمْرِو بْنِ عَبَسَةَ وَابْنِ عَبَّاسٍ وَوَاثِلَةَ بْنِ الأَسْقَعِ وَأَبِي أُمَامَةَ وَعُقْبَةَ بْنِ عَامِرٍ وَكَعْبِ بْنِ مُرَّةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَابْنُ الْهَادِ اسْمُهُ يَزِيدُ بْنُ عَبْدِ اللَّهِ بْنِ أُسَامَةَ بْنِ الْهَادِ وَهُوَ مَدَنِيٌّ ثِقَةٌ قَدْ رَوَى عَنْهُ مَالِكُ بْنُ أَنَسٍ وَغَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ ‏.‏\hadithno{1541}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah:"I heard the Messenger of Allah (ﷺ) saying: 'Whoever frees a believing slave, then Allah frees a limb from the Fire for each of his limbs, such that he frees his private parts in lieu of his private parts}}
\hadithdefcmd{tirmidhi}{1542}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنْ شُعْبَةَ، عَنْ حُصَيْنٍ، عَنْ هِلاَلِ بْنِ يِسَافٍ، عَنْ سُوَيْدِ بْنِ مُقَرِّنٍ الْمُزَنِيِّ، قَالَ لَقَدْ رَأَيْتُنَا سَبْعَةَ إِخْوَةٍ مَا لَنَا خَادِمٌ إِلاَّ وَاحِدَةٌ فَلَطَمَهَا أَحَدُنَا فَأَمَرَنَا النَّبِيُّ صلى الله عليه وسلم أَنْ نُعْتِقَهَا ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى غَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ حُصَيْنِ بْنِ عَبْدِ الرَّحْمَنِ فَذَكَرَ بَعْضُهُمْ فِي الْحَدِيثِ قَالَ لَطَمَهَا عَلَى وَجْهِهَا ‏.‏\hadithno{1542}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Suwaid bin Muqarrin Al-Muzani:"We were seven brothers without a servant except one, and one of us slapped her, so the Prophet (ﷺ) ordered us to free her}}
\hadithdefcmd{tirmidhi}{1543}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ ثَابِتِ بْنِ الضَّحَّاكِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ بِمِلَّةٍ غَيْرِ الإِسْلاَمِ كَاذِبًا فَهُوَ كَمَا قَالَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي هَذَا إِذَا حَلَفَ الرَّجُلُ بِمِلَّةٍ سِوَى الإِسْلاَمِ فَقَالَ هُوَ يَهُودِيٌّ أَوْ نَصْرَانِيٌّ إِنْ فَعَلَ كَذَا وَكَذَا فَفَعَلَ ذَلِكَ الشَّىْءَ فَقَالَ بَعْضُهُمْ قَدْ أَتَى عَظِيمًا وَلاَ كَفَّارَةَ عَلَيْهِ وَهُوَ قَوْلُ أَهْلِ الْمَدِينَةِ وَبِهِ يَقُولُ مَالِكُ بْنُ أَنَسٍ وَإِلَى هَذَا الْقَوْلِ ذَهَبَ أَبُو عُبَيْدٍ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَالتَّابِعِينَ وَغَيْرِهِمْ عَلَيْهِ فِي ذَلِكَ الْكَفَّارَةُ وَهُوَ قَوْلُ سُفْيَانَ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1543}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Thabit bin Adh-Dahhak:That the Messenger of Allah (ﷺ) said: "Whoever swears by a religion other than Islam while lying, then he is as he said}}
\hadithdefcmd{tirmidhi}{1544}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ زَحْرٍ، عَنْ أَبِي سَعِيدٍ الرُّعَيْنِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَالِكٍ الْيَحْصُبِيِّ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أُخْتِي نَذَرَتْ أَنْ تَمْشِيَ إِلَى الْبَيْتِ حَافِيَةً غَيْرَ مُخْتَمِرَةٍ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ لاَ يَصْنَعُ بِشَقَاءِ أُخْتِكَ شَيْئًا فَلْتَرْكَبْ وَلْتَخْتَمِرْ وَلْتَصُمْ ثَلاَثَةَ أَيَّامٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1544}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Uqbah bin 'Amir:"I said: 'O Messenger of Allah! My sister vowed that she would walk to the House barefoot and without Khimar (covering).' The Prophet (ﷺ) said: 'Verily Allah will not do anything with the misery of your sister. She should ride, and cover, and fast three days}}
\hadithdefcmd{tirmidhi}{1545}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ مِنْكُمْ فَقَالَ فِي حَلِفِهِ وَاللاَّتِ وَالْعُزَّى فَلْيَقُلْ لاَ إِلَهَ إِلاَّ اللَّهُ وَمَنْ قَالَ تَعَالَ أُقَامِرْكَ فَلْيَتَصَدَّقْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو الْمُغِيرَةِ هُوَ الْخَوْلاَنِيُّ الْحِمْصِيُّ وَاسْمُهُ عَبْدُ الْقُدُّوسِ بْنُ الْحَجَّاجِ ‏.‏\hadithno{1545}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah:That the Messenger of Allah (ﷺ) said: "Whoever among you swears, saying in his oath: 'By Al-Lat! By Al-'Uzza!' Then let him say 'La ilaha illa Allah' And whoever says: 'Come let me gamble with you!' Then let him give in charity}}
\hadithdefcmd{tirmidhi}{1546}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ سَعْدَ بْنَ عُبَادَةَ، اسْتَفْتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فِي نَذْرٍ كَانَ عَلَى أُمِّهِ تُوُفِّيَتْ قَبْلَ أَنْ تَقْضِيَهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اقْضِهِ عَنْهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1546}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Abbas:That Sa'd bin 'Ubadah asked the Messenger of Allah (ﷺ) about a vow that was due from his mother, who died before fulfilling it. The Prophet (ﷺ) said: "Fulfill it for her}}
\hadithdefcmd{tirmidhi}{1547}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْأَعْلَى حَدَّثَنَا عِمْرَانُ بْنُ عُيَيْنَةَ هُوَ أَخُو سُفْيَانَ بْنِ عُيَيْنَةَ عَنْ حُصَيْنٍ عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ عَنْ أَبِي أُمَامَةَ وَغَيْرِهِ مِنْ أَصْحَابِ النَّبِيِّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ عَنْ النَّبِيِّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ قَالَ أَيُّمَا امْرِئٍ مُسْلِمٍ أَعْتَقَ امْرَأً مُسْلِمًا كَانَ فَكَاكَهُ مِنْ النَّارِ يُجْزِي كُلُّ عُضْوٍ مِنْهُ عُضْوًا مِنْهُ وَأَيُّمَا امْرِئٍ مُسْلِمٍ أَعْتَقَ امْرَأَتَيْنِ مُسْلِمَتَيْنِ كَانَتَا فَكَاكَهُ مِنْ النَّارِ يُجْزِي كُلُّ عُضْوٍ مِنْهُمَا عُضْوًا مِنْهُ وَأَيُّمَا امْرَأَةٍ مُسْلِمَةٍ أَعْتَقَتْ امْرَأَةً مُسْلِمَةً كَانَتْ فَكَاكَهَا مِنْ النَّارِ يُجْزِي كُلُّ عُضْوٍ مِنْهَا عُضْوًا مِنْهَا قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ قَالَ أَبُو عِيسَى وَفِي الْحَدِيثِ مَا يَدُلُّ عَلَى أَنَّ عِتْقَ الذُّكُورِ لِلرِّجَالِ أَفْضَلُ مِنْ عِتْقِ الْإِنَاثِ لِقَوْلِ رَسُولِ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ مَنْ أَعْتَقَ امْرَأً مُسْلِمًا كَانَ فَكَاكَهُ مِنْ النَّارِ يُجْزِي كُلُّ عُضْوٍ مِنْهُ عُضْوًا مِنْهُ\hadithno{1547}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Umamah, and other than him from the Companions of the Prophet (ﷺ), narrated that the Prophet (ﷺ) said:"Any Muslim man who frees a Muslim man, then it is his salvation from the Fire - each of his limbs suffices for a limb of himself. And any Muslim man that frees two Muslim women, then are his salvation from the Fire - each of their limbs suffices for a limb of himself. And any Muslim woman that frees a Muslim woman, then she is her salvation from the Fire - each of her limb suffices for a limb of herself}}
