% Auto-generated chapter 45 for bukhari
% Hadiths in this chapter: 15

\hadithdefcmd{bukhari}{2426}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ،‏.‏ وَحَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ، سَمِعْتُ سُوَيْدَ بْنَ غَفَلَةَ، قَالَ لَقِيتُ أُبَىَّ بْنَ كَعْبٍ ـ رضى الله عنه ـ فَقَالَ أَخَذْتُ صُرَّةً مِائَةَ دِينَارٍ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ عَرِّفْهَا حَوْلاً‏"‏‏.‏ فَعَرَّفْتُهَا حَوْلَهَا فَلَمْ أَجِدْ مَنْ يَعْرِفُهَا، ثُمَّ أَتَيْتُهُ فَقَالَ ‏"‏ عَرِّفْهَا حَوْلاً ‏"‏ فَعَرَّفْتُهَا فَلَمْ أَجِدْ، ثُمَّ أَتَيْتُهُ ثَلاَثًا فَقَالَ ‏"‏ احْفَظْ وِعَاءَهَا وَعَدَدَهَا وَوِكَاءَهَا، فَإِنْ جَاءَ صَاحِبُهَا، وَإِلاَّ فَاسْتَمْتِعْ بِهَا ‏"‏‏.‏ فَاسْتَمْتَعْتُ فَلَقِيتُهُ بَعْدُ بِمَكَّةَ فَقَالَ لاَ أَدْرِي ثَلاَثَةَ أَحْوَالٍ أَوْ حَوْلاً وَاحِدًا‏.‏\hadithno{2426}\hadithtrans{Narrated Ubai bin Ka`b:I found a purse containing one hundred Diners. So I went to the Prophet (and informed him about it), he said, "Make public announcement about it for one year" I did so, but nobody turned up to claim it, so I again went to the Prophet (ﷺ) who said, "Make public announcement for another year." I did, but none turned up to claim it. I went to him for the third time and he said, "Keep the container and the string which is used for its tying and count the money it contains and if its owner comes, give it to him; otherwise, utilize it." The sub-narrator Salama said, "I met him (Suwaid, another sub-narrator) in Mecca and he said, 'I don't know whether Ubai made the announcement for three years or just one year}}
\hadithdefcmd{bukhari}{2427}{حَدَّثَنَا عَمْرُو بْنُ عَبَّاسٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ رَبِيعَةَ، حَدَّثَنِي يَزِيدُ، مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ ـ رضى الله عنه ـ قَالَ جَاءَ أَعْرَابِيٌّ النَّبِيَّ صلى الله عليه وسلم فَسَأَلَهُ عَمَّا يَلْتَقِطُهُ فَقَالَ ‏"‏ عَرِّفْهَا سَنَةً، ثُمَّ احْفَظْ عِفَاصَهَا وَوِكَاءَهَا، فَإِنْ جَاءَ أَحَدٌ يُخْبِرُكَ بِهَا، وَإِلاَّ فَاسْتَنْفِقْهَا ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ فَضَالَّةُ الْغَنَمِ قَالَ ‏"‏ لَكَ أَوْ لأَخِيكَ أَوْ لِلذِّئْبِ ‏"‏‏.‏ قَالَ ضَالَّةُ الإِبِلِ فَتَمَعَّرَ وَجْهُ النَّبِيِّ صلى الله عليه وسلم‏.‏ فَقَالَ ‏"‏ مَا لَكَ وَلَهَا، مَعَهَا حِذَاؤُهَا وَسِقَاؤُهَا، تَرِدُ الْمَاءَ وَتَأْكُلُ الشَّجَرَ ‏"‏‏.‏\hadithno{2427}\hadithtrans{Narrated Zaid bin Khalid Al-Juhani:A bedouin went to the Prophet (ﷺ) and asked him about picking up a lost thing. The Prophet (ﷺ) said, "Make public announcement about it for one year. Remember the description of its container and the string with which it is tied; and if somebody comes and claims it and describes it correctly, (give it to him); otherwise, utilize it." He said, "O Allah's Messenger (ﷺ)! What about a lost sheep?" The Prophet (ﷺ) said, "It is for you, for your brother (i.e. its owner), or for the wolf." He further asked, "What about a lost camel?" On that the face of the Prophet (ﷺ) became red (with anger) and said, "You have nothing to do with it, as it has its feet, its water reserve and can reach places of water and drink, and eat trees}}
\hadithdefcmd{bukhari}{2428}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي سُلَيْمَانُ، عَنْ يَحْيَى، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ أَنَّهُ سَمِعَ زَيْدَ بْنَ خَالِدٍ ـ رضى الله عنه ـ يَقُولُ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنِ اللُّقَطَةِ فَزَعَمَ أَنَّهُ قَالَ ‏"‏ اعْرِفْ عِفَاصَهَا وَوِكَاءَهَا، ثُمَّ عَرِّفْهَا سَنَةً ‏"‏‏.‏ يَقُولُ يَزِيدُ إِنْ لَمْ تُعْتَرَفِ اسْتَنْفَقَ بِهَا صَاحِبُهَا وَكَانَتْ وَدِيعَةً، عِنْدَهُ‏.‏ قَالَ يَحْيَى فَهَذَا الَّذِي لاَ أَدْرِي أَفِي حَدِيثِ رَسُولِ اللَّهِ صلى الله عليه وسلم هُوَ أَمْ شَىْءٌ مِنْ عِنْدِهِ ـ ثُمَّ قَالَ كَيْفَ تَرَى فِي ضَالَّةِ الْغَنَمِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ خُذْهَا فَإِنَّمَا هِيَ لَكَ أَوْ لأَخِيكَ أَوْ لِلذِّئْبِ ‏"‏‏.‏ قَالَ يَزِيدُ وَهْىَ تُعَرَّفُ أَيْضًا‏.‏ ثُمَّ قَالَ كَيْفَ تَرَى فِي ضَالَّةِ الإِبِلِ قَالَ فَقَالَ ‏"‏ دَعْهَا فَإِنَّ مَعَهَا حِذَاءَهَا وَسِقَاءَهَا، تَرِدُ الْمَاءَ وَتَأْكُلُ الشَّجَرَ، حَتَّى يَجِدَهَا رَبُّهَا ‏"‏‏.‏\hadithno{2428}\hadithtrans{Narrated Sulaiman bin Bilal from Yahya:Yazid Maula Al-Munba'ith heard Zaid bin Khalid al-Juhani saying, "The Prophet (ﷺ) was asked about Luqata. He said, 'Remember the description of its container and the string it is tied with, and announce it publicly for one year.' " Yazid added, "If nobody claims then the person who has found it can spend it, and it is regarded as a trust entrusted to him." Yahya said, "I do not know whether the last sentences were said by the Prophet (ﷺ) or by Yazid." Zaid further said, "The Prophet (ﷺ) was asked, 'What about a lost sheep?' The Prophet (ﷺ) said, 'Take it, for it is for you or for your brother (i.e. its owner) or for the wolf." Yazid added that it should also be announced publicly. The man then asked the Prophet (ﷺ) about a lost camel. The Prophet (ﷺ) said, "Leave it, as it has its feet, water container (reservoir), and it will reach a place of water and eat trees till its owner finds it}}
\hadithdefcmd{bukhari}{2429}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ خَالِدٍ ـ رضى الله عنه ـ قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ عَنِ اللُّقَطَةِ‏.‏ فَقَالَ ‏"‏ اعْرِفْ عِفَاصَهَا وَوِكَاءَهَا، ثُمَّ عَرِّفْهَا سَنَةً، فَإِنْ جَاءَ صَاحِبُهَا، وَإِلاَّ فَشَأْنَكَ بِهَا ‏"‏‏.‏ قَالَ فَضَالَّةُ الْغَنَمِ قَالَ ‏"‏ هِيَ لَكَ أَوْ لأَخِيكَ أَوْ لِلذِّئْبِ ‏"‏‏.‏ قَالَ فَضَالَّةُ الإِبِلِ قَالَ ‏"‏ مَا لَكَ وَلَهَا، مَعَهَا سِقَاؤُهَا وَحِذَاؤُهَا، تَرِدُ الْمَاءَ وَتَأْكُلُ الشَّجَرَ، حَتَّى يَلْقَاهَا رَبُّهَا ‏"‏‏.‏\hadithno{2429}\hadithtrans{Narrated Zaid bin Khalid:A man came and asked Allah's Messenger (ﷺ) about picking a lost thing. The Prophet (ﷺ) said, "Remember the description of its container and the string it is tied with, and make public announcement about it for one year. If the owner shows up, give it to him; otherwise, do whatever you like with it." He then asked, "What about a lost sheep?" The Prophet (ﷺ) said, "It is for you, for your brother (i.e. its owner), or for the wolf." He further asked, "What about a lost camel?" The Prophet (ﷺ) said, "It is none of your concern. It has its water-container (reservoir) and its feet, and it will reach water and drink it and eat the trees till its owner finds it}}
\hadithdefcmd{bukhari}{2430}{وَقَالَ اللَّيْثُ حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ ذَكَرَ رَجُلاً مِنْ بَنِي إِسْرَائِيلَ ـ وَسَاقَ الْحَدِيثَ ـ ‏ "‏فَخَرَجَ يَنْظُرُ لَعَلَّ مَرْكَبًا قَدْ جَاءَ بِمَالِهِ، فَإِذَا هُوَ بِالْخَشَبَةِ فَأَخَذَهَا لأَهْلِهِ حَطَبًا، فَلَمَّا نَشَرَهَا وَجَدَ الْمَالَ وَالصَّحِيفَةَ ‏"‏‏.‏\hadithno{2430}\hadithtrans{Narrated 'Abdur-Rahman bin Hurmuz:Abu Hurairah (ra) said, "Allah's Messenger (ﷺ) mentioned an Israeli man." Abu Hurairah then told the whole narration). (At the end of the narration it was mentioned that the creditor) went out to the sea, hoping that a boat might have brought his money. Suddenly he saw a piece of wood and he took it to his house to use as firewood. When he sawed it, he found his money and a letter in it. [See hadith No. 2291 for details]}}
\hadithdefcmd{bukhari}{2431}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ طَلْحَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ مَرَّ النَّبِيُّ صلى الله عليه وسلم بِتَمْرَةٍ فِي الطَّرِيقِ قَالَ ‏ "‏ لَوْلاَ أَنِّي أَخَافُ أَنْ تَكُونَ مِنَ الصَّدَقَةِ لأَكَلْتُهَا ‏"‏‏.‏ وَقَالَ يَحْيَى حَدَّثَنَا سُفْيَانُ حَدَّثَنِي مَنْصُورٌ وَقَالَ زَائِدَةُ عَنْ مَنْصُورٍ عَنْ طَلْحَةَ حَدَّثَنَا أَنَسٌ‏.‏\hadithno{2431}\hadithtrans{Narrated Anas:The Prophet (ﷺ) passed a date fallen on the way and said, "Were I not afraid that it may be from a Sadaqa (charitable gifts), I would have eaten it}}
\hadithdefcmd{bukhari}{2432}{وَحَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنِّي لأَنْقَلِبُ إِلَى أَهْلِي، فَأَجِدُ التَّمْرَةَ سَاقِطَةً عَلَى فِرَاشِي فَأَرْفَعُهَا لآكُلَهَا، ثُمَّ أَخْشَى أَنْ تَكُونَ صَدَقَةً فَأُلْفِيَهَا ‏"‏‏.‏\hadithno{2432}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Sometimes when I return home and find a date fallen on my bed, I pick it up in order to eat it, but I fear that it might be from a Sadaqa, so I throw it}}
\hadithdefcmd{bukhari}{2433}{وَقَالَ أَحْمَدُ بْنُ سَعِيدٍ حَدَّثَنَا رَوْحٌ، حَدَّثَنَا زَكَرِيَّاءُ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يُعْضَدُ عِضَاهُهَا، وَلاَ يُنَفَّرُ صَيْدُهَا، وَلاَ تَحِلُّ لُقَطَتُهَا إِلاَّ لِمُنْشِدٍ، وَلاَ يُخْتَلَى خَلاَهَا ‏"‏‏.‏ فَقَالَ عَبَّاسٌ يَا رَسُولَ اللَّهِ إِلاَّ الإِذْخِرَ‏.‏ فَقَالَ ‏"‏ إِلاَّ الإِذْخِرَ ‏"‏‏.‏\hadithno{2433}\hadithtrans{Narrated Ibn 'Abbas (ra):Allah's Messenger (ﷺ) also said, "It (i.e., Makkah's) thorny bushes should not be uprooted and its game should not be chased, and picking up its fallen things is illegal except by him who makes public announcement about it, and its grass should not be cut." 'Abbas said, "O Allah's Messenger ! Except Idhkhir (a kind of grass)." The Prophet (ﷺ) said, "Except Idhkhir}}
\hadithdefcmd{bukhari}{2434}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ لَمَّا فَتَحَ اللَّهُ عَلَى رَسُولِهِ صلى الله عليه وسلم مَكَّةَ قَامَ فِي النَّاسِ، فَحَمِدَ اللَّهَ، وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ إِنَّ اللَّهَ حَبَسَ عَنْ مَكَّةَ الْفِيلَ، وَسَلَّطَ عَلَيْهَا رَسُولَهُ وَالْمُؤْمِنِينَ، فَإِنَّهَا لاَ تَحِلُّ لأَحَدٍ كَانَ قَبْلِي، وَإِنَّهَا أُحِلَّتْ لِي سَاعَةً مِنْ نَهَارٍ، وَإِنَّهَا لاَ تَحِلُّ لأَحَدٍ بَعْدِي، فَلاَ يُنَفَّرُ صَيْدُهَا وَلاَ يُخْتَلَى شَوْكُهَا، وَلاَ تَحِلُّ سَاقِطَتُهَا إِلاَّ لِمُنْشِدٍ، وَمَنْ قُتِلَ لَهُ قَتِيلٌ فَهْوَ بِخَيْرِ النَّظَرَيْنِ، إِمَّا أَنْ يُفْدَى، وَإِمَّا أَنْ يُقِيدَ ‏"‏‏.‏ فَقَالَ الْعَبَّاسُ إِلاَّ الإِذْخِرَ، فَإِنَّا نَجْعَلُهُ لِقُبُورِنَا وَبُيُوتِنَا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِلاَّ الإِذْخِرَ ‏"‏‏.‏ فَقَامَ أَبُو شَاهٍ ـ رَجُلٌ مِنْ أَهْلِ الْيَمَنِ ـ فَقَالَ اكْتُبُوا لِي يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اكْتُبُوا لأَبِي شَاهٍ ‏"‏‏.‏ قُلْتُ لِلأَوْزَاعِيِّ مَا قَوْلُهُ اكْتُبُوا لِي يَا رَسُولَ اللَّهِ قَالَ هَذِهِ الْخُطْبَةَ الَّتِي سَمِعَهَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{2434}\hadithtrans{Narrated Abu Huraira:When Allah gave victory to His Apostle over the people of Mecca, Allah's Messenger (ﷺ) stood up among the people and after glorifying Allah, said, "Allah has prohibited fighting in Mecca and has given authority to His Apostle and the believers over it, so fighting was illegal for anyone before me, and was made legal for me for a part of a day, and it will not be legal for anyone after me. Its game should not be chased, its thorny bushes should not be uprooted, and picking up its fallen things is not allowed except for one who makes public announcement for it, and he whose relative is murdered has the option either to accept a compensation for it or to retaliate." Al-`Abbas said, "Except Al-Idhkhir, for we use it in our graves and houses." Allah's Messenger (ﷺ) said, "Except Al-Idhkhir." Abu Shah, a Yemenite, stood up and said, "O Allah's Messenger (ﷺ)! Get it written for me." Allah's Messenger (ﷺ) said, "Write it for Abu Shah." (The sub-narrator asked Al-Auza'i): What did he mean by saying, "Get it written, O Allah's Apostle?" He replied, "The speech which he had heard from Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{2435}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحْلُبَنَّ أَحَدٌ مَاشِيَةَ امْرِئٍ بِغَيْرِ إِذْنِهِ، أَيُحِبُّ أَحَدُكُمْ أَنْ تُؤْتَى مَشْرُبَتُهُ فَتُكْسَرَ خِزَانَتُهُ، فَيُنْتَقَلَ طَعَامُهُ فَإِنَّمَا تَخْزُنُ لَهُمْ ضُرُوعُ مَوَاشِيهِمْ أَطْعِمَاتِهِمْ، فَلاَ يَحْلُبَنَّ أَحَدٌ مَاشِيَةَ أَحَدٍ إِلاَّ بِإِذْنِهِ ‏"‏‏.‏\hadithno{2435}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "An animal should not be milked without the permission of its owner. Does any of you like that somebody comes to his store and breaks his container and takes away his food? The udders of the animals are the stores of their owners where their provision is kept, so nobody should milk the animals of somebody else, without the permission of its owner}}
\hadithdefcmd{bukhari}{2436}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ ـ رضى الله عنه ـ أَنَّ رَجُلاً سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ اللُّقَطَةِ قَالَ ‏"‏ عَرِّفْهَا سَنَةً، ثُمَّ اعْرِفْ وِكَاءَهَا وَعِفَاصَهَا، ثُمَّ اسْتَنْفِقْ بِهَا، فَإِنْ جَاءَ رَبُّهَا فَأَدِّهَا إِلَيْهِ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ فَضَالَّةُ الْغَنَمِ قَالَ ‏"‏ خُذْهَا فَإِنَّمَا هِيَ لَكَ أَوْ لأَخِيكَ أَوْ لِلذِّئْبِ ‏"‏‏.‏ قَالَ يَا رَسُولَ اللَّهِ، فَضَالَّةُ الإِبِلِ قَالَ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى احْمَرَّتْ وَجْنَتَاهُ ـ أَوِ احْمَرَّ وَجْهُهُ ـ ثُمَّ قَالَ ‏"‏ مَا لَكَ وَلَهَا، مَعَهَا حِذَاؤُهَا وَسِقَاؤُهَا، حَتَّى يَلْقَاهَا رَبُّهَا ‏"‏‏.‏\hadithno{2436}\hadithtrans{Narrated Zaid bin Khalid Al-Juhani:A man asked Allah's Messenger (ﷺ) about the Luqata. He said, "Make public announcement of it for one year, then remember the description of its container and the string it is tied with, utilize the money, and if its owner comes back after that, give it to him." The people asked, "O Allah's Messenger (ﷺ)! What about a lost sheep?" Allah's Messenger (ﷺ) said, "Take it, for it is for you, for your brother, or for the wolf." The man asked, "O Allah's Messenger (ﷺ)! What about a lost camel?" Allah's Messenger (ﷺ) got angry and his cheeks or face became red, and said, "You have no concern with it as it has its feet, and its watercontainer, till its owner finds it}}
\hadithdefcmd{bukhari}{2437}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، قَالَ سَمِعْتُ سُوَيْدَ بْنَ غَفَلَةَ، قَالَ كُنْتُ مَعَ سَلْمَانَ بْنِ رَبِيعَةَ، وَزَيْدِ بْنِ صُوحَانَ فِي غَزَاةٍ، فَوَجَدْتُ سَوْطًا‏.‏ فَقَالَ لِي أَلْقِهِ‏.‏ قُلْتُ لاَ، وَلَكِنْ إِنْ وَجَدْتُ صَاحِبَهُ، وَإِلاَّ اسْتَمْتَعْتُ بِهِ‏.‏ فَلَمَّا رَجَعْنَا حَجَجْنَا فَمَرَرْتُ بِالْمَدِينَةِ، فَسَأَلْتُ أُبَىَّ بْنَ كَعْبٍ ـ رضى الله عنه ـ فَقَالَ وَجَدْتُ صُرَّةً عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فِيهَا مِائَةُ دِينَارٍ، فَأَتَيْتُ بِهَا النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ عَرِّفْهَا حَوْلاً ‏"‏‏.‏ فَعَرَّفْتُهَا حَوْلاً ثُمَّ أَتَيْتُ، فَقَالَ ‏"‏ عَرِّفْهَا حَوْلاً ‏"‏‏.‏ فَعَرَّفْتُهَا حَوْلاً ثُمَّ أَتَيْتُهُ، فَقَالَ ‏"‏ عَرِّفْهَا حَوْلاً ‏"‏‏.‏ فَعَرَّفْتُهَا حَوْلاً ثُمَّ أَتَيْتُهُ الرَّابِعَةَ فَقَالَ ‏"‏ اعْرِفْ عِدَّتَهَا وَوِكَاءَهَا وَوِعَاءَهَا، فَإِنْ جَاءَ صَاحِبُهَا وَإِلاَّ اسْتَمْتِعْ بِهَا ‏"‏‏.‏\hadithno{2437}\hadithtrans{Narrated Suwaid bin Ghafala:While I was in the company of Salman bin Rabi`a and Suhan, in one of the holy battles, I found a whip. One of them told me to drop it but I refused to do so and said that I would give it to its owner if I found him, otherwise I would utilize it. On our return we performed Hajj and on passing by Medina, I asked Ubai bin Ka`b about it. He said, "I found a bag containing a hundred Dinars in the lifetime of the Prophet (ﷺ) and took it to the Prophet (ﷺ) who said to me, 'Make public announcement about it for one year.' So, I announced it for one year and went to the Prophet (ﷺ) who said, 'Announce it publicly for another year.' So, I announced it for another year. I went to him again and he said, "Announce for another year." So I announced for still another year. I went to the Prophet (ﷺ) for the fourth time, and he said, 'Remember the amount of money, the description of its container and the string it is tied with, and if the owner comes, give it to him; otherwise, utilize it}}
\hadithdefcmd{bukhari}{2437p2}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، عَنْ سَلَمَةَ، بِهَذَا قَالَ فَلَقِيتُهُ بَعْدُ بِمَكَّةَ، فَقَالَ لاَ أَدْرِي أَثَلاَثَةَ أَحْوَالٍ أَوْ حَوْلاً وَاحِدًا‏.‏\hadithno{2437.2}\hadithtrans{Narrated Salama:the above narration (Hadith 616) from Ubai bin Ka`b: adding, "I met the sub-narrator at Mecca later on, but he did not remember whether Ka`b had announced what he had found one year or three years}}
\hadithdefcmd{bukhari}{2438}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ رَبِيعَةَ، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ خَالِدٍ ـ رضى الله عنه ـ أَنَّ أَعْرَابِيًّا، سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنِ اللُّقَطَةِ قَالَ ‏"‏ عَرِّفْهَا سَنَةً، فَإِنْ جَاءَ أَحَدٌ يُخْبِرُكَ بِعِفَاصِهَا وَوِكَائِهَا، وَإِلاَّ فَاسْتَنْفِقْ بِهَا ‏"‏‏.‏ وَسَأَلَهُ عَنْ ضَالَّةِ الإِبِلِ فَتَمَعَّرَ وَجْهُهُ، قَالَ ‏"‏ مَا لَكَ وَلَهَا مَعَهَا سِقَاؤُهَا وَحِذَاؤُهَا، تَرِدُ الْمَاءَ وَتَأْكُلُ الشَّجَرَ، دَعْهَا حَتَّى يَجِدَهَا رَبُّهَا ‏"‏‏.‏ وَسَأَلَهُ عَنْ ضَالَّةِ الْغَنَمِ‏.‏ فَقَالَ ‏"‏ هِيَ لَكَ أَوْ لأَخِيكَ، أَوْ لِلذِّئْبِ ‏"‏‏.‏\hadithno{2438}\hadithtrans{Narrated Zaid bin Khalid:A bedouin asked the Prophet (ﷺ) about the Luqata. The Prophet (ﷺ) said, "Make public announcement about it for one year and if then somebody comes and describes the container of the Luqata and the string it was tied with, (give it to him); otherwise, spend it." He then asked the Prophet (ﷺ) about a lost camel. The face of the Prophet (ﷺ) became red and he said, "You have no concern with it as it has its water reservoir and feet and it will reach water and drink and eat trees. Leave it till its owner finds it." He then asked the Prophet (ﷺ) about a lost sheep. The Prophet (ﷺ) said, "It is for you, for your brother, or for the wolf}}
\hadithdefcmd{bukhari}{2439}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا النَّضْرُ، أَخْبَرَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، قَالَ أَخْبَرَنِي الْبَرَاءُ، عَنْ أَبِي بَكْرٍ ـ رضى الله عنهما ـ‏.‏ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، عَنْ أَبِي بَكْرٍ ـ رضى الله عنهما ـ قَالَ انْطَلَقْتُ، فَإِذَا أَنَا بِرَاعِي غَنَمٍ يَسُوقُ غَنَمَهُ فَقُلْتُ لِمَنْ أَنْتَ قَالَ لِرَجُلٍ مِنْ قُرَيْشٍ‏.‏ فَسَمَّاهُ فَعَرَفْتُهُ‏.‏ فَقُلْتُ هَلْ فِي غَنَمِكَ مِنْ لَبَنٍ فَقَالَ نَعَمْ‏.‏ فَقُلْتُ هَلْ أَنْتَ حَالِبٌ لِي قَالَ نَعَمْ‏.‏ فَأَمَرْتُهُ فَاعْتَقَلَ شَاةً مِنْ غَنَمِهِ، ثُمَّ أَمَرْتُهُ أَنْ يَنْفُضَ ضَرْعَهَا مِنَ الْغُبَارِ، ثُمَّ أَمَرْتُهُ أَنْ يَنْفُضَ كَفَّيْهِ، فَقَالَ هَكَذَا ـ ضَرَبَ إِحْدَى كَفَّيْهِ بِالأُخْرَى ـ فَحَلَبَ كُثْبَةً مِنْ لَبَنٍ وَقَدْ جَعَلْتُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِدَاوَةً عَلَى فَمِهَا خِرْقَةٌ، فَصَبَبْتُ عَلَى اللَّبَنِ، حَتَّى بَرَدَ أَسْفَلُهُ، فَانْتَهَيْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقُلْتُ اشْرَبْ يَا رَسُولَ اللَّهِ‏.‏ فَشَرِبَ حَتَّى رَضِيتُ‏.‏\hadithno{2439}\hadithtrans{Narrated Abu Bakr:While I was on my way, all of a sudden I saw a shepherd driving his sheep, I asked him whose servant he was. He replied that he was the servant of a man from Quraish, and then he mentioned his name and I recognized him. I asked, "Do your sheep have some milk?" He replied in the affirmative. I said, "Are you going to milk for me?" He replied in the affirmative. I ordered him and he tied the legs of one of the sheep. Then I told him to clean the udder (teats) of dust and to remove dust off his hands. He removed the dust off his hands by clapping his hands. He then milked a little milk. I put the milk for Allah's Messenger (ﷺ) in a pot and closed its mouth with a piece of cloth and poured water over it till it became cold. I took it to the Prophet (ﷺ) and said, "Drink, O Allah's Messenger (ﷺ)!" He drank it till I was pleased}}
