% Auto-generated chapter 55 for malik
% Hadiths in this chapter: 3

\hadithdefcmd{malik}{1808}{حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ كُنَّا إِذَا بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ يَقُولُ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فِيمَا اسْتَطَعْتُمْ ‏"‏ ‏.‏\hadithno{1808}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abdullah ibn Dinar that Abdullah ibn Umar said, "When we took an oath of allegiance with him to hear and obey, the Messenger of Allah, may Allah bless him and grant him peace, said to us, 'In what you are able}}
\hadithdefcmd{malik}{1809}{وَحَدَّثَنِي مَالِكٌ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ أُمَيْمَةَ بِنْتِ رُقَيْقَةَ، أَنَّهَا قَالَتْ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي نِسْوَةٍ بَايَعْنَهُ عَلَى الإِسْلاَمِ فَقُلْنَ يَا رَسُولَ اللَّهِ نُبَايِعُكَ عَلَى أَنْ لاَ نُشْرِكَ بِاللَّهِ شَيْئًا وَلاَ نَسْرِقَ وَلاَ نَزْنِيَ وَلاَ نَقْتُلَ أَوْلاَدَنَا وَلاَ نَأْتِيَ بِبُهْتَانٍ نَفْتَرِيهِ بَيْنَ أَيْدِينَا وَأَرْجُلِنَا وَلاَ نَعْصِيَكَ فِي مَعْرُوفٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فِيمَا اسْتَطَعْتُنَّ وَأَطَقْتُنَّ ‏"‏ ‏.‏ قَالَتْ فَقُلْنَ اللَّهُ وَرَسُولُهُ أَرْحَمُ بِنَا مِنْ أَنْفُسِنَا هَلُمَّ نُبَايِعْكَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي لاَ أُصَافِحُ النِّسَاءَ إِنَّمَا قَوْلِي لِمِائَةِ امْرَأَةٍ كَقَوْلِي لاِمْرَأَةٍ وَاحِدَةٍ أَوْ مِثْلِ قَوْلِي لاِمْرَأَةٍ وَاحِدَةٍ ‏"‏ ‏.‏\hadithno{1809}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Muhammad ibn al-Munkadir that Umayma bint Ruqayqa said, "I went to the Messenger of Allah, may Allah bless him and grant him peace, with the women who took an oath of allegiance with him in Islam. They said, 'Messenger of Allah! We take a pledge with you not to associate anything with Allah, not to steal, not to commit adultery, not to kill our children, nor to produce any lie that we have devised between our hands and feet, and not to disobey you in what is known.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'In what you can do and are able.' " Umayma continued, "They said, 'Allah and His Messenger are more merciful to us than ourselves. Come, let us give our hands to you, Messenger of Allah!' The Messenger of Allah, may Allah bless him and grant him peace, said, 'I do not shake hands with women. My word to a hundred women is like my word to one woman}}
\hadithdefcmd{malik}{1810}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَتَبَ إِلَى عَبْدِ الْمَلِكِ بْنِ مَرْوَانَ يُبَايِعُهُ فَكَتَبَ إِلَيْهِ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏.‏ أَمَّا بَعْدُ لِعَبْدِ اللَّهِ عَبْدِ الْمَلِكِ أَمِيرِ الْمُؤْمِنِينَ سَلاَمٌ عَلَيْكَ فَإِنِّي أَحْمَدُ إِلَيْكَ اللَّهَ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ وَأُقِرُّ لَكَ بِالسَّمْعِ وَالطَّاعَةِ عَلَى سُنَّةِ اللَّهِ وَسُنَّةِ رَسُولِهِ فِيمَا اسْتَطَعْتُ ‏.‏\hadithno{1810}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Abdullah ibn Dinar that Abdullah ibn Umar wrote to Abd al-Malik ibn Marwan, making an oath of allegiance. He wrote, "In the name of Allah, the Merciful, the Compassionate. To the slave of Allah, Abd al-Malik, the amir al-muminin, Peace be upon you. I praise Allah to you. There is no god but Him. I acknowledge your right to my hearing and my obedience according to the sunna of Allah and the sunna of His Prophet, in what I am able}}
