% Auto-generated chapter 48 for malik
% Hadiths in this chapter: 20

\hadithdefcmd{malik}{1651}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ الأَنْصَارِيِّ، أَنَّهُ قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ بَنِي أَنْمَارٍ ‏.‏ قَالَ جَابِرٌ فَبَيْنَا أَنَا نَازِلٌ تَحْتَ شَجَرَةٍ إِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ هَلُمَّ إِلَى الظِّلِّ ‏.‏ قَالَ فَنَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُمْتُ إِلَى غِرَارَةٍ لَنَا فَالْتَمَسْتُ فِيهَا شَيْئًا فَوَجَدْتُ فِيهَا جِرْوَ قِثَّاءٍ فَكَسَرْتُهُ ثُمَّ قَرَّبْتُهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مِنْ أَيْنَ لَكُمْ هَذَا ‏"‏ ‏.‏ قَالَ فَقُلْتُ خَرَجْنَا بِهِ يَا رَسُولَ اللَّهِ مِنَ الْمَدِينَةِ ‏.‏ قَالَ جَابِرٌ وَعِنْدَنَا صَاحِبٌ لَنَا نُجَهِّزُهُ يَذْهَبُ يَرْعَى ظَهْرَنَا - قَالَ - فَجَهَّزْتُهُ ثُمَّ أَدْبَرَ يَذْهَبُ فِي الظَّهْرِ وَعَلَيْهِ بُرْدَانِ لَهُ قَدْ خَلَقَا - قَالَ - فَنَظَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَيْهِ فَقَالَ ‏"‏ أَمَا لَهُ ثَوْبَانِ غَيْرُ هَذَيْنِ ‏"‏ ‏.‏ فَقُلْتُ بَلَى يَا رَسُولَ اللَّهِ لَهُ ثَوْبَانِ فِي الْعَيْبَةِ كَسَوْتُهُ إِيَّاهُمَا ‏.‏ قَالَ ‏"‏ فَادْعُهُ فَمُرْهُ فَلْيَلْبَسْهُمَا ‏"‏ ‏.‏ قَالَ فَدَعَوْتُهُ فَلَبِسَهُمَا ثُمَّ وَلَّى يَذْهَبُ ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا لَهُ ضَرَبَ اللَّهُ عُنُقَهُ أَلَيْسَ هَذَا خَيْرًا لَهُ ‏"‏ ‏.‏ قَالَ فَسَمِعَهُ الرَّجُلُ فَقَالَ يَا رَسُولَ اللَّهِ فِي سَبِيلِ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ فَقُتِلَ الرَّجُلُ فِي سَبِيلِ اللَّهِ ‏.‏\hadithno{1651}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that Jabir ibn Abdullah al-Ansari said, "We went out with the Messenger of Allah, may Allah bless him and grant him peace, in the raid on the Banu Ammar tribe." Jabir said, "I was resting under a tree when the Messenger of Allah, may Allah bless him and grant him peace, came. I said, 'Messenger of Allah; come to the shade.' So the Messenger of Allah, may Allah bless him and grant him peace, sat down, and I stood up and went to a sack of ours. I looked in it for something and found a small cucumber and broke it. Then I brought it to the Messenger of Allah, may Allah bless him and grant him peace. He said, 'From where did you get this?' I said, 'We brought it from Madina, Messenger of Allah.' " Jabir continued, "We had a friend of ours with us whom we used to equip to go out to guard our mounts. I gave him what was necessary and then he turned about to go to the mounts and he was wearing two threadbare cloaks of his. The Messenger of Allah, may Allah bless him and grant him peace, looked at him and said, 'Does he have two garments other than these?' I said, 'Yes, Messenger of Allah. He has two garments in the bag.' I gave them to him. He said, 'Let him go and put them on.' I let him go to put them on. As he turned to go, the Messenger of Allah, may Allah bless him and grant him peace, exclaimed, 'May Allah strike his neck. Isn't that better for him?' He said (taking him literally), 'Messenger of Allah, in the way of Allah.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'In the way of Allah.' " Jabir added, "The man was killed in the way of Allah}}
\hadithdefcmd{malik}{1652}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ إِنِّي لأُحِبُّ أَنْ أَنْظُرَ، إِلَى الْقَارِئِ أَبْيَضَ الثِّيَابِ ‏.‏\hadithno{1652}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he heard that Umar ibn al- Khattab said, "I love to look at a Qur'an reader in white garments}}
\hadithdefcmd{malik}{1653}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَيُّوبَ بْنِ أَبِي تَمِيمَةَ، عَنِ ابْنِ سِيرِينَ، قَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ إِذَا أَوْسَعَ اللَّهُ عَلَيْكُمْ فَأَوْسِعُوا عَلَى أَنْفُسِكُمْ جَمَعَ رَجُلٌ عَلَيْهِ ثِيَابَهُ ‏.‏\hadithno{1653}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ayyub ibn Abi Tamim that Ibn Sirin said, ''Umar ibn al-Khattab said, 'Allah has been generous to you, so be generous to yourselves. Let a man wear a combination of his garments}}
\hadithdefcmd{malik}{1654}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَلْبَسُ الثَّوْبَ الْمَصْبُوغَ بِالْمِشْقِ وَالْمَصْبُوغَ بِالزَّعْفَرَانِ ‏.‏\hadithno{1654}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar wore garments dyed with red earth and dyed with saffron}}
\hadithdefcmd{malik}{1655}{قَالَ يَحْيَى وَسَمِعْتُ مَالِكًا، يَقُولُ وَأَنَا أَكْرَهُ، أَنْ يَلْبَسَ الْغِلْمَانُ، شَيْئًا مِنَ الذَّهَبِ لأَنَّهُ بَلَغَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ تَخَتُّمِ الذَّهَبِ فَأَنَا أَكْرَهُهُ لِلرِّجَالِ الْكَبِيرِ مِنْهُمْ وَالصَّغِيرِ ‏.‏ قَالَ يَحْيَى وَسَمِعْتُ مَالِكًا يَقُولُ فِي الْمَلاَحِفِ الْمُعَصْفَرَةِ فِي الْبُيُوتِ لِلرِّجَالِ وَفِي الأَفْنِيَةِ قَالَ لاَ أَعْلَمُ مِنْ ذَلِكَ شَيْئًا حَرَامًا وَغَيْرُ ذَلِكَ مِنَ اللِّبَاسِ أَحَبُّ إِلَىَّ ‏.‏\hadithno{1655}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya said that he heard Malik say, "I disapprove of youths wearing any gold because I heard that the Messenger of Allah, may Allah bless him and grant him peace, forbade wearing gold rings, and I disapprove of it for males old or young." Yahya said, "I heard Malik say about men wearing wraps dyed with safflower in their houses and courtyards, 'I do not know that any of that is haram but I prefer other garments than that}}
\hadithdefcmd{malik}{1656}{وَحَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا كَسَتْ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ مِطْرَفَ خَزٍّ كَانَتْ عَائِشَةُ تَلْبَسُهُ ‏.‏\hadithno{1656}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Hisham ibn Urwa from his father that A'isha the wife of the Prophet, may Allah bless him and grant him peace, dressed Abdullah ibn az-Zubayr in a shawl of silk which A'isha used to wear}}
\hadithdefcmd{malik}{1657}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَلْقَمَةَ بْنِ أَبِي عَلْقَمَةَ، عَنْ أُمِّهِ، أَنَّهَا قَالَتْ دَخَلَتْ حَفْصَةُ بِنْتُ عَبْدِ الرَّحْمَنِ عَلَى عَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَعَلَى حَفْصَةَ خِمَارٌ رَقِيقٌ فَشَقَّتْهُ عَائِشَةُ وَكَسَتْهَا خِمَارًا كَثِيفًا ‏.‏\hadithno{1657}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Yahya related to me from Malik from Alqama ibn Abi Alqama that his mother said, "Hafsa bint Abd ar-Rahman visited A'isha, the wife of the Prophet, may Allah bless him and grant him peace, and Hafsa was wearing a long thin head scarf. A'isha tore it in two and made a thick one for her}}
\hadithdefcmd{malik}{1658}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُسْلِمِ بْنِ أَبِي مَرْيَمَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ نِسَاءٌ كَاسِيَاتٌ عَارِيَاتٌ مَائِلاَتٌ مُمِيلاَتٌ لاَ يَدْخُلْنَ الْجَنَّةَ وَلاَ يَجِدْنَ رِيحَهَا وَرِيحُهَا يُوجَدُ مِنْ مَسِيرَةِ خَمْسِمِائَةِ سَنَةٍ ‏.‏\hadithno{1658}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Muslim ibn Abi Maryam from Abu Salih that Abu Hurayra said, "Women who are naked even though they are wearing clothes, go astray and make others go astray, and they will not enter the Garden and they will not find its scent, and its scent is experienced from as far as the distance travelled in five hundred years}}
\hadithdefcmd{malik}{1659}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ مِنَ اللَّيْلِ فَنَظَرَ فِي أُفُقِ السَّمَاءِ فَقَالَ ‏ "‏ مَاذَا فُتِحَ اللَّيْلَةَ مِنَ الْخَزَائِنِ وَمَاذَا وَقَعَ مِنَ الْفِتَنِ كَمْ مِنْ كَاسِيَةٍ فِي الدُّنْيَا عَارِيَةٌ يَوْمَ الْقِيَامَةِ أَيْقِظُوا صَوَاحِبَ الْحُجَرِ ‏"‏ ‏.‏\hadithno{1659}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Ibn Shihab that the Messenger of Allah, may Allah bless him and grant him peace, stood up in the night and looked at the horizon of the sky. He said, "What treasures has the night opened? What trials have occurred? How many are dressed in this world and will be naked on the Day of Rising. Warn the women in their rooms}}
\hadithdefcmd{malik}{1660}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الَّذِي يَجُرُّ ثَوْبَهُ خُيَلاَءَ لاَ يَنْظُرُ اللَّهُ إِلَيْهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{1660}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "A person who drags his garment in arrogance will not be looked at by Allah on the Day of Rising}}
\hadithdefcmd{malik}{1661}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَنْظُرُ اللَّهُ تَبَارَكَ وَتَعَالَى يَوْمَ الْقِيَامَةِ إِلَى مَنْ يَجُرُّ إِزَارَهُ بَطَرًا ‏"‏ ‏.‏\hadithno{1661}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "On the Day of Rising, Allah the Blessed, the Exalted, will not look at a person who drags his lower garment in arrogance}}
\hadithdefcmd{malik}{1662}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، وَعَبْدِ اللَّهِ بْنِ دِينَارٍ، وَزَيْدِ بْنِ أَسْلَمَ، كُلُّهُمْ يُخْبِرُهُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَنْظُرُ اللَّهُ يَوْمَ الْقِيَامَةِ إِلَى مَنْ يَجُرُّ ثَوْبَهُ خُيَلاَءَ ‏"‏ ‏.‏\hadithno{1662}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi and Abdullah ibn Dinar and Zayd ibn Aslam that all of them informed him from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "On the Day of Rising, Allah will not look at a person who drags his garment in arrogance}}
\hadithdefcmd{malik}{1663}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، أَنَّهُ قَالَ سَأَلْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ عَنِ الإِزَارِ، فَقَالَ أَنَا أُخْبِرُكَ بِعِلْمٍ، سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِزْرَةُ الْمُؤْمِنِ إِلَى أَنْصَافِ سَاقَيْهِ لاَ جُنَاحَ عَلَيْهِ فِيمَا بَيْنَهُ وَبَيْنَ الْكَعْبَيْنِ مَا أَسْفَلَ مِنْ ذَلِكَ فَفِي النَّارِ مَا أَسْفَلَ مِنْ ذَلِكَ فَفِي النَّارِ لاَ يَنْظُرُ اللَّهُ يَوْمَ الْقِيَامَةِ إِلَى مَنْ جَرَّ إِزَارَهُ بَطَرًا ‏"‏ ‏.‏\hadithno{1663}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from al Ala ibn Abd ar-Rahman that his father said, "I asked Abu Said al-Khudri about the lower garment. He said that he would inform me with knowledge and that he had heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'The lower garment of the mumin should reach to the middle of his calves. There is no harm in what is between that and the ankles. What is lower than that is in the Fire. What is lower than that is in the Fire. On the Day of Rising, Allah will not look at a person who trails his lower garment in arrogance}}
\hadithdefcmd{malik}{1664}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي بَكْرِ بْنِ نَافِعٍ، عَنْ أَبِيهِ، نَافِعٍ مَوْلَى ابْنِ عُمَرَ عَنْ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ، أَنَّهَا أَخْبَرَتْهُ عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ حِينَ ذُكِرَ الإِزَارُ فَالْمَرْأَةُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ تُرْخِيهِ شِبْرًا ‏"‏ ‏.‏ قَالَتْ أُمُّ سَلَمَةَ إِذًا يَنْكَشِفُ عَنْهَا ‏.‏ قَالَ ‏"‏ فَذِرَاعًا لاَ تَزِيدُ عَلَيْهِ ‏"‏ ‏.‏\hadithno{1664}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu Bakr ibn Nafi from his father Nafi, the mawla of Ibn Umar that Safiyya bint Abi Ubayd informed him that Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, said that when the lower garment of women was mentioned to the Messenger of Allah, he said, "She lets it down a handspan." Umm Salama said, "If it leaves her uncovered?" He said, "Then the length of a forearm and let her not increase it}}
\hadithdefcmd{malik}{1665}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمْشِيَنَّ أَحَدُكُمْ فِي نَعْلٍ وَاحِدَةٍ لِيُنْعَلْهُمَا جَمِيعًا أَوْ لِيُحْفِهِمَا جَمِيعًا ‏"‏ ‏.‏\hadithno{1665}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Do not wear one sandal. Wear both of them or go with both feet bare}}
\hadithdefcmd{malik}{1666}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا انْتَعَلَ أَحَدُكُمْ فَلْيَبْدَأْ بِالْيَمِينِ وَإِذَا نَزَعَ فَلْيَبْدَأْ بِالشِّمَالِ وَلْتَكُنِ الْيُمْنَى أَوَّلَهُمَا تُنْعَلُ وَآخِرَهُمَا تُنْزَعُ ‏"‏ ‏.‏\hadithno{1666}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "When you put on sandals, begin with the right foot. When you take them off, begin with the left foot. The right foot is the first to be put in the sandal and the last to be taken out}}
\hadithdefcmd{malik}{1667}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَمِّهِ أَبِي سُهَيْلِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، عَنْ كَعْبِ الأَحْبَارِ، أَنَّ رَجُلاً، نَزَعَ نَعْلَيْهِ فَقَالَ لِمَ خَلَعْتَ نَعْلَيْكَ لَعَلَّكَ تَأَوَّلْتَ هَذِهِ الآيَةَ ‏\{‏فَاخْلَعْ نَعْلَيْكَ إِنَّكَ بِالْوَادِي الْمُقَدَّسِ طُوًى‏\}‏ قَالَ ثُمَّ قَالَ كَعْبٌ لِلرَّجُلِ أَتَدْرِي مَا كَانَتْ نَعْلاَ مُوسَى قَالَ مَالِكٌ لاَ أَدْرِي مَا أَجَابَهُ الرَّجُلُ فَقَالَ كَعْبٌ كَانَتَا مِنْ جِلْدِ حِمَارٍ مَيِّتٍ ‏.‏\hadithno{1667}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from his paternal uncle Abu Suhayl ibn Malik from his father that Kab al-Ahbar said to a man who took off his sandals, "Why have you taken off your sandals? Perhaps you have interpreted this ayat, 'Remove your sandals. You are in the pure valley of Tuwa?' (Sura 20 ayat 12) Do you know what the sandals of Musa were?" Malik (the father of Abu Suhayl) said, "I do not know what the man answered." Kab said, "They were made from the skin of a dead donkey}}
\hadithdefcmd{malik}{1668}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ لِبْسَتَيْنِ وَعَنْ بَيْعَتَيْنِ عَنِ الْمُلاَمَسَةِ وَعَنِ الْمُنَابَذَةِ وَعَنْ أَنْ يَحْتَبِيَ الرَّجُلُ فِي ثَوْبٍ وَاحِدٍ لَيْسَ عَلَى فَرْجِهِ مِنْهُ شَىْءٌ وَعَنْ أَنْ يَشْتَمِلَ الرَّجُلُ بِالثَّوْبِ الْوَاحِدِ عَلَى أَحَدِ شِقَّيْهِ ‏.‏\hadithno{1668}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj that Abu Hurayra said, "The Messenger of Allah, may Allah bless him and grant him peace, forbade two sales. Mulamasa, in which a man is obliged to buy whatever he touches without any choice in the matter, and munabadha, in which two men throw their garment to each other without either seeing the other's garment. He also forbade two ways of dressing. One in which a man sits with his legs drawn up to his chest wrapped in one garment that does not cover his genitals, and the other in which a man wraps a single garment over one arm and shoulder restricting them}}
\hadithdefcmd{malik}{1669}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، رَأَى حُلَّةً سِيَرَاءَ تُبَاعُ عِنْدَ بَابِ الْمَسْجِدِ فَقَالَ يَا رَسُولَ اللَّهِ لَوِ اشْتَرَيْتَ هَذِهِ الْحُلَّةَ فَلَبِسْتَهَا يَوْمَ الْجُمُعَةِ وَلِلْوَفْدِ إِذَا قَدِمُوا عَلَيْكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا يَلْبَسُ هَذِهِ مَنْ لاَ خَلاَقَ لَهُ فِي الآخِرَةِ ‏"‏ ‏.‏ ثُمَّ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْهَا حُلَلٌ فَأَعْطَى عُمَرَ بْنَ الْخَطَّابِ مِنْهَا حُلَّةً فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ أَكَسَوْتَنِيهَا وَقَدْ قُلْتَ فِي حُلَّةِ عُطَارِدٍ مَا قُلْتَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَمْ أَكْسُكَهَا لِتَلْبَسَهَا ‏"‏ ‏.‏ فَكَسَاهَا عُمَرُ أَخًا لَهُ مُشْرِكًا بِمَكَّةَ ‏.‏\hadithno{1669}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that Umar ibn al-Khattab saw a silk robe at the door of the mosque. He said, "Messenger of Allah, would you buy this robe and wear it on jumua and when envoys come to you?" The Messenger of Allah, may Allah bless him and grant him peace, said, "Only a person who has no portion in the next world wears this." Then the Messenger of Allah, may Allah bless him and grant him peace, was brought some robes of the same material and gave Umar ibn al-Khattab one of the robes. Umar said, "Messenger of Allah, do you clothe me in it when you said what you said about the robe of Utarid?" The Messenger of Allah, may Allah bless him and grant him peace, said, "I did not give it to you to wear." Umar gave it to a brother of his in Makka who was still an idolater}}
\hadithdefcmd{malik}{1670}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ قَالَ قَالَ أَنَسُ بْنُ مَالِكٍ رَأَيْتُ عُمَرَ بْنَ الْخَطَّابِ وَهُوَ يَوْمَئِذٍ أَمِيرُ الْمَدِينَةِ وَقَدْ رَقَعَ بَيْنَ كَتِفَيْهِ بِرُقَعٍ ثَلاَثٍ لَبَّدَ بَعْضَهَا فَوْقَ بَعْضٍ ‏.‏\hadithno{1670}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Ishaq ibn Abdullah ibn Abi Talha said, "Anas ibn Malik said, 'I saw Umar ibn al-Khattab when he was the amir of Madina. Three patches were sewn between his shoulders, one patched over the other}}
