% Auto-generated chapter 35 for ibnmajah
% Hadiths in this chapter: 34

\hadithdefcmd{ibnmajah}{3893}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، حَدَّثَنِي إِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الرُّؤْيَا الْحَسَنَةُ مِنَ الرَّجُلِ الصَّالِحِ جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{3893}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“A good dream from a righteous man is one of the forty-six parts of prophecy.”}}
\hadithdefcmd{ibnmajah}{3894}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ رُؤْيَا الْمُؤْمِنِ جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{3894}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“The dream of a believer is one of the forty-six parts of prophecy.”}}
\hadithdefcmd{ibnmajah}{3895}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَنْبَأَنَا شَيْبَانُ، عَنْ فِرَاسٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ رُؤْيَا الرَّجُلِ الْمُسْلِمِ الصَّالِحِ جُزْءٌ مِنْ سَبْعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{3895}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Prophet (ﷺ) said:“The dream of a righteous Muslim man is one of the seventy parts of prophecy.”}}
\hadithdefcmd{ibnmajah}{3896}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ الْحَمَّالُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، عَنْ أَبِيهِ، عَنْ سِبَاعِ بْنِ ثَابِتٍ، عَنْ أُمِّ كُرْزٍ الْكَعْبِيَّةِ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ ذَهَبَتِ النُّبُوَّةُ وَبَقِيَتِ الْمُبَشِّرَاتُ ‏"‏ ‏.‏\hadithno{3896}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Umm Kurz Al-Ka’biyyah said:“I heard the Messenger of Allah (ﷺ) say: ‘Prophecy is gone, but good dreams remain.’”}}
\hadithdefcmd{ibnmajah}{3897}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الرُّؤْيَا الصَّالِحَةُ جُزْءٌ مِنْ سَبْعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{3897}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) said: ‘A righteous dream is one of the seventy parts of prophecy.’”}}
\hadithdefcmd{ibnmajah}{3898}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ عَلِيِّ بْنِ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ قَوْلِ اللَّهِ سُبْحَانَهُ ‏\{لَهُمُ الْبُشْرَى فِي الْحَيَاةِ الدُّنْيَا وَفِي الآخِرَةِ\}‏ ‏.‏ قَالَ ‏"‏ هِيَ الرُّؤْيَا الصَّالِحَةُ يَرَاهَا الْمُسْلِمُ أَوْ تُرَى لَهُ ‏"‏ ‏.‏\hadithno{3898}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ubadah bin Samit said:“I asked the Messenger of Allah (ﷺ) the about the Saying of Allah, Glorious is He: ‘For them are glad tidings, in the life of the present world, and in the Hereafter.”[10:64] He said: ‘Those are good dreams that a Muslim sees or are seen about him.’”}}
\hadithdefcmd{ibnmajah}{3899}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ الأَيْلِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ سُلَيْمَانَ بْنِ سُحَيْمٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ مَعْبَدِ بْنِ عَبَّاسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَشَفَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ السِّتَارَةَ فِي مَرَضِهِ وَالنَّاسُ صُفُوفٌ خَلْفَ أَبِي بَكْرٍ فَقَالَ ‏ "‏ أَيُّهَا النَّاسُ إِنَّهُ لَمْ يَبْقَ مِنْ مُبَشِّرَاتِ النُّبُوَّةِ إِلاَّ الرُّؤْيَا الصَّالِحَةُ يَرَاهَا الْمُسْلِمُ أَوْ تُرَى لَهُ ‏"‏ ‏.‏\hadithno{3899}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) drew aside the curtain when he was sick, and the rows (of worshippers) were behind Abu Bakr. He said: ‘O people, nothing of the glad tidings of prophecy is left except a good dream that a Muslim sees or is seen about him.’”}}
\hadithdefcmd{ibnmajah}{3900}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ رَآنِي فِي الْمَنَامِ فَقَدْ رَآنِي فِي الْيَقَظَةِ فَإِنَّ الشَّيْطَانَ لاَ يَتَمَثَّلُ عَلَى صُورَتِي ‏"‏ ‏.‏\hadithno{3900}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah that the Prophet (ﷺ) said:“Whoever sees me in a dream, has seen me in reality, for Satan cannot appear in my form.”}}
\hadithdefcmd{ibnmajah}{3901}{حَدَّثَنَا أَبُو مَرْوَانَ الْعُثْمَانِيُّ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ رَآنِي فِي الْمَنَامِ فَقَدْ رَآنِي فَإِنَّ الشَّيْطَانَ لاَ يَتَمَثَّلُ بِي ‏"‏ ‏.‏\hadithno{3901}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever sees me in a dream has (really) seen me, for Satan cannot appear in my form.”}}
\hadithdefcmd{ibnmajah}{3902}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ مَنْ رَآنِي فِي الْمَنَامِ فَقَدْ رَآنِي إِنَّهُ لاَ يَنْبَغِي لِلشَّيْطَانِ أَنْ يَتَمَثَّلَ فِي صُورَتِي ‏"‏ ‏.‏\hadithno{3902}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“Whoever sees me in a dream has (really) seen me, for Satan cannot appear in my form.”}}
\hadithdefcmd{ibnmajah}{3903}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا بَكْرُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا عِيسَى بْنُ الْمُخْتَارِ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ رَآنِي فِي الْمَنَامِ فَقَدْ رَآنِي فَإِنَّ الشَّيْطَانَ لاَ يَتَمَثَّلُ بِي ‏"‏ ‏.‏\hadithno{3903}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa’eed that the Prophet (ﷺ) said:“Whoever sees me in a dream has (really) seen me, for Satan cannot imitate me.”}}
\hadithdefcmd{ibnmajah}{3904}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ الدِّمَشْقِيُّ، حَدَّثَنَا سَعْدَانُ بْنُ يَحْيَى بْنِ صَالِحٍ اللَّخْمِيُّ، حَدَّثَنَا صَدَقَةُ بْنُ أَبِي عِمْرَانَ، عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ رَآنِي فِي الْمَنَامِ فَكَأَنَّمَا رَآنِي فِي الْيَقَظَةِ إِنَّ الشَّيْطَانَ لاَ يَسْتَطِيعُ أَنْ يَتَمَثَّلَ بِي ‏"‏ ‏.‏\hadithno{3904}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Awn bin Abu Juhaifah, from his father, that the Messenger of Allah (ﷺ) said:“Whoever sees me in a dream, it is as if he has seen me when he is awake, for Satan is not able to resemble me.”}}
\hadithdefcmd{ibnmajah}{3905}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ أَبُو عَوَانَةَ حَدَّثَنَا عَنْ جَابِرٍ، عَنْ عَمَّارٍ، - هُوَ الدُّهْنِيُّ - عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ رَآنِي فِي الْمَنَامِ فَقَدْ رَآنِي فَإِنَّ الشَّيْطَانَ لاَ يَتَمَثَّلُ بِي ‏"‏ ‏.‏\hadithno{3905}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“Whoever sees me in a dream has (really) sees me, for Satan cannot imitate me.”}}
\hadithdefcmd{ibnmajah}{3906}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هَوْذَةُ بْنُ خَلِيفَةَ، حَدَّثَنَا عَوْفٌ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الرُّؤْيَا ثَلاَثٌ فَبُشْرَى مِنَ اللَّهِ وَحَدِيثُ النَّفْسِ وَتَخْوِيفٌ مِنَ الشَّيْطَانِ فَإِذَا رَأَى أَحَدُكُمْ رُؤْيَا تُعْجِبُهُ فَلْيَقُصَّهَا إِنْ شَاءَ وَإِنْ رَأَى شَيْئًا يَكْرَهُهُ فَلاَ يَقُصَّهُ عَلَى أَحَدٍ وَلْيَقُمْ يُصَلِّي ‏"‏ ‏.‏\hadithno{3906}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Dreams are of three types: Glad tidings from Allah, what is on a person’s mind, and frightening dreams from Satan. If any of you sees a dream that he likes, let him tell others of it if he wishes, but if he sees something that he dislikes, he should not tell anyone about it, and he should get up and perform prayer.”}}
\hadithdefcmd{ibnmajah}{3907}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنَا يَزِيدُ بْنُ عَبِيدَةَ، حَدَّثَنِي أَبُو عُبَيْدِ اللَّهِ، مُسْلِمُ بْنُ مِشْكَمٍ عَنْ عَوْفِ بْنِ مَالِكٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ الرُّؤْيَا ثَلاَثٌ مِنْهَا أَهَاوِيلُ مِنَ الشَّيْطَانِ لِيَحْزُنَ بِهَا ابْنَ آدَمَ وَمِنْهَا مَا يَهُمُّ بِهِ الرَّجُلُ فِي يَقَظَتِهِ فَيَرَاهُ فِي مَنَامِهِ وَمِنْهَا جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏ قَالَ قُلْتُ لَهُ أَنْتَ سَمِعْتَ هَذَا مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ نَعَمْ أَنَا سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَا سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{3907}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu ‘Ubaidullah Muslim bin Mishkam, that ‘Awf bin Malik narrated that the Messenger of Allah (ﷺ) said:“Dreams are of three types: Some are terrifying things from Satan, aimed at causing grief to the son of Adam; some are things that a person is concerned with when he is awake, so he sees them in his dreams; and some are a part of the forty-six parts of prophecy.” He said: “I said to him: ‘Did you hear this from the Messenger of Allah (ﷺ)?’ He said: ‘Yes, I heard it from the Messenger of Allah (ﷺ), I heard it from the Messenger of Allah (ﷺ).’”}}
\hadithdefcmd{ibnmajah}{3908}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ إِذَا رَأَى أَحَدُكُمُ الرُّؤْيَا يَكْرَهُهَا فَلْيَبْصُقْ عَنْ يَسَارِهِ ثَلاَثًا وَلْيَسْتَعِذْ بِاللَّهِ مِنَ الشَّيْطَانِ ثَلاَثًا وَلْيَتَحَوَّلْ عَنْ جَنْبِهِ الَّذِي كَانَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{3908}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) said:“If anyone of you sees a dream that he dislikes, let him spit dryly to his left three times and seek refuge with Allah from Satan three times, and turn over onto his other side.”}}
\hadithdefcmd{ibnmajah}{3909}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي قَتَادَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الرُّؤْيَا مِنَ اللَّهِ وَالْحُلْمُ مِنَ الشَّيْطَانِ فَإِنْ رَأَى أَحَدُكُمْ شَيْئًا يَكْرَهُهُ فَلْيَبْصُقْ عَنْ يَسَارِهِ ثَلاَثًا وَلْيَسْتَعِذْ بِاللَّهِ مِنَ الشَّيْطَانِ الرَّجِيمِ ثَلاَثًا وَلْيَتَحَوَّلْ عَنْ جَنْبِهِ الَّذِي كَانَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{3909}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Qatadah that the Messenger of Allah (ﷺ) said:“(Good) dreams come from Allah and (bad) dreams come from Satan, so if anyone of you sees something that he dislikes, let him spit dryly to his left three times, and seek refuge with Allah from the accursed Satan three times, and turn over onto his other side.”}}
\hadithdefcmd{ibnmajah}{3910}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الْعُمَرِيِّ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا رَأَى أَحَدُكُمْ رُؤْيَا يَكْرَهُهَا فَلْيَتَحَوَّلْ وَلْيَتْفِلْ عَنْ يَسَارِهِ ثَلاَثًا وَلْيَسْأَلِ اللَّهَ مِنْ خَيْرِهَا وَلْيَتَعَوَّذْ بِاللَّهِ مِنْ شَرِّهَا ‏"‏ ‏.‏\hadithno{3910}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“If anyone of you sees a dream that he dislikes, let him turn over and spit dryly to his left three times, and ask Allah for its good and seek refuge from its evil.”}}
\hadithdefcmd{ibnmajah}{3911}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عُمَرَ بْنِ سَعِيدِ بْنِ أَبِي حُسَيْنٍ، حَدَّثَنِي عَطَاءُ بْنُ أَبِي رَبَاحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ إِنِّي رَأَيْتُ رَأْسِي ضُرِبَ فَرَأَيْتُهُ يَتَدَهْدَهُ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَعْمِدُ الشَّيْطَانُ إِلَى أَحَدِكُمْ فَيَتَهَوَّلُ لَهُ ثُمَّ يَغْدُو يُخْبِرُ النَّاسَ ‏"‏ ‏.‏\hadithno{3911}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“A man came to the Prophet (ﷺ) and said: ‘I saw my head was cut off and I saw it rolling away.’ The Messenger of Allah (ﷺ) said: ‘Satan goes to one of you and terrifies him, then he tells people of that the next morning.’”}}
\hadithdefcmd{ibnmajah}{3912}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ رَجُلٌ وَهْوَ يَخْطُبُ فَقَالَ يَا رَسُولَ اللَّهِ رَأَيْتُ الْبَارِحَةَ فِيمَا يَرَى النَّائِمُ كَأَنَّ عُنُقِي ضُرِبَتْ وَسَقَطَ رَأْسِي فَاتَّبَعْتُهُ فَأَخَذْتُهُ فَأَعَدْتُهُ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا لَعِبَ الشَّيْطَانُ بِأَحَدِكُمْ فِي مَنَامِهِ فَلاَ يُحَدِّثَنَّ بِهِ النَّاسَ ‏"‏ ‏.‏\hadithno{3912}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:“A man came to the Prophet (ﷺ) when he was delivering a sermon and said: ‘O Messenger of Allah! Last night in my dream I saw my neck being struck and my head fell off, and I chased it, picked it up and put it back.’ The Messenger of Allah (ﷺ) said: ‘If Satan plays with any one of you in his dreams, he should not tell people about it.’”}}
\hadithdefcmd{ibnmajah}{3913}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا حَلَمَ أَحَدُكُمْ فَلاَ يُخْبِرِ النَّاسَ بِتَلَعُّبِ الشَّيْطَانِ بِهِ فِي الْمَنَامِ ‏"‏ ‏.‏\hadithno{3913}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“If anyone of you has a bad dream, he should not tell people about how Satan played with him in his dream.”}}
\hadithdefcmd{ibnmajah}{3914}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ وَكِيعِ بْنِ عُدُسٍ الْعُقَيْلِيِّ، عَنْ عَمِّهِ أَبِي رَزِينٍ، أَنَّهُ سَمِعَ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ الرُّؤْيَا عَلَى رِجْلِ طَائِرٍ مَا لَمْ تُعْبَرْ فَإِذَا عُبِرَتْ وَقَعَتْ ‏"‏ ‏.‏ قَالَ ‏"‏ وَالرُّؤْيَا جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏ قَالَ وَأَحْسِبُهُ قَالَ ‏"‏ لاَ يَقُصُّهَا إِلاَّ عَلَى وَادٍّ أَوْ ذِي رَأْىٍ ‏"‏ ‏.‏\hadithno{3914}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Razin that he heard the Prophet (ﷺ) say:“Dreams are attached to the foot of a bird* until they are interpreted, then when they are interpreted they come to pass.” He said: “And dreams are one of the forty-six parts of prophecy.” He (the narrator) said: “And I think he said: ‘(A person) should not tell them except to one whom he loves or one who is wise.’”}}
\hadithdefcmd{ibnmajah}{3915}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ يَزِيدَ الرَّقَاشِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اعْتَبِرُوهَا بِأَسْمَائِهَا وَكَنُّوهَا بِكُنَاهَا وَالرُّؤْيَا لأَوَّلِ عَابِرٍ ‏"‏ ‏.‏\hadithno{3915}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“Interpret them (dreams) in accordance with the names of the things you see, and understand what is hinted at, and the dream is for the first interpreter.”}}
\hadithdefcmd{ibnmajah}{3916}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ تَحَلَّمَ حُلُمًا كَاذِبًا كُلِّفَ أَنْ يَعْقِدَ بَيْنَ شَعِيرَتَيْنِ وَيُعَذَّبُ عَلَى ذَلِكَ ‏"‏ ‏.‏\hadithno{3916}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“Whoever tells of a false dream, will be ordered (on the Day of Resurrection) to tie two grains of barley together, and he will be punished for that.”}}
\hadithdefcmd{ibnmajah}{3917}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ، حَدَّثَنَا بِشْرُ بْنُ بَكْرٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا قَرُبَ الزَّمَانُ لَمْ تَكَدْ رُؤْيَا الْمُؤْمِنِ تَكْذِبُ وَأَصْدَقُهُمْ رُؤْيَا أَصْدَقُهُمْ حَدِيثًا وَرُؤْيَا الْمُسْلِمِ جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{3917}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“When the end of time draws near, hardly any believer will see a false dream, and the ones who see the truest dreams will be the ones who are truest in speech. And the dream of the believer is one of the forty-six parts of prophecy.’”}}
\hadithdefcmd{ibnmajah}{3918}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ الْمَدَنِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ رَجُلٌ مُنْصَرَفَهُ مِنْ أُحُدٍ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي رَأَيْتُ فِي الْمَنَامِ ظُلَّةً تَنْطِفُ سَمْنًا وَعَسَلاً وَرَأَيْتُ النَّاسَ يَتَكَفَّفُونَ مِنْهَا فَالْمُسْتَكْثِرُ وَالْمُسْتَقِلُّ وَرَأَيْتُ سَبَبًا وَاصِلاً إِلَى السَّمَاءِ رَأَيْتُكَ أَخَذْتَ بِهِ فَعَلَوْتَ بِهِ ثُمَّ أَخَذَ بِهِ رَجُلٌ بَعْدَكَ فَعَلاَ بِهِ ثُمَّ أَخَذَ بِهِ رَجُلٌ بَعْدَهُ فَعَلاَ بِهِ ثُمَّ أَخَذَ بِهِ رَجُلٌ بَعْدَهُ فَانْقَطَعَ بِهِ ثُمَّ وُصِلَ لَهُ فَعَلاَ بِهِ ‏.‏ فَقَالَ أَبُو بَكْرٍ دَعْنِي أَعْبُرْهَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ اعْبُرْهَا ‏"‏ ‏.‏ قَالَ أَمَّا الظُّلَّةُ فَالإِسْلاَمُ وَأَمَّا مَا يَنْطِفُ مِنْهَا مِنَ الْعَسَلِ وَالسَّمْنِ فَهُوَ الْقُرْآنُ حَلاَوَتُهُ وَلِينُهُ وَأَمَّا مَا يَتَكَفَّفُ مِنْهُ النَّاسُ فَالآخِذُ مِنَ الْقُرْآنِ كَثِيرًا وَقَلِيلاً وَأَمَّا السَّبَبُ الْوَاصِلُ إِلَى السَّمَاءِ فَمَا أَنْتَ عَلَيْهِ مِنَ الْحَقِّ أَخَذْتَ بِهِ فَعَلاَ بِكَ ثُمَّ يَأْخُذُهُ رَجُلٌ مِنْ بَعْدِكَ فَيَعْلُو بِهِ ثُمَّ آخَرُ فَيَعْلُو بِهِ ثُمَّ آخَرُ فَيَنْقَطِعُ بِهِ ثُمَّ يُوَصَّلُ لَهُ فَيَعْلُو بِهِ ‏.‏ قَالَ ‏"‏ أَصَبْتَ بَعْضًا وَأَخْطَأْتَ بَعْضًا ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ أَقْسَمْتُ عَلَيْكَ يَا رَسُولَ اللَّهِ لَتُخْبِرَنِّي بِالَّذِي أَصَبْتُ مِنَ الَّذِي أَخْطَأْتُ ‏.‏ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ لاَ تُقْسِمْ يَا أَبَا بَكْرٍ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ أَبُو هُرَيْرَةَ يُحَدِّثُ أَنَّ رَجُلاً، أَتَى رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ رَأَيْتُ ظُلَّةً بَيْنَ السَّمَاءِ وَالأَرْضِ تَنْطِفُ سَمْنًا وَعَسَلاً فَذَكَرَ الْحَدِيثَ نَحْوَهُ ‏.‏\hadithno{3918}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn ‘Abbas said:“A man came to the Prophet (ﷺ), upon his return from Uhud, and said: ‘O Messenger of Allah, in my dream I saw a cloud giving shade, from which drops of ghee and honey were falling, and I saw people collecting them in the palms of their hands, some gathering a lot and some a little. And I saw a rope reaching up into heaven, and I saw you take hold of it and rise with it. Then another man took hold of it after you rose with it, then another man took hold of it after him and rose with it. Then a man took hold of it after him and it broke, then it was reconnected and he rose with it.’ Abu Bakr said: ‘Let me interpret it, O Messenger of Allah.’ He said: ‘Interpret it.’ He said: ‘As for the cloud giving shade, it is Islam, and the drops of honey and ghee that fall from it (represent) the Qur’an with its sweetness and softness. As for the people collecting that in their palms, some learn a lot of the Qur’an and some learn a little. As for the rope reaching up into heaven, it is the truth that you are following; you took hold of it and rose with it, then another man till take hold of it after you and rise with you, then another, who will rise with it, then another, but it will break and then he reconnected, then he will rise with it.’ He said: ‘You have got some of it right and some of it wrong.’ Abu Bakr said: ‘I adjure you O Messenger of Allah, tell me what I got right and what I got wrong.’ The Prophet (ﷺ) said: ‘Do not swear, O Abu Bakr.”}}
\hadithdefcmd{ibnmajah}{3919}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاذٍ الصَّنْعَانِيُّ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنْتُ غُلاَمًا شَابًّا عَزَبًا فِي عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَكُنْتُ أَبِيتُ فِي الْمَسْجِدِ فَكَانَ مَنْ رَأَى مِنَّا رُؤْيَا يَقُصُّهَا عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقُلْتُ اللَّهُمَّ إِنْ كَانَ لِي عِنْدَكَ خَيْرٌ فَأَرِنِي رُؤْيَا يُعَبِّرُهَا لِي النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏.‏ فَنِمْتُ فَرَأَيْتُ مَلَكَيْنِ أَتَيَانِي فَانْطَلَقَا بِي فَلَقِيَهُمَا مَلَكٌ آخَرُ فَقَالَ لَمْ تُرَعْ ‏.‏ فَانْطَلَقَا بِي إِلَى النَّارِ فَإِذَا هِيَ مَطْوِيَّةٌ كَطَىِّ الْبِئْرِ وَإِذَا فِيهَا نَاسٌ قَدْ عَرَفْتُ بَعْضَهُمْ فَأَخَذُوا بِي ذَاتَ الْيَمِينِ فَلَمَّا أَصْبَحْتُ ذَكَرْتُ ذَلِكَ لِحَفْصَةَ فَزَعَمَتْ حَفْصَةُ أَنَّهَا قَصَّتْهَا عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ إِنَّ عَبْدَ اللَّهِ رَجُلٌ صَالِحٌ لَوْ كَانَ يُكْثِرُ الصَّلاَةَ مِنَ اللَّيْلِ ‏"‏ ‏.‏ قَالَ فَكَانَ عَبْدُ اللَّهِ يُكْثِرُ الصَّلاَةَ مِنَ اللَّيْلِ ‏.‏\hadithno{3919}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“I was a young unmarried man at the time of the Messenger of Allah (ﷺ), and I used to stay overnight in the mosque. If any of us had seen a dream, he would tell it to the Prophet (ﷺ). I said: ‘O Allah, if there is any good in me before You, show me a dream that the Prophet (ﷺ) can interpret for me.’ So I went to sleep and I saw two angels who came to me and took me away. They were met by another angel who said: ‘Do not be alarmed,’ and they took me to Hell which was built like a well. In it were people, some of whom I recognized. Then they took me off to the right. In the morning I mentioned that to Hafsah, and Hafsah said that she told the Messenger of Allah (ﷺ) about it, and he said: ‘Abdullah is a righteous man, if only he would pray more at night.’”}}
\hadithdefcmd{ibnmajah}{3920}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى الأَشْيَبُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَاصِمِ بْنِ بَهْدَلَةَ، عَنِ الْمُسَيَّبِ بْنِ رَافِعٍ، عَنْ خَرَشَةَ بْنِ الْحُرِّ، قَالَ قَدِمْتُ الْمَدِينَةَ فَجَلَسْتُ إِلَى أَشْيِخَةٍ فِي مَسْجِدِ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَجَاءَ شَيْخٌ يَتَوَكَّأُ عَلَى عَصًا لَهُ فَقَالَ الْقَوْمُ مَنْ سَرَّهُ أَنْ يَنْظُرَ إِلَى رَجُلٍ مِنْ أَهْلِ الْجَنَّةِ فَلْيَنْظُرْ إِلَى هَذَا ‏.‏ فَقَامَ خَلْفَ سَارِيَةٍ فَصَلَّى رَكْعَتَيْنِ فَقُمْتُ إِلَيْهِ فَقُلْتُ لَهُ قَالَ بَعْضُ الْقَوْمِ كَذَا وَكَذَا ‏.‏ قَالَ الْحَمْدُ لِلَّهِ الْجَنَّةُ لِلَّهِ يُدْخِلُهَا مَنْ يَشَاءُ وَإِنِّي رَأَيْتُ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ رُؤْيَا رَأَيْتُ كَأَنَّ رَجُلاً أَتَانِي فَقَالَ لِيَ انْطَلِقْ ‏.‏ فَذَهَبْتُ مَعَهُ فَسَلَكَ بِي فِي مَنْهَجٍ عَظِيمٍ فَعُرِضَتْ عَلَىَّ طَرِيقٌ عَلَى يَسَارِي فَأَرَدْتُ أَنْ أَسْلُكَهَا فَقَالَ إِنَّكَ لَسْتَ مِنْ أَهْلِهَا ‏.‏ ثُمَّ عُرِضَتْ عَلَىَّ طَرِيقٌ عَنْ يَمِينِي فَسَلَكْتُهَا حَتَّى إِذَا انْتَهَيْتُ إِلَى جَبَلٍ زَلَقٍ فَأَخَذَ بِيَدِي فَزَجَلَ بِي فَإِذَا أَنَا عَلَى ذُرْوَتِهِ فَلَمْ أَتَقَارَّ وَلَمْ أَتَمَاسَكْ وَإِذَا عَمُودٌ مِنْ حَدِيدٍ فِي ذُرْوَتِهِ حَلْقَةٌ مِنْ ذَهَبٍ فَأَخَذَ بِيَدِي فَزَجَّلَ بِي حَتَّى أَخَذْتُ بِالْعُرْوَةِ فَقَالَ اسْتَمْسَكْتَ قُلْتُ نَعَمْ فَضَرَبَ الْعَمُودَ بِرِجْلِهِ ‏.‏ فَاسْتَمْسَكْتُ بِالْعُرْوَةِ ‏.‏ فَقَالَ قَصَصْتُهَا عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ ‏ "‏ رَأَيْتَ خَيْرًا أَمَّا الْمَنْهَجُ الْعَظِيمُ فَالْمَحْشَرُ وَأَمَّا الطَّرِيقُ الَّتِي عُرِضَتْ عَنْ يَسَارِكَ فَطَرِيقُ أَهْلِ النَّارِ وَلَسْتَ مِنْ أَهْلِهَا وَأَمَّا الطَّرِيقُ الَّتِي عُرِضَتْ عَنْ يَمِينِكَ فَطَرِيقُ أَهْلِ الْجَنَّةِ وَأَمَّا الْجَبَلُ الزَّلَقُ فَمَنْزِلُ الشُّهَدَاءِ وَأَمَّا الْعُرْوَةُ الَّتِي اسْتَمْسَكْتَ بِهَا فَعُرْوَةُ الإِسْلاَمِ فَاسْتَمْسِكْ بِهَا حَتَّى تَمُوتَ ‏"‏ ‏.‏ فَأَنَا أَرْجُو أَنْ أَكُونَ مِنْ أَهْلِ الْجَنَّةِ فَإِذَا هُوَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ ‏.‏\hadithno{3920}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Kharashah bin Hurr said:“I came to Al-Madinah and sat with some old men in the mosque of the Prophet (ﷺ). Then an old man came, leaning on his stick, and the people said: ‘Whoever would like to look at a man from among the people of Paradise, let him look at this man.’ He stood behind a pillar and prayed two Rak’ah. I got up and went to him, and said to him: ‘Some of the people said such and such.’ He said: ‘Praise is to Allah. Paradise belongs to Allah and He admits whomsoever He wills to it. At the time of the Messenger of Allah (ﷺ) I saw a dream in which a man came to me and said: “Let’s go.” So I went with him and he took me along a great road. A road was shown to me on the left and I wanted to follow it, but he said: “You are not one of its people.” Then a road was shown to me on the right, and I followed him until I reached a slippery mountain. He took me by the hand and helped me up. When I reached the top I could not stand firm. There was an iron pillar there with a golden ring at the top. He took my hand and helped me up until I reached the handhold, then he said: “Have you gotten a firm hold?” I said: “Yes.” Then he struck the pillar with his foot and I held tight to the pillar. I told this to the Prophet (ﷺ) and he said: "You have seen something good. The great road is the plain of gathering (on the Day of Resurrection). The road that you were shown on your left is the way of the people of Hell, and you are not one of its people. The road which you were shown on your right is the way of the people of Paradise. The slippery mountain is the place of the martyrs, and the handhold that you held on tight to is the handhold of Islam. Hold on tight to it until you die." I hope to be one of the people of Paradise,' and he was 'Abdullah bin Salam}}
\hadithdefcmd{ibnmajah}{3921}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا بُرَيْدٌ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ رَأَيْتُ فِي الْمَنَامِ أَنِّي أُهَاجِرُ مِنْ مَكَّةَ إِلَى أَرْضٍ بِهَا نَخْلٌ فَذَهَبَ وَهَلِي إِلَى أَنَّهَا يَمَامَةُ أَوْ هَجَرٌ فَإِذَا هِيَ الْمَدِينَةُ يَثْرِبُ وَرَأَيْتُ فِي رُؤْيَاىَ هَذِهِ أَنِّي هَزَزْتُ سَيْفًا فَانْقَطَعَ صَدْرُهُ فَإِذَا هُوَ مَا أُصِيبَ مِنَ الْمُؤْمِنِينَ يَوْمَ أُحُدٍ ثُمَّ هَزَزْتُهُ فَعَادَ أَحْسَنَ مَا كَانَ فَإِذَا هُوَ مَا جَاءَ اللَّهُ بِهِ مِنَ الْفَتْحِ وَاجْتِمَاعِ الْمُؤْمِنِينَ وَرَأَيْتُ فِيهَا أَيْضًا بَقَرًا وَاللَّهُ خَيْرٌ فَإِذَا هُمُ النَّفَرُ مِنَ الْمُؤْمِنِينَ يَوْمَ أُحُدٍ وَإِذَا الْخَيْرُ مَا جَاءَ اللَّهُ بِهِ مِنَ الْخَيْرِ بَعْدُ وَثَوَابِ الصِّدْقِ الَّذِي آتَانَا اللَّهُ بِهِ يَوْمَ بَدْرٍ ‏"‏ ‏.‏\hadithno{3921}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Musa that the Prophet (ﷺ) said:“In a dream I saw myself emigrating from Makkah to a land in which there were date-palm trees, and I thought that it was Yamamah or Hajar, but it was Al-Madinah, Yathrib. And I saw in this dream of mine that I was wielding a sword then it broke in the middle. That was what befell the believers on the Day of Uhud. Then I wielded it again and it was better than it had been before, and that is what Allah brought about of the Conquest and the regrouping of the believers. And I also saw cows, and by Allah it is good, for they are the group of the believers (who were martyred) on the Day of Uhud, and the goodness is that which Allah brought forth after that, and the reward of the truth which Allah brought us on the Day of Badr.”}}
\hadithdefcmd{ibnmajah}{3922}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ رَأَيْتُ فِي يَدِي سِوَارَيْنِ مِنْ ذَهَبٍ فَنَفَخْتُهُمَا ‏.‏ فَأَوَّلْتُهُمَا هَذَيْنِ الْكَذَّابَيْنِ مُسَيْلِمَةَ وَالْعَنْسِيَّ ‏"‏ ‏.‏\hadithno{3922}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“I saw wristbands of gold on my arms, so I blew into them, and I interpreted them as being these two liars, Musailimah and ‘Ansi.”}}
\hadithdefcmd{ibnmajah}{3923}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، حَدَّثَنَا عَلِيُّ بْنُ صَالِحٍ، عَنْ سِمَاكٍ، عَنْ قَابُوسَ، قَالَ قَالَتْ أُمُّ الْفَضْلِ يَا رَسُولَ اللَّهِ رَأَيْتُ كَأَنَّ فِي بَيْتِي عُضْوًا مِنْ أَعْضَائِكَ قَالَ ‏"‏ خَيْرًا رَأَيْتِ تَلِدُ فَاطِمَةُ غُلاَمًا فَتُرْضِعِيهِ ‏"‏ ‏.‏ فَوَلَدَتْ حُسَيْنًا أَوْ حَسَنًا فَأَرْضَعَتْهُ بِلَبَنِ قُثَمَ قَالَتْ فَجِئْتُ بِهِ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَوَضَعْتُهُ فِي حَجْرِهِ فَبَالَ فَضَرَبْتُ كَتِفَهُ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ أَوْجَعْتِ ابْنِي رَحِمَكِ اللَّهُ ‏"‏ ‏.‏\hadithno{3923}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Qabus said:“Umm Fadl said: ‘O Messenger of Allah! It is as if I saw (in a dream) one of your limbs in my house.’ He said: ‘What you have seen is good. Fatimah will give birth to a boy and you will breastfeed him.’ Fatimah gave birth to Husain or Hasan, and I breastfed him with the milk of Qutham.’ She said: ‘I brought him to the Prophet (ﷺ) and placed him in his lap, and he urinated, so I struck him on the shoulder.” The Prophet (ﷺ) said: “You have hurt my son, may Allah have mercy on you.”}}
\hadithdefcmd{ibnmajah}{3924}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، أَخْبَرَنِي ابْنُ جُرَيْجٍ، أَخْبَرَنِي مُوسَى بْنُ عُقْبَةَ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ رُؤْيَا النَّبِيِّ، ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ رَأَيْتُ امْرَأَةً سَوْدَاءَ ثَائِرَةَ الرَّأْسِ خَرَجَتْ مِنَ الْمَدِينَةِ حَتَّى قَامَتْ بِالْمَهْيَعَةِ وَهِيَ الْجُحْفَةُ ‏.‏ فَأَوَّلْتُهَا وَبَاءً بِالْمَدِينَةِ فَنُقِلَ إِلَى الْجُحْفَةِ ‏"‏ ‏.‏\hadithno{3924}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from ‘Abdullah bin ‘Umar concerning the dream of the Prophet (ﷺ) that he (the Prophet (ﷺ)) said:“I saw a black woman with disheveled hair, who left Al-Madinah and went to stay in Al- Mahya’ah, which is Juhfah. I interpreted it as referring to an epidemic in Al-Madinah which moved to Juhfah.”}}
\hadithdefcmd{ibnmajah}{3925}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ، أَنَّ رَجُلَيْنِ، مِنْ بَلِيٍّ قَدِمَا عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَكَانَ إِسْلاَمُهُمَا جَمِيعًا فَكَانَ أَحَدُهُمَا أَشَدَّ اجْتِهَادًا مِنَ الآخَرِ فَغَزَا الْمُجْتَهِدُ مِنْهُمَا فَاسْتُشْهِدَ ثُمَّ مَكَثَ الآخَرُ بَعْدَهُ سَنَةً ثُمَّ تُوُفِّيَ ‏.‏ قَالَ طَلْحَةُ فَرَأَيْتُ فِي الْمَنَامِ بَيْنَا أَنَا عِنْدَ بَابِ الْجَنَّةِ إِذَا أَنَا بِهِمَا فَخَرَجَ خَارِجٌ مِنَ الْجَنَّةِ فَأَذِنَ لِلَّذِي تُوُفِّيَ الآخِرَ مِنْهُمَا ثُمَّ خَرَجَ فَأَذِنَ لِلَّذِي اسْتُشْهِدَ ثُمَّ رَجَعَ إِلَىَّ فَقَالَ ارْجِعْ فَإِنَّكَ لَمْ يَأْنِ لَكَ بَعْدُ ‏.‏ فَأَصْبَحَ طَلْحَةُ يُحَدِّثُ بِهِ النَّاسَ فَعَجِبُوا لِذَلِكَ فَبَلَغَ ذَلِكَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ وَحَدَّثُوهُ الْحَدِيثَ فَقَالَ ‏"‏ مِنْ أَىِّ ذَلِكَ تَعْجَبُونَ ‏"‏ فَقَالُوا يَا رَسُولَ اللَّهِ هَذَا كَانَ أَشَدَّ الرَّجُلَيْنِ اجْتِهَادًا ثُمَّ اسْتُشْهِدَ وَدَخَلَ هَذَا الآخِرُ الْجَنَّةَ قَبْلَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَلَيْسَ قَدْ مَكَثَ هَذَا بَعْدَهُ سَنَةً ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ قَالَ ‏"‏ وَأَدْرَكَ رَمَضَانَ فَصَامَهُ وَصَلَّى كَذَا وَكَذَا مِنْ سَجْدَةٍ فِي السَّنَةِ ‏"‏ ‏.‏ قَالُوا بَلَى قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ فَمَا بَيْنَهُمَا أَبْعَدُ مِمَّا بَيْنَ السَّمَاءِ وَالأَرْضِ ‏"‏ ‏.‏\hadithno{3925}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Talhah bin ‘Ubaidullah that two men from Bali came to the Messenger of Allah (ﷺ). They had become Muslim together, but one of them used to strive harder than the other. The one who used to strive harder went out to fight and was martyred. The other one stayed for a year longer, then he passed away. Talhah said:“I saw in a dream that I was at the gate of Paradise and I saw them (those two men). Someone came out of Paradise and admitted the one who had died last, then he came out and admitted the one who had been martyred. Then he came back to me and said: ‘Go back, for your time has not yet come.’” The next morning, Talhah told the people of that and they were amazed. News of that reached the Messenger of Allah (ﷺ) and they told him the story. He said: “Why are you so amazed at that?” They said: “O Messenger of Allah, the first one was the one who strove harder, then he was martyred, but the other one was admitted to Paradise before him. The Messenger of Allah (ﷺ) said: “Did he not stay behind for a year?” They said: “Yes.” He said: “And did not Ramadan come and he fasted, and he offered such and such prayers during that year?” They said: “Yes.” The Messenger of Allah (ﷺ) said: “The difference between them is greater than the difference between heaven and earth.”}}
\hadithdefcmd{ibnmajah}{3926}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا أَبُو بَكْرٍ الْهُذَلِيُّ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَكْرَهُ الْغُلَّ وَأُحِبُّ الْقَيْدَ الْقَيْدُ ثَبَاتٌ فِي الدِّينِ ‏"‏ ‏.‏\hadithno{3926}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“I dislike (to see in a dream) a chain around the neck, but I like to see fetters on the feet, for fetters (represent) steadfastness in religion.”}}
