% Auto-generated chapter 49 for malik
% Hadiths in this chapter: 40

\hadithdefcmd{malik}{1671}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ سَمِعَهُ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْسَ بِالطَّوِيلِ الْبَائِنِ وَلاَ بِالْقَصِيرِ وَلَيْسَ بِالأَبْيَضِ الأَمْهَقِ وَلاَ بِالآدَمِ وَلاَ بِالْجَعْدِ الْقَطَطِ وَلاَ بِالسَّبِطِ بَعَثَهُ اللَّهُ عَلَى رَأْسِ أَرْبَعِينَ سَنَةً فَأَقَامَ بِمَكَّةَ عَشْرَ سِنِينَ وَبِالْمَدِينَةِ عَشْرَ سِنِينَ وَتَوَفَّاهُ اللَّهُ عَزَّ وَجَلَّ عَلَى رَأْسِ سِتِّينَ سَنَةً وَلَيْسَ فِي رَأْسِهِ وَلِحْيَتِهِ عِشْرُونَ شَعْرَةً بَيْضَاءَ صلى الله عليه وسلم ‏.‏\hadithno{1671}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Rabia ibn Abi Abd ar-Rahman heard Anas ibn Malik say, "The Messenger of Allah, may Allah bless him and grant him peace, was not excessively tall or short. He was not very pallid nor dark. He did not have curly hair or lank hair. Allah commissioned him at the age of forty. He stayed in Makka ten years and at Madina for ten years and Allah the Mighty, the Majestic made him die when he was sixty. There were not twenty white hairs in his hair or beard, may Allah bless him and grant him peace}}
\hadithdefcmd{malik}{1672}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَرَانِي اللَّيْلَةَ عِنْدَ الْكَعْبَةِ فَرَأَيْتُ رَجُلاً آدَمَ كَأَحْسَنِ مَا أَنْتَ رَاءٍ مِنْ أُدْمِ الرِّجَالِ لَهُ لِمَّةٌ كَأَحْسَنِ مَا أَنْتَ رَاءٍ مِنَ اللِّمَمِ قَدْ رَجَّلَهَا فَهِيَ تَقْطُرُ مَاءً مُتَّكِئًا عَلَى رَجُلَيْنِ - أَوْ عَلَى عَوَاتِقِ رَجُلَيْنِ - يَطُوفُ بِالْكَعْبَةِ فَسَأَلْتُ مَنْ هَذَا قِيلَ هَذَا الْمَسِيحُ ابْنُ مَرْيَمَ ثُمَّ إِذَا أَنَا بِرَجُلٍ جَعْدٍ قَطَطٍ أَعْوَرِ الْعَيْنِ الْيُمْنَى كَأَنَّهَا عِنَبَةٌ طَافِيَةٌ فَسَأَلْتُ مَنْ هَذَا فَقِيلَ لِي هَذَا الْمَسِيحُ الدَّجَّالُ ‏"‏ ‏.‏\hadithno{1672}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "I dreamt at night that I was at the Kaba, and I saw a dark man like the most handsome of dark men you have ever seen. He had hair reaching to between his ears and his shoulders like the most excellent of such hair that you have seen. He had combed his hair, and water was dripping from it. He was leaning on two men or on the shoulders of two men doing tawaf around Kaba. I asked, 'Who is this?' It was said, 'al- Masih ibn Maryam.' Then we were with a man with wiry hair and blind in his right eye, as if it was a floating grape. I asked 'Who is this?' It was said to me, 'This is al-Masih ad-Dajjal}}
\hadithdefcmd{malik}{1673}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ خَمْسٌ مِنَ الْفِطْرَةِ تَقْلِيمُ الأَظَافِرِ وَقَصُّ الشَّارِبِ وَنَتْفُ الإِبْطِ وَحَلْقُ الْعَانَةِ وَالاِخْتِتَانُ ‏.‏\hadithno{1673}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Said ibn Abi Said al-Maqburi from his father that Abu Hurayra said, "There are five things from the fitra:cutting the nails, trimming the moustache, removing the hair from the armpit, shaving the pubic region and circumcision}}
\hadithdefcmd{malik}{1674}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ كَانَ إِبْرَاهِيمُ صلى الله عليه وسلم أَوَّلَ النَّاسِ ضَيَّفَ الضَّيْفَ وَأَوَّلَ النَّاسِ اخْتَتَنَ وَأَوَّلَ النَّاسِ قَصَّ الشَّارِبَ وَأَوَّلَ النَّاسِ رَأَى الشَّيْبَ فَقَالَ يَا رَبِّ مَا هَذَا فَقَالَ اللَّهُ تَبَارَكَ وَتَعَالَى وَقَارٌ يَا إِبْرَاهِيمُ ‏.‏ فَقَالَ رَبِّ زِدْنِي وَقَارًا ‏.‏ قَالَ يَحْيَى وَسَمِعْتُ مَالِكًا يَقُولُ يُؤْخَذُ مِنَ الشَّارِبِ حَتَّى يَبْدُوَ طَرَفُ الشَّفَةِ وَهُوَ الإِطَارُ وَلاَ يَجُزُّهُ فَيُمَثِّلُ بِنَفْسِهِ ‏.‏\hadithno{1674}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyub said, "Ibrahim, may Allah bless him and grant him peace, was the first to give hospitality to the guest and the first person to be circumcised and the first person to trim the moustache and the first person to see grey hair. He said, 'O Lord! What is this?' Allah the Blessed, the Exalted, said, 'It is dignity, Ibrahim.' He said, 'Lord, increase me in dignity!' " Yahya said that he had heard Malik say, "One takes from the moustache until the edge of the lip appears, that is the rim. One does not cut if off completely so that one mutilates oneself}}
\hadithdefcmd{malik}{1675}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ السَّلَمِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يَأْكُلَ الرَّجُلُ بِشِمَالِهِ أَوْ يَمْشِيَ فِي نَعْلٍ وَاحِدَةٍ وَأَنْ يَشْتَمِلَ الصَّمَّاءَ وَأَنْ يَحْتَبِيَ فِي ثَوْبٍ وَاحِدٍ كَاشِفًا عَنْ فَرْجِهِ ‏.‏\hadithno{1675}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zubayr from Jabir ibn Abdullah as-Salami that the Messenger of Allah, may Allah bless him and grant him peace, forbade a man to eat with his left hand or walk in one sandal or wrap a single garment around his drawn-up legs exposing his genitals}}
\hadithdefcmd{malik}{1676}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَكَلَ أَحَدُكُمْ فَلْيَأْكُلْ بِيَمِينِهِ وَلْيَشْرَبْ بِيَمِينِهِ فَإِنَّ الشَّيْطَانَ يَأْكُلُ بِشِمَالِهِ وَيَشْرَبُ بِشِمَالِهِ ‏"‏ ‏.‏\hadithno{1676}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Abu Bakr ibn Ubaydullah ibn Abdullah ibn Umar from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "When you eat, eat with your right hand and drink with your right hand. Shaytan eats with his left hand and drinks with his left hand}}
\hadithdefcmd{malik}{1677}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَيْسَ الْمِسْكِينُ بِهَذَا الطَّوَّافِ الَّذِي يَطُوفُ عَلَى النَّاسِ فَتَرُدُّهُ اللُّقْمَةُ وَاللُّقْمَتَانِ وَالتَّمْرَةُ وَالتَّمْرَتَانِ ‏"‏ ‏.‏ قَالُوا فَمَا الْمِسْكِينُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الَّذِي لاَ يَجِدُ غِنًى يُغْنِيهِ وَلاَ يَفْطُنُ النَّاسُ لَهُ فَيُتَصَدَّقَ عَلَيْهِ وَلاَ يَقُومُ فَيَسْأَلَ النَّاسَ ‏"‏ ‏.‏\hadithno{1677}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "The very poor are not the people who constantly walk from person to person and are given one or two morsels, and one or two dates." They said, "Who are the very poor, Messenger of Allah?" He said, "People who do not find enough for themselves and other people are not aware of them to give sadaqa to them, and they do not start begging from other people}}
\hadithdefcmd{malik}{1678}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنِ ابْنِ بُجَيْدٍ الأَنْصَارِيِّ، ثُمَّ الْحَارِثِيِّ عَنْ جَدَّتِهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رُدُّوا الْمِسْكِينَ وَلَوْ بِظِلْفٍ مُحْرَقٍ ‏"‏ ‏.‏\hadithno{1678}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ibn Bujayd (formerly al-Ansari) from his grandmother that the Messenger of Allah, may Allah bless him and grant him peace, said, "Give to the very poor, if only a roasted hoof}}
\hadithdefcmd{malik}{1679}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَأْكُلُ الْمُسْلِمُ فِي مِعًى وَاحِدٍ وَالْكَافِرُ يَأْكُلُ فِي سَبْعَةِ أَمْعَاءٍ ‏"‏ ‏.‏\hadithno{1679}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj that Abu Hurayra said, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'The muslim eats in one intestine, and the kafir eats in seven}}
\hadithdefcmd{malik}{1680}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ضَافَهُ ضَيْفٌ كَافِرٌ فَأَمَرَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَاةٍ فَحُلِبَتْ فَشَرِبَ حِلاَبَهَا ثُمَّ أُخْرَى فَشَرِبَهُ ثُمَّ أُخْرَى فَشَرِبَهُ حَتَّى شَرِبَ حِلاَبَ سَبْعِ شِيَاهٍ ثُمَّ إِنَّهُ أَصْبَحَ فَأَسْلَمَ فَأَمَرَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَاةٍ فَحُلِبَتْ فَشَرِبَ حِلاَبَهَا ثُمَّ أَمَرَ لَهُ بِأُخْرَى فَلَمْ يَسْتَتِمَّهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُؤْمِنُ يَشْرَبُ فِي مِعًى وَاحِدٍ وَالْكَافِرُ يَشْرَبُ فِي سَبْعَةِ أَمْعَاءٍ ‏"‏ ‏.‏\hadithno{1680}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Suhayl ibn Abi Salih from his father from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, gave hospitality to a kafir guest. The Messenger of Allah, may Allah bless him and grant him peace, ordered a sheep to be brought for him and it was milked. He drank its milk. Then another came, and he drank it. Then another came and he drank it until he had drunk the milk of seven sheep. In the morning he became muslim, and the Messenger of Allah, may Allah bless him and grant him peace, ordered a sheep for him. It was milked and he drank its milk. Then he ordered another for him and he could not finish it. The Messenger of Allah, may Allah bless him and grant him peace, said, "The mumin drinks in one intestine, and the kafir drinks in seven intestines}}
\hadithdefcmd{malik}{1681}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ زَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الَّذِي يَشْرَبُ فِي آنِيَةِ الْفِضَّةِ إِنَّمَا يُجَرْجِرُ فِي بَطْنِهِ نَارَ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{1681}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Zayd ibn Abdullah ibn Umar ibn al-Khattab from Abdullah ibn Abd ar-Rahman ibn Abi Bakras-Siddiq from Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, that the Messenger of Allah, may Allah bless him and grant him peace, said, "A person who drinks from a silver vessel brings the fire of Jahannam into his belly}}
\hadithdefcmd{malik}{1682}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَيُّوبَ بْنِ حَبِيبٍ، مَوْلَى سَعْدِ بْنِ أَبِي وَقَّاصٍ عَنْ أَبِي الْمُثَنَّى الْجُهَنِيِّ، أَنَّهُ قَالَ كُنْتُ عِنْدَ مَرْوَانَ بْنِ الْحَكَمِ فَدَخَلَ عَلَيْهِ أَبُو سَعِيدٍ الْخُدْرِيُّ فَقَالَ لَهُ مَرْوَانُ بْنُ الْحَكَمِ أَسَمِعْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ نَهَى عَنِ النَّفْخِ فِي الشَّرَابِ فَقَالَ لَهُ أَبُو سَعِيدٍ نَعَمْ فَقَالَ لَهُ رَجُلٌ يَا رَسُولَ اللَّهِ إِنِّي لاَ أَرْوَى مِنْ نَفَسٍ وَاحِدٍ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَأَبِنِ الْقَدَحَ عَنْ فِيكَ ثُمَّ تَنَفَّسْ ‏"‏ ‏.‏ قَالَ فَإِنِّي أَرَى الْقَذَاةَ فِيهِ ‏.‏ قَالَ ‏"‏ فَأَهْرِقْهَا ‏"‏ ‏.‏\hadithno{1682}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik from Ayyub ibn Habib, the mawla of Sad ibn Abi Waqqas that Abu'l-Muthanna al-Juhani said, "I was with Marwan ibn al-Hakam and Abu Said al-Khudri came to him. Marwan ibn al- Hakam said to him, 'Have you heard that the Messenger of Allah, may Allah bless him and grant him peace, forbade blowing into drinks?' Abu Said said to him, 'Yes.' A man said to him, 'Messenger of Allah, I am not quenched from one breath.' The Messenger of Allah, may Allah bless him and grant him peace, said to him, 'Remove the cup from your mouth and then breathe.' He said, 'Sometimes I see something floating in it?' He said, 'Then pour it out}}
\hadithdefcmd{malik}{1683}{حَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، وَعَلِيَّ بْنَ أَبِي طَالِبٍ، وَعُثْمَانَ بْنَ عَفَّانَ، كَانُوا يَشْرَبُونَ قِيَامًا ‏.‏\hadithno{1683}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Umar ibn al-Khattab and Ali ibn Abi Talib and Uthman ibn Affan drank while standing}}
\hadithdefcmd{malik}{1684}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ، وَسَعْدَ بْنَ أَبِي وَقَّاصٍ، كَانَا لاَ يَرَيَانِ بِشُرْبِ الإِنْسَانِ وَهُوَ قَائِمٌ بَأْسًا ‏.‏\hadithno{1684}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that A'isha, umm al-muminin and Sad ibn Abi Waqqas did not see any harm in a man drinking while standing}}
\hadithdefcmd{malik}{1685}{وَحَدَّثَنِي مَالِكٌ، عَنْ أَبِي جَعْفَرٍ الْقَارِيِّ، أَنَّهُ قَالَ رَأَيْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ يَشْرَبُ قَائِمًا ‏.‏\hadithno{1685}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Abu Jafar al-Qari said, "I saw Abdullah ibn Umar drink while standing}}
\hadithdefcmd{malik}{1686}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَشْرَبُ قَائِمًا ‏.‏\hadithno{1686}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Amir ibn Abdullah ibn az- Zubayr that his father used to drink while standing}}
\hadithdefcmd{malik}{1687}{حَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِلَبَنٍ قَدْ شِيبَ بِمَاءٍ مِنَ الْبِئْرِ وَعَنْ يَمِينِهِ أَعْرَابِيٌّ وَعَنْ يَسَارِهِ أَبُو بَكْرٍ الصِّدِّيقُ فَشَرِبَ ثُمَّ أَعْطَى الأَعْرَابِيَّ وَقَالَ ‏ "‏ الأَيْمَنَ فَالأَيْمَنَ ‏"‏ ‏.‏\hadithno{1687}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Anas ibn Malik that the Messenger of Allah, may Allah bless him and grant him peace, was brought some milk which was mixed with well-water. There was a Bedouin at his right side and Abu Bakr as-Siddiq on his left. He drank and then gave it to the Bedouin and said, "The right-hand to the right-hand}}
\hadithdefcmd{malik}{1688}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي حَازِمِ بْنِ دِينَارٍ، عَنْ سَهْلِ بْنِ سَعْدٍ الأَنْصَارِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِشَرَابٍ فَشَرِبَ مِنْهُ وَعَنْ يَمِينِهِ غُلاَمٌ وَعَنْ يَسَارِهِ الأَشْيَاخُ فَقَالَ لِلْغُلاَمِ ‏ "‏ أَتَأْذَنُ لِي أَنْ أُعْطِيَ هَؤُلاَءِ ‏"‏ ‏.‏ فَقَالَ الْغُلاَمُ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ لاَ أُوثِرُ بِنَصِيبِي مِنْكَ أَحَدًا ‏.‏ قَالَ فَتَلَّهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي يَدِهِ ‏.‏\hadithno{1688}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu Hazim ibn Dinar from Sahl ibn Sad al-Ansari that the Messenger of Allah, may Allah bless him and grant him peace, was brought a drink and he drank some of it. There was a boy at his right and some old men on his left. He said to the boy, "Will you give me permission to give it to these people?" The boy said, "No, Messenger of Allah, I will not prefer anyone to get my portion from you." He said, "So the Messenger of Allah, may Allah bless him and grant him peace, placed it in his hand}}
\hadithdefcmd{malik}{1689}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ أَبُو طَلْحَةَ لأُمِّ سُلَيْمٍ لَقَدْ سَمِعْتُ صَوْتَ، رَسُولِ اللَّهِ صلى الله عليه وسلم ضَعِيفًا أَعْرِفُ فِيهِ الْجُوعَ فَهَلْ عِنْدَكِ مِنْ شَىْءٍ فَقَالَتْ نَعَمْ ‏.‏ فَأَخْرَجَتْ أَقْرَاصًا مِنْ شَعِيرٍ ثُمَّ أَخَذَتْ خِمَارًا لَهَا فَلَفَّتِ الْخُبْزَ بِبَعْضِهِ ثُمَّ دَسَّتْهُ تَحْتَ يَدِي وَرَدَّتْنِي بِبَعْضِهِ ثُمَّ أَرْسَلَتْنِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَذَهَبْتُ بِهِ فَوَجَدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم جَالِسًا فِي الْمَسْجِدِ وَمَعَهُ النَّاسُ فَقُمْتُ عَلَيْهِمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ آرْسَلَكَ أَبُو طَلْحَةَ ‏"‏ ‏.‏ قَالَ فَقُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ لِلطَّعَامِ ‏"‏ ‏.‏ فَقُلْتُ نَعَمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِمَنْ مَعَهُ ‏"‏ قُومُوا ‏"‏ ‏.‏ قَالَ فَانْطَلَقَ وَانْطَلَقْتُ بَيْنَ أَيْدِيهِمْ حَتَّى جِئْتُ أَبَا طَلْحَةَ فَأَخْبَرْتُهُ فَقَالَ أَبُو طَلْحَةَ يَا أُمَّ سُلَيْمٍ قَدْ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالنَّاسِ وَلَيْسَ عِنْدَنَا مِنَ الطَّعَامِ مَا نُطْعِمُهُمْ ‏.‏ فَقَالَتِ اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ فَانْطَلَقَ أَبُو طَلْحَةَ حَتَّى لَقِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو طَلْحَةَ مَعَهُ حَتَّى دَخَلاَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلُمِّي يَا أُمَّ سُلَيْمٍ مَا عِنْدَكِ ‏"‏ ‏.‏ فَأَتَتْ بِذَلِكَ الْخُبْزِ فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَفُتَّ وَعَصَرَتْ عَلَيْهِ أُمُّ سُلَيْمٍ عُكَّةً لَهَا فَآدَمَتْهُ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا شَاءَ اللَّهُ أَنْ يَقُولَ ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ بِالدُّخُولِ ‏"‏ ‏.‏ فَأَذِنَ لَهُمْ فَأَكَلُوا حَتَّى شَبِعُوا ثُمَّ خَرَجُوا ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ ‏"‏ ‏.‏ فَأَذِنَ لَهُمْ فَأَكَلُوا حَتَّى شَبِعُوا ثُمَّ خَرَجُوا ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ ‏"‏ ‏.‏ فَأَذِنَ لَهُمْ فَأَكَلُوا حَتَّى شَبِعُوا ثُمَّ خَرَجُوا ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ ‏"‏ ‏.‏ فَأَذِنَ لَهُمْ فَأَكَلُوا حَتَّى شَبِعُوا ثُمَّ خَرَجُوا ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ ‏"‏ ‏.‏ حَتَّى أَكَلَ الْقَوْمُ كُلُّهُمْ وَشَبِعُوا وَالْقَوْمُ سَبْعُونَ رَجُلاً أَوْ ثَمَانُونَ رَجُلاً ‏.‏\hadithno{1689}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Ishaq ibn Abdullah ibn Abi Talha heard Anas ibn Malik say that Abu Talha had said to Umm Sulaym, "I have just been listening to the Messenger of Allah, may Allah bless him and grant him peace, and his voice was very weak. I recognised hunger in it, so, do you have anything?" She replied, "Yes," and brought out some barley loaves. She took her long head scarf and wrapped up the bread with part of it and put it into my (Anas's) hand and gave me part of it to wear. Then she sent me to the Messenger of Allah, may Allah bless him and grant him peace." Anas continued, "I took it, and I found the Messenger of Allah, may Allah bless him and grant him peace, sitting in the mosque with some people. I watched them. The Messenger of Allah, may Allah bless him and grant him peace, said, 'Did Abu Talha send you?' I replied, 'Yes.' He said, 'For food?' I said, 'Yes.' The Messenger of Allah, may Allah bless him and grant him peace, said to those with him, 'Let us go.' He set off and I went among them until I came to Abu Talha and told him. Abu Talha said, 'Umm Sulaym! The Messenger of Allah, may Allah bless him and grant him peace, has brought people and we have no food. What shall we give them to eat?' She said, 'Allah and His Messenger know best.' " Anas continued, "Abu Talha went out and met the Messenger of Allah, may Allah bless him and grant him peace, and the Messenger of Allah, may Allah bless him and grant him peace, approached with Abu Talha until they entered. The Messenger of Allah, may Allah bless him and grant him peace, said, 'Come now, Umm Sulaym, what have you got?' She brought out bread. The Messenger of Allah, may Allah bless him and grant him peace, ordered it to be broken into pieces, and Umm Sulaym squeezed out onto it a container of clarified butter which she had seasoned. Then the Messenger of Allah, may Allah bless him and grant him peace, said whatever Allah wished him to say, and said, 'Will you give permission for ten of them to come in?' He gave them permission, and they ate until they were full and then left. He said, 'Give permission to ten more.' He gave them permission, and they ate until they were full and left. Then he said, 'Give permission to ten more.' He gave them permission and they ate until they were full and left. Then he said, 'Give permission to ten more.' He gave permission and they ate until they were full and left. There were seventy or eighty men}}
\hadithdefcmd{malik}{1690}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ طَعَامُ الاِثْنَيْنِ كَافِي الثَّلاَثَةِ وَطَعَامُ الثَّلاَثَةِ كَافِي الأَرْبَعَةِ ‏"‏ ‏.‏\hadithno{1690}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "The food of two is enough for three, and the food of three is enough for four}}
\hadithdefcmd{malik}{1691}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَغْلِقُوا الْبَابَ وَأَوْكُوا السِّقَاءَ وَأَكْفِئُوا الإِنَاءَ - أَوْ خَمِّرُوا الإِنَاءَ - وَأَطْفِئُوا الْمِصْبَاحَ فَإِنَّ الشَّيْطَانَ لاَ يَفْتَحُ غَلَقًا وَلاَ يَحُلُّ وِكَاءً وَلاَ يَكْشِفُ إِنَاءً وَإِنَّ الْفُوَيْسِقَةَ تُضْرِمُ عَلَى النَّاسِ بَيْتَهُمْ ‏"‏ ‏.‏\hadithno{1691}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zubayr al-Makki from Jabir ibn Abdullah that the Messenger of Allah, may Allah bless him and grant him peace, said, "Lock the door, tie the waterskin, turn the vessel over or cover it, and put out the lamp. Shaytan does not open a locked door or untie a tied knot, or uncover a vessel. A mouse may set fire to people's houses about them}}
\hadithdefcmd{malik}{1692}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي شُرَيْحٍ الْكَعْبِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيَقُلْ خَيْرًا أَوْ لِيَصْمُتْ وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيُكْرِمْ جَارَهُ وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيُكْرِمْ ضَيْفَهُ جَائِزَتُهُ يَوْمٌ وَلَيْلَةٌ وَضِيَافَتُهُ ثَلاَثَةُ أَيَّامٍ فَمَا كَانَ بَعْدَ ذَلِكَ فَهُوَ صَدَقَةٌ وَلاَ يَحِلُّ لَهُ أَنْ يَثْوِيَ عِنْدَهُ حَتَّى يُحْرِجَهُ ‏"‏ ‏.‏\hadithno{1692}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Said ibn Abi Said al-Maqburi from Abu Shurayh al-Kabi that the Messenger of Allah, may Allah bless him and grant him peace, said, "Whoever believes in Allah and the Last Day should speak good or be silent. Whoever believes in Allah and the Last Day should be generous to his neighbour. Whoever believes in Allah and the Last Day, should be generous to his guest. His welcome is for a day and a night, and his hospitality is for three days. Whatever is more than that is sadaqa. It is not halal for a guest to stay with a man until he becomes a burden}}
\hadithdefcmd{malik}{1693}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَمَا رَجُلٌ يَمْشِي بِطَرِيقٍ إِذِ اشْتَدَّ عَلَيْهِ الْعَطَشُ فَوَجَدَ بِئْرًا فَنَزَلَ فِيهَا فَشَرِبَ وَخَرَجَ فَإِذَا كَلْبٌ يَلْهَثُ يَأْكُلُ الثَّرَى مِنَ الْعَطَشِ فَقَالَ الرَّجُلُ لَقَدْ بَلَغَ هَذَا الْكَلْبَ مِنَ الْعَطَشِ مِثْلُ الَّذِي بَلَغَ مِنِّي فَنَزَلَ الْبِئْرَ فَمَلأَ خُفَّهُ ثُمَّ أَمْسَكَهُ بِفِيهِ حَتَّى رَقِيَ فَسَقَى الْكَلْبَ فَشَكَرَ اللَّهُ لَهُ فَغَفَرَ لَهُ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ وَإِنَّ لَنَا فِي الْبَهَائِمِ لأَجْرًا فَقَالَ ‏"‏ فِي كُلِّ ذَاتِ كَبِدٍ رَطْبَةٍ أَجْرٌ ‏"‏ ‏.‏\hadithno{1693}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Sumayy, the mawla of Abu Bakr from Abu Salih as-Samman from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "A man was walking on a road when he became very thirsty. He found a well and went into it and drank and came out. There was a dog panting and eating earth out of thirst. The man said, 'This dog has become as thirsty as I was.' He went down into the well and filled his shoe and then held it in his mouth until he climbed out and gave the dog water to drink. Allah thanked him for it and forgave him." They said, "Messenger of Allah, do we have a reward for taking care of beasts?" He said, "There is a reward for every one with a moist liver}}
\hadithdefcmd{malik}{1694}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْثًا قِبَلَ السَّاحِلِ فَأَمَّرَ عَلَيْهِمْ أَبَا عُبَيْدَةَ بْنَ الْجَرَّاحِ وَهُمْ ثَلاَثُمِائَةٍ ‏.‏ قَالَ وَأَنَا فِيهِمْ - قَالَ - فَخَرَجْنَا حَتَّى إِذَا كُنَّا بِبَعْضِ الطَّرِيقِ فَنِيَ الزَّادُ فَأَمَرَ أَبُو عُبَيْدَةَ بِأَزْوَادِ ذَلِكَ الْجَيْشِ فَجُمِعَ ذَلِكَ كُلُّهُ فَكَانَ مِزْوَدَىْ تَمْرٍ - قَالَ - فَكَانَ يُقَوِّتُنَاهُ كُلَّ يَوْمٍ قَلِيلاً قَلِيلاً حَتَّى فَنِيَ وَلَمْ تُصِبْنَا إِلاَّ تَمْرَةٌ تَمْرَةٌ فَقُلْتُ وَمَا تُغْنِي تَمْرَةٌ فَقَالَ لَقَدْ وَجَدْنَا فَقْدَهَا حِينَ فَنِيَتْ - قَالَ - ثُمَّ انْتَهَيْنَا إِلَى الْبَحْرِ فَإِذَا حُوتٌ مِثْلُ الظَّرِبِ فَأَكَلَ مِنْهُ ذَلِكَ الْجَيْشُ ثَمَانِيَ عَشْرَةَ لَيْلَةً ثُمَّ أَمَرَ أَبُو عُبَيْدَةَ بِضِلَعَيْنِ مِنْ أَضْلاَعِهِ فَنُصِبَا ثُمَّ أَمَرَ بِرَاحِلَةٍ فَرُحِلَتْ ثُمَّ مَرَّتْ تَحْتَهُمَا وَلَمْ تُصِبْهُمَا\hadithno{1694}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Wahb ibn Kaysan that Jabir ibn Abdullah said, "The Messenger of Allah, may Allah bless him and grant him peace, sent a delegation to the coast. Abu Ubayda ibn al- Jarrah was in command of them. There were 300 people and I was among them. We went out until we had gone part of the way and our provisions were finished. Abu Ubayda ordered that the provisions of the army be gathered up and they amounted to two containers of dates. He used to give us a little provision from it each day until it was finished, and we used to have only a single date each. I said, 'What use is one date?' He said, 'We will certainly feel its loss when they are finished.' " Jabir continued, "Then we reached the sea and there was a fish like a small mountain. The army ate from it for eighteen nights. Then Abu Ubayda ordered two ribs from it to be set up. Then he commanded that a camel be ridden underneath them and it did not touch them}}
\hadithdefcmd{malik}{1695}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَمْرِو بْنِ سَعْدِ بْنِ مُعَاذٍ، عَنْ جَدَّتِهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَا نِسَاءَ الْمُؤْمِنَاتِ لاَ تَحْقِرَنَّ إِحْدَاكُنَّ لِجَارَتِهَا وَلَوْ كُرَاعَ شَاةٍ مُحْرَقًا ‏"‏ ‏.‏\hadithno{1695}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Amr ibn Sad ibn Muadh from his grandmother that the Messenger of Allah, may Allah bless him and grant him peace, said, "O trusting women, none of you must consider even a roasted sheep's trotter too small to give to her neighbour}}
\hadithdefcmd{malik}{1696}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَاتَلَ اللَّهُ الْيَهُودَ نُهُوا عَنْ أَكْلِ الشَّحْمِ فَبَاعُوهُ فَأَكَلُوا ثَمَنَهُ ‏"‏ ‏.‏\hadithno{1696}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that Abdullah ibn Abi Bakr said, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'May Allah curse the jews! They were forbidden to eat fat, so they sold it and ate its price}}
\hadithdefcmd{malik}{1697}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عِيسَى ابْنَ مَرْيَمَ، كَانَ يَقُولُ يَا بَنِي إِسْرَائِيلَ عَلَيْكُمْ بِالْمَاءِ الْقَرَاحِ وَالْبَقْلِ الْبَرِّيِّ وَخُبْزِ الشَّعِيرِ وَإِيَّاكُمْ وَخُبْزَ الْبُرِّ فَإِنَّكُمْ لَنْ تَقُومُوا بِشُكْرِهِ ‏.‏\hadithno{1697}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Isa ibn Maryam used to say, "O Banu Israil! You must drink pure water and the green things of the land and barley bread . Beware of wheat bread, for you will not be grateful enough for it}}
\hadithdefcmd{malik}{1698}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ الْمَسْجِدَ فَوَجَدَ فِيهِ أَبَا بَكْرٍ الصِّدِّيقَ وَعُمَرَ بْنَ الْخَطَّابِ فَسَأَلَهُمَا فَقَالاَ أَخْرَجَنَا الْجُوعُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَأَنَا أَخْرَجَنِي الْجُوعُ ‏"‏ ‏.‏ فَذَهَبُوا إِلَى أَبِي الْهَيْثَمِ بْنِ التَّيِّهَانِ الأَنْصَارِيِّ فَأَمَرَ لَهُمْ بِشَعِيرٍ عِنْدَهُ يُعْمَلُ وَقَامَ يَذْبَحُ لَهُمْ شَاةً فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَكِّبْ عَنْ ذَاتِ الدَّرِّ ‏"‏ ‏.‏ فَذَبَحَ لَهُمْ شَاةً وَاسْتَعْذَبَ لَهُمْ مَاءً فَعُلِّقَ فِي نَخْلَةٍ ثُمَّ أُتُوا بِذَلِكَ الطَّعَامِ فَأَكَلُوا مِنْهُ وَشَرِبُوا مِنْ ذَلِكَ الْمَاءِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَتُسْئَلُنَّ عَنْ نَعِيمِ هَذَا الْيَوْمِ ‏"‏ ‏.‏\hadithno{1698}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he heard that the Messenger of Allah, may Allah bless him and grant him peace, entered the mosque and found Abu Bakr as-Siddiq and Umar ibn al-Khattab there. He questioned them and they said, "Hunger has driven us out." The Messenger of Allah, may Allah bless him and grant him peace, said, "And hunger has brought me out." They went to Abu'l-Haytham ibn at- Tayyihan al-Ansari. He ordered that some barley that was in the house be prepared and he got up to slaughter a sheep for them. The Messenger of Allah, may Allah bless him and grant him peace, said, "Leave the one with milk." He slaughtered a sheep for them and brought them sweet water and it was hung on a palm-tree. Then they were brought the food and ate it and drank the water. The Messenger of Allah, may Allah bless him and grant him peace, recited, "Then, on that day, you will be asked concerning pleasure." (Sura 102 ayat)}}
\hadithdefcmd{malik}{1699}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ يَأْكُلُ خُبْزًا بِسَمْنٍ فَدَعَا رَجُلاً مِنْ أَهْلِ الْبَادِيَةِ فَجَعَلَ يَأْكُلُ وَيَتَّبِعُ بِاللُّقْمَةِ وَضَرَ الصَّحْفَةِ فَقَالَ عُمَرُ كَأَنَّكَ مُقْفِرٌ ‏.‏ فَقَالَ وَاللَّهِ مَا أَكَلْتُ سَمْنًا وَلاَ رَأَيْتُ أَكْلاً بِهِ مُنْذُ كَذَا وَكَذَا ‏.‏ فَقَالَ عُمَرُ لاَ آكُلُ السَّمْنَ حَتَّى يَحْيَا النَّاسُ مِنْ أَوَّلِ مَا يَحْيَوْنَ ‏.‏\hadithno{1699}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Umar ibn al-Khattab was eating bread with ghee. He summoned one of the desert people and he began to eat and follow the grease in the dish with a morsel of bread. Umar said, "It is as if you were poor." He said, "By Allah. I have not eaten ghee nor have I seen food with it since such- and-such a time." Umar declared, "I shall not eat clarified butter until people are given life again like they were first given life," (i.e. on the Day of Rising)}}
\hadithdefcmd{malik}{1700}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ رَأَيْتُ عُمَرَ بْنَ الْخَطَّابِ - وَهُوَ يَوْمَئِذٍ أَمِيرُ الْمُؤْمِنِينَ - يُطْرَحُ لَهُ صَاعٌ مِنْ تَمْرٍ فَيَأْكُلُهُ حَتَّى يَأْكُلَ حَشَفَهَا ‏.‏\hadithno{1700}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ishaq ibn Abdullah ibn Abi Talha that Anas ibn Malik said, "I saw Umar ibn al-Khattab when he was amir al-muminin being given a sa of dates, and he ate all of them, even the inferior ones}}
\hadithdefcmd{malik}{1701}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ سُئِلَ عُمَرُ بْنُ الْخَطَّابِ عَنِ الْجَرَادِ، فَقَالَ وَدِدْتُ أَنَّ عِنْدِي، قَفْعَةً نَأْكُلُ مِنْهُ ‏.‏\hadithno{1701}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar that Abdullah ibn Umar said, ''Umar ibn al-Khattab was asked about locusts. He said, 'I would like to have a basket of them, from which we could eat}}
\hadithdefcmd{malik}{1702}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَلْحَلَةَ، عَنْ حُمَيْدِ بْنِ مَالِكِ بْنِ خُثَيْمٍ، أَنَّهُ قَالَ كُنْتُ جَالِسًا مَعَ أَبِي هُرَيْرَةَ بِأَرْضِهِ بِالْعَقِيقِ فَأَتَاهُ قَوْمٌ مِنْ أَهْلِ الْمَدِينَةِ عَلَى دَوَابَّ فَنَزَلُوا عِنْدَهُ - قَالَ حُمَيْدٌ - فَقَالَ أَبُو هُرَيْرَةَ اذْهَبْ إِلَى أُمِّي فَقُلْ إِنَّ ابْنَكِ يُقْرِئُكِ السَّلاَمَ وَيَقُولُ أَطْعِمِينَا شَيْئًا ‏.‏ قَالَ فَوَضَعَتْ ثَلاَثَةَ أَقْرَاصٍ فِي صَحْفَةٍ وَشَيْئًا مِنْ زَيْتٍ وَمِلْحٍ ثُمَّ وَضَعَتْهَا عَلَى رَأْسِي وَحَمَلْتُهَا إِلَيْهِمْ فَلَمَّا وَضَعْتُهَا بَيْنَ أَيْدِيهِمْ كَبَّرَ أَبُو هُرَيْرَةَ وَقَالَ الْحَمْدُ لِلَّهِ الَّذِي أَشْبَعَنَا مِنَ الْخُبْزِ بَعْدَ أَنْ لَمْ يَكُنْ طَعَامُنَا إِلاَّ الأَسْوَدَيْنِ الْمَاءَ وَالتَّمْرَ ‏.‏ فَلَمْ يُصِبِ الْقَوْمُ مِنَ الطَّعَامِ شَيْئًا فَلَمَّا انْصَرَفُوا قَالَ يَا ابْنَ أَخِي أَحْسِنْ إِلَى غَنَمِكَ وَامْسَحِ الرُّعَامَ عَنْهَا وَأَطِبْ مُرَاحَهَا وَصَلِّ فِي نَاحِيَتِهَا فَإِنَّهَا مِنْ دَوَابِّ الْجَنَّةِ وَالَّذِي نَفْسِي بِيَدِهِ لَيُوشِكُ أَنْ يَأْتِيَ عَلَى النَّاسِ زَمَانٌ تَكُونُ الثُّلَّةُ مِنَ الْغَنَمِ أَحَبَّ إِلَى صَاحِبِهَا مِنْ دَارِ مَرْوَانَ ‏.‏\hadithno{1702}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Muhammad ibn Amr ibn Halhala that Humayd ibn Malik ibn Khu'haym said, "I was sitting with Abu Hurayra on his land at al-Aqiq. Some people rode out from Madina to call upon Abu Hurayra. He told me to go to his mother, sending his greetings and asking her to prepare some food." Humayd continued, "She set down three loaves on a plate and some oil and salt. Then she put it on my head and I carried it to them. When I set it before them, Abu Hurayra said, 'Allah is greater' and added, 'Praise be to Allah who has filled us with bread after our food had previously been only water and dates,' as the people did not touch any of the food. When they left, he said, 'O son of my brother, be good to your sheep and wipe the mucus from them and clean their pen. Pray in their quarter for they are among the animals of the Garden. By He in Whose Hand my self is, a time is about to come upon people when a small group of sheep will be more beloved to their owner than the house of Marwan}}
\hadithdefcmd{malik}{1703}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي نُعَيْمٍ، وَهْبِ بْنِ كَيْسَانَ قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِطَعَامٍ وَمَعَهُ رَبِيبُهُ عُمَرُ بْنُ أَبِي سَلَمَةَ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سَمِّ اللَّهَ وَكُلْ مِمَّا يَلِيكَ ‏"‏ ‏.‏\hadithno{1703}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu Nuaym that Wahb ibn Kaysan said, "The Messenger of Allah, may Allah bless him and grant him peace, was brought food while his stepson Umar ibn Salama was with him. The Messenger of Allah, may Allah bless him and grant him peace, said to him, 'Say "Bismillah," and eat what is in front of you}}
\hadithdefcmd{malik}{1704}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ سَمِعْتُ الْقَاسِمَ بْنَ مُحَمَّدٍ، يَقُولُ جَاءَ رَجُلٌ إِلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ فَقَالَ لَهُ إِنَّ لِي يَتِيمًا وَلَهُ إِبِلٌ أَفَأَشْرَبُ مِنْ لَبَنِ إِبِلِهِ فَقَالَ ابْنُ عَبَّاسٍ إِنْ كُنْتَ تَبْغِي ضَالَّةَ إِبِلِهِ وَتَهْنَأُ جَرْبَاهَا وَتَلُطُّ حَوْضَهَا وَتَسْقِيهَا يَوْمَ وِرْدِهَا فَاشْرَبْ غَيْرَ مُضِرٍّ بِنَسْلٍ وَلاَ نَاهِكٍ فِي الْحَلْبِ ‏.‏\hadithno{1704}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said that he had heard al-Qasim ibn Muhammad say that a man came to Abdullah ibn Abbas and said to him, "I have an orphan and he has camels. Can I drink from the camels' milk?" Ibn Abbas said, "If you search for the lost camels of his and treat the camels' mange and fill in the cracks in their water basin and give it water on the day it drinks, then drink it without doing harm to the suckling camels by milking them excessively}}
\hadithdefcmd{malik}{1705}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ كَانَ لاَ يُؤْتَى أَبَدًا بِطَعَامٍ وَلاَ شَرَابٍ حَتَّى الدَّوَاءُ فَيَطْعَمَهُ أَوْ يَشْرَبَهُ إِلاَّ قَالَ الْحَمْدُ لِلَّهِ الَّذِي هَدَانَا وَأَطْعَمَنَا وَسَقَانَاوَنَعَّمَنَا اللَّهُ أَكْبَرُ اللَّهُمَّ أَلْفَتْنَا نِعْمَتُكَ بِكُلِّ شَرٍّ فَأَصْبَحْنَا مِنْهَا وَأَمْسَيْنَا بِكُلِّ خَيْرٍ نَسْأَلُكَ تَمَامَهَا وَشُكْرَهَا لاَ خَيْرَ إِلاَّ خَيْرُكَ وَلاَ إِلَهَ غَيْرُكَ إِلَهَ الصَّالِحِينَ وَرَبَّ الْعَالَمِينَ الْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ مَا شَاءَ اللَّهُ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ اللَّهُمَّ بَارِكْ لَنَا فِيمَا رَزَقْتَنَا وَقِنَا عَذَابَ النَّارِ ‏.‏ قَالَ يَحْيَى سُئِلَ مَالِكٌ هَلْ تَأْكُلُ الْمَرْأَةُ مَعَ غَيْرِ ذِي مَحْرَمٍ مِنْهَا أَوْ مَعَ غُلاَمِهَا فَقَالَ مَالِكٌ لَيْسَ بِذَلِكَ بَأْسٌ إِذَا كَانَ ذَلِكَ عَلَى وَجْهِ مَا يُعْرَفُ لِلْمَرْأَةِ أَنْ تَأْكُلَ مَعَهُ مِنَ الرِّجَالِ ‏.‏ قَالَ وَقَدْ تَأْكُلُ الْمَرْأَةُ مَعَ زَوْجِهَا وَمَعَ غَيْرِهِ مِمَّنْ يُؤَاكِلُهُ أَوْ مَعَ أَخِيهَا عَلَى مِثْلِ ذَلِكَ وَيُكْرَهُ لِلْمَرْأَةِ أَنْ تَخْلُوَ مَعَ الرَّجُلِ لَيْسَ بَيْنَهُ وَبَيْنَهَا حُرْمَةٌ ‏.‏\hadithno{1705}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father never brought food or drink, nor even a remedy which he ate or drank but that he said, "Praise be to Allah who has guided us and fed us and given us to drink and blessed us. Allah is greater. O Allah! We have found Your blessing with every evil, give us every good in the morning and evening. We ask You for its completion and its gratitude. There is no good except Your good. There is no god other than You, the God of the salihun and the Lord of the Worlds. Praise be to Allah. There is no god but Allah. What Allah wills. There is no power except in Allah. O Allah! Bless us in what You have provided us with and protect us from the punishment of the Fire!" Al-hamdu lillahi-lladhi hadana wa at amana wa saqana wa naamana. Allahu akbar. Allahumma'l fatna nimatik bi-kulli sharr. Fa asbahna minha wa amsayna bi-kulli khayr. Nasaluka tamamaha wa shukraha. La khayr illa khayruk. Wa la ilaha ghayruk. Ilaha'-saliheen wa rabba'l-alameen. Al-hamdu lillah. Wa la ilaha illa'llah. Ma sha'Allah. Wa la quwwata illa billah. Allahumma barik lana fima razaqtana. Waqina adhaba'n-nar}}
\hadithdefcmd{malik}{1706}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ إِيَّاكُمْ وَاللَّحْمَ فَإِنَّ لَهُ ضَرَاوَةً كَضَرَاوَةِ الْخَمْرِ ‏.‏\hadithno{1706}\hadithgrade{Salim al-Hilali: Mauquf Hasan Lighairihi}\hadithtrans{Yahya said that Malik was asked, "Can a woman eat with other than her relative or slave?" Malik said, "There is no harm in that if it is in a manner which is accepted for a woman to eat with men." Malik said, "A woman sometimes eats with her husband and with others he dines with or with her brother in the same way. It is disapproved of for a woman to be alone with a man when there is no relationship between them by blood, marriage or suckling that would prevent him marrying her." Hadith Translation Not available}}
\hadithdefcmd{malik}{1707}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، أَدْرَكَ جَابِرَ بْنَ عَبْدِ اللَّهِ وَمَعَهُ حِمَالُ لَحْمٍ فَقَالَ مَا هَذَا فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ قَرِمْنَا إِلَى اللَّحْمِ فَاشْتَرَيْتُ بِدِرْهَمٍ لَحْمًا ‏.‏ فَقَالَ عُمَرُ أَمَا يُرِيدُ أَحَدُكُمْ أَنْ يَطْوِيَ بَطْنَهُ عَنْ جَارِهِ أَوِ ابْنِ عَمِّهِ أَيْنَ تَذْهَبُ عَنْكُمْ هَذِهِ الآيَةُ ‏\{‏أَذْهَبْتُمْ طَيِّبَاتِكُمْ فِي حَيَاتِكُمُ الدُّنْيَا وَاسْتَمْتَعْتُمْ بِهَا ‏\}‏\hadithno{1707}\hadithgrade{Salim al-Hilali: Mauquf Hasan Lighairihi}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Umar ibn al-Khattab said, "Beware of meat. It has addictiveness like the addictiveness of wine." Yahya related to me from Malik from Yahya ibn Said that Umar ibn al-Khattab saw Jabir ibn Abdullah carrying some meat. He said, "What is this?" He said, "Amir al- muminin. We desired meat and I bought some meat for a dirham." Umar said, "Does one of you want to fill his belly apart from his neighbour or nephew? How can you overlook this ayat? 'You squandered your good things in the life of this world and sought comfort in them.' " (Sura 46 ayat)}}
\hadithdefcmd{malik}{1708}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَلْبَسُ خَاتَمًا مِنْ ذَهَبٍ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَنَبَذَهُ وَقَالَ ‏ "‏ لاَ أَلْبَسُهُ أَبَدًا ‏"‏ ‏.‏ قَالَ فَنَبَذَ النَّاسُ خَوَاتِيمَهُمْ ‏.‏\hadithno{1708}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar from 'Abdullah ibn 'Umar that the Messenger of Allah, may Allah bless him and grant him peace, used to wear a gold ring. Then the Messenger of Allah, may Allah bless him and grant him peace, stood up and threw it away and said, "I will never wear it." He said, "So the people threw away their rings}}
\hadithdefcmd{malik}{1709}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ صَدَقَةَ بْنِ يَسَارٍ، أَنَّهُ قَالَ سَأَلْتُ سَعِيدَ بْنَ الْمُسَيَّبِ عَنْ لُبْسِ الْخَاتَمِ، فَقَالَ الْبَسْهُ وَأَخْبِرِ النَّاسَ، أَنِّي أَفْتَيْتُكَ بِذَلِكَ ‏.‏\hadithno{1709}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Sadaqa ibn Yasar said, "I asked Said ibn al-Musayyab about wearing a ring. He said, 'Wear it, and tell people that I gave you that decision}}
\hadithdefcmd{malik}{1710}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، أَنَّ أَبَا بَشِيرٍ الأَنْصَارِيَّ، أَخْبَرَهُ أَنَّهُ، كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ - قَالَ - فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَسُولاً قَالَ عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ حَسِبْتُ أَنَّهُ قَالَ وَالنَّاسُ فِي مَقِيلِهِمْ ‏ "‏ لاَ تَبْقَيَنَّ فِي رَقَبَةِ بَعِيرٍ قِلاَدَةٌ مِنْ وَتَرٍ أَوْ قِلاَدَةٌ إِلاَّ قُطِعَتْ ‏"‏ ‏.‏\hadithno{1710}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr from Abbad ibn Tamim that Abu Bashir al-Ansari told him that he was with the Messenger of Allah, may Allah bless him and grant him peace, on one of his journeys. He related, "The Messenger of Allah, may Allah bless him and grant him peace, sent a messenger." (Abdullah ibn Abi Bakr said, (I think that he said it was while the people were in their resting place.) He said, "Do not let a single-string necklace, or any necklace, remain unbroken on the neck of a camel." Yahya said, "I heard Malik say, 'I think that was because of the evil eye}}
