% Auto-generated chapter 18 for bukhari
% Hadiths in this chapter: 39

\hadithdefcmd{bukhari}{1080}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَاصِمٍ، وَحُصَيْنٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ أَقَامَ النَّبِيُّ صلى الله عليه وسلم تِسْعَةَ عَشَرَ يَقْصُرُ، فَنَحْنُ إِذَا سَافَرْنَا تِسْعَةَ عَشَرَ قَصَرْنَا، وَإِنْ زِدْنَا أَتْمَمْنَا‏.‏\hadithno{1080}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) once stayed for nineteen days and prayed shortened prayers. So when we travelled (and stayed) for nineteen days, we used to shorten the prayer but if we traveled (and stayed) for a longer period we used to offer the full prayer}}
\hadithdefcmd{bukhari}{1081}{حَدَّثَنَا أَبُو مَعْمَرٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم مِنَ الْمَدِينَةِ إِلَى مَكَّةَ، فَكَانَ يُصَلِّي رَكْعَتَيْنِ رَكْعَتَيْنِ حَتَّى رَجَعْنَا إِلَى الْمَدِينَةِ‏.‏ قُلْتُ أَقَمْتُمْ بِمَكَّةَ شَيْئًا قَالَ أَقَمْنَا بِهَا عَشْرًا‏.‏\hadithno{1081}\hadithtrans{Narrated Yahya bin 'Is-haq:I heard Anas saying, "We traveled with the Prophet (ﷺ) from Medina to Mecca and offered two rak`at (for every prayer) till we returned to Medina." I said, "Did you stay for a while in Mecca?" He replied, "We stayed in Mecca for ten days}}
\hadithdefcmd{bukhari}{1082}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم بِمِنًى رَكْعَتَيْنِ، وَأَبِي بَكْرٍ وَعُمَرَ، وَمَعَ عُثْمَانَ صَدْرًا مِنْ إِمَارَتِهِ ثُمَّ أَتَمَّهَا‏.‏\hadithno{1082}\hadithtrans{Narrated `Abdullah bin `Umar:I offered the prayer with the Prophet, Abu Bakr and `Umar at Mina and it was of two rak`at. `Uthman in the early days of his caliphate did the same, but later on he started praying the full prayer}}
\hadithdefcmd{bukhari}{1083}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا شُعْبَةُ، أَنْبَأَنَا أَبُو إِسْحَاقَ، قَالَ سَمِعْتُ حَارِثَةَ بْنَ وَهْبٍ، قَالَ صَلَّى بِنَا النَّبِيُّ صلى الله عليه وسلم آمَنَ مَا كَانَ بِمِنًى رَكْعَتَيْنِ‏.‏\hadithno{1083}\hadithtrans{Narrated Haritha bin Wahab:The Prophet (ﷺ) led us in the prayer at Mina during the peace period by offering two rak`at}}
\hadithdefcmd{bukhari}{1084}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ، عَنِ الأَعْمَشِ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ يَزِيدَ، يَقُولُ صَلَّى بِنَا عُثْمَانُ بْنُ عَفَّانَ ـ رضى الله عنه ـ بِمِنًى أَرْبَعَ رَكَعَاتٍ، فَقِيلَ ذَلِكَ لِعَبْدِ اللَّهِ بْنِ مَسْعُودٍ ـ رضى الله عنه ـ فَاسْتَرْجَعَ ثُمَّ قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِنًى رَكْعَتَيْنِ، وَصَلَّيْتُ مَعَ أَبِي بَكْرٍ ـ رضى الله عنه ـ بِمِنًى رَكْعَتَيْنِ، وَصَلَّيْتُ مَعَ عُمَرَ بْنِ الْخَطَّابِ ـ رضى الله عنه ـ بِمِنًى رَكْعَتَيْنِ، فَلَيْتَ حَظِّي مِنْ أَرْبَعِ رَكَعَاتٍ رَكْعَتَانِ مُتَقَبَّلَتَانِ‏.‏\hadithno{1084}\hadithtrans{Narrated `Abdur Rahman bin Yazid:We offered a four rak`at prayer at Mina behind Ibn `Affan . `Abdullah bin Mas`ud was informed about it. He said sadly, "Truly to Allah we belong and truly to Him we shall return." And added, "I prayed two rak`at with Allah's Messenger (ﷺ) at Mina and similarly with Abu Bakr and with `Umar (during their caliphates)." He further said, "May I be lucky enough to have two of the four rak`at accepted (by Allah)}}
\hadithdefcmd{bukhari}{1085}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي الْعَالِيَةِ الْبَرَّاءِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم وَأَصْحَابُهُ لِصُبْحِ رَابِعَةٍ يُلَبُّونَ بِالْحَجِّ، فَأَمَرَهُمْ أَنْ يَجْعَلُوهَا عُمْرَةً إِلاَّ مَنْ مَعَهُ الْهَدْىُ‏.‏ تَابَعَهُ عَطَاءٌ عَنْ جَابِرٍ‏.‏\hadithno{1085}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) and his companions reached Mecca in the morning of the 4th Dhul-Hijja reciting Talbiya (O Allah! We are obedient to your orders, we respond to your call) ... intending to perform Hajj. The Prophet (ﷺ) ordered his companions to assume the Ihram for Umra instead of Hajj, excepting those who had Hadi (sacrifice) with them}}
\hadithdefcmd{bukhari}{1086}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، قَالَ قُلْتُ لأَبِي أُسَامَةَ حَدَّثَكُمْ عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُسَافِرِ الْمَرْأَةُ ثَلاَثَةَ أَيَّامٍ إِلاَّ مَعَ ذِي مَحْرَمٍ ‏"‏‏.‏\hadithno{1086}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "A woman should not travel for more than three days except with a Dhi-Mahram (i.e. a male with whom she cannot marry at all, e.g. her brother, father, grandfather, etc.) or her own husband}}
\hadithdefcmd{bukhari}{1087}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُسَافِرِ الْمَرْأَةُ ثَلاَثًا إِلاَّ مَعَ ذِي مَحْرَمٍ ‏"‏‏.‏ تَابَعَهُ أَحْمَدُ عَنِ ابْنِ الْمُبَارَكِ عَنْ عُبَيْدِ اللَّهِ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1087}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "A woman should not travel for more than three days except with a Dhi-Mahram}}
\hadithdefcmd{bukhari}{1088}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، قَالَ حَدَّثَنَا سَعِيدٌ الْمَقْبُرِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُسَافِرَ مَسِيرَةَ يَوْمٍ وَلَيْلَةٍ لَيْسَ مَعَهَا حُرْمَةٌ ‏"‏‏.‏ تَابَعَهُ يَحْيَى بْنُ أَبِي كَثِيرٍ وَسُهَيْلٌ وَمَالِكٌ عَنِ الْمَقْبُرِيِّ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه‏.‏\hadithno{1088}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "It is not permissible for a woman who believes in Allah and the Last Day to travel for one day and night except with a Mahram}}
\hadithdefcmd{bukhari}{1089}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، وَإِبْرَاهِيمَ بْنِ مَيْسَرَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ صَلَّيْتُ الظُّهْرَ مَعَ النَّبِيِّ صلى الله عليه وسلم بِالْمَدِينَةِ أَرْبَعًا، وَبِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ‏.‏\hadithno{1089}\hadithtrans{Narrated Anas bin Malik: I offered four rak`at of Zuhr prayer with the Prophet (ﷺ) at Medina and two rak`at at Dhul-Hulaifa. (i.e. shortened the `Asr prayer)}}
\hadithdefcmd{bukhari}{1090}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتِ الصَّلاَةُ أَوَّلُ مَا فُرِضَتْ رَكْعَتَيْنِ فَأُقِرَّتْ صَلاَةُ السَّفَرِ، وَأُتِمَّتْ صَلاَةُ الْحَضَرِ‏.‏ قَالَ الزُّهْرِيُّ فَقُلْتُ لِعُرْوَةَ مَا بَالُ عَائِشَةَ تُتِمُّ قَالَ تَأَوَّلَتْ مَا تَأَوَّلَ عُثْمَانُ‏.‏\hadithno{1090}\hadithtrans{Narrated `Aisha:"When the prayers were first enjoined they were of two rak`at each. Later the prayer in a journey was kept as it was but the prayers for non-travelers were completed." Az-Zuhri said, "I asked `Urwa what made Aisha pray the full prayers (in journey)." He replied, "She did the same as `Uthman did}}
\hadithdefcmd{bukhari}{1092}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا أَعْجَلَهُ السَّيْرُ فِي السَّفَرِ يُؤَخِّرُ الْمَغْرِبَ حَتَّى يَجْمَعَ بَيْنَهَا وَبَيْنَ الْعِشَاءِ‏.‏ قَالَ سَالِمٌ وَكَانَ عَبْدُ اللَّهِ يَفْعَلُهُ إِذَا أَعْجَلَهُ السَّيْرُ‏.‏ وَزَادَ اللَّيْثُ قَالَ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ سَالِمٌ كَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ يَجْمَعُ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ بِالْمُزْدَلِفَةِ‏.‏ قَالَ سَالِمٌ وَأَخَّرَ ابْنُ عُمَرَ الْمَغْرِبَ، وَكَانَ اسْتُصْرِخَ عَلَى امْرَأَتِهِ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ فَقُلْتُ لَهُ الصَّلاَةُ‏.‏ فَقَالَ سِرْ‏.‏ فَقُلْتُ الصَّلاَةُ‏.‏ فَقَالَ سِرْ‏.‏ حَتَّى سَارَ مِيلَيْنِ أَوْ ثَلاَثَةً ثُمَّ نَزَلَ فَصَلَّى ثُمَّ قَالَ هَكَذَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يُصَلِّي إِذَا أَعْجَلَهُ السَّيْرُ‏.‏ وَقَالَ عَبْدُ اللَّهِ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم إِذَا أَعْجَلَهُ السَّيْرُ يُؤَخِّرُ الْمَغْرِبَ، فَيُصَلِّيهَا ثَلاَثًا ثُمَّ يُسَلِّمُ، ثُمَّ قَلَّمَا يَلْبَثُ حَتَّى يُقِيمَ الْعِشَاءَ فَيُصَلِّيَهَا رَكْعَتَيْنِ ثُمَّ يُسَلِّمُ، وَلاَ يُسَبِّحُ بَعْدَ الْعِشَاءِ حَتَّى يَقُومَ مِنْ جَوْفِ اللَّيْلِ‏.‏\hadithno{1092}\hadithtrans{Narrated `Abdullah bin `Umar:"I saw Allah's Messenger (ﷺ) delaying the Maghrib prayer till he offered it along with the `Isha' prayer whenever he was in a hurry during the journey." Salim narrated, "Ibn `Umar used to do the same whenever he was in a hurry during the journey." And Salim added, "Ibn `Umar used to pray the Maghrib and `Isha' prayers together in Al-Muzdalifa." Salim said, "Ibn `Umar delayed the Maghrib prayer because at that time he heard the news of the death of his wife Safiya bint Abi `Ubaid. I said to him, 'The prayer (is due).' He said, 'Go on.' Again I said, 'The prayer (is due).' He said, 'Go on,' till we covered two or three miles. Then he got down, prayed and said, 'I saw the Prophet (ﷺ) praying in this way, whenever he was in a hurry during the journey.' `Abdullah (bin `Umar) added, "Whenever the Prophet was in a hurry, he used to delay the Maghrib prayer and then offer three rak`at (of the Maghrib) and perform Taslim, and after waiting for a short while, Iqama used to be pronounced for the `Isha' prayer when he would offer two rak`at and perform Taslim. He would never offer any optional prayer till the middle of the night (when he used to pray the Tahajjud)}}
\hadithdefcmd{bukhari}{1093}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يُصَلِّي عَلَى رَاحِلَتِهِ حَيْثُ تَوَجَّهَتْ بِهِ‏.‏\hadithno{1093}\hadithtrans{Narrated `Abdullah bin 'Amir from his father who said:I saw the Prophet (ﷺ) offering the prayer on his mount (Rahila) whatever direction it took}}
\hadithdefcmd{bukhari}{1094}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي التَّطَوُّعَ وَهْوَ رَاكِبٌ فِي غَيْرِ الْقِبْلَةِ‏.‏\hadithno{1094}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) used to offer the Nawafil, while riding, facing a direction other than that of the Qibla}}
\hadithdefcmd{bukhari}{1095}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، قَالَ وَكَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ يُصَلِّي عَلَى رَاحِلَتِهِ وَيُوتِرُ عَلَيْهَا، وَيُخْبِرُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَفْعَلُهُ‏.‏\hadithno{1095}\hadithtrans{Narrated Nafi`:Ibn `Umar (while on a journey) used to offer the prayer and the witr on his mount (Rahila). He said that the Prophet (ﷺ) used to do so}}
\hadithdefcmd{bukhari}{1096}{حَدَّثَنَا مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، قَالَ كَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ ـ رضى الله عنهما ـ يُصَلِّي فِي السَّفَرِ عَلَى رَاحِلَتِهِ، أَيْنَمَا تَوَجَّهَتْ يُومِئُ‏.‏ وَذَكَرَ عَبْدُ اللَّهِ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَفْعَلُهُ‏.‏\hadithno{1096}\hadithtrans{Narrated `Abdullah bin Dinar:On traveling, `Abdullah bin `Umar used to offer the prayer on his Mount by signs whatever direction it took. `Abdullah said that the Prophet (ﷺ) used to do so}}
\hadithdefcmd{bukhari}{1097}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، أَنَّ عَامِرَ بْنَ رَبِيعَةَ، أَخْبَرَهُ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهْوَ عَلَى الرَّاحِلَةِ يُسَبِّحُ، يُومِئُ بِرَأْسِهِ قِبَلَ أَىِّ وَجْهٍ تَوَجَّهَ، وَلَمْ يَكُنْ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْنَعُ ذَلِكَ فِي الصَّلاَةِ الْمَكْتُوبَةِ‏.‏\hadithno{1097}\hadithtrans{Narrated 'Amir bin Rabi`a:I saw the Prophet (ﷺ) on his Mount praying Nawafil by nodding his head, whatever direction he faced, but Allah's Messenger (ﷺ) never did the same in offering the compulsory prayers}}
\hadithdefcmd{bukhari}{1098}{وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ قَالَ سَالِمٌ كَانَ عَبْدُ اللَّهِ يُصَلِّي عَلَى دَابَّتِهِ مِنَ اللَّيْلِ وَهْوَ مُسَافِرٌ، مَا يُبَالِي حَيْثُ مَا كَانَ وَجْهُهُ‏.‏ قَالَ ابْنُ عُمَرَ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُسَبِّحُ عَلَى الرَّاحِلَةِ قِبَلَ أَىِّ وَجْهٍ تَوَجَّهَ، وَيُوتِرُ عَلَيْهَا، غَيْرَ أَنَّهُ لاَ يُصَلِّي عَلَيْهَا الْمَكْتُوبَةَ‏.‏\hadithno{1098}\hadithtrans{Narrated Salim:At night `Abdullah bin `Umar used to offer the prayer on the back of his animal during the journey and never cared about the direction he faced. Ibn `Umar said, "Allah's Messenger (ﷺ) used to offer the optional prayer on the back of his Mount facing any direction and also used to pray the witr on it but never offered the compulsory prayer on it}}
\hadithdefcmd{bukhari}{1099}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، قَالَ حَدَّثَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي عَلَى رَاحِلَتِهِ نَحْوَ الْمَشْرِقِ فَإِذَا أَرَادَ أَنْ يُصَلِّيَ الْمَكْتُوبَةَ نَزَلَ فَاسْتَقْبَلَ الْقِبْلَةَ‏.‏\hadithno{1099}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) used to pray (the Nawafil) on his Mount facing east and whenever he wanted to offer the compulsory prayer, he used to dismount and face the Qibla}}
\hadithdefcmd{bukhari}{1100}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَبَّانُ، قَالَ حَدَّثَنَا هَمَّامٌ، قَالَ حَدَّثَنَا أَنَسُ بْنُ سِيرِينَ، قَالَ اسْتَقْبَلْنَا أَنَسًا حِينَ قَدِمَ مِنَ الشَّأْمِ، فَلَقِينَاهُ بِعَيْنِ التَّمْرِ، فَرَأَيْتُهُ يُصَلِّي عَلَى حِمَارٍ وَوَجْهُهُ مِنْ ذَا الْجَانِبِ، يَعْنِي عَنْ يَسَارِ الْقِبْلَةِ‏.‏ فَقُلْتُ رَأَيْتُكَ تُصَلِّي لِغَيْرِ الْقِبْلَةِ‏.‏ فَقَالَ لَوْلاَ أَنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَعَلَهُ لَمْ أَفْعَلْهُ‏.‏ رَوَاهُ ابْنُ طَهْمَانَ عَنْ حَجَّاجٍ عَنْ أَنَسِ بْنِ سِيرِينَ عَنْ أَنَسٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{1100}\hadithtrans{Narrated Anas bin Seereen:We went to receive Anas bin Malik when he returned from Sham and met him at a place called 'Ain at-Tamr. I saw him praying riding the donkey, with his face to this direction, i.e. to the left of the Qibla. I said to him, "I have seen you offering the prayer in a direction other than that of the Qibla." He replied, "If I had not seen Allah's Messenger (ﷺ) doing it, I would not have done it}}
\hadithdefcmd{bukhari}{1101}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي عُمَرُ بْنُ مُحَمَّدٍ، أَنَّ حَفْصَ بْنَ عَاصِمٍ، حَدَّثَهُ قَالَ سَافَرَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ فَقَالَ صَحِبْتُ النَّبِيَّ صلى الله عليه وسلم فَلَمْ أَرَهُ يُسَبِّحُ فِي السَّفَرِ، وَقَالَ اللَّهُ جَلَّ ذِكْرُهُ ‏\{‏لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏‏.‏\hadithno{1101}\hadithtrans{Narrated Hafs bin `Asim:Ibn `Umar went on a journey and said, "I accompanied the Prophet (ﷺ) and he did not offer optional prayers during the journey, and Allah says: 'Verily! In Allah's Messenger (ﷺ) you have a good example to follow}}
\hadithdefcmd{bukhari}{1102}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عِيسَى بْنِ حَفْصِ بْنِ عَاصِمٍ، قَالَ حَدَّثَنِي أَبِي أَنَّهُ، سَمِعَ ابْنَ عُمَرَ، يَقُولُ صَحِبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَكَانَ لاَ يَزِيدُ فِي السَّفَرِ عَلَى رَكْعَتَيْنِ، وَأَبَا بَكْرٍ وَعُمَرَ وَعُثْمَانَ كَذَلِكَ ـ رضى الله عنهم‏.‏\hadithno{1102}\hadithtrans{Narrated Ibn `Umar:I accompanied Allah's Messenger (ﷺ) and he never offered more than two rak`at during the journey. Abu Bakr, `Umar and `Uthman used to do the same}}
\hadithdefcmd{bukhari}{1103}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، عَنِ ابْنِ أَبِي لَيْلَى، قَالَ مَا أَنْبَأَ أَحَدٌ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم صَلَّى الضُّحَى غَيْرُ أُمِّ هَانِئٍ ذَكَرَتْ أَنَّ النَّبِيَّ صلى الله عليه وسلم يَوْمَ فَتْحِ مَكَّةَ اغْتَسَلَ فِي بَيْتِهَا، فَصَلَّى ثَمَانِ رَكَعَاتٍ، فَمَا رَأَيْتُهُ صَلَّى صَلاَةً أَخَفَّ مِنْهَا، غَيْرَ أَنَّهُ يُتِمُّ الرُّكُوعَ وَالسُّجُودَ‏.‏\hadithno{1103}\hadithtrans{Narrated Ibn Abu Laila:Only Um Hani told us that she had seen the Prophet (ﷺ) offering the Duha (forenoon prayer). She said, "On the day of the conquest of Mecca, the Prophet (ﷺ) took a bath in my house and offered eight rak`at. I never saw him praying such a light prayer but he performed perfect prostration and bowing}}
\hadithdefcmd{bukhari}{1104}{وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَامِرٍ، أَنَّ أَبَاهُ، أَخْبَرَهُ أَنَّهُ، رَأَى النَّبِيَّ صلى الله عليه وسلم صَلَّى السُّبْحَةَ بِاللَّيْلِ فِي السَّفَرِ عَلَى ظَهْرِ رَاحِلَتِهِ حَيْثُ تَوَجَّهَتْ بِهِ‏.‏\hadithno{1104}\hadithtrans{Narrated `Abdullah bin Amir that his father had told him that he had seen the Prophet (ﷺ) praying Nawafil at night on the back of his Mount on a journey, facing whatever direction it took}}
\hadithdefcmd{bukhari}{1105}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُسَبِّحُ عَلَى ظَهْرِ رَاحِلَتِهِ حَيْثُ كَانَ وَجْهُهُ، يُومِئُ بِرَأْسِهِ، وَكَانَ ابْنُ عُمَرَ يَفْعَلُهُ‏.‏\hadithno{1105}\hadithtrans{Narrated Salim bin `Abdullah:Ibn `Umar said, "Allah's Messenger (ﷺ) used to pray the Nawafil on the back of his Mount (carriage) by signs facing any direction." Ibn `Umar used to do the same}}
\hadithdefcmd{bukhari}{1106}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ الزُّهْرِيَّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَجْمَعُ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ إِذَا جَدَّ بِهِ السَّيْرُ‏.‏\hadithno{1106}\hadithtrans{Narrated Salim's father:The Prophet (ﷺ) used to offer the Maghrib and `Isha' prayers together whenever he was in a hurry on a journey}}
\hadithdefcmd{bukhari}{1107}{وَقَالَ إِبْرَاهِيمُ بْنُ طَهْمَانَ عَنِ الْحُسَيْنِ الْمُعَلِّمِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَجْمَعُ بَيْنَ صَلاَةِ الظُّهْرِ وَالْعَصْرِ إِذَا كَانَ عَلَى ظَهْرِ سَيْرٍ، وَيَجْمَعُ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ‏.‏\hadithno{1107}\hadithtrans{Narrated Ibn `Abbas: Allah's Messenger (ﷺ) used to offer the Zuhr and `Asr prayers together on journeys, and also used to offer the Maghrib and `Isha' prayers together. Narrated Anas bin Malik: The Prophet (ﷺ) used to offer the Maghrib and the `Isha' prayers together on journeys}}
\hadithdefcmd{bukhari}{1108}{وَعَنْ حُسَيْنٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ حَفْصِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَجْمَعُ بَيْنَ صَلاَةِ الْمَغْرِبِ وَالْعِشَاءِ فِي السَّفَرِ‏.‏ وَتَابَعَهُ عَلِيُّ بْنُ الْمُبَارَكِ وَحَرْبٌ عَنْ يَحْيَى عَنْ حَفْصٍ عَنْ أَنَسٍ جَمَعَ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{1108}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) used to offer these two prayers together on journeys i.e. the Maghrib and the `Isha}}
\hadithdefcmd{bukhari}{1109}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا أَعْجَلَهُ السَّيْرُ فِي السَّفَرِ يُؤَخِّرُ صَلاَةَ الْمَغْرِبِ، حَتَّى يَجْمَعَ بَيْنَهَا وَبَيْنَ الْعِشَاءِ‏.‏ قَالَ سَالِمٌ وَكَانَ عَبْدُ اللَّهِ يَفْعَلُهُ إِذَا أَعْجَلَهُ السَّيْرُ، وَيُقِيمُ الْمَغْرِبَ فَيُصَلِّيهَا ثَلاَثًا، ثُمَّ يُسَلِّمُ، ثُمَّ قَلَّمَا يَلْبَثُ حَتَّى يُقِيمَ الْعِشَاءَ، فَيُصَلِّيهَا رَكْعَتَيْنِ، ثُمَّ يُسَلِّمُ وَلاَ يُسَبِّحُ بَيْنَهَا بِرَكْعَةٍ، وَلاَ بَعْدَ الْعِشَاءِ بِسَجْدَةٍ حَتَّى يَقُومَ مِنْ جَوْفِ اللَّيْلِ‏.‏\hadithno{1109}\hadithtrans{Narrated Az-Zuhri:Salim told me, "`Abdullah bin `Umar said, 'I saw Allah's Messenger (ﷺ) delaying the Maghrib prayer till he offered it along with the `Isha prayer whenever he was in a hurry during the journey.' " Salim said, "Abdullah bin `Umar used to do the same whenever he was in a hurry during the journey. After making the call for Iqama, for the Maghrib prayer he used to offer three rak`at and then perform Taslim. After waiting for a short while, he would pronounce the Iqama for the `Isha' prayer and offer two rak`at and perform Taslim. He never prayed any Nawafil in between the two prayers or after the `Isha' prayers till he got up in the middle of the night (for Tahajjud prayer)}}
\hadithdefcmd{bukhari}{1110}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا حَرْبٌ، حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنِي حَفْصُ بْنُ عُبَيْدِ اللَّهِ بْنِ أَنَسٍ، أَنَّ أَنَسًا ـ رضى الله عنه ـ حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَجْمَعُ بَيْنَ هَاتَيْنِ الصَّلاَتَيْنِ فِي السَّفَرِ‏.‏ يَعْنِي الْمَغْرِبَ وَالْعِشَاءَ‏.‏\hadithno{1110}\hadithtrans{Narrated Anas bin Malik:Whenever the Prophet (ﷺ) started a journey before noon, he used to delay the Zuhr prayer till the time of `Asr and then offer them together; and if the sun declined (at noon) he used to offer the Zuhr prayer and then ride (for the journey)}}
\hadithdefcmd{bukhari}{1111}{حَدَّثَنَا حَسَّانُ الْوَاسِطِيُّ، قَالَ حَدَّثَنَا الْمُفَضَّلُ بْنُ فَضَالَةَ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا ارْتَحَلَ قَبْلَ أَنْ تَزِيغَ الشَّمْسُ أَخَّرَ الظُّهْرَ إِلَى وَقْتِ الْعَصْرِ، ثُمَّ يَجْمَعُ بَيْنَهُمَا، وَإِذَا زَاغَتْ صَلَّى الظُّهْرَ ثُمَّ رَكِبَ‏.‏\hadithno{1111}\hadithtrans{Narrated Anas bin Malik:Whenever the Prophet (ﷺ) started the journey before noon, he used to delay the Zuhr prayer till the time for the `Asr prayer and then he would dismount and pray them together; and whenever the sun declined before he started the journey he used to offer the Zuhr prayer and then ride (for the journey)}}
\hadithdefcmd{bukhari}{1112}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا الْمُفَضَّلُ بْنُ فَضَالَةَ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا ارْتَحَلَ قَبْلَ أَنْ تَزِيغَ الشَّمْسُ أَخَّرَ الظُّهْرَ إِلَى وَقْتِ الْعَصْرِ، ثُمَّ نَزَلَ فَجَمَعَ بَيْنَهُمَا، فَإِنْ زَاغَتِ الشَّمْسُ قَبْلَ أَنْ يَرْتَحِلَ صَلَّى الظُّهْرَ ثُمَّ رَكِبَ‏.‏\hadithno{1112}\hadithtrans{Narrated Anas bin Malik:Whenever the Prophet (ﷺ) started on a journey before noon, he used to delay the Zuhr prayer till the time for the 'Asr prayer and then he would dismount and offer them together; and whenever the sun declined before he started on a journey he used to offer the Zuhr prayers and then ride (for journey)}}
\hadithdefcmd{bukhari}{1113}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَيْتِهِ وَهْوَ شَاكٍ، فَصَلَّى جَالِسًا وَصَلَّى وَرَاءَهُ قَوْمٌ قِيَامًا، فَأَشَارَ إِلَيْهِمْ أَنِ اجْلِسُوا، فَلَمَّا انْصَرَفَ قَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ، فَإِذَا رَكَعَ فَارْكَعُوا، وَإِذَا رَفَعَ فَارْفَعُوا ‏"‏‏.‏\hadithno{1113}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) prayed in his house while sitting during his illness and the people prayed behind him standing and he pointed to them to sit down. When he had finished the prayer, he said, "The Imam is to be followed and so when he bows you should bow; and when he lifts his head you should also do the same}}
\hadithdefcmd{bukhari}{1114}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ سَقَطَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ فَرَسٍ فَخُدِشَ ـ أَوْ فَجُحِشَ ـ شِقُّهُ الأَيْمَنُ، فَدَخَلْنَا عَلَيْهِ نَعُودُهُ، فَحَضَرَتِ الصَّلاَةُ فَصَلَّى قَاعِدًا فَصَلَّيْنَا قُعُودًا وَقَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ، فَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا رَكَعَ فَارْكَعُوا، وَإِذَا رَفَعَ فَارْفَعُوا، وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ‏.‏ فَقُولُوا رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏‏.‏\hadithno{1114}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) fell down from a horse and his right side was either injured or scratched, so we went to inquire about his health. The time for the prayer became due and he offered the prayer while sitting and we prayed while standing. He said, "The Imam is to be followed; so if he says Takbir, you should also say Takbir, and if he bows you should also bow; and when he lifts his head you should also do the same and if he says: Sami`a l-lahu liman hamidah (Allah hears whoever sends his praises to Him) you should say: Rabbana walakal-Hamd (O our Lord! All the praises are for You.") (See Hadith No. 656 Vol)}}
\hadithdefcmd{bukhari}{1115}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، أَخْبَرَنَا حُسَيْنٌ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ ـ رضى الله عنه ـ أَنَّهُ سَأَلَ نَبِيَّ اللَّهِ صلى الله عليه وسلم‏.‏ أَخْبَرَنَا إِسْحَاقُ قَالَ أَخْبَرَنَا عَبْدُ الصَّمَدِ قَالَ سَمِعْتُ أَبِي قَالَ حَدَّثَنَا الْحُسَيْنُ عَنِ ابْنِ بُرَيْدَةَ قَالَ حَدَّثَنِي عِمْرَانُ بْنُ حُصَيْنٍ ـ وَكَانَ مَبْسُورًا ـ قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ صَلاَةِ الرَّجُلِ قَاعِدًا فَقَالَ ‏ "‏ إِنْ صَلَّى قَائِمًا فَهْوَ أَفْضَلُ، وَمَنْ صَلَّى قَاعِدًا فَلَهُ نِصْفُ أَجْرِ الْقَائِمِ، وَمَنْ صَلَّى نَائِمًا فَلَهُ نِصْفُ أَجْرِ الْقَاعِدِ ‏"‏‏.‏\hadithno{1115}\hadithtrans{Narrated `Imran bin Husain:(who had piles) I asked Allah's Messenger (ﷺ) about the praying of a man while sitting. He said, "If he prays while standing it is better and he who prays while sitting gets half the reward of that who prays standing; and whoever prays while Lying gets half the reward of that who prays while sitting}}
\hadithdefcmd{bukhari}{1116}{حَدَّثَنَا أَبُو مَعْمَرٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، أَنَّ عِمْرَانَ بْنَ حُصَيْنٍ ـ وَكَانَ رَجُلاً مَبْسُورًا ـ وَقَالَ أَبُو مَعْمَرٍ مَرَّةً عَنْ عِمْرَانَ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنْ صَلاَةِ الرَّجُلِ وَهْوَ قَاعِدٌ فَقَالَ ‏ "‏ مَنْ صَلَّى قَائِمًا فَهْوَ أَفْضَلُ، وَمَنْ صَلَّى قَاعِدًا فَلَهُ نِصْفُ أَجْرِ الْقَائِمِ، وَمَنْ صَلَّى نَائِمًا فَلَهُ نِصْفُ أَجْرِ الْقَاعِدِ ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ نَائِمًا عِنْدِي مُضْطَجِعًا هَا هُنَا‏.‏\hadithno{1116}\hadithtrans{Narrated `Abdullah bin Buraida:`Imran bin Husain had piles. Once Abu Ma mar narrated from `Imran bin Husain had said, "I asked the Prophet (ﷺ) about the prayer of a person while sitting. He said, 'It is better for one to pray standing; and whoever prays sitting gets half the reward of that who prays while standing; and whoever prays while Lying gets half the reward of that who prays while sitting}}
\hadithdefcmd{bukhari}{1117}{حَدَّثَنَا عَبْدَانُ، عَنْ عَبْدِ اللَّهِ، عَنْ إِبْرَاهِيمَ بْنِ طَهْمَانَ، قَالَ حَدَّثَنِي الْحُسَيْنُ الْمُكْتِبُ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ ـ رضى الله عنه ـ قَالَ كَانَتْ بِي بَوَاسِيرُ فَسَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنِ الصَّلاَةِ فَقَالَ ‏ "‏ صَلِّ قَائِمًا، فَإِنْ لَمْ تَسْتَطِعْ فَقَاعِدًا، فَإِنْ لَمْ تَسْتَطِعْ فَعَلَى جَنْبٍ ‏"‏‏.‏\hadithno{1117}\hadithtrans{Narrated `Imran bin Husain: I had piles, so I asked the Prophet (ﷺ) about the prayer. He said, "Pray while standing and if you can't, pray while sitting and if you cannot do even that, then pray Lying on your side}}
\hadithdefcmd{bukhari}{1118}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أُمِّ الْمُؤْمِنِينَ أَنَّهَا أَخْبَرَتْهُ أَنَّهَا لَمْ تَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي صَلاَةَ اللَّيْلِ قَاعِدًا قَطُّ حَتَّى أَسَنَّ، فَكَانَ يَقْرَأُ قَاعِدًا حَتَّى إِذَا أَرَادَ أَنْ يَرْكَعَ قَامَ، فَقَرَأَ نَحْوًا مِنْ ثَلاَثِينَ آيَةً أَوْ أَرْبَعِينَ آيَةً، ثُمَّ رَكَعَ‏.‏\hadithno{1118}\hadithtrans{Narrated Aisha:(the mother of the faithful believers) I never saw Allah's Messenger (ﷺ) offering the night prayer while sitting except in his old age and then he used to recite while sitting and whenever he wanted to bow he would get up and recite thirty or forty verses (while standing) and then bow}}
\hadithdefcmd{bukhari}{1119}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، وَأَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ ـ رضى الله عنها ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي جَالِسًا فَيَقْرَأُ وَهْوَ جَالِسٌ، فَإِذَا بَقِيَ مِنْ قِرَاءَتِهِ نَحْوٌ مِنْ ثَلاَثِينَ أَوْ أَرْبَعِينَ آيَةً قَامَ فَقَرَأَهَا وَهْوَ قَائِمٌ، ثُمَّ يَرْكَعُ ثُمَّ يَسْجُدُ، يَفْعَلُ فِي الرَّكْعَةِ الثَّانِيَةِ مِثْلَ ذَلِكَ، فَإِذَا قَضَى صَلاَتَهُ نَظَرَ، فَإِنْ كُنْتُ يَقْظَى تَحَدَّثَ مَعِي، وَإِنْ كُنْتُ نَائِمَةً اضْطَجَعَ‏.‏\hadithno{1119}\hadithtrans{Narrated `Aisha:(the mother of the faithful believers) Allah's Messenger (ﷺ) (in his last days) used to pray sitting. He would recite while sitting, and when thirty or forty verses remained from the recitation he would get up and recite them while standing and then he would bow and prostrate. He used to do the same in the second rak`a. After finishing the Prayer he used to look at me and if I was awake he would talk to me and if I was asleep, he would lie down}}
