% Auto-generated chapter 51 for bukhari
% Hadiths in this chapter: 68

\hadithdefcmd{bukhari}{2566}{حَدَّثَنَا عَاصِمُ بْنُ عَلِيٍّ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الْمَقْبُرِيِّ، ‏\{‏عَنْ أَبِيهِ،‏\}‏ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَا نِسَاءَ الْمُسْلِمَاتِ لاَ تَحْقِرَنَّ جَارَةٌ لِجَارَتِهَا، وَلَوْ فِرْسِنَ شَاةٍ ‏"‏‏.‏\hadithno{2566}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "O Muslim women! None of you should look down upon the gift sent by her female neighbor even if it were the trotters of the sheep (fleshless part of legs)}}
\hadithdefcmd{bukhari}{2567}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ الأُوَيْسِيُّ، حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ بْنِ رُومَانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ لِعُرْوَةَ ابْنَ أُخْتِي، إِنْ كُنَّا لَنَنْظُرُ إِلَى الْهِلاَلِ ثُمَّ الْهِلاَلِ، ثَلاَثَةَ أَهِلَّةٍ فِي شَهْرَيْنِ، وَمَا أُوقِدَتْ فِي أَبْيَاتِ رَسُولِ اللَّهِ صلى الله عليه وسلم نَارٌ‏.‏ فَقُلْتُ يَا خَالَةُ مَا كَانَ يُعِيشُكُمْ قَالَتِ الأَسْوَدَانِ التَّمْرُ وَالْمَاءُ، إِلاَّ أَنَّهُ قَدْ كَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم جِيرَانٌ مِنَ الأَنْصَارِ كَانَتْ لَهُمْ مَنَائِحُ، وَكَانُوا يَمْنَحُونَ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْ أَلْبَانِهِمْ، فَيَسْقِينَا‏.‏\hadithno{2567}\hadithtrans{Narrated `Urwa:Aisha said to me, "O my nephew! We used to see the crescent, and then the crescent and then the crescent in this way we saw three crescents in two months and no fire (for cooking) used to be made in the houses of Allah's Messenger (ﷺ). I said, "O my aunt! Then what use to sustain you?" `Aisha said, "The two black things: dates and water, our neighbors from Ansar had some Manaih and they used to present Allah's Messenger (ﷺ) some of their milk and he used to make us drink}}
\hadithdefcmd{bukhari}{2568}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ دُعِيتُ إِلَى ذِرَاعٍ أَوْ كُرَاعٍ لأَجَبْتُ، وَلَوْ أُهْدِيَ إِلَىَّ ذِرَاعٌ أَوْ كُرَاعٌ لَقَبِلْتُ ‏"‏‏.‏\hadithno{2568}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "I shall accept the invitation even if I were invited to a meal of a sheep's trotter, and I shall accept the gift even if it were an arm or a trotter of a sheep}}
\hadithdefcmd{bukhari}{2569}{حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَرْسَلَ إِلَى امْرَأَةٍ مِنَ الْمُهَاجِرِينَ، وَكَانَ لَهَا غُلاَمٌ نَجَّارٌ قَالَ لَهَا ‏"‏ مُرِي عَبْدَكِ فَلْيَعْمَلْ لَنَا أَعْوَادَ الْمِنْبَرِ ‏"‏‏.‏ فَأَمَرَتْ عَبْدَهَا، فَذَهَبَ فَقَطَعَ مِنَ الطَّرْفَاءِ، فَصَنَعَ لَهُ مِنْبَرًا، فَلَمَّا قَضَاهُ أَرْسَلَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَدْ قَضَاهُ، قَالَ صلى الله عليه وسلم ‏"‏ أَرْسِلِي بِهِ إِلَىَّ ‏"‏‏.‏ فَجَاءُوا بِهِ فَاحْتَمَلَهُ النَّبِيُّ صلى الله عليه وسلم فَوَضَعَهُ حَيْثُ تَرَوْنَ‏.‏\hadithno{2569}\hadithtrans{Narrated Sahl:The Prophet (ﷺ) sent for a woman from the emigrants and she had a slave who was a carpenter. The Prophet said to her "Order your slave to prepare the wood (pieces) for the pulpit." So, she ordered her slave who went and cut the wood from the tamarisk and prepared the pulpit, for the Prophet. When he finished the pulpit, the woman informed the Prophet (ﷺ) that it had been finished. The Prophet (ﷺ) asked her to send that pulpit to him, so they brought it. The Prophet (ﷺ) lifted it and placed it at the place in which you see now}}
\hadithdefcmd{bukhari}{2570}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ أَبِي حَازِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ السَّلَمِيِّ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ كُنْتُ يَوْمًا جَالِسًا مَعَ رِجَالٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فِي مَنْزِلٍ فِي طَرِيقِ مَكَّةَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم نَازِلٌ أَمَامَنَا وَالْقَوْمُ مُحْرِمُونَ، وَأَنَا غَيْرُ مُحْرِمٍ، فَأَبْصَرُوا حِمَارًا وَحْشِيًّا، وَأَنَا مَشْغُولٌ أَخْصِفُ نَعْلِي، فَلَمْ يُؤْذِنُونِي بِهِ، وَأَحَبُّوا لَوْ أَنِّي أَبْصَرْتُهُ، وَالْتَفَتُّ فَأَبْصَرْتُهُ، فَقُمْتُ إِلَى الْفَرَسِ فَأَسْرَجْتُهُ ثُمَّ رَكِبْتُ وَنَسِيتُ السَّوْطَ وَالرُّمْحَ فَقُلْتُ لَهُمْ نَاوِلُونِي السَّوْطَ وَالرُّمْحَ‏.‏ فَقَالُوا لاَ وَاللَّهِ، لاَ نُعِينُكَ عَلَيْهِ بِشَىْءٍ‏.‏ فَغَضِبْتُ فَنَزَلْتُ فَأَخَذْتُهُمَا، ثُمَّ رَكِبْتُ، فَشَدَدْتُ عَلَى الْحِمَارِ فَعَقَرْتُهُ، ثُمَّ جِئْتُ بِهِ وَقَدْ مَاتَ، فَوَقَعُوا فِيهِ يَأْكُلُونَهُ، ثُمَّ إِنَّهُمْ شَكُّوا فِي أَكْلِهِمْ إِيَّاهُ، وَهُمْ حُرُمٌ، فَرُحْنَا وَخَبَأْتُ الْعَضُدَ مَعِي، فَأَدْرَكْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلْنَاهُ عَنْ ذَلِكَ فَقَالَ ‏ "‏ مَعَكُمْ مِنْهُ شَىْءٌ ‏"‏‏.‏ فَقُلْتُ نَعَمْ‏.‏ فَنَاوَلْتُهُ الْعَضُدَ فَأَكَلَهَا، حَتَّى نَفَّدَهَا وَهْوَ مُحْرِمٌ‏.‏ فَحَدَّثَنِي بِهِ زَيْدُ بْنُ أَسْلَمَ عَنْ عَطَاءِ بْنِ يَسَارٍ عَنْ أَبِي قَتَادَةَ ‏عَنْ النَّبِيِّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ.‏\hadithno{2570}\hadithtrans{Narrated `Abdullah bin Abu Qatada Al-Aslami:That his father said, "One day I was sitting with some of the Prophet's companions on the way to Mecca. Allah's Messenger (ﷺ) was ahead of us. All of my companions were in the state of Ihram while I was a non-Muhrim. They saw an onager while I was busy repairing my shoes, so they did not tell me about it but they wished I had seen it. By chance I looked up and saw it. So, I turned to the horse, saddled it and rode on it, forgetting to take the spear and the whip. I asked them if they could hand over to me the whip and the spear but they said, 'No, by Allah, we shall not help you in that in any way.' I became angry and got down from the horse, picked up both the things and rode the horse again. I attacked the onager and slaughtered it, and brought it (after it had been dead). They took it (cooked some of it) and started eating it, but they doubted whether it was allowed for them to eat it or not, as they were in the state of Ihram. So, we proceeded and I hid with me one of its fore-legs. When we met Allah's Messenger (ﷺ) and asked him about the case, he asked, 'Do you have a portion of it with you?' I replied in the affirmative and gave him that fleshy foreleg which he ate completely while he was in the state of Ihram}}
\hadithdefcmd{bukhari}{2571}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، قَالَ حَدَّثَنِي أَبُو طَوَالَةَ ـ اسْمُهُ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ ـ قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ يَقُولُ أَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي دَارِنَا هَذِهِ، فَاسْتَسْقَى، فَحَلَبْنَا لَهُ شَاةً لَنَا، ثُمَّ شُبْتُهُ مِنْ مَاءِ بِئْرِنَا هَذِهِ، فَأَعْطَيْتُهُ وَأَبُو بَكْرٍ عَنْ يَسَارِهِ، وَعُمَرُ تُجَاهَهُ وَأَعْرَابِيٌّ عَنْ يَمِينِهِ فَلَمَّا فَرَغَ قَالَ عُمَرُ هَذَا أَبُو بَكْرٍ‏.‏ فَأَعْطَى الأَعْرَابِيَّ، ثُمَّ قَالَ ‏ "‏ الأَيْمَنُونَ، الأَيْمَنُونَ، أَلاَ فَيَمِّنُوا ‏"‏‏.‏ قَالَ أَنَسٌ فَهْىَ سُنَّةٌ فَهْىَ سُنَّةٌ‏.‏ ثَلاَثَ مَرَّاتٍ‏.‏\hadithno{2571}\hadithtrans{Narrated Anas:Once Allah's Messenger (ﷺ) visited us in this house of ours and asked for something to drink. We milked one of our sheep and mixed it with water from this well of ours and gave it to him. Abu Bakr was sitting on his left side and `Umar in front of him and a bedouin on his right side. When Allah's Messenger (ﷺ) finished, `Umar said to Allah's Messenger (ﷺ) "Here is Abu Bakr." But Allah's Messenger (ﷺ) gave the remaining milk to the bedouin and said twice, "The (persons on the) right side! So, start from the right side." Anas added, "It is a Sunna (the Prophet's traditions)" and repeated it thrice}}
\hadithdefcmd{bukhari}{2572}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدِ بْنِ أَنَسِ بْنِ مَالِكٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ أَنْفَجْنَا أَرْنَبًا بِمَرِّ الظَّهْرَانِ، فَسَعَى الْقَوْمُ فَلَغَبُوا، فَأَدْرَكْتُهَا فَأَخَذْتُهَا، فَأَتَيْتُ بِهَا أَبَا طَلْحَةَ فَذَبَحَهَا، وَبَعَثَ بِهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِوَرِكِهَا ـ أَوْ فَخِذَيْهَا قَالَ فَخِذَيْهَا لاَ شَكَّ فِيهِ ـ فَقَبِلَهُ‏.‏ قُلْتُ وَأَكَلَ مِنْهُ قَالَ وَأَكَلَ مِنْهُ‏.‏ ثُمَّ قَالَ بَعْدُ قَبِلَهُ‏.‏\hadithno{2572}\hadithtrans{Narrated Anas:We chased a rabbit at Mar-al-Zahran and the people ran after it but were exhausted. I overpowered and caught it, and gave it to Abu Talha who slaughtered it and sent its hip or two thighs to Allah's Apostle. (The narrator confirms that he sent two thighs). The Prophet (ﷺ) accepted that. (The sub-narrator asked Anas, "Did the Prophet; eat from it?" Anas replied, "He ate from it)}}
\hadithdefcmd{bukhari}{2573}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنِ الصَّعْبِ بْنِ جَثَّامَةَ ـ رضى الله عنهم ـ أَنَّهُ أَهْدَى لِرَسُولِ اللَّهِ صلى الله عليه وسلم حِمَارًا وَحْشِيًّا وَهْوَ بِالأَبْوَاءِ أَوْ بِوَدَّانَ فَرَدَّ عَلَيْهِ، فَلَمَّا رَأَى مَا فِي وَجْهِهِ قَالَ ‏ "‏ أَمَا إِنَّا لَمْ نَرُدَّهُ عَلَيْكَ إِلاَّ أَنَّا حُرُمٌ ‏"‏‏.‏\hadithno{2573}\hadithtrans{Narrated As-Sa'b bin Jath-thama:An onager was presented to Allah's Messenger (ﷺ) at the place called Al-Abwa' or Waddan, but Allah's Apostle rejected it. When the Prophet (ﷺ) noticed the signs of sorrow on the giver's face he said, "We have not rejected your gift, but we are in the state of Ihram." (i.e. if we were not in a state of Ihram we would have accepted your gift, Fath-ul-Bari page 130, Vol)}}
\hadithdefcmd{bukhari}{2574}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، حَدَّثَنَا عَبْدَةُ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّاسَ، كَانُوا يَتَحَرَّوْنَ بِهَدَايَاهُمْ يَوْمَ عَائِشَةَ، يَبْتَغُونَ بِهَا ـ أَوْ يَبْتَغُونَ بِذَلِكَ ـ مَرْضَاةَ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{2574}\hadithtrans{Narrated Aisha:The people used to look forward for the days of my (`Aisha's) turn to send gifts to Allah's Messenger (ﷺ) in order to please him}}
\hadithdefcmd{bukhari}{2575}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا جَعْفَرُ بْنُ إِيَاسٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ أَهْدَتْ أُمُّ حُفَيْدٍ خَالَةُ ابْنِ عَبَّاسٍ إِلَى النَّبِيِّ صلى الله عليه وسلم أَقِطًا وَسَمْنًا وَأَضُبًّا، فَأَكَلَ النَّبِيُّ صلى الله عليه وسلم مِنَ الأَقِطِ وَالسَّمْنِ، وَتَرَكَ الضَّبَّ تَقَذُّرًا‏.‏ قَالَ ابْنُ عَبَّاسٍ فَأُكِلَ عَلَى مَائِدَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم، وَلَوْ كَانَ حَرَامًا مَا أُكِلَ عَلَى مَائِدَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{2575}\hadithtrans{Narrated Sa`id bin Jubair:Ibn `Abbas said: Um Hufaid, Ibn `Abbas's aunt sent some dried yogurt (butter free), ghee (butter) and a mastigar to the Prophet (ﷺ) as a gift. The Prophet (ﷺ) ate the dried yogurt and butter but left the mastigar because he disliked it. Ibn `Abbas said, "The mastigar was eaten at the table of Allah's Messenger (ﷺ) and if it had been illegal to eat, it could not have been eaten at the table of Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{2576}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏إِذَا أُتِيَ بِطَعَامٍ سَأَلَ عَنْهُ أَهَدِيَّةٌ أَمْ صَدَقَةٌ فَإِنْ قِيلَ صَدَقَةٌ‏.‏ قَالَ لأَصْحَابِهِ كُلُوا‏.‏ وَلَمْ يَأْكُلْ، وَإِنْ قِيلَ هَدِيَّةٌ‏.‏ ضَرَبَ بِيَدِهِ صلى الله عليه وسلم فَأَكَلَ مَعَهُمْ ‏"‏‏.‏\hadithno{2576}\hadithtrans{Narrated Abu Huraira:Whenever a meal was brought to Allah's Messenger (ﷺ), he would ask whether it was a gift or Sadaqa (something given in charity). If he was told that it was Sadaqa, he would tell his companions to eat it, but if it was a gift, he would hurry to share it with them}}
\hadithdefcmd{bukhari}{2577}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِلَحْمٍ فَقِيلَ تُصُدِّقَ عَلَى بَرِيرَةَ قَالَ ‏ "‏ هُوَ لَهَا صَدَقَةٌ، وَلَنَا هَدِيَّةٌ ‏"‏‏.‏\hadithno{2577}\hadithtrans{Narrated Anas bin Malik:Some meat was brought to the Prophet (ﷺ) and it was said that the meat had been given in charity to Barirah. He said, "It was Sadaqa for Barirah but a gift for us}}
\hadithdefcmd{bukhari}{2578}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، قَالَ سَمِعْتُهُ مِنْهُ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا أَرَادَتْ أَنْ تَشْتَرِيَ بَرِيرَةَ، وَأَنَّهُمُ اشْتَرَطُوا وَلاَءَهَا، فَذُكِرَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اشْتَرِيهَا فَأَعْتِقِيهَا، فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏ وَأُهْدِيَ لَهَا لَحْمٌ، فَقِيلَ لِلنَّبِيِّ صلى الله عليه وسلم هَذَا تُصُدِّقَ عَلَى بَرِيرَةَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هُوَ لَهَا صَدَقَةٌ وَلَنَا هَدِيَّةٌ ‏"‏‏.‏ وَخُيِّرَتْ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ زَوْجُهَا حُرٌّ أَوْ عَبْدٌ قَالَ شُعْبَةُ سَأَلْتُ عَبْدَ الرَّحْمَنِ عَنْ زَوْجِهَا‏.‏ قَالَ لاَ أَدْرِي أَحُرٌّ أَمْ عَبْدٌ\hadithno{2578}\hadithtrans{Narrated `Aisha:I intended to buy Barirah but her masters stipulated that her Wala should be for them. When the Prophet was told about it, he said to me, "Buy and manumit her, as the Wala' is for the liberator." Once Barirah was given some meat, and the Prophet (ﷺ) asked, "What is this?" I said, "It has been given to Barirah in charity." He said, "It is sadaqa for her but a gift for us." Barirah was given the option (to stay with her husband or to part with him). `Abdur-Rahman (a sub-narrator) wondered, "Was her husband a slave or a free man?" Shu`ba (another sub-narrator) said, "I asked `Abdur-Rahman whether her husband was a slave or a free man. He replied that he did not know whether he was a slave or a free man}}
\hadithdefcmd{bukhari}{2579}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ أَبُو الْحَسَنِ، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ دَخَلَ النَّبِيُّ صلى الله عليه وسلم عَلَى عَائِشَةَ ـ رضى الله عنها ـ فَقَالَ ‏"‏ عِنْدَكُمْ شَىْءٌ ‏"‏‏.‏ قَالَتْ لاَ، إِلاَّ شَىْءٌ بَعَثَتْ بِهِ أُمُّ عَطِيَّةَ مِنَ الشَّاةِ الَّتِي بُعِثَ إِلَيْهَا مِنَ الصَّدَقَةِ‏.‏ قَالَ ‏"‏ إِنَّهَا قَدْ بَلَغَتْ مَحِلَّهَا ‏"‏‏.‏\hadithno{2579}\hadithtrans{Narrated Um 'Atiyya:Once the Prophet (ﷺ) went to `Aisha and asked her whether she had something (to eat). She said that she had nothing except the mutton which Um 'Atiyya had sent to (Barirah) in charity. The Prophet (ﷺ) said that it had reached its destination (i.e. it is no longer an object of charity)}}
\hadithdefcmd{bukhari}{2580}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّاسُ يَتَحَرَّوْنَ بِهَدَايَاهُمُ يَوْمِي‏.‏ وَقَالَتْ أُمُّ سَلَمَةَ إِنَّ صَوَاحِبِي اجْتَمَعْنَ‏.‏ فَذَكَرَتْ لَهُ، فَأَعْرَضَ عَنْهَا‏.‏\hadithno{2580}\hadithtrans{Narrated `Aisha:The people used to send gifts to the Prophet (ﷺ) on the day of my turn. Um Salama said: "My companions (the wives of the Prophet (ﷺ) Other than Aisha) gathered and they complained about it. So I informed the Prophet about it on their behalf, but he remained silent}}
\hadithdefcmd{bukhari}{2581}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ نِسَاءَ، رَسُولِ اللَّهِ صلى الله عليه وسلم كُنَّ حِزْبَيْنِ فَحِزْبٌ فِيهِ عَائِشَةُ وَحَفْصَةُ وَصَفِيَّةُ وَسَوْدَةُ، وَالْحِزْبُ الآخَرُ أُمُّ سَلَمَةَ وَسَائِرُ نِسَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم، وَكَانَ الْمُسْلِمُونَ قَدْ عَلِمُوا حُبَّ رَسُولِ اللَّهِ صلى الله عليه وسلم عَائِشَةَ، فَإِذَا كَانَتْ عِنْدَ أَحَدِهِمْ هَدِيَّةٌ يُرِيدُ أَنْ يُهْدِيَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَخَّرَهَا، حَتَّى إِذَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَيْتِ عَائِشَةَ بَعَثَ صَاحِبُ الْهَدِيَّةِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَيْتِ عَائِشَةَ، فَكَلَّمَ حِزْبُ أُمِّ سَلَمَةَ، فَقُلْنَ لَهَا كَلِّمِي رَسُولَ اللَّهِ صلى الله عليه وسلم يُكَلِّمُ النَّاسَ، فَيَقُولُ مَنْ أَرَادَ أَنْ يُهْدِيَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم هَدِيَّةً فَلْيُهْدِهِ إِلَيْهِ حَيْثُ كَانَ مِنْ بُيُوتِ نِسَائِهِ، فَكَلَّمَتْهُ أُمُّ سَلَمَةَ بِمَا قُلْنَ، فَلَمْ يَقُلْ لَهَا شَيْئًا، فَسَأَلْنَهَا‏.‏ فَقَالَتْ مَا قَالَ لِي شَيْئًا‏.‏ فَقُلْنَ لَهَا فَكَلِّمِيهِ‏.‏ قَالَتْ فَكَلَّمَتْهُ حِينَ دَارَ إِلَيْهَا أَيْضًا، فَلَمْ يَقُلْ لَهَا شَيْئًا، فَسَأَلْنَهَا‏.‏ فَقَالَتْ مَا قَالَ لِي شَيْئًا‏.‏ فَقُلْنَ لَهَا كَلِّمِيهِ حَتَّى يُكَلِّمَكِ‏.‏ فَدَارَ إِلَيْهَا فَكَلَّمَتْهُ‏.‏ فَقَالَ لَهَا ‏"‏ لاَ تُؤْذِينِي فِي عَائِشَةَ، فَإِنَّ الْوَحْىَ لَمْ يَأْتِنِي، وَأَنَا فِي ثَوْبِ امْرَأَةٍ إِلاَّ عَائِشَةَ ‏"‏‏.‏ قَالَتْ فَقَالَتْ أَتُوبُ إِلَى اللَّهِ مِنْ أَذَاكَ يَا رَسُولَ اللَّهِ‏.‏ ثُمَّ إِنَّهُنَّ دَعَوْنَ فَاطِمَةَ بِنْتَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَرْسَلْنَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم تَقُولُ إِنَّ نِسَاءَكَ يَنْشُدْنَكَ اللَّهَ الْعَدْلَ فِي بِنْتِ أَبِي بَكْرٍ‏.‏ فَكَلَّمَتْهُ‏.‏ فَقَالَ ‏"‏ يَا بُنَيَّةُ، أَلاَ تُحِبِّينَ مَا أُحِبُّ ‏"‏‏.‏ قَالَتْ بَلَى‏.‏ فَرَجَعَتْ إِلَيْهِنَّ، فَأَخْبَرَتْهُنَّ‏.‏ فَقُلْنَ ارْجِعِي إِلَيْهِ‏.‏ فَأَبَتْ أَنْ تَرْجِعَ، فَأَرْسَلْنَ زَيْنَبَ بِنْتَ جَحْشٍ، فَأَتَتْهُ فَأَغْلَظَتْ، وَقَالَتْ إِنَّ نِسَاءَكَ يَنْشُدْنَكَ اللَّهَ الْعَدْلَ فِي بِنْتِ ابْنِ أَبِي قُحَافَةَ‏.‏ فَرَفَعَتْ صَوْتَهَا، حَتَّى تَنَاوَلَتْ عَائِشَةَ‏.‏ وَهْىَ قَاعِدَةٌ، فَسَبَّتْهَا حَتَّى إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَيَنْظُرُ إِلَى عَائِشَةَ هَلْ تَكَلَّمُ قَالَ فَتَكَلَّمَتْ عَائِشَةُ تَرُدُّ عَلَى زَيْنَبَ، حَتَّى أَسْكَتَتْهَا‏.‏ قَالَتْ فَنَظَرَ النَّبِيُّ صلى الله عليه وسلم إِلَى عَائِشَةَ، وَقَالَ ‏"‏ إِنَّهَا بِنْتُ أَبِي بَكْرٍ ‏"‏‏.‏ قَالَ الْبُخَارِيُّ الْكَلاَمُ الأَخِيرُ قِصَّةُ فَاطِمَةَ يُذْكَرُ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ رَجُلٍ عَنِ الزُّهْرِيِّ عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ‏.‏ وَقَالَ أَبُو مَرْوَانَ عَنْ هِشَامٍ عَنْ عُرْوَةَ كَانَ النَّاسُ يَتَحَرَّوْنَ بِهَدَايَاهُمْ يَوْمَ عَائِشَةَ‏.‏ وَعَنْ هِشَامٍ عَنْ رَجُلٍ مِنْ قُرَيْشٍ، وَرَجُلٍ مِنَ الْمَوَالِي، عَنِ الزُّهْرِيِّ عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ قَالَتْ عَائِشَةُ كُنْتُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَاسْتَأْذَنَتْ فَاطِمَةُ‏.‏\hadithno{2581}\hadithtrans{Narrated `Urwa from `Aisha:The wives of Allah's Messenger (ﷺ) were in two groups. One group consisted of `Aisha, Hafsa, Safiyya and Sauda; and the other group consisted of Um Salama and the other wives of Allah's Messenger (ﷺ). The Muslims knew that Allah's Messenger (ﷺ) loved `Aisha, so if any of them had a gift and wished to give to Allah's Messenger (ﷺ), he would delay it, till Allah's Messenger (ﷺ) had come to `Aisha's home and then he would send his gift to Allah's Messenger (ﷺ) in her home. The group of Um Salama discussed the matter together and decided that Um Salama should request Allah's Messenger (ﷺ) to tell the people to send their gifts to him in whatever wife's house he was. Um Salama told Allah's Messenger (ﷺ) of what they had said, but he did not reply. Then they (those wives) asked Um Salama about it. She said, "He did not say anything to me." They asked her to talk to him again. She talked to him again when she met him on her day, but he gave no reply. When they asked her, she replied that he had given no reply. They said to her, "Talk to him till he gives you a reply." When it was her turn, she talked to him again. He then said to her, "Do not hurt me regarding Aisha, as the Divine Inspirations do not come to me on any of the beds except that of Aisha." On that Um Salama said, "I repent to Allah for hurting you." Then the group of Um Salama called Fatima, the daughter of Allah's Messenger (ﷺ) and sent her to Allah's Messenger (ﷺ) to say to him, "Your wives request to treat them and the daughter of Abu Bakr on equal terms." Then Fatima conveyed the message to him. The Prophet (ﷺ) said, "O my daughter! Don't you love whom I love?" She replied in the affirmative and returned and told them of the situation. They requested her to go to him again but she refused. They then sent Zainab bint Jahsh who went to him and used harsh words saying, "Your wives request you to treat them and the daughter of Ibn Abu Quhafa on equal terms." On that she raised her voice and abused `Aisha to her face so much so that Allah's Messenger (ﷺ) looked at `Aisha to see whether she would retort. `Aisha started replying to Zainab till she silenced her. The Prophet (ﷺ) then looked at `Aisha and said, "She is really the daughter of Abu Bakr}}
\hadithdefcmd{bukhari}{2582}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا عَزْرَةُ بْنُ ثَابِتٍ الأَنْصَارِيُّ، قَالَ حَدَّثَنِي ثُمَامَةُ بْنُ عَبْدِ اللَّهِ، قَالَ دَخَلْتُ عَلَيْهِ فَنَاوَلَنِي طِيبًا، قَالَ كَانَ أَنَسٌ ـ رضى الله عنه ـ لاَ يَرُدُّ الطِّيبَ‏.‏ قَالَ وَزَعَمَ أَنَسٌ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لاَ يَرُدُّ الطِّيبَ‏.‏\hadithno{2582}\hadithtrans{Narrated 'Azra bin Thabit Al-Ansari:When I went to Thumama bin `Abdullah, he gave me some perfume and said that Anas would not reject the gifts of perfume. Anas said: The Prophet (ﷺ) used not to reject the gifts of perfume}}
\hadithdefcmd{bukhari}{2583}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ ذَكَرَ عُرْوَةُ أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ، رضى الله عنهما وَمَرْوَانَ أَخْبَرَاهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم حِينَ جَاءَهُ وَفْدُ هَوَازِنَ قَامَ فِي النَّاسِ، فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ، ثُمَّ قَالَ ‏ "‏ أَمَّا بَعْدُ، فَإِنَّ إِخْوَانَكُمْ جَاءُونَا تَائِبِينَ، وَإِنِّي رَأَيْتُ أَنْ أَرُدَّ إِلَيْهِمْ سَبْيَهُمْ، فَمَنْ أَحَبَّ مِنْكُمْ أَنْ يُطَيِّبَ ذَلِكَ فَلْيَفْعَلْ، وَمَنْ أَحَبَّ أَنْ يَكُونَ عَلَى حَظِّهِ حَتَّى نُعْطِيَهُ إِيَّاهُ مِنْ أَوَّلِ مَا يُفِيءُ اللَّهُ عَلَيْنَا ‏"‏‏.‏ فَقَالَ النَّاسُ طَيَّبْنَا لَكَ‏.‏\hadithno{2583}\hadithtrans{Narrated Al-Miswar bin Makhrama and Marwan:When the delegates of the tribe of Hawazin came to the Prophet (ﷺ) he stood up amongst the people, Glorified and Praised Allah as He deserved, and said, "Then after: Your brethren have come to you with repentance and I see it logical to return to them their captives; so whoever amongst you likes to do that as a favor, then he can do it, and whoever of you like to stick to his share till we give him his right from the very first Fai (war booty) (1) which Allah will bestow on us, then (he can do so)." The people replied, "We do that (to return the captives) willingly as a favor for your sake}}
\hadithdefcmd{bukhari}{2585}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْبَلُ الْهَدِيَّةَ وَيُثِيبُ عَلَيْهَا‏.‏ لَمْ يَذْكُرْ وَكِيعٌ وَمُحَاضِرٌ عَنْ هِشَامٍ عَنْ أَبِيهِ عَنْ عَائِشَةَ‏.‏\hadithno{2585}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to accept gifts and used to give something in return}}
\hadithdefcmd{bukhari}{2586}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، وَمُحَمَّدِ بْنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّهُمَا حَدَّثَاهُ عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ أَبَاهُ، أَتَى بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنِّي نَحَلْتُ ابْنِي هَذَا غُلاَمًا‏.‏ فَقَالَ ‏"‏ أَكُلَّ وَلَدِكَ نَحَلْتَ مِثْلَهُ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ فَارْجِعْهُ ‏"‏‏.‏\hadithno{2586}\hadithtrans{Narrated An-Nu`man bin Bashir:that his father took him to Allah's Messenger (ﷺ) and said, "I have given this son of mine a slave." The Prophet asked, "Have you given all your sons the like?" He replied in the negative. The Prophet (ﷺ) said, "Take back your gift then}}
\hadithdefcmd{bukhari}{2587}{حَدَّثَنَا حَامِدُ بْنُ عُمَرَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ حُصَيْنٍ، عَنْ عَامِرٍ، قَالَ سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ ـ رضى الله عنهما ـ وَهُوَ عَلَى الْمِنْبَرِ يَقُولُ أَعْطَانِي أَبِي عَطِيَّةً، فَقَالَتْ عَمْرَةُ بِنْتُ رَوَاحَةَ لاَ أَرْضَى حَتَّى تُشْهِدَ رَسُولَ اللَّهِ صلى الله عليه وسلم‏.‏ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنِّي أَعْطَيْتُ ابْنِي مِنْ عَمْرَةَ بِنْتِ رَوَاحَةَ عَطِيَّةً، فَأَمَرَتْنِي أَنْ أُشْهِدَكَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ أَعْطَيْتَ سَائِرَ وَلَدِكَ مِثْلَ هَذَا ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ فَاتَّقُوا اللَّهَ، وَاعْدِلُوا بَيْنَ أَوْلاَدِكُمْ ‏"‏‏.‏ قَالَ فَرَجَعَ فَرَدَّ عَطِيَّتَهُ‏.‏\hadithno{2587}\hadithtrans{Narrated 'Amir:I heard An-Nu`man bin Bashir on the pulpit saying, "My father gave me a gift but `Amra bint Rawaha (my mother) said that she would not agree to it unless he made Allah's Messenger (ﷺ) as a witness to it. So, my father went to Allah's Messenger (ﷺ) and said, 'I have given a gift to my son from `Amra bint Rawaha, but she ordered me to make you as a witness to it, O Allah's Messenger (ﷺ)!' Allah's Messenger (ﷺ) asked, 'Have you given (the like of it) to everyone of your sons?' He replied in the negative. Allah's Messenger (ﷺ) said, 'Be afraid of Allah, and be just to your children.' My father then returned and took back his gift}}
\hadithdefcmd{bukhari}{2588}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، قَالَتْ عَائِشَةُ ـ رضى الله عنها ـ لَمَّا ثَقُلَ النَّبِيُّ صلى الله عليه وسلم فَاشْتَدَّ وَجَعُهُ اسْتَأْذَنَ أَزْوَاجَهُ أَنْ يُمَرَّضَ فِي بَيْتِي، فَأَذِنَّ لَهُ، فَخَرَجَ بَيْنَ رَجُلَيْنِ، تَخُطُّ رِجْلاَهُ الأَرْضَ، وَكَانَ بَيْنَ الْعَبَّاسِ، وَبَيْنَ رَجُلٍ آخَرَ‏.‏ فَقَالَ عُبَيْدُ اللَّهِ فَذَكَرْتُ لاِبْنِ عَبَّاسٍ مَا قَالَتْ عَائِشَةُ، فَقَالَ لِي وَهَلْ تَدْرِي مَنِ الرَّجُلُ الَّذِي لَمْ تُسَمِّ عَائِشَةُ قُلْتُ لاَ‏.‏ قَالَ هُوَ عَلِيُّ بْنُ أَبِي طَالِبٍ‏.‏\hadithno{2588}\hadithtrans{Narrated Az-Zuhri:Ubaidullah bin `Abdullah told me that `Aisha had said, "When the Prophet (ﷺ) became sick and his condition became serious, he requested his wives to allow him to be treated in my house, and they allowed him. He came out leaning on two men while his feet were dragging on the ground. He was walking between Al-`Abbas and another man." 'Ubaidullah said, "When I informed Ibn `Abbas of what `Aisha had said, he asked me whether I knew who was the second man whom `Aisha had not named. I replied in the negative. He said, 'He was `Ali bin Abi Talib}}
\hadithdefcmd{bukhari}{2589}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْعَائِدُ فِي هِبَتِهِ كَالْكَلْبِ يَقِيءُ، ثُمَّ يَعُودُ فِي قَيْئِهِ ‏"‏‏.‏\hadithno{2589}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "One who takes back his gift (which he has already given) is like a dog that swallows its vomit}}
\hadithdefcmd{bukhari}{2590}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ، عَنْ أَسْمَاءَ ـ رضى الله عنها ـ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ مَا لِي مَالٌ إِلاَّ مَا أَدْخَلَ عَلَىَّ الزُّبَيْرُ فَأَتَصَدَّقُ‏.‏ قَالَ ‏ "‏ تَصَدَّقِي، وَلاَ تُوعِي فَيُوعَى عَلَيْكِ ‏"‏‏.‏\hadithno{2590}\hadithtrans{Narrated Asma:Once I said, "O Allah's Messenger (ﷺ)! I have no property except what has been given to me by Az-Zubair (i.e. her husband). May I give in charity?" The Prophet (ﷺ) said, "Give in charity and do not withhold it; otherwise Allah will withhold it back from you}}
\hadithdefcmd{bukhari}{2591}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَنْفِقِي وَلاَ تُحْصِي فَيُحْصِيَ اللَّهُ عَلَيْكِ، وَلاَ تُوعِي فَيُوعِيَ اللَّهُ عَلَيْكِ ‏"‏‏.‏\hadithno{2591}\hadithtrans{Narrated Asma:Allah's Messenger (ﷺ) said, "Give (in charity) and do not give reluctantly lest Allah should give you in a limited amount; and do not withhold your money lest Allah should withhold it from you}}
\hadithdefcmd{bukhari}{2592}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، عَنِ اللَّيْثِ، عَنْ يَزِيدَ، عَنْ بُكَيْرٍ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ أَنَّ مَيْمُونَةَ بِنْتَ الْحَارِثِ ـ رضى الله عنها ـ أَخْبَرَتْهُ أَنَّهَا، أَعْتَقَتْ وَلِيدَةً وَلَمْ تَسْتَأْذِنِ النَّبِيَّ صلى الله عليه وسلم، فَلَمَّا كَانَ يَوْمُهَا الَّذِي يَدُورُ عَلَيْهَا فِيهِ قَالَتْ أَشَعَرْتَ يَا رَسُولَ اللَّهِ أَنِّي أَعْتَقْتُ وَلِيدَتِي قَالَ ‏"‏ أَوَفَعَلْتِ ‏"‏‏.‏ قَالَتْ نَعَمْ‏.‏ قَالَ ‏"‏ أَمَا إِنَّكِ لَوْ أَعْطَيْتِيهَا أَخْوَالَكِ كَانَ أَعْظَمَ لأَجْرِكِ ‏"‏‏.‏ وَقَالَ بَكْرُ بْنُ مُضَرَ عَنْ عَمْرٍو عَنْ بُكَيْرٍ عَنْ كُرَيْبٍ إِنَّ مَيْمُونَةَ أَعْتَقَتْ\hadithno{2592}\hadithtrans{Narrated Kuraib:the freed slave of Ibn `Abbas, that Maimuna bint Al-Harith told him that she manumitted a slave-girl without taking the permission of the Prophet. On the day when it was her turn to be with the Prophet, she said, "Do you know, O Allah's Messenger (ﷺ), that I have manumitted my slave-girl?" He said, "Have you really?" She replied in the affirmative. He said, "You would have got more reward if you had given her (i.e. the slave-girl) to one of your maternal uncles}}
\hadithdefcmd{bukhari}{2593}{حَدَّثَنَا حِبَّانُ بْنُ مُوسَى، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ سَفَرًا أَقْرَعَ بَيْنَ نِسَائِهِ، فَأَيَّتُهُنَّ خَرَجَ سَهْمُهَا خَرَجَ بِهَا مَعَهُ، وَكَانَ يَقْسِمُ لِكُلِّ امْرَأَةٍ مِنْهُنَّ يَوْمَهَا وَلَيْلَتَهَا، غَيْرَ أَنَّ سَوْدَةَ بِنْتَ زَمْعَةَ وَهَبَتْ يَوْمَهَا وَلَيْلَتَهَا، لِعَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم تَبْتَغِي بِذَلِكَ رِضَا رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{2593}\hadithtrans{Narrated Aisha:Whenever Allah's Messenger (ﷺ) wanted to go on a journey, he would draw lots as to which of his wives would accompany him. He would take her whose name came out. He used to fix for each of them a day and a night. But Sauda bint Zam`a gave up her (turn) day and night to `Aisha, the wife of the Prophet in order to seek the pleasure of Allah's Messenger (ﷺ) (by that action)}}
\hadithdefcmd{bukhari}{2594}{وَقَالَ بَكْرٌ عَنْ عَمْرٍو، عَنْ بُكَيْرٍ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ إِنَّ مَيْمُونَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَعْتَقَتْ وَلِيدَةً لَهَا فَقَالَ لَهَا ‏ "‏ وَلَوْ وَصَلْتِ بَعْضَ أَخْوَالِكِ كَانَ أَعْظَمَ لأَجْرِكِ ‏"‏‏.‏\hadithno{2594}\hadithtrans{Narrated Maimuna, the wife of the Prophet (ﷺ) that she manumitted her slave-girl and the Prophet (ﷺ) said to her, "You would have got more reward if you had given the slave-girl to one of your maternal uncles}}
\hadithdefcmd{bukhari}{2595}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ ـ رَجُلٍ مِنْ بَنِي تَيْمِ بْنِ مُرَّةَ ـ عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ، إِنَّ لِي جَارَيْنِ فَإِلَى أَيِّهِمَا أُهْدِي قَالَ ‏ "‏ إِلَى أَقْرَبِهِمَا مِنْكِ بَابًا ‏"‏‏.‏\hadithno{2595}\hadithtrans{Narrated Aisha:I said, "O Allah's Messenger (ﷺ)! I have two neighbors; which of them should I give a gift to?" The Prophet (ﷺ) said, "(Give) to the one whose door is nearer to you}}
\hadithdefcmd{bukhari}{2596}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّهُ، سَمِعَ الصَّعْبَ بْنَ جَثَّامَةَ اللَّيْثِيَّ،، وَكَانَ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم يُخْبِرُ أَنَّهُ أَهْدَى لِرَسُولِ اللَّهِ صلى الله عليه وسلم حِمَارَ وَحْشٍ وَهْوَ بِالأَبْوَاءِ ـ أَوْ بِوَدَّانَ ـ وَهْوَ مُحْرِمٌ فَرَدَّهُ، قَالَ صَعْبٌ فَلَمَّا عَرَفَ فِي وَجْهِي رَدَّهُ هَدِيَّتِي قَالَ ‏ "‏ لَيْسَ بِنَا رَدٌّ عَلَيْكَ، وَلَكِنَّا حُرُمٌ ‏"‏‏.‏\hadithno{2596}\hadithtrans{Narrated `Abdullah bin `Abbas:That he heard As-Sa'b bin Jath-thama Al-Laithi, who was one of the companions of the Prophet, saying that he gave the meat of an onager to Allah's Messenger (ﷺ) while he was at a place called Al-Abwa' or Waddan, and was in a state of Ihram. The Prophet (ﷺ) did not accept it. When the Prophet (ﷺ) saw the signs of sorrow on As-Sa'b's face because of not accepting his present, he said (to him), "We are not returning your present, but we are in the state of Ihram." (See Hadith No)}}
\hadithdefcmd{bukhari}{2597}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ ـ رضى الله عنه ـ قَالَ اسْتَعْمَلَ النَّبِيُّ صلى الله عليه وسلم رَجُلاً مِنَ الأَزْدِ يُقَالُ لَهُ ابْنُ اللُّتْبِيَّةِ عَلَى الصَّدَقَةِ، فَلَمَّا قَدِمَ قَالَ هَذَا لَكُمْ، وَهَذَا أُهْدِيَ لِي‏.‏ قَالَ ‏ "‏ فَهَلاَّ جَلَسَ فِي بَيْتِ أَبِيهِ أَوْ بَيْتِ أُمِّهِ، فَيَنْظُرَ يُهْدَى لَهُ أَمْ لاَ وَالَّذِي نَفْسِي بِيَدِهِ لاَ يَأْخُذُ أَحَدٌ مِنْهُ شَيْئًا إِلاَّ جَاءَ بِهِ يَوْمَ الْقِيَامَةِ يَحْمِلُهُ عَلَى رَقَبَتِهِ، إِنْ كَانَ بَعِيرًا لَهُ رُغَاءٌ أَوْ بَقَرَةً لَهَا خُوَارٌ أَوْ شَاةً تَيْعَرُ ـ ثُمَّ رَفَعَ بِيَدِهِ، حَتَّى رَأَيْنَا عُفْرَةَ إِبْطَيْهِ ـ اللَّهُمَّ هَلْ بَلَّغْتُ اللَّهُمَّ هَلْ بَلَّغْتُ ثَلاَثًا ‏"‏‏.‏\hadithno{2597}\hadithtrans{Narrated Abu Humaid Al-Sa`idi:The Prophet (ﷺ) appointed a man from the tribe of Al-Azd, called Ibn 'Utbiyya for collecting the Zakat. When he returned he said, "This (i.e. the Zakat) is for you and this has been given to me as a present." The Prophet (ﷺ) said, "Why hadn't he stayed in his father's or mother's house to see whether he would be given presents or not? By Him in Whose Hands my life is, whoever takes something from the resources of the Zakat (unlawfully) will be carrying it on his neck on the Day of Resurrection; if it be a camel, it will be grunting; if a cow, it will be mooing; and if a sheep, it will be bleating." The Prophet then raised his hands till we saw the whiteness of his armpits, and he said thrice, "O Allah! Haven't I conveyed Your Message (to them)?}}
\hadithdefcmd{bukhari}{2598}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا ابْنُ الْمُنْكَدِرِ، سَمِعْتُ جَابِرًا ـ رضى الله عنه ـ قَالَ قَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَوْ جَاءَ مَالُ الْبَحْرَيْنِ أَعْطَيْتُكَ هَكَذَا ثَلاَثًا ‏"‏‏.‏ فَلَمْ يَقْدَمْ حَتَّى تُوُفِّيَ النَّبِيُّ صلى الله عليه وسلم، فَأَمَرَ أَبُو بَكْرٍ مُنَادِيًا فَنَادَى مَنْ كَانَ لَهُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم عِدَةٌ أَوْ دَيْنٌ فَلْيَأْتِنَا‏.‏ فَأَتَيْتُهُ فَقُلْتُ إِنَّ النَّبِيَّ صلى الله عليه وسلم وَعَدَنِي‏.‏ فَحَثَى لِي ثَلاَثًا‏.‏\hadithno{2598}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) said to me, "I will give you so much (the Prophet (ﷺ) pointed thrice with his hands) when funds of Bahrain will come to me." But the Prophet (ﷺ) died before the money reached him. (When it came) Abu Bakr ordered an announcer to announce that whoever had a money claim on the Prophet (ﷺ) or was promised to be given something, should come to Abu Bakr. I went to Abu Bakr and told him that the Prophet (ﷺ) had promised to give me so much. On that Abu Bakr gave me three handfuls (of money)}}
\hadithdefcmd{bukhari}{2599}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ ـ رضى الله عنهما ـ قَالَ قَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَقْبِيَةً، وَلَمْ يُعْطِ مَخْرَمَةَ مِنْهَا شَيْئًا، فَقَالَ مَخْرَمَةُ يَا بُنَىَّ انْطَلِقْ بِنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَانْطَلَقْتُ مَعَهُ، فَقَالَ ادْخُلْ فَادْعُهُ لِي‏.‏ قَالَ فَدَعَوْتُهُ لَهُ فَخَرَجَ إِلَيْهِ، وَعَلَيْهِ قَبَاءٌ مِنْهَا، فَقَالَ ‏ "‏ خَبَأْنَا هَذَا لَكَ ‏"‏‏.‏ قَالَ فَنَظَرَ إِلَيْهِ، فَقَالَ رَضِيَ مَخْرَمَةُ‏.‏\hadithno{2599}\hadithtrans{Narrated Al-Miswar bin Makhrama:Allah's Messenger (ﷺ) distributed some cloaks but did not give anything thereof to Makhrama. Makhrama said (to me), "O son! accompany me to Allah's Messenger (ﷺ)." When I went with him, he said, "Call him to me." I called him (i.e. the Prophet (ﷺ) ) for my father. He came out wearing one of those cloaks and said, "We kept this (cloak) for you, (Makhrama)." Makhrama looked at the cloak and said, "Makhrama is pleased," (or the Prophet (ﷺ) said), "Is Makhrama pleased?}}
\hadithdefcmd{bukhari}{2600}{حَدَّثَنَا مُحَمَّدُ بْنُ مَحْبُوبٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ هَلَكْتُ‏.‏ فَقَالَ ‏"‏ وَمَا ذَاكَ ‏"‏‏.‏ قَالَ وَقَعْتُ بِأَهْلِي فِي رَمَضَانَ‏.‏ قَالَ ‏"‏ تَجِدُ رَقَبَةً ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ فَهَلْ تَسْتَطِيعُ أَنْ تَصُومَ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ ‏"‏ فَتَسْتَطِيعُ أَنْ تُطْعِمَ سِتِّينَ مِسْكِينًا ‏"‏‏.‏ قَالَ لاَ‏.‏ قَالَ فَجَاءَ رَجُلٌ مِنَ الأَنْصَارِ بِعَرَقٍ ـ وَالْعَرَقُ الْمِكْتَلُ ـ فِيهِ تَمْرٌ فَقَالَ ‏"‏ اذْهَبْ بِهَذَا فَتَصَدَّقْ بِهِ ‏"‏‏.‏ قَالَ عَلَى أَحْوَجَ مِنَّا يَا رَسُولَ اللَّهِ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا بَيْنَ لاَبَتَيْهَا أَهْلُ بَيْتٍ أَحْوَجُ مِنَّا‏.‏ قَالَ ‏"‏ اذْهَبْ فَأَطْعِمْهُ أَهْلَكَ ‏"‏‏.‏\hadithno{2600}\hadithtrans{Narrated Abu Huraira:A man came to Allah's Messenger (ﷺ) and said, "I am ruined." The Prophet (ﷺ) asked, "What do you mean?" He said, "I had a sexual intercourse with my wife during Ramadan (while fasting)." The Prophet (ﷺ) asked him, "Can you manumit a slave?" He replied in the negative. He then asked him, "Can you fast for two successive months continuously" He replied in the negative. The Prophet (ﷺ) then asked him, "Can you feed sixty poor persons?" He replied in the negative. In the meantime an Ansari came with a basket full of dates. The Prophet (ﷺ) said to the man, "Take it and give it in charity (as an expiation of your sin)." The man said "Should I give it to some people who are poorer than we O Allah's Messenger (ﷺ)? By Him Who has sent you with the Truth, there is no family between Medina's two mountains poorer than we." Allah's Messenger (ﷺ) told him to take it and provide his family with it}}
\hadithdefcmd{bukhari}{2601}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ،‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي ابْنُ كَعْبِ بْنِ مَالِكٍ، أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ أَبَاهُ قُتِلَ يَوْمَ أُحُدٍ شَهِيدًا، فَاشْتَدَّ الْغُرَمَاءُ فِي حُقُوقِهِمْ، فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَكَلَّمْتُهُ، فَسَأَلَهُمْ أَنْ يَقْبَلُوا ثَمَرَ حَائِطِي، وَيُحَلِّلُوا أَبِي، فَأَبَوْا، فَلَمْ يُعْطِهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم حَائِطِي، وَلَمْ يَكْسِرْهُ لَهُمْ، وَلَكِنْ قَالَ ‏"‏ سَأَغْدُو عَلَيْكَ ‏"‏‏.‏ فَغَدَا عَلَيْنَا حَتَّى أَصْبَحَ، فَطَافَ فِي النَّخْلِ، وَدَعَا فِي ثَمَرِهِ بِالْبَرَكَةِ، فَجَدَدْتُهَا، فَقَضَيْتُهُمْ حُقُوقَهُمْ، وَبَقِيَ لَنَا مِنْ ثَمَرِهَا بَقِيَّةٌ، ثُمَّ جِئْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهْوَ جَالِسٌ، فَأَخْبَرْتُهُ بِذَلِكَ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِعُمَرَ ‏"‏ اسْمَعْ ـ وَهْوَ جَالِسٌ ـ يَا عُمَرُ ‏"‏‏.‏ فَقَالَ أَلاَّ يَكُونُ قَدْ عَلِمْنَا أَنَّكَ رَسُولُ اللَّهِ، وَاللَّهِ إِنَّكَ لَرَسُولُ اللَّهِ‏.‏\hadithno{2601}\hadithtrans{Narrated Jabir bin `Abdullah:My father was martyred on the day (of the battle) of Uhud and his creditors demanded the debt back in a harsh manner. So I went to Allah's Messenger (ﷺ) and informed him of that, he asked them to accept the fruits of my garden and excuse my father, but they refused. So, Allah's Messenger (ﷺ) did not give them the fruits, nor did he cut them and distribute them among them, but said, "I will come to you tomorrow morning." So, he came to us the next morning and walked about in between the date-palms and invoked Allah to bless their fruits. I plucked the fruits and gave back all the rights of the creditors in full, and a lot of fruits were left for us. Then I went to Allah's Messenger (ﷺ), who was sitting, and informed him about what happened. Allah's Messenger (ﷺ) told `Umar, who was sitting there, to listen to the story. `Umar said, "Don't we know that you are Allah's Messenger (ﷺ)? By Allah! you are Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{2602}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِشَرَابٍ فَشَرِبَ، وَعَنْ يَمِينِهِ غُلاَمٌ وَعَنْ يَسَارِهِ الأَشْيَاخُ فَقَالَ لِلْغُلاَمِ ‏ "‏ إِنْ أَذِنْتَ لِي أَعْطَيْتُ هَؤُلاَءِ ‏"‏‏.‏ فَقَالَ مَا كُنْتُ لأُوثِرَ بِنَصِيبِي مِنْكَ يَا رَسُولَ اللَّهِ أَحَدًا‏.‏ فَتَلَّهُ فِي يَدِهِ‏.‏\hadithno{2602}\hadithtrans{Narrated Sahl bin Sa`d:A drink (milk mixed with water) was brought to the Prophet (ﷺ) who drank some of it while a boy was sitting on his right and old men on his left. The Prophet (ﷺ) said to the boy, "If you permit me, I'll give (the rest of the drink to) these old men first." The boy said, "I will not give preference to any one over me as regards my share from you, O Allah's Messenger (ﷺ)!" The Prophet (ﷺ) then put that container in the boy's hand. (See Hadith No)}}
\hadithdefcmd{bukhari}{2603}{حَدَّثَنَا ثَابِتٌ حَدَّثَنَا مِسْعَرٌ عَنْ مُحَارِبٍ عَنْ جَابِرٍ رَضِيَ اللَّهُ عَنْهُ أَتَيْتُ النَّبِيَّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ فِي الْمَسْجِدِ فَقَضَانِي وَزَادَنِي\hadithno{2603}\hadithtrans{Jabir (ra) said, "I went to the Prophet (ﷺ) in the mosque and he paid me my right and gave me more than he owed me}}
\hadithdefcmd{bukhari}{2604}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَارِبٍ، سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ يَقُولُ بِعْتُ مِنَ النَّبِيِّ صلى الله عليه وسلم بَعِيرًا فِي سَفَرٍ، فَلَمَّا أَتَيْنَا الْمَدِينَةَ قَالَ ‏ "‏ ائْتِ الْمَسْجِدَ فَصَلِّ رَكْعَتَيْنِ ‏"‏‏.‏ فَوَزَنَ ـ قَالَ شُعْبَةُ أُرَاهُ فَوَزَنَ لِي فَأَرْجَحَ، فَمَا زَالَ مِنْهَا شَىْءٌ حَتَّى أَصَابَهَا أَهْلُ الشَّأْمِ يَوْمَ الْحَرَّةِ‏.‏\hadithno{2604}\hadithtrans{Narrated Jabir bin `Abdullah:I sold a camel to the Prophet (ﷺ) on one of the journeys. When we reached Medina, he ordered me to go to the Mosque and offer two rak`at. Then he weighed for me (the price of the camel in gold) and gave an extra amount over it. A part of it remained with me till it was taken by the army of Sham on the day of Harra}}
\hadithdefcmd{bukhari}{2605}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِشَرَابٍ، وَعَنْ يَمِينِهِ غُلاَمٌ وَعَنْ يَسَارِهِ أَشْيَاخٌ، فَقَالَ لِلْغُلاَمِ ‏ "‏ أَتَأْذَنُ لِي أَنْ أُعْطِيَ هَؤُلاَءِ ‏"‏‏.‏ فَقَالَ الْغُلاَمُ لاَ، وَاللَّهِ لاَ أُوثِرُ بِنَصِيبِي مِنْكَ أَحَدًا‏.‏ فَتَلَّهُ فِي يَدِهِ‏.‏\hadithno{2605}\hadithtrans{Narrated Sahl bin Sa`d:A drink (of milk and water) was brought to Allah's Messenger (ﷺ) while a boy was sitting on his right side and old men were sitting on his left side. He asked the boy, "Will you allow me to give it to these (people)?" The boy said, "No, by Allah, I will not allow anyone to take my right from you." Then the Prophet put the bowl in the boy's hand}}
\hadithdefcmd{bukhari}{2606}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ جَبَلَةَ، قَالَ أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، عَنْ سَلَمَةَ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ كَانَ لِرَجُلٍ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم دَيْنٌ فَهَمَّ بِهِ أَصْحَابُهُ، فَقَالَ ‏"‏ دَعُوهُ فَإِنَّ لِصَاحِبِ الْحَقِّ مَقَالاً‏.‏ وَقَالَ اشْتَرُوا لَهُ سِنًّا فَأَعْطُوهَا إِيَّاهُ ‏"‏‏.‏ فَقَالُوا إِنَّا لاَ نَجِدُ سِنًّا إِلاَّ سِنًّا هِيَ أَفْضَلُ مِنْ سِنِّهِ‏.‏ قَالَ ‏"‏ فَاشْتَرُوهَا فَأَعْطُوهَا إِيَّاهُ، فَإِنَّ مِنْ خَيْرِكُمْ أَحْسَنَكُمْ قَضَاءً ‏"‏‏.‏\hadithno{2606}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) owed a man some debt (and that man demanded it very harshly). The companions of the Prophet (ﷺ) wanted to harm him, but the Prophet (ﷺ) said to them, "Leave him, as the creditor has the right to speak harshly." He then added, "Buy (a camel) of the same age and give it to him." They said, "We cannot get except a camel of an older age than that of his." He said, "Buy it and give it to him, as the best amongst you is he who pays back his debt in the most handsome way}}
\hadithdefcmd{bukhari}{2607}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ مَرْوَانَ بْنَ الْحَكَمِ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَاهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ حِينَ جَاءَهُ وَفْدُ هَوَازِنَ مُسْلِمِينَ، فَسَأَلُوهُ أَنْ يَرُدَّ إِلَيْهِمْ أَمْوَالَهُمْ وَسَبْيَهُمْ فَقَالَ لَهُمْ ‏"‏ مَعِي مَنْ تَرَوْنَ، وَأَحَبُّ الْحَدِيثِ إِلَىَّ أَصْدَقُهُ، فَاخْتَارُوا إِحْدَى الطَّائِفَتَيْنِ إِمَّا السَّبْىَ وَإِمَّا الْمَالَ، وَقَدْ كُنْتُ اسْتَأْنَيْتُ ‏"‏‏.‏ وَكَانَ النَّبِيُّ صلى الله عليه وسلم انْتَظَرَهُمْ بِضْعَ عَشْرَةَ لَيْلَةً حِينَ قَفَلَ مِنَ الطَّائِفِ، فَلَمَّا تَبَيَّنَ لَهُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم غَيْرُ رَادٍّ إِلَيْهِمْ إِلاَّ إِحْدَى الطَّائِفَتَيْنِ قَالُوا فَإِنَّا نَخْتَارُ سَبْيَنَا‏.‏ فَقَامَ فِي الْمُسْلِمِينَ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَإِنَّ إِخْوَانَكُمْ هَؤُلاَءِ جَاءُونَا تَائِبِينَ، وَإِنِّي رَأَيْتُ أَنْ أَرُدَّ إِلَيْهِمْ سَبْيَهُمْ، فَمَنْ أَحَبَّ مِنْكُمْ أَنْ يُطَيِّبَ ذَلِكَ فَلْيَفْعَلْ، وَمَنْ أَحَبَّ أَنْ يَكُونَ عَلَى حَظِّهِ حَتَّى نُعْطِيَهُ إِيَّاهُ مِنْ أَوَّلِ مَا يُفِيءُ اللَّهُ عَلَيْنَا فَلْيَفْعَلْ ‏"‏‏.‏ فَقَالَ النَّاسُ طَيَّبْنَا يَا رَسُولَ اللَّهِ لَهُمْ‏.‏ فَقَالَ لَهُمْ ‏"‏ إِنَّا لاَ نَدْرِي مَنْ أَذِنَ مِنْكُمْ فِيهِ مِمَّنْ لَمْ يَأْذَنْ، فَارْجِعُوا حَتَّى يَرْفَعَ إِلَيْنَا عُرَفَاؤُكُمْ أَمْرَكُمْ ‏"‏‏.‏ فَرَجَعَ النَّاسُ فَكَلَّمَهُمْ عُرَفَاؤُهُمْ، ثُمَّ رَجَعُوا إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرُوهُ أَنَّهُمْ طَيَّبُوا وَأَذِنُوا‏.‏ وَهَذَا الَّذِي بَلَغَنَا مِنْ سَبْىِ هَوَازِنَ هَذَا آخِرُ قَوْلِ الزُّهْرِيِّ، يَعْنِي فَهَذَا الَّذِي بَلَغَنَا‏.‏\hadithno{2607}\hadithtrans{Narrated Marwan bin Al-Hakam and Al-Miswar bin Makhrama:When the delegates of the tribe of Hawazin came to the Prophet (ﷺ) they requested him to return their property and their captives. He said to them, "This concerns also other people along with me as you see, and the best statement to me is the true one, so you may choose one of two alternatives; either the captives or the property and (I have not distributed the booty for) I have been waiting for you." When the Prophet (ﷺ) had returned from Ta'if, he waited for them for more than ten nights. When they came to know that the Prophet (ﷺ) would not return except one of the two, they chose their captives. The Prophet then stood up amongst the Muslims, Glorified and Praised Allah as He deserved, and then said, "Then after: These brothers of yours have come to you with repentance and I see it proper to return their captives, so whoever amongst you likes to do that as a favor, then he can do it, and whoever of you wants to stick to his share till we pay him from the very first Fai (i.e. war booty) which Allah will give us, then he can do so." The people said, "We return (the captives) to them willingly as a favor, O Allah's Messenger (ﷺ)!" The Prophet (ﷺ) said, "I do not know who of you has given his consent and who has not; so go back and your leaders may present your decision to me." The people went away, and their leaders discussed the matter with them, and then came to the Prophet (ﷺ) to tell him that all of them had given their consent (to return the captives) willingly. (Az-Zuhri, the sub-narrator said, "This is what we know about the captives of Hawazin)}}
\hadithdefcmd{bukhari}{2609}{حَدَّثَنَا ابْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا شُعْبَةُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ أَخَذَ سِنًّا فَجَاءَ صَاحِبُهُ يَتَقَاضَاهُ فَقَالَ ‏"‏ إِنَّ لِصَاحِبِ الْحَقِّ مَقَالاً ‏"‏‏.‏ ثُمَّ قَضَاهُ أَفْضَلَ مِنْ سِنِّهِ وَقَالَ ‏"‏ أَفْضَلُكُمْ أَحْسَنُكُمْ قَضَاءً ‏"‏‏.‏\hadithno{2609}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) took a camel of special age from somebody on credit. Its owner came and demanded it back (harshly). The Prophet (ﷺ) said, "No doubt, he who has a right, can demand it." Then the Prophet (ﷺ) gave him an older camel than his camel and said, "The best amongst you is he who repays his debts in the most handsome way}}
\hadithdefcmd{bukhari}{2610}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ كَانَ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَكَانَ عَلَى بَكْرٍ لِعُمَرَ صَعْبٍ، فَكَانَ يَتَقَدَّمُ النَّبِيَّ صلى الله عليه وسلم فَيَقُولُ أَبُوهُ يَا عَبْدَ اللَّهِ لاَ يَتَقَدَّمِ النَّبِيَّ صلى الله عليه وسلم أَحَدٌ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بِعْنِيهِ ‏"‏‏.‏ فَقَالَ عُمَرُ هُوَ لَكَ‏.‏ فَاشْتَرَاهُ ثُمَّ قَالَ ‏"‏ هُوَ لَكَ يَا عَبْدَ اللَّهِ، فَاصْنَعْ بِهِ مَا شِئْتَ ‏"‏‏.‏\hadithno{2610}\hadithtrans{Narrated Ibn `Umar:That he was in the company of the Prophet (ﷺ) on a journey, riding a troublesome camel belonging to `Umar. The camel used to go ahead of the Prophet, so Ibn `Umar's father would say, "O `Abdullah! No one should go ahead of the Prophet." The Prophet (ﷺ) said to him, "Sell it to me." `Umar said to the Prophet "It is for you." So, he bought it and said, "O `Abdullah! It is for you, and you can do with it what you like}}
\hadithdefcmd{bukhari}{2611}{وَقَالَ الْحُمَيْدِيُّ حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ، وَكُنْتُ عَلَى بَكْرٍ صَعْبٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لِعُمَرَ ‏"‏ بِعْنِيهِ ‏"‏‏.‏ فَابْتَاعَهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هُوَ لَكَ يَا عَبْدَ اللَّهِ ‏"‏‏.‏\hadithno{2611}\hadithtrans{Narrated Ibn 'Umar (ra):We were in the company of the Prophet (ﷺ) on a journey, and I was riding a troublesome camel. The Prophet (ﷺ) asked 'Umar to sell that camel to him. So, 'Umar sold it to him. The Prophet (ﷺ) then said, "O 'Abdullah! The camel is for you}}
\hadithdefcmd{bukhari}{2612}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ رَأَى عُمَرُ بْنُ الْخَطَّابِ حُلَّةً سِيَرَاءَ عِنْدَ باب الْمَسْجِدِ فَقَالَ يَا رَسُولَ اللَّهِ لَوِ اشْتَرَيْتَهَا فَلَبِسْتَهَا يَوْمَ الْجُمُعَةِ وَلِلْوَفْدِ قَالَ ‏"‏ إِنَّمَا يَلْبَسُهَا مَنْ لاَ خَلاَقَ لَهُ فِي الآخِرَةِ ‏"‏‏.‏ ثُمَّ جَاءَتْ حُلَلٌ فَأَعْطَى رَسُولُ اللَّهِ صلى الله عليه وسلم عُمَرَ مِنْهَا حُلَّةً، وَقَالَ أَكَسَوْتَنِيهَا وَقُلْتَ فِي حُلَّةِ عُطَارِدٍ مَا قُلْتَ‏.‏ فَقَالَ ‏"‏ إِنِّي لَمْ أَكْسُكَهَا لِتَلْبَسَهَا ‏"‏‏.‏ فَكَسَا عُمَرُ أَخًا لَهُ بِمَكَّةَ مُشْرِكًا‏.‏\hadithno{2612}\hadithtrans{Narrated `Abdullah bin `Umar:`Umar bin Al-Khattab saw a silken dress (cloak) being sold at the gate of the Mosque and said, "O Allah's Messenger (ﷺ)! Would that you buy it and wear it on Fridays and when the delegates come to you!" Allah's Messenger (ﷺ) said, "This is worn by the one who will have no share in the Hereafter." Later on some silk dresses were brought and Allah's Messenger (ﷺ) sent one of them to `Umar. `Umar said, "How do you give me this to wear while you said what you said about the dress of 'Utarid?" Allah's Messenger (ﷺ) said, "I have not given it to you to wear." So, `Umar gave it to a pagan brother of his in Mecca}}
\hadithdefcmd{bukhari}{2613}{حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ أَبُو جَعْفَرٍ، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ أَبِيهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ أَتَى النَّبِيُّ صلى الله عليه وسلم بَيْتَ فَاطِمَةَ فَلَمْ يَدْخُلْ عَلَيْهَا، وَجَاءَ عَلِيٌّ فَذَكَرَتْ لَهُ ذَلِكَ فَذَكَرَهُ لِلنَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنِّي رَأَيْتُ عَلَى بَابِهَا سِتْرًا مَوْشِيًّا ‏"‏‏.‏ فَقَالَ ‏"‏ مَا لِي وَلِلدُّنْيَا ‏"‏‏.‏ فَأَتَاهَا عَلِيٌّ فَذَكَرَ ذَلِكَ لَهَا فَقَالَتْ لِيَأْمُرْنِي فِيهِ بِمَا شَاءَ‏.‏ قَالَ تُرْسِلُ بِهِ إِلَى فُلاَنٍ‏.‏ أَهْلِ بَيْتٍ بِهِمْ حَاجَةٌ‏.‏\hadithno{2613}\hadithtrans{Narrated Ibn `Umar:Once the Prophet (ﷺ) went to the house of Fatima but did not enter it. `Ali came and she told him about that. When 'Ali asked the Prophet (ﷺ) about it, he said, "I saw a (multicolored) decorated curtain on her door. I am not interested in worldly things." `Ali went to Fatima and told her about it. Fatima said, "I am ready to dispense with it in the way he suggests." The Prophet (ﷺ) ordered her to send it to such-andsuch needy people}}
\hadithdefcmd{bukhari}{2614}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَبْدُ الْمَلِكِ بْنُ مَيْسَرَةَ، قَالَ سَمِعْتُ زَيْدَ بْنَ وَهْبٍ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ أَهْدَى إِلَىَّ النَّبِيُّ صلى الله عليه وسلم حُلَّةً سِيَرَاءَ فَلَبِسْتُهَا، فَرَأَيْتُ الْغَضَبَ فِي وَجْهِهِ، فَشَقَقْتُهَا بَيْنَ نِسَائِي‏.‏\hadithno{2614}\hadithtrans{Narrated `Ali:The Prophet (ﷺ) gave me a silken dress as a gift and I wore it. When I saw the signs of anger on his face, I cut it into pieces and distributed it among my wives}}
\hadithdefcmd{bukhari}{2616}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسٌ ـ رضى الله عنه ـ قَالَ أُهْدِيَ لِلنَّبِيِّ صلى الله عليه وسلم جُبَّةُ سُنْدُسٍ، وَكَانَ يَنْهَى عَنِ الْحَرِيرِ، فَعَجِبَ النَّاسُ مِنْهَا فَقَالَ ‏ "‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَمَنَادِيلُ سَعْدِ بْنِ مُعَاذٍ فِي الْجَنَّةِ أَحْسَنُ مِنْ هَذَا ‏"‏‏.‏ وَقَالَ سَعِيدٌ عَنْ قَتَادَةَ، عَنْ أَنَسٍ، إِنَّ أُكَيْدِرَ دُومَةَ أَهْدَى إِلَى النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2616}\hadithtrans{Narrated Anas:A Jubba (i.e. cloak) made of thick silken cloth was presented to the Prophet. The Prophet (ﷺ) used to forbid people to wear silk. So, the people were pleased to see it. The Prophet (ﷺ) said, "By Him in Whose Hands Muhammad's soul is, the handkerchiefs of Sa`d bin Mu`adh in Paradise are better than this." Anas added, "The present was sent to the Prophet (ﷺ) by Ukaidir (a Christian) from Dauma}}
\hadithdefcmd{bukhari}{2617}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ يَهُودِيَّةً، أَتَتِ النَّبِيَّ صلى الله عليه وسلم بِشَاةٍ مَسْمُومَةٍ، فَأَكَلَ مِنْهَا فَجِيءَ بِهَا فَقِيلَ أَلاَ نَقْتُلُهَا‏.‏ قَالَ ‏ "‏ لاَ ‏"‏‏.‏ فَمَا زِلْتُ أَعْرِفُهَا فِي لَهَوَاتِ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{2617}\hadithtrans{Narrated Anas bin Malik:A Jewess brought a poisoned (cooked) sheep for the Prophet (ﷺ) who ate from it. She was brought to the Prophet and he was asked, "Shall we kill her?" He said, "No." I continued to see the effect of the poison on the palate of the mouth of Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{2618}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، عَنْ أَبِي عُثْمَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم ثَلاَثِينَ وَمِائَةً فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلْ مَعَ أَحَدٍ مِنْكُمْ طَعَامٌ ‏"‏‏.‏ فَإِذَا مَعَ رَجُلٍ صَاعٌ مِنْ طَعَامٍ أَوْ نَحْوُهُ، فَعُجِنَ ثُمَّ جَاءَ رَجُلٌ مُشْرِكٌ مُشْعَانٌّ طَوِيلٌ بِغَنَمٍ يَسُوقُهَا، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بَيْعًا أَمْ عَطِيَّةً ـ أَوْ قَالَ ـ أَمْ هِبَةً ‏"‏‏.‏ قَالَ لاَ، بَلْ بَيْعٌ‏.‏ فَاشْتَرَى مِنْهُ شَاةً، فَصُنِعَتْ وَأَمَرَ النَّبِيُّ صلى الله عليه وسلم بِسَوَادِ الْبَطْنِ أَنْ يُشْوَى، وَايْمُ اللَّهِ مَا فِي الثَّلاَثِينَ وَالْمِائَةِ إِلاَّ قَدْ حَزَّ النَّبِيُّ صلى الله عليه وسلم لَهُ حُزَّةً مِنْ سَوَادِ بَطْنِهَا، إِنْ كَانَ شَاهِدًا أَعْطَاهَا إِيَّاهُ، وَإِنْ كَانَ غَائِبًا خَبَأَ لَهُ، فَجَعَلَ مِنْهَا قَصْعَتَيْنِ، فَأَكَلُوا أَجْمَعُونَ، وَشَبِعْنَا، فَفَضَلَتِ الْقَصْعَتَانِ، فَحَمَلْنَاهُ عَلَى الْبَعِيرِ‏.‏ أَوْ كَمَا قَالَ‏.‏\hadithno{2618}\hadithtrans{Narrated `Abdur-Rahman bin Abu Bakr:We were one-hundred and thirty persons accompanying the Prophet (ﷺ) who asked us whether anyone of us had food. There was a man who had about a Sa of wheat which was mixed with water then. A very tall pagan came driving sheep. The Prophet (ﷺ) asked him, "Will you sell us (a sheep) or give it as a present?" He said, "I will sell you (a sheep)." The Prophet (ﷺ) bought a sheep and it was slaughtered. The Prophet ordered that its liver and other Abdominal organs be roasted. By Allah, the Prophet (ﷺ) gave every person of the one-hundred-and-thirty a piece of that; he gave all those of them who were present; and kept the shares of those who were absent. The Prophet (ﷺ) then put its meat in two huge basins and all of them ate to their fill, and even then more food was left in the two basins which were carried on the camel (or said something like it)}}
\hadithdefcmd{bukhari}{2619}{حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ رَأَى عُمَرُ حُلَّةً عَلَى رَجُلٍ تُبَاعُ فَقَالَ لِلنَّبِيِّ صلى الله عليه وسلم ابْتَعْ هَذِهِ الْحُلَّةَ تَلْبَسْهَا يَوْمَ الْجُمُعَةِ وَإِذَا جَاءَكَ الْوَفْدُ‏.‏ فَقَالَ ‏"‏ إِنَّمَا يَلْبَسُ هَذَا مَنْ لاَ خَلاَقَ لَهُ فِي الآخِرَةِ ‏"‏‏.‏ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْهَا بِحُلَلٍ فَأَرْسَلَ إِلَى عُمَرَ مِنْهَا بِحُلَّةٍ‏.‏ فَقَالَ عُمَرُ كَيْفَ أَلْبَسُهَا وَقَدْ قُلْتَ فِيهَا مَا قُلْتَ قَالَ ‏"‏ إِنِّي لَمْ أَكْسُكَهَا لِتَلْبَسَهَا، تَبِيعُهَا أَوْ تَكْسُوهَا ‏"‏‏.‏ فَأَرْسَلَ بِهَا عُمَرُ إِلَى أَخٍ لَهُ مِنْ أَهْلِ مَكَّةَ قَبْلَ أَنْ يُسْلِمَ‏.‏\hadithno{2619}\hadithtrans{Narrated Ibn `Umar:`Umar saw a silken cloak over a man for sale and requested the Prophet (ﷺ) to buy it in order to wear it on Fridays and while meeting delegates. The Prophet (ﷺ) said, "This is worn by the one who will have no share in the Hereafter." Later on Allah's Messenger (ﷺ) got some silken cloaks similar to that one, and he sent one to `Umar. `Umar said to the Prophet (ﷺ) "How can I wear it, while you said about it what you said?" The Prophet (ﷺ) said, "I have not given it to you to wear, but to sell or to give to someone else." So, `Umar sent it to his brother at Mecca before he embraced Islam}}
\hadithdefcmd{bukhari}{2620}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ قَالَتْ قَدِمَتْ عَلَىَّ أُمِّي وَهْىَ مُشْرِكَةٌ، فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم، فَاسْتَفْتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قُلْتُ ‏\{‏إِنَّ أُمِّي قَدِمَتْ‏\}‏ وَهْىَ رَاغِبَةٌ، أَفَأَصِلُ أُمِّي قَالَ ‏ "‏ نَعَمْ صِلِي أُمَّكِ ‏"‏‏.‏\hadithno{2620}\hadithtrans{Narrated Asma' bint Abu Bakr:My mother came to me during the lifetime of Allah's Messenger (ﷺ) and she was a pagan. I said to Allah's Apostle (seeking his verdict), "My mother has come to me and she desires to receive a reward from me, shall I keep good relations with her?" The Prophet (ﷺ) said, "Yes, keep good relation with her}}
\hadithdefcmd{bukhari}{2621}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، وَشُعْبَةُ، قَالاَ حَدَّثَنَا قَتَادَةُ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْعَائِدُ فِي هِبَتِهِ كَالْعَائِدِ فِي قَيْئِهِ ‏"‏‏.‏\hadithno{2621}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "He who takes back his present is like him who swallows his vomit}}
\hadithdefcmd{bukhari}{2622}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْمُبَارَكِ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَيْسَ لَنَا مَثَلُ السَّوْءِ، الَّذِي يَعُودُ فِي هِبَتِهِ كَالْكَلْبِ يَرْجِعُ فِي قَيْئِهِ ‏"‏‏.‏\hadithno{2622}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "The bad example is not for us. He who takes back his present is like a dog that swallows back its vomit}}
\hadithdefcmd{bukhari}{2623}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ يَقُولُ حَمَلْتُ عَلَى فَرَسٍ فِي سَبِيلِ اللَّهِ، فَأَضَاعَهُ الَّذِي كَانَ عِنْدَهُ، فَأَرَدْتُ أَنْ أَشْتَرِيَهُ مِنْهُ، وَظَنَنْتُ أَنَّهُ بَائِعُهُ بِرُخْصٍ، فَسَأَلْتُ عَنْ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تَشْتَرِهِ، وَإِنْ أَعْطَاكَهُ بِدِرْهَمٍ وَاحِدٍ، فَإِنَّ الْعَائِدَ فِي صَدَقَتِهِ كَالْكَلْبِ يَعُودُ فِي قَيْئِهِ ‏"‏‏.‏\hadithno{2623}\hadithtrans{Narrated `Umar bin Al-Khattab:I gave a horse in Allah's Cause. The person to whom it was given, did not look after it. I intended to buy it from him, thinking that he would sell it cheap. When I asked the Prophet (ﷺ) he said, "Don't buy it, even if he gives it to you for one Dirham, as the person who takes back what he has given in charity, is like a dog that swallows back its vomit}}
\hadithdefcmd{bukhari}{2624}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عُبَيْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، أَنَّ بَنِي صُهَيْبٍ، مَوْلَى ابْنِ جُدْعَانَ ادَّعَوْا بَيْتَيْنِ وَحُجْرَةً، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْطَى ذَلِكَ صُهَيْبًا، فَقَالَ مَرْوَانُ مَنْ يَشْهَدُ لَكُمَا عَلَى ذَلِكَ قَالُوا ابْنُ عُمَرَ‏.‏ فَدَعَاهُ فَشَهِدَ لأَعْطَى رَسُولُ اللَّهِ صلى الله عليه وسلم صُهَيْبًا بَيْتَيْنِ وَحُجْرَةً‏.‏ فَقَضَى مَرْوَانُ بِشَهَادَتِهِ لَهُمْ‏.‏\hadithno{2624}\hadithtrans{Narrated Asma' bint Abu Bakr (ra):My mother came to me during the lifetime of Allah's Messenger (ﷺ) and she was a Mushrikah (polytheist, idolatress, pagan). I said to Allah's Messenger (ﷺ) (seeking his verdict), "My mother has come to and she desires to recieve a reward from me, shall I keep good relations with her ?" The Prophet (ﷺ) said, "Yes, keep good relation with her}}
\hadithdefcmd{bukhari}{2625}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ قَضَى النَّبِيُّ صلى الله عليه وسلم بِالْعُمْرَى أَنَّهَا لِمَنْ وُهِبَتْ لَهُ‏.‏\hadithno{2625}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) gave the verdict that `Umra is for the one to whom it is presented}}
\hadithdefcmd{bukhari}{2626}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، قَالَ حَدَّثَنِي النَّضْرُ بْنُ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَى جَائِزَةٌ ‏"‏‏.‏ وَقَالَ عَطَاءٌ حَدَّثَنِي جَابِرٌ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ‏.‏\hadithno{2626}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Umra is permissible." Ata said, "Jabir narrated the same to me from the Prophet}}
\hadithdefcmd{bukhari}{2627}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ كَانَ فَزَعٌ بِالْمَدِينَةِ فَاسْتَعَارَ النَّبِيُّ صلى الله عليه وسلم فَرَسًا مِنْ أَبِي طَلْحَةَ يُقَالُ لَهُ الْمَنْدُوبُ، فَرَكِبَ فَلَمَّا رَجَعَ قَالَ ‏ "‏ مَا رَأَيْنَا مِنْ شَىْءٍ، وَإِنْ وَجَدْنَاهُ لَبَحْرًا ‏"‏‏.‏\hadithno{2627}\hadithtrans{Narrated Anas:Once the people of Medina were frightened, so the Prophet (ﷺ) borrowed a horse from Abu Talha called Al-Mandub, and rode it. When he came back he said, "We have not seen anything (to be afraid of), but the horse was very fast (having an energy as inexhaustible as the water of the sea)}}
\hadithdefcmd{bukhari}{2628}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ أَيْمَنَ، قَالَ حَدَّثَنِي أَبِي قَالَ، دَخَلْتُ عَلَى عَائِشَةَ ـ رضى الله عنها ـ وَعَلَيْهَا دِرْعُ قِطْرٍ ثَمَنُ خَمْسَةِ دَرَاهِمَ، فَقَالَتِ ارْفَعْ بَصَرَكَ إِلَى جَارِيَتِي، انْظُرْ إِلَيْهَا فَإِنَّهَا تُزْهَى أَنْ تَلْبَسَهُ فِي الْبَيْتِ، وَقَدْ كَانَ لِي مِنْهُنَّ دِرْعٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم، فَمَا كَانَتِ امْرَأَةٌ تُقَيَّنُ بِالْمَدِينَةِ إِلاَّ أَرْسَلَتْ إِلَىَّ تَسْتَعِيرُهُ‏.‏\hadithno{2628}\hadithtrans{Narrated Aiman:I went to `Aisha and she was wearing a coarse dress costing five Dirhams. `Aisha said, "Look up and see my slave-girl who refuses to wear it in the house though during the lifetime of Allah's Messenger (ﷺ) I had a similar dress which no woman desiring to appear elegant (before her husband) failed to borrow from me}}
\hadithdefcmd{bukhari}{2629}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ نِعْمَ الْمَنِيحَةُ اللِّقْحَةُ الصَّفِيُّ مِنْحَةً، وَالشَّاةُ الصَّفِيُّ تَغْدُو بِإِنَاءٍ وَتَرُوحُ بِإِنَاءٍ ‏"‏‏.‏ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ وَإِسْمَاعِيلُ عَنْ مَالِكٍ قَالَ نِعْمَ الصَّدَقَةُ‏.‏\hadithno{2629}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "What a good Maniha (the she-camel which has recently given birth and which gives profuse milk) is, and (what a good Maniha) (the sheep which gives profuse milk, a bowl in the morning and another in the evening) is!" Narrated Malik: Maniha is a good deed of charity}}
\hadithdefcmd{bukhari}{2630}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ لَمَّا قَدِمَ الْمُهَاجِرُونَ الْمَدِينَةَ مِنْ مَكَّةَ وَلَيْسَ بِأَيْدِيهِمْ ـ يَعْنِي شَيْئًا ـ وَكَانَتِ الأَنْصَارُ أَهْلَ الأَرْضِ وَالْعَقَارِ، فَقَاسَمَهُمُ الأَنْصَارُ عَلَى أَنْ يُعْطُوهُمْ ثِمَارَ أَمْوَالِهِمْ كُلَّ عَامٍ وَيَكْفُوهُمُ الْعَمَلَ وَالْمَئُونَةَ، وَكَانَتْ أُمُّهُ أُمُّ أَنَسٍ أُمُّ سُلَيْمٍ كَانَتْ أُمَّ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، فَكَانَتْ أَعْطَتْ أُمُّ أَنَسٍ رَسُولَ اللَّهِ صلى الله عليه وسلم عِذَاقًا فَأَعْطَاهُنَّ النَّبِيُّ صلى الله عليه وسلم أُمَّ أَيْمَنَ مَوْلاَتَهُ أُمَّ أُسَامَةَ بْنِ زَيْدِ‏.‏ قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمَّا فَرَغَ مِنْ قَتْلِ أَهْلِ خَيْبَرَ فَانْصَرَفَ إِلَى الْمَدِينَةِ، رَدَّ الْمُهَاجِرُونَ إِلَى الأَنْصَارِ مَنَائِحَهُمُ الَّتِي كَانُوا مَنَحُوهُمْ مِنْ ثِمَارِهِمْ فَرَدَّ النَّبِيُّ صلى الله عليه وسلم إِلَى أُمِّهِ عِذَاقَهَا، وَأَعْطَى رَسُولُ اللَّهِ صلى الله عليه وسلم أُمَّ أَيْمَنَ مَكَانَهُنَّ مِنْ حَائِطِهِ‏.‏ وَقَالَ أَحْمَدُ بْنُ شَبِيبٍ أَخْبَرَنَا أَبِي عَنْ يُونُسَ بِهَذَا، وَقَالَ مَكَانَهُنَّ مِنْ خَالِصِهِ‏.‏\hadithno{2630}\hadithtrans{Narrated Ibn Shihab Az-Zuhri:Anas bin Malik said, "When the emigrants came to Medina, they had nothing whereas the Ansar had land and property. The Ansar gave them their land on condition that the emigrants would give them half the yearly yield and work on the land and provide the necessaries for cultivation." His (i.e. Anas's mother who was also the mother of `Abdullah bin Abu Talha, gave some date-palms to Allah's Apostle who gave them to his freed slave-girl (Um Aiman) who was also the mother of Usama bin Zaid. When the Prophet (ﷺ) finished from the fighting against the people of Khaibar and returned to Medina, the emigrants returned to the Ansar the fruit gifts which the Ansar had given them. The Prophet (ﷺ) also returned to Anas's mother the date-palms. Allah's Messenger (ﷺ) gave Um Aiman other trees from his garden in lieu of the old gift}}
\hadithdefcmd{bukhari}{2631}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ حَسَّانَ بْنِ عَطِيَّةَ، عَنْ أَبِي كَبْشَةَ السَّلُولِيِّ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو ـ رضى الله عنهما ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَرْبَعُونَ خَصْلَةً أَعْلاَهُنَّ مَنِيحَةُ الْعَنْزِ، مَا مِنْ عَامِلٍ يَعْمَلُ بِخَصْلَةٍ مِنْهَا رَجَاءَ ثَوَابِهَا وَتَصْدِيقَ مَوْعُودِهَا إِلاَّ أَدْخَلَهُ اللَّهُ بِهَا الْجَنَّةَ ‏"‏‏.‏ قَالَ حَسَّانُ فَعَدَدْنَا مَا دُونَ مَنِيحَةِ الْعَنْزِ مِنْ رَدِّ السَّلاَمِ، وَتَشْمِيتِ الْعَاطِسِ، وَإِمَاطَةِ الأَذَى عَنِ الطَّرِيقِ وَنَحْوِهِ، فَمَا اسْتَطَعْنَا أَنْ نَبْلُغَ خَمْسَ عَشْرَةَ خَصْلَةً‏.‏\hadithno{2631}\hadithtrans{Narrated `Abdullah bin `Amr:That Allah's Messenger (ﷺ) said, "There are forty virtuous deeds and the best of them is the Maniha of a she-goat, and anyone who does one of these virtuous deeds hoping for Allah's reward with firm confidence that he will get it, then Allah will make him enter Paradise because of it. Hassan (a subnarrator) said, "We tried to count those good deeds below the Maniha; we mentioned replying to the sneezer, removing harmful things from the road, etc., but we failed to count even fifteen}}
\hadithdefcmd{bukhari}{2632}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي عَطَاءٌ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ كَانَتْ لِرِجَالٍ مِنَّا فُضُولُ أَرَضِينَ فَقَالُوا نُؤَاجِرُهَا بِالثُّلُثِ وَالرُّبُعِ وَالنِّصْفِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَزْرَعْهَا أَوْ لِيَمْنَحْهَا أَخَاهُ، فَإِنْ أَبَى فَلْيُمْسِكْ أَرْضَهُ ‏"‏‏.‏\hadithno{2632}\hadithtrans{Narrated Jabir:Some men had superfluous land and they said that they would give it to others to cultivate on the condition that they would get one-third or one-fourth or one half of its yield. The Prophet (ﷺ) said, "Whoever has land should cultivate it himself or give it to his brother or keep it uncultivated}}
\hadithdefcmd{bukhari}{2633}{وَقَالَ مُحَمَّدُ بْنُ يُوسُفَ حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي الزُّهْرِيُّ، حَدَّثَنِي عَطَاءُ بْنُ يَزِيدَ، حَدَّثَنِي أَبُو سَعِيدٍ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم فَسَأَلَهُ عَنِ الْهِجْرَةِ، فَقَالَ ‏"‏ وَيْحَكَ إِنَّ الْهِجْرَةَ شَأْنُهَا شَدِيدٌ فَهَلْ لَكَ مِنْ إِبِلٍ ‏"‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَتُعْطِي صَدَقَتَهَا ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَهَلْ تَمْنَحُ مِنْهَا شَيْئًا ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَتَحْلُبُهَا يَوْمَ وِرْدِهَا ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ فَاعْمَلْ مِنْ وَرَاءِ الْبِحَارِ، فَإِنَّ اللَّهَ لَنْ يَتِرَكَ مِنْ عَمَلِكَ شَيْئًا ‏"‏‏.‏\hadithno{2633}\hadithtrans{Narrated Abu Sa`id:A bedouin came to the Prophet (ﷺ) and asked him about emigration. The Prophet (ﷺ) said to him, "May Allah be merciful to you. The matter of emigration is difficult. Have you got some camels?" He replied in the affirmative. The Prophet (ﷺ) asked him, "Do you pay their Zakat?" He replied in the affirmative. He asked, "Do you lend them so that their milk may be utilized by others?" The bedouin said, "Yes." The Prophet (ﷺ) asked, "Do you milk them on the day of watering them?" He replied, "Yes." The Prophet (ﷺ) said, "Do good deeds beyond the merchants (or the sea) and Allah will never disregard any of your deeds." (See Hadith No. 260, Vol)}}
\hadithdefcmd{bukhari}{2634}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، قَالَ حَدَّثَنِي أَعْلَمُهُمْ، بِذَاكَ ـ يَعْنِي ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ إِلَى أَرْضٍ تَهْتَزُّ زَرْعًا فَقَالَ ‏"‏ لِمَنْ هَذِهِ ‏"‏‏.‏ فَقَالُوا اكْتَرَاهَا فُلاَنٌ‏.‏ فَقَالَ ‏"‏ أَمَا إِنَّهُ لَوْ مَنَحَهَا إِيَّاهُ كَانَ خَيْرًا لَهُ مِنْ أَنْ يَأْخُذَ عَلَيْهَا أَجْرًا مَعْلُومًا ‏"‏‏.‏\hadithno{2634}\hadithtrans{Narrated Tawus:That he was told by the most learned one amongst them (i.e. Ibn `Abbas) that the Prophet (ﷺ) went towards some land which was flourishing with vegetation and asked to whom it belonged. He was told that such and such a person took it on rent. The Prophet (ﷺ) said, "It would have been better (for the owner) if he had given it to him gratis rather than charging him a fixed rent}}
\hadithdefcmd{bukhari}{2635}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ هَاجَرَ إِبْرَاهِيمُ بِسَارَةَ، فَأَعْطَوْهَا آجَرَ، فَرَجَعَتْ فَقَالَتْ أَشَعَرْتَ أَنَّ اللَّهَ كَبَتَ الْكَافِرَ وَأَخْدَمَ وَلِيدَةً ‏"‏‏.‏ وَقَالَ ابْنُ سِيرِينَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ فَأَخْدَمَهَا هَاجَرَ ‏"‏‏.‏\hadithno{2635}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Prophet Abraham (ﷺ) migrated with Sarah. The people (of the town where they migrated) gave her Ajar (i.e. Hajar). Sarah returned and said to Abraham, "Do you know that Allah has humiliated that pagan and he has given a slave-girl for my service?}}
\hadithdefcmd{bukhari}{2636}{حَدَّثَنَا الْحُمَيْدِيُّ، أَخْبَرَنَا سُفْيَانُ، قَالَ سَمِعْتُ مَالِكًا، يَسْأَلُ زَيْدَ بْنَ أَسْلَمَ قَالَ سَمِعْتُ أَبِي يَقُولُ، قَالَ عُمَرُ ـ رضى الله عنه ـ حَمَلْتُ عَلَى فَرَسٍ فِي سَبِيلِ اللَّهِ، فَرَأَيْتُهُ يُبَاعُ، فَسَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تَشْتَرِ، وَلاَ تَعُدْ فِي صَدَقَتِكَ ‏"‏‏.‏\hadithno{2636}\hadithtrans{Narrated `Umar bin Al-Khattab:Once I gave a horse (for riding) in Allah's Cause. Later I saw it being sold. I asked Allah's Messenger (ﷺ) (whether I could buy it). He said, "Don't buy it, for you should not get back what you have given in charity}}
