% Auto-generated chapter 10 for malik
% Hadiths in this chapter: 13

\hadithdefcmd{malik}{428}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ سَمِعَ غَيْرَ، وَاحِدٍ، مِنْ عُلَمَائِهِمْ يَقُولُ لَمْ يَكُنْ فِي عِيدِ الْفِطْرِ وَلاَ فِي الأَضْحَى نِدَاءٌ وَلاَ إِقَامَةٌ مُنْذُ زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى الْيَوْمِ ‏.‏ قَالَ مَالِكٌ وَتِلْكَ السُّنَّةُ الَّتِي لاَ اخْتِلاَفَ فِيهَا عِنْدَنَا ‏.‏\hadithno{428}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he had heard more than one of their men of knowledge say, "There has been no call to prayer or iqama for the id al-Fitr or the id al-Adha since the time of the Messenger of Allah, may Allah bless him and grant him peace." Malik said, "That is the sunna about which there is no disagreement among us}}
\hadithdefcmd{malik}{429}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَغْتَسِلُ يَوْمَ الْفِطْرِ قَبْلَ أَنْ يَغْدُوَ إِلَى الْمُصَلَّى ‏.‏\hadithno{429}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to do ghusl on the day of Fitr before going to the place of prayer}}
\hadithdefcmd{malik}{430}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي يَوْمَ الْفِطْرِ وَيَوْمَ الأَضْحَى قَبْلَ الْخُطْبَةِ ‏.‏\hadithno{430}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that the Messenger of Allah, may Allah bless him and grant him peace, used to pray on the day of Fitr and the day of Adha before the khutba}}
\hadithdefcmd{malik}{431}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ أَبَا بَكْرٍ، وَعُمَرَ، كَانَا يَفْعَلاَنِ ذَلِكَ ‏.‏\hadithno{431}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Abu Bakr and Umar used to do that}}
\hadithdefcmd{malik}{432}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى ابْنِ أَزْهَرَ قَالَ شَهِدْتُ الْعِيدَ مَعَ عُمَرَ بْنِ الْخَطَّابِ فَصَلَّى ثُمَّ انْصَرَفَ فَخَطَبَ النَّاسَ فَقَالَ إِنَّ هَذَيْنِ يَوْمَانِ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ صِيَامِهِمَا يَوْمُ فِطْرِكُمْ مِنْ صِيَامِكُمْ وَالآخَرُ يَوْمٌ تَأْكُلُونَ فِيهِ مِنْ نُسُكِكُمْ ‏.‏ قَالَ أَبُو عُبَيْدٍ ثُمَّ شَهِدْتُ الْعِيدَ مَعَ عُثْمَانَ بْنِ عَفَّانَ فَجَاءَ فَصَلَّى ثُمَّ انْصَرَفَ فَخَطَبَ وَقَالَ إِنَّهُ قَدِ اجْتَمَعَ لَكُمْ فِي يَوْمِكُمْ هَذَا عِيدَانِ فَمَنْ أَحَبَّ مِنْ أَهْلِ الْعَالِيَةِ أَنْ يَنْتَظِرَ الْجُمُعَةَ فَلْيَنْتَظِرْهَا وَمَنْ أَحَبَّ أَنْ يَرْجِعَ فَقَدْ أَذِنْتُ لَهُ ‏.‏ قَالَ أَبُو عُبَيْدٍ ثُمَّ شَهِدْتُ الْعِيدَ مَعَ عَلِيِّ بْنِ أَبِي طَالِبٍ - وَعُثْمَانُ مَحْصُورٌ - فَجَاءَ فَصَلَّى ثُمَّ انْصَرَفَ فَخَطَبَ ‏.‏\hadithno{432}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Abu Ubayd, the mawla of Ibn Azhar said, "I was present at an id with Umar ibn al- Khattab. He prayed, and then after he had prayed he gave a khutba to the people and said, 'The Messenger of Allah, may Allah bless him and grant him peace, forbade fasting on these two days - the day you break your fast (after Ramadan), and the day you eat from your sacrifice (after Hajj) .' " Abu Ubaydcontinued,"Then I was present at an id with Uthman ibn Affan. He came and prayed, and when he had finished he gave a khutba and said, 'Two ids have been joined together for you on this day of yours. If any of the people of al-Aliyya (the hills outlying Madina) want to wait for the jumua they can do so, and if any of them want to return, I have given them permission.' Abu Ubayd continued, "Then I was present at an id with AIi ibn Abi Talib (at the time when Uthman was being detained). He came and prayed, and then after he had prayed he gave a khutba}}
\hadithdefcmd{malik}{433}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَأْكُلُ يَوْمَ عِيدِ الْفِطْرِ قَبْلَ أَنْ يَغْدُوَ ‏.‏\hadithno{433}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that he used to eat on the day of the id al-Fitr before going out}}
\hadithdefcmd{malik}{434}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ أَخْبَرَهُ أَنَّ النَّاسَ كَانُوا يُؤْمَرُونَ بِالأَكْلِ يَوْمَ الْفِطْرِ قَبْلَ الْغُدُوِّ ‏.‏ قَالَ مَالِكٌ وَلاَ أَرَى ذَلِكَ عَلَى النَّاسِ فِي الأَضْحَى ‏.‏\hadithno{434}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Said al- Musayyab told him that people used to be told to eat on the day of Fitr before setting out. Malik said that he did not consider that people had to do that for Adha}}
\hadithdefcmd{malik}{435}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ ضَمْرَةَ بْنِ سَعِيدٍ الْمَازِنِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، سَأَلَ أَبَا وَاقِدٍ اللَّيْثِيَّ مَا كَانَ يَقْرَأُ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الأَضْحَى وَالْفِطْرِ فَقَالَ كَانَ يَقْرَأُ بِـ ‏\{‏ق وَالْقُرْآنِ الْمَجِيدِ‏\}‏ وَ ‏\{‏اقْتَرَبَتِ السَّاعَةُ وَانْشَقَّ الْقَمَرُ‏\}‏‏.‏\hadithno{435}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Damra ibn Said al-Mazini from Ubaydullah ibn Abdullah ibn Utba ibn Masud that Umar ibn al-Khattab asked Abu Waqid al-Laythi what the Messenger of Allah, may Allah bless him and grant him peace, used to recite in the prayers of Adha and Fitr. He said, "He used to recite Qaf (Sura 50) and al-lnshiqaq (Sura)}}
\hadithdefcmd{malik}{436}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عُمَرَ أَنَّهُ قَالَ شَهِدْتُ الأَضْحَى وَالْفِطْرَ مَعَ أَبِي هُرَيْرَةَ فَكَبَّرَ فِي الرَّكْعَةِ الأُولَى سَبْعَ تَكْبِيرَاتٍ قَبْلَ الْقِرَاءَةِ وَفِي الآخِرَةِ خَمْسَ تَكْبِيرَاتٍ قَبْلَ الْقِرَاءَةِ ‏.‏ قَالَ مَالِكٌ وَهُوَ الأَمْرُ عِنْدَنَا ‏.‏ قَالَ مَالِكٌ فِي رَجُلٍ وَجَدَ النَّاسَ قَدِ انْصَرَفُوا مِنَ الصَّلاَةِ يَوْمَ الْعِيدِ إِنَّهُ لاَ يَرَى عَلَيْهِ صَلاَةً فِي الْمُصَلَّى وَلاَ فِي بَيْتِهِ وَإِنَّهُ إِنْ صَلَّى فِي الْمُصَلَّى أَوْ فِي بَيْتِهِ لَمْ أَرَ بِذَلِكَ بَأْسًا وَيُكَبِّرُ سَبْعًا فِي الأُولَى قَبْلَ الْقِرَاءَةِ وَخَمْسًا فِي الثَّانِيَةِ قَبْلَ الْقِرَاءَةِ ‏.‏\hadithno{436}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Nafi, the mawla of Abdullah ibn Umar said, "I was at Adha and Fitr with Abu Hurayra and he said 'Allah is greater' seven times in the first raka, before the recitation, and five times in the second, before the recitation}}
\hadithdefcmd{malik}{437}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، لَمْ يَكُنْ يُصَلِّي يَوْمَ الْفِطْرِ قَبْلَ الصَّلاَةِ وَلاَ بَعْدَهَا ‏.‏\hadithno{437}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar did not pray either before the prayer or after it on the day of Fitr}}
\hadithdefcmd{malik}{438}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، كَانَ يَغْدُو إِلَى الْمُصَلَّى بَعْدَ أَنْ يُصَلِّيَ الصُّبْحَ قَبْلَ طُلُوعِ الشَّمْسِ ‏.‏\hadithno{438}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn al-Musayyab used to go to the place of prayer after praying subh, and before the sun rose}}
\hadithdefcmd{malik}{439}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، أَنَّ أَبَاهُ الْقَاسِمَ، كَانَ يُصَلِّي قَبْلَ أَنْ يَغْدُوَ، إِلَى الْمُصَلَّى أَرْبَعَ رَكَعَاتٍ ‏.‏\hadithno{439}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim that his father used to pray four rakas before he went to the place of prayer}}
\hadithdefcmd{malik}{440}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يُصَلِّي يَوْمَ الْفِطْرِ قَبْلَ الصَّلاَةِ فِي الْمَسْجِدِ ‏.‏\hadithno{440}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Hisham ibn Urwa that his father used to pray on the day of Fitr before the prayer in the mosque}}
