% Auto-generated chapter 23 for tirmidhi
% Hadiths in this chapter: 50

\hadithdefcmd{tirmidhi}{1670}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ ائْتُونِي بِالْكَتِفِ أَوِ اللَّوْحِ ‏"‏ ‏.‏ فَكَتَبَ ‏:‏ ‏(‏ لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ ‏)‏ وَعَمْرُو بْنُ أُمِّ مَكْتُومٍ خَلْفَ ظَهْرِهِ فَقَالَ هَلْ لِي مِنْ رُخْصَةٍ فَنَزَلَتْ ‏:‏ ‏(‏ غَيْرُ أُولِي الضَّرَرِ ‏)‏ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَجَابِرٍ وَزَيْدِ بْنِ ثَابِتٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَهُوَ حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ سُلَيْمَانَ التَّيْمِيِّ عَنْ أَبِي إِسْحَاقَ ‏.‏ وَقَدْ رَوَى شُعْبَةُ وَالثَّوْرِيُّ عَنْ أَبِي إِسْحَاقَ هَذَا الْحَدِيثَ ‏\hadithno{1670}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Al-Bara' bin 'Azib: That the Messenger of Allah (ﷺ) said: "Bring me a shoulder blade or tablet." Then he wrote: Not equal are those of believers who sit. 'Amr bin Umm Maktum who was behind him said: "Is there an exemption for me?" So the following was revealed: Except those who are disabled. There are narrations on this topic from Ibn 'Abbas, Jabir and Zaid bin Thabit. This Hadith is Hasan Sahih and it is a Hadith that is Gharib from the narration of Sulaiman At-Taimi from Abu Ishaq. And Shu'bah and Ath-Thawri reported this Hadith from Abu Ishaq}}
\hadithdefcmd{tirmidhi}{1671}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، وَشُعْبَةَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ أَبِي الْعَبَّاسِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم يَسْتَأْذِنُهُ فِي الْجِهَادِ فَقَالَ ‏"‏ أَلَكَ وَالِدَانِ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَفِيهِمَا فَجَاهِدْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو الْعَبَّاسِ هُوَ الشَّاعِرُ الأَعْمَى الْمَكِّيُّ وَاسْمُهُ السَّائِبُ بْنُ فَرُّوخَ ‏.‏\hadithno{1671}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah bin 'Umar: A man came to Prophet (ﷺ) seeking permission to go for Jihad. So he said: 'Do you have parents (living)? ' He said: 'Yes.' He said: 'Then it is for them that you should perform Jihad.'" [Abu 'Eisa said:] There is something on this topic from Ibn 'Abbas. This Hadith is Hasan Sahih. (One of the narrators) Abul-Abbas is the blind (Al-A'ma) poet (Ash-Sha'ir), from Makkah, and his name is As-Sa'ab bin Farrukh}}
\hadithdefcmd{tirmidhi}{1672}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى النَّيْسَابُورِيُّ، حَدَّثَنَا الْحَجَّاجُ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، فِي قَوْلِهِِ ‏:‏ ‏(‏أطِيعُوا اللَّهَ وَأَطِيعُوا الرَّسُولَ وَأُولِي الأَمْرِ مِنْكُمْ ‏)‏ قَالَ عَبْدُ اللَّهِ بْنُ حُذَافَةَ بْنِ قَيْسِ بْنِ عَدِيٍّ السَّهْمِيُّ بَعَثَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى سَرِيَّةٍ ‏.‏ أَخْبَرَنِيهِ يَعْلَى بْنُ مُسْلِمٍ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ابْنِ جُرَيْجٍ ‏.‏\hadithno{1672}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Al-Hajjaj bin Muhammad: That Ibn Juraij commented on Allah's saying: Obey Allah and obey the Messenger, and those in authority among you. He said: "Abdullah bin Hudhafah bin Qais bin 'Adi As-Sahmi was sent by the Messenger of Allah (ﷺ) over a military expedition. I was informed of that by Ya'la bin Muslim, from Sa'eed bin Jubair, from Ibn 'Abbas. [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib. We do not know if it except as a narration of Ibn Juraij}}
\hadithdefcmd{tirmidhi}{1673}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ الْبَصْرِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَاصِمِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ أَنَّ النَّاسَ يَعْلَمُونَ مَا أَعْلَمُ مِنَ الْوَحْدَةِ مَا سَرَى رَاكِبٌ بِلَيْلٍ ‏"‏ ‏.‏ يَعْنِي وَحْدَهُ ‏.‏\hadithno{1673}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Ibn 'Umar:That the Messenger of Allah (ﷺ) said: "If the people knew what I know about being alone, then a rider would not journey at night." - meaning alone}}
\hadithdefcmd{tirmidhi}{1674}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حَرْمَلَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الرَّاكِبُ شَيْطَانٌ وَالرَّاكِبَانِ شَيْطَانَانِ وَالثَّلاَثَةُ رَكْبٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ عَاصِمٍ وَهُوَ ابْنُ مُحَمَّدِ بْنِ زَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ وَحَدِيثُ عَبْدِ اللَّهِ بْنِ عَمْرٍو حَدِيثٌ حَسَنٌ ‏.‏ قَالَ مُحَمَّدٌ هُوَ ثِقَةٌ صَدُوقٌ وَعَاصِمُ بْنُ عُمَرَ الْعُمَرِيُّ ضَعِيفٌ فِي الْحَدِيثِ لاَ أَرْوِي عَنْهُ شَيْئًا ‏.‏ وَحَدِيثُ عَبْدِ اللَّهِ بْنِ عَمْرٍو حَدِيثٌ حَسَنٌ\hadithno{1674}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr bin Shu'aib: From his father, from his grandfather that the Messenger of Allah (ﷺ) said: "The (lone) rider is a Shaitan, and two raiders are two Shaitan. Three is a travelling party. [Abu 'Eisa said:] The Hadith of Ibn 'Umar (no, 1673) is Hasan Sahih. We do not know of it except from this route ; as a narration of 'Asim. And he is Ibn Muhammad bin Zaid bin 'Abdullah bin 'Umar. Muhammad said: "He is trustworthy, truthful. And 'Asim bin 'Umar Al-'Umari is weak in Hadith, I do not report anything from him." The Hadith of 'Abdullah bin 'Amr (no. 1674) is better}}
\hadithdefcmd{tirmidhi}{1675}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَنَصْرُ بْنُ عَلِيٍّ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْحَرْبُ خُدْعَةٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ وَزَيْدِ بْنِ ثَابِتٍ وَعَائِشَةَ وَابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ وَأَسْمَاءَ بِنْتِ يَزِيدَ بْنِ السَّكَنِ وَكَعْبِ بْنِ مَالِكٍ وَأَنَسِ بْنِ مَالِكٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1675}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Jabir bin ‘Abdullah : That the Messenger of Allah (ﷺ) said: "War is deceit." [Abu 'Eisa said:] There are narrations on this topic from 'Ali, Zaid bin Thabit, 'Aishah, Ibn 'Abbas, Abu Hurairah, Asma' bint Yazid bin As-Sakan, Ka'b bin Malik and Anas bin Malik. This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1676}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، وَأَبُو دَاوُدَ الطَّيَالِسِيُّ قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ كُنْتُ إِلَى جَنْبِ زَيْدِ بْنِ أَرْقَمَ فَقِيلَ لَهُ كَمْ غَزَا النَّبِيُّ صلى الله عليه وسلم مِنْ غَزْوَةٍ قَالَ تِسْعَ عَشْرَةَ ‏.‏ فَقُلْتُ كَمْ غَزَوْتَ أَنْتَ مَعَهُ قَالَ سَبْعَ عَشْرَةَ ‏.‏ قُلْتُ أَيَّتُهُنَّ كَانَ أَوَّلَ قَالَ ذَاتُ الْعُشَيْرَاءِ أَوِ الْعُسَيْرَاءِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1676}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Ishaq: "I was next to Zaid bin Arqam when he was asked: 'How many battles did the Prophet (ﷺ) fight ?' He said: 'Nineteen.' So I said: 'How many battles did you take part in with him ?' he said: 'Seventeen.' I said: 'Which of them was the first?' He said: 'Dhat Al-Ushaira' or Al-'Usaira'. '" [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1677}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، حَدَّثَنَا سَلَمَةُ بْنُ الْفَضْلِ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، قَالَ عَبَّأَنَا النَّبِيُّ صلى الله عليه وسلم بِبَدْرٍ لَيْلاً ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي أَيُّوبَ ‏.‏ وَهَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَسَأَلْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ عَنْ هَذَا الْحَدِيثِ فَلَمْ يَعْرِفْهُ وَقَالَ مُحَمَّدُ بْنُ إِسْحَاقَ سَمِعَ مِنْ عِكْرِمَةَ ‏.‏ وَحِينَ رَأَيْتُهُ كَانَ حَسَنَ الرَّأْىِ فِي مُحَمَّدِ بْنِ حُمَيْدٍ الرَّازِيِّ ثُمَّ ضَعَّفَهُ بَعْدُ ‏.‏\hadithno{1677}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdur-Rahman bin 'Awf: "The Messenger of Allah (ﷺ) positioned us during the night at Badr." [Abu 'Eisa said:] There is something on this topic from Abu Ayyub. This Hadith is Gharib, we do not know of it except from this route. I asked Muhammad bin Isma'il about this Hadith, but he did not know it, and he said: "Muhammad bin Ishaq heard from 'Ikrimah." And when I saw him, he had a good opinion about Muhammad bin Humaid Ar-Razi, then he considered him weak later}}
\hadithdefcmd{tirmidhi}{1678}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنِ ابْنِ أَبِي أَوْفَى، قَالَ سَمِعْتُهُ يَقُولُ يَعْنِي النَّبِيَّ صلى الله عليه وسلم يَدْعُو عَلَى الأَحْزَابِ فَقَالَ ‏ "‏ اللَّهُمَّ مُنْزِلَ الْكِتَابِ سَرِيعَ الْحِسَابِ اهْزِمِ الأَحْزَابَ اللَّهُمَّ اهْزِمْهُمْ وَزَلْزِلْهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1678}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn Abi Awfa: "I heard him saying" - meaning the Prophet (ﷺ) - "while supplicating against the Ahzab: 'O Allah, Revealer of Book! Severe is reckoning! Rout the Ahzab and shake them.'" [Abu 'Eisa said:] There is something on this topic from Ibn Masu'd This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1679}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ الْوَلِيدِ الْكِنْدِيُّ الْكُوفِيُّ، وَأَبُو كُرَيْبٍ وَمُحَمَّدُ بْنُ رَافِعٍ قَالُوا حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ شَرِيكٍ، عَنْ عَمَّارٍ يَعْنِي الدُّهْنِيَّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ مَكَّةَ وَلِوَاؤُهُ أَبْيَضُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ يَحْيَى بْنِ آدَمَ عَنْ شَرِيكٍ ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَلَمْ يَعْرِفْهُ إِلاَّ مِنْ حَدِيثِ يَحْيَى بْنِ آدَمَ عَنْ شَرِيكٍ وَقَالَ حَدَّثَنَا غَيْرُ وَاحِدٍ عَنْ شَرِيكٍ عَنْ عَمَّارٍ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ مَكَّةَ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ ‏.‏ قَالَ مُحَمَّدٌ وَالْحَدِيثُ هُوَ هَذَا ‏.‏ قَالَ أَبُو عِيسَى وَالدُّهْنُ بَطْنٌ مِنْ بَجِيلَةَ وَعَمَّارٌ الدُّهْنِيُّ هُوَ عَمَّارُ بْنُ مُعَاوِيَةَ الدُّهْنِيُّ وَيُكْنَى أَبَا مُعَاوِيَةَ وَهُوَ كُوفِيٌّ وَهُوَ ثِقَةٌ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏\hadithno{1679}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Jabir: "The Messenger of Allah (ﷺ) entered Makkah, and his standard was white." [Abu 'Eisa said:] This Hadith is Gharib, we do know of it except as a narration of Yayha bin Adam from Sharik. He said: I asked Muhammad about this Hadith, but he did not know it except as a narration of Yahya bin Adam from Sharik, he said: "More than one narrator has narrated to us from Sharik from 'Ammar bin Abu Az-Zubair from Jabir: 'The Prophet (ﷺ) entered Makkah and he was wearing a black 'Imamah.'" Muhammad said: "This is the Hadith." [Abu 'Eisa said:] Duhn is a branch of Bajilah (the tribe), and 'Ammar ad-Duhni (one of the narrators) is 'Ammar bin Mu'awiyah Ad-Duhni, and his kunyah is Abu Mu'awiyah, he is from Al-Kufah, and he is trustworthy according to the people of Hadith}}
\hadithdefcmd{tirmidhi}{1680}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، حَدَّثَنَا أَبُو يَعْقُوبَ الثَّقَفِيُّ، حَدَّثَنَا يُونُسُ بْنُ عُبَيْدٍ، مَوْلَى مُحَمَّدِ بْنِ الْقَاسِمِ قَالَ بَعَثَنِي مُحَمَّدُ بْنُ الْقَاسِمِ إِلَى الْبَرَاءِ بْنِ عَازِبٍ أَسْأَلُهُ عَنْ رَايَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ كَانَتْ سَوْدَاءَ مُرَبَّعَةً مِنْ نَمِرَةٍ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ وَالْحَارِثِ بْنِ حَسَّانَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ابْنِ أَبِي زَائِدَةَ ‏.‏ وَأَبُو يَعْقُوبَ الثَّقَفِيُّ اسْمُهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ وَرَوَى عَنْهُ أَيْضًا عُبَيْدُ اللَّهِ بْنُ مُوسَى ‏.‏\hadithno{1680}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Yunus bin 'Ubaid: the freed salve of Muhammad bin Al-Qasim said: "Muhammad bin Al-Qasim sent me to Al-Bara' bin 'Azib to ask him about the flag of the Messenger of Allah (ﷺ). He said: 'It was a black square of Namirah.'" [Abu 'Eisa said:] There are narrations on this topic from 'Ali, Al-Harith bin Hassan, and Ibn 'Abbas. [Abu 'Eisa said:] This Hadith is Hasan Gharib, we don know know of it except from the report of Ibn Abi Za'idah. And Abu Ya'qub Ath-Thaqafi's name is Ishaq bin Ibrahim. 'Ubaidullah bin Musa also reports from him}}
\hadithdefcmd{tirmidhi}{1681}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ إِسْحَاقَ، وَهُوَ السَّالِحَانِيُّ حَدَّثَنَا يَزِيدُ بْنُ حَيَّانَ، قَالَ سَمِعْتُ أَبَا مِجْلَزٍ، لاَحِقَ بْنَ حُمَيْدٍ يُحَدِّثُ عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَتْ رَايَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم سَوْدَاءَ وَلِوَاؤُهُ أَبْيَضَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{1681}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas: "The flag of the Messenger of Allah (ﷺ) was black, and his standard was white." [Abu 'Eisa said:] This Hadith is Hasan Gharib from this route, as a narration of Ibn 'Abbas}}
\hadithdefcmd{tirmidhi}{1682}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْمُهَلَّبِ بْنِ أَبِي صُفْرَةَ، عَمَّنْ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنْ بَيَّتَكُمُ الْعَدُوُّ فَقُولُوا‏:‏ حم لاَ يُنْصَرُونَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ سَلَمَةَ بْنِ الأَكْوَعِ ‏.‏ وَهَكَذَا رَوَى بَعْضُهُمْ عَنْ أَبِي إِسْحَاقَ مِثْلَ رِوَايَةِ الثَّوْرِيِّ وَرُوِيَ عَنْهُ عَنِ الْمُهَلَّبِ بْنِ أَبِي صُفْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏\hadithno{1682}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Al-Muhallab bin Abi Sufrah: From one who heard the Prophet (ﷺ) saying: "If you suffer a surprise attack from the enemy then say: 'Ha Min, they will not be victorious.'" [Abu 'Eisa said:] There is something on this topic from Salamah bin Al-Akwa'. This is how some of them reported it from Abu Ishaq, the same as the narration of Ath-Thawri. And it has been reported from him, from Al-Muhallab bin Abi Sufrah from the Prophet (ﷺ) in Mursal form}}
\hadithdefcmd{tirmidhi}{1683}{حَدَّثَنَا مُحَمَّدُ بْنُ شُجَاعٍ الْبَغْدَادِيُّ، حَدَّثَنَا أَبُو عُبَيْدَةَ الْحَدَّادُ، عَنْ عُثْمَانَ بْنِ سَعْدٍ، عَنِ ابْنِ سِيرِينَ، قَالَ صَنَعْتُ سَيْفِي عَلَى سَيْفِ سَمُرَةَ بْنِ جُنْدَبٍ وَزَعَمَ سَمُرَةُ أَنَّهُ صَنَعَ سَيْفَهُ عَلَى سَيْفِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَ حَنَفِيًّا ‏.‏ قَالَ أَبُو عِيسَى هَذَ حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ تَكَلَّمَ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ فِي عُثْمَانَ بْنِ سَعْدٍ الْكَاتِبِ وَضَعَّفَهُ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{1683}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Uthman bin Sa'd: That Ibn Sirin said: "I made my sword like the sword of Samurah bin Jundab. Samurah claimed that he made his sword like the sword of the Messenger of Allah (ﷺ), and it was a Hanafiyah." [Abu 'Eisa said:] This Hadith is Gharib, we do not know of it except through this route. Yahya bin Sa'eed Al-Qattan has criticized 'Uthman bin Sa'd the scribe, and he graded him weak due to his memory}}
\hadithdefcmd{tirmidhi}{1684}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ مُوسَى، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَنْبَأَنَا سَعِيدُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ عَطِيَّةَ بْنِ قَيْسٍ، عَنْ قَزَعَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ لَمَّا بَلَغَ النَّبِيُّ صلى الله عليه وسلم عَامَ الْفَتْحِ مَرَّ الظَّهْرَانِ فَآذَنَنَا بِلِقَاءِ الْعَدُوِّ فَأَمَرَنَا بِالْفِطْرِ فَأَفْطَرْنَا أَجْمَعُونَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنْ عُمَرَ ‏.‏\hadithno{1684}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Sa’id Al Khudri : "During the year of the conquest, when the Prophet (ﷺ) reached Marr Zahran, he told us that we would meet the enemy. So he ordered us to break the fast, and we [all] broke our fast." [Abu 'Eisa said:] This Hadith is Hasan Sahih, and there is something on this topic from Ibn 'Umar}}
\hadithdefcmd{tirmidhi}{1685}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ رَكِبَ النَّبِيُّ صلى الله عليه وسلم فَرَسًا لأَبِي طَلْحَةَ يُقَالُ لَهُ مَنْدُوبٌ فَقَالَ ‏ "‏ مَا كَانَ مِنْ فَزَعٍ وَإِنْ وَجَدْنَاهُ لَبَحْرًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عَمْرِو بْنِ الْعَاصِ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1685}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik: "The Prophet (ﷺ) rode a horse belonging to Abu Talhah called Mandub. He said: 'There is nothing to be frightened of, and we found him to be (quick) like the sea.'" [Abu 'Eisa said:] There is something on this topic from Ibn 'Amr Al-'As}}
\hadithdefcmd{tirmidhi}{1686}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَابْنُ أَبِي عَدِيٍّ، وَأَبُو دَاوُدَ قَالُوا حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ فَزَعٌ بِالْمَدِينَةِ فَاسْتَعَارَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَرَسًا لَنَا يُقَالُ لَهُ مَنْدُوبٌ فَقَالَ ‏ "‏ مَا رَأَيْنَا مِنْ فَزَعٍ وَإِنْ وَجَدْنَاهُ لَبَحْرًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1686}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Anas bin Malik: "There was a cause of fright in Al-Madinah. So the Messenger of Allah (ﷺ) borrowed a horse of ours called Mandub. He said: 'I have not seen anything to be frightened of, and we found him to be (quick) like the sea.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1687}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم مِنْ أَجْرَإِ النَّاسِ وَأَجْوَدِ النَّاسِ وَأَشْجَعِ النَّاسِ ‏.‏ قَالَ وَقَدْ فَزِعَ أَهْلُ الْمَدِينَةِ لَيْلَةً سَمِعُوا صَوْتًا قَالَ فَتَلَقَّاهُمُ النَّبِيُّ صلى الله عليه وسلم عَلَى فَرَسٍ لأَبِي طَلْحَةَ عُرْىٍ وَهُوَ مُتَقَلِّدٌ سَيْفَهُ فَقَالَ ‏"‏ لَمْ تُرَاعُوا لَمْ تُرَاعُوا ‏"‏ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَجَدْتُهُ بَحْرًا ‏"‏ ‏.‏ يَعْنِي الْفَرَسَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{1687}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas: "The Prophet (ﷺ) was the nicest person among the people, the most generous of the people, and the bravest among the people." He said: "The inhabitants of Al-Madinah became freightened one night upon hearing a loud noise." He said: "So the Prophet (ﷺ) met them upon an unsaddled horse belonging to Abu Talhah, with a sword hanging around his neck. He said: 'I found him to be (quick) like the sea.'" - meaning the horse. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1688}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ قَالَ لَنَا رَجُلٌ أَفَرَرْتُمْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم يَا أَبَا عُمَارَةَ قَالَ لاَ وَاللَّهِ مَا وَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَكِنْ وَلَّى سَرَعَانُ النَّاسِ تَلَقَّتْهُمْ هَوَازِنُ بِالنَّبْلِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى بَغْلَتِهِ وَأَبُو سُفْيَانَ بْنُ الْحَارِثِ بْنِ عَبْدِ الْمُطَّلِبِ آخِذٌ بِلِجَامِهَا وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَنَا النَّبِيُّ لاَ كَذِبْ أَنَا ابْنُ عَبْدِ الْمُطَّلِبْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ عُمَرَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1688}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Ishaq: From Al-Bara' bin 'Azib who said: "A man said to us: 'Did you flee from the Messenger of Allah (ﷺ) O Abu 'Umarah ?'" He said: "No, By Allah! I did not flee from the Messenger of Allah (ﷺ), but som hasty people fled and (the tribe of) Hawazin assaulted them with arrows. The Messenger of Allah (Saws) was on his white muls, and Abu Sufyan bin Al-Harith bin 'Abdul Muttalib was holding its reigns. The Messenger of Allah (ﷺ) was saying: 'I am the Prophet without lie, I am the son of 'Abdul-Muttalib.'" [Abu 'Eisa said:] There are narrations on this topic from 'Ali, and Ibn 'Umar}}
\hadithdefcmd{tirmidhi}{1689}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ عَلِيٍّ الْمُقَدَّمِيُّ الْبَصْرِيُّ، حَدَّثَنِي أَبِي، عَنْ سُفْيَانَ بْنِ حُسَيْنٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ لَقَدْ رَأَيْتُنَا يَوْمَ حُنَيْنٍ وَإِنَّ الْفِئَتَيْنِ لَمُوَلِّيَتَيْنِ وَمَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِائَةُ رَجُلٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ عُبَيْدِ اللَّهِ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{1689}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn 'Umar: "Indeed we saw the day of Hunain, and indeed the two armies fled from the Messenger of Allah (ﷺ), and there did not remain one hundred men with the Messenger of Allah (ﷺ)." [Abu 'Eisa said:] This Hadith is Hasan Gharib as a narration of 'Ubaidullah. We do not know of it except from this route}}
\hadithdefcmd{tirmidhi}{1690}{حَدَّثَنَا مُحَمَّدُ بْنُ صُدْرَانَ أَبُو جَعْفَرٍ الْبَصْرِيُّ، حَدَّثَنَا طَالِبُ بْنُ حُجَيْرٍ، عَنْ هُودِ بْنِ عَبْدِ اللَّهِ بْنِ سَعْدٍ، عَنْ جَدِّهِ، مَزِيدَةَ قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الْفَتْحِ وَعَلَى سَيْفِهِ ذَهَبٌ وَفِضَّةٌ ‏.‏ قَالَ طَالِبٌ فَسَأَلْتُهُ عَنِ الْفِضَّةِ فَقَالَ كَانَتْ قَبِيعَةُ السَّيْفِ فِضَّةً ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏ وَهَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَجَدُّ هُودٍ اسْمُهُ مَزِيدَةُ الْعَصَرِيُّ ‏.‏\hadithno{1690}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Talib bin Hujair: From Hud bin 'Abdullah bin Sa'd, from his grandfather Mazidah, who said: "The Messenger of Allah (ﷺ) on the Day of the Conquest and there was gold and silver on his sword." Talib said: "So I asked him about the silver and he said: 'The hand-guard of his sword was of silver.'" [Abu 'Eisa said:] There is something on this topic form Anas. This Hadith is Hasan Gharib. Hud's (great) grandfather's name is Mazidah Al-'Asari}}
\hadithdefcmd{tirmidhi}{1691}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرِ بْنِ حَازِمٍ، حَدَّثَنَا أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَانَتْ قَبِيعَةُ سَيْفِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ فِضَّةٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَهَكَذَا رُوِيَ عَنْ هَمَّامٍ عَنْ قَتَادَةَ عَنْ أَنَسٍ وَقَدْ رَوَى بَعْضُهُمْ عَنْ قَتَادَةَ عَنْ سَعِيدِ بْنِ أَبِي الْحَسَنِ قَالَ كَانَتْ قَبِيعَةُ سَيْفِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ فِضَّةٍ ‏.‏\hadithno{1691}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas: "The hand-guard on the sword of the Messenger of Allah (ﷺ) was made from silver." [Abu 'Eisa said:] This Hadith is Hasan Gharib. This is how it has been reported from Hamam from Qatadah from Anas. While some of them reported it from Qatadah, from Sa'eed bin Abu Al-Hasan who said: "The hand-guard on the sword of Messenger of Allah (ﷺ) was made from silver}}
\hadithdefcmd{tirmidhi}{1692}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَحْيَى بْنِ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنِ الزُّبَيْرِ بْنِ الْعَوَّامِ، قَالَ كَانَ عَلَى النَّبِيِّ صلى الله عليه وسلم دِرْعَانِ يَوْمَ أُحُدٍ فَنَهَضَ إِلَى الصَّخْرَةِ فَلَمْ يَسْتَطِعْ فَأَقْعَدَ طَلْحَةَ تَحْتَهُ فَصَعِدَ النَّبِيُّ صلى الله عليه وسلم عَلَيْهِ حَتَّى اسْتَوَى عَلَى الصَّخْرَةِ فَقَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَوْجَبَ طَلْحَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ صَفْوَانَ بْنِ أُمَيَّةَ وَالسَّائِبِ بْنِ يَزِيدَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُحَمَّدِ بْنِ إِسْحَاقَ ‏.‏\hadithno{1692}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Az-Zubair bin Al-'Awwam: "On the Day of Uhud, the Prophet (ﷺ) wore two coats of mail. He tried to get up on a boulder but was not able to, so Talhah squatted under him, lifting the Prophet (ﷺ) upon it such that he could sit on the boulder. So he said: (Paradise) "It is obligated from Talhah.'" [Abu 'Eisa said:] There are narrations on this topic from Safwan bin Umayyah and As-Sa'ib bin Yazid. This Hadith is Hasan Gharib, we do not know of it except through the narration of Muhammad bin Ishaq}}
\hadithdefcmd{tirmidhi}{1693}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم عَامَ الْفَتْحِ وَعَلَى رَأْسِهِ الْمِغْفَرُ فَقِيلَ لَهُ ابْنُ خَطَلٍ مُتَعَلِّقٌ بِأَسْتَارِ الْكَعْبَةِ ‏.‏ فَقَالَ ‏ "‏ اقْتُلُوهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُ كَبِيرَ أَحَدٍ رَوَاهُ غَيْرَ مَالِكٍ عَنِ الزُّهْرِيِّ ‏.‏\hadithno{1693}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik: The Prophet (ﷺ) entered (Makkah) during they year of the Conquest, and upon his head was a helmet (Mighfar). It was said to him: 'Ibn Khatal is clinging to the covering of the Ka'bah.' So he said: 'Kill him.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib. We do knot know of anyone important who reported it other than Malik from Az-Zuhri}}
\hadithdefcmd{tirmidhi}{1694}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْثَرُ بْنُ الْقَاسِمِ، عَنْ حُصَيْنٍ، عَنِ الشَّعْبِيِّ، عَنْ عُرْوَةَ الْبَارِقِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْخَيْرُ مَعْقُودٌ فِي نَوَاصِي الْخَيْلِ إِلَى يَوْمِ الْقِيَامَةِ الأَجْرُ وَالْمَغْنَمُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَبِي سَعِيدٍ وَجَرِيرٍ وَأَبِي هُرَيْرَةَ وَأَسْمَاءَ بِنْتِ يَزِيدَ وَالْمُغِيرَةِ بْنِ شُعْبَةَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعُرْوَةُ هُوَ ابْنُ أَبِي الْجَعْدِ الْبَارِقِيُّ وَيُقَالُ هُوَ عُرْوَةُ بْنُ الْجَعْدِ ‏.‏ قَالَ أَحْمَدُ بْنُ حَنْبَلٍ وَفِقْهُ هَذَا الْحَدِيثِ أَنَّ الْجِهَادَ مَعَ كُلِّ إِمَامٍ إِلَى يَوْمِ الْقِيَامَةِ ‏.‏\hadithno{1694}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated 'Urwah Al-Bariqi: That the Messenger of Allah (ﷺ) said: "Goodness will remain in the forelocks of horses until the Day of Judgement: (They bring about) Rewards and spoils of war." [Abu 'Eisa said:] There are narrations on this topic from Ibn 'Umar, Abu Sa'eed, Jarir, Abu Hurairah, Asma' bin Yazid, Al-Mughira bin Shu'bah, and Jabir. [Abu 'Eisa said:] This Hadith is Hasan Sahih. 'Urwah is Ibn Al-Ja'd Al-Bariqi, and they say he is 'Urwah bin Al-Ja'd. Ahmad bin Hanbal said: "The Fiqh of this Hadith is that Jihad is with every Imam until the Day of Judgement}}
\hadithdefcmd{tirmidhi}{1695}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ الْهَاشِمِيُّ الْبَصْرِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا شَيْبَانُ يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا عِيسَى بْنُ عَلِيِّ بْنِ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُمْنُ الْخَيْلِ فِي الشُّقْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ شَيْبَانَ ‏.‏\hadithno{1695}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Abbas: That the Messenger of Allah (ﷺ) said: "The blessing of the horse is in its redness." [Abu 'Eisa said:] This Hadith is Hasan Gharib, we do not know of it except from this route, from the narration of Shaiban}}
\hadithdefcmd{tirmidhi}{1696}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا ابْنُ لَهِيعَةَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عُلَىِّ بْنِ رَبَاحٍ، عَنْ أَبِي قَتَادَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ الْخَيْلِ الأَدْهَمُ الأَقْرَحُ الأَرْثَمُ ثُمَّ الأَقْرَحُ الْمُحَجَّلُ طَلْقُ الْيَمِينِ فَإِنْ لَمْ يَكُنْ أَدْهَمَ فَكُمَيْتٌ عَلَى هَذِهِ الشِّيَةِ ‏"‏ ‏.‏\hadithno{1696}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Qatadah:That the Prophet (ﷺ) said: "The best horse is the black one with a spot on the face, and white on the upper lip. Then the one with some white on his lower legs, except for the right. So if it is no black, then the Kumait (red one with black on its ears and its mane) with these markings}}
\hadithdefcmd{tirmidhi}{1697}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي، عَنْ يَحْيَى بْنِ أَيُّوبَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ بِمَعْنَاهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{1697}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Another chain with similar meaning. [Abu 'Eisa said:] This Hadith is Hasan Gharib Sahih}}
\hadithdefcmd{tirmidhi}{1698}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي سَلْمُ بْنُ عَبْدِ الرَّحْمَنِ النَّخَعِيُّ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَرِهَ الشِّكَالَ مِنَ الْخَيْلِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ شُعْبَةُ عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْخَثْعَمِيِّ عَنْ أَبِي زُرْعَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ وَأَبُو زُرْعَةَ بْنُ عَمْرِو بْنِ جَرِيرٍ اسْمُهُ هَرِمٌ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ حَدَّثَنَا جَرِيرٌ عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ قَالَ قَالَ لِي إِبْرَاهِيمُ النَّخَعِيُّ إِذَا حَدَّثْتَنِي فَحَدِّثْنِي عَنْ أَبِي زُرْعَةَ فَإِنَّهُ حَدَّثَنِي مَرَّةً بِحَدِيثٍ ثُمَّ سَأَلْتُهُ بَعْدَ ذَلِكَ بِسِنِينَ فَمَا أَخْرَمَ مِنْهُ حَرْفًا ‏.‏\hadithno{1698}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Hurairah: That the Prophet (ﷺ) disliked Shikal in horses. [Abu 'Eisa said:] This Hadith is Hasan Sahih. Shu'bah reported similarly from 'Abdullah bin Yazid Al-Khath'ami, from Abu Zur'ah (one of the narrators in the chain of this Hadith), from Abu Hurairah, from the Prophet (ﷺ). Abu Zur'ah bin 'Amr bin Jarir's name is Harim. Muhammed bin Hammad Ar-Razi narrated to us (he said): "Jarir narrated to us from 'Umarah bin Al-Qa'qa' who said: 'Ibrahim An-Nakha'i said to me: "When you narrate from me, then narrate from me from Abu Zur'ah, for one time he narrated a Hadith to me, then I asked him about it two years later, and he did not leave a letter out of it}}
\hadithdefcmd{tirmidhi}{1699}{حَدَّثَنَا مُحَمَّدُ بْنُ وَزِيرٍ الْوَاسِطِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، عَنْ سُفْيَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَجْرَى الْمُضَمَّرَ مِنَ الْخَيْلِ مِنَ الْحَفْيَاءِ إِلَى ثَنِيَّةِ الْوَدَاعِ وَبَيْنَهُمَا سِتَّةُ أَمْيَالٍ وَمَا لَمْ يُضَمَّرْ مِنَ الْخَيْلِ مِنْ ثَنِيَّةِ الْوَدَاعِ إِلَى مَسْجِدِ بَنِي زُرَيْقٍ وَبَيْنَهُمَا مِيلٌ وَكُنْتُ فِيمَنْ أَجْرَى فَوَثَبَ بِي فَرَسِي جِدَارًا ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَجَابِرٍ وَعَائِشَةَ وَأَنَسٍ ‏.‏ وَهَذَا حَدِيثٌ صَحِيحٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ الثَّوْرِيِّ ‏.‏\hadithno{1699}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ibn 'Umar: "The Messenger of Allah (ﷺ) arranged for the Mudammar among horses to race from Al-Hafiya' to Thaniyyah Al-Wada', between which was a distance of six miles. And for whatever horse was not among the Mudammar, they raced from Thaniya Al-Wada' to the Masjid of Banu Zuraiq, between which was a distance of a mile. I was among those who raced, and my horse jumped along with me over a wall." [Abu 'Eisa said:] There are narrations on this topic from Abu Hurairah, Jabir, Anas, and 'Aishah. This Hadith is Hasan Sahih Gharib as a narration of Ath-Thawri}}
\hadithdefcmd{tirmidhi}{1700}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ نَافِعِ بْنِ أَبِي نَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ سَبَقَ إِلاَّ فِي نَصْلٍ أَوْ خُفٍّ أَوْ حَافِرٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1700}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:That the Prophet (ﷺ) said: "No stake is acceptable except in archery, racing a camel, and racing a horse}}
\hadithdefcmd{tirmidhi}{1701}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبُو جَهْضَمٍ، مُوسَى بْنُ سَالِمٍ عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَبْدًا مَأْمُورًا مَا اخْتَصَّنَا دُونَ النَّاسِ بِشَيْءٍ إِلاَّ بِثَلاَثٍ أَمَرَنَا أَنْ نُسْبِغَ الْوُضُوءَ وَأَنْ لاَ نَأْكُلَ الصَّدَقَةَ وَأَنْ لاَ نُنْزِيَ حِمَارًا عَلَى فَرَسٍ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى سُفْيَانُ الثَّوْرِيُّ هَذَا عَنْ أَبِي جَهْضَمٍ فَقَالَ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدًا يَقُولُ حَدِيثُ الثَّوْرِيِّ غَيْرُ مَحْفُوظٍ وَوَهِمَ فِيهِ الثَّوْرِيُّ وَالصَّحِيحُ مَا رَوَى إِسْمَاعِيلُ ابْنُ عُلَيَّةَ وَعَبْدُ الْوَارِثِ بْنُ سَعِيدٍ عَنْ أَبِي جَهْضَمٍ عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ اللَّهِ بْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{1701}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Abbas: "The Messenger of Allah (ﷺ) was a slave (of Allah), who would order as he has ben ordered to. He did not give an order to us instead of the people regarding anything except for three: He ordered us that we make our Wudu' well (Isbagh), that we not eat from charity, and the we not mate a donkey with a horse." [Abu 'Eisa said:] There is something on this topic from 'Ali. This Hadith is Hasan Sahih. Sufyan Ath-Thawri reported this from Abu Jahdam, who said: "From 'Ubaidullah bin 'Abdullah bin 'Abbas, from Ibn 'Abbas." He said I heard Muhammad saying: "The narration of Ath-Thawri is not preserved. Ath-Thawri made a mistake in it. What is correct is what Ismail bin 'Ulaiyyah and 'Abul-Warith bin Sa'eed reported from Abu Jahdam, from 'Abdullah bin 'Ubaidullah bin 'Abbas from Ibn 'Abbas}}
\hadithdefcmd{tirmidhi}{1702}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ مُوسَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، قَالَ أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ بْنِ جَابِرٍ، حَدَّثَنَا زَيْدُ بْنُ أَرْطَاةَ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ ابْغُونِي ضُعَفَاءَكُمْ فَإِنَّمَا تُرْزَقُونَ وَتُنْصَرُونَ بِضُعَفَائِكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1702}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Ad-Darda': That he heard the Prophet (ﷺ) saying: "Seek your weak for me. For indeed you sustenance and aid is only by your weak." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1703}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَصْحَبُ الْمَلاَئِكَةُ رُفْقَةً فِيهَا كَلْبٌ وَلاَ جَرَسٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُمَرَ وَعَائِشَةَ وَأُمِّ حَبِيبَةَ وَأُمِّ سَلَمَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1703}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "The angels do no accompany a group among whom there is a dog or a bell." [Abu 'Eisa said:] There are narrations on this topic from Ibn 'Umar, Umm Habibah, and Umm Salamah. This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1704}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، حَدَّثَنَا الأَحْوَصُ بْنُ الْجَوَّابِ أَبُو الْجَوَّابِ، عَنْ يُونُسَ بْنِ أَبِي إِسْحَاقَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ جَيْشَيْنِ وَأَمَّرَ عَلَى أَحَدِهِمَا عَلِيَّ بْنَ أَبِي طَالِبٍ وَعَلَى الآخَرِ خَالِدَ بْنَ الْوَلِيدِ وَقَالَ ‏"‏ إِذَا كَانَ الْقِتَالُ فَعَلِيٌّ ‏"‏ ‏.‏ قَالَ فَافْتَتَحَ عَلِيٌّ حِصْنًا فَأَخَذَ مِنْهُ جَارِيَةً فَكَتَبَ مَعِي خَالِدُ بْنُ الْوَلِيدِ إِلَى النَّبِيِّ صلى الله عليه وسلم يَشِي بِهِ فَقَدِمْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَرَأَ الْكِتَابَ فَتَغَيَّرَ لَوْنُهُ ثُمَّ قَالَ ‏"‏ مَا تَرَى فِي رَجُلٍ يُحِبُّ اللَّهَ وَرَسُولَهُ وَيُحِبُّهُ اللَّهُ وَرَسُولُهُ ‏"‏ ‏.‏ قَالَ قُلْتُ أَعُوذُ بِاللَّهِ مِنْ غَضَبِ اللَّهِ وَغَضَبِ رَسُولِهِ وَإِنَّمَا أَنَا رَسُولٌ ‏.‏ فَسَكَتَ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الأَحْوَصِ بْنِ جَوَّابٍ ‏.‏ مَعْنَى قَوْلِهِ يَشِي بِهِ يَعْنِي النَّمِيمَةَ ‏.‏\hadithno{1704}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Bara' : "The Prophet (ﷺ) sent two armies, place 'Ali bin Abi Talib as the commanded of one of them, and Khalid bin Al-Walid over the other. He said: 'Where there is fighting, then 'Ali (is in command).'" He said: "So 'Ali conquered a fortress and took a slave girl. Khalid [bin Al-Walid] wrote a letter and sent me with it to the Prophet (ﷺ), to speak against him for it. So I arrived to the Prophet (ﷺ) to read the letter. The color of his face changed, the he said: 'What do you think about a man who loves Allah and His Messenger, and Allah and His Messenger love him?'" He said: "I said: 'I seek refuge from angering Allah and angering His Messenger, I am only the Messenger.' So he was silent. [Abu 'Eisa said:] There is something about this from Ibn 'Umar. This Hadith is Hasan Gharib, we do not know of it except from the narration of Al-Ahwas bin Jawwab. And his saying: "To speak against him for that." refers to An-Namimah}}
\hadithdefcmd{tirmidhi}{1705}{\hadithno{1705}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1706}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى النَّيْسَابُورِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنِ الْعَيْزَارِ بْنِ حُرَيْثٍ، عَنْ أُمِّ الْحُصَيْنِ الأَحْمَسِيَّةِ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَخْطُبُ فِي حَجَّةِ الْوَدَاعِ وَعَلَيْهِ بُرْدٌ قَدِ الْتَفَعَ بِهِ مِنْ تَحْتِ إِبْطِهِ قَالَتْ فَأَنَا أَنْظُرُ إِلَى عَضَلَةِ عَضُدِهِ تَرْتَجُّ سَمِعْتُهُ يَقُولُ ‏ "‏ يَا أَيُّهَا النَّاسُ اتَّقُوا اللَّهَ وَإِنْ أُمِّرَ عَلَيْكُمْ عَبْدٌ حَبَشِيٌّ مُجَدَّعٌ فَاسْمَعُوا لَهُ وَأَطِيعُوا مَا أَقَامَ لَكُمْ كِتَابَ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعِرْبَاضِ بْنِ سَارِيَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أُمِّ حُصَيْنٍ ‏.‏\hadithno{1706}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Umm Al-Husain Al-Ahmasiyyah: I heard the Messenger of Allah (ﷺ) delivering Khutbah during the farewell Hajj, and he was wearing a Burd which he had wrapped from under his armpit." She said: "I was look at muscle of his upper arm quivering and I heard him saying: O you people! Have Taqwa of Allah. If a mutilated Ethiopian slave is put in command over you, then listen to him and obey him, as long as he upholds the Book of Allah among you.'" [Abu 'Eisa said:] There are narrations on this topic from Abu Hurairah and 'Irbad bin Sariyah. This Hadith is Hasan Sahih, it has been reported through other routes from Umm Husain}}
\hadithdefcmd{tirmidhi}{1707}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ السَّمْعُ وَالطَّاعَةُ عَلَى الْمَرْءِ الْمُسْلِمِ فِيمَا أَحَبَّ وَكَرِهَ مَا لَمْ يُؤْمَرْ بِمَعْصِيَةٍ فَإِنْ أُمِرَ بِمَعْصِيَةٍ فَلاَ سَمْعَ عَلَيْهِ وَلاَ طَاعَةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ وَعِمْرَانَ بْنِ حُصَيْنٍ وَالْحَكَمِ بْنِ عَمْرٍو الْغِفَارِيِّ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1707}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Ibn 'Umar: That the Messenger of Allah (ﷺ) said: "Hearing and obeying is required from every Muslim man - in what he like and what he dislikes - as long as he is not ordered with disobedience. If he is ordered with disobedience, then no hearing or obeying is required of him." [Abu 'Eisa said:] There are narrations on this topic from 'Ali, 'Imran bin Husain, and Al-Hakam bin 'Amr Al-Ghifari. This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1708}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ قُطْبَةَ بْنِ عَبْدِ الْعَزِيزِ، عَنِ الأَعْمَشِ، عَنْ أَبِي يَحْيَى، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ التَّحْرِيشِ بَيْنَ الْبَهَائِمِ ‏.‏\hadithno{1708}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Yahya:From Mujahid from Ibn 'Abbas who said: "The Messenger of Allah (ﷺ) prohibited instigating fights between beasts}}
\hadithdefcmd{tirmidhi}{1709}{\hadithno{1709}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1710}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْوَسْمِ فِي الْوَجْهِ وَالضَّرْبِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1710}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir: "The Prophet (ﷺ) prohibited branding on the face and striking (it)." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1711}{\hadithno{1711}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1712}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَهُ يُحَدِّثُ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَامَ فِيهِمْ فَذَكَرَ لَهُمْ أَنَّ الْجِهَادَ فِي سَبِيلِ اللَّهِ وَالإِيمَانَ بِاللَّهِ أَفْضَلُ الأَعْمَالِ فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ قُتِلْتُ فِي سَبِيلِ اللَّهِ أَيُكَفِّرُ عَنِّي خَطَايَاىَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ إِنْ قُتِلْتَ فِي سَبِيلِ اللَّهِ وَأَنْتَ صَابِرٌ مُحْتَسِبٌ مُقْبِلٌ غَيْرُ مُدْبِرٍ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَيْفَ قُلْتَ ‏"‏ ‏.‏ قُلْتُ أَرَأَيْتَ إِنْ قُتِلْتُ فِي سَبِيلِ اللَّهِ أَيُكَفِّرُ عَنِّي خَطَايَاىَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ وَأَنْتَ صَابِرٌ مُحْتَسِبٌ مُقْبِلٌ غَيْرُ مُدْبِرٍ إِلاَّ الدَّيْنَ فَإِنَّ جِبْرِيلَ قَالَ لِي ذَلِكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَنَسٍ وَمُحَمَّدِ بْنِ جَحْشٍ وَأَبِي هُرَيْرَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ سَعِيدٍ الْمَقْبُرِيِّ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا وَرَوَى يَحْيَى بْنُ سَعِيدٍ الأَنْصَارِيُّ وَغَيْرُ وَاحِدٍ نَحْوَ هَذَا عَنْ سَعِيدٍ الْمَقْبُرِيِّ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ سَعِيدٍ الْمَقْبُرِيِّ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{1712}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Abdullah bin Abi Qatadah: That he heard is father, narating a Hadith, which he heard from the Messenger of Allah (ﷺ) in which he stood among them, mentioning to them that Jihad in the cause of Allah and faith in Allah were the most virtuous of deeds. Then a man stood and said: "O Messenger of Allah! If I were killed in the cause of Allah, would my sins forgiven ?" So the Messenger of Allah (ﷺ) said: "Yes, If you are killed in Allah's cause, and you are patient, seeking the reward, advancing, not fleeing." Then the Messenger of Allah (ﷺ) said: "What was it that you said?" So he replied: "If I were killed in the cause of Allah, would my sins be removed (forgiven)?" So the Messenger of Allah (ﷺ) said: "Yes, If you are patient, seeking the reward, advancing, not fleeing - except debt. For Jibril said that to me." [Abu 'Eisa said:] There are narrations on this topic from Anas, Muhammad bin Jahsh, And Abu Hurairah. This Hadith is Hasan Sahih. Some of them reported this Hadith from Sa'eed Al-Maqburi, from Abu Hurairah, from the Prophet (ﷺ) similar to this. Yahya bin Sa'eed Al-Ansari and more than one narrator reported this from Sa'eed Al-Maqburi from 'Abdullah bin Abi Qatadah, from his fahter, from the Prophet (ﷺ). This is more correct than the narration of Sa'eed Al-Maqburi from Abu Hurairah}}
\hadithdefcmd{tirmidhi}{1713}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ أَيُّوبَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَبِي الدَّهْمَاءِ، عَنْ هِشَامِ بْنِ عَامِرٍ، قَالَ شُكِيَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الْجِرَاحَاتُ يَوْمَ أُحُدٍ فَقَالَ ‏ "‏ احْفِرُوا وَأَوْسِعُوا وَأَحْسِنُوا وَادْفِنُوا الاِثْنَيْنِ وَالثَّلاَثَةَ فِي قَبْرٍ وَاحِدٍ وَقَدِّمُوا أَكْثَرَهُمْ قُرْآنًا ‏"‏ ‏.‏ فَمَاتَ أَبِي فَقُدِّمَ بَيْنَ يَدَىْ رَجُلَيْنِ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ خَبَّابٍ وَجَابِرٍ وَأَنَسٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى سُفْيَانُ الثَّوْرِيُّ وَغَيْرُهُ هَذَا الْحَدِيثَ عَنْ أَيُّوبَ عَنْ حُمَيْدِ بْنِ هِلاَلٍ عَنْ هِشَامِ بْنِ عَامِرٍ ‏.‏ وَأَبُو الدَّهْمَاءِ اسْمُهُ قِرْفَةُ بْنُ بُهَيْسٍ أَوْ بَيْهَسٍ ‏.‏\hadithno{1713}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Hisham bin 'Amr: "On the day of Uhud, the wounded complained to the Messenger of Allah, so he said: 'Dig, and make it wide, and appropriate, and bury two and three in one grave. And advance the one who knew the most Qu'ran.' My father had died so he placed before two men." [Abu 'Eisa said:] There are narrations on this topic from Khabbab, Jabir, and Anas. This Hadith is Hasan Sahih Sufyan Ath-Thawri and others reported this Hadith from Ayyub, from Humaid bin Hilal, from Hisham bin 'Amir. And Abu Ad-Dahma's (a narrator in the chain) name is Qirfah bin Buhais or Baihas}}
\hadithdefcmd{tirmidhi}{1714}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ لَمَّا كَانَ يَوْمُ بَدْرٍ وَجِيءَ بِالأُسَارَى قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا تَقُولُونَ فِي هَؤُلاَءِ الأُسَارَى ‏"‏ ‏.‏ فَذَكَرَ قِصَّةً فِي هَذَا الْحَدِيثِ طَوِيلَةً ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُمَرَ وَأَبِي أَيُّوبَ وَأَنَسٍ وَأَبِي هُرَيْرَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ وَأَبُو عُبَيْدَةَ لَمْ يَسْمَعْ مِنْ أَبِيهِ ‏.‏ وَيُرْوَى عَنْ أَبِي هُرَيْرَةَ قَالَ مَا رَأَيْتُ أَحَدًا أَكْثَرَ مَشُورَةً لأَصْحَابِهِ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1714}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu 'Ubaidah: That 'Abdullah said: "On the Day of Badr when the captives were gathered, the Messenger of Allah (ﷺ) said: 'What do you (people) say about these captives?'" Then he mentioned the story in the lengthy Hadith. [Abu 'Eisa said:] There are narrations of this topic from 'Umar, Abu Ayyub, Anas, and Abu Hurairah This Hadith is Hasan, and Abu 'Ubaidah did not hear from his father. It has been reported that Abu Hurairah said: "None was more apt to seek council of his Companions than the Messenger of Allah (ﷺ)}}
\hadithdefcmd{tirmidhi}{1715}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي لَيْلَى، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ الْمُشْرِكِينَ، أَرَادُوا أَنْ يَشْتَرُوا، جَسَدَ رَجُلٍ مِنَ الْمُشْرِكِينَ فَأَبَى النَّبِيُّ صلى الله عليه وسلم أَنْ يَبِيعَهُمْ إِيَّاهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الْحَكَمِ ‏.‏ وَرَوَاهُ الْحَجَّاجُ بْنُ أَرْطَاةَ أَيْضًا عَنِ الْحَكَمِ ‏.‏ وَقَالَ أَحْمَدُ بْنُ الْحَسَنِ سَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ يَقُولُ ابْنُ أَبِي لَيْلَى لاَ يُحْتَجُّ بِحَدِيثِهِ ‏.‏ وَقَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ ابْنُ أَبِي لَيْلَى صَدُوقٌ وَلَكِنْ لاَ يُعْرَفُ صَحِيحُ حَدِيثِهِ مِنْ سَقِيمِهِ وَلاَ أَرْوِي عَنْهُ شَيْئًا ‏.‏ وَابْنُ أَبِي لَيْلَى صَدُوقٌ فَقِيهٌ وَإِنَّمَا يَهِمُ فِي الإِسْنَادِ ‏.‏ حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ عَنْ سُفْيَانَ الثَّوْرِيِّ قَالَ فُقَهَاؤُنَا ابْنُ أَبِي لَيْلَى وَعَبْدُ اللَّهِ بْنُ شُبْرُمَةَ ‏.‏\hadithno{1715}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas: "The idolaters wanted to purchase the body of a man who was from the idolaters. But the Prophet (ﷺ) refused to trade with them [for him]." [Abu 'Eisa said:] This Hadith is Hasan Gharib, we do not know of it except from a narration of Al-Hakam. Al-Hajjaj bin Artah also reported it from Al-Ahkam. Ahmad bin Al-Hasan said: "I heard Ahmad bin Hanbal saying: 'Ibn Abi Laila's narrations are not used as proof." Muhammad bin Isma'il said: "Ibn Abi Laila is truthful, but his correct Ahadith are not recognizable from his weak ones. And I do not report anything from him." Ibn Abi Laila is truthful, and Faqih, the problem is only in the chain. Nasr bin 'Ali narrated to us, [he said:] "Abdullah bin Dawud narrated us, from Sufyan Ath-Thawri who said: 'Our Fuqaha' are Ibn Abi Laila and 'Abdullah bin Shubrumah}}
\hadithdefcmd{tirmidhi}{1716}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ ابْنِ عُمَرَ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي سَرِيَّةٍ فَحَاصَ النَّاسُ حَيْصَةً فَقَدِمْنَا الْمَدِينَةَ فَاخْتَبَيْنَا بِهَا وَقُلْنَا هَلَكْنَا ثُمَّ أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْنَا يَا رَسُولَ اللَّهِ نَحْنُ الْفَرَّارُونَ ‏.‏ قَالَ ‏"‏ بَلْ أَنْتُمُ الْعَكَّارُونَ وَأَنَا فِئَتُكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ يَزِيدَ بْنِ أَبِي زِيَادٍ ‏.‏ وَمَعْنَى قَوْلِهِ فَحَاصَ النَّاسُ حَيْصَةً يَعْنِي أَنَّهُمْ فَرُّوا مِنَ الْقِتَالِ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ بَلْ أَنْتُمُ الْعَكَّارُونَ ‏"‏ ‏.‏ وَالْعَكَّارُ الَّذِي يَفِرُّ إِلَى إِمَامِهِ لِيَنْصُرَهُ لَيْسَ يُرِيدُ الْفِرَارَ مِنَ الزَّحْفِ ‏.‏\hadithno{1716}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Umar: "The Messenger of Allah sent us on a military expedition, and the people turned to escape. So we arrived in Al-Madinah and concealed ourselves in it and we said: 'We are ruined.' Then we went to the Messenger of Allah (ﷺ) and we said: 'O Messenger of Allah! We are those who fled.' He said: 'Rather you are Al-'Akkarun (those who are regrouping) and I am your reinforcement. [Abu 'Eisa said:] This Hadith is Hasan Gharib. We do not know of it except as a narration of Yazid bin Abi Ziyad. And the meaning of his saying: "The people turned to escape" is that they fled from the fighting. As for the meaning of his saying: "Rather you are Al-'Akkarun," the 'Akkar is the one who flees to his Imam in order that he may help him, it does not mean fleeing from the advancing army}}
\hadithdefcmd{tirmidhi}{1717}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، قَالَ سَمِعْتُ نُبَيْحًا الْعَنَزِيَّ، يُحَدِّثُ عَنْ جَابِرٍ، قَالَ لَمَّا كَانَ يَوْمُ أُحُدٍ جَاءَتْ عَمَّتِي بِأَبِي لِتَدْفِنَهُ فِي مَقَابِرِنَا فَنَادَى مُنَادِي رَسُولِ اللَّهِ صلى الله عليه وسلم رُدُّوا الْقَتْلَى إِلَى مَضَاجِعِهِمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ أَبُو عِيسَى وَنُبَيْحٌ ثِقَةٌ ‏.‏\hadithno{1717}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir bin ‘Abdullah : "On the day of Uhud, my father's sister came with my father to bury him in a cemetery of ours. So one of the callers of the Messenger of Allah (ﷺ) called out: 'Return those killed to where they were lying." [Abu 'Eisa said:] This Hadith is Hasan Sahih. And (one of the narrators) Nubaih is trustworthy}}
\hadithdefcmd{tirmidhi}{1718}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَسَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنِ السَّائِبِ بْنِ يَزِيدَ، قَالَ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ تَبُوكَ خَرَجَ النَّاسُ يَتَلَقَّوْنَهُ إِلَى ثَنِيَّةِ الْوَدَاعِ ‏.‏ قَالَ السَّائِبُ فَخَرَجْتُ مَعَ النَّاسِ وَأَنَا غُلاَمٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1718}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated As-Sa'ib bin Yazid: "When the Messenger of Allah (ﷺ) arrived from Tabuk, the people went out to Thaniyyah Al-Wada' to meet him." As-Sa'ib said: "I went out with the people, and I was a boy." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1719}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ شِهَابٍ، عَنْ مَالِكِ بْنِ أَوْسِ بْنِ الْحَدَثَانِ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ كَانَتْ أَمْوَالُ بَنِي النَّضِيرِ مِمَّا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِمَّا لَمْ يُوجِفِ الْمُسْلِمُونَ عَلَيْهِ بِخَيْلٍ وَلاَ رِكَابٍ وَكَانَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم خَالِصًا وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْزِلُ نَفَقَةَ أَهْلِهِ سَنَةً ثُمَّ يَجْعَلُ مَا بَقِيَ فِي الْكُرَاعِ وَالسِّلاَحِ عُدَّةً فِي سَبِيلِ اللَّهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى سُفْيَانُ بْنُ عُيَيْنَةَ هَذَا الْحَدِيثَ عَنْ مَعْمَرٍ عَنِ ابْنِ شِهَابٍ ‏.‏\hadithno{1719}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Umar bin Al-Khattab: "The wealth of Banu An-Nadir was among the spoils of war which Allah granted upon His Messenger (ﷺ) which the Muslims did not gain with the rush of their horses nor camel. So it was purely for the Messenger of Allah (ﷺ), and the Messenger of Allah (ﷺ) would set aside a year's worth of expenditure for his family, then he would use what remained of it for horses and weapons to be used in Allah's cause." [Abu 'Eisa said:] This Hadith is Hasan Sahih. Sufyan bin 'Uyainah reported this Hadith from Ma'mar, from Ibn Shihab}}
