% Auto-generated chapter 27 for bukhari
% Hadiths in this chapter: 15

\hadithdefcmd{bukhari}{1806}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ حِينَ خَرَجَ إِلَى مَكَّةَ مُعْتَمِرًا فِي الْفِتْنَةِ قَالَ إِنْ صُدِدْتُ عَنِ الْبَيْتِ صَنَعْتُ كَمَا صَنَعْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَأَهَلَّ بِعُمْرَةٍ، مِنْ أَجْلِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ أَهَلَّ بِعُمْرَةٍ عَامَ الْحُدَيْبِيَةِ‏.‏\hadithno{1806}\hadithtrans{Narrated Nafi`:When `Abdullah bin `Umar set out for Mecca intending to perform Umra, at the time of afflictions, he said, "If I should be prevented from reaching the Ka`ba, then I would do the same as Allah's Messenger (ﷺ) did, so I assume the Ihram for Umra as Allah's Messenger (ﷺ) assumed the Ihram for Umra in the year of Hudaibiya}}
\hadithdefcmd{bukhari}{1807}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، وَسَالِمَ بْنَ عَبْدِ اللَّهِ، أَخْبَرَاهُ أَنَّهُمَا، كَلَّمَا عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ لَيَالِيَ نَزَلَ الْجَيْشُ بِابْنِ الزُّبَيْرِ فَقَالاَ لاَ يَضُرُّكَ أَنْ لاَ تَحُجَّ الْعَامَ، وَإِنَّا نَخَافُ أَنْ يُحَالَ بَيْنَكَ وَبَيْنَ الْبَيْتِ‏.‏ فَقَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَحَالَ كُفَّارُ قُرَيْشٍ دُونَ الْبَيْتِ، فَنَحَرَ النَّبِيُّ صلى الله عليه وسلم هَدْيَهُ، وَحَلَقَ رَأْسَهُ، وَأُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ الْعُمْرَةَ، إِنْ شَاءَ اللَّهُ أَنْطَلِقُ، فَإِنْ خُلِّيَ بَيْنِي وَبَيْنَ الْبَيْتِ طُفْتُ، وَإِنْ حِيلَ بَيْنِي وَبَيْنَهُ فَعَلْتُ كَمَا فَعَلَ النَّبِيُّ صلى الله عليه وسلم وَأَنَا مَعَهُ‏.‏ فَأَهَلَّ بِالْعُمْرَةِ مِنْ ذِي الْحُلَيْفَةِ، ثُمَّ سَارَ سَاعَةً، ثُمَّ قَالَ ‏ "‏ إِنَّمَا شَأْنُهُمَا وَاحِدٌ، أُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ حَجَّةً مَعَ عُمْرَتِي ‏"‏‏.‏ فَلَمْ يَحِلَّ مِنْهُمَا حَتَّى حَلَّ يَوْمَ النَّحْرِ، وَأَهْدَى، وَكَانَ يَقُولُ لاَ يَحِلُّ حَتَّى يَطُوفَ طَوَافًا وَاحِدًا يَوْمَ يَدْخُلُ مَكَّةَ‏.‏\hadithno{1807}\hadithtrans{Narrated Nafi`:That Ubaidullah bin `Abdullah and Salim bin `Abdullah informed him that they told Ibn `Umar when Ibn Az-Zubair was attacked by the army, saying "There is no harm for you if you did not perform Hajj this year. We are afraid that you may be prevented from reaching the Ka`ba." Ibn `Umar said "We set out with Allah's Messenger (ﷺ) and the non-believers of Quraish prevented us from reaching the Ka`ba, and so the Prophet (ﷺ) slaughtered his Hadi and got his head shaved." Ibn `Umar added, "I make you witnesses that I have made `Umra obligatory for me. And, Allah willing, I will go and then if the way to Ka`ba is clear, I will perform the Tawaf, but if I am prevented from going to the Ka`ba then I will do the same as the Prophet (ﷺ) did while I was in his company." Ibn `Umar then assumed Ihram for Umra from Dhul-Hulaifa and proceeded for a while and said, "The conditions of `Umra and Hajj are similar and I make you witnesses that I have made `Umra and Hajj obligatory for myself." So, he did not finish the Ihram till the day of Nahr (slaughtering) came, and he slaughtered his Hadi. He used to say, "I will not finish the Ihram till I perform the Tawaf, one Tawaf on the day of entering Mecca (i.e. of Safa and Marwa for both `Umra and Hajj)}}
\hadithdefcmd{bukhari}{1808}{حَدَّثَنِي مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، أَنَّ بَعْضَ بَنِي عَبْدِ اللَّهِ، قَالَ لَهُ لَوْ أَقَمْتَ‏.‏ بِهَذَا‏.‏\hadithno{1808}\hadithtrans{Narrated Nafi`:Some of the sons of `Abdullah told him (i.e. `Abdullah) if he had stayed (and not performed Hajj that year)}}
\hadithdefcmd{bukhari}{1809}{حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا يَحْيَى بْنُ صَالِحٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ سَلاَّمٍ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ عِكْرِمَةَ، قَالَ قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ قَدْ أُحْصِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَحَلَقَ رَأْسَهُ وَجَامَعَ نِسَاءَهُ، وَنَحَرَ هَدْيَهُ، حَتَّى اعْتَمَرَ عَامًا قَابِلاً‏.‏\hadithno{1809}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) was prevented from performing (`Umra) Therefore, he shaved his head and had sexual relations with his wives and slaughtered his Hadi and performed Umra in the following year}}
\hadithdefcmd{bukhari}{1810}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمٌ، قَالَ كَانَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ أَلَيْسَ حَسْبُكُمْ سُنَّةَ رَسُولِ اللَّهِ صلى الله عليه وسلم، إِنْ حُبِسَ أَحَدُكُمْ عَنِ الْحَجِّ طَافَ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ، ثُمَّ حَلَّ مِنْ كُلِّ شَىْءٍ، حَتَّى يَحُجَّ عَامًا قَابِلاً، فَيُهْدِي أَوْ يَصُومُ، إِنْ لَمْ يَجِدْ هَدْيًا‏.‏ وَعَنْ عَبْدِ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سَالِمٌ، عَنِ ابْنِ عُمَرَ، نَحْوَهُ‏.‏\hadithno{1810}\hadithtrans{Narrated Salim:(Abdullah) bin `Umar used to say, "Is not (the following of) the tradition of Allah's Messenger (ﷺ) sufficient for you? If anyone of you is prevented from performing Hajj, he should perform the Tawaf of the Ka`ba and between As-Safa and Al-Marwa and then finish the Ihram and everything will become legal for him which was illegal for him (during the state of Ihram) and he can perform Hajj in a following year and he should slaughter a Hadi or fast in case he cannot afford the Hadi}}
\hadithdefcmd{bukhari}{1811}{حَدَّثَنَا مَحْمُودٌ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنِ الْمِسْوَرِ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَحَرَ قَبْلَ أَنْ يَحْلِقَ، وَأَمَرَ أَصْحَابَهُ بِذَلِكَ‏.‏\hadithno{1811}\hadithtrans{Narrated Al-Miswar:Allah's Messenger (ﷺ) slaughtered (the Hadi) before he had his head shaved and then he ordered his Companions to do the same}}
\hadithdefcmd{bukhari}{1812}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، أَخْبَرَنَا أَبُو بَدْرٍ، شُجَاعُ بْنُ الْوَلِيدِ عَنْ عُمَرَ بْنِ مُحَمَّدٍ الْعُمَرِيِّ، قَالَ وَحَدَّثَ نَافِعٌ، أَنَّ عَبْدَ اللَّهِ، وَسَالِمًا، كَلَّمَا عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ فَقَالَ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم مُعْتَمِرِينَ، فَحَالَ كُفَّارُ قُرَيْشٍ دُونَ الْبَيْتِ، فَنَحَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بُدْنَهُ، وَحَلَقَ رَأْسَهُ‏.‏\hadithno{1812}\hadithtrans{Narrated Nafi`:That `Abdullah and Salim said to `Abdullah bin `Umar, "(You should not go for Hajj this year)." `Abdullah bin `Umar replied, "We set out with the Prophet (to Mecca for performing `Umra) and the infidels of Quraish prevented us from reaching the Ka`ba. Allah's Messenger (ﷺ) slaughtered his Budn (camels for sacrifice) and got his head shaved}}
\hadithdefcmd{bukhari}{1813}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ حِينَ خَرَجَ إِلَى مَكَّةَ مُعْتَمِرًا فِي الْفِتْنَةِ إِنْ صُدِدْتُ عَنِ الْبَيْتِ صَنَعْنَا كَمَا صَنَعْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَهَلَّ بِعُمْرَةٍ، مِنْ أَجْلِ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ أَهَلَّ بِعُمْرَةٍ عَامَ الْحُدَيْبِيَةِ، ثُمَّ إِنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ نَظَرَ فِي أَمْرِهِ فَقَالَ مَا أَمْرُهُمَا إِلاَّ وَاحِدٌ‏.‏ فَالْتَفَتَ إِلَى أَصْحَابِهِ فَقَالَ مَا أَمْرُهُمَا إِلاَّ وَاحِدٌ، أُشْهِدُكُمْ أَنِّي قَدْ أَوْجَبْتُ الْحَجَّ مَعَ الْعُمْرَةِ، ثُمَّ طَافَ لَهُمَا طَوَافًا وَاحِدًا، وَرَأَى أَنَّ ذَلِكَ مُجْزِيًا عَنْهُ، وَأَهْدَى‏.‏\hadithno{1813}\hadithtrans{Narrated Nafi`:When `Abdullah bin `Umar set out for Mecca with the intention of performing `Umra in the period of afflictions, he said, "If I should be prevented from reaching the Ka`ba, then I would do the same as we did while in the company of Allah's Messenger (ﷺ) ." So, he assumed the Ihram for `Umra since the Prophet (ﷺ) had assumed the Ihram for `Umra in the year of Al-Hudaibiya. Then `Abdullah bin `Umar thought about it and said, "The conditions for both Hajj and `Umra are similar." He then turned towards his companions and said, "The conditions of both Hajj and `Umra are similar and I make you witnesses that I have made the performance of Hajj obligatory for myself along with `Umra." He then performed one Tawaf (between As-Safa and Al-Marwa) for both of them (i.e. Hajj and (`Umra) and considered that to be sufficient for him and offered a Hadi}}
\hadithdefcmd{bukhari}{1814}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ حُمَيْدِ بْنِ قَيْسٍ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لَعَلَّكَ آذَاكَ هَوَامُّكَ ‏"‏‏.‏ قَالَ نَعَمْ يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ احْلِقْ رَأْسَكَ وَصُمْ ثَلاَثَةَ أَيَّامٍ، أَوْ أَطْعِمْ سِتَّةَ مَسَاكِينَ، أَوِ انْسُكْ بِشَاةٍ ‏"‏‏.‏\hadithno{1814}\hadithtrans{Narrated `Abdur-Rahman bin Abu Layla:Ka`b bin 'Ujra said that Allah's Messenger (ﷺ) said to him (Ka`b), "Perhaps your lice have troubled you?" Ka`b replied, "Yes! O Allah's Messenger (ﷺ)." Allah's Messenger (ﷺ) said, "Have your head shaved and then either fast three days or feed six poor persons or slaughter one sheep as a sacrifice}}
\hadithdefcmd{bukhari}{1815}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سَيْفٌ، قَالَ حَدَّثَنِي مُجَاهِدٌ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ أَبِي لَيْلَى، أَنَّ كَعْبَ بْنَ عُجْرَةَ، حَدَّثَهُ قَالَ وَقَفَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْحُدَيْبِيَةِ، وَرَأْسِي يَتَهَافَتُ قَمْلاً فَقَالَ ‏"‏ يُؤْذِيكَ هَوَامُّكَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ فَاحْلِقْ رَأْسَكَ ـ أَوْ قَالَ ـ احْلِقْ ‏"‏‏.‏ قَالَ فِيَّ نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏فَمَنْ كَانَ مِنْكُمْ مَرِيضًا أَوْ بِهِ أَذًى مِنْ رَأْسِهِ‏\}‏ إِلَى آخِرِهَا‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ صُمْ ثَلاَثَةَ أَيَّامٍ، أَوْ تَصَدَّقْ بِفَرَقٍ بَيْنَ سِتَّةٍ، أَوِ انْسُكْ بِمَا تَيَسَّرَ ‏"‏‏.‏\hadithno{1815}\hadithtrans{Narrated Ka`b bin `Umra:Allah's Messenger (ﷺ) stood beside me at Al-Hudaibiya and the lice were falling from my head in great number. He asked me, "Have your lice troubled you?" I replied in the affirmative. He ordered me to get my head shaved. Ka`b added, "This Holy Verse:--'And if any of you is ill, or has ailment in his scalp (2.196), etc. was revealed regarding me. "The Prophet (ﷺ) then ordered me either to fast three days, or to feed six poor persons with one Faraq (three Sas) (of dates), or to slaughter a sheep, etc. (sacrifice) whatever was available}}
\hadithdefcmd{bukhari}{1816}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَصْبِهَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْقِلٍ، قَالَ جَلَسْتُ إِلَى كَعْبِ بْنِ عُجْرَةَ ـ رضى الله عنه ـ فَسَأَلْتُهُ عَنِ الْفِدْيَةِ، فَقَالَ نَزَلَتْ فِيَّ خَاصَّةً، وَهْىَ لَكُمْ عَامَّةً، حُمِلْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَالْقَمْلُ يَتَنَاثَرُ عَلَى وَجْهِي فَقَالَ ‏"‏ مَا كُنْتُ أُرَى الْوَجَعَ بَلَغَ بِكَ مَا أَرَى أَوْ مَا كُنْتُ أُرَى الْجَهْدَ بَلَغَ بِكَ مَا أَرَى، تَجِدُ شَاةً ‏"‏‏.‏ فَقُلْتُ لاَ‏.‏ فَقَالَ ‏"‏ فَصُمْ ثَلاَثَةَ أَيَّامٍ، أَوْ أَطْعِمْ سِتَّةَ مَسَاكِينَ، لِكُلِّ مِسْكِينٍ نِصْفَ صَاعٍ ‏"‏‏.‏\hadithno{1816}\hadithtrans{Narrated `Abdullah bin Ma'qil:I sat with Ka`b bin 'Ujra and asked him about the Fidya. He replied, "This revelation was revealed concerning my case especially, but it is also for you in general. I was carried to Allah's Messenger (ﷺ) and the lice were falling in great number on my face. The Prophet (ﷺ) said, "I have never thought that your ailment (or struggle) has reached to such an extent as I see. Can you afford a sheep?" I replied in the negative. He then said, "Fast for three days, or feed six poor persons each with half a Sa of food." (1 Sa = 3 Kilograms approx)}}
\hadithdefcmd{bukhari}{1817}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا شِبْلٌ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَآهُ وَأَنَّهُ يَسْقُطُ عَلَى وَجْهِهِ فَقَالَ ‏ "‏ أَيُؤْذِيكَ هَوَامُّكَ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ فَأَمَرَهُ أَنْ يَحْلِقَ وَهُوَ بِالْحُدَيْبِيَةِ، وَلَمْ يَتَبَيَّنْ لَهُمْ أَنَّهُمْ يَحِلُّونَ بِهَا، وَهُمْ عَلَى طَمَعٍ أَنْ يَدْخُلُوا مَكَّةَ، فَأَنْزَلَ اللَّهُ الْفِدْيَةَ، فَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُطْعِمَ فَرَقًا بَيْنَ سِتَّةٍ، أَوْ يُهْدِيَ شَاةً، أَوْ يَصُومَ ثَلاَثَةَ أَيَّامٍ‏.‏\hadithno{1817}\hadithtrans{Narrated `Abdur-Rahman bin Abu Layla:(Reporting the speech of Ka`b bin Ujra) Allah's Messenger (ﷺ) saw him (i.e. Ka`b) while the lice were falling on his face. He asked (him), "Have your lice troubled you?" He replied in the affirmative. So, he ordered him to get his head shaved while he was at Al-Hudaibiya. At that time they were not permitted to finish their Ihram, and were still hoping to enter Mecca. So, Allah revealed the verses of Al-Fidya. Allah's Messenger (ﷺ) ordered him to feed six poor persons with one Faraq of food or to slaughter one sheep (as a sacrifice) or to fast for three days}}
\hadithdefcmd{bukhari}{1818}{وَعَنْ مُحَمَّدِ بْنِ يُوسُفَ، حَدَّثَنَا وَرْقَاءُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَآهُ، وَقَمْلُهُ يَسْقُطُ عَلَى وَجْهِهِ‏.‏ مِثْلَهُ‏.‏\hadithno{1818}\hadithtrans{Narrated Ka'b bin 'Ujra (ra):Allah's Messenger (ﷺ) saw him (i.e. Ka'b) while the lice were falling on his face}}
\hadithdefcmd{bukhari}{1819}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَجَّ هَذَا الْبَيْتَ، فَلَمْ يَرْفُثْ وَلَمْ يَفْسُقْ، رَجَعَ كَمَا وَلَدَتْهُ أُمُّهُ ‏"‏‏.‏\hadithno{1819}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Whoever performs Hajj to this House (Ka`ba) and does not approach his wife for sexual relations nor commits sins (while performing Hajj), he will come out as sinless as a newlyborn child. (Just delivered by his mother)}}
\hadithdefcmd{bukhari}{1820}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ حَجَّ هَذَا الْبَيْتَ، فَلَمْ يَرْفُثْ، وَلَمْ يَفْسُقْ، رَجَعَ كَيَوْمِ وَلَدَتْهُ أُمُّهُ ‏"‏‏.‏\hadithno{1820}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever performs Hajj to this Ka`ba and does not approach his wife for sexual relations nor commit sins (while performing Hajj), he will come out as sinless as a newborn child, (just delivered by his mother)}}
