% Auto-generated chapter 33 for nasai
% Hadiths in this chapter: 14

\hadithdefcmd{nasai}{3706}{أَخْبَرَنَا هِلاَلُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، - وَهُوَ ابْنُ عَمْرٍو - عَنْ سُفْيَانَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ طَاوُسٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الرُّقْبَى جَائِزَةٌ ‏"‏ ‏.‏\hadithno{3706}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Hilal bin Al-'Ala' informed us:"My father narrated to us: Ubaidullah -he is, Ibn 'Amr- narrated to us, from Sufyan, from Ibn Abi Najih, from Tawus, from Zaid bin Thabit, that the Prophet said: 'Ar-Ruqba is permissible}}
\hadithdefcmd{nasai}{3707}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَلِيِّ بْنِ مَيْمُونٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ يُوسُفَ - قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ طَاوُسٍ، عَنْ رَجُلٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم جَعَلَ الرُّقْبَى لِلَّذِي أُرْقِبَهَا ‏.‏\hadithno{3707}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Muhammad bin 'Ali bin Maimun informed us, he said:"Muhammad -he is, Ibn Yusuf- narrated to us, he said: 'Sufyan narrated to us from Ibn Abi Najih, from Tawus, from a man, from Zaid bin Thabit that the Prophet ruled that the Ruqba belongs to the one to whom it is given}}
\hadithdefcmd{nasai}{3708}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ الْجَبَّارِ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ طَاوُسٍ، لَعَلَّهُ عَنِ ابْنِ عَبَّاسٍ، قَالَ لاَ رُقْبَى فَمَنْ أُرْقِبَ شَيْئًا فَهُوَ سَبِيلُ الْمِيرَاثِ ‏.‏\hadithno{3708}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Zakariyya bin Yahya informed us, he said:"Abdul-Jabbar bin Al-'Ala' narrated to us, he said: 'Sufyan narrated to us from Ibn Abi Najih, from Tawus, and perhaps it is from Ibn 'Abbas, who said: There is no Ruqba, and whoever gives a gift on the basis of Ruqba, it is part of his estate}}
\hadithdefcmd{nasai}{3709}{أَخْبَرَنِي مُحَمَّدُ بْنُ وَهْبٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنِي أَبُو عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنِي زَيْدٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُرْقِبُوا أَمْوَالَكُمْ فَمَنْ أَرْقَبَ شَيْئًا فَهُوَ لِمَنْ أُرْقِبَهُ ‏"‏ ‏.‏\hadithno{3709}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Zaid narrated from Abu Az-Zubair, from Tawus, from Ibn 'Abbas that the Messenger of Allah said:"Do not give away your property on the basis of Ruqba, for whoever gives a gift on that basis, it belongs to the one to whom he gave it}}
\hadithdefcmd{nasai}{3710}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ حَجَّاجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعُمْرَى جَائِزَةٌ لِمَنْ أُعْمِرَهَا وَالرُّقْبَى جَائِزَةٌ لِمَنْ أُرْقِبَهَا وَالْعَائِدُ فِي هِبَتِهِ كَالْعَائِدِ فِي قَيْئِهِ ‏"‏ ‏.‏\hadithno{3710}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Hajjaj narrated from Abu Az-Zubair, from Tawus, from Ibn 'Abbas, who said:"The Messenger of Allah said: 'Umra (life-long gift) is permissible for the one to whom it is given, and Ruqba is permissible to the one to whom it is given, and the one who takes back his gift is like the one who goes back to his vomit}}
\hadithdefcmd{nasai}{3711}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ الْعُمْرَى وَالرُّقْبَى سَوَاءٌ ‏.‏\hadithno{3711}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Sufyan narrated from Abu Az-Zubair, from Tawus, from Ibn 'Abbas, who said:"'Umra and Ruqba are the same}}
\hadithdefcmd{nasai}{3712}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَعْلَى، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لاَ تَحِلُّ الرُّقْبَى وَلاَ الْعُمْرَى فَمَنْ أُعْمِرَ شَيْئًا فَهُوَ لَهُ وَمَنْ أُرْقِبَ شَيْئًا فَهُوَ لَهُ ‏.‏\hadithno{3712}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{(A different chain) from Sufyan, from Abu Az-Zubair, from Tawus, from Ibn 'Abbas, who said:"Ruqba and 'Umra are not permissible; whoever is given something on the basis of 'Umra, it is his, and whoever is given something on the basis of Ruqba, it is his}}
\hadithdefcmd{nasai}{3713}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لاَ تَصْلُحُ الْعُمْرَى وَلاَ الرُّقْبَى فَمَنْ أَعْمَرَ شَيْئًا أَوْ أَرْقَبَهُ فَإِنَّهُ لِمَنْ أُعْمِرَهُ وَأُرْقِبَهُ حَيَاتَهُ وَمَوْتَهُ ‏.‏ أَرْسَلَهُ حَنْظَلَةُ ‏.‏\hadithno{3713}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{(A different chain) from Hajjaj, from Abu Az-Zubair, from Tawus, from Ibn 'Abbas, who said:"'Umra and Ruqba are not proper. Whoever gives something on the basis of 'Umra or Ruqba, it belongs to the one to whom he gave it on that basis, both during his lifetime and after his death." Hanzalah narrated it in Mursal form}}
\hadithdefcmd{nasai}{3714}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ أَنْبَأَنَا حِبَّانُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ حَنْظَلَةَ، أَنَّهُ سَمِعَ طَاوُسًا، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَحِلُّ الرُّقْبَى فَمَنْ أُرْقِبَ رُقْبَى فَهُوَ سَبِيلُ الْمِيرَاثِ ‏"‏ ‏.‏\hadithno{3714}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Hanzalah narrated that he heard Tawus say:"The Messenger of Allah said: 'Ruqba is not permissible. Whoever is given something on the basis of Ruqba, it is part of his estate}}
\hadithdefcmd{nasai}{3715}{أَخْبَرَنِي عَبْدَةُ بْنُ عَبْدِ الرَّحِيمِ، عَنْ وَكِيعٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ طَاوُسٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعُمْرَى مِيرَاثٌ ‏"‏ ‏.‏\hadithno{3715}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Sufyan narrated from Ibn Abi Najih, from Tawus, from Zaid bin Thabit, who said:"The Messenger of Allah said: 'Umra (a gift given for life) is part of the estate}}
\hadithdefcmd{nasai}{3716}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ حُجْرٍ الْمَدَرِيِّ، عَنْ زَيْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعُمْرَى لِلْوَارِثِ ‏"‏ ‏.‏\hadithno{3716}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Sufyan narrated from Ibn Tawus, from his father, from Hujr Al-Madari, from Zaid, who said:"The Messenger of Allah said: 'Umra (a gift given for life) is for the heir}}
\hadithdefcmd{nasai}{3717}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ حُجْرٍ الْمَدَرِيِّ، عَنْ زَيْدِ بْنِ ثَابِتٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَى جَائِزَةٌ ‏"‏ ‏.‏\hadithno{3717}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ma'mar narrated from Ibn Tawus, from his father, from Hujr Al-Madari, from Zaid bin Thabit, from Prophet, who said:"'Umra (a gift given for life) is permissible}}
\hadithdefcmd{nasai}{3718}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَى لِلْوَارِثِ ‏"‏ ‏.‏\hadithno{3718}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ma'mar narrated from 'Amr bin Dinar, from Tawus, from Zaid bin Thabit, that the Prophet said:"'Umra (a gift given for life) belongs to the heir}}
\hadithdefcmd{nasai}{3719}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمٍ، قَالَ أَنْبَأَنَا حِبَّانُ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ مَعْمَرٍ، قَالَ سَمِعْتُ عَمْرَو بْنَ دِينَارٍ، يُحَدِّثُ عَنْ طَاوُسٍ، عَنْ حُجْرٍ الْمَدَرِيِّ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَى لِلْوَارِثِ ‏"‏ ‏.‏ وَاللَّهُ أَعْلَمُ ‏.‏\hadithno{3719}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{(A different chain) from Ma'mar who said:"I heard 'Amr bin Dinar, narrating from Tawus, from Hujr Al-Madari, from Zaid bin Thabit, that the Messenger of Allah said: "'Umra (a gift given for life) belongs to the heir." And Allah knows best}}
