% Auto-generated chapter 39 for nasai
% Hadiths in this chapter: 63

\hadithdefcmd{nasai}{4149}{أَخْبَرَنَا الإِمَامُ أَبُو عَبْدِ الرَّحْمَنِ النَّسَائِيُّ، مِنْ لَفْظِهِ قَالَ أَنْبَأَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عُبَادَةَ بْنِ الْوَلِيدِ بْنِ عُبَادَةَ بْنِ الصَّامِتِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ فِي الْيُسْرِ وَالْعُسْرِ وَالْمَنْشَطِ وَالْمَكْرَهِ وَأَنْ لاَ نُنَازِعَ الأَمْرَ أَهْلَهُ وَأَنْ نَقُومَ بِالْحَقِّ حَيْثُ كُنَّا لاَ نَخَافُ لَوْمَةَ لاَئِمٍ ‏.‏\hadithno{4149}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ubadah bin As-Samit said:"We pledged to the Messenger of Allah to hear and obey, both in times of ease and hardship, when we felt energetic and when we felt tired, that we would not contend with the orders of whomever was entrusted with it, that we would was entrusted with it, that we would stand firm in the way of truth wherever we may be, and that we would not fear the blame of the blamers}}
\hadithdefcmd{nasai}{4150}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عُبَادَةَ بْنِ الْوَلِيدِ بْنِ عُبَادَةَ بْنِ الصَّامِتِ، عَنْ أَبِيهِ، أَنَّ عُبَادَةَ بْنَ الصَّامِتِ، قَالَ بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ فِي الْعُسْرِ وَالْيُسْرِ ‏.‏ وَذَكَرَ مِثْلَهُ ‏.‏\hadithno{4150}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ubadah bin As-Samit said:"We pledged to the Messenger of Allah to hear and obey, both in times of hardship and ease." And he mentioned similarly}}
\hadithdefcmd{nasai}{4151}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ أَخْبَرَنِي عُبَادَةُ بْنُ الْوَلِيدِ بْنِ عُبَادَةَ، قَالَ حَدَّثَنِي أَبِي، عَنْ عُبَادَةَ، قَالَ بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ فِي الْيُسْرِ وَالْعُسْرِ وَالْمَنْشَطِ وَالْمَكْرَهِ وَأَنْ لاَ نُنَازِعَ الأَمْرَ أَهْلَهُ وَأَنْ نَقُولَ - أَوْ نَقُومَ - بِالْحَقِّ حَيْثُمَا كُنَّا لاَ نَخَافُ لَوْمَةَ لاَئِمٍ ‏.‏\hadithno{4151}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Ubadah said:"We pledged to the Messenger of Allah to hear and obey both in times of hardship and ease, when we felt energetic and when we felt tired, that we would not contend with the orders of whomever was entrusted with it, that we would speak the truth or stand firm in the way of truth wherever we may be, and that we would not fear the blame of the blamers}}
\hadithdefcmd{nasai}{4152}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ أَيُّوبَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ ابْنِ إِسْحَاقَ، وَيَحْيَى بْنِ سَعِيدٍ، عَنْ عُبَادَةَ بْنِ الْوَلِيدِ بْنِ عُبَادَةَ بْنِ الصَّامِتِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ فِي الْعُسْرِ وَالْيُسْرِ وَالْمَنْشَطِ وَالْمَكْرَهِ وَأَنْ لاَ نُنَازِعَ الأَمْرَ أَهْلَهُ وَعَلَى أَنْ نَقُولَ بِالْحَقِّ حَيْثُ كُنَّا ‏.‏\hadithno{4152}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Ubadah bin Al-Walid bin 'Ubadah bin As-Samit, frim this father, that his grandfather said:"We pledged to the Messenger of Allah to hear and obey both in times of hardship and ease, when we felt energetic and when we felt tired, and when others are preferred over us, that we would not contend with the orders of whomever was entrusted with it, and that we would speak the truth wherever we may be}}
\hadithdefcmd{nasai}{4153}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنِي الْوَلِيدُ بْنُ كَثِيرٍ، قَالَ حَدَّثَنِي عُبَادَةُ بْنُ الْوَلِيدِ، أَنَّ أَبَاهُ الْوَلِيدَ، حَدَّثَهُ عَنْ جَدِّهِ، عُبَادَةَ بْنِ الصَّامِتِ قَالَ بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ فِي عُسْرِنَا وَيُسْرِنَا وَمَنْشَطِنَا وَمَكَارِهِنَا وَعَلَى أَنْ لاَ نُنَازِعَ الأَمْرَ أَهْلَهُ وَعَلَى أَنْ نَقُولَ بِالْعَدْلِ أَيْنَ كُنَّا لاَ نَخَافُ فِي اللَّهِ لَوْمَةَ لاَئِمٍ ‏.‏\hadithno{4153}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ubadah bin As-Samit said:"We pledged to the Messenger of Allah to hear and obey during our hardship and our ease, when we felt energetic and when we felt tired, that we would not contend with the orders of whomever was entrusted with it, that we would stand for justice wherever we may be, and that we would not fear the blame of any blamer for the sake of Allah}}
\hadithdefcmd{nasai}{4154}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْوَلِيدِ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَيَّارٍ، وَيَحْيَى بْنِ سَعِيدٍ، أَنَّهُمَا سَمِعَا عُبَادَةَ بْنَ الْوَلِيدِ، يُحَدِّثُ عَنْ أَبِيهِ، - أَمَّا سَيَّارٌ فَقَالَ عَنْ أَبِيهِ، وَأَمَّا، يَحْيَى فَقَالَ عَنْ أَبِيهِ، عَنْ جَدِّهِ، - قَالَ بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ فِي عُسْرِنَا وَيُسْرِنَا وَمَنْشَطِنَا وَمَكْرَهِنَا وَأَثَرَةٍ عَلَيْنَا وَأَنْ لاَ نُنَازِعَ الأَمْرَ أَهْلَهُ وَأَنْ نَقُومَ بِالْحَقِّ حَيْثُمَا كَانَ لاَ نَخَافُ فِي اللَّهِ لَوْمَةَ لاَئِمٍ ‏.‏ قَالَ شُعْبَةُ سَيَّارٌ لَمْ يَذْكُرْ هَذَا الْحَرْفَ حَيْثُمَا كَانَ وَذَكَرَهُ يَحْيَى ‏.‏ قَالَ شُعْبَةُ إِنْ كُنْتُ زِدْتُ فِيهِ شَيْئًا فَهُوَ عَنْ سَيَّارٍ أَوْ عَنْ يَحْيَى ‏.‏\hadithno{4154}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Shu'bah, from Sayyar and Yahya bin Sa'eed that they heard 'Ubadah bin Al-Walid narrating from his father. Sayyar said:"From his father," and Yahya said: "From his father," from his grandfather, whom said: 'We pledged to the Messenger of Allah to hear and obey during our hardship and our ease, when we felt energetic and when we felt tired, and when others are preferred over us, that we would not contend with the orders of whomever was entrusted with it, that we would stand firm for the truth wherever it may be, and that we would not fear the blame of any blamer for the sake of Allah." (Sahih) Shu'bah said: "Sayyar did not mention this statement: 'Wherever it may be' while Yahya mentioned it." Shu'bah said: "If I have added anything to it, then it is from Sayyar or from Yahya}}
\hadithdefcmd{nasai}{4155}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَعْقُوبُ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عَلَيْكَ بِالطَّاعَةِ فِي مَنْشَطِكَ وَمَكْرَهِكَ وَعُسْرِكَ وَيُسْرِكَ وَأَثَرَةٍ عَلَيْكَ ‏"‏ ‏.‏\hadithno{4155}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"You have to obey when you feel energetic and when you feel tired, during your ease and your hardship, and when others are preferred over you}}
\hadithdefcmd{nasai}{4156}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ جَرِيرٍ، قَالَ بَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى النُّصْحِ لِكُلِّ مُسْلِمٍ ‏.‏\hadithno{4156}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jarir said:"I pledged to the Messenger of Allah to be sincere toward ever Muslim}}
\hadithdefcmd{nasai}{4157}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ يُونُسَ، عَنْ عَمْرِو بْنِ سَعِيدٍ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، قَالَ جَرِيرٌ بَايَعْتُ النَّبِيَّ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ وَأَنْ أَنْصَحَ لِكُلِّ مُسْلِمٍ ‏.‏\hadithno{4157}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jarir said:"I pledged to the Prophet to hear and obey and to be sincere toward every Muslim}}
\hadithdefcmd{nasai}{4158}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، سَمِعَ جَابِرًا، يَقُولُ لَمْ نُبَايِعْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الْمَوْتِ إِنَّمَا بَايَعْنَاهُ عَلَى أَنْ لاَ نَفِرَّ ‏.‏\hadithno{4158}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir said:"We did not give our pledge to the Messenger of Allah for death, rather we pledged not to flee (from battle)}}
\hadithdefcmd{nasai}{4159}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، قَالَ قُلْتُ لِسَلَمَةَ بْنِ الأَكْوَعِ عَلَى أَىِّ شَىْءٍ بَايَعْتُمُ النَّبِيَّ صلى الله عليه وسلم يَوْمَ الْحُدَيْبِيَةِ قَالَ عَلَى الْمَوْتِ ‏.‏\hadithno{4159}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Yazid bin Abi 'Ubaid said:"I said to Salamah bin Al-Akwa': 'What pledge did you make to the Prophet on the Day of Al-Hudaibiyyah?' He said: 'For death}}
\hadithdefcmd{nasai}{4160}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، أَنَّ عَمْرَو بْنَ عَبْدِ الرَّحْمَنِ بْنِ أُمَيَّةَ بْنِ أَخِي، يَعْلَى بْنِ أُمَيَّةَ حَدَّثَهُ أَنَّ أَبَاهُ أَخْبَرَهُ أَنَّ يَعْلَى بْنَ أُمَيَّةَ قَالَ جِئْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِأَبِي أُمَيَّةَ يَوْمَ الْفَتْحِ فَقُلْتُ يَا رَسُولَ اللَّهِ بَايِعْ أَبِي عَلَى الْهِجْرَةِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُبَايِعُهُ عَلَى الْجِهَادِ وَقَدِ انْقَطَعَتِ الْهِجْرَةُ ‏"‏ ‏.‏\hadithno{4160}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ya'la bin Umayyah said:"I came to the Messenger of Allah with my father Umayyah on the Day of the Conquest (of Makkah) and said: 'O Messenger of Allah, accept my father's pledge for emigration (Al-Hijrah).' The Messenger of Allah said: 'I will accept his pledge to fight in Jihad, for the emigration (Al-Hijrah) has ceased}}
\hadithdefcmd{nasai}{4161}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، قَالَ حَدَّثَنِي عَمِّي، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ، أَنَّ عُبَادَةَ بْنَ الصَّامِتِ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ وَحَوْلَهُ عِصَابَةٌ مِنْ أَصْحَابِهِ ‏ "‏ تُبَايِعُونِي عَلَى أَنْ لاَ تُشْرِكُوا بِاللَّهِ شَيْئًا وَلاَ تَسْرِقُوا وَلاَ تَزْنُوا وَلاَ تَقْتُلُوا أَوْلاَدَكُمْ وَلاَ تَأْتُوا بِبُهْتَانٍ تَفْتَرُونَهُ بَيْنَ أَيْدِيكُمْ وَأَرْجُلِكُمْ وَلاَ تَعْصُونِي فِي مَعْرُوفٍ فَمَنْ وَفَّى فَأَجْرُهُ عَلَى اللَّهِ وَمَنْ أَصَابَ مِنْكُمْ شَيْئًا فَعُوقِبَ بِهِ فَهُوَ لَهُ كَفَّارَةٌ وَمَنْ أَصَابَ مِنْ ذَلِكَ شَيْئًا ثُمَّ سَتَرَهُ اللَّهُ فَأَمْرُهُ إِلَى اللَّهِ إِنْ شَاءَ عَفَا عَنْهُ وَإِنْ شَاءَ عَاقَبَهُ ‏"‏ ‏.‏ خَالَفَهُ أَحْمَدُ بْنُ سَعِيدٍ ‏.‏\hadithno{4161}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Ubadah bin As-Samit said:"While there was a group of his companions around him, the Messenger of Allah said: 'Pledge to me, that you will not associate anything with Allah, nor steal, nor commit unlawful sexual relations, nor kill your children; you will not utter slander, fabricating from between your hands and feet, and you will not disobey me in goodness (Ma'ruf). Whoever fulfills (this pledge), his reward will be with Allah, and whoever commits any of these actions and is punished for it, it will be an expiation for him. Whoever commits any of these actions then Allah conceals him, then his affair is up to Allah; if He wills He will forgive him, and if He wills punish him."' (Sahih) Ahmed bin Sa'eed contradicted him}}
\hadithdefcmd{nasai}{4162}{أَخْبَرَنِي أَحْمَدُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَعْقُوبُ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ الْحَارِثِ بْنِ فُضَيْلٍ، أَنَّ ابْنَ شِهَابٍ، حَدَّثَهُ عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَلاَ تُبَايِعُونِي عَلَى مَا بَايَعَ عَلَيْهِ النِّسَاءُ أَنْ لاَ تُشْرِكُوا بِاللَّهِ شَيْئًا وَلاَ تَسْرِقُوا وَلاَ تَزْنُوا وَلاَ تَقْتُلُوا أَوْلاَدَكُمْ وَلاَ تَأْتُوا بِبُهْتَانٍ تَفْتَرُونَهُ بَيْنَ أَيْدِيكُمْ وَأَرْجُلِكُمْ وَلاَ تَعْصُونِي فِي مَعْرُوفٍ ‏"‏ ‏.‏ قُلْنَا بَلَى يَا رَسُولَ اللَّهِ فَبَايَعْنَاهُ عَلَى ذَلِكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَمَنْ أَصَابَ بَعْدَ ذَلِكَ شَيْئًا فَنَالَتْهُ عُقُوبَةٌ فَهُوَ كَفَّارَةٌ وَمَنْ لَمْ تَنَلْهُ عُقُوبَةٌ فَأَمْرُهُ إِلَى اللَّهِ إِنْ شَاءَ غَفَرَ لَهُ وَإِنْ شَاءَ عَاقَبَهُ ‏"‏ ‏.‏\hadithno{4162}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Ubadah bin As-Samit that the Messenger of Allah said:"Why don't you pledge to me upon that which the women have pledged: That you will not associate anything with Allah, that you will not steal, that you will not have unlawful sexual relations, that you will not utter slander, fabricating from between your hands and feet, and that you will not disobey me in goodness (Ma'ruf)?" We said: "yes, O Messenger of Allah." So we gave him our pledge, on that basis. The Messenger of Allah said: "Whoever commits any of these actions after that, and is punished, that will be an expiation. Whoever is not punished, then his affair is up to Allah; if He wills, He will forgive him, and if He wills, He will punish him}}
\hadithdefcmd{nasai}{4163}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنِّي جِئْتُ أُبَايِعُكَ عَلَى الْهِجْرَةِ وَلَقَدْ تَرَكْتُ أَبَوَىَّ يَبْكِيَانِ ‏.‏ قَالَ ‏ "‏ ارْجِعْ إِلَيْهِمَا فَأَضْحِكْهُمَا كَمَا أَبْكَيْتَهُمَا ‏"‏ ‏.‏\hadithno{4163}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that a man came to the Prophet and said:"I have come pledging to emigrate (Hijrah), and I have left my parents weeping." He said: "Go back to them, and make them smile as you made them weep}}
\hadithdefcmd{nasai}{4164}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ، أَنَّ أَعْرَابِيًّا، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْهِجْرَةِ فَقَالَ ‏"‏ وَيْحَكَ إِنَّ شَأْنَ الْهِجْرَةِ شَدِيدٌ فَهَلْ لَكَ مِنْ إِبِلٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَهَلْ تُؤَدِّي صَدَقَتَهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَاعْمَلْ مِنْ وَرَاءِ الْبِحَارِ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ لَنْ يَتِرَكَ مِنْ عَمَلِكَ شَيْئًا ‏"‏ ‏.‏\hadithno{4164}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Sa'eed that:a Bedouin asked the Messenger of Allah about emigration (Hijrah). He said: "Woe to you, emigration is very important. Do you have any camels?" He said: "Yes. He said: "Do you pay Sadaqah on them?" He said: "Yes." He said: "Do righteous deeds no matter how far away you are from the Muslims, for Allah, the Mighty and sublime, will never cause any of your deeds tobe lost}}
\hadithdefcmd{nasai}{4165}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَىُّ الْهِجْرَةِ أَفْضَلُ قَالَ ‏"‏ أَنْ تَهْجُرَ مَا كَرِهَ رَبُّكَ عَزَّ وَجَلَّ ‏"‏ ‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْهِجْرَةُ هِجْرَتَانِ هِجْرَةُ الْحَاضِرِ وَهِجْرَةُ الْبَادِي فَأَمَّا الْبَادِي فَيُجِيبُ إِذَا دُعِيَ وَيُطِيعُ إِذَا أُمِرَ وَأَمَّا الْحَاضِرُ فَهُوَ أَعْظَمُهُمَا بَلِيَّةً وَأَعْظَمُهُمَا أَجْرًا ‏"‏ ‏.‏\hadithno{4165}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"A man said: 'O Messenger of Allah! Which emigration (Hijrah) is best?' He said: 'To leave what your Lord, the Mighty and Sublime, dislikes.' He said: 'There are two kinds of emigration, the emigration of the town dweller and the emigration of the Bedouin. As for the Bedouin, when he is called (to fight in Jihad) he must respond, and he must obey when he is commanded, and as for the town dweller, he is the one who is more severely tested and more greatly rewarded}}
\hadithdefcmd{nasai}{4166}{أَخْبَرَنَا الْحُسَيْنُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا مُبَشِّرُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ حُسَيْنٍ، عَنْ يَعْلَى بْنِ مُسْلِمٍ، عَنْ جَابِرِ بْنِ زَيْدٍ، قَالَ قَالَ ابْنُ عَبَّاسٍ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ كَانُوا مِنَ الْمُهَاجِرِينَ لأَنَّهُمْ هَجَرُوا الْمُشْرِكِينَ وَكَانَ مِنَ الأَنْصَارِ مُهَاجِرُونَ لأَنَّ الْمَدِينَةَ كَانَتْ دَارَ شِرْكٍ فَجَاءُوا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَيْلَةَ الْعَقَبَةِ ‏.‏\hadithno{4166}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Jabir bin Zaid said:"Ibn 'Abbas said: 'The Messenger of Allah (ﷺ), Abu Bakr and 'Umar were among the Muhajirin (emigrants), because they forsook (hajaru) the idolators, and some of the Ansar were Muhajirun because Al-Madinah was a land of shirk, and they came to the Messenger of Allah (ﷺ) on the Night of Al-'Aqabah}}
\hadithdefcmd{nasai}{4167}{أَخْبَرَنِي هَارُونُ بْنُ مُحَمَّدِ بْنِ بَكَّارِ بْنِ بِلاَلٍ، عَنْ مُحَمَّدٍ، - وَهُوَ ابْنُ عِيسَى بْنِ سُمَيْعٍ - قَالَ حَدَّثَنَا زَيْدُ بْنُ وَاقِدٍ، عَنْ كَثِيرِ بْنِ مُرَّةَ، أَنَّ أَبَا فَاطِمَةَ، حَدَّثَهُ أَنَّهُ، قَالَ يَا رَسُولَ اللَّهِ حَدِّثْنِي بِعَمَلٍ، أَسْتَقِيمُ عَلَيْهِ وَأَعْمَلُهُ ‏.‏ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلَيْكَ بِالْهِجْرَةِ فَإِنَّهُ لاَ مِثْلَ لَهَا ‏"‏ ‏.‏\hadithno{4167}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Kathir bin Murrah that Abu Fatimah told him that he said:"O Messenger of Allah, tell me of an action that I may do and persist in it." The Messenger of Allah said to him: "You should emigrate, for there is nothing like it}}
\hadithdefcmd{nasai}{4168}{أَخْبَرَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عَمْرِو بْنِ عَبْدِ الرَّحْمَنِ بْنِ أُمَيَّةَ، أَنَّ أَبَاهُ، أَخْبَرَهُ أَنَّ يَعْلَى قَالَ جِئْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِأَبِي يَوْمَ الْفَتْحِ فَقُلْتُ يَا رَسُولَ اللَّهِ بَايِعْ أَبِي عَلَى الْهِجْرَةِ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُبَايِعُهُ عَلَى الْجِهَادِ وَقَدِ انْقَطَعَتِ الْهِجْرَةُ ‏"‏ ‏.‏\hadithno{4168}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Amr bin 'Abdur-Rahman bin Umayyah that his father told him that Ya'la said:"I came to the Messenger of Allah with my father on the day of the Conquest (of Makkah) and said: 'O Messenger of Allah, accept my father's pledge to emigrate.' The Messenger of Allah said: 'I will accept his pledge for Jihad, for the emigration (Hijrah) has ceased}}
\hadithdefcmd{nasai}{4169}{أَخْبَرَنِي مُحَمَّدُ بْنُ دَاوُدَ، قَالَ حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، قَالَ حَدَّثَنَا وُهَيْبُ بْنُ خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ صَفْوَانَ بْنِ أُمَيَّةَ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّهُمْ يَقُولُونَ إِنَّ الْجَنَّةَ لاَ يَدْخُلُهَا إِلاَّ مُهَاجِرٌ ‏.‏ قَالَ ‏ "‏ لاَ هِجْرَةَ بَعْدَ فَتْحِ مَكَّةَ وَلَكِنْ جِهَادٌ وَنِيَّةٌ فَإِذَا اسْتُنْفِرْتُمْ فَانْفِرُوا ‏"‏ ‏.‏\hadithno{4169}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Safwan bin Umayyah said:"I said: 'O Messenger of Allah, they are saying that no one will enter Paradise except a Muhajir."' He said: "There is no more emigration (Hijrah) after the Conquest of Makkah, rather there is Jihad and intention. When you are called to moblize (for Jihad) then do so}}
\hadithdefcmd{nasai}{4170}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي مَنْصُورٌ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الْفَتْحِ ‏ "‏ لاَ هِجْرَةَ وَلَكِنْ جِهَادٌ وَنِيَّةٌ فَإِذَا اسْتُنْفِرْتُمْ فَانْفِرُوا ‏"‏ ‏.‏\hadithno{4170}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah said on the Day of the Conquest (of Makkah): "There is no more emigration (Hijrah), rather there is Jihad and intention. When you are called to moblize (for Jihad) then do so}}
\hadithdefcmd{nasai}{4171}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ يَحْيَى بْنِ هَانِئٍ، عَنْ نُعَيْمِ بْنِ دِجَاجَةَ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ لاَ هِجْرَةَ بَعْدَ وَفَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4171}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Nu'aim bin Dijajah said:"I heard 'Umar bin Al-Khattab say: 'There is no more emigration (Hijrah) after the death of the Messenger of Allah}}
\hadithdefcmd{nasai}{4172}{أَخْبَرَنَا عِيسَى بْنُ مُسَاوِرٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، عَنْ عَبْدِ اللَّهِ بْنِ الْعَلاَءِ بْنِ زَبْرٍ، عَنْ بُسْرِ بْنِ عُبَيْدِ اللَّهِ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ وَاقِدٍ السَّعْدِيِّ، قَالَ وَفَدْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي وَفْدٍ كُلُّنَا يَطْلُبُ حَاجَةً وَكُنْتُ آخِرَهُمْ دُخُولاً عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي تَرَكْتُ مَنْ خَلْفِي وَهُمْ يَزْعُمُونَ أَنَّ الْهِجْرَةَ قَدِ انْقَطَعَتْ ‏.‏ قَالَ ‏ "‏ لاَ تَنْقَطِعُ الْهِجْرَةُ مَا قُوتِلَ الْكُفَّارُ ‏"‏ ‏.‏\hadithno{4172}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin Waqdan As-Sa'di said:"We came in a delegation to the messenger of Allah, each of us with a question to ask him. I was the last of them to come in to the Messenger of Allah, and I said: 'O Messenger of Allah, I have left people behind me, and they are saying that emigration (Hijrah) has ceased.' He said: 'Emigration will not cease so long as the disbelievers are being fought}}
\hadithdefcmd{nasai}{4173}{أَخْبَرَنَا مَحْمُودُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْعَلاَءِ بْنِ زَبْرٍ، قَالَ حَدَّثَنِي بُسْرُ بْنُ عُبَيْدِ اللَّهِ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ حَسَّانَ بْنِ عَبْدِ اللَّهِ الضَّمْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ السَّعْدِيِّ، قَالَ وَفَدْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَدَخَلَ أَصْحَابِي فَقَضَى حَاجَتَهُمْ وَكُنْتُ آخِرَهُمْ دُخُولاً فَقَالَ ‏"‏ حَاجَتُكَ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ مَتَى تَنْقَطِعُ الْهِجْرَةُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَنْقَطِعُ الْهِجْرَةُ مَا قُوتِلَ الْكُفَّارُ ‏"‏ ‏.‏\hadithno{4173}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah bin As-Sa'di said:"We came in a delegation to the Messenger of Allah and my companions entered and asked their questions. I was the last of them to enter, and he said: 'What is you question?' I said: 'O Messenger of Allah, when will emigration end?' The Messenger of Allah said: 'Emigration will not cease so long as the disbelievers are being fought}}
\hadithdefcmd{nasai}{4174}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، عَنْ جَرِيرٍ، عَنْ مُغِيرَةَ، عَنْ أَبِي وَائِلٍ، وَالشَّعْبِيِّ، قَالاَ قَالَ جَرِيرٌ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ لَهُ أُبَايِعُكَ عَلَى السَّمْعِ وَالطَّاعَةِ فِيمَا أَحْبَبْتُ وَفِيمَا كَرِهْتُ ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَوَتَسْتَطِيعُ ذَلِكَ يَا جَرِيرُ أَوَتُطِيقُ ذَلِكَ ‏"‏ ‏.‏ قَالَ ‏"‏ قُلْ فِيمَا اسْتَطَعْتُ ‏"‏ ‏.‏ فَبَايَعَنِي وَالنُّصْحِ لِكُلِّ مُسْلِمٍ ‏.‏\hadithno{4174}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Jarir said:"I came to the Prophet and said to him: 'I pledge to you to hear and obey in what I like and what I dislike.' The Prophet said: 'Can you do that, O Jarir,' or, 'Are you able for that?' He said: Say: As much as I can.' So he accepted my pledge (for that), and that I be sincere toward every Muslim}}
\hadithdefcmd{nasai}{4175}{أَخْبَرَنَا بِشْرُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي وَائِلٍ، عَنْ جَرِيرٍ، قَالَ بَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى إِقَامِ الصَّلاَةِ وَإِيتَاءِ الزَّكَاةِ وَالنُّصْحِ لِكُلِّ مُسْلِمٍ وَعَلَى فِرَاقِ الْمُشْرِكِ ‏.‏\hadithno{4175}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jarir said:I pledged to the Messenger of Allah (ﷺ) to perform Salah, pay the Zakah, be sincere toward every Muslim and forsake the idolaters}}
\hadithdefcmd{nasai}{4176}{أَخْبَرَنِي مُحَمَّدُ بْنُ يَحْيَى بْنِ مُحَمَّدٍ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ الرَّبِيعِ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي نُخَيْلَةَ، عَنْ جَرِيرٍ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{4176}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jarir said:"I came to the Messenger of Allah" and he mentioned something similar}}
\hadithdefcmd{nasai}{4177}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي نُخَيْلَةَ الْبَجَلِيِّ، قَالَ قَالَ جَرِيرٌ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَهُوَ يُبَايِعُ فَقُلْتُ يَا رَسُولَ اللَّهِ ابْسُطْ يَدَكَ حَتَّى أُبَايِعَكَ وَاشْتَرِطْ عَلَىَّ فَأَنْتَ أَعْلَمُ ‏.‏ قَالَ ‏ "‏ أُبَايِعُكَ عَلَى أَنْ تَعْبُدَ اللَّهَ وَتُقِيمَ الصَّلاَةَ وَتُؤْتِيَ الزَّكَاةَ وَتُنَاصِحَ الْمُسْلِمِينَ وَتُفَارِقَ الْمُشْرِكِينَ ‏"‏ ‏.‏\hadithno{4177}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Jarir said:"I came to the Prophet when he was accepting (the people's) pledge, and said: 'O Messenger of Allah, extend you hand so that I may give you my pledge, and state your terms, for you know best.' He said: 'I accept you pledge that you will worship Allah, establish Salah, pay the Zakah, be sincere toward the Muslims, and forsake the idolaters}}
\hadithdefcmd{nasai}{4178}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا غُنْدَرٌ، قَالَ أَنْبَأَنَا مَعْمَرٌ، قَالَ أَنْبَأَنَا ابْنُ شِهَابٍ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، قَالَ سَمِعْتُ عُبَادَةَ بْنَ الصَّامِتِ، قَالَ بَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي رَهْطٍ فَقَالَ ‏ "‏ أُبَايِعُكُمْ عَلَى أَنْ لاَ تُشْرِكُوا بِاللَّهِ شَيْئًا وَلاَ تَسْرِقُوا وَلاَ تَزْنُوا وَلاَ تَقْتُلُوا أَوْلاَدَكُمْ وَلاَ تَأْتُوا بِبُهْتَانٍ تَفْتَرُونَهُ بَيْنَ أَيْدِيكُمْ وَأَرْجُلِكُمْ وَلاَ تَعْصُونِي فِي مَعْرُوفٍ فَمَنْ وَفَّى مِنْكُمْ فَأَجْرُهُ عَلَى اللَّهِ وَمَنْ أَصَابَ مِنْ ذَلِكَ شَيْئًا فَعُوقِبَ فِيهِ فَهُوَ طَهُورُهُ وَمَنْ سَتَرَهُ اللَّهُ فَذَاكَ إِلَى اللَّهِ إِنْ شَاءَ عَذَّبَهُ وَإِنْ شَاءَ غَفَرَ لَهُ ‏"‏ ‏.‏\hadithno{4178}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Idris Al-Khawlani said:"I heard 'Ubadah bin As-Samit say: 'I pledged to the Messenger of Allah among a group of people, and he said: I accept your pledge that you will not associate anything with Allah, you will not steal, you will not have unlawful sexual relations, you will not kill you children, you will not utter slander, fabricating from between your hands and feet, and you will not disobey me when commanded with goodness. Whoever fulfills (this pledge), his reward will be with Allah, and whoever commits any of these actions and is punished for it, it will be purification for him. Whoever (commits any of these action then) Allah conceals him, it is up to Allah; if He wills He will forgive him, and if He wills, He will punish him}}
\hadithdefcmd{nasai}{4179}{أَخْبَرَنِي مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ لَمَّا أَرَدْتُ أَنْ أُبَايِعَ، رَسُولَ اللَّهِ صلى الله عليه وسلم قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ امْرَأَةً أَسْعَدَتْنِي فِي الْجَاهِلِيَّةِ فَأَذْهَبُ فَأُسْعِدُهَا ثُمَّ أَجِيئُكَ فَأُبَايِعُكَ ‏.‏ قَالَ ‏ "‏ اذْهَبِي فَأَسْعِدِيهَا ‏"‏ ‏.‏ قَالَتْ فَذَهَبْتُ فَسَاعَدْتُهَا ثُمَّ جِئْتُ فَبَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4179}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Umm 'Atiyyah said:"When I wanted to give pledge to the Messenger of Allah, I said: 'O Messenger of Allah, women helped me (in wailing for the dead) during the Jahiliyyah; shall I go and help her (in wailing) and then come to you and give you my oath of allegiance?' He said: 'Go and help her.' So I went and helped her, then I came, and gave my pledge to the Messenger of Allah}}
\hadithdefcmd{nasai}{4180}{أَخْبَرَنَا الْحَسَنُ بْنُ أَحْمَدَ، قَالَ حَدَّثَنَا أَبُو الرَّبِيعِ، قَالَ أَنْبَأَنَا حَمَّادٌ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ أَخَذَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم الْبَيْعَةَ عَلَى أَنْ لاَ نَنُوحَ ‏.‏\hadithno{4180}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Umm 'Atiyyah said:"The Messenger of Allah accepted our pledge that we would not wail (for the dead)}}
\hadithdefcmd{nasai}{4181}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ أُمَيْمَةَ بِنْتِ رُقَيْقَةَ، أَنَّهَا قَالَتْ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فِي نِسْوَةٍ مِنَ الأَنْصَارِ نُبَايِعُهُ فَقُلْنَا يَا رَسُولَ اللَّهِ نُبَايِعُكَ عَلَى أَنْ لاَ نُشْرِكَ بِاللَّهِ شَيْئًا وَلاَ نَسْرِقَ وَلاَ نَزْنِيَ وَلاَ نَأْتِيَ بِبُهْتَانٍ نَفْتَرِيهِ بَيْنَ أَيْدِينَا وَأَرْجُلِنَا وَلاَ نَعْصِيَكَ فِي مَعْرُوفٍ ‏.‏ قَالَ ‏"‏ فِيمَا اسْتَطَعْتُنَّ وَأَطَقْتُنَّ ‏"‏ ‏.‏ قَالَتْ قُلْنَا اللَّهُ وَرَسُولُهُ أَرْحَمُ بِنَا هَلُمَّ نُبَايِعْكَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي لاَ أُصَافِحُ النِّسَاءَ إِنَّمَا قَوْلِي لِمِائَةِ امْرَأَةٍ كَقَوْلِي لاِمْرَأَةٍ وَاحِدَةٍ أَوْ مِثْلِ قَوْلِي لاِمْرَأَةٍ وَاحِدَةٍ ‏"‏ ‏.‏\hadithno{4181}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Umaimah bint Ruqaiqah said:"I came to the Prophet with some other Ansari women to give our pledge. We said: 'O Messenger of Allah, we give you our pledge that we will not associate anything with Allah, we will not steal, we will not have unlawful sexual relations, we will not utter slander, fabricating from between our hands and feet, and we will not disobey you in goodness.' He said: 'As much as you can and are able.' We said: 'Allah and His Messenger are more merciful toward us. Com, let us give you our pledge, O Messenger of Allah! The Messenger of Allah said: 'I do not shake hands with women. Rather my word to a hundred women is like my word to one woman}}
\hadithdefcmd{nasai}{4182}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ رَجُلٍ، مِنْ آلِ الشَّرِيدِ يُقَالُ لَهُ عَمْرٌو عَنْ أَبِيهِ قَالَ كَانَ فِي وَفْدِ ثَقِيفٍ رَجُلٌ مَجْذُومٌ فَأَرْسَلَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ ارْجِعْ فَقَدْ بَايَعْتُكَ ‏"‏ ‏.‏\hadithno{4182}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrted from a man from Al Ash-Sharid, who was called 'Amr, that his father said:"Among the delegation of Thaqif there was a man who suffered from leprosy. The Prophet sent word to him saying: 'Go back, for I have accepted your pledge}}
\hadithdefcmd{nasai}{4183}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنِ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالَ حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، عَنِ الْهِرْمَاسِ بْنِ زِيَادٍ، قَالَ مَدَدْتُ يَدِي إِلَى النَّبِيِّ صلى الله عليه وسلم وَأَنَا غُلاَمٌ لِيُبَايِعَنِي فَلَمْ يُبَايِعْنِي ‏.‏\hadithno{4183}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Al-Hirmas bin Ziyad said:"I stretched forth my hand to the Prophet for him to accept my pledge, when I was a child, but he did not accept my pledge}}
\hadithdefcmd{nasai}{4184}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ جَاءَ عَبْدٌ فَبَايَعَ النَّبِيَّ صلى الله عليه وسلم عَلَى الْهِجْرَةِ وَلاَ يَشْعُرُ النَّبِيُّ صلى الله عليه وسلم أَنَّهُ عَبْدٌ فَجَاءَ سَيِّدُهُ يُرِيدُهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ بِعْنِيهِ ‏"‏ ‏.‏ فَاشْتَرَاهُ بِعَبْدَيْنِ أَسْوَدَيْنِ ثُمَّ لَمْ يُبَايِعْ أَحَدًا حَتَّى يَسْأَلَهُ أَعَبْدٌ هُوَ\hadithno{4184}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that jabir said:"A slave came and pledged to the Prophet to emigrate, and the Prophet did not realize that he was a slave. Then his master came looking for him. The Prophet said: 'Sell him to me,' and he bought him for two black slaves. Then he did not accept the pledge from anyone until he asked: 'Is he a slave?}}
\hadithdefcmd{nasai}{4185}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ أَعْرَابِيًّا، بَايَعَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الإِسْلاَمِ فَأَصَابَ الأَعْرَابِيَّ وَعَكٌ بِالْمَدِينَةِ فَجَاءَ الأَعْرَابِيُّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَقِلْنِي بَيْعَتِي ‏.‏ فَأَبَى ثُمَّ جَاءَهُ فَقَالَ أَقِلْنِي بَيْعَتِي ‏.‏ فَأَبَى فَخَرَجَ الأَعْرَابِيُّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الْمَدِينَةُ كَالْكِيرِ تَنْفِي خَبَثَهَا وَتَنْصَعُ طَيِّبَهَا ‏"‏ ‏.‏\hadithno{4185}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Jabir bin 'Abdullah that:a Bedouin pledged Islam to the Messenger of Allah, then the Bedouin was stricken with the fever in Al-Madinah. So he came to the Messenger of Allah and said: "O Messenger of Allah, cancel my pledge," but he refused. Then he came to him again and said: "Cancel my pledge," but he refused. Then he came to him again and said: "Cancel my pledge," but he refused. Then the Bedouin left (Al-Madinah) and the Messenger of Allah sadi: "Al-Madinah his like the bellows; it expels its dross and brightness its good}}
\hadithdefcmd{nasai}{4186}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، أَنَّهُ دَخَلَ عَلَى الْحَجَّاجِ فَقَالَ يَا ابْنَ الأَكْوَعِ ارْتَدَدْتَ عَلَى عَقِبَيْكَ وَذَكَرَ كَلِمَةً مَعْنَاهَا وَبَدَوْتَ ‏.‏ قَالَ لاَ وَلَكِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَذِنَ لِي فِي الْبُدُوِّ ‏.‏\hadithno{4186}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salamah bin Al-Akwa ' that he entered upon Al-Hajjaj who said:O son of Al-Akwa, you have turned on your heels (i.e., deserted Islam) by staying in the desert with the Bedouins." He said: "No; the Messenger of Allah gave me permission to stay in the desert with the Bedouins}}
\hadithdefcmd{nasai}{4187}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، ح وَأَخْبَرَنِي عَلِيُّ بْنُ حُجْرٍ، عَنْ إِسْمَاعِيلَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنَّا نُبَايِعُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ ثُمَّ يَقُولُ ‏"‏ فِيمَا اسْتَطَعْتَ ‏"‏ ‏.‏ وَقَالَ عَلِيٌّ ‏"‏ فِيمَا اسْتَطَعْتُمْ ‏"‏ ‏.‏\hadithno{4187}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Umar said:"We used to pledge to the Messenger of Allah to hear and obey, the he said: 'In as much as you can}}
\hadithdefcmd{nasai}{4188}{أَخْبَرَنَا الْحَسَنُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي مُوسَى بْنُ عُقْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنَّا حِينَ نُبَايِعُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ يَقُولُ لَنَا ‏ "‏ فِيمَا اسْتَطَعْتُمْ ‏"‏ ‏.‏\hadithno{4188}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn 'Umar said:"When we gave our pledge to the Messenger of Allah to hear and obey, he would say to us: 'In as much as you can}}
\hadithdefcmd{nasai}{4189}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ حَدَّثَنَا سَيَّارٌ، عَنِ الشَّعْبِيِّ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ بَايَعْتُ النَّبِيَّ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ فَلَقَّنَنِي ‏ "‏ فِيمَا اسْتَطَعْتَ وَالنُّصْحِ لِكُلِّ مُسْلِمٍ ‏"‏ ‏.‏\hadithno{4189}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jarir bin 'Abdullah said:"I gave my pledge to the Prophet to hear and obey, and he told me to add the words.' In as much as you can, and to be since toward every Muslim"'. (Sahih)}}
\hadithdefcmd{nasai}{4190}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ أُمَيْمَةَ بِنْتِ رُقَيْقَةَ، قَالَتْ بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فِي نِسْوَةٍ فَقَالَ لَنَا ‏ "‏ فِيمَا اسْتَطَعْتُنَّ وَأَطَقْتُنَّ ‏"‏ ‏.‏\hadithno{4190}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Umaimah bin Ruqaiqah said:"We gave pledge to the Messenger of Allah among a group of women, and he said to us: 'In as much as you can and are able}}
\hadithdefcmd{nasai}{4191}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ رَبِّ الْكَعْبَةِ، قَالَ انْتَهَيْتُ إِلَى عَبْدِ اللَّهِ بْنِ عَمْرٍو وَهُوَ جَالِسٌ فِي ظِلِّ الْكَعْبَةِ وَالنَّاسُ عَلَيْهِ مُجْتَمِعُونَ قَالَ فَسَمِعْتُهُ يَقُولُ بَيْنَا نَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ إِذْ نَزَلْنَا مَنْزِلاً فَمِنَّا مَنْ يَضْرِبُ خِبَاءَهُ وَمِنَّا مَنْ يَنْتَضِلُ وَمِنَّا مَنْ هُوَ فِي جَشْرَتِهِ إِذْ نَادَى مُنَادِي النَّبِيِّ صلى الله عليه وسلم الصَّلاَةَ جَامِعَةً فَاجْتَمَعْنَا فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَخَطَبَنَا فَقَالَ ‏ "‏ إِنَّهُ لَمْ يَكُنْ نَبِيٌّ قَبْلِي إِلاَّ كَانَ حَقًّا عَلَيْهِ أَنْ يَدُلَّ أُمَّتَهُ عَلَى مَا يَعْلَمُهُ خَيْرًا لَهُمْ وَيُنْذِرَهُمْ مَا يَعْلَمُهُ شَرًّا لَهُمْ وَإِنَّ أُمَّتَكُمْ هَذِهِ جُعِلَتْ عَافِيَتُهَا فِي أَوَّلِهَا وَإِنَّ آخِرَهَا سَيُصِيبُهُمْ بَلاَءٌ وَأُمُورٌ يُنْكِرُونَهَا تَجِيءُ فِتَنٌ فَيُدَقِّقُ بَعْضُهَا لِبَعْضٍ فَتَجِيءُ الْفِتْنَةُ فَيَقُولُ الْمُؤْمِنُ هَذِهِ مُهْلِكَتِي ثُمَّ تَنْكَشِفُ ثُمَّ تَجِيءُ فَيَقُولُ هَذِهِ مُهْلِكَتِي ثُمَّ تَنْكَشِفُ فَمَنْ أَحَبَّ مِنْكُمْ أَنْ يُزَحْزَحَ عَنِ النَّارِ وَيُدْخَلَ الْجَنَّةَ فَلْتُدْرِكْهُ مَوْتَتُهُ وَهُوَ مُؤْمِنٌ بِاللَّهِ وَالْيَوْمِ الآخِرِ وَلْيَأْتِ إِلَى النَّاسِ مَا يُحِبُّ أَنْ يُؤْتَى إِلَيْهِ وَمَنْ بَايَعَ إِمَامًا فَأَعْطَاهُ صَفْقَةَ يَدِهِ وَثَمَرَةَ قَلْبِهِ فَلْيُطِعْهُ مَا اسْتَطَاعَ فَإِنْ جَاءَ أَحَدٌ يُنَازِعُهُ فَاضْرِبُوا رَقَبَةَ الآخَرِ ‏"‏ ‏.‏ فَدَنَوْتُ مِنْهُ فَقُلْتُ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ هَذَا قَالَ نَعَمْ ‏.‏ وَذَكَرَ الْحَدِيثَ ‏.‏\hadithno{4191}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdur-Rahman bin 'Abd Rabb Al-Kabah said:" I came to 'Abdullah bin Amr bin Al-As while he was sitting in the shade of Kabah, and the people were gathered around him, and I heard him say: 'While we were with the Messenger of Allah on a journey, we stopped to camp, and some of us were pitching tents, some were competing in shooting arrows, and some were taking the animals out to race them. Then the caller of the Prophet called out: As-Salatu Jamiah (prayer is about to begin). So we gathered, and the Messenger of Allah stood up and addressed us. He said: There has a never been a prophet before me who was not obliged to tell his nation of what he knew was good for them, and to warn against that he knew was bad for them. With regard to Ummah of yours, soundness (of religious commitment) has been placed in its earlier generations, and the last of them will be afflicted with calamities and things that you dislike. Then there will come tribulations which will make the earlier ones pale into significances, and the believer will say: This will be then end of me, then relief will come. Then (more) tribulations will come and the believer will say: this will be the end of me, then relief will come. Whoever would like to be taken far away from the Fire and admitted to Paradise, let him die believing in Allah and the Last Day, and let him treat people as he would like to be treated. Whoever pledges to a ruler and gives him the grasp of his hand and the sincerity of his heart, the let him obey him as much as he can, and if another comes and challenges him, let them strike the neck of (i.e., kill) the second one."' He said: " I drew near to him and said: 'Did you hear the Messenger of Allah say that? He 'Yes, and quoted the Hadith without interruption (in the chain)}}
\hadithdefcmd{nasai}{4192}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ يَحْيَى بْنِ حُصَيْنٍ، قَالَ سَمِعْتُ جَدَّتِي، تَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي حَجَّةِ الْوَدَاعِ ‏ "‏ وَلَوِ اسْتُعْمِلَ عَلَيْكُمْ عَبْدٌ حَبَشِيٌّ يَقُودُكُمْ بِكِتَابِ اللَّهِ فَاسْمَعُوا لَهُ وَأَطِيعُوا ‏"‏ ‏.‏\hadithno{4192}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Yahya bin Husain said:"I heard my grandmother say: 'I heard the Messenger of Allah say, during the Farewell Pilgrimage: If an Ethiopian slave is appointed over you who rules according to the Book of Allah, then listen to him and obey}}
\hadithdefcmd{nasai}{4193}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، أَنَّ زِيَادَ بْنَ سَعْدٍ، أَخْبَرَهُ أَنَّ ابْنَ شِهَابٍ أَخْبَرَهُ أَنَّ أَبَا سَلَمَةَ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَطَاعَنِي فَقَدْ أَطَاعَ اللَّهَ وَمَنْ عَصَانِي فَقَدْ عَصَى اللَّهَ وَمَنْ أَطَاعَ أَمِيرِي فَقَدْ أَطَاعَنِي وَمَنْ عَصَى أَمِيرِي فَقَدْ عَصَانِي ‏"‏ ‏.‏\hadithno{4193}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah said:"The Messenger of Allah said: 'Whoever obeys me, obeys Allah, and whoever disobeys me, disobeys Allah. Whoever obeys my governor (Amir), he has obeyed me, and whoever disobeys my governor, he has disobeyed me}}
\hadithdefcmd{nasai}{4194}{أَخْبَرَنَا الْحَسَنُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي يَعْلَى بْنُ مُسْلِمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا أَطِيعُوا اللَّهَ وَأَطِيعُوا الرَّسُولَ ‏\}‏ قَالَ نَزَلَتْ فِي عَبْدِ اللَّهِ بْنِ حُذَافَةَ بْنِ قَيْسِ بْنِ عَدِيٍّ بَعَثَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي سَرِيَّةٍ ‏.‏\hadithno{4194}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas (concerning the Verse):"O you who believe! Obey Allah and obey the Messenger (Muhammad). That he said: This was revealed concerning 'Abdullah bin Hudhaifah bin Qais bin 'Adiyy, whom the Messenger of Allah appointed in charge of an expedition}}
\hadithdefcmd{nasai}{4195}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدٍ، قَالَ حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، قَالَ حَدَّثَنَا بَحِيرٌ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ أَبِي بَحْرِيَّةَ، عَنْ مُعَاذِ بْنِ جَبَلٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْغَزْوُ غَزْوَانِ فَأَمَّا مَنِ ابْتَغَى وَجْهَ اللَّهِ وَأَطَاعَ الإِمَامَ وَأَنْفَقَ الْكَرِيمَةَ وَاجْتَنَبَ الْفَسَادَ فَإِنَّ نَوْمَهُ وَنُبْهَتَهُ أَجْرٌ كُلُّهُ وَأَمَّا مَنْ غَزَا رِيَاءً وَسُمْعَةً وَعَصَى الإِمَامَ وَأَفْسَدَ فِي الأَرْضِ فَإِنَّهُ لاَ يَرْجِعُ بِالْكَفَافِ ‏"‏ ‏.‏\hadithno{4195}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Muadah bin Jabal that the Messenger of Allah said:"Military campaigns are of two types: as for the one who seeks the Face of Allah, obeys the imam, spends what is precious and avoids mischief, whether he is asleep or awake, he is earning reward. But as for the one who fights in order to show off and gain a reputation, and disobeys the imam and spreads mischief in the land, he comes back empty-handed." (Da 'if)}}
\hadithdefcmd{nasai}{4196}{أَخْبَرَنَا عِمْرَانُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، قَالَ حَدَّثَنَا شُعَيْبٌ، قَالَ حَدَّثَنِي أَبُو الزِّنَادِ، مِمَّا حَدَّثَهُ عَبْدُ الرَّحْمَنِ الأَعْرَجُ، مِمَّا ذَكَرَ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا الإِمَامُ جُنَّةٌ يُقَاتَلُ مِنْ وَرَائِهِ وَيُتَّقَى بِهِ فَإِنْ أَمَرَ بِتَقْوَى اللَّهِ وَعَدَلَ فَإِنَّ لَهُ بِذَلِكَ أَجْرًا وَإِنْ أَمَرَ بِغَيْرِهِ فَإِنَّ عَلَيْهِ وِزْرًا ‏"‏ ‏.‏\hadithno{4196}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"The Imam is like a shield whose orders should be obeyed when they (the Muslims) fight, and where they should seek protection. If he enjoins fear of Allah and behaves justly, then he will be rewarded, but if he enjoins otherwise, then it will be a burden (of sin) on him}}
\hadithdefcmd{nasai}{4197}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ سَأَلْتُ سُهَيْلَ بْنَ أَبِي صَالِحٍ قُلْتُ حَدَّثَنَا عَمْرٌو، عَنِ الْقَعْقَاعِ، عَنْ أَبِيكَ، قَالَ أَنَا سَمِعْتُهُ مِنَ الَّذِي، حَدَّثَ أَبِي، حَدَّثَهُ رَجُلٌ، مِنْ أَهْلِ الشَّامِ يُقَالُ لَهُ عَطَاءُ بْنُ يَزِيدَ عَنْ تَمِيمٍ الدَّارِيِّ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا الدِّينُ النَّصِيحَةُ ‏"‏ ‏.‏ قَالُوا لِمَنْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لِلَّهِ وَلِكِتَابِهِ وَلِرَسُولِهِ وَلأَئِمَّةِ الْمُسْلِمِينَ وَعَامَّتِهِمْ ‏"‏ ‏.‏\hadithno{4197}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Tamim Ad-Dari said:"The Messenger of Allah said: 'Religion is sincerity (An-Nasihah).' They said: 'To whom, O Messenger of Allah?' he said: 'To Allah, to His Book, to His Messenger, to the imams of the Muslims, and to their common folk}}
\hadithdefcmd{nasai}{4198}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ تَمِيمٍ الدَّارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا الدِّينُ النَّصِيحَةُ ‏"‏ ‏.‏ قَالُوا لِمَنْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لِلَّهِ وَلِكِتَابِهِ وَلِرَسُولِهِ وَلأَئِمَّةِ الْمُسْلِمِينَ وَعَامَّتِهِمْ ‏"‏ ‏.‏\hadithno{4198}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Tamim Ad-Dari said:"The Messenger of Allah said: 'Religion is sincerity (An-Nasihah).' They said: 'To whom, O Messenger of Allah? He said: 'To Allah, to His Book, to His Messenger, to the imams of the Muslims and to their common folk}}
\hadithdefcmd{nasai}{4199}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ اللَّيْثِ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الدِّينَ النَّصِيحَةُ إِنَّ الدِّينَ النَّصِيحَةُ إِنَّ الدِّينَ النَّصِيحَةُ ‏"‏ ‏.‏ قَالُوا لِمَنْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لِلَّهِ وَلِكِتَابِهِ وَلِرَسُولِهِ وَلأَئِمَّةِ الْمُسْلِمِينَ وَعَامَّتِهِمْ ‏"‏ ‏.‏\hadithno{4199}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Religion is sincerity, religion is sincerity (Al-Nasihah), religion is sincerity." They said; "To whom, O Messenger of Allah?" He said: "To Allah, to His Book, to His Messenger, to the imams of the Muslims and to their common folk}}
\hadithdefcmd{nasai}{4200}{أَخْبَرَنَا عَبْدُ الْقُدُّوسِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الْكَبِيرِ بْنِ شُعَيْبِ بْنِ الْحَبْحَابِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَهْضَمٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنِ ابْنِ عَجْلاَنَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، وَعَنْ سُمَىٍّ، وَعَنْ عُبَيْدِ اللَّهِ بْنِ مِقْسَمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ الدِّينُ النَّصِيحَةُ ‏"‏ ‏.‏ قَالُوا لِمَنْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لِلَّهِ وَلِكِتَابِهِ وَلِرَسُولِهِ وَلأَئِمَّةِ الْمُسْلِمِينَ وَعَامَّتِهِمْ ‏"‏ ‏.‏\hadithno{4200}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Religion is sincerity (An-Nasihah)." The said: "To whom, O Messenger of Allah?" he said: "To Allah, to His Book, to His Messenger, to the imams of the Muslims and to their common folk}}
\hadithdefcmd{nasai}{4201}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مُعَمَّرُ بْنُ يَعْمَرَ، قَالَ حَدَّثَنِي مُعَاوِيَةُ بْنُ سَلاَّمٍ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ وَالٍ إِلاَّ وَلَهُ بِطَانَتَانِ بِطَانَةٌ تَأْمُرُهُ بِالْمَعْرُوفِ وَتَنْهَاهُ عَنِ الْمُنْكَرِ وَبِطَانَةٌ لاَ تَأْلُوهُ خَبَالاً فَمَنْ وُقِيَ شَرَّهَا فَقَدْ وُقِيَ وَهُوَ مِنَ الَّتِي تَغْلِبُ عَلَيْهِ مِنْهُمَا ‏"‏ ‏.‏\hadithno{4201}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Hurairah said " The Messenger of Allah said:'No ruler is appointed but he has tow groups of advisers: A group which urges him to do good and tells him not to do evil, and a group which does its best to corrupt him. Whoever is protected from their evil is indeed protected. And he (the ruler) belongs to the group that has the greater influence over him}}
\hadithdefcmd{nasai}{4202}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَعِيدٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا بَعَثَ اللَّهُ مِنْ نَبِيٍّ وَلاَ اسْتَخْلَفَ مِنْ خَلِيفَةٍ إِلاَّ كَانَتْ لَهُ بِطَانَتَانِ بِطَانَةٌ تَأْمُرُهُ بِالْخَيْرِ وَبِطَانَةٌ تَأْمُرُهُ بِالشَّرِّ وَتَحُضُّهُ عَلَيْهِ وَالْمَعْصُومُ مَنْ عَصَمَ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4202}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Saeed tht the Messenger of Allah said:"Allah never sends a prophet or appoints a Khalifah but he has two groups of advisers: A group that tells him to do good and a group that tells him to do evil and urges him to do it. And the one who is truly protected is the one who is protected by Allah, the Mighty and Sublime}}
\hadithdefcmd{nasai}{4203}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، عَنِ اللَّيْثِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ صَفْوَانَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي أَيُّوبَ، أَنَّهُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا بُعِثَ مِنْ نَبِيٍّ وَلاَ كَانَ بَعْدَهُ مِنْ خَلِيفَةٍ إِلاَّ وَلَهُ بِطَانَتَانِ بِطَانَةٌ تَأْمُرُهُ بِالْمَعْرُوفِ وَتَنْهَاهُ عَنِ الْمُنْكَرِ وَبِطَانَةٌ لاَ تَأْلُوهُ خَبَالاً فَمَنْ وُقِيَ بِطَانَةَ السُّوءِ فَقَدْ وُقِيَ ‏"‏ ‏.‏\hadithno{4203}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Ayyub said; "I heard the Messenger of Allah say:'No prophet has eve been sent, nor has there been any Khalifah after him, but he has two groups of advisers, a group that tells him to do good and a group that tells him to do evil. Whoever is protected from the evil group, then he is indeed protected}}
\hadithdefcmd{nasai}{4204}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، قَالَ حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنِ ابْنِ أَبِي حُسَيْنٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، قَالَ سَمِعْتُ عَمَّتِي، تَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ وَلِيَ مِنْكُمْ عَمَلاً فَأَرَادَ اللَّهُ بِهِ خَيْرًا جَعَلَ لَهُ وَزِيرًا صَالِحًا إِنْ نَسِيَ ذَكَّرَهُ وَإِنْ ذَكَرَ أَعَانَهُ ‏"‏ ‏.‏\hadithno{4204}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Qasim bin Muhammad said:" I heard my paternal aunt say: 'The Messenger of Allah said; "Whoever among you is appointed to a position of authority. If Allah wills good for him. He will give him a righteous minister who will remind him if he forgets and help him if he remembers}}
\hadithdefcmd{nasai}{4205}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ زُبَيْدٍ الإِيَامِيِّ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَلِيٍّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ جَيْشًا وَأَمَّرَ عَلَيْهِمْ رَجُلاً فَأَوْقَدَ نَارًا فَقَالَ ادْخُلُوهَا ‏.‏ فَأَرَادَ نَاسٌ أَنْ يَدْخُلُوهَا وَقَالَ الآخَرُونَ إِنَّمَا فَرَرْنَا مِنْهَا ‏.‏ فَذَكَرُوا ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لِلَّذِينَ أَرَادُوا أَنْ يَدْخُلُوهَا ‏"‏ لَوْ دَخَلْتُمُوهَا لَمْ تَزَالُوا فِيهَا إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏ وَقَالَ لِلآخَرِينَ خَيْرًا ‏.‏ وَقَالَ أَبُو مُوسَى فِي حَدِيثِهِ قَوْلاً حَسَنًا ‏.‏ وَقَالَ ‏"‏ لاَ طَاعَةَ فِي مَعْصِيَةِ اللَّهِ إِنَّمَا الطَّاعَةُ فِي الْمَعْرُوفِ ‏"‏ ‏.‏\hadithno{4205}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu 'Adur-Rahman from Ali that:the Messenger of Allah sent an army and appointed a man in charge of them. He lit a fire and said: "Enter it." Some people wanted to enter it, and other said: "We are trying to keep away from it." They mentioned that to the Messenger of Allah, and he said to those who had wanted to enter if: "If you had entered it you would have stayed there until the Day of Resurrection." And he spoke good words to the others. And he said: "There is no obedience if it involves disobedience toward Allah. Rather obedience is only (required) in that which is good}}
\hadithdefcmd{nasai}{4206}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلَى الْمَرْءِ الْمُسْلِمِ السَّمْعُ وَالطَّاعَةُ فِيمَا أَحَبَّ وَكَرِهَ إِلاَّ أَنْ يُؤْمَرَ بِمَعْصِيَةٍ فَإِذَا أُمِرَ بِمَعْصِيَةٍ فَلاَ سَمْعَ وَلاَ طَاعَةَ ‏"‏ ‏.‏\hadithno{4206}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'The Muslim must hear and obey whether he likes it or not, unless he is commanded to commit an act of disobedience. If he is commanded to commit an act of disobedience, then he is not required to hear and obey}}
\hadithdefcmd{nasai}{4207}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنْ أَبِي حَصِينٍ، عَنِ الشَّعْبِيِّ، عَنْ عَاصِمٍ الْعَدَوِيِّ، عَنْ كَعْبِ بْنِ عُجْرَةَ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ تِسْعَةٌ فَقَالَ ‏ "‏ إِنَّهُ سَتَكُونُ بَعْدِي أُمَرَاءُ مَنْ صَدَّقَهُمْ بِكَذِبِهِمْ وَأَعَانَهُمْ عَلَى ظُلْمِهِمْ فَلَيْسَ مِنِّي وَلَسْتُ مِنْهُ وَلَيْسَ بِوَارِدٍ عَلَىَّ الْحَوْضَ وَمَنْ لَمْ يُصَدِّقْهُمْ بِكَذِبِهِمْ وَلَمْ يُعِنْهُمْ عَلَى ظُلْمِهِمْ فَهُوَ مِنِّي وَأَنَا مِنْهُ وَهُوَ وَارِدٌ عَلَىَّ الْحَوْضَ ‏"‏ ‏.‏\hadithno{4207}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Kab bin Ujrah said:"The Messenger of Allah came out to us, and there were nine of us. He said; 'After me there will be rulers, whoever believes in their lies and helps them in their wrongdoing is not of me, and I am not of him, and he will not come to me at the Cistern. Whoever does not believe their lies and does not help them in their wrongdoing, he is of me, and I am of hi, and he will come to me at the Cistern}}
\hadithdefcmd{nasai}{4208}{أَخْبَرَنَا هَارُونُ بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ عَبْدِ الْوَهَّابِ - قَالَ حَدَّثَنَا مِسْعَرٌ، عَنْ أَبِي حَصِينٍ، عَنِ الشَّعْبِيِّ، عَنْ عَاصِمٍ الْعَدَوِيِّ، عَنْ كَعْبِ بْنِ عُجْرَةَ، قَالَ خَرَجَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ تِسْعَةٌ خَمْسَةٌ وَأَرْبَعَةٌ أَحَدُ الْعَدَدَيْنِ مِنَ الْعَرَبِ وَالآخَرُ مِنَ الْعَجَمِ فَقَالَ ‏ "‏ اسْمَعُوا هَلْ سَمِعْتُمْ أَنَّهُ سَتَكُونُ بَعْدِي أُمَرَاءُ مَنْ دَخَلَ عَلَيْهِمْ فَصَدَّقَهُمْ بِكَذِبِهِمْ وَأَعَانَهُمْ عَلَى ظُلْمِهِمْ فَلَيْسَ مِنِّي وَلَسْتُ مِنْهُ وَلَيْسَ يَرِدُ عَلَىَّ الْحَوْضَ وَمَنْ لَمْ يَدْخُلْ عَلَيْهِمْ وَلَمْ يُصَدِّقْهُمْ بِكَذِبِهِمْ وَلَمْ يُعِنْهُمْ عَلَى ظُلْمِهِمْ فَهُوَ مِنِّي وَأَنَا مِنْهُ وَسَيَرِدُ عَلَىَّ الْحَوْضَ ‏"‏ ‏.‏\hadithno{4208}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Kab bin Ujrah said:"The Messenger of Allah came out to us and we were nine, fie and four, some 'Arabs and some non- 'Arabs. He said: 'Listen. Have you heard that after me there will be rulers, whoever enters upon them and believes their lies and help them in their wrongdoing is not of me, and I am not of him, and he will not come to me at the Cistern? Whoever does not enter upon them or belive their lies or help them in their wrongdoing is of me and I am of him, and he will come to me at the Cistern}}
\hadithdefcmd{nasai}{4209}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، أَنَّ رَجُلاً، سَأَلَ النَّبِيَّ صلى الله عليه وسلم وَقَدْ وَضَعَ رِجْلَهُ فِي الْغَرْزِ أَىُّ الْجِهَادِ أَفْضَلُ قَالَ ‏ "‏ كَلِمَةُ حَقٍّ عِنْدَ سُلْطَانٍ جَائِرٍ ‏"‏ ‏.‏\hadithno{4209}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Tariq bin Shihab that:a man asked the Prophet, when he had put his leg in the stirrup: "Which kind of Jihad is best?'" He said: " a word of truth spoken before an unjust rulers}}
\hadithdefcmd{nasai}{4210}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فِي مَجْلِسٍ فَقَالَ ‏"‏ بَايِعُونِي عَلَى أَنْ لاَ تُشْرِكُوا بِاللَّهِ شَيْئًا وَلاَ تَسْرِقُوا وَلاَ تَزْنُوا ‏"‏ ‏.‏ وَقَرَأَ عَلَيْهِمُ الآيَةَ ‏"‏ فَمَنْ وَفَّى مِنْكُمْ فَأَجْرُهُ عَلَى اللَّهِ وَمَنْ أَصَابَ مِنْ ذَلِكَ شَيْئًا فَسَتَرَ اللَّهُ عَلَيْهِ فَهُوَ إِلَى اللَّهِ عَزَّ وَجَلَّ إِنْ شَاءَ عَذَّبَهُ وَإِنْ شَاءَ غَفَرَ لَهُ ‏"‏ ‏.‏\hadithno{4210}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ubadah bin As-Samit said:"We were with the Prophet in a gathering and he said: 'Pledge to me that you will not associate anything with Allah, you will not steal, and you will not have unlawful sexual relations.' He recited the Verse to them (and said) Whoever does any of these things, and Allah conceals him then it is up to Allah, the mighty and Sublime: If He wills, He will punish him, and if He wills, He will forgive him}}
\hadithdefcmd{nasai}{4211}{أَخْبَرَنِي مُحَمَّدُ بْنُ آدَمَ بْنِ سُلَيْمَانَ، عَنِ ابْنِ الْمُبَارَكِ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّكُمْ سَتَحْرِصُونَ عَلَى الإِمَارَةِ وَإِنَّهَا سَتَكُونُ نَدَامَةً وَحَسْرَةً فَنِعْمَتِ الْمُرْضِعَةُ وَبِئْسَتِ الْفَاطِمَةُ ‏"‏ ‏.‏\hadithno{4211}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{it was narrated from Abu Hurairah that the Prophet said:"You will become keen for positions of authority, but that will become a regret and loss. What a good life they will live, but how hard it will be for them when they die}}
