% Auto-generated chapter 22 for malik
% Hadiths in this chapter: 18

\hadithdefcmd{malik}{1009}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ سَعْدَ بْنَ عُبَادَةَ، اسْتَفْتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ أُمِّي مَاتَتْ وَعَلَيْهَا نَذْرٌ وَلَمْ تَقْضِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْضِهِ عَنْهَا ‏"‏ ‏.‏\hadithno{1009}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Ubaydullah ibn Abdullah ibn Utba ibn Masud from Abdullah ibn Abbas that Sad ibn Ubada questioned the Messenger of Allah, may Allah bless him and grant him peace, and said,"My mother died while she still had a vow which she had not fulfilled." The Messenger of Allah, may Allah bless him and grant him peace, said, "Fulfill it for her}}
\hadithdefcmd{malik}{1010}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمَّتِهِ، أَنَّهَا حَدَّثَتْهُ عَنْ جَدَّتِهِ، أَنَّهَا كَانَتْ جَعَلَتْ عَلَى نَفْسِهَا مَشْيًا إِلَى مَسْجِدِ قُبَاءٍ فَمَاتَتْ وَلَمْ تَقْضِهِ فَأَفْتَى عَبْدُ اللَّهِ بْنُ عَبَّاسٍ ابْنَتَهَا أَنْ تَمْشِيَ عَنْهَا ‏.‏ قَالَ يَحْيَى وَسَمِعْتُ مَالِكًا يَقُولُ لاَ يَمْشِي أَحَدٌ عَنْ أَحَدٍ ‏.‏\hadithno{1010}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr that his paternal aunt related that her grandmother made a vow to walk to the Quba mosque. She died, and did not fulfill it, so Abdullah ibn Abbas asked her daughter to walk for her. Yahya said that he had heard Malik say, "No one walks for anyone else}}
\hadithdefcmd{malik}{1011}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي حَبِيبَةَ، قَالَ قُلْتُ لِرَجُلٍ وَأَنَا حَدِيثُ السِّنِّ، مَا عَلَى الرَّجُلِ أَنْ يَقُولَ عَلَىَّ مَشْىٌ إِلَى بَيْتِ اللَّهِ وَلَمْ يَقُلْ عَلَىَّ نَذْرُ مَشْىٍ ‏.‏ فَقَالَ لِي رَجُلٌ هَلْ لَكَ أَنْ أُعْطِيَكَ هَذَا الْجِرْوَ - لِجِرْوِ قِثَّاءٍ فِي يَدِهِ - وَتَقُولُ عَلَىَّ مَشْىٌ إِلَى بَيْتِ اللَّهِ قَالَ فَقُلْتُ نَعَمْ فَقُلْتُهُ وَأَنَا يَوْمَئِذٍ حَدِيثُ السِّنِّ ثُمَّ مَكَثْتُ حَتَّى عَقَلْتُ فَقِيلَ لِي إِنَّ عَلَيْكَ مَشْيًا فَجِئْتُ سَعِيدَ بْنَ الْمُسَيَّبِ فَسَأَلْتُهُ عَنْ ذَلِكَ فَقَالَ لِي عَلَيْكَ مَشْىٌ ‏.‏ فَمَشَيْتُ ‏.‏ قَالَ مَالِكٌ وَهَذَا الأَمْرُ عِنْدَنَا ‏.‏\hadithno{1011}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that Abdullah ibn Abi Habiba said, "I said to a man, when I was young, 'A man who only says that he must walk to the House of Allah and does not say that he has vowed to walk, does not have to walk.' A man said, 'Shall I give you this small cucumber?' and he had a small cucumber in his hand and you will say, 'I must walk to the house of Allah?' I said, 'Yes' and I said it, for at that time I was still immature. Then, when I came of age, some one said to me that I had to fulfill my vow. I went and asked Said ibn al- Musayyab about it, and he said to me, 'You must walk.' So I walked." Malik said, "That is the custom among us}}
\hadithdefcmd{malik}{1012}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عُرْوَةَ بْنِ أُذَيْنَةَ اللَّيْثِيِّ، أَنَّهُ قَالَ خَرَجْتُ مَعَ جَدَّةٍ لِي عَلَيْهَا مَشْىٌ إِلَى بَيْتِ اللَّهِ حَتَّى إِذَا كُنَّا بِبَعْضِ الطَّرِيقِ عَجَزَتْ فَأَرْسَلَتْ مَوْلًى لَهَا يَسْأَلُ عَبْدَ اللَّهِ بْنَ عُمَرَ فَخَرَجْتُ مَعَهُ فَسَأَلَ عَبْدَ اللَّهِ بْنَ عُمَرَ فَقَالَ لَهُ عَبْدُ اللَّهِ بْنُ عُمَرَ مُرْهَا فَلْتَرْكَبْ ثُمَّ لْتَمْشِي مِنْ حَيْثُ عَجَزَتْ ‏.‏ قَالَ يَحْيَى وَسَمِعْتُ مَالِكًا يَقُولُ وَنَرَى عَلَيْهَا مَعَ ذَلِكَ الْهَدْىَ ‏.‏ وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، وَأَبَا، سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ كَانَا يَقُولاَنِ مِثْلَ قَوْلِ عَبْدِ اللَّهِ بْنِ عُمَرَ ‏\hadithno{1012}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Yahya related to me from Malik that Urwa ibn Udhayna al-Laythi said, "I went out with my grandmother who had vowed to walk to the House of Allah. When we had gone part of the way, she could not go on. I sent one of her mawlas to question Abdullah ibn Umar and I went with him. He asked Abdullah ibn Umar, and Abdullah ibn Umar said to him, 'Take her and let her ride, and when she has the strength let her ride back, and start to walk from the place from which she was unable to go on.'\textasciitilde{} Yahya said that he had heard Malik say, "I think that she must sacrifice an animal." Yahya related to me from Malik that he had heard that Said ibn al-Musayyab and Abu Salama ibn Abd ar- Rahman said the same as Abdullah ibn Umar}}
\hadithdefcmd{malik}{1014}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ كَانَ عَلَىَّ مَشْىٌ فَأَصَابَتْنِي خَاصِرَةٌ فَرَكِبْتُ حَتَّى أَتَيْتُ مَكَّةَ فَسَأَلْتُ عَطَاءَ بْنَ أَبِي رَبَاحٍ وَغَيْرَهُ فَقَالُوا عَلَيْكَ هَدْىٌ ‏.‏ فَلَمَّا قَدِمْتُ الْمَدِينَةَ سَأَلْتُ عُلَمَاءَهَا فَأَمَرُونِي أَنْ أَمْشِيَ مَرَّةً أُخْرَى مِنْ حَيْثُ عَجَزْتُ فَمَشَيْتُ ‏.‏ قَالَ يَحْيَى وَسَمِعْتُ مَالِكًا يَقُولُ فَالأَمْرُ عِنْدَنَا فِيمَنْ يَقُولُ عَلَىَّ مَشْىٌ إِلَى بَيْتِ اللَّهِ أَنَّهُ إِذَا عَجَزَ رَكِبَ ثُمَّ عَادَ فَمَشَى مِنْ حَيْثُ عَجَزَ فَإِنْ كَانَ لاَ يَسْتَطِيعُ الْمَشْىَ فَلْيَمْشِ مَا قَدَرَ عَلَيْهِ ثُمَّ لْيَرْكَبْ وَعَلَيْهِ هَدْىُ بَدَنَةٍ أَوْ بَقَرَةٍ أَوْ شَاةٍ إِنْ لَمْ يَجِدْ إِلاَّ هِيَ ‏.‏ وَسُئِلَ مَالِكٌ عَنِ الرَّجُلِ يَقُولُ لِلرَّجُلِ أَنَا أَحْمِلُكَ إِلَى بَيْتِ اللَّهِ فَقَالَ مَالِكٌ إِنْ نَوَى أَنْ يَحْمِلَهُ عَلَى رَقَبَتِهِ يُرِيدُ بِذَلِكَ الْمَشَقَّةَ وَتَعَبَ نَفْسِهِ فَلَيْسَ ذَلِكَ عَلَيْهِ وَلْيَمْشِ عَلَى رِجْلَيْهِ وَلْيُهْدِ وَإِنْ لَمْ يَكُنْ نَوَى شَيْئًا فَلْيَحْجُجْ وَلْيَرْكَبْ وَلْيَحْجُجْ بِذَلِكَ الرَّجُلِ مَعَهُ وَذَلِكَ أَنَّهُ قَالَ أَنَا أَحْمِلُكَ إِلَى بَيْتِ اللَّهِ فَإِنْ أَبَى أَنْ يَحُجَّ مَعَهُ فَلَيْسَ عَلَيْهِ شَىْءٌ وَقَدْ قَضَى مَا عَلَيْهِ ‏.‏ قَالَ يَحْيَى سُئِلَ مَالِكٌ عَنِ الرَّجُلِ يَحْلِفُ بِنُذُورٍ مُسَمَّاةٍ مَشْيًا إِلَى بَيْتِ اللَّهِ أَنْ لاَ يُكَلِّمَ أَخَاهُ أَوْ أَبَاهُ بِكَذَا وَكَذَا نَذْرًا لِشَىْءٍ لاَ يَقْوَى عَلَيْهِ وَلَوْ تَكَلَّفَ ذَلِكَ كُلَّ عَامٍ لَعُرِفَ أَنَّهُ لاَ يَبْلُغُ عُمْرُهُ مَا جَعَلَ عَلَى نَفْسِهِ مِنْ ذَلِكَ فَقِيلَ لَهُ هَلْ يُجْزِيهِ مِنْ ذَلِكَ نَذْرٌ وَاحِدٌ أَوْ نُذُورٌ مُسَمَّاةٌ فَقَالَ مَالِكٌ مَا أَعْلَمُهُ يُجْزِئُهُ مِنْ ذَلِكَ إِلاَّ الْوَفَاءُ بِمَا جَعَلَ عَلَى نَفْسِهِ فَلْيَمْشِ مَا قَدَرَ عَلَيْهِ مِنَ الزَّمَانِ وَلْيَتَقَرَّبْ إِلَى اللَّهِ تَعَالَى بِمَا اسْتَطَاعَ مِنَ الْخَيْرِ ‏.‏\hadithno{1014}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said, "I vowed to walk, but I was struck by a pain in the kidney, so I rode until I came to Makka. I questioned Ata ibn Abi Rabah and others, and they said, 'You must sacrifice an animal.' When I came to Madina I questioned the ulama there, and they ordered me to walk again from the place from which I was unable to go on. So I walked." Yahya said that he had heard Malik say, "What is done among us regarding someone who makes a vow to walk to the House of Allah, and then cannot do it and so rides, is that he must return and walk from the place from which he was unable to go on. If he cannot walk, he should walk what he can and then ride, and he must sacrifice a camel, a cow, or a sheep if that is all that he can find." Malik, when asked about a man who said to another, "I will carry you to the House of Allah", answered, "If he intended to carry him on his shoulder, by that he meant hardship and exhaustion to himself, and he does not have to do that. Let him walk by foot and make sacrifice. If he did not intend anything, let him do hajj and ride, and take the man on hajj with him. That is because he said, 'I will carry you to the house of Allah.' If the man refuses to do hajj with him, then there is nothing against him, and what is demanded of him is cancelled." Yahya said that Malik was asked whether it was enough for a man who had made a vow that he would walk to the House of Allah a certain (large) number of times, or who had forbidden himself from talking to his father and brother, if he did not fulfil a certain vow, and he had taken upon himself, by the oath, something which he was incapable of fulfilling in his lifetime, even though he were to try every year, to fulfil only one or a (smaller) number of vows by Allah? Malik said, "The only satisfaction for that that I know is fulfilling what he has obliged himself to do. Let him walk for as long as he is able and draw near Allah the Exalted by what he can of good}}
\hadithdefcmd{malik}{1015}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ حُمَيْدِ بْنِ قَيْسٍ، وَثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، أَنَّهُمَا أَخْبَرَاهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَحَدُهُمَا يَزِيدُ فِي الْحَدِيثِ عَلَى صَاحِبِهِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً قَائِمًا فِي الشَّمْسِ فَقَالَ ‏"‏ مَا بَالُ هَذَا ‏"‏ ‏.‏ فَقَالُوا نَذَرَ أَنْ لاَ يَتَكَلَّمَ وَلاَ يَسْتَظِلَّ مِنَ الشَّمْسِ وَلاَ يَجْلِسَ وَيَصُومَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مُرُوهُ فَلْيَتَكَلَّمْ وَلْيَسْتَظِلَّ وَلْيَجْلِسْ وَلْيُتِمَّ صِيَامَهُ ‏"‏ ‏.‏ قَالَ مَالِكٌ وَلَمْ أَسْمَعْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَهُ بِكَفَّارَةٍ وَقَدْ أَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُتِمَّ مَا كَانَ لِلَّهِ طَاعَةً وَيَتْرُكَ مَا كَانَ لِلَّهِ مَعْصِيَةً ‏.‏\hadithno{1015}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that what he preferred of what he had heard from the people of knowledge about a man or woman who vowed to walk to the House of Allah, was that they fulfilled the oath when performing umra, by walking until they had done say between Safa and Marwa. When they had done say it was finished. If they vowed to walk in the hajj, they walked until they came to Makka, then they walked until they had finished all the rites. Malik said, "Walking is only for hajj or umra." Yahya related to me from Malik that Humayd ibn Qays and Thawr ibn Zayd adDili both informed him that the Messenger of Allah, may Allah bless him and grant him peace, (and one of them gave more detail than the other),saw a man standing in the sun. The Messenger asked, "What's wrong with him?" The people said, "He has vowed not to speak or to seek shade from the sun or to sit and to fast." The Messenger of Allah, may Allah bless him and grant him peace, said, "Go and tell him to speak, seek shade, and sit, but let him complete his fast." Malik said, "I have not heard that the Messenger of Allah, may Allah bless him and grant him peace, ordered the man in question to do any kaffara. The Messenger of Allah, may Allah bless him and grant him peace, only ordered him to complete that in which there was obedience to Allah and to abandon that in which there was disobedience to Allah}}
\hadithdefcmd{malik}{1016}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، أَنَّهُ سَمِعَهُ يَقُولُ أَتَتِ امْرَأَةٌ إِلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ فَقَالَتْ إِنِّي نَذَرْتُ أَنْ أَنْحَرَ ابْنِي ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ لاَ تَنْحَرِي ابْنَكِ وَكَفِّرِي عَنْ يَمِينِكِ، ‏.‏ فَقَالَ شَيْخٌ عِنْدَ ابْنِ عَبَّاسٍ وَكَيْفَ يَكُونُ فِي هَذَا كَفَّارَةٌ فَقَالَ ابْنُ عَبَّاسٍ إِنَّ اللَّهَ تَعَالَى قَالَ وَ ‏\{‏الَّذِينَ يُظَاهِرُونَ مِنْكُمْ مِنْ نِسَائِهِمْ‏\}‏ ثُمَّ جَعَلَ فِيهِ مِنَ الْكَفَّارَةِ مَا قَدْ رَأَيْتَ ‏.‏\hadithno{1016}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said heard al-Qasim ibn Muhammad say, "A woman came to Abdullah ibn Abbas and said, 'I have vowed to sacrifice my son.' Ibn Abbas said, 'Do not sacrifice your son. Do kaffara for your oath.' An old man with Ibn Abbas said, 'What kaffara is there for this?' Ibn Abbas said, 'Allah the Exalted said, "Those of you who say, regarding their wives.'Be as my mother's back' (Sura58 ayat 2) and then He went on to oblige the kaffara for it as you have seen}}
\hadithdefcmd{malik}{1017}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ طَلْحَةَ بْنِ عَبْدِ الْمَلِكِ الأَيْلِيِّ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدِ بْنِ الصِّدِّيقِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ نَذَرَ أَنْ يُطِيعَ اللَّهَ فَلْيُطِعْهُ وَمَنْ نَذَرَ أَنْ يَعْصِيَ اللَّهَ فَلاَ يَعْصِهِ ‏"‏ ‏.‏\hadithno{1017}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Talha ibn Abi al-Malik al- Ayli from al-Qasim ibn Muhammad ibn as-Siddiq from A'isha that the Messenger of Allah, may Allah bless him and grant him peace, said, "Whoever vows to obey Allah, let him obey Him. Whoever vows to disobey Allah, let him not disobey Him." Yahya said that he had heard Malik say, "The meaning of the statement of the Prophet, may Allah bless him and grant him peace, 'Whoever vows to disobey Allah, let him not disobey Him' is that for instance a man who vows that, if he speaks to such-and-such a person, he will walk to Syria, Egypt, or any other such things which are not considered as ibada, is not under any obligation by any of that, even if he did speak to the man or did break whatever it was he swore, because Allah does not demand obedience in such things. He should only fulfill those things in which there is obedience to Allah." 22.5 Rashness in Oaths}}
\hadithdefcmd{malik}{1018}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا كَانَتْ تَقُولُ لَغْوُ الْيَمِينِ قَوْلُ الإِنْسَانِ لاَ وَاللَّهِ بَلَى وَاللَّهِ ‏.‏ قَالَ مَالِكٌ أَحْسَنُ مَا سَمِعْتُ فِي هَذَا أَنَّ اللَّغْوَ حَلِفُ الإِنْسَانِ عَلَى الشَّىْءِ يَسْتَيْقِنُ أَنَّهُ كَذَلِكَ ثُمَّ يُوجَدُ عَلَى غَيْرِ ذَلِكَ فَهُوَ اللَّغْوُ ‏.‏ قَالَ مَالِكٌ وَعَقْدُ الْيَمِينِ أَنْ يَحْلِفَ الرَّجُلُ أَنْ لاَ يَبِيعَ ثَوْبَهُ بِعَشَرَةِ دَنَانِيرَ ثُمَّ يَبِيعَهُ بِذَلِكَ أَوْ يَحْلِفَ لَيَضْرِبَنَّ غُلاَمَهُ ثُمَّ لاَ يَضْرِبُهُ وَنَحْوَ هَذَا فَهَذَا الَّذِي يُكَفِّرُ صَاحِبُهُ عَنْ يَمِينِهِ وَلَيْسَ فِي اللَّغْوِ كَفَّارَةٌ ‏.‏ قَالَ مَالِكٌ فَأَمَّا الَّذِي يَحْلِفُ عَلَى الشَّىْءِ وَهُوَ يَعْلَمُ أَنَّهُ آثِمٌ وَيَحْلِفُ عَلَى الْكَذِبِ وَهُوَ يَعْلَمُ لِيُرْضِيَ بِهِ أَحَدًا أَوْ لِيَعْتَذِرَ بِهِ إِلَى مُعْتَذَرٍ إِلَيْهِ أَوْ لِيَقْطَعَ بِهِ مَالاً فَهَذَا أَعْظَمُ مِنْ أَنْ تَكُونَ فِيهِ كَفَّارَةٌ ‏.‏\hadithno{1018}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that A'isha, umm al-muminin said, "Rashness in oaths is that a man says, 'By Allah, No! by Allah!' " i.e. out of habit. Malik said, "The best of what I have heard on the matter is that rashness in oaths is that a man take an oath on something to show that he is certain that it is like he said, only to find that it is other than what he said. This is rashness." Malik said, "The binding oath is for example, that a man says that he will not sell his garment for ten dinars, and then he sells it for that, or that he will beat his young slave and then does not beat him, and so on. One does kaffara for making such an oath, and there is no kaffara in rashness." Malik said, "As for the one who swears to a thing which he knows is wicked, and he swears to a lie he knows to be a lie, in order to please someone with it or to excuse himself to someone by it or to gain money by it, no kaffara that he does for it can cover it}}
\hadithdefcmd{malik}{1019}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ مَنْ قَالَ وَاللَّهِ ثُمَّ قَالَ إِنْ شَاءَ اللَّهُ ثُمَّ لَمْ يَفْعَلِ الَّذِي حَلَفَ عَلَيْهِ لَمْ يَحْنَثْ ‏.‏ قَالَ مَالِكٌ أَحْسَنُ مَا سَمِعْتُ فِي الثُّنْيَا أَنَّهَا لِصَاحِبِهَا مَا لَمْ يَقْطَعْ كَلاَمَهُ وَمَا كَانَ مِنْ ذَلِكَ نَسَقًا يَتْبَعُ بَعْضُهُ بَعْضًا قَبْلَ أَنْ يَسْكُتَ فَإِذَا سَكَتَ وَقَطَعَ كَلاَمَهُ فَلاَ ثُنْيَا لَهُ ‏.‏ قَالَ يَحْيَى وَقَالَ مَالِكٌ فِي الرَّجُلِ يَقُولُ كَفَرَ بِاللَّهِ أَوْ أَشْرَكَ بِاللَّهِ ثُمَّ يَحْنَثُ إِنَّهُ لَيْسَ عَلَيْهِ كَفَّارَةٌ وَلَيْسَ بِكَافِرٍ وَلاَ مُشْرِكٍ حَتَّى يَكُونَ قَلْبُهُ مُضْمِرًا عَلَى الشِّرْكِ وَالْكُفْرِ وَلْيَسْتَغْفِرِ اللَّهَ وَلاَ يَعُدْ إِلَى شَىْءٍ مِنْ ذَلِكَ وَبِئْسَ مَا صَنَعَ ‏.‏\hadithno{1019}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "Whoever swears by Allah and then says, 'Allah willing' and then does not do what he has sworn to, has not broken his oath." Malik said, "The best I have heard on this reservation is that it belongs to the statement made if the speaker does not break the normal flow of speech before he is silent. If he is silent and breaks the flow of speech, he has no exception." Yahya said, "Malik said that a man who said that he had disbelieved or associated something with Allah and then he broke his oath, had no kaffara, and he was not a disbeliever or one who associated something with Allah unless his heart concealed something of either of those. He should ask forgiveness of Allah and not return to it - for what he did was evil}}
\hadithdefcmd{malik}{1020}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَلَفَ بِيَمِينٍ فَرَأَى غَيْرَهَا خَيْرًا مِنْهَا فَلْيُكَفِّرْ عَنْ يَمِينِهِ وَلْيَفْعَلِ الَّذِي هُوَ خَيْرٌ ‏"‏ ‏.‏\hadithno{1020}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Suhayl ibn Abi Salih from his father from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Whoever makes an oath and then sees that something else would be better than it, should do kaffara for his oath and do what is better." Yahya said that he heard Malik say, "Anyone who says that he has a vow but does not mention the name of Allah, is still obliged to make the kaffara for an oath (if he breaks it)". Malik said, "Emphasis is when a man swears one thing several times, repeating the oath in his speech time after time. For instance, the statement, 'By Allah, I will not decrease it from such-and-such,' sworn three times or more. The kaffara of that is like the kaffara of one oath. If a man swears, 'I will not eat this food or wear these clothes or enter this house,' that is all in one oath, and he is only obliged to do one kaffara. It is the same for a man who says to his wife, 'You are divorced if I clothe you in this garment or let you go to the mosque,' and it is one entire statement in the normal pattern of speech. If he breaks any of that oath, divorce is necessary, and there is no breaking of oath after that in whatever he does. There is only one oath to be broken in that." Malik said, "What we do about a woman who makes a vow without her husband's permission is that she is allowed to do so and she must fulfill it, if it only concerns her own person and will not harm her husband. If, however, it will harm her husband, he may forbid her to fulfill it, but it remains an obligation against her until she has the opportunity to complete it}}
\hadithdefcmd{malik}{1021}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ مَنْ حَلَفَ بِيَمِينٍ فَوَكَّدَهَا ثُمَّ حَنِثَ فَعَلَيْهِ عِتْقُ رَقَبَةٍ أَوْ كِسْوَةُ عَشَرَةِ مَسَاكِينَ وَمَنْ حَلَفَ بِيَمِينٍ فَلَمْ يُؤَكِّدْهَا ثُمَّ حَنِثَ فَعَلَيْهِ إِطْعَامُ عَشَرَةِ مَسَاكِينَ لِكُلِّ مِسْكِينٍ مُدٌّ مِنْ حِنْطَةٍ فَمَنْ لَمْ يَجِدْ فَصِيَامُ ثَلاَثَةِ أَيَّامٍ ‏.‏\hadithno{1021}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "If someone breaks an oath which he has stressed, he has to free a slave, or clothe ten poor people. If someone breaks an oath, but has not stressed it, he only has to feed ten poor people and each poor person is fed a mudd of wheat. Some one who does not have the means for that, should fast for three days}}
\hadithdefcmd{malik}{1022}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يُكَفِّرُ عَنْ يَمِينِهِ، بِإِطْعَامِ عَشَرَةِ مَسَاكِينَ لِكُلِّ مِسْكِينٍ مُدٌّ مِنْ حِنْطَةٍ وَكَانَ يَعْتِقُ الْمِرَارَ إِذَا وَكَّدَ الْيَمِينَ ‏.‏\hadithno{1022}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to do kaffara for a broken oath by feeding ten poor people. Each person got a mudd of wheat. He sometimes freed a slave if he had repeated the oath}}
\hadithdefcmd{malik}{1023}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّهُ قَالَ أَدْرَكْتُ النَّاسَ وَهُمْ إِذَا أَعْطَوْا فِي كَفَّارَةِ الْيَمِينِ أَعْطَوْا مُدًّا مِنْ حِنْطَةٍ بِالْمُدِّ الأَصْغَرِ وَرَأَوْا ذَلِكَ مُجْزِئًا عَنْهُمْ ‏.‏ قَالَ مَالِكٌ أَحْسَنُ مَا سَمِعْتُ فِي الَّذِي يُكَفِّرُ عَنْ يَمِينِهِ بِالْكِسْوَةِ أَنَّهُ إِنْ كَسَا الرِّجَالَ كَسَاهُمْ ثَوْبًا ثَوْبًا وَإِنْ كَسَا النِّسَاءَ كَسَاهُنَّ ثَوْبَيْنِ ثَوْبَيْنِ دِرْعًا وَخِمَارًا وَذَلِكَ أَدْنَى مَا يُجْزِي كُلاًّ فِي صَلاَتِهِ ‏.‏\hadithno{1023}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Sulayman ibn Yasar said, "I understood from people that when they made the kaffara for a broken oath, they gave a mudd of wheat according to the smaller mudd. They thought that that would compensate for them." Malik said, "The best of what I have heard about the one who does kaffara for breaking his oath by clothing people is that if he clothes men he clothes them each in one garment. If he clothes women, he clothes them each in two garments, a long shift and a long scarf, because that is what is satisfactory for each of them in the prayer}}
\hadithdefcmd{malik}{1024}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَدْرَكَ عُمَرَ بْنَ الْخَطَّابِ - رضى الله عنه - وَهُوَ يَسِيرُ فِي رَكْبٍ وَهُوَ يَحْلِفُ بِأَبِيهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يَنْهَاكُمْ أَنْ تَحْلِفُوا بِآبَائِكُمْ فَمَنْ كَانَ حَالِفًا فَلْيَحْلِفْ بِاللَّهِ أَوْ لِيَصْمُتْ ‏"‏ ‏.‏\hadithno{1024}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that one time the Messenger of Allah, may Allah bless him and grant him peace, was speaking to Umar ibn al-Khattab while he was travelling with a troop and Umar swore by his father and he (the Messenger) said, "Allah forbids you to swear by your fathers. If anyone swears, let him swear by Allah or keep silent}}
\hadithdefcmd{malik}{1025}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ لاَ وَمُقَلِّبِ الْقُلُوبِ ‏"‏ ‏.‏\hadithno{1025}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, used tosay, "No, by the Overturner of hearts}}
\hadithdefcmd{malik}{1026}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عُثْمَانَ بْنِ حَفْصِ بْنِ عُمَرَ بْنِ خَلْدَةَ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ بَلَغَهُ أَنَّ أَبَا لُبَابَةَ بْنَ عَبْدِ الْمُنْذِرِ، حِينَ تَابَ اللَّهُ عَلَيْهِ قَالَ يَا رَسُولَ اللَّهِ أَهْجُرُ دَارَ قَوْمِي الَّتِي أَصَبْتُ فِيهَا الذَّنْبَ وَأُجَاوِرُكَ وَأَنْخَلِعُ مِنْ مَالِي صَدَقَةً إِلَى اللَّهِ وَإِلَى رَسُولِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُجْزِيكَ مِنْ ذَلِكَ الثُّلُثُ ‏"‏ ‏.‏\hadithno{1026}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Uthman ibn Hafs ibn Umar ibn Khalda that Ibn Shihab had heard that Abu Lubaba ibn Abd al-Mundhir, when Allah turned to him said, "Messenger of Allah, should I leave my people's house in which I committed wrong action and keep your company, and give away all my property as sadaqa for Allah and His Messenger? "The Messenger of Allah, may Allah bless him and grant him peace, said, "Giving away a third of it is enough for you}}
\hadithdefcmd{malik}{1027}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ مَنْصُورِ بْنِ عَبْدِ الرَّحْمَنِ الْحَجَبِيِّ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، - رضى الله عنها أَنَّهَا سُئِلَتْ عَنْ رَجُلٍ قَالَ مَالِي فِي رِتَاجِ الْكَعْبَةِ ‏.‏ فَقَالَتْ عَائِشَةُ يُكَفِّرُهُ مَا يُكَفِّرُ الْيَمِينَ ‏.‏ قَالَ مَالِكٌ فِي الَّذِي يَقُولُ مَالِي فِي سَبِيلِ اللَّهِ ثُمَّ يَحْنَثُ قَالَ يَجْعَلُ ثُلُثَ مَالِهِ فِي سَبِيلِ اللَّهِ وَذَلِكَ لِلَّذِي جَاءَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي أَمْرِ أَبِي لُبَابَةَ ‏.‏\hadithno{1027}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ayyub ibn Musa from Mansur ibn Abd ar-Rahman al-Hajabi from his mother that A'isha, umm al- muminin, may Allah be pleased with her, was asked about a man who devoted his property to the door of Kaba. She said, "Let him do kaffara for it with the kaffara of the oath." Malik said, that someone who devoted all his property in the way of Allah, and then broke his oath, should put a third of his property in the way of Allah, as that was what the Messenger of Allah, may Allah bless him and grant him peace, did in the case of Abu Lubaba}}
