% Auto-generated chapter 18 for ibnmajah
% Hadiths in this chapter: 10

\hadithdefcmd{ibnmajah}{2502}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنِ الْحَسَنِ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ضَالَّةُ الْمُسْلِمِ حَرَقُ النَّارِ ‏"‏ ‏.‏\hadithno{2502}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Mutarrif bin 'Abdullah bin Shikhkhir that his father said:“The Messenger of Allah (ﷺ) said: 'The lost animal of the Muslim may lead to the burning flame of Hell.' ”}}
\hadithdefcmd{ibnmajah}{2503}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو حَيَّانَ التَّيْمِيُّ، حَدَّثَنَا الضَّحَّاكُ، خَالُ الْمُنْذِرِ بْنِ جَرِيرٍ عَنِ الْمُنْذِرِ بْنِ جَرِيرٍ، قَالَ كُنْتُ مَعَ أَبِي بِالْبَوَازِيجِ فَرَاحَتِ الْبَقَرُ فَرَأَى بَقَرَةً أَنْكَرَهَا فَقَالَ مَا هَذِهِ قَالُوا بَقَرَةٌ لَحِقَتْ بِالْبَقَرِ ‏.‏ قَالَ فَأَمَرَ بِهَا فَطُرِدَتْ حَتَّى تَوَارَتْ ثُمَّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يُئْوِي الضَّالَّةَ إِلاَّ ضَالٌّ ‏"‏ ‏.‏\hadithno{2503}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Mundhir bin Jarir said:“I was with my father in Bawazij and the cows came back in the evening. He saw a cow did not recognize it. He said: 'What is this?' He said: 'A cow that joined the herd.' And he issued orders that it be driven away until it disappeared from view. Then he said: 'I heard the Messenger of Allah (ﷺ) say: “No one gives refuge to a stray animal but one who is also astray.”}}
\hadithdefcmd{ibnmajah}{2504}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ بْنِ الْعَلاَءِ الأَيْلِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، فَلَقِيتُ رَبِيعَةَ فَسَأَلْتُهُ فَقَالَ حَدَّثَنِي يَزِيدُ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ سُئِلَ عَنْ ضَالَّةِ الإِبِلِ فَغَضِبَ وَاحْمَرَّتْ وَجْنَتَاهُ وَقَالَ ‏"‏ مَالَكَ وَلَهَا مَعَهَا الْحِذَاءُ وَالسِّقَاءُ تَرِدُ الْمَاءَ وَتَأْكُلُ الشَّجَرَ حَتَّى يَلْقَاهَا رَبُّهَا ‏"‏ ‏.‏ وَسُئِلَ عَنْ ضَالَّةِ الْغَنَمِ فَقَالَ ‏"‏ خُذْهَا فَإِنَّمَا هِيَ لَكَ أَوْ لأَخِيكَ أَوْ لِلذِّئْبِ ‏"‏ ‏.‏ وَسُئِلَ عَنِ اللُّقَطَةِ فَقَالَ ‏"‏ اعْرِفْ عِفَاصَهَا وَوِكَاءَهَا وَعَرِّفْهَا سَنَةً فَإِنِ اعْتُرِفَتْ وَإِلاَّ فَاخْلِطْهَا بِمَالِكَ ‏"‏ ‏.‏\hadithno{2504}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Zaid bin Khalid that the Prophet (ﷺ) was asked about a lost camel. :He turned red, and he said: “What does it have to do with you? It has its feet and its water supply, it can go and drink water and eat from the trees until its owner finds it.” And he was asked about lost sheep, and he said: “Take it, for it will be for you or for your brother or for the wolf.” And he was asked about lost property and he said: “Remember the features of its leather bag and strap, and announce it for one year, then if someone claims it, describing it to you with those features (give it to him), otherwise incorporate it into your own wealth.”}}
\hadithdefcmd{ibnmajah}{2505}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي الْعَلاَءِ، عَنْ مُطَرِّفٍ، عَنْ عِيَاضِ بْنِ حِمَارٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ وَجَدَ لُقَطَةً فَلْيُشْهِدْ ذَا عَدْلٍ أَوْ ذَوَىْ عَدْلٍ ثُمَّ لاَ يُغَيِّرْهُ وَلاَ يَكْتُمْ فَإِنْ جَاءَ رَبُّهَا فَهُوَ أَحَقُّ بِهَا وَإِلاَّ فَهُوَ مَالُ اللَّهِ يُؤْتِيهِ مَنْ يَشَاءُ ‏"‏ ‏.‏\hadithno{2505}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Iyad bin Himar that the Messenger of Allah (ﷺ) said:“Whoever finds lost property, let him ask one or two men of good character to witness it, then he should not alter it nor conceal it. If its owner comes along, then he has more right to it, otherwise it belongs to Allah (SWT), Who gives it to whomsoever He wills.”}}
\hadithdefcmd{ibnmajah}{2506}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، قَالَ خَرَجْتُ مَعَ زَيْدِ بْنِ صُوحَانَ وَسَلْمَانَ بْنِ رَبِيعَةَ حَتَّى إِذَا كُنَّا بِالْعُذَيْبِ الْتَقَطْتُ سَوْطًا فَقَالاَ لِي أَلْقِهِ ‏.‏ فَأَبَيْتُ فَلَمَّا قَدِمْنَا الْمَدِينَةَ أَتَيْتُ أُبَىَّ بْنَ كَعْبٍ فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ أَصَبْتَ الْتَقَطْتُ مِائَةَ دِينَارٍ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلْتُهُ فَقَالَ ‏"‏ عَرِّفْهَا سَنَةً ‏"‏ ‏.‏ فَعَرَّفْتُهَا فَلَمْ أَجِدْ أَحَدًا يَعْرِفُهَا فَسَأَلْتُهُ فَقَالَ ‏"‏ عَرِّفْهَا ‏"‏ ‏.‏ فَعَرَّفْتُهَا فَلَمْ أَجِدْ أَحَدًا يَعْرِفُهَا ‏.‏ فَقَالَ ‏"‏ اعْرِفْ وِعَاءَهَا وَوِكَاءَهَا وَعَدَدَهَا ثُمَّ عَرِّفْهَا سَنَةً فَإِنْ جَاءَ مَنْ يَعْرِفُهَا وَإِلاَّ فَهِيَ كَسَبِيلِ مَالِكَ ‏"‏ ‏.‏\hadithno{2506}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Suwaid bin Ghafalah said:“I went out with Zaid bin Suhan and Salman bin Rabi'ah, and when we were at `Udhaib, I found a whip. They said to me: 'Throw it away,' but I refused. When we came to Al-Madinah I went to Ubayy bin Ka'b and told him about that. He said: 'You did the right thing. I found one hundred dinar that had been lost at the time of the Messenger of Allah (ﷺ), and I asked him about it. He said, “Announce it for a year.” So I Announced it, and I did not find anyone who recognized it. He said: “Remember the features of its bag and strap, and how many it contains, then announce it for a year. If someone comes who describes it with those features, (give it to him), otherwise it is like your own property.”}}
\hadithdefcmd{ibnmajah}{2507}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، ح وَحَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالاَ حَدَّثَنَا الضَّحَّاكُ بْنُ عُثْمَانَ الْقُرَشِيُّ، حَدَّثَنِي سَالِمٌ أَبُو النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ اللُّقَطَةِ فَقَالَ ‏ "‏ عَرِّفْهَا سَنَةً فَإِنِ اعْتُرِفَتْ فَأَدِّهَا فَإِنْ لَمْ تُعْرَفْ فَاعْرِفْ عِفَاصَهَا وَوِعَاءَهَا ثُمَّ كُلْهَا فَإِنْ جَاءَ صَاحِبُهَا فَأَدِّهَا إِلَيْهِ ‏"‏ ‏.‏\hadithno{2507}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Zaid bin Khalid Al-Juhani that the Messenger of Allah (ﷺ) was asked about lost property. :He said: “Announce it for a year, then if someone describes it with its features, return it to him. If no one claims it, then remember the features of its leather bag and strap, and consume it (use it). Then if its owner comes along, give it to him.”}}
\hadithdefcmd{ibnmajah}{2508}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدِ بْنِ عَثْمَةَ، حَدَّثَنِي مُوسَى بْنُ يَعْقُوبَ الزَّمْعِيُّ، حَدَّثَتْنِي عَمَّتِي، قُرَيْبَةُ بِنْتُ عَبْدِ اللَّهِ أَنَّ أُمَّهَا، كَرِيمَةَ بِنْتَ الْمِقْدَادِ بْنِ عَمْرٍو أَخْبَرَتْهَا عَنْ ضُبَاعَةَ بِنْتِ الزُّبَيْرِ، عَنِ الْمِقْدَادِ بْنِ عَمْرٍو، أَنَّهُ خَرَجَ ذَاتَ يَوْمٍ إِلَى الْبَقِيعِ وَهُوَ الْمَقْبُرَةُ لِحَاجَتِهِ وَكَانَ النَّاسُ لاَ يَذْهَبُ أَحَدُهُمْ فِي حَاجَتِهِ إِلاَّ فِي الْيَوْمَيْنِ وَالثَّلاَثَةِ فَإِنَّمَا يَبْعَرُ كَمَا تَبْعَرُ الإِبِلُ ثُمَّ دَخَلَ خَرِبَةً فَبَيْنَمَا هُوَ جَالِسٌ لِحَاجَتِهِ إِذْ رَأَى جُرَذًا أَخْرَجَ مِنْ جُحْرٍ دِينَارًا ثُمَّ دَخَلَ فَأَخْرَجَ آخَرَ حَتَّى أَخْرَجَ سَبْعَةَ عَشَرَ دِينَارًا ثُمَّ أَخْرَجَ طَرَفَ خِرْقَةٍ حَمْرَاءَ ‏.‏ قَالَ الْمِقْدَادُ فَسَلَلْتُ الْخِرْقَةَ فَوَجَدْتُ فِيهَا دِينَارًا فَتَمَّتْ ثَمَانِيَةَ عَشَرَ دِينَارًا فَخَرَجْتُ بِهَا حَتَّى أَتَيْتُ بِهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ خَبَرَهَا فَقُلْتُ خُذْ صَدَقَتَهَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ ارْجِعْ بِهَا لاَ صَدَقَةَ فِيهَا بَارَكَ اللَّهُ لَكَ فِيهَا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ لَعَلَّكَ أَتْبَعْتَ يَدَكَ فِي الْجُحْرِ ‏"‏ ‏.‏ قُلْتُ لاَ وَالَّذِي أَكْرَمَكَ بِالْحَقِّ ‏.‏ قَالَ فَلَمْ يَفْنَ آخِرُهَا حَتَّى مَاتَ ‏.‏\hadithno{2508}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Miqdad bin 'Amr:That he went out one day to Al-Baqi', which is the graveyard, to relieve himself. People used to go out to relieve themselves only every two or three days, and their faces was like that of a camel (because of hunger and rough food). Then he entered a ruin and while he was squatting to relieve himself, he saw a rat bringing a Dinar out of a hole, then it went in and brought out another, until it had brought out seventeen Dinars. Then it brought out a piece of red rag.Miqdad said: “I picked up the rag and found another Dinar inside it, thus completing eighteen Dinar. I took them out and brought them to the Messenger of Allah (ﷺ), and told him what had happened. I said, 'Take its Sadaqah (charity), O Messenger of Allah (ﷺ).' He said: 'Take them back, for no Sadaqah is due on them. May Allah (SWT) bless them for you.' Then he said: 'Perhaps you put your hand in the hole?' I said: 'No, by the One Who has honored you with the truth.”}}
\hadithdefcmd{ibnmajah}{2509}{حَدَّثَنَا مُحَمَّدُ بْنُ مَيْمُونٍ الْمَكِّيُّ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فِي الرِّكَازِ الْخُمُسُ ‏"‏ ‏.‏\hadithno{2509}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“One fifth is due on buried treasure.”}}
\hadithdefcmd{ibnmajah}{2510}{حَدَّثَنَا نَصْرُ بْنُ عَلِيىٍّ الْجَهْضَمِيُّ، حَدَّثَنَا أَبُو أَحْمَدَ، عَنْ إِسْرَائِيلَ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فِي الرِّكَازِ الْخُمُسُ ‏"‏ ‏.‏\hadithno{2510}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn`Abbas that the Messenger of Allah (ﷺ) said:“One fifth is due on buried treasure.”}}
\hadithdefcmd{ibnmajah}{2511}{حَدَّثَنَا أَحْمَدُ بْنُ ثَابِتٍ الْجَحْدَرِيُّ، حَدَّثَنَا يَعْقُوبُ بْنُ إِسْحَاقَ الْحَضْرَمِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ حَيَّانَ، سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كَانَ فِيمَنْ كَانَ قَبْلَكُمْ رَجُلٌ اشْتَرَى عَقَارًا فَوَجَدَ فِيهَا جَرَّةً مِنْ ذَهَبٍ فَقَالَ اشْتَرَيْتُ مِنْكَ الأَرْضَ وَلَمْ أَشْتَرِ مِنْكَ الذَّهَبَ ‏.‏ فَقَالَ الرَّجُلُ إِنَّمَا بِعْتُكَ الأَرْضَ بِمَا فِيهَا ‏.‏ فَتَحَاكَمَا إِلَى رَجُلٍ فَقَالَ أَلَكُمَا وَلَدٌ فَقَالَ أَحَدُهُمَا لِي غُلاَمٌ ‏.‏ وَقَالَ الآخَرُ لِي جَارِيَةٌ ‏.‏ قَالَ فَأَنْكِحَا الْغُلاَمَ الْجَارِيَةَ وَلْيُنْفِقَا عَلَى أَنْفُسِهِمَا مِنْهُ وَلْيَتَصَدَّقَا ‏"‏ ‏.‏\hadithno{2511}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sulaiman bin Hayyan said:“I heard my father narrate from Abu Hurairah that the Prophet (ﷺ) said: 'Among those who came before you there was a man who bought some property and found therein a jar of gold. He said: “I bought land from you, but I did not buy the gold from you.” The man said: “Rather I sold you the land with whatever is in it.” They referred their case to (a third) man who said: “Do you have children?” One of them said: “I have a boy.” The other said: “I have a girl.” He said: “Marry the boy to the girl, and let them spend on themselves from it and give in charity.”}}
