% Auto-generated chapter 16 for tirmidhi
% Hadiths in this chapter: 37

\hadithdefcmd{tirmidhi}{1386}{حَدَّثَنَا عَلِيُّ بْنُ سَعِيدٍ الْكِنْدِيُّ الْكُوفِيُّ، أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، عَنِ الْحَجَّاجِ، عَنْ زَيْدِ بْنِ جُبَيْرٍ، عَنْ خِشْفِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ ابْنَ مَسْعُودٍ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي دِيَةِ الْخَطَإِ عِشْرِينَ بِنْتَ مَخَاضٍ وَعِشْرِينَ بَنِي مَخَاضٍ ذُكُورًا وَعِشْرِينَ بِنْتَ لَبُونٍ وَعِشْرِينَ جَذَعَةً وَعِشْرِينَ حِقَّةً ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، وَأَبُو خَالِدٍ الأَحْمَرُ عَنِ الْحَجَّاجِ بْنِ أَرْطَاةَ، نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ مَسْعُودٍ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ هَذَا الْوَجْهِ وَقَدْ رُوِيَ عَنْ عَبْدِ اللَّهِ مَوْقُوفًا ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَدْ أَجْمَعَ أَهْلُ الْعِلْمِ عَلَى أَنَّ الدِّيَةَ تُؤْخَذُ فِي ثَلاَثِ سِنِينَ فِي كُلِّ سَنَةٍ ثُلُثُ الدِّيَةِ وَرَأَوْا أَنَّ دِيَةَ الْخَطَإِ عَلَى الْعَاقِلَةِ ‏.‏ وَرَأَى بَعْضُهُمْ أَنَّ الْعَاقِلَةَ قَرَابَةُ الرَّجُلِ مِنْ قِبَلِ أَبِيهِ ‏.‏ وَهُوَ قَوْلُ مَالِكٍ وَالشَّافِعِيِّ ‏.‏ وَقَالَ بَعْضُهُمْ إِنَّمَا الدِّيَةُ عَلَى الرِّجَالِ دُونَ النِّسَاءِ وَالصِّبْيَانِ مِنَ الْعَصَبَةِ يُحَمَّلُ كُلُّ رَجُلٍ مِنْهُمْ رُبُعَ دِينَارٍ ‏.‏ وَقَدْ قَالَ بَعْضُهُمْ إِلَى نِصْفِ دِينَارٍ فَإِنْ تَمَّتِ الدِّيَةُ وَإِلاَّ نُظِرَ إِلَى أَقْرَبِ الْقَبَائِلِ مِنْهُمْ فَأُلْزِمُوا ذَلِكَ ‏.‏\hadithno{1386}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Mas'ud:"The Messenger of Allah (ﷺ) judged for the accidental blood-Money: Twenty Bint Makhad, twenty make Ibn Makhad, twenty Bint Labunm twenty Jadha'ah, and twenty Hiqqah. (Another chain) with similar meaning}}
\hadithdefcmd{tirmidhi}{1387}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، أَخْبَرَنَا حَبَّانُ، وَهُوَ ابْنُ هِلاَلٍ حَدَّثَنَا مُحَمَّدُ بْنُ رَاشِدٍ، أَخْبَرَنَا سُلَيْمَانُ بْنُ مُوسَى، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَتَلَ مُؤْمِنًا مُتَعَمِّدًا دُفِعَ إِلَى أَوْلِيَاءِ الْمَقْتُولِ فَإِنْ شَاءُوا قَتَلُوا وَإِنْ شَاءُوا أَخَذُوا الدِّيَةَ وَهِيَ ثَلاَثُونَ حِقَّةً وَثَلاَثُونَ جَذَعَةً وَأَرْبَعُونَ خَلِفَةً وَمَا صَالَحُوا عَلَيْهِ فَهُوَ لَهُمْ ‏"‏ ‏.‏ وَذَلِكَ لِتَشْدِيدِ الْعَقْلِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ عَمْرٍو حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{1387}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Amr bin Shu'aib:from his father, from his grandfather that the Prophet (ﷺ) said: "Whoever kills [a believer] deliberately, he is handed over to the guardians of the one killed. If they wish to, they have him killed, and if they wish to, they take the blood-money. That is thirty Hiqqah, thirty Jadha'ahs and forty pregnant camels. Whatever (amount more) they require from him, than that is for them (if they choose)." THat is because of the severity of blood-money}}
\hadithdefcmd{tirmidhi}{1388}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هَانِئٍ، حَدَّثَنَا مُحَمَّدُ بْنُ مُسْلِمٍ الطَّائِفِيُّ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ جَعَلَ الدِّيَةَ اثْنَىْ عَشَرَ أَلْفًا ‏.‏\hadithno{1388}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Ikrimah:from Ibn 'Abbas that the Prophet (ﷺ) made the blood-money twelve thousand}}
\hadithdefcmd{tirmidhi}{1389}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَلَمْ يَذْكُرْ فِيهِ عَنِ ابْنِ عَبَّاسٍ وَفِي حَدِيثِ ابْنِ عُيَيْنَةَ كَلاَمٌ أَكْثَرُ مِنْ هَذَا ‏.‏ قَالَ أَبُو عِيسَى وَلاَ نَعْلَمُ أَحَدًا يَذْكُرُ فِي هَذَا الْحَدِيثِ عَنِ ابْنِ عَبَّاسٍ غَيْرَ مُحَمَّدِ بْنِ مُسْلِمٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَرَأَى بَعْضُ أَهْلِ الْعِلْمِ الدِّيَةَ عَشَرَةَ آلاَفٍ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏ وَقَالَ الشَّافِعِيُّ لاَ أَعْرِفُ الدِّيَةَ إِلاَّ مِنَ الإِبِلِ وَهِيَ مِائَةٌ مِنَ الإِبِلِ أَوْ قِيمَتُهَا ‏.‏\hadithno{1389}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{(Another chain) from 'Ikrimah from the Prophet (ﷺ) and it is similar but he did not mention "from Ibn 'Abbas" in it. There is much more criticism than this for (this) narration of Ibn 'Uyainah}}
\hadithdefcmd{tirmidhi}{1390}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، أَخْبَرَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ فِي الْمَوَاضِحِ خَمْسٌ خَمْسٌ ‏"‏ ‏.‏ قال أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ أَنَّ فِي الْمُوضِحَةِ خَمْسًا مِنَ الإِبِلِ ‏.‏\hadithno{1390}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr bin Shu'aib:from his father, from his grandfather that the Prophet (ﷺ) said: "Regarding the Mawadih; five, five}}
\hadithdefcmd{tirmidhi}{1391}{حَدَّثَنَا أَبُو عَمَّارٍ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الْحُسَيْنِ بْنِ وَاقِدٍ، عَنْ يَزِيدَ بْنِ عَمْرٍو النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دِيَةُ الأَصَابِعِ الْيَدَيْنِ وَالرِّجْلَيْنِ سَوَاءٌ عَشْرٌ مِنَ الإِبِلِ لِكُلِّ أُصْبُعٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي مُوسَى وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ سُفْيَانُ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{1391}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn 'Abbas:that the Messenger of Allah (ﷺ) said: "The blood-money for the fingers on the hands and (the toes of) the feet is the same: Ten camels for each finger}}
\hadithdefcmd{tirmidhi}{1392}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ هَذِهِ وَهَذِهِ سَوَاءٌ ‏"‏ ‏.‏ يَعْنِي الْخِنْصَرَ وَالإِبْهَامَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1392}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn 'Abbas:that the Prophet (ﷺ) said: "These and these are the same." referring to the little finger and thumb}}
\hadithdefcmd{tirmidhi}{1393}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، حَدَّثَنَا أَبُو السَّفَرِ، قَالَ دَقَّ رَجُلٌ مِنْ قُرَيْشٍ سِنَّ رَجُلٍ مِنَ الأَنْصَارِ فَاسْتَعْدَى عَلَيْهِ مُعَاوِيَةَ فَقَالَ لِمُعَاوِيَةَ يَا أَمِيرَ الْمُؤْمِنِينَ إِنَّ هَذَا دَقَّ سِنِّي ‏.‏ قَالَ مُعَاوِيَةُ إِنَّا سَنُرْضِيكَ وَأَلَحَّ الآخَرُ عَلَى مُعَاوِيَةَ فَأَبْرَمَهُ فَلَمْ يُرْضِهِ فَقَالَ لَهُ مُعَاوِيَةُ شَأْنَكَ بِصَاحِبِكَ ‏.‏ وَأَبُو الدَّرْدَاءِ جَالِسٌ عِنْدَهُ قَالَ أَبُو الدَّرْدَاءِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ رَجُلٍ يُصَابُ بِشَيْءٍ فِي جَسَدِهِ فَيَتَصَدَّقُ بِهِ إِلاَّ رَفَعَهُ اللَّهُ بِهِ دَرَجَةً وَحَطَّ عَنْهُ بِهِ خَطِيئَةً ‏"‏ ‏.‏ قَالَ الأَنْصَارِيُّ أَأَنْتَ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ سَمِعَتْهُ أُذُنَاىَ وَوَعَاهُ قَلْبِي ‏.‏ قَالَ فَإِنِّي أَذَرُهَا لَهُ ‏.‏ قَالَ مُعَاوِيَةُ لاَ جَرَمَ لاَ أُخَيِّبُكَ ‏.‏ فَأَمَرَ لَهُ بِمَالٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَلاَ أَعْرِفُ لأَبِي السَّفَرِ سَمَاعًا مِنْ أَبِي الدَّرْدَاءِ وَأَبُو السَّفَرِ اسْمُهُ سَعِيدُ بْنُ أَحْمَدَ وَيُقَالُ ابْنُ يُحْمِدَ الثَّوْرِيُّ ‏.‏\hadithno{1393}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu As-Safar:"A man from the Quraish broke a tooth of a man from the Ansar. So he appealed to Mu'awiyah against him. He said to Mu'awiyah: 'O Commander of the Believers! This person broke one of my teeth.' Mu'awiyah said: 'We will try to get satisfaction for you.' And the other person insisted that Mu'awiyah get him to agree [but he was not satisfied]. So Mu'awiyah said him: 'It is up to your companion.' Abu Ad-Darda' was sitting with him, so Abu Ad-Darda said: 'I heard the Messenger of Allah (ﷺ) saying [he said: 'My ears heard and my heart remembered]: "There is no man who is struck in his body and he forgives for it, except that Allah raises him a level and removes a sin from him.'" The Ansari said: 'Did you hear that from the Messenger of Allah (ﷺ)?' He said: "My ears heard it and my heart remembered it.' He said: 'Then I will leave it to him.' Mu'awiyah said: 'Surely you should not suffer.' So he ordered that he be given some wealth}}
\hadithdefcmd{tirmidhi}{1394}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ خَرَجَتْ جَارِيَةٌ عَلَيْهَا أَوْضَاحٌ فَأَخَذَهَا يَهُودِيٌّ فَرَضَخَ رَأْسَهَا بِحَجَرٍ وَأَخَذَ مَا عَلَيْهَا مِنَ الْحُلِيِّ ‏.‏ قَالَ فَأُدْرِكَتْ وَبِهَا رَمَقٌ فَأُتِيَ بِهَا النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ مَنْ قَتَلَكِ أَفُلاَنٌ ‏"‏ ‏.‏ قَالَتْ بِرَأْسِهَا لاَ ‏.‏ قَالَ ‏"‏ فَفُلاَنٌ ‏"‏ ‏.‏ حَتَّى سُمِّيَ الْيَهُودِيُّ فَقَالَتْ بِرَأْسِهَا أَىْ نَعَمْ ‏.‏ قَالَ فَأُخِذَ فَاعْتَرَفَ فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَرُضِخَ رَأْسُهُ بَيْنَ حَجَرَيْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لاَ قَوَدَ إِلاَّ بِالسَّيْفِ ‏.‏\hadithno{1394}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas:that a girl went out in Al-Madinah wearing some silver ornaments. A Jew grabbed her and fractured her head with a stone, and he took the jewelry she had on. He said: "She was found with some spark of life in her, and was brought to the Prophet (ﷺ) and he said: 'Did such and such person strike you?' She nodded 'no' with her head. He said: 'Such and such?' until he named the Jew and she nodded 'yes' with her head." He said: "He was brought and recognized so the Messenger of Allah (ﷺ) ordered that his head be crushed between two stones}}
\hadithdefcmd{tirmidhi}{1395}{\hadithno{1395}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1396}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَوَّلَ مَا يُحْكَمُ بَيْنَ الْعِبَادِ فِي الدِّمَاءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَكَذَا رَوَى غَيْرُ وَاحِدٍ عَنِ الأَعْمَشِ مَرْفُوعًا وَرَوَى بَعْضُهُمْ عَنِ الأَعْمَشِ وَلَمْ يَرْفَعُوهُ ‏.‏\hadithno{1396}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah:that the Messenger of Allah (ﷺ) said: "Indeed the first cases to be judged between the people are those of bloodshed}}
\hadithdefcmd{tirmidhi}{1397}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَوَّلَ مَا يُقْضَى بَيْنَ الْعِبَادِ فِي الدِّمَاءِ ‏"‏ ‏.‏\hadithno{1397}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah narrated that the Messenger of Allah (ﷺ) said:"Indeed the first cases to be judged between the worshippers are those of bloodshed}}
\hadithdefcmd{tirmidhi}{1398}{حَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الْحُسَيْنِ بْنِ وَاقِدٍ، عَنْ يَزِيدَ الرَّقَاشِيِّ، حَدَّثَنَا أَبُو الْحَكَمِ الْبَجَلِيُّ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، وَأَبَا، هُرَيْرَةَ يَذْكُرَانِ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ أَنَّ أَهْلَ السَّمَاءِ وَأَهْلَ الأَرْضِ اشْتَرَكُوا فِي دَمِ مُؤْمِنٍ لأَكَبَّهُمُ اللَّهُ فِي النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏. ‏وَأَبُو الْحَكَمِ الْبَجَلِيُّ هُوَ عَبْدُ الرَّحْمَنِ بْنُ أَبِي نُعْمٍ الْكُوفِيُّ\hadithno{1398}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abul-Hakam Al-Bajali:"I heard Abu Sa'eed Al-Khudri and Abu Hurairah mentioning from the Messenger of Allah (ﷺ) that he said: 'If the inhabitants of the heavens and the inhabitants of the earth all took part in shedding the blood of believer, then Allah would cast them (all) in the Fire}}
\hadithdefcmd{tirmidhi}{1399}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا الْمُثَنَّى بْنُ الصَّبَّاحِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ سُرَاقَةَ بْنِ مَالِكِ بْنِ جُعْشُمٍ، قَالَ حَضَرْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُقِيدُ الأَبَ مِنِ ابْنِهِ وَلاَ يُقِيدُ الاِبْنَ مِنْ أَبِيهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ سُرَاقَةَ إِلاَّ مِنْ هَذَا الْوَجْهِ وَلَيْسَ إِسْنَادُهُ بِصَحِيحٍ رَوَاهُ إِسْمَاعِيلُ بْنُ عَيَّاشٍ عَنِ الْمُثَنَّى بْنِ الصَّبَّاحِ ‏.‏ وَالْمُثَنَّى بْنُ الصَّبَّاحِ يُضَعَّفُ فِي الْحَدِيثِ ‏.‏ وَقَدْ رَوَى هَذَا الْحَدِيثَ أَبُو خَالِدٍ الأَحْمَرُ عَنِ الْحَجَّاجِ بْنِ أَرْطَاةَ عَنْ عَمْرِو بْنِ شُعَيْبٍ عَنْ أَبِيهِ عَنْ جَدِّهِ عَنْ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَمْرِو بْنِ شُعَيْبٍ مُرْسَلاً وَهَذَا حَدِيثٌ فِيهِ اضْطِرَابٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّ الأَبَ إِذَا قَتَلَ ابْنَهُ لاَ يُقْتَلُ بِهِ وَإِذَا قَذَفَ ابْنَهُ لاَ يُحَدُّ ‏.‏\hadithno{1399}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Suraqah bin Malik bin [Ju'shum]:"The Messenger of Allah (ﷺ) judged that the son is to suffer retaliation for [killing] his father, but the father is not to suffer retaliation for [killing] his son}}
\hadithdefcmd{tirmidhi}{1400}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا الأَحْمَرُ، عَنِ الْحَجَّاجِ بْنِ أَرْطَاةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يُقَادُ الْوَالِدُ بِالْوَلَدِ ‏"‏ ‏.‏\hadithno{1400}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Umar bin Al-Khattab:that the Messenger of Allah (ﷺ) said: "The father does not suffer retaliation for [killing] the son}}
\hadithdefcmd{tirmidhi}{1401}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُقَامُ الْحُدُودُ فِي الْمَسَاجِدِ وَلاَ يُقْتَلُ الْوَالِدُ بِالْوَلَدِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ بِهَذَا الإِسْنَادِ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ إِسْمَاعِيلَ بْنِ مُسْلِمٍ ‏.‏ وَإِسْمَاعِيلُ بْنُ مُسْلِمٍ الْمَكِّيُّ قَدْ تَكَلَّمَ فِيهِ بَعْضُ أَهْلِ الْعِلْمِ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{1401}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:that the Prophet (ﷺ) said: 'The Hudud are not carried in the Masjid, and the father is not killed for the son}}
\hadithdefcmd{tirmidhi}{1402}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ دَمُ امْرِئٍ مُسْلِمٍ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ إِلاَّ بِإِحْدَى ثَلاَثٍ الثَّيِّبُ الزَّانِي وَالنَّفْسُ بِالنَّفْسِ وَالتَّارِكُ لِدِينِهِ الْمُفَارِقُ لِلْجَمَاعَةِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُثْمَانَ وَعَائِشَةَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ مَسْعُودٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1402}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah bin Mas'ud:that the Messenger of Allah (ﷺ) said: "The blood of a Muslim man, who testifies that none has the right to be worshipped Allah, is not lawful except for one of three cases: The (previously married or) married adulterer, a life for a life, and the one who leaves the religion and parts from the Jama'ah (the community of Muslims)}}
\hadithdefcmd{tirmidhi}{1403}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مَعْدِيُّ بْنُ سُلَيْمَانَ، هُوَ الْبَصْرِيُّ عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ مَنْ قَتَلَ نَفْسًا مُعَاهِدَةً لَهُ ذِمَّةُ اللَّهِ وَذِمَّةُ رَسُولِهِ فَقَدْ أَخْفَرَ بِذِمَّةِ اللَّهِ فَلاَ يَرَحْ رَائِحَةَ الْجَنَّةِ وَإِنَّ رِيحَهَا لَيُوجَدُ مِنْ مَسِيرَةِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي بَكْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1403}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah:that the Prophet (ﷺ) said: "Indeed, whoever kills a Mu'ahid that has a covenant from Allah and a covenant from His Messenger (ﷺ), then he has violated the covenant with Allah and the covenant of His Messenger, so he shall not smell the fragrance of Paradise; even though its fragrance can be sensed from the distance of seventy autumns}}
\hadithdefcmd{tirmidhi}{1404}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ أَبِي بَكْرِ بْنِ عَيَّاشٍ، عَنْ أَبِي سَعْدٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَدَى الْعَامِرِيَّيْنِ بِدِيَةِ الْمُسْلِمِينَ وَكَانَ لَهُمَا عَهْدٌ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأَبُو سَعْدٍ الْبَقَّالُ اسْمُهُ سَعِيدُ بْنُ الْمَرْزُبَانِ ‏.‏\hadithno{1404}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:"The Prophet (ﷺ) assigned the same blood-money for the two 'Amiris as that of the Muslims, and they had covenant from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{tirmidhi}{1405}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، وَيَحْيَى بْنُ مُوسَى، قَالاَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي أَبُو سَلَمَةَ، حَدَّثَنِي أَبُو هُرَيْرَةَ، قَالَ لَمَّا فَتَحَ اللَّهُ عَلَى رَسُولِهِ مَكَّةَ قَامَ فِي النَّاسِ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏ "‏ وَمَنْ قُتِلَ لَهُ قَتِيلٌ فَهُوَ بِخَيْرِ النَّظَرَيْنِ إِمَّا أَنْ يَعْفُوَ وَإِمَّا أَنْ يَقْتُلَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ وَائِلِ بْنِ حُجْرٍ وَأَنَسٍ وَأَبِي شُرَيْحٍ خُوَيْلِدِ بْنِ عَمْرٍو ‏.‏\hadithno{1405}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah:"When Allah granted His Messenger (ﷺ) victory over Makkah, he stood (to deliver an address) among the people. He thanked and praised Allah, then he said: 'And from whomever (one of his relatives) was killed, then he has two options to choose from: Either to pardon or that he be killed}}
\hadithdefcmd{tirmidhi}{1406}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ الْمَقْبُرِيُّ، عَنْ أَبِي شُرَيْحٍ الْكَعْبِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ اللَّهَ حَرَّمَ مَكَّةَ وَلَمْ يُحَرِّمْهَا النَّاسُ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلاَ يَسْفِكَنَّ فِيهَا دَمًا وَلاَ يَعْضِدَنَّ فِيهَا شَجَرًا فَإِنْ تَرَخَّصَ مُتَرَخِّصٌ فَقَالَ أُحِلَّتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَإِنَّ اللَّهَ أَحَلَّهَا لِي وَلَمْ يُحِلَّهَا لِلنَّاسِ وَإِنَّمَا أُحِلَّتْ لِي سَاعَةً مِنْ نَهَارٍ ثُمَّ هِيَ حَرَامٌ إِلَى يَوْمِ الْقِيَامَةِ ثُمَّ إِنَّكُمْ مَعْشَرَ خُزَاعَةَ قَتَلْتُمْ هَذَا الرَّجُلَ مِنْ هُذَيْلٍ وَإِنِّي عَاقِلُهُ فَمَنْ قُتِلَ لَهُ قَتِيلٌ بَعْدَ الْيَوْمِ فَأَهْلُهُ بَيْنَ خِيرَتَيْنِ إِمَّا أَنْ يَقْتُلُوا أَوْ يَأْخُذُوا الْعَقْلَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَحَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ وَرَوَاهُ شَيْبَانُ أَيْضًا عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ مِثْلَ هَذَا ‏.‏ - وَرُوِيَ عَنْ أَبِي شُرَيْحٍ الْخُزَاعِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ قُتِلَ لَهُ قَتِيلٌ فَلَهُ أَنْ يَقْتُلَ أَوْ يَعْفُوَ أَوْ يَأْخُذَ الدِّيَةَ ‏"‏ ‏.‏ وَذَهَبَ إِلَى هَذَا بَعْضُ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1406}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Shuraih Al-Ka'bi:that the Messenger of Allah (ﷺ) said: "Indeed Allah made Makkah sacred, it was not made sacred by the people. Whoever believes in Allah, and the Last Day, then let them not shed blood in it, nor cut down any of its trees. If one tries to make an excuse by saying: 'It was made lawful for the Messenger of Allah (ﷺ)' then indeed Allah made it lawful for me but He did not make it lawful for the people, and it was only made lawful for me for an hour of a day. Then it is returned to being sacred until the Day of Judgement. Then, to you people of Khuza'ah who killed this man from Hudhail: I am his 'Aqil, so whomever (one of his relatives) is killed after today, then his people have two options; either they have him killed, or they take the blood-money from him}}
\hadithdefcmd{tirmidhi}{1407}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قُتِلَ رَجُلٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَدُفِعَ الْقَاتِلُ إِلَى وَلِيِّهِ فَقَالَ الْقَاتِلُ يَا رَسُولَ اللَّهِ وَاللَّهِ مَا أَرَدْتُ قَتْلَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَمَا إِنَّهُ إِنْ كَانَ صَادِقًا فَقَتَلْتَهُ دَخَلْتَ النَّارَ ‏"‏ ‏.‏ فَخَلَّى عَنْهُ الرَّجُلُ ‏.‏ قَالَ وَكَانَ مَكْتُوفًا بِنِسْعَةٍ ‏.‏ قَالَ فَخَرَجَ يَجُرُّ نِسْعَتَهُ ‏.‏ قَالَ فَكَانَ يُسَمَّى ذَا النِّسْعَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالنِّسْعَةُ حَبْلٌ ‏.‏\hadithno{1407}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah:"A man was killed during the time of the Messenger of Allah (ﷺ), so the killer was brought to the man's guardian. The killer said: 'O Messenger of Allah! By Allah! I did not mean to kill him.' So the Messenger of Allah (ﷺ) said: 'Then if what he is saying is true, and you kill him, you would enter the Fire.' So he let the man go." He said: "His hands were bound behind him with a Nis'ah." He said: "So he left, dragging his Nis'ah." [He said:] "So he was called Dhan-Nis'ah}}
\hadithdefcmd{tirmidhi}{1408}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا بَعَثَ أَمِيرًا عَلَى جَيْشٍ أَوْصَاهُ فِي خَاصَّةِ نَفْسِهِ بِتَقْوَى اللَّهِ وَمَنْ مَعَهُ مِنَ الْمُسْلِمِينَ خَيْرًا فَقَالَ ‏ "‏ اغْزُوا بِسْمِ اللَّهِ وَفِي سَبِيلِ اللَّهِ قَاتِلُوا مَنْ كَفَرَ بِاللَّهِ اغْزُوا وَلاَ تَغُلُّوا وَلاَ تَغْدِرُوا وَلاَ تُمَثِّلُوا وَلاَ تَقْتُلُوا وَلِيدًا ‏"‏ ‏.‏ وَفِي الْحَدِيثِ قِصَّةٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَشَدَّادِ بْنِ أَوْسٍ وَعِمْرَانَ بْنِ حُصَيْنٍ وَأَنَسٍ وَسَمُرَةَ وَالْمُغِيرَةِ وَيَعْلَى بْنِ مُرَّةَ وَأَبِي أَيُّوبَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ بُرَيْدَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَكَرِهَ أَهْلُ الْعِلْمِ الْمُثْلَةَ ‏.‏\hadithno{1408}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Buraidah:from his father who said: "Whenever the Messenger of Allah (ﷺ) dispatched a commander of an army he would exhort him personally; that he should have Taqwa of Allah, and regarding those of the Muslims who are with him; that he should be good to them. He would say: 'Fight in the Name of Allah and in Allah's curse. Fight those who disbelieve in Allah and fight, do not be treacherous, nor mutilate, nor kill a child}}
\hadithdefcmd{tirmidhi}{1409}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، عَنْ شَدَّادِ بْنِ أَوْسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ كَتَبَ الإِحْسَانَ عَلَى كُلِّ شَيْءٍ فَإِذَا قَتَلْتُمْ فَأَحْسِنُوا الْقِتْلَةَ وَإِذَا ذَبَحْتُمْ فَأَحْسِنُوا الذِّبْحَةَ وَلْيُحِدَّ أَحَدُكُمْ شَفْرَتَهُ وَلْيُرِحْ ذَبِيحَتَهُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ أَبُو الأَشْعَثِ الصَّنْعَانِيُّ اسْمُهُ شُرَحْبِيلُ بْنُ آدَةَ ‏.‏\hadithno{1409}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Shaddad bin Aws:that the Prophet (ﷺ) said: "Indeed Allah has decreed Ihsan in everything. So when you kill, then do the killing well, and when you slaughter, then do the slaughtering well. Let one of you sharpen his blade, and let him comfort his animal (before slaughtering)}}
\hadithdefcmd{tirmidhi}{1410}{حَدَّثَنَا عَلِيُّ بْنُ سَعِيدٍ الْكِنْدِيُّ الْكُوفِيُّ، حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْجَنِينِ بِغُرَّةٍ عَبْدٍ أَوْ أَمَةٍ ‏.‏ فَقَالَ الَّذِي قُضِيَ عَلَيْهِ أَنُعْطِي مَنْ لاَ شَرِبَ وَلاَ أَكَلَ وَلاَ صَاحَ فَاسْتَهَلَّ فَمِثْلُ ذَلِكَ يُطَلُّ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ هَذَا لَيَقُولُ بِقَوْلِ شَاعِرٍ بَلْ فِيهِ غُرَّةٌ عَبْدٌ أَوْ أَمَةٌ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ حَمَلِ بْنِ مَالِكِ بْنِ النَّابِغَةِ وَالْمُغِيرَةِ بْنِ شُعْبَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ وَقَالَ بَعْضُهُمُ الْغُرَّةُ عَبْدٌ أَوْ أَمَةٌ أَوْ خَمْسُمِائَةِ دِرْهَمٍ ‏.‏ وَقَالَ بَعْضُهُمْ أَوْ فَرَسٌ أَوْ بَغْلٌ ‏.‏\hadithno{1410}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah:"The Messenger of Allah (ﷺ) judged that a Ghurrah male slave or female slave be given in the case of a fetus. The one of the judgement was made against said: 'Should we give something for one who did not drink, not eat, nor cry out to shed a tear, the likes of which is useless?' So the Prophet (ﷺ) said: 'This is the speech of a poet. Rather it requires a Ghurrah: a male slave or a female slave}}
\hadithdefcmd{tirmidhi}{1411}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عُبَيْدِ بْنِ نَضْلَةَ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَنَّ امْرَأَتَيْنِ، كَانَتَا ضَرَّتَيْنِ فَرَمَتْ إِحْدَاهُمَا الأُخْرَى بِحَجَرٍ أَوْ عَمُودِ فُسْطَاطٍ فَأَلْقَتْ جَنِينَهَا فَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْجَنِينِ غُرَّةٌ عَبْدٌ أَوْ أَمَةٌ وَجَعَلَهُ عَلَى عَصَبَةِ الْمَرْأَةِ ‏.‏ قَالَ الْحَسَنُ وَأَخْبَرَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، بِهَذَا الْحَدِيثِ نَحْوَهُ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1411}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Al-Mughirah bin Shu'bah:"Two women co-wives, (were fighting), and one of them hit the other with a stone or a tent post, causing her to have a miscarriage. The Messenger of Allah (ﷺ) judged that a Ghurrah male or female slave should be given for fetus, and he required it from the Asabah of the woman." (Another Chain) for this Hadith [and it is similar to this]}}
\hadithdefcmd{tirmidhi}{1412}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَنْبَأَنَا مُطَرِّفٌ، عَنِ الشَّعْبِيِّ، حَدَّثَنَا أَبُو جُحَيْفَةَ، قَالَ قُلْتُ لِعَلِيٍّ يَا أَمِيرَ الْمُؤْمِنِينَ هَلْ عِنْدَكُمْ سَوْدَاءُ فِي بَيْضَاءَ لَيْسَ فِي كِتَابِ اللَّهِ قَالَ لاَ وَالَّذِي فَلَقَ الْحَبَّةَ وَبَرَأَ النَّسَمَةَ مَا عَلِمْتُهُ إِلاَّ فَهْمًا يُعْطِيهِ اللَّهُ رَجُلاً فِي الْقُرْآنِ وَمَا فِي الصَّحِيفَةِ ‏.‏ قُلْتُ وَمَا فِي الصَّحِيفَةِ قَالَ فِيهَا الْعَقْلُ وَفِكَاكُ الأَسِيرِ وَأَنْ لاَ يُقْتَلَ مُؤْمِنٌ بِكَافِرٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكِ بْنِ أَنَسٍ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ قَالُوا لاَ يُقْتَلُ مُؤْمِنٌ بِكَافِرٍ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ يُقْتَلُ الْمُسْلِمُ بِالْمُعَاهِدِ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏\hadithno{1412}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Juhaifah said:"I said to 'Ali: O Commander of the Believers! Do you have anything written that is not in Allah's Book?' He said: 'By the One Who splits the seed and creates the soul, I have not learned from it except what understanding of the Qur'an Allah gives to a man, and what is in this sheet of paper.' I said: 'What is in the paper?' He said: 'It is the 'Aql, the (ransom for) release of captives, and the judgement that no believer is killed for a disbeliever}}
\hadithdefcmd{tirmidhi}{1413}{حَدَّثَنَا عِيسَى بْنُ أَحْمَدَ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يُقْتَلُ مُسْلِمٌ بِكَافِرٍ ‏"‏ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ دِيَةُ عَقْلِ الْكَافِرِ نِصْفُ دِيَةِ عَقْلِ الْمُؤْمِنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ عَمْرٍو فِي هَذَا الْبَابِ حَدِيثٌ حَسَنٌ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي دِيَةِ الْيَهُودِيِّ وَالنَّصْرَانِيِّ فَذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ فِي دِيَةِ الْيَهُودِيِّ وَالنَّصْرَانِيِّ إِلَى مَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَقَالَ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ دِيَةُ الْيَهُودِيِّ وَالنَّصْرَانِيِّ نِصْفُ دِيَةِ الْمُسْلِمِ ‏.‏ وَبِهَذَا يَقُولُ أَحْمَدُ بْنُ حَنْبَلٍ وَرُوِيَ عَنْ عُمَرَ بْنِ الْخَطَّابِ أَنَّهُ قَالَ دِيَةُ الْيَهُودِيِّ وَالنَّصْرَانِيِّ أَرْبَعَةُ آلاَفِ دِرْهَمٍ وَدِيَةُ الْمَجُوسِيِّ ثَمَانُمِائَةِ دِرْهَمٍ ‏.‏ وَبِهَذَا يَقُولُ مَالِكُ بْنُ أَنَسٍ وَالشَّافِعِيُّ وَإِسْحَاقُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ دِيَةُ الْيَهُودِيِّ وَالنَّصْرَانِيِّ مِثْلُ دِيَةِ الْمُسْلِمِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏\hadithno{1413}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Amr bin Shu'aib:from his father, from his grandfather that the Messenger of Allah (ﷺ) said: "The Muslim is not killed for disbeliever." And with this chain, it has been narrated that the Prophet (ﷺ) said: "The blood-money paid for disbeliever is half of the blood-money paid for a believer}}
\hadithdefcmd{tirmidhi}{1414}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَتَلَ عَبْدَهُ قَتَلْنَاهُ وَمَنْ جَدَعَ عَبْدَهُ جَدَعْنَاهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ مِنَ التَّابِعِينَ مِنْهُمْ إِبْرَاهِيمُ النَّخَعِيُّ إِلَى هَذَا وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْهُمُ الْحَسَنُ الْبَصْرِيُّ وَعَطَاءُ بْنُ أَبِي رَبَاحٍ لَيْسَ بَيْنَ الْحُرِّ وَالْعَبْدِ قِصَاصٌ فِي النَّفْسِ وَلاَ فِيمَا دُونَ النَّفْسِ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُهُمْ إِذَا قَتَلَ عَبْدَهُ لاَ يُقْتَلُ بِهِ وَإِذَا قَتَلَ عَبْدَ غَيْرِهِ قُتِلَ بِهِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏\hadithno{1414}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Samurah:that the Messenger of Allah (ﷺ) said: "Whoever kills his slave, then we will kill him, and whoever maims his slave, then we will maim him}}
\hadithdefcmd{tirmidhi}{1415}{حَدَّثَنَا قُتَيْبَةُ، وَأَحْمَدُ بْنُ مَنِيعٍ، وَأَبُو عَمَّارٍ وَغَيْرُ وَاحِدٍ قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ عُمَرَ، كَانَ يَقُولُ الدِّيَةُ عَلَى الْعَاقِلَةِ وَلاَ تَرِثُ الْمَرْأَةُ مِنْ دِيَةِ زَوْجِهَا شَيْئًا ‏.‏ حَتَّى أَخْبَرَهُ الضَّحَّاكُ بْنُ سُفْيَانَ الْكِلاَبِيُّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَتَبَ إِلَيْهِ ‏ "‏ أَنْ وَرِّثِ امْرَأَةَ أَشْيَمَ الضِّبَابِيِّ مِنْ دِيَةِ زَوْجِهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{1415}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Sa'eed bin Al-Musayyab:that 'Umar would say: "The blood-money upon the tribe, and the wife does not inherit any of her husband's blood-money." Until Ad-Dahhak bin Sufyan Al-Kulabi informed him that the Messenger of Allah (ﷺ) wrote to me, that Ashaim Ad-Dibabi's wife inherited the blood-money of her husband}}
\hadithdefcmd{tirmidhi}{1416}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَنْبَأَنَا عِيسَى بْنُ يُونُسَ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ زُرَارَةَ بْنَ أَوْفَى، يُحَدِّثُ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَجُلاً، عَضَّ يَدَ رَجُلٍ فَنَزَعَ يَدَهُ فَوَقَعَتْ ثَنِيَّتَاهُ فَاخْتَصَمُوا إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ يَعَضُّ أَحَدُكُمْ أَخَاهُ كَمَا يَعَضُّ الْفَحْلُ لاَ دِيَةَ لَكَ ‏"‏ ‏.‏ فَأَنْزَلَ اللَّهُ ‏(‏وَالْجُرُوحَ قِصَاصٌ ‏)‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ يَعْلَى بْنِ أُمَيَّةَ وَسَلَمَةَ بْنِ أُمَيَّةَ وَهُمَا أَخَوَانِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عِمْرَانَ بْنِ حُصَيْنٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1416}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Imran bin Husain:"A man bit the hand of another man. The man who was bitten pulled his hand out, causing two of his incisors (teeth) to fall out. They brought their case of the Prophet (ﷺ). So he said: "One of you bites his brother like the stallion bites? There is no blood-money for you.' So Allah Most High revealed: Wounds, equal for equal}}
\hadithdefcmd{tirmidhi}{1417}{حَدَّثَنَا عَلِيُّ بْنُ سَعِيدٍ الْكِنْدِيُّ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنْ بَهْزِ بْنِ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم حَبَسَ رَجُلاً فِي تُهْمَةٍ ثُمَّ خَلَّى عَنْهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ بَهْزٍ عَنْ أَبِيهِ عَنْ جَدِّهِ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَى إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ عَنْ بَهْزِ بْنِ حَكِيمٍ هَذَا الْحَدِيثَ أَتَمَّ مِنْ هَذَا وَأَطْوَلَ ‏.‏\hadithno{1417}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Bahz bin Hakim:from his father, from his grandfather, that the Prophet (ﷺ) imprisoned a man for an accusation, then he let him go}}
\hadithdefcmd{tirmidhi}{1418}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، وَحَاتِمُ بْنُ سِيَاهٍ الْمَرْوَزِيُّ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ بْنِ عَوْفٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَمْرِو بْنِ سَهْلٍ، عَنْ سَعِيدِ بْنِ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ قُتِلَ دُونَ مَالِهِ فَهُوَ شَهِيدٌ وَمَنْ سَرَقَ مِنَ الأَرْضِ شِبْرًا طُوِّقَهُ يَوْمَ الْقِيَامَةِ مِنْ سَبْعِ أَرَضِينَ ‏"‏ ‏.‏ وَزَادَ حَاتِمُ بْنُ سِيَاهٍ الْمَرْوَزِيُّ فِي هَذَا الْحَدِيثِ قَالَ مَعْمَرٌ بَلَغَنِي عَنِ الزُّهْرِيِّ وَلَمْ أَسْمَعْ مِنْهُ زَادَ فِي هَذَا الْحَدِيثِ ‏"‏ مَنْ قُتِلَ دُونَ مَالِهِ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏ وَهَكَذَا رَوَى شُعَيْبُ بْنُ أَبِي حَمْزَةَ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَمْرِو بْنِ سَهْلٍ عَنْ سَعِيدِ بْنِ زَيْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَى سُفْيَانُ بْنُ عُيَيْنَةَ عَنِ الزُّهْرِيِّ عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ عَنْ سَعِيدِ بْنِ زَيْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَذْكُرْ فِيهِ سُفْيَانُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَمْرِو بْنِ سَهْلٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1418}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Sa'eed bin Zaid bin 'Amr bin Nufail:that the Prophet (ﷺ) said: "Whoever is killed over his wealth then he is a martyr. [And whoever steals a hand-span of land, he will bear seven earths on the Day of Resurrection]}}
\hadithdefcmd{tirmidhi}{1419}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُطَّلِبِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَسَنِ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ طَلْحَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قُتِلَ دُونَ مَالِهِ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَسَعِيدِ بْنِ زَيْدٍ وَأَبِي هُرَيْرَةَ وَابْنِ عُمَرَ وَابْنِ عَبَّاسٍ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ عَمْرٍو حَدِيثٌ حَسَنٌ وَقَدْ رُوِيَ عَنْهُ مِنْ غَيْرِ وَجْهٍ ‏.‏ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ لِلرَّجُلِ أَنْ يُقَاتِلَ عَنْ نَفْسِهِ وَمَالِهِ ‏.‏ وَقَالَ ابْنُ الْمُبَارَكِ يُقَاتِلُ عَنْ مَالِهِ وَلَوْ دِرْهَمَيْنِ ‏.‏\hadithno{1419}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Abdullah bin 'Amr:that the Prophet (ﷺ) said: "Whoever is killed over his wealth, then he is martyr}}
\hadithdefcmd{tirmidhi}{1420}{\hadithno{1420}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1421}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، قَالَ أَخْبَرَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ أَبِيهِ، عَنْ أَبِي عُبَيْدَةَ بْنِ مُحَمَّدِ بْنِ عَمَّارِ بْنِ يَاسِرٍ، عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ بْنِ عَوْفٍ، عَنْ سَعِيدِ بْنِ زَيْدٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ قُتِلَ دُونَ مَالِهِ فَهُوَ شَهِيدٌ وَمَنْ قُتِلَ دُونَ دِينِهِ فَهُوَ شَهِيدٌ وَمَنْ قُتِلَ دُونَ دَمِهِ فَهُوَ شَهِيدٌ وَمَنْ قُتِلَ دُونَ أَهْلِهِ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَهَكَذَا رَوَى غَيْرُ وَاحِدٍ عَنْ إِبْرَاهِيمَ بْنِ سَعْدٍ نَحْوَ هَذَا ‏.‏ وَيَعْقُوبُ هُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدِ بْنِ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ الزُّهْرِيُّ ‏.‏\hadithno{1421}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Zaid:that he heard the Messenger of Allah (ﷺ) saying: "Whoever is killed over his wealth then he is a martyr, and whoever is killed over his religion, then he is a martyr, and whoever is killed over his blood, then he is martyr, and whoever is killed over his family, then he is martyr}}
\hadithdefcmd{tirmidhi}{1422}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، قَالَ يَحْيَى وَحَسِبْتُ عَنْ رَافِعِ بْنِ خَدِيجٍ، أَنَّهُمَا قَالاَ خَرَجَ عَبْدُ اللَّهِ بْنُ سَهْلِ بْنِ زَيْدٍ وَمُحَيِّصَةُ بْنُ مَسْعُودِ بْنِ زَيْدٍ حَتَّى إِذَا كَانَا بِخَيْبَرَ تَفَرَّقَا فِي بَعْضِ مَا هُنَاكَ ثُمَّ إِنَّ مُحَيِّصَةَ وَجَدَ عَبْدَ اللَّهِ بْنَ سَهْلٍ قَتِيلاً قَدْ قُتِلَ فَدَفَنَهُ ثُمَّ أَقْبَلَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم هُوَ وَحُوَيِّصَةُ بْنُ مَسْعُودٍ وَعَبْدُ الرَّحْمَنِ بْنُ سَهْلٍ وَكَانَ أَصْغَرَ الْقَوْمِ ذَهَبَ عَبْدُ الرَّحْمَنِ لِيَتَكَلَّمَ قَبْلَ صَاحِبَيْهِ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَبِّرِ الْكُبْرَ ‏"‏ ‏.‏ فَصَمَتَ وَتَكَلَّمَ صَاحِبَاهُ ثُمَّ تَكَلَّمَ مَعَهُمَا فَذَكَرُوا لِرَسُولِ اللَّهِ صلى الله عليه وسلم مَقْتَلَ عَبْدِ اللَّهِ بْنِ سَهْلٍ فَقَالَ لَهُمْ ‏"‏ أَتَحْلِفُونَ خَمْسِينَ يَمِينًا فَتَسْتَحِقُّونَ صَاحِبَكُمْ أَوْ قَاتِلَكُمْ ‏"‏ ‏.‏ قَالُوا وَكَيْفَ نَحْلِفُ وَلَمْ نَشْهَدْ قَالَ ‏"‏ فَتُبَرِّئُكُمْ يَهُودُ بِخَمْسِينَ يَمِينًا ‏"‏ ‏.‏ قَالُوا وَكَيْفَ نَقْبَلُ أَيْمَانَ قَوْمٍ كُفَّارٍ فَلَمَّا رَأَى ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَعْطَى عَقْلَهُ ‏.‏ حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، وَرَافِعِ بْنِ خَدِيجٍ، نَحْوَ هَذَا الْحَدِيثِ بِمَعْنَاهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ فِي الْقَسَامَةِ وَقَدْ رَأَى بَعْضُ فُقَهَاءِ الْمَدِينَةِ الْقَوَدَ بِالْقَسَامَةِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَهْلِ الْكُوفَةِ وَغَيْرِهِمْ إِنَّ الْقَسَامَةَ لاَ تُوجِبُ الْقَوَدَ وَإِنَّمَا تُوجِبُ الدِّيَةَ ‏.‏ آخِرُ أَبْوَابِ الدِّيَاتِ وَالْحَمْدُ لِلَّهِ ‏.‏\hadithno{1422}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Sahl bin Abi Hatamah:Yahya (one of the narrators) said: And I think it was from Rafi' bin Khadij - that 'Abdullah bin Sahl bin Zaid and Muhaiysah bin Mas'ud bin Zaid went out and when they reached Khaibar they separated while there. Then Muhayyisah found 'Abdullah bin Sahl murdered [so he buried him]. Then he went to the Messenger of Allah (ﷺ) along with Huwayyisah bin Mas'ud and Abdur-Rahman bin Sahl. The youngest of the people, Abdur-Rahman, went to speak ahead of his companions. The Messenger of Allah (ﷺ) said to him: "Let the eldest of you speak." So he was silent and two companions spoke. So he conversed with them and they mentioned to the Messenger of Allah (ﷺ) about the murder of 'Abdullah bin Sahl. He said to them: "If fifty of you can swear an oath then you will have the right against the murderer." They said: "How can we take an oath when we did not witness it?" He said: "Then fifty of Jews can swear to clear the charge with you?" They said: "How could we accept the oaths of a disbelieving people?" So when he saw that, the Messenger of Allah (ﷺ) paid the blood-money." (Another Chain) from Sahl bin Abi Hathman and Rafi' bin Khadij, and the meaning is similar to this Hadith}}
