% Auto-generated chapter 52 for malik
% Hadiths in this chapter: 8

\hadithdefcmd{malik}{1747}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ الأَنْصَارِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الرُّؤْيَا الْحَسَنَةُ مِنَ الرَّجُلِ الصَّالِحِ جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏ وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِثْلِ ذَلِكَ ‏.‏\hadithno{1747}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ishaq ibn Abdullah ibn Abi Talha al-Ansari from Anas ibn Malik that the Messenger of Allah, may Allah bless him and grant him peace, said, "The good dream of a man who is salih is a forty-sixth part of prophecy." Yahya related the like of that to me from Malik from Abu'z-Zinad from al- Araj from Abu Hurayra from the Messenger of Allah, may Allah bless him and grant him peace}}
\hadithdefcmd{malik}{1749}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ زُفَرَ بْنِ صَعْصَعَةَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا انْصَرَفَ مِنْ صَلاَةِ الْغَدَاةِ يَقُولُ ‏"‏ هَلْ رَأَى أَحَدٌ مِنْكُمُ اللَّيْلَةَ رُؤْيَا ‏"‏ ‏.‏ وَيَقُولُ ‏"‏ لَيْسَ يَبْقَى بَعْدِي مِنَ النُّبُوَّةِ إِلاَّ الرُّؤْيَا الصَّالِحَةُ ‏"‏ ‏.‏\hadithno{1749}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ishaq ibn Abdullah ibn Abi Talha from Zufar ibn Sasaca from his father from Abu Hurayra that when the Messenger of Allah, may Allah bless him and grant him peace, left the morning prayer, he would say, "Has any of you had a dream last night? All that will remain of prophecy after me will be the true dream}}
\hadithdefcmd{malik}{1750}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَنْ يَبْقَى بَعْدِي مِنَ النُّبُوَّةِ إِلاَّ الْمُبَشِّرَاتُ ‏"‏ ‏.‏ فَقَالُوا وَمَا الْمُبَشِّرَاتُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الرُّؤْيَا الصَّالِحَةُ يَرَاهَا الرَّجُلُ الصَّالِحُ أَوْ تُرَى لَهُ جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{1750}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar that the Messenger of Allah, may Allah bless him and grant him peace, said, "All that will be left of prophecy after me are the mubashshirat." They said, "What are the mubashshirat, Messenger of Allah?" He said, "The true dream which a man who is salih sees - or which is shown to him - is a forty-sixth part of prophecy}}
\hadithdefcmd{malik}{1751}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ قَالَ سَمِعْتُ أَبَا قَتَادَةَ بْنَ رِبْعِيٍّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الرُّؤْيَا الصَّالِحَةُ مِنَ اللَّهِ وَالْحُلْمُ مِنَ الشَّيْطَانِ فَإِذَا رَأَى أَحَدُكُمُ الشَّىْءَ يَكْرَهُهُ فَلْيَنْفُثْ عَنْ يَسَارِهِ ثَلاَثَ مَرَّاتٍ إِذَا اسْتَيْقَظَ وَلْيَتَعَوَّذْ بِاللَّهِ مِنْ شَرِّهَا فَإِنَّهَا لَنْ تَضُرَّهُ إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏ قَالَ أَبُو سَلَمَةَ إِنْ كُنْتُ لأَرَى الرُّؤْيَا هِيَ أَثْقَلُ عَلَىَّ مِنَ الْجَبَلِ فَلَمَّا سَمِعْتُ هَذَا الْحَدِيثَ فَمَا كُنْتُ أُبَالِيهَا ‏.‏\hadithno{1751}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Abu Salama ibn Abd ar-Rahman said, "I heard Abu Qatada ibn Ribiyy say that he heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'The good dream is from Allah, and the bad dream is from shaytan. When you see what you dislike, spit to your left side three times when you wake up, and seek refuge with Allah from its evil. It will not harm you then, Allah willing.' " Abu Salama said, "I would see dreams which weighed on me more heavily than a mountain. When I heard this hadith, I was not concerned about it}}
\hadithdefcmd{malik}{1752}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَقُولُ فِي هَذِهِ الآيَةِ ‏\{‏لَهُمُ الْبُشْرَى فِي الْحَيَاةِ الدُّنْيَا وَفِي الآخِرَةِ‏\}‏ ‏.‏ قَالَ هِيَ الرُّؤْيَا الصَّالِحَةُ يَرَاهَا الرَّجُلُ الصَّالِحُ أَوْ تُرَى لَهُ ‏.‏\hadithno{1752}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said about this ayat, "You have good news in the life of this world and the next world," (Sura 10 ayat 64), that it was the good dream which the man who was salih saw or which was shown to him}}
\hadithdefcmd{malik}{1753}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُوسَى بْنِ مَيْسَرَةَ، عَنْ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَعِبَ بِالنَّرْدِ فَقَدْ عَصَى اللَّهَ وَرَسُولَهُ ‏"‏ ‏.‏\hadithno{1753}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik from Musa ibn Maysara from Said ibn Abi Hind from Abu Musa al-Ashari that the Messenger of Allah, may Allah bless him and grant him peace, said, "Whoever plays games of dice has disobeyed Allah and His Messenger}}
\hadithdefcmd{malik}{1754}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَلْقَمَةَ بْنِ أَبِي عَلْقَمَةَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ بَلَغَهَا أَنَّ أَهْلَ بَيْتٍ فِي دَارِهَا كَانُوا سُكَّانًا فِيهَا وَعِنْدَهُمْ نَرْدٌ فَأَرْسَلَتْ إِلَيْهِمْ لَئِنْ لَمْ تُخْرِجُوهَا لأُخْرِجَنَّكُمْ مِنْ دَارِي وَأَنْكَرَتْ ذَلِكَ عَلَيْهِمْ ‏.‏\hadithno{1754}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Yahya related to me from Malik from Alqama from his mother that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, heard that the people who lived in a room in her house had some dice. She sent a message to them, "If you do not remove them, I will remove you from my house," and she reproached them for it}}
\hadithdefcmd{malik}{1755}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ إِذَا وَجَدَ أَحَدًا مِنْ أَهْلِهِ يَلْعَبُ بِالنَّرْدِ ضَرَبَهُ وَكَسَرَهَا ‏.‏ قَالَ يَحْيَى وَسَمِعْتُ مَالِكًا يَقُولُ لاَ خَيْرَ فِي الشَّطْرَنْجِ ‏.‏ وَكَرِهَهَا وَسَمِعْتُهُ يَكْرَهُ اللَّعِبَ بِهَا وَبِغَيْرِهَا مِنَ الْبَاطِلِ وَيَتْلُو هَذِهِ الآيَةَ ‏\{‏فَمَاذَا بَعْدَ الْحَقِّ إِلاَّ الضَّلاَلُ ‏\}‏‏.‏\hadithno{1755}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that when he found one of his family playing dice he beat him and destroyed the dice. Yahya said that he heard Malik say, "There is no good in chess, and he disapproved of it." Yahya said, "I heard him disapprove of playing it and other worthless games. He recited this ayat, 'What is there after the truth except going the wrong way.' " (Sura l0 ayat)}}
