% Auto-generated chapter 30 for malik
% Hadiths in this chapter: 18

\hadithdefcmd{malik}{1272}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ، أَخْبَرَتْهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عِنْدَهَا وَأَنَّهَا سَمِعَتْ صَوْتَ رَجُلٍ يَسْتَأْذِنُ فِي بَيْتِ حَفْصَةَ قَالَتْ عَائِشَةُ فَقُلْتُ يَا رَسُولَ اللَّهِ هَذَا رَجُلٌ يَسْتَأْذِنُ فِي بَيْتِكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أُرَاهُ فُلاَنًا ‏"‏ ‏.‏ لِعَمٍّ لِحَفْصَةَ مِنَ الرَّضَاعَةِ ‏.‏ فَقَالَتْ عَائِشَةُ يَا رَسُولَ اللَّهِ لَوْ كَانَ فُلاَنٌ حَيًّا - لِعَمِّهَا مِنَ الرَّضَاعَةِ - دَخَلَ عَلَىَّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ إِنَّ الرَّضَاعَةَ تُحَرِّمُ مَا تُحَرِّمُ الْوِلاَدَةُ ‏"‏ ‏.‏\hadithno{1272}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr from Amra bint Abd ar-Rahman that A'isha, umm al-muminin informed her that the Messenger of Allah, may Allah bless him and grant him peace, was with her and she heard the voice of a man asking permission to enter the room of Hafsa. A'isha said that she had said, "Messenger of Allah! There is a man asking permission to enter your house!" The Messenger of Allah, may Allah bless him and grant him peace, said, "I think it is so-and-so" (referring to a paternal uncle of Hafsa by suckling). A'isha said, "Messenger of Allah! If so-and-so were alive (referring to her paternal uncle by suckling) could he enter where I am?" The Messenger of Allah, may Allah bless him and grant him peace, said, "Yes. Suckling makes haram as birth makes haram}}
\hadithdefcmd{malik}{1273}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا قَالَتْ جَاءَ عَمِّي مِنَ الرَّضَاعَةِ يَسْتَأْذِنُ عَلَىَّ فَأَبَيْتُ أَنْ آذَنَ لَهُ عَلَىَّ حَتَّى أَسْأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَأَلْتُهُ عَنْ ذَلِكَ فَقَالَ ‏"‏ إِنَّهُ عَمُّكِ فَأْذَنِي لَهُ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّمَا أَرْضَعَتْنِي الْمَرْأَةُ وَلَمْ يُرْضِعْنِي الرَّجُلُ ‏.‏ فَقَالَ ‏"‏ إِنَّهُ عَمُّكِ فَلْيَلِجْ عَلَيْكِ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ وَذَلِكَ بَعْدَ مَا ضُرِبَ عَلَيْنَا الْحِجَابُ ‏.‏ وَقَالَتْ عَائِشَةُ يَحْرُمُ مِنَ الرَّضَاعَةِ مَا يَحْرُمُ مِنَ الْوِلاَدَةِ ‏.‏\hadithno{1273}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that A'isha, umm al-muminin said, "My paternal uncle by suckling came to me and I refused to give him permission to enter until I had asked the Messenger of Allah, may Allah bless him and grant him peace, about it. The Messenger of Allah, may Allah bless him and grant him peace, came and I asked him about it. He said, 'He is your paternal uncle, so give him permission.' So I said, 'Messenger of Allah! The woman nursed me not the man.' He said, 'He is your paternal uncle, so let him enter.' " A'isha said, "That was after the veil had been imposed on us." A'isha added, "What is haram by birth is made haram by suckling}}
\hadithdefcmd{malik}{1274}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا أَخْبَرَتْهُ أَنَّ أَفْلَحَ أَخَا أَبِي الْقُعَيْسِ جَاءَ يَسْتَأْذِنُ عَلَيْهَا وَهُوَ عَمُّهَا مِنَ الرَّضَاعَةِ بَعْدَ أَنْ أُنْزِلَ الْحِجَابُ قَالَتْ فَأَبَيْتُ أَنْ آذَنَ لَهُ عَلَىَّ فَلَمَّا جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَخْبَرْتُهُ بِالَّذِي صَنَعْتُ فَأَمَرَنِي أَنْ آذَنَ لَهُ عَلَىَّ ‏.‏\hadithno{1274}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Urwa ibn az- Zubayr that A'isha umm al-muminin told him that Aflah, the brother of Abu'l-Quays came and asked permission to visit her after the veil had been lowered, and he was her paternal uncle by suckling. She said, "I refusedto give him permission to enter. When the Messenger of Allah, may Allah bless him and grant him peace, came, I told him about what I had done, and he ordered me to give him permission to enter}}
\hadithdefcmd{malik}{1275}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ كَانَ يَقُولُ مَا كَانَ فِي الْحَوْلَيْنِ وَإِنْ كَانَ مَصَّةً وَاحِدَةً فَهُوَ يُحَرِّمُ ‏.‏\hadithno{1275}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Thawr ibn Zayd ad-Dili that Abdullah ibn Abbas said, "The milk which a child under two years old sucks, even if it is only one suck, makes the foster relatives haram}}
\hadithdefcmd{malik}{1276}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، سُئِلَ عَنْ رَجُلٍ، كَانَتْ لَهُ امْرَأَتَانِ فَأَرْضَعَتْ إِحْدَاهُمَا غُلاَمًا وَأَرْضَعَتِ الأُخْرَى جَارِيَةً فَقِيلَ لَهُ هَلْ يَتَزَوَّجُ الْغُلاَمُ الْجَارِيَةَ فَقَالَ لاَ اللِّقَاحُ وَاحِدٌ ‏.‏\hadithno{1276}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Amr ibn ash- Sharid that Abdullah ibn Abbas was asked whether, if a man had two wives, and one of them nursed a slave-boy, and the other had nursed a slave-girl, could the slave-boy marry the slave-girl. He said, "No. The husband is the same}}
\hadithdefcmd{malik}{1277}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ لاَ رَضَاعَةَ إِلاَّ لِمَنْ أُرْضِعَ فِي الصِّغَرِ وَلاَ رَضَاعَةَ لِكَبِيرٍ ‏.‏\hadithno{1277}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "There is no kinship by suckling except for a person who is nursed when he is small. There is no kinship by suckling over the age of two years}}
\hadithdefcmd{malik}{1278}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ سَالِمَ بْنَ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَخْبَرَهُ أَنَّ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ أَرْسَلَتْ بِهِ وَهُوَ يَرْضَعُ إِلَى أُخْتِهَا أُمِّ كُلْثُومٍ بِنْتِ أَبِي بَكْرٍ الصِّدِّيقِ فَقَالَتْ أَرْضِعِيهِ عَشْرَ رَضَعَاتٍ حَتَّى يَدْخُلَ عَلَىَّ ‏.‏ قَالَ سَالِمٌ فَأَرْضَعَتْنِي أُمُّ كُلْثُومٍ ثَلاَثَ رَضَعَاتٍ ثُمَّ مَرِضَتْ فَلَمْ تُرْضِعْنِي غَيْرَ ثَلاَثِ رَضَعَاتٍ فَلَمْ أَكُنْ أَدْخُلُ عَلَى عَائِشَةَ مِنْ أَجْلِ أَنَّ أُمَّ كُلْثُومٍ لَمْ تُتِمَّ لِي عَشْرَ رَضَعَاتٍ ‏.‏\hadithno{1278}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Nafi that Salim ibn Abdullah ibn Umar informed him that A'isha umm al-muminin sent him away while he was being nursed to her sister Umm Kulthum bint Abi Bakr as-Siddiq and said, "Suckle him ten times so that he can come in to see me." Salim said, "Umm Kulthum nursed me three times and then fell ill, so that she only nursed me three times. I could not go in to see A'isha because Umm Kulthum did not finish for me the ten times}}
\hadithdefcmd{malik}{1279}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ صَفِيَّةَ بِنْتَ أَبِي عُبَيْدٍ، أَخْبَرَتْهُ أَنَّ حَفْصَةَ أُمَّ الْمُؤْمِنِينَ أَرْسَلَتْ بِعَاصِمِ بْنِ عَبْدِ اللَّهِ بْنِ سَعْدٍ إِلَى أُخْتِهَا فَاطِمَةَ بِنْتِ عُمَرَ بْنِ الْخَطَّابِ تُرْضِعُهُ عَشْرَ رَضَعَاتٍ لِيَدْخُلَ عَلَيْهَا وَهُوَ صَغِيرٌ يَرْضَعُ فَفَعَلَتْ فَكَانَ يَدْخُلُ عَلَيْهَا ‏.‏\hadithno{1279}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Safiyya bint Abi Ubayd told him that Hafsa, umm al-muminin, sent Asim ibn Abdullah ibn Sad to her sister Fatima bint Umar ibn al-Khattab for her to suckle him ten times so that he could come in to see her. She did it, so he used to come in to see her}}
\hadithdefcmd{malik}{1280}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، أَنَّهُ أَخْبَرَهُ أَنَّ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَانَ يَدْخُلُ عَلَيْهَا مَنْ أَرْضَعَتْهُ أَخَوَاتُهَا وَبَنَاتُ أَخِيهَا وَلاَ يَدْخُلُ عَلَيْهَا مَنْ أَرْضَعَهُ نِسَاءُ إِخْوَتِهَا ‏.‏\hadithno{1280}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim that his father told him that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, admitted those whom her sisters and the daughters of her brother had nursed, and she did not admit those who were nursed by the wives of her brothers}}
\hadithdefcmd{malik}{1281}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِبْرَاهِيمَ بْنِ عُقْبَةَ، أَنَّهُ سَأَلَ سَعِيدَ بْنَ الْمُسَيَّبِ عَنِ الرَّضَاعَةِ، فَقَالَ سَعِيدٌ كُلُّ مَا كَانَ فِي الْحَوْلَيْنِ وَإِنْ كَانَتْ قَطْرَةً وَاحِدَةً فَهُوَ يُحَرِّمُ وَمَا كَانَ بَعْدَ الْحَوْلَيْنِ فَإِنَّمَا هُوَ طَعَامٌ يَأْكُلُهُ ‏.‏ قَالَ إِبْرَاهِيمُ بْنُ عُقْبَةَ ثُمَّ سَأَلْتُ عُرْوَةَ بْنَ الزُّبَيْرِ فَقَالَ مِثْلَ مَا قَالَ سَعِيدُ بْنُ الْمُسَيَّبِ ‏.‏\hadithno{1281}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Ibrahim ibn Uqba asked Said ibn al-Musayyab about suckling. Said said, "All that occurs in the first two years, even if it is only a drop, makes haram. Whatever is after two years, is only food that is eaten." Ibrahim ibn Uqba said, ''Then I asked Urwa ibn az-Zubayr and he told me the same as what Said ibn al-Musayyab said}}
\hadithdefcmd{malik}{1282}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ لاَ رَضَاعَةَ إِلاَّ مَا كَانَ فِي الْمَهْدِ وَإِلاَّ مَا أَنْبَتَ اللَّحْمَ وَالدَّمَ ‏.‏\hadithno{1282}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said that he heard Said ibn al-Musayyab say, "Suckling is only while the child is in the cradle. If not, it does not cause flesh and blood relations}}
\hadithdefcmd{malik}{1283}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ كَانَ يَقُولُ الرَّضَاعَةُ قَلِيلُهَا وَكَثِيرُهَا تُحَرِّمُ وَالرَّضَاعَةُ مِنْ قِبَلِ الرِّجَالِ تُحَرِّمُ ‏.‏ قَالَ يَحْيَى وَسَمِعْتُ مَالِكًا يَقُولُ الرَّضَاعَةُ قَلِيلُهَا وَكَثِيرُهَا إِذَا كَانَ فِي الْحَوْلَيْنِ تُحَرِّمُ فَأَمَّا مَا كَانَ بَعْدَ الْحَوْلَيْنِ فَإِنَّ قَلِيلَهُ وَكَثِيرَهُ لاَ يُحَرِّمُ شَيْئًا وَإِنَّمَا هُوَ بِمَنْزِلَةِ الطَّعَامِ ‏.‏\hadithno{1283}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that he said, "Suckling however little or much, makes haram. Kinship by suckling makes men mahram." Yahya said that he had heard Malik say, "Suckling, however little or much when it is in the first two years, makes haram. As for what is after the first two years, little or much, it does not make anything haram. It is like food}}
\hadithdefcmd{malik}{1284}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ سُئِلَ عَنْ رَضَاعَةِ الْكَبِيرِ، فَقَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ أَبَا حُذَيْفَةَ بْنَ عُتْبَةَ بْنِ رَبِيعَةَ، وَكَانَ، مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَ قَدْ شَهِدَ بَدْرًا وَكَانَ تَبَنَّى سَالِمًا الَّذِي يُقَالُ لَهُ سَالِمٌ مَوْلَى أَبِي حُذَيْفَةَ كَمَا تَبَنَّى رَسُولُ اللَّهِ صلى الله عليه وسلم زَيْدَ بْنَ حَارِثَةَ وَأَنْكَحَ أَبُو حُذَيْفَةَ سَالِمًا وَهُوَ يَرَى أَنَّهُ ابْنُهُ أَنْكَحَهُ بِنْتَ أَخِيهِ فَاطِمَةَ بِنْتَ الْوَلِيدِ بْنِ عُتْبَةَ بْنِ رَبِيعَةَ وَهِيَ يَوْمَئِذٍ مِنَ الْمُهَاجِرَاتِ الأُوَلِ وَهِيَ مِنْ أَفْضَلِ أَيَامَى قُرَيْشٍ فَلَمَّا أَنْزَلَ اللَّهُ تَعَالَى فِي كِتَابِهِ فِي زَيْدِ بْنِ حَارِثَةَ مَا أَنْزَلَ فَقَالَ ‏\{‏ادْعُوهُمْ لآبَائِهِمْ هُوَ أَقْسَطُ عِنْدَ اللَّهِ فَإِنْ لَمْ تَعْلَمُوا آبَاءَهُمْ فَإِخْوَانُكُمْ فِي الدِّينِ وَمَوَالِيكُمْ‏\}‏ رُدَّ كُلُّ وَاحِدٍ مِنْ أُولَئِكَ إِلَى أَبِيهِ فَإِنْ لَمْ يُعْلَمْ أَبُوهُ رُدَّ إِلَى مَوْلاَهُ فَجَاءَتْ سَهْلَةُ بِنْتُ سُهَيْلٍ وَهِيَ امْرَأَةُ أَبِي حُذَيْفَةَ وَهِيَ مِنْ بَنِي عَامِرِ بْنِ لُؤَىٍّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ كُنَّا نَرَى سَالِمًا وَلَدًا وَكَانَ يَدْخُلُ عَلَىَّ وَأَنَا فُضُلٌ وَلَيْسَ لَنَا إِلاَّ بَيْتٌ وَاحِدٌ فَمَاذَا تَرَى فِي شَأْنِهِ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرْضِعِيهِ خَمْسَ رَضَعَاتٍ فَيَحْرُمُ بِلَبَنِهَا ‏"‏ ‏.‏ وَكَانَتْ تَرَاهُ ابْنًا مِنَ الرَّضَاعَةِ فَأَخَذَتْ بِذَلِكَ عَائِشَةُ أُمُّ الْمُؤْمِنِينَ فِيمَنْ كَانَتْ تُحِبُّ أَنْ يَدْخُلَ عَلَيْهَا مِنَ الرِّجَالِ فَكَانَتْ تَأْمُرُ أُخْتَهَا أُمَّ كُلْثُومٍ بِنْتَ أَبِي بَكْرٍ الصِّدِّيقِ وَبَنَاتِ أَخِيهَا أَنْ يُرْضِعْنَ مَنْ أَحَبَّتْ أَنْ يَدْخُلَ عَلَيْهَا مِنَ الرِّجَالِ وَأَبَى سَائِرُ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم أَنْ يَدْخُلَ عَلَيْهِنَّ بِتِلْكَ الرَّضَاعَةِ أَحَدٌ مِنَ النَّاسِ وَقُلْنَ لاَ وَاللَّهِ مَا نَرَى الَّذِي أَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم سَهْلَةَ بِنْتَ سُهَيْلٍ إِلاَّ رُخْصَةً مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَضَاعَةِ سَالِمٍ وَحْدَهُ لاَ وَاللَّهِ لاَ يَدْخُلُ عَلَيْنَا بِهَذِهِ الرَّضَاعَةِ أَحَدٌ فَعَلَى هَذَا كَانَ أَزْوَاجُ النَّبِيِّ صلى الله عليه وسلم فِي رَضَاعَةِ الْكَبِيرِ ‏.‏\hadithno{1284}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that he was asked about the suckling of an older person. He said, ''Urwa ibn az-Zubayr informed me that Abu Hudhayfa ibn Utba ibn Rabia, one of the companions of the Messenger of Allah, may Allah bless him and grant him peace, who was present at Badr, adopted Salim (who is called Salim, the mawla of Abu Hudhayfa) as the Messenger of Allah, may Allah bless him and grant him peace, adopted Zayd ibn Haritha. He thought of him as his son, and Abu Hudhayfa married him to his brother's sister, Fatima bint al-Walid ibn Utba ibn Rabia, who was at that time among the first emigrants. She was one of the best unmarried women of the Quraysh. When Allah the Exalted sent down in His Book what He sent down about Zayd ibn Haritha, 'Call them after their true fathers. That is more equitable in the sight of Allah. If you do not know who their fathers were then they are your brothers in the deen and your mawali,' (Sura 33 ayat 5) people in this position were traced back to their fathers. When the father was not known, they were traced to their mawla. "Sahla bint Suhayl who was the wife of Abu Hudhayfa, and one of the tribe of Amr ibn Luayy, came to the Messenger of Allah, may Allah bless him and grant him peace, and said, 'Messenger of Allah! We think of Salim as a son and he comes in to see me while I am uncovered. We only have one room, so what do you think about the situation?' The Messenger of Allah, may Allah bless him and grant him peace, said, 'Give him five drinks of your milk and he will be mahram by it.' She then saw him as a foster son. A'isha umm al-muminin took that as a precedent for whatever men she wanted to be able to come to see her. She ordered her sister, Umm Kulthum bint Abi Bakr as-Siddiq and the daughters of her brother to give milk to whichever men she wanted to be able to come in to see her. The rest of the wives of the Prophet, may Allah bless him and grant him peace, refused to let anyone come in to them by such nursing. They said, 'No! By Allah! We think that what the Messenger of Allah, may Allah bless him and grant him peace, ordered Sahla bint Suhayl to do was only an indulgence concerning the nursing of Salim alone. No! By Allah! No one will come in upon us by such nursing!' "This is what the wives of the Prophet, may Allah bless him and grant him peace, thought about the suckling of an older person}}
\hadithdefcmd{malik}{1285}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ قَالَ جَاءَ رَجُلٌ إِلَى عَبْدِ اللَّهِ بْنِ عُمَرَ وَأَنَا مَعَهُ عِنْدَ دَارِ الْقَضَاءِ يَسْأَلُهُ عَنْ رَضَاعَةِ الْكَبِيرِ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ جَاءَ رَجُلٌ إِلَى عُمَرَ بْنِ الْخَطَّابِ فَقَالَ إِنِّي كَانَتْ لِي وَلِيدَةٌ وَكُنْتُ أَطَؤُهَا فَعَمَدَتِ امْرَأَتِي إِلَيْهَا فَأَرْضَعَتْهَا فَدَخَلْتُ عَلَيْهَا فَقَالَتْ دُونَكَ فَقَدْ وَاللَّهِ أَرْضَعْتُهَا ‏.‏ فَقَالَ عُمَرُ أَوْجِعْهَا وَأْتِ جَارِيتَكَ فَإِنَّمَا الرَّضَاعَةُ رَضَاعَةُ الصَّغِيرِ ‏.‏\hadithno{1285}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Abdullah ibn Dinar said, "A man came to Abdullah ibn Umar when I waswith him at the place where judgments were given and asked him about the suckling of an older person. Abdullah ibn Umar replied, 'A man came to Umar ibn al-Khattab and said, 'I have a slave-girl and I used to have intercourse with her. My wife went to her and suckled her. When I went to the girl, my wife told me to watch out, because she had suckled her!' Umar told him to beat his wife and to go to his slave-girl because kinship by suckling was only by the suckling of the young}}
\hadithdefcmd{malik}{1286}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ رَجُلاً، سَأَلَ أَبَا مُوسَى الأَشْعَرِيَّ فَقَالَ إِنِّي مَصِصْتُ عَنِ امْرَأَتِي، مِنْ ثَدْيِهَا لَبَنًا فَذَهَبَ فِي بَطْنِي فَقَالَ أَبُو مُوسَى لاَ أُرَاهَا إِلاَّ قَدْ حَرُمَتْ عَلَيْكَ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ انْظُرْ مَاذَا تُفْتِي بِهِ الرَّجُلَ فَقَالَ أَبُو مُوسَى فَمَاذَا تَقُولُ أَنْتَ فَقَالَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ لاَ رَضَاعَةَ إِلاَّ مَا كَانَ فِي الْحَوْلَيْنِ ‏.‏ فَقَالَ أَبُو مُوسَى لاَ تَسْأَلُونِي عَنْ شَىْءٍ مَا كَانَ هَذَا الْحَبْرُ بَيْنَ أَظْهُرِكُمْ ‏.‏\hadithno{1286}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that a man said to Abu Musa al-Ashari, "I drank some milk from my wife's breasts and it went into my stomach." Abu Musa said, "I can only but think that she is haram for you." Abdullah ibn Masud said, "Look at what opinion you are giving the man." Abu Musa said, "Then what do you say?" Abdullah ibn Masud said, "There is only kinship by suckling in the first two years." Abu Musa said, "Do not ask me about anything while this learned man is among you}}
\hadithdefcmd{malik}{1287}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَحْرُمُ مِنَ الرَّضَاعَةِ مَا يَحْرُمُ مِنَ الْوِلاَدَةِ ‏"‏ ‏.‏\hadithno{1287}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar from Sulayman ibn Yasar and from Urwa ibn az-Zubayr from A'isha umm al- muminin, that the Messenger of Allah, may Allah bless him and grant him peace, said, " What is haram by birth is haram by suckling}}
\hadithdefcmd{malik}{1288}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ، أَنَّهُ قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، عَنْ جُدَامَةَ بِنْتِ وَهْبٍ الأَسَدِيَّةِ، أَنَّهَا أَخْبَرَتْهَا أَنَّهَا، سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَقَدْ هَمَمْتُ أَنْ أَنْهَى عَنِ الْغِيلَةِ حَتَّى ذَكَرْتُ أَنَّ الرُّومَ وَفَارِسَ يَصْنَعُونَ ذَلِكَ فَلاَ يَضُرُّ أَوْلاَدَهُمْ ‏"‏ ‏.‏\hadithno{1288}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Muhammad ibn Abd ar-Rahman ibn Nawfal said, ''Urwa ibn az-Zubayr informed me from A'isha umm al- muminin that Judama bint Wahb al-Asadiyya informed her that she heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'I intended to prohibit ghila but I remembered that the Greeks and Persians do that without it causing any injury to their children.' " Malik explained, "Ghila is that a man has intercourse with his wife while she is suckling}}
\hadithdefcmd{malik}{1289}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ حَزْمٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كَانَ فِيمَا أُنْزِلَ مِنَ الْقُرْآنِ عَشْرُ رَضَعَاتٍ مَعْلُومَاتٍ يُحَرِّمْنَ ثُمَّ نُسِخْنَ بِخَمْسٍ مَعْلُومَاتٍ فَتُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ فِيمَا يُقْرَأُ مِنَ الْقُرْآنِ ‏.‏\hadithno{1289}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr ibn Hazm from Amra bint Abd ar-Rahman that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "Amongst what was sent down of the Qur'an was 'ten known sucklings make haram' - then it was abrogated by 'five known sucklings'. When the Messenger of Allah, may Allah bless him and grant him peace, died, it was what is now recited of the Qur'an." Yahya said that Malik said, "One does not act on this}}
