% Auto-generated chapter index for abudawud
% Source: ara-abudawud.json
% Total hadiths: 5274
% Chapters: 43

\hadithcollectionname{abudawud}{Sunan Abu Dawud}

\hadithsectionname{abudawud}{1}{Purification (Kitab Al-Taharah)}
\hadithsectionname{abudawud}{2}{Prayer (Kitab Al-Salat)}
\hadithsectionname{abudawud}{3}{The Book Of The Prayer For Rain (Kitab al-Istisqa')}
\hadithsectionname{abudawud}{4}{Prayer (Kitab Al-Salat): Detailed Rules of Law about the Prayer during Journey}
\hadithsectionname{abudawud}{5}{Prayer (Kitab Al-Salat): Voluntary Prayers}
\hadithsectionname{abudawud}{6}{Prayer (Kitab Al-Salat): Detailed Injunctions about Ramadan}
\hadithsectionname{abudawud}{7}{Prayer (Kitab Al-Salat): Prostration while reciting the Qur'an}
\hadithsectionname{abudawud}{8}{Prayer (Kitab Al-Salat): Detailed Injunctions about Witr}
\hadithsectionname{abudawud}{9}{Zakat (Kitab Al-Zakat)}
\hadithsectionname{abudawud}{10}{The Book of Lost and Found Items}
\hadithsectionname{abudawud}{11}{The Rites of Hajj (Kitab Al-Manasik Wa'l-Hajj)}
\hadithsectionname{abudawud}{12}{Marriage (Kitab Al-Nikah)}
\hadithsectionname{abudawud}{13}{Divorce (Kitab Al-Talaq)}
\hadithsectionname{abudawud}{14}{Fasting (Kitab Al-Siyam)}
\hadithsectionname{abudawud}{15}{Jihad (Kitab Al-Jihad)}
\hadithsectionname{abudawud}{16}{Sacrifice (Kitab Al-Dahaya)}
\hadithsectionname{abudawud}{17}{Game (Kitab Al-Said)}
\hadithsectionname{abudawud}{18}{Wills (Kitab Al-Wasaya)}
\hadithsectionname{abudawud}{19}{Shares of Inheritance (Kitab Al-Fara'id)}
\hadithsectionname{abudawud}{20}{Tribute, Spoils, and Rulership (Kitab Al-Kharaj, Wal-Fai' Wal-Imarah)}
\hadithsectionname{abudawud}{21}{Funerals (Kitab Al-Jana'iz)}
\hadithsectionname{abudawud}{22}{Oaths and Vows (Kitab Al-Aiman Wa Al-Nudhur)}
\hadithsectionname{abudawud}{23}{Commercial Transactions (Kitab Al-Buyu)}
\hadithsectionname{abudawud}{24}{Wages (Kitab Al-Ijarah)}
\hadithsectionname{abudawud}{25}{The Office of the Judge (Kitab Al-Aqdiyah)}
\hadithsectionname{abudawud}{26}{Knowledge (Kitab Al-Ilm)}
\hadithsectionname{abudawud}{27}{Drinks (Kitab Al-Ashribah)}
\hadithsectionname{abudawud}{28}{Foods (Kitab Al-At'imah)}
\hadithsectionname{abudawud}{29}{Medicine (Kitab Al-Tibb)}
\hadithsectionname{abudawud}{30}{Divination and Omens (Kitab Al-Kahanah Wa Al-Tatayyur)}
\hadithsectionname{abudawud}{31}{The Book of Manumission of Slaves}
\hadithsectionname{abudawud}{32}{Dialects and Readings of the Qur'an (Kitab Al-Huruf Wa Al-Qira'at)}
\hadithsectionname{abudawud}{33}{Hot Baths (Kitab Al-Hammam)}
\hadithsectionname{abudawud}{34}{Clothing (Kitab Al-Libas)}
\hadithsectionname{abudawud}{35}{Combing the Hair (Kitab Al-Tarajjul)}
\hadithsectionname{abudawud}{36}{Signet-Rings (Kitab Al-Khatam)}
\hadithsectionname{abudawud}{37}{Trials and Fierce Battles (Kitab Al-Fitan Wa Al-Malahim)}
\hadithsectionname{abudawud}{38}{The Promised Deliverer (Kitab Al-Mahdi)}
\hadithsectionname{abudawud}{39}{Battles (Kitab Al-Malahim)}
\hadithsectionname{abudawud}{40}{Prescribed Punishments (Kitab Al-Hudud)}
\hadithsectionname{abudawud}{41}{Types of Blood-Wit (Kitab Al-Diyat)}
\hadithsectionname{abudawud}{42}{Model Behavior of the Prophet (Kitab Al-Sunnah)}
\hadithsectionname{abudawud}{43}{General Behavior (Kitab Al-Adab)}

\hadithsectionrange{abudawud}{1}{1}{390}
\hadithsectionrange{abudawud}{2}{391}{1160}
\hadithsectionrange{abudawud}{3}{1161}{1197}
\hadithsectionrange{abudawud}{4}{1198}{1249}
\hadithsectionrange{abudawud}{5}{1250}{1370}
\hadithsectionrange{abudawud}{6}{1371}{1400}
\hadithsectionrange{abudawud}{7}{1401}{1415}
\hadithsectionrange{abudawud}{8}{1416}{1555}
\hadithsectionrange{abudawud}{9}{1556}{1700}
\hadithsectionrange{abudawud}{10}{1701}{1720}
\hadithsectionrange{abudawud}{11}{1721}{2045}
\hadithsectionrange{abudawud}{12}{2046}{2174}
\hadithsectionrange{abudawud}{13}{2175}{2312}
\hadithsectionrange{abudawud}{14}{2313}{2476}
\hadithsectionrange{abudawud}{15}{2477}{2787}
\hadithsectionrange{abudawud}{16}{2788}{2843}
\hadithsectionrange{abudawud}{17}{2844}{2861}
\hadithsectionrange{abudawud}{18}{2862}{2884}
\hadithsectionrange{abudawud}{19}{2885}{2927}
\hadithsectionrange{abudawud}{20}{2928}{3088}
\hadithsectionrange{abudawud}{21}{3089}{3241}
\hadithsectionrange{abudawud}{22}{3242}{3325}
\hadithsectionrange{abudawud}{23}{3326}{3415}
\hadithsectionrange{abudawud}{24}{3416}{3570}
\hadithsectionrange{abudawud}{25}{3571}{3640}
\hadithsectionrange{abudawud}{26}{3641}{3668}
\hadithsectionrange{abudawud}{27}{3669}{3735}
\hadithsectionrange{abudawud}{28}{3736}{3854}
\hadithsectionrange{abudawud}{29}{3855}{3903}
\hadithsectionrange{abudawud}{30}{3904}{3925}
\hadithsectionrange{abudawud}{31}{3926}{3968}
\hadithsectionrange{abudawud}{32}{3969}{4008}
\hadithsectionrange{abudawud}{33}{4009}{4019}
\hadithsectionrange{abudawud}{34}{4020}{4158}
\hadithsectionrange{abudawud}{35}{4159}{4213}
\hadithsectionrange{abudawud}{36}{4214}{4239}
\hadithsectionrange{abudawud}{37}{4240}{4278}
\hadithsectionrange{abudawud}{38}{4279}{4290}
\hadithsectionrange{abudawud}{39}{4291}{4350}
\hadithsectionrange{abudawud}{40}{4351}{4493}
\hadithsectionrange{abudawud}{41}{4494}{4595}
\hadithsectionrange{abudawud}{42}{4596}{4772}
\hadithsectionrange{abudawud}{43}{4773}{5274}

% Chapter index — which .def file to load for each chapter

\hadithchapterfile{abudawud}{1}{hadithtext-abudawud-ch01.def}{1}{390}
\hadithchapterfile{abudawud}{2}{hadithtext-abudawud-ch02.def}{391}{1160}
\hadithchapterfile{abudawud}{3}{hadithtext-abudawud-ch03.def}{1161}{1197}
\hadithchapterfile{abudawud}{4}{hadithtext-abudawud-ch04.def}{1198}{1249}
\hadithchapterfile{abudawud}{5}{hadithtext-abudawud-ch05.def}{1250}{1370}
\hadithchapterfile{abudawud}{6}{hadithtext-abudawud-ch06.def}{1371}{1400}
\hadithchapterfile{abudawud}{7}{hadithtext-abudawud-ch07.def}{1401}{1415}
\hadithchapterfile{abudawud}{8}{hadithtext-abudawud-ch08.def}{1416}{1555}
\hadithchapterfile{abudawud}{9}{hadithtext-abudawud-ch09.def}{1556}{1700}
\hadithchapterfile{abudawud}{10}{hadithtext-abudawud-ch10.def}{1701}{1720}
\hadithchapterfile{abudawud}{11}{hadithtext-abudawud-ch11.def}{1721}{2045}
\hadithchapterfile{abudawud}{12}{hadithtext-abudawud-ch12.def}{2046}{2174}
\hadithchapterfile{abudawud}{13}{hadithtext-abudawud-ch13.def}{2175}{2312}
\hadithchapterfile{abudawud}{14}{hadithtext-abudawud-ch14.def}{2313}{2476}
\hadithchapterfile{abudawud}{15}{hadithtext-abudawud-ch15.def}{2477}{2787}
\hadithchapterfile{abudawud}{16}{hadithtext-abudawud-ch16.def}{2788}{2843}
\hadithchapterfile{abudawud}{17}{hadithtext-abudawud-ch17.def}{2844}{2861}
\hadithchapterfile{abudawud}{18}{hadithtext-abudawud-ch18.def}{2862}{2884}
\hadithchapterfile{abudawud}{19}{hadithtext-abudawud-ch19.def}{2885}{2927}
\hadithchapterfile{abudawud}{20}{hadithtext-abudawud-ch20.def}{2928}{3088}
\hadithchapterfile{abudawud}{21}{hadithtext-abudawud-ch21.def}{3089}{3241}
\hadithchapterfile{abudawud}{22}{hadithtext-abudawud-ch22.def}{3242}{3325}
\hadithchapterfile{abudawud}{23}{hadithtext-abudawud-ch23.def}{3326}{3415}
\hadithchapterfile{abudawud}{24}{hadithtext-abudawud-ch24.def}{3416}{3570}
\hadithchapterfile{abudawud}{25}{hadithtext-abudawud-ch25.def}{3571}{3640}
\hadithchapterfile{abudawud}{26}{hadithtext-abudawud-ch26.def}{3641}{3668}
\hadithchapterfile{abudawud}{27}{hadithtext-abudawud-ch27.def}{3669}{3735}
\hadithchapterfile{abudawud}{28}{hadithtext-abudawud-ch28.def}{3736}{3854}
\hadithchapterfile{abudawud}{29}{hadithtext-abudawud-ch29.def}{3855}{3903}
\hadithchapterfile{abudawud}{30}{hadithtext-abudawud-ch30.def}{3904}{3925}
\hadithchapterfile{abudawud}{31}{hadithtext-abudawud-ch31.def}{3926}{3968}
\hadithchapterfile{abudawud}{32}{hadithtext-abudawud-ch32.def}{3969}{4008}
\hadithchapterfile{abudawud}{33}{hadithtext-abudawud-ch33.def}{4009}{4019}
\hadithchapterfile{abudawud}{34}{hadithtext-abudawud-ch34.def}{4020}{4158}
\hadithchapterfile{abudawud}{35}{hadithtext-abudawud-ch35.def}{4159}{4213}
\hadithchapterfile{abudawud}{36}{hadithtext-abudawud-ch36.def}{4214}{4239}
\hadithchapterfile{abudawud}{37}{hadithtext-abudawud-ch37.def}{4240}{4278}
\hadithchapterfile{abudawud}{38}{hadithtext-abudawud-ch38.def}{4279}{4290}
\hadithchapterfile{abudawud}{39}{hadithtext-abudawud-ch39.def}{4291}{4350}
\hadithchapterfile{abudawud}{40}{hadithtext-abudawud-ch40.def}{4351}{4493}
\hadithchapterfile{abudawud}{41}{hadithtext-abudawud-ch41.def}{4494}{4595}
\hadithchapterfile{abudawud}{42}{hadithtext-abudawud-ch42.def}{4596}{4772}
\hadithchapterfile{abudawud}{43}{hadithtext-abudawud-ch43.def}{4773}{5274}
