% Auto-generated chapter 43 for nasai
% Hadiths in this chapter: 88

\hadithdefcmd{nasai}{4361}{أَخْبَرَنَا سُلَيْمَانُ بْنُ سَلْمٍ الْبَلْخِيُّ، قَالَ حَدَّثَنَا النَّضْرُ، - وَهُوَ ابْنُ شُمَيْلٍ - قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنِ ابْنِ مُسْلِمٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أُمِّ سَلَمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ رَأَى هِلاَلَ ذِي الْحِجَّةِ فَأَرَادَ أَنْ يُضَحِّيَ فَلاَ يَأْخُذْ مِنْ شَعْرِهِ وَلاَ مِنْ أَظْفَارِهِ حَتَّى يُضَحِّيَ ‏"‏ ‏.‏\hadithno{4361}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ummm Salamah that the Prophet said:"Whoever sees the new crescent of Dhul-Hijjah and wants to offer a sacrifice, let him not remove any of his hair or nails until he has offered the sacrifice}}
\hadithdefcmd{nasai}{4362}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، قَالَ حَدَّثَنَا خَالِدُ بْنُ يَزِيدَ، عَنِ ابْنِ أَبِي هِلاَلٍ، عَنْ عَمْرِو بْنِ مُسْلِمٍ، أَنَّهُ قَالَ أَخْبَرَنِي ابْنُ الْمُسَيَّبِ، أَنَّ أُمَّ سَلَمَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَرَادَ أَنْ يُضَحِّيَ فَلاَ يَقْلِمْ مِنْ أَظْفَارِهِ وَلاَ يَحْلِقْ شَيْئًا مِنْ شَعْرِهِ فِي عَشْرِ الأُوَلِ مِنْ ذِي الْحِجَّةِ ‏"‏ ‏.‏\hadithno{4362}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Amr bin Muslim said:"Ibn Al-Musayyab told me that Umm Salamah, the wife of the Prophet told him that the Messenger of Allah said: 'Whoever wants to offer a sacrifice, let him not remove anything from his nails or cut his hair for the first ten days Dhul-Jijjah}}
\hadithdefcmd{nasai}{4363}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا شَرِيكٌ، عَنْ عُثْمَانَ الأَحْلاَفِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ مَنْ أَرَادَ أَنْ يُضَحِّيَ، فَدَخَلَتْ أَيَّامُ الْعَشْرِ فَلاَ يَأْخُذْ مِنْ شَعْرِهِ وَلاَ أَظْفَارِهِ ‏.‏ فَذَكَرْتُهُ لِعِكْرِمَةَ فَقَالَ أَلاَ يَعْتَزِلُ النِّسَاءَ وَالطِّيبَ ‏.‏\hadithno{4363}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sa'eed bin Al-Musayyab said:"Whoever wants to offer a sacrifice when dhul-Hijjah begins, let him not remove anything from his hair or nails." I (the narrator) mentioned that to 'Ikrimah, and he said: "Should he not also keep away from women and perfume?}}
\hadithdefcmd{nasai}{4364}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أُمِّ سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دَخَلَتِ الْعَشْرُ فَأَرَادَ أَحَدُكُمْ أَنْ يُضَحِّيَ فَلاَ يَمَسَّ مِنْ شَعْرِهِ وَلاَ مِنْ بَشَرِهِ شَيْئًا ‏"‏ ‏.‏\hadithno{4364}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Umm Salamah that the Messenger of Allah said:"when the (first) ten (days of Dhul-Jijjah) begin, and one of you wants to offer a sacrifice, let him not remove anything from his hair or skin}}
\hadithdefcmd{nasai}{4365}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ أَبِي أَيُّوبَ، وَذَكَرَ، آخَرِينَ عَنْ عَيَّاشِ بْنِ عَبَّاسٍ الْقِتْبَانِيِّ، عَنْ عِيسَى بْنِ هِلاَلٍ الصَّدَفِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِرَجُلٍ ‏"‏ أُمِرْتُ بِيَوْمِ الأَضْحَى عِيدًا جَعَلَهُ اللَّهُ عَزَّ وَجَلَّ لِهَذِهِ الأُمَّةِ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ أَرَأَيْتَ إِنْ لَمْ أَجِدْ إِلاَّ مَنِيحَةً أُنْثَى أَفَأُضَحِّي بِهَا قَالَ ‏"‏ لاَ وَلَكِنْ تَأْخُذُ مِنْ شَعْرِكَ وَتُقَلِّمُ أَظْفَارَكَ وَتَقُصُّ شَارِبَكَ وَتَحْلِقُ عَانَتَكَ فَذَلِكَ تَمَامُ أُضْحِيَتِكَ عِنْدَ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4365}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Amr bin al-As that the Messenger of Allah said to a man:"I have been instructed to take the Day of Sacrifice as an 'Id which Allah, the Might and Sublime, has ordained for this Ummah." The man said: "What do you think if I cannot find anything but a female sheep that has been loaned to me so that I may benefit from its milk - should I sacrifice it?" He said: "No. Rather cut something from your hair and your nails, trim your mustache and shave your pubic hairs, and you will have a complete reward with Allah, the Might and Sublime, as if you had offered the sacrifice}}
\hadithdefcmd{nasai}{4366}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، عَنِ اللَّيْثِ، عَنْ كَثِيرِ بْنِ فَرْقَدٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَذْبَحُ أَوْ يَنْحَرُ بِالْمُصَلَّى ‏.‏\hadithno{4366}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Nafi that:'Abdullah told him that the Messenger of Allah used to offer the sacrifice at the prayer place}}
\hadithdefcmd{nasai}{4367}{أَخْبَرَنَا عَلِيُّ بْنُ عُثْمَانَ النُّفَيْلِيُّ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ عِيسَى، قَالَ حَدَّثَنَا الْمُفَضَّلُ بْنُ فَضَالَةَ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَحَرَ يَوْمَ الأَضْحَى بِالْمَدِينَةِ - قَالَ - وَقَدْ كَانَ إِذَا لَمْ يَنْحَرْ يَذْبَحُ بِالْمُصَلَّى ‏.‏\hadithno{4367}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that:the Messenger of Allah offered the sacrifice obn the Day of Sacrifice in Al-Madinah. He said: "if he did not offer the Nahr (sacrifice a camel) he would have offered Dhabihah (Sacrificed a sheep) at the prayer place}}
\hadithdefcmd{nasai}{4368}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ جُنْدُبِ بْنِ سُفْيَانَ، قَالَ شَهِدْتُ أَضْحَى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى بِالنَّاسِ فَلَمَّا قَضَى الصَّلاَةَ رَأَى غَنَمًا قَدْ ذُبِحَتْ فَقَالَ ‏ "‏ مَنْ ذَبَحَ قَبْلَ الصَّلاَةِ فَلْيَذْبَحْ شَاةً مَكَانَهَا وَمَنْ لَمْ يَكُنْ ذَبَحَ فَلْيَذْبَحْ عَلَى اسْمِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4368}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jundub bin Sufyan said:"I attended (the day of) sacrifice with the Messenger of Allah He led the people 9in prayer, then when he finished praying he saw some sheep that had been sacrificed. He said 'Whoever slaughtered (his sacrifice) before the prayer. Let him slaughtered (his sacrifice) before the prayer, let him slaughter a sheep in its place, and whoever has not slaughtered, let him offer a sacrifice in the name of Allah, the Mighty and Sublime}}
\hadithdefcmd{nasai}{4369}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ بْنِ عَبْدِ الرَّحْمَنِ، مَوْلَى بَنِي أَسَدٍ عَنْ أَبِي الضَّحَّاكِ، عُبَيْدِ بْنِ فَيْرُوزَ مَوْلَى بَنِي شَيْبَانَ قَالَ قُلْتُ لِلْبَرَاءِ حَدِّثْنِي عَمَّا، نَهَى عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الأَضَاحِي ‏.‏ قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَيَدِي أَقْصَرُ مِنْ يَدِهِ فَقَالَ ‏ "‏ أَرْبَعٌ لاَ يَجُزْنَ الْعَوْرَاءُ الْبَيِّنُ عَوَرُهَا وَالْمَرِيضَةُ الْبَيِّنُ مَرَضُهَا وَالْعَرْجَاءُ الْبَيِّنُ ظَلْعُهَا وَالْكَسِيرَةُ الَّتِي لاَ تُنْقِي ‏"‏ ‏.‏ قُلْتُ إِنِّي أَكْرَهُ أَنْ يَكُونَ فِي الْقَرْنِ نَقْصٌ وَأَنْ يَكُونَ فِي السِّنِّ نَقْصٌ ‏.‏ قَالَ مَا كَرِهْتَهُ فَدَعْهُ وَلاَ تُحَرِّمْهُ عَلَى أَحَدٍ ‏.‏\hadithno{4369}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Ad-Dahhak 'Ubaid bin Fairuz, the freed slave of Banu Shaiban, said:"IU said to Al-Bara bin Azib: 'Tell me of the sacrificial animals that the Messenger of Allah disliked or forbade, He said: The Messenger of Allah stood up, and my hands are shorter than his, and he said: "There are four that will not do as sacrifices: the animals that clearly has one bad eye: the sick animals that is obviously sick; the lame animal with an obvious limp; and the animal that is so emaciated that it is as if three is no marrow in its bones."' I said: "I dislike that the animals should have some fault in its horns or teeth' He said;'what you dislike, forget about it and do not make it for bidden to anyone}}
\hadithdefcmd{nasai}{4370}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَأَبُو دَاوُدَ وَيَحْيَى وَعَبْدُ الرَّحْمَنِ وَابْنُ أَبِي عَدِيٍّ وَأَبُو الْوَلِيدِ قَالُوا أَنْبَأَنَا شُعْبَةُ، قَالَ سَمِعْتُ سُلَيْمَانَ بْنَ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ عُبَيْدَ بْنَ فَيْرُوزَ، قَالَ قُلْتُ لِلْبَرَاءِ بْنِ عَازِبٍ حَدِّثْنِي مَا، كَرِهَ أَوْ نَهَى عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الأَضَاحِي ‏.‏ قَالَ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ هَكَذَا بِيَدِهِ وَيَدِي أَقْصَرُ مِنْ يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَرْبَعَةٌ لاَ يَجْزِينَ فِي الأَضَاحِي الْعَوْرَاءُ الْبَيِّنُ عَوَرُهَا وَالْمَرِيضَةُ الْبَيِّنُ مَرَضُهَا وَالْعَرْجَاءُ الْبَيِّنُ ظَلْعُهَا وَالْكَسِيرَةُ الَّتِي لاَ تُنْقِي ‏"‏ ‏.‏ قَالَ فَإِنِّي أَكْرَهُ أَنْ يَكُونَ نَقْصٌ فِي الْقَرْنِ وَالأُذُنِ ‏.‏ قَالَ فَمَا كَرِهْتَ مِنْهُ فَدَعْهُ وَلاَ تُحَرِّمْهُ عَلَى أَحَدٍ ‏.‏\hadithno{4370}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ubaid bin Fairuz said:"I said to Al-Bara bin Azib: 'Tell me of the sacrificial animals that the Messenger of Allah dislike or forbade. He said: "The Messenger of Allah gestured like this with his hand, and my hands are shorter than the hand of the Messenger of Allah, (and he said). 'There are four that will not do as sacrifices: The animal that clearly has one bad eye: the sick animals that is obviously sick; the lame animal with an obvious lamp; and the animal that is so emaciated that it is as if there is no marrow in its bones: He said: "And I dislike that the animal should have some fault in its horns or ears." He said: "What you dislike, forget about it, and do not make it forbidden to anyone}}
\hadithdefcmd{nasai}{4371}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، وَاللَّيْثُ بْنُ سَعْدٍ، وَذَكَرَ، آخَرَ وَقَدَّمَهُ أَنَّ سُلَيْمَانَ بْنَ عَبْدِ الرَّحْمَنِ، حَدَّثَهُمْ عَنْ عُبَيْدِ بْنِ فَيْرُوزَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَشَارَ بِأَصَابِعِهِ وَأَصَابِعِي أَقْصَرُ مِنْ أَصَابِعِ رَسُولِ اللَّهِ صلى الله عليه وسلم يُشِيرُ بِأَصْبُعِهِ يَقُولُ ‏ "‏ لاَ يَجُوزُ مِنَ الضَّحَايَا الْعَوْرَاءُ الْبَيِّنُ عَوَرُهَا وَالْعَرْجَاءُ الْبَيِّنُ عَرَجُهَا وَالْمَرِيضَةُ الْبَيِّنُ مَرَضُهَا وَالْعَجْفَاءُ الَّتِي لاَ تُنْقِي ‏"‏ ‏.‏\hadithno{4371}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Ubaid bin Fairuz thatAl; -Bara bnin 'Azib said:"I heard the Messenger of Allah say" - and he gestured with his fingers, but his fingers were shorter than the fingers of the Messenger of Allah - he said "It is not permissible to offer as a sacrifice an animal that clearly has one bad eye, a lame animal that is obviously lame, as sick animal that is obviously sick, or an animals that is so emaciated that it is as if there is no marrow in its bones}}
\hadithdefcmd{nasai}{4372}{أَخْبَرَنِي مُحَمَّدُ بْنُ آدَمَ، عَنْ عَبْدِ الرَّحِيمِ، - وَهُوَ ابْنُ سُلَيْمَانَ - عَنْ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ شُرَيْحِ بْنِ النُّعْمَانِ، عَنْ عَلِيٍّ، رضى الله عنه قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَسْتَشْرِفَ الْعَيْنَ وَالأُذُنَ وَأَنْ لاَ نُضَحِّيَ بِمُقَابَلَةٍ وَلاَ مُدَابَرَةٍ وَلاَ بَتْرَاءَ وَلاَ خَرْقَاءَ ‏.‏\hadithno{4372}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali, may Allah be pleased with him, said:"The Messenger of Allah commanded us to examine the eyes and ears (of animals), and no}}
\hadithdefcmd{nasai}{4373}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ أَعْيَنَ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ شُرَيْحِ بْنِ النُّعْمَانِ، - قَالَ أَبُو إِسْحَاقَ وَكَانَ رَجُلَ صِدْقٍ - عَنْ عَلِيٍّ، رضى الله عنه قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَسْتَشْرِفَ الْعَيْنَ وَالأُذُنَ وَأَنْ لاَ نُضَحِّيَ بِعَوْرَاءَ وَلاَ مُقَابَلَةٍ وَلاَ مُدَابَرَةٍ وَلاَ شَرْقَاءَ وَلاَ خَرْقَاءَ ‏.‏\hadithno{4373}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:"The Messenger of Allah commanded us to examine the eyes and ears (of animals) and not to Sacrifice and animal with a bad eye, nor an animal with its ears slit from the front, nor an animals with its ears slit form the back, nor an animal with a round hole in its ear}}
\hadithdefcmd{nasai}{4374}{أَخْبَرَنَا أَحْمَدُ بْنُ نَاصِحٍ، قَالَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ شُرَيْحِ بْنِ النُّعْمَانِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، رضى الله عنه قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نُضَحِّيَ بِمُقَابَلَةٍ أَوْ مُدَابَرَةٍ أَوْ شَرْقَاءَ أَوْ خَرْقَاءَ أَوْ جَدْعَاءَ ‏.‏\hadithno{4374}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali bin Abi Talib, may Allah be please with him, said:"The Messenger of Allah forbade sacrificing an animals with its ears slit form the front, and animals with its ears slit form the back, and animal with its ears slit lengthwise, an animals with a round hole in tits ear, or an animals with its nose cut off}}
\hadithdefcmd{nasai}{4375}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا شُجَاعُ بْنُ الْوَلِيدِ، قَالَ حَدَّثَنِي زِيَادُ بْنُ خَيْثَمَةَ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ شُرَيْحِ بْنِ النُّعْمَانِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُضَحَّى بِمُقَابَلَةٍ وَلاَ مُدَابَرَةٍ وَلاَ شَرْقَاءَ وَلاَ خَرْقَاءَ وَلاَ عَوْرَاءَ ‏"‏ ‏.‏\hadithno{4375}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Ali bin Abi Talib, may Allah be please wityh him, that the messenger of Allah said:"Do not sacrifice and animal with its ears slit from the front, and animal with its ears slit from the back, an animals with its ears slit lengthwise, and animal with a round hole in its ears, or an animal with one bad eye}}
\hadithdefcmd{nasai}{4376}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، أَنَّ سَلَمَةَ، - وَهُوَ ابْنُ كُهَيْلٍ - أَخْبَرَهُ قَالَ سَمِعْتُ حُجَيَّةَ بْنَ عَدِيٍّ، يَقُولُ سَمِعْتُ عَلِيًّا، يَقُولُ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَسْتَشْرِفَ الْعَيْنَ وَالأُذُنَ ‏.‏\hadithno{4376}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ali said:" The Messenger of Allah commanded us to examine the eyes and ears (of animals for sacrifice)}}
\hadithdefcmd{nasai}{4377}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ سُفْيَانَ، - وَهُوَ ابْنُ حَبِيبٍ - عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ جُرَىِّ بْنِ كُلَيْبٍ، قَالَ سَمِعْتُ عَلِيًّا، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُضَحَّى بِأَعْضَبِ الْقَرْنِ ‏.‏ فَذَكَرْتُ ذَلِكَ لِسَعِيدِ بْنِ الْمُسَيَّبِ قَالَ نَعَمْ إِلاَّ عَضَبَ النِّصْفِ وَأَكْثَرَ مِنْ ذَلِكَ ‏.‏\hadithno{4377}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ali said:"Messenger of Allah forbade us from sacrificing an animal with a broken horn." I (the narrator) mentioned that to Sa'eed bin Al\_Musayyab and he said: "Yes, m unless half or more of the horn is missing}}
\hadithdefcmd{nasai}{4378}{أَخْبَرَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ سَيْفٍ قَالَ حَدَّثَنَا الْحَسَنُ، - وَهُوَ ابْنُ أَعْيَنَ - وَأَبُو جَعْفَرٍ - يَعْنِي النُّفَيْلِيَّ - قَالاَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَذْبَحُوا إِلاَّ مُسِنَّةً إِلاَّ أَنْ يَعْسُرَ عَلَيْكُمْ فَتَذْبَحُوا جَذَعَةً مِنَ الضَّأْنِ ‏"‏ ‏.‏\hadithno{4378}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah said: 'Do not slaughter anything but a Musinnah, unless that is difficult, in which case you can slaughter a Jadh'ah sheep}}
\hadithdefcmd{nasai}{4379}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْطَاهُ غَنَمًا يُقَسِّمُهَا عَلَى صَحَابَتِهِ فَبَقِيَ عَتُودٌ فَذَكَرَهُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ ضَحِّ بِهِ أَنْتَ ‏"‏ ‏.‏\hadithno{4379}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Uqbah bin 'Amair that:the Messenger of Allah gave him some sheep to distribute among his Companions. A small goat was left over and he mentioned that to the Messenger of Allah. He said: "Sacrifice it yourself}}
\hadithdefcmd{nasai}{4380}{أَخْبَرَنَا يَحْيَى بْنُ دُرُسْتَ، قَالَ حَدَّثَنَا أَبُو إِسْمَاعِيلَ، - وَهُوَ الْقَنَّادُ - قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنِي بَعْجَةُ بْنُ عَبْدِ اللَّهِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَسَّمَ بَيْنَ أَصْحَابِهِ ضَحَايَا فَصَارَتْ لِي جَذَعَةٌ فَقُلْتُ يَا رَسُولَ اللَّهِ صَارَتْ لِي جَذَعَةٌ ‏.‏ فَقَالَ ‏ "‏ ضَحِّ بِهَا ‏"‏ ‏.‏\hadithno{4380}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Uqbah bin 'Amir that:the Messenger of Allah divided some sacrificial animals among his Companions, and I got a Jadh'ah sheep. I said: 'O Messenger of Allah, I got a Jadh'ah sheep.' He said: 'Sacrifice it}}
\hadithdefcmd{nasai}{4381}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ بَعْجَةَ بْنِ عَبْدِ اللَّهِ الْجُهَنِيِّ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ قَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَصْحَابِهِ أَضَاحِيَّ فَأَصَابَنِي جَذَعَةٌ فَقُلْتُ يَا رَسُولَ اللَّهِ أَصَابَتْنِي جَذَعَةٌ ‏.‏ فَقَالَ ‏ "‏ ضَحِّ بِهَا ‏"‏ ‏.‏\hadithno{4381}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Uqbah bin 'Amir said:"The Messenger of Allah divided some sacrificial animals among his Companions, and I got a Jadh'ah sheep. I said: 'O Messenger of Allah, I got a Jadh'ah sheep.' He said: 'Sacrifice it}}
\hadithdefcmd{nasai}{4382}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ مُعَاذِ بْنِ عَبْدِ اللَّهِ بْنِ خُبَيْبٍ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ ضَحَّيْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِجَذَعٍ مِنَ الضَّأْنِ ‏.‏\hadithno{4382}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{it was narrated that 'Uqbah bin 'Amir said:'We sacrificed a Jadh'ah sheep with the Messenger of Allah}}
\hadithdefcmd{nasai}{4383}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، فِي حَدِيثِهِ عَنْ أَبِي الأَحْوَصِ، عَنِ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، قَالَ كُنَّا فِي سَفَرٍ فَحَضَرَ الأَضْحَى فَجَعَلَ الرَّجُلُ مِنَّا يَشْتَرِي الْمُسِنَّةَ بِالْجَذَعَتَيْنِ وَالثَّلاَثَةِ فَقَالَ لَنَا رَجُلٌ مِنْ مُزَيْنَةَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَحَضَرَ هَذَا الْيَوْمُ فَجَعَلَ الرَّجُلُ يَطْلُبُ الْمُسِنَّةَ بِالْجَذَعَتَيْنِ وَالثَّلاَثَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْجَذَعَ يُوفِي مِمَّا يُوفِي مِنْهُ الثَّنِيُّ ‏"‏ ‏.‏\hadithno{4383}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Asim bin Kulaib that his father said:"We were on a journey and the day of Al-adha came, so we started to by sheep, a Musinnah for two or three Jadh'ahs. A man from Muzainah said to us: 'We were with the Messenger of Allah on a journey when this came, and we stated to look for sheep, (offering to buy) aMusinnah for two or three Jadh'ahs. Then the Messenger of Allah said: "A Jadh'ah is sufficient for that for which a Thani is sufficient}}
\hadithdefcmd{nasai}{4384}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ رَجُلٍ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم قَبْلَ الأَضْحَى بِيَوْمَيْنِ نُعْطِي الْجَذَعَتَيْنِ بِالثَّنِيَّةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْجَذَعَةَ تُجْزِئُ مَا تُجْزِئُ مِنْهُ الثَّنِيَّةُ ‏"‏ ‏.‏\hadithno{4384}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Asim bin Kulaib said:"I heard my father narrating from a man who said: 'We were with the Messenger of Allah two days before Al-Adha and we started to offer two Jadh ahs for one Thaniiyah, Then the Messenger of Allah said: 'A Jadh'ah is sufficient for that for which a Thaniyah is sufficient}}
\hadithdefcmd{nasai}{4385}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ عَبْدِ الْعَزِيزِ، - وَهُوَ ابْنُ صُهَيْبٍ - عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُضَحِّي بِكَبْشَيْنِ ‏.‏ قَالَ أَنَسٌ وَأَنَا أُضَحِّي بِكَبْشَيْنِ ‏.‏\hadithno{4385}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated form Anas that:the Messenger of Allah used to sacrifice two rams. And Anas said: "And I sacrifice two rams}}
\hadithdefcmd{nasai}{4386}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ خَالِدٍ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ ضَحَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِكَبْشَيْنِ أَمْلَحَيْنِ ‏.‏\hadithno{4386}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ans said:"The Messenger of Allah sacrificed two Amlah rams}}
\hadithdefcmd{nasai}{4387}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ ضَحَّى النَّبِيُّ صلى الله عليه وسلم بِكَبْشَيْنِ أَمْلَحَيْنِ أَقْرَنَيْنِ ذَبَحَهُمَا بِيَدِهِ وَسَمَّى وَكَبَّرَ وَوَضَعَ رِجْلَهُ عَلَى صِفَاحِهِمَا ‏.‏\hadithno{4387}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The Prophet sacrificed two horned, Amlah rams, slaughtering them with his own hand, pronouncing the name of Allah, and saying: 'Allahu Akbar, and placing his foot on their sides}}
\hadithdefcmd{nasai}{4388}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ وَرْدَانَ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ أَضْحَى وَانْكَفَأَ إِلَى كَبْشَيْنِ أَمْلَحَيْنِ فَذَبَحَهُمَا ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{4388}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenge of Allah addressed us on the Day of Sacrifice, and he went toward two Amlah rams and sacrificed them." An abridgment. (Sahih)}}
\hadithdefcmd{nasai}{4389}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، فِي حَدِيثِهِ عَنْ يَزِيدَ بْنِ زُرَيْعٍ، عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، قَالَ ثُمَّ انْصَرَفَ - كَأَنَّهُ يَعْنِي النَّبِيَّ صلى الله عليه وسلم - يَوْمَ النَّحْرِ إِلَى كَبْشَيْنِ أَمْلَحَيْنِ فَذَبَحَهُمَا وَإِلَى جُذَيْعَةٍ مِنَ الْغَنَمِ فَقَسَمَهَا بَيْنَنَا ‏.‏\hadithno{4389}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Adbur-Rahman bin Abi Bakrah that his father said:"Then he" meaning the Prophet on the Day of Sacrifice - "Went toward two Amlah rams and sacrificed them, then (he went toward) a small flock of sheep and distributed them among us." (Sahih)}}
\hadithdefcmd{nasai}{4390}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ أَبُو سَعِيدٍ الأَشَجُّ، قَالَ حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ، قَالَ ضَحَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِكَبْشٍ أَقْرَنَ فَحِيلٍ يَمْشِي فِي سَوَادٍ وَيَأْكُلُ فِي سَوَادٍ وَيَنْظُرُ فِي سَوَادٍ ‏.‏\hadithno{4390}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa'eed said:"The Messenger of Allah sacrificed a horned, intact ram, with black feet some black at the stomach and black around its eyes." (Sahih)}}
\hadithdefcmd{nasai}{4391}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ أَبِيهِ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ بْنِ رَافِعٍ، عَنْ جَدِّهِ، رَافِعِ بْنِ خَدِيجٍ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَجْعَلُ فِي قَسْمِ الْغَنَائِمِ عَشْرًا مِنَ الشَّاءِ بِبَعِيرٍ ‏.‏ قَالَ شُعْبَةُ وَأَكْبَرُ عِلْمِي أَنِّي سَمِعْتُهُ مِنْ سَعِيدِ بْنِ مَسْرُوقٍ وَحَدَّثَنِي بِهِ سُفْيَانُ عَنْهُ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{4391}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Rafi bin Khadij Said:"When distributing the spoils of war, the Messenger of Allah used to make ten sheep equivalent to one camel." Shu'bah said: "I know most if it from what I heard form Sa'eed bin Masruq, and Sufyan narrated it to me." (Sahih)}}
\hadithdefcmd{nasai}{4392}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ بْنِ غَزْوَانَ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ حُسَيْنٍ، - يَعْنِي ابْنَ وَاقِدٍ - عَنْ عِلْبَاءَ بْنِ أَحْمَرَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَحَضَرَ النَّحْرُ فَاشْتَرَكْنَا فِي الْبَعِيرِ عَنْ عَشْرَةٍ وَالْبَقَرَةِ عَنْ سَبْعَةٍ ‏.‏\hadithno{4392}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"We were with the Mesenger of Allah on a journey, when the Day of Sacrifice came, so we shared a camel among ten men, and a cow among seven}}
\hadithdefcmd{nasai}{4393}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ يَحْيَى، عَنْ عَبْدِ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ كُنَّا نَتَمَتَّعُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَنَذْبَحُ الْبَقَرَةَ عَنْ سَبْعَةٍ وَنَشْتَرِكُ فِيهَا ‏.‏\hadithno{4393}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"We would make Tamattu' when the Prophet was with us, and we would sacrifice a cow on behalf of seven people, sharing it among ourselves." (Sahih)}}
\hadithdefcmd{nasai}{4394}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنِ ابْنِ أَبِي زَائِدَةَ، قَالَ أَنْبَأَنَا أَبِي، عَنْ فِرَاسٍ، عَنْ عَامِرٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، ح وَأَنْبَأَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ، - فَذَكَرَ أَحَدُهُمَا مَا لَمْ يَذْكُرِ الآخَرُ - قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الأَضْحَى فَقَالَ ‏"‏ مَنْ وَجَّهَ قِبْلَتَنَا وَصَلَّى صَلاَتَنَا وَنَسَكَ نُسُكَنَا فَلاَ يَذْبَحْ حَتَّى يُصَلِّيَ ‏"‏ ‏.‏ فَقَامَ خَالِي فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي عَجَّلْتُ نُسُكِي لأُطْعِمَ أَهْلِي وَأَهْلَ دَارِي أَوْ أَهْلِي وَجِيرَانِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعِدْ ذِبْحًا آخَرَ ‏"‏ ‏.‏ قَالَ فَإِنَّ عِنْدِي عَنَاقَ لَبَنٍ هِيَ أَحَبُّ إِلَىَّ مِنْ شَاتَىْ لَحْمٍ ‏.‏ قَالَ ‏"‏ اذْبَحْهَا فَإِنَّهَا خَيْرُ نَسِيكَتَيْكَ وَلاَ تَقْضِي جَذَعَةٌ عَنْ أَحَدٍ بَعْدَكَ ‏"‏ ‏.‏\hadithno{4394}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Bara bin 'Azib said:"The Messenger of Allah stood up on the Day of Sacrifice and Said: 'Whoever turn toward our Qiblah and prays as we pray and offers the same sacrifice as we do, let him not offer his sacrifice until he has prayed; My maternal uncle stood up and said: 'O Messenger of Allah, I hastened to slaughter my sacrifice, so that I could feed my family,. And the members of my household,; or my family and my neighbors,; The Messenger of Allah said; 'Offer another sacrifice,; He said: 'I have a suckling she-goat kid that is dearer to me than two sheep raised for meat,' He said: 'Sacrifice it, for it is the better of your two sacrifices. But no Jadh'ah will do as a sacrifice for anyone after you."' (Sahih)}}
\hadithdefcmd{nasai}{4395}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ مَنْصُورٍ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ النَّحْرِ بَعْدَ الصَّلاَةِ ثُمَّ قَالَ ‏"‏ مَنْ صَلَّى صَلاَتَنَا وَنَسَكَ نُسُكَنَا فَقَدْ أَصَابَ النُّسُكَ وَمَنْ نَسَكَ قَبْلَ الصَّلاَةِ فَتِلْكَ شَاةُ لَحْمٍ ‏"‏ ‏.‏ فَقَالَ أَبُو بُرْدَةَ يَا رَسُولَ اللَّهِ وَاللَّهِ لَقَدْ نَسَكْتُ قَبْلَ أَنْ أَخْرُجَ إِلَى الصَّلاَةِ وَعَرَفْتُ أَنَّ الْيَوْمَ يَوْمَ أَكْلٍ وَشُرْبٍ فَتَعَجَّلْتُ فَأَكَلْتُ وَأَطْعَمْتُ أَهْلِي وَجِيرَانِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تِلْكَ شَاةُ لَحْمٍ ‏"‏ ‏.‏ قَالَ فَإِنَّ عِنْدِي عَنَاقًا جَذَعَةً خَيْرٌ مِنْ شَاتَىْ لَحْمٍ فَهَلْ تُجْزِئُ عَنِّي قَالَ ‏"‏ نَعَمْ وَلَنْ تَجْزِيَ عَنْ أَحَدٍ بَعْدَكَ ‏"‏ ‏.‏\hadithno{4395}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Bara bin 'Azib said:"The Messenger of Allah addressed us on the Day of Sacrifice and said: 'whoever prays as we pray nand offers the sacrtifice as we do, has done the rituals properly. Whoever offered the sacrifice before the prayer, that is just a sheep for meat." Abu Burdah said: 'O Messengers of Allah, by Allah, I offered my sacrifice before I went out to pray. I knew that this day is a day of eating and drinking, so I hastened to eat and to feed my family and my neighbors.' The Messenger of Allah said: 'The Messenger of Allah said; 'That was just a sheep for meat.' He said: 'I have a Jadh'ah she-goat that is better than two sheep for meat; will it suffice for me (as a sacrifice)?' He said: 'Yes, but it will never suff8ice for anyone after you."' (Sahih)}}
\hadithdefcmd{nasai}{4396}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ النَّحْرِ ‏ "‏ مَنْ كَانَ ذَبَحَ قَبْلَ الصَّلاَةِ فَلْيُعِدْ ‏"‏ ‏.‏ فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ هَذَا يَوْمٌ يُشْتَهَى فِيهِ اللَّحْمُ فَذَكَرَ هَنَةً مِنْ جِيرَانِهِ كَأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَدَّقَهُ ‏.‏ قَالَ عِنْدِي جَذَعَةٌ هِيَ أَحَبُّ إِلَىَّ مِنْ شَاتَىْ لَحْمٍ ‏.‏ فَرَخَّصَ لَهُ فَلاَ أَدْرِي أَبَلَغَتْ رُخْصَتُهُ مَنْ سِوَاهُ أَمْ لاَ ثُمَّ انْكَفَأَ إِلَى كَبْشَيْنِ فَذَبَحَهُمَا ‏.‏\hadithno{4396}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"The Messenger of Allah said on the Day of Sacrifice:' Whoever slaughtered his sacrifice before the prayer, let him repeat it.' A man stood up and said: 'O Messenger of Allah, this is a day when people want to eat meat.' He mentioned that his neighbors were poor and it was as if the Messenger of Allah believed him. He said: 'I have a Jadh'ah that is dearer to me than tow sheep for meat.; So he granted him a concession (allowing him to sacrifice it) but I do not know whether it applied to anyone else or not. Then he went toward two rams and sacrificed them." (Sahih)}}
\hadithdefcmd{nasai}{4397}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ يَحْيَى، ح وَأَنْبَأَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ بُشَيْرِ بْنِ يَسَارٍ، عَنْ أَبِي بُرْدَةَ بْنِ نِيَارٍ، أَنَّهُ ذَبَحَ قَبْلَ النَّبِيِّ صلى الله عليه وسلم فَأَمَرَهُ النَّبِيُّ صلى الله عليه وسلم أَنْ يُعِيدَ ‏.‏ قَالَ عِنْدِي عَنَاقُ جَذَعَةٍ هِيَ أَحَبُّ إِلَىَّ مِنْ مُسِنَّتَيْنِ ‏.‏ قَالَ ‏ "‏ اذْبَحْهَا ‏"‏ ‏.‏ فِي حَدِيثِ عُبَيْدِ اللَّهِ فَقَالَ إِنِّي لاَ أَجِدُ إِلاَّ جَذَعَةً ‏.‏ فَأَمَرَهُ أَنْ يَذْبَحَ ‏.‏\hadithno{4397}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Burdah bin Niyar that he slaughtered (his sacrifice) before the Prophet and the Prophet told him to repeat it. He said:"I have a Jadh'ah she-goat that is dearer to me than two Muslinnahs." He said: "Sacrifice it," According to the Hadith of: Ubaidullah, he said: "I cannot find anything but a Jadh'ah," and he told him to slaughter it. (Sahih)}}
\hadithdefcmd{nasai}{4398}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ جُنْدُبِ بْنِ سُفْيَانَ، قَالَ ضَحَّيْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَضْحَى ذَاتَ يَوْمٍ فَإِذَا النَّاسُ قَدْ ذَبَحُوا ضَحَايَاهُمْ قَبْلَ الصَّلاَةِ فَلَمَّا انْصَرَفَ رَآهُمُ النَّبِيُّ صلى الله عليه وسلم أَنَّهُمْ ذَبَحُوا قَبْلَ الصَّلاَةِ فَقَالَ ‏ "‏ مَنْ ذَبَحَ قَبْلَ الصَّلاَةِ فَلْيَذْبَحْ مَكَانَهَا أُخْرَى وَمَنْ كَانَ لَمْ يَذْبَحْ حَتَّى صَلَّيْنَا فَلْيَذْبَحْ عَلَى اسْمِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4398}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jundab bin Sufyan said:"We slaughtered the sacrifice with the Messenger of Allah on day, and the people slaughtered their sacrifices before the prayer. When he finished (the prayer) the Prophet saw that they had slaughtered their sacrifices before the prayer. He said: "Whoever slaughtered his sacrifice before the prayer, let him slaughter another in its place, and whoever did not slaughter his sacrifice until we had prayed, let him slaughter it in the name of Allah, The Mighty and Sublime," (Sahih)}}
\hadithdefcmd{nasai}{4399}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ حَدَّثَنَا دَاوُدُ، عَنْ عَامِرٍ، عَنْ مُحَمَّدِ بْنِ صَفْوَانَ، أَنَّهُ أَصَابَ أَرْنَبَيْنِ وَلَمْ يَجِدْ حَدِيدَةً يَذْبَحُهُمَا بِهِ فَذَكَّاهُمَا بِمَرْوَةٍ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي اصْطَدْتُ أَرْنَبَيْنِ فَلَمْ أَجِدْ حَدِيدَةً أُذَكِّيهِمَا بِهِ فَذَكَّيْتُهُمَا بِمَرْوَةٍ أَفَآكُلُ قَالَ ‏ "‏ كُلْ ‏"‏ ‏.‏\hadithno{4399}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Muhammad bin Safwan that:he caught two rabbits and he could not find a knife with which to slaughter then, so he slaughtered them with Marwah. Then he came to the Prophet and said: "O Mesenger of Allah! I caught two rabbits but I could not find a knife with which to slaughter them, so I slaughtered them with Marwah;l can I eat them?" He said: "Eat (them)}}
\hadithdefcmd{nasai}{4400}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا حَاضِرُ بْنُ الْمُهَاجِرِ الْبَاهِلِيُّ، قَالَ سَمِعْتُ سُلَيْمَانَ بْنَ يَسَارٍ، يُحَدِّثُ عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ ذِئْبًا، نَيَّبَ فِي شَاةٍ فَذَبَحُوهَا بِالْمَرْوَةِ فَرَخَّصَ النَّبِيُّ صلى الله عليه وسلم فِي أَكْلِهَا ‏.‏\hadithno{4400}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Zaid bin Thabit that:a wolf bit a sheep so he slaughtered it with Marwah, and the Prophet allowed him to eat it}}
\hadithdefcmd{nasai}{4401}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، وَإِسْمَاعِيلُ بْنُ مَسْعُودٍ، عَنْ خَالِدٍ، عَنْ شُعْبَةَ، عَنْ سِمَاكٍ، قَالَ سَمِعْتُ مُرِّيَّ بْنَ قَطَرِيٍّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أُرْسِلُ كَلْبِي فَآخُذُ الصَّيْدَ فَلاَ أَجِدُ مَا أُذَكِّيهِ بِهِ فَأَذْبَحُهُ بِالْمَرْوَةِ وَبِالْعَصَا ‏.‏ قَالَ ‏ "‏ أَنْهِرِ الدَّمَ بِمَا شِئْتَ وَاذْكُرِ اسْمَ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4401}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Adiyy bin Hatim said:"I said: 'O Messenger of Allah, I release my dog and I catch the game, but I cannot find anything to slaughter it with, so I slaughter it with a Marwah or a stick,; He said: 'Shed the blood with whatever you wish, and say the name of Allah}}
\hadithdefcmd{nasai}{4402}{أَخْبَرَنِي مُحَمَّدُ بْنُ مَعْمَرٍ، قَالَ حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، قَالَ حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ زَيْدِ بْنِ أَسْلَمَ، فَلَقِيتُ زَيْدَ بْنَ أَسْلَمَ فَحَدَّثَنِي عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كَانَتْ لِرَجُلٍ مِنَ الأَنْصَارِ نَاقَةٌ تَرْعَى فِي قِبَلِ أُحُدٍ فَعُرِضَ لَهَا فَنَحَرَهَا بِوَتَدٍ ‏.‏ فَقُلْتُ لِزَيْدٍ وَتَدٌ مِنْ خَشَبٍ أَوْ حَدِيدٍ قَالَ لاَ بَلْ خَشَبٌ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَسَأَلَهُ فَأَمَرَهُ بِأَكْلِهَا ‏.‏\hadithno{4402}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"A man form among the Ansar had a she-camel which used to graze in front of Uhud. Something happened to it, and he slaughtered it with a stake,"- (Ayyub, one of the narrators, said) I said to Zaid:' A stake of wood or of iron?" He said "No of wood."- "Then he went to the Prophet and asked him, and he told him to eat it." (Sahih)}}
\hadithdefcmd{nasai}{4403}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عُمَرَ بْنِ سَعِيدٍ، عَنْ أَبِيهِ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا أَنْهَرَ الدَّمَ وَذُكِرَ اسْمُ اللَّهِ فَكُلْ إِلاَّ بِسِنٍّ أَوْ ظُفْرٍ ‏"‏ ‏.‏\hadithno{4403}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Rafi bin Khadij that the Messenger of Allah said:"If the blood is shed and the name of Allah is mentioned, then eat, unless (it is slaughtered) with teeth or nails}}
\hadithdefcmd{nasai}{4404}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي الأَحْوَصِ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، رَافِعِ بْنِ خَدِيجٍ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا نَلْقَى الْعَدُوَّ غَدًا وَلَيْسَ مَعَنَا مُدًى ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أَنْهَرَ الدَّمَ وَذُكِرَ اسْمُ اللَّهِ عَزَّ وَجَلَّ فَكُلُوا مَا لَمْ يَكُنْ سِنًّا أَوْ ظُفْرًا وَسَأُحَدِّثُكُمْ عَنْ ذَلِكَ أَمَّا السِّنُّ فَعَظْمٌ وَأَمَّا الظُّفْرُ فَمُدَى الْحَبَشَةِ ‏"‏ ‏.‏\hadithno{4404}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Rafi bin Khadij said:"I said: 'O Messenger of Allah we are going to meet the enemy tomorrow and we do not have any knives.' The Messenger of Allah said: "If the blood is shed and the name of Allah is mentioned, then eat, unless (it is slaughtered (with teeth or nails, and I will tell you about that. As for teeth, they are bones, and as for nails, they are the knives of the Ethiopians."' (Sahih)}}
\hadithdefcmd{nasai}{4405}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ، عَنْ شَدَّادِ بْنِ أَوْسٍ، قَالَ اثْنَتَانِ حَفِظْتُهُمَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ كَتَبَ الإِحْسَانَ عَلَى كُلِّ شَىْءٍ فَإِذَا قَتَلْتُمْ فَأَحْسِنُوا الْقِتْلَةَ وَإِذَا ذَبَحْتُمْ فَأَحْسِنُوا الذِّبْحَةَ وَلْيُحِدَّ أَحَدُكُمْ شَفْرَتَهُ وَلْيُرِحْ ذَبِيحَتَهُ ‏"‏ ‏.‏\hadithno{4405}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Shaddad bin Aws said:"There are two things that I memorized from the Messenger of Allah, who said: 'Allah has decreed proficiency in all things, so when you kill, kill well, and when you slaughter, slaughter well. Let one of you sharpen his blade and spare suffering to the animal he slaughters.'" (Sahih)}}
\hadithdefcmd{nasai}{4406}{أَخْبَرَنَا عِيسَى بْنُ أَحْمَدَ الْعَسْقَلاَنِيُّ، - عَسْقَلاَنُ بَلْخٍ - قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، حَدَّثَهُ عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ نَحَرْنَا فَرَسًا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَكَلْنَاهُ ‏.‏\hadithno{4406}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Asma bint Abi Bakr said:"We slaughtered (Naharna) a horse during the time of the Messenger of Allah and ate it". (Sahih)}}
\hadithdefcmd{nasai}{4407}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ حَاضِرَ بْنَ الْمُهَاجِرِ الْبَاهِلِيَّ، قَالَ سَمِعْتُ سُلَيْمَانَ بْنَ يَسَارٍ، يُحَدِّثُ عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ ذِئْبًا، نَيَّبَ فِي شَاةٍ فَذَبَحُوهَا بِمَرْوَةٍ فَرَخَّصَ النَّبِيُّ صلى الله عليه وسلم فِي أَكْلِهَا ‏.‏\hadithno{4407}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zaid bin Thabit that:a wolf attacked a sheep so they slaughtered it with a Marwah, and the Prophet allowed it to be eaten}}
\hadithdefcmd{nasai}{4408}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ أَبِي الْعُشَرَاءِ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَمَا تَكُونُ الذَّكَاةُ إِلاَّ فِي الْحَلْقِ وَاللَّبَّةِ قَالَ ‏ "‏ لَوْ طَعَنْتَ فِي فَخِذِهَا لأَجْزَأَكَ ‏"‏ ‏.‏\hadithno{4408}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Ushara' that his father said:"I said: "O Messenger of Allah, is slaughtering only in the throat or upper chest?" He said: 'If you stab it in the thigh, that will suffice,"'(Daif)}}
\hadithdefcmd{nasai}{4409}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رَافِعٍ، عَنْ رَافِعٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا لاَقُو الْعَدُوِّ غَدًا وَلَيْسَ مَعَنَا مُدًى ‏.‏ قَالَ ‏"‏ مَا أَنْهَرَ الدَّمَ وَذُكِرَ اسْمُ اللَّهِ عَزَّ وَجَلَّ فَكُلْ مَا خَلاَ السِّنَّ وَالظُّفْرَ ‏"‏ ‏.‏ قَالَ فَأَصَابَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَهْبًا فَنَدَّ بَعِيرٌ فَرَمَاهُ رَجُلٌ بِسَهْمٍ فَحَبَسَهُ فَقَالَ ‏"‏ إِنَّ لِهَذِهِ النَّعَمِ - أَوْ قَالَ الإِبِلِ - أَوَابِدَ كَأَوَابِدِ الْوَحْشِ فَمَا غَلَبَكُمْ مِنْهَا فَافْعَلُوا بِهِ هَكَذَا ‏"‏ ‏.‏\hadithno{4409}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Rafi said:"I said: 'O Messenger of Allah, we are going to meet the enemy tomorrow, and we do not have any knives.' He said: 'If the blood is shed and the name of Allah is mentioned, then eat, unlike (it is slaughtered) with teeth or nails." Then the Messenger of Allah got some spoils of war and a camel ran away. A man shot and arrow at it and stopped it. He (the Prophet) said; 'Some of these animals - or 'these camels'- 'are untamed like wild animals, so if one of them goes out of your control, do the same."' (Sahih)}}
\hadithdefcmd{nasai}{4410}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ أَنْبَأَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا لاَقُو الْعَدُوِّ غَدًا وَلَيْسَتْ مَعَنَا مُدًى ‏.‏ قَالَ ‏"‏ مَا أَنْهَرَ الدَّمَ وَذُكِرَ اسْمُ اللَّهِ عَزَّ وَجَلَّ فَكُلْ لَيْسَ السِّنَّ وَالظُّفْرَ وَسَأُحَدِّثُكُمْ أَمَّا السِّنُّ فَعَظْمٌ وَأَمَّا الظُّفْرُ فَمُدَى الْحَبَشَةِ ‏"‏ ‏.‏ وَأَصَبْنَا نَهْبَةَ إِبِلٍ أَوْ غَنَمٍ فَنَدَّ مِنْهَا بَعِيرٌ فَرَمَاهُ رَجُلٌ بِسَهْمٍ فَحَبَسَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ لِهَذِهِ الإِبِلِ أَوَابِدَ كَأَوَابِدِ الْوَحْشِ فَإِذَا غَلَبَكُمْ مِنْهَا شَىْءٌ فَافْعَلُوا بِهِ هَكَذَا ‏"‏ ‏.‏\hadithno{4410}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Rafi bin Khadij said:"I said: 'O Messenger of Allah, we are going to meet the enemy tomorrow, and we do not have any knives.' He said: If the blood is shed and the name of Allah is mentioned, then eat, unlike (it is slaughtered) with teeth or nails and I will tell you about that. As for teeth, they are bones, and as for nails, they are the knives of the Ethiopians,; We acquired some spoils of war including sheep or camels, and a camel ran away, so a man shot an arrow at it an stopped it. The Messenger of Allah said: 'some of these animals' or 'these camels'- 'are untamed like wild animals, so if one of them goes out of your control, do the same." (Sahih)}}
\hadithdefcmd{nasai}{4411}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، قَالَ أَنْبَأَنَا إِسْرَائِيلُ، عَنْ مَنْصُورٍ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ الرَّحَبِيِّ، عَنْ أَبِي الأَشْعَثِ، عَنْ شَدَّادِ بْنِ أَوْسٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ كَتَبَ الإِحْسَانَ عَلَى كُلِّ شَىْءٍ فَإِذَا قَتَلْتُمْ فَأَحْسِنُوا الْقِتْلَةَ وَإِذَا ذَبَحْتُمْ فَأَحْسِنُوا الذَّبْحَ وَلْيُحِدَّ أَحَدُكُمْ إِذَا ذَبَحَ شَفْرَتَهُ وَلْيُرِحْ ذَبِيحَتَهُ ‏"‏ ‏.‏\hadithno{4411}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Shaddad bin Aws said:"I heard the Messenger of Allah say: 'Allah, the Mighty and Sublime, has decreed proficiency in all things, so when you kill, kill well, and when you slaughter, slaughter well. Let one of you sharpen his blade and spare suffering to the animal he slaughters" (Sahih)}}
\hadithdefcmd{nasai}{4412}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ أَبُو عَمَّارٍ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، عَنْ شَدَّادِ بْنِ أَوْسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ كَتَبَ الإِحْسَانَ عَلَى كُلِّ شَىْءٍ فَإِذَا قَتَلْتُمْ فَأَحْسِنُوا الْقِتْلَةَ وَإِذَا ذَبَحْتُمْ فَأَحْسِنُوا الذَّبْحَ وَلْيُحِدَّ أَحَدُكُمْ شَفْرَتَهُ وَلْيُرِحْ ذَبِيحَتَهُ ‏"‏ ‏.‏\hadithno{4412}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Shaddad bin Aws said:"The Messenger of Allah said: 'Allah has decreed proficiency in all things, so when you kill, kill well, and when you slaughter, slaughter well. Let one of you sharpen his blade and spare suffering to the animal he slaughters}}
\hadithdefcmd{nasai}{4413}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ، عَنْ شَدَّادِ بْنِ أَوْسٍ، قَالَ سَمِعْتُ مِنَ النَّبِيِّ، صلى الله عليه وسلم اثْنَتَيْنِ فَقَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ كَتَبَ الإِحْسَانَ عَلَى كُلِّ شَىْءٍ فَإِذَا قَتَلْتُمْ فَأَحْسِنُوا الْقِتْلَةَ وَإِذَا ذَبَحْتُمْ فَأَحْسِنُوا الذَّبْحَ وَلْيُحِدَّ أَحَدُكُمْ شَفْرَتَهُ ثُمَّ لِيُرِحْ ذَبِيحَتَهُ ‏"‏ ‏.‏\hadithno{4413}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Shadad bin Aws said:"I heard two things from the Messenger of Allah He said 'Allah, the Mighty and Sublime, ahs decreed proficiency in all things, so when you kill, kill well, and when you slaughter, slaughter well. Let one of you sharpen his blade and spear suffering to the animal he slaughter."" (Sahih)}}
\hadithdefcmd{nasai}{4414}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا خَالِدٌ، ح وَأَنْبَأَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ، عَنْ شَدَّادِ بْنِ أَوْسٍ، قَالَ ثِنْتَانِ حَفِظْتُهُمَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ كَتَبَ الإِحْسَانَ عَلَى كُلِّ شَىْءٍ فَإِذَا قَتَلْتُمْ فَأَحْسِنُوا الْقِتْلَةَ وَإِذَا ذَبَحْتُمْ فَأَحْسِنُوا الذِّبْحَةَ لِيُحِدَّ أَحَدُكُمْ شَفْرَتَهُ وَلْيُرِحْ ذَبِيحَتَهُ ‏"‏ ‏.‏\hadithno{4414}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Shaddad bin Aws said:"Two things that I memorized form the Messenger of Allah; 'Allah, the Mighty and Sublime, has decreed proficiency in all things, so when you kill, kill well, and when you slaughter, slaughter well. Let one of you sharpen his blade and spare suffering to the animal he slaughter,"" (Sahih)}}
\hadithdefcmd{nasai}{4415}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، أَخْبَرَنِي قَتَادَةُ، قَالَ سَمِعْتُ أَنَسًا، قَالَ ضَحَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِكَبْشَيْنِ أَمْلَحَيْنِ أَقْرَنَيْنِ يُكَبِّرُ وَيُسَمِّي وَلَقَدْ رَأَيْتُهُ يَذْبَحُهُمَا بِيَدِهِ وَاضِعًا عَلَى صِفَاحِهِمَا قَدَمَهُ ‏.‏ قُلْتُ أَنْتَ سَمِعْتَهُ مِنْهُ قَالَ نَعَمْ ‏.‏\hadithno{4415}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas said:"The Messenger of Allah sacrificed two horned, Amlah rams, saying: 'Allah Akbar and pronouncing the Name of Allah. I saw him slaughtering them with his own hand, and placing his foot on their sides." I said: You heard it from Him? He said: Yes. (Sahih)}}
\hadithdefcmd{nasai}{4416}{أَخْبَرَنَا أَحْمَدُ بْنُ نَاصِحٍ، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، قَالَ حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُضَحِّي بِكَبْشَيْنِ أَمْلَحَيْنِ أَقْرَنَيْنِ وَكَانَ يُسَمِّي وَيُكَبِّرُ وَلَقَدْ رَأَيْتُهُ يَذْبَحُهُمَا بِيَدِهِ وَاضِعًا رِجْلَهُ عَلَى صِفَاحِهِمَا ‏.‏\hadithno{4416}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Anas bin Malik said:"The Messenger of Allah used to sacrifice two pronounce the name of Allah and say: 'Allah Akabar,' and I saw him slaughtering them with his own hand, and placing his foot on their sides "(Sahih)}}
\hadithdefcmd{nasai}{4417}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا بْنِ دِينَارٍ، قَالَ حَدَّثَنَا مُصْعَبُ بْنُ الْمِقْدَامِ، عَنِ الْحَسَنِ، - يَعْنِي ابْنَ صَالِحٍ - عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ لَقَدْ رَأَيْتُهُ - يَعْنِي النَّبِيَّ صلى الله عليه وسلم - يَذْبَحُهُمَا بِيَدِهِ وَاضِعًا عَلَى صِفَاحِهِمَا قَدَمَهُ يُسَمِّي وَيُكَبِّرُ كَبْشَيْنِ أَمْلَحَيْنِ أَقْرَنَيْنِ ‏.‏\hadithno{4417}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas said:"I saw him: - meaning the Prophet - "slaughtering them with his own hand, and placing his foot on their sides, pronouncing the name of Allah and saying: 'Allah Akbar,' (sacrificing) two horned, Amlah rams." (Sahih)}}
\hadithdefcmd{nasai}{4418}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - قَالَ حَدَّثَنَا سَعِيدٌ، قَالَ حَدَّثَنَا قَتَادَةُ، أَنَّ أَنَسَ بْنَ مَالِكٍ، حَدَّثَهُمْ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم ضَحَّى بِكَبْشَيْنِ أَقْرَنَيْنِ أَمْلَحَيْنِ يَطَؤُ عَلَى صِفَاحِهِمَا وَيَذْبَحُهُمَا وَيُسَمِّي وَيُكَبِّرُ ‏.‏\hadithno{4418}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas bin Malik told them that:the Prophet sacrificed two Amlah horned rams, putting his foot on their sides and slaughtering them pronouncing the name of Allah, and saying: Allahu Akbar."" (Sahih)}}
\hadithdefcmd{nasai}{4419}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَحَرَ بَعْضَ بُدْنِهِ بِيَدِهِ وَنَحَرَ بَعْضَهَا غَيْرُهُ ‏.‏\hadithno{4419}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah that:the Messenger of Allah slaughtered some of his sacrificial animals with his won hand, and someone else slaughtered some of them. (Sahih)}}
\hadithdefcmd{nasai}{4420}{أَخْبَرَنَا قُتَيْبَةُ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، قَالَتْ نَحَرْنَا فَرَسًا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَكَلْنَاهُ ‏.‏ وَقَالَ قُتَيْبَةُ فِي حَدِيثِهِ فَأَكَلْنَا لَحْمَهُ ‏.‏ خَالَفَهُ عَبْدَةُ بْنُ سُلَيْمَانَ ‏.‏\hadithno{4420}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Asma said:"We slaughtered (Naharna) a horse during the time of Messenger of Allah and ate it." In his hadith Qutaibah (one of the narrators) said: "And we ate its meat." (Sahih ) 'Abdah bin sulaiman contradicted him}}
\hadithdefcmd{nasai}{4421}{أَخْبَرَنِي مُحَمَّدُ بْنُ آدَمَ، قَالَ حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، قَالَتْ ذَبَحْنَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَسًا وَنَحْنُ بِالْمَدِينَةِ فَأَكَلْنَاهُ ‏.‏\hadithno{4421}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Asma said:"We slaughtered (naharna) a horse during the time of the Messenger of Allah while we were in Al-Madinah, and we ate it." (Sahih)}}
\hadithdefcmd{nasai}{4422}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ - عَنِ ابْنِ حَيَّانَ، - يَعْنِي مَنْصُورًا - عَنْ عَامِرِ بْنِ وَاثِلَةَ، قَالَ سَأَلَ رَجُلٌ عَلِيًّا هَلْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُسِرُّ إِلَيْكَ بِشَىْءٍ دُونَ النَّاسِ فَغَضِبَ عَلِيٌّ حَتَّى احْمَرَّ وَجْهُهُ وَقَالَ مَا كَانَ يُسِرُّ إِلَىَّ شَيْئًا دُونَ النَّاسِ غَيْرَ أَنَّهُ حَدَّثَنِي بِأَرْبَعِ كَلِمَاتٍ وَأَنَا وَهُوَ فِي الْبَيْتِ فَقَالَ ‏ "‏ لَعَنَ اللَّهُ مَنْ لَعَنَ وَالِدَهُ وَلَعَنَ اللَّهُ مَنْ ذَبَحَ لِغَيْرِ اللَّهِ وَلَعَنَ اللَّهُ مَنْ آوَى مُحْدِثًا وَلَعَنَ اللَّهُ مَنْ غَيَّرَ مَنَارَ الأَرْضِ ‏"‏ ‏.‏\hadithno{4422}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Amir bin Wathilah said:"A man asked 'Ali" Did the Messenger of Allah used to tell you anything in secret that he did not tell the people?' Ali got so angry that his face turned red, and he said: 'He used not to tell me anything in secret that he di}}
\hadithdefcmd{nasai}{4423}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ تُؤْكَلَ لُحُومُ الأَضَاحِي بَعْدَ ثَلاَثٍ ‏.‏\hadithno{4423}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that:the Messenger of Allah forbade eating the meat of sacrificial animals after three days" (Sahih)}}
\hadithdefcmd{nasai}{4424}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، عَنْ غُنْدَرٍ، قَالَ حَدَّثَنَا مَعْمَرٌ، قَالَ حَدَّثَنَا الزُّهْرِيُّ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى ابْنِ عَوْفٍ قَالَ شَهِدْتُ عَلِيَّ بْنَ أَبِي طَالِبٍ كَرَّمَ اللَّهُ وَجْهَهُ فِي يَوْمِ عِيدٍ بَدَأَ بِالصَّلاَةِ قَبْلَ الْخُطْبَةِ ثُمَّ صَلَّى بِلاَ أَذَانٍ وَلاَ إِقَامَةٍ ثُمَّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى أَنْ يُمْسِكَ أَحَدٌ مِنْ نُسُكِهِ شَيْئًا فَوْقَ ثَلاَثَةِ أَيَّامٍ ‏.‏\hadithno{4424}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It ws narrated that Abu 'Ubaid - the freed slave of Ibn 'Awf - said:"I saw 'Ali bin Abi Talib - may Allah honor his face on the day of 'Id. He started with the prayer before the Khutbah, and then he prayed with no Adhan and no Iqamah. Then he said: 'I heard the Messenger of Allah forbidding anyone form keeping anything of his sacrificial animal for more than three days." (Sahih)}}
\hadithdefcmd{nasai}{4425}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَعْقُوبُ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ أَبَا عُبَيْدٍ، أَخْبَرَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ نَهَاكُمْ أَنْ تَأْكُلُوا لُحُومَ نُسُكِكُمْ فَوْقَ ثَلاَثٍ ‏.‏\hadithno{4425}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ali bin Abi Talib Said:"The Messenger of Allah has forbidden you from eating the meat of your sacrificaial animals for more than three day." (Sahih)}}
\hadithdefcmd{nasai}{4426}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ أَكْلِ لُحُومِ الضَّحَايَا بَعْدَ ثَلاَثٍ ثُمَّ قَالَ ‏ "‏ كُلُوا وَتَزَوَّدُوا وَادَّخِرُوا ‏"‏ ‏.‏\hadithno{4426}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin 'Abdullah that:the Messenger of Allah forbade eating the meat of the sacrificial animals after three days then he said: "Eat, take some with you (if traveling). And store some." ( Sahih)}}
\hadithdefcmd{nasai}{4427}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، زُغْبَةُ قَالَ أَنْبَأَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنِ ابْنِ خَبَّابٍ، - هُوَ عَبْدُ اللَّهِ بْنُ خَبَّابٍ - أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ، قَدِمَ مِنْ سَفَرٍ فَقَدَّمَ إِلَيْهِ أَهْلُهُ لَحْمًا مِنْ لُحُومِ الأَضَاحِي فَقَالَ مَا أَنَا بِآكِلِهِ حَتَّى أَسْأَلَ ‏.‏ فَانْطَلَقَ إِلَى أَخِيهِ لأُمِّهِ قَتَادَةَ بْنِ النُّعْمَانِ - وَكَانَ بَدْرِيًّا - فَسَأَلَهُ عَنْ ذَلِكَ فَقَالَ إِنَّهُ قَدْ حَدَثَ بَعْدَكَ أَمْرٌ نَقْضًا لِمَا كَانُوا نُهُوا عَنْهُ مِنْ أَكْلِ لُحُومِ الأَضَاحِي بَعْدَ ثَلاَثَةِ أَيَّامٍ ‏.‏\hadithno{4427}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn Khabbab - who is 'Abdullah bin Khabbab - that:Abu Sa 'eed Al- Kahudri arrived from a jouney and his family offered him some meat from the sacrificial animal. He said: "I am not going to eat it until I ask about it," So he went to his half-brother through his mother, Qatadah bin An- Nu man who had been presently at Badr, and asked him about that. He said: "The opposite of what you were forbidden occurred after that, and (Permission was granted) to eat the sacrificial meat after three days" (Sahih)}}
\hadithdefcmd{nasai}{4428}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سَعْدِ بْنِ إِسْحَاقَ، قَالَ حَدَّثَتْنِي زَيْنَبُ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُحُومِ الأَضَاحِي فَوْقَ ثَلاَثَةِ أَيَّامٍ فَقَدِمَ قَتَادَةُ بْنُ النُّعْمَانِ - وَكَانَ أَخَا أَبِي سَعِيدٍ لأُمِّهِ وَكَانَ بَدْرِيًّا - فَقَدَّمُوا إِلَيْهِ فَقَالَ أَلَيْسَ قَدْ نَهَى عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ أَبُو سَعِيدٍ إِنَّهُ قَدْ حَدَثَ فِيهِ أَمْرٌ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَانَا أَنْ نَأْكُلَهُ فَوْقَ ثَلاَثَةِ أَيَّامٍ ثُمَّ رَخَّصَ لَنَا أَنْ نَأْكُلَهُ وَنَدَّخِرَهُ ‏.‏\hadithno{4428}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that:the Messenger of Alllah forbade (Eating) the meat of sacrificial animals after three days. Then Qatadh bin An-Nu' man, who was brother of Abu Sa'eed through his mo0ther, and had been present at Badr, came and they offered him (some of the meat) .He said: "Didn't the Messenger of Allah forbid it?" Abu Sa eed said: "Something happened later. The Messenger of Allah forbade us to eat it for more than three days, then he allowed us to eat it and store it." (Sahih)}}
\hadithdefcmd{nasai}{4429}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، - وَهُوَ النُّفَيْلِيُّ - قَالَ حَدَّثَنَا زُهَيْرٌ، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ مَعْدَانَ بْنِ عِيسَى، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا زُبَيْدُ بْنُ الْحَارِثِ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي كُنْتُ نَهَيْتُكُمْ عَنْ ثَلاَثٍ عَنْ زِيَارَةِ الْقُبُورِ فَزُورُوهَا وَلْتَزِدْكُمْ زِيَارَتُهَا خَيْرًا وَنَهَيْتُكُمْ عَنْ لُحُومِ الأَضَاحِي بَعْدَ ثَلاَثٍ فَكُلُوا مِنْهَا وَأَمْسِكُوا مَا شِئْتُمْ وَنَهَيْتُكُمْ عَنِ الأَشْرِبَةِ فِي الأَوْعِيَةِ فَاشْرَبُوا فِي أَىِّ وِعَاءٍ شِئْتُمْ وَلاَ تَشْرَبُوا مُسْكِرًا ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ مُحَمَّدٌ ‏"‏ وَأَمْسِكُوا ‏"‏ ‏.‏\hadithno{4429}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Buraidah that his father said:" The Messenger of Allah said: 'I used to forbid you from doing three things: to visit graves, but now visit three, for you may benefit from that. And I used to forbid you (from eating) the meat of sacrificial animals after three days but now eat it, and keep whatever you want. A and I forbade you to drink form (certain kinds of) vessels, but now drink form whatever kind of vessel you want but do not drink any kind of intoxicant." (Sahih ) Muhammad (one of the narrators) did not mention: "kept (whatever you want)}}
\hadithdefcmd{nasai}{4430}{أَخْبَرَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، عَنِ الأَحْوَصِ بْنِ جَوَّابٍ، عَنْ عَمَّارِ بْنِ رُزَيْقٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الزُّبَيْرِ بْنِ عَدِيٍّ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي كُنْتُ نَهَيْتُكُمْ عَنْ لُحُومِ الأَضَاحِي بَعْدَ ثَلاَثٍ وَعَنِ النَّبِيذِ إِلاَّ فِي سِقَاءٍ وَعَنْ زِيَارَةِ الْقُبُورِ فَكُلُوا مِنْ لُحُومِ الأَضَاحِي مَا بَدَا لَكُمْ وَتَزَوَّدُوا وَادَّخِرُوا وَمَنْ أَرَادَ زِيَارَةَ الْقُبُورِ فَإِنَّهَا تُذَكِّرُ الآخِرَةَ وَاشْرَبُوا وَاتَّقُوا كُلَّ مُسْكِرٍ ‏"‏ ‏.‏\hadithno{4430}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Buraidah that his fhater said:"The Messenger of Allah said: "I used to forbid you (from eating) the meat of sacrificial animals after three days, and to (make) Nadidh except in a water skin, and to visit graves. But now eat whatever you want of the meat, or take some with you (when traveling) or store it: and whoever wants to visit graves, it will remind him of the Hereafter; and drink, but beware of any kind of intoxicant."' (Sahih)}}
\hadithdefcmd{nasai}{4431}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ مَالِكٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ دَفَّتْ دَافَّةٌ مِنْ أَهْلِ الْبَادِيَةِ حَضْرَةَ الأَضْحَى فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُلُوا وَادَّخِرُوا ثَلاَثًا ‏"‏ ‏.‏ فَلَمَّا كَانَ بَعْدَ ذَلِكَ قَالُوا يَا رَسُولَ اللَّهِ إِنَّ النَّاسَ كَانُوا يَنْتَفِعُونَ مِنْ أَضَاحِيهِمْ يَجْمِلُونَ مِنْهَا الْوَدَكَ وَيَتَّخِذُونَ مِنْهَا الأَسْقِيَةَ ‏.‏ قَالَ ‏"‏ وَمَا ذَاكَ ‏"‏ ‏.‏ قَالَ الَّذِي نَهَيْتَ مِنْ إِمْسَاكِ لُحُومِ الأَضَاحِي ‏.‏ قَالَ ‏"‏ إِنَّمَا نَهَيْتُ لِلدَّافَّةِ الَّتِي دَفَّتْ كُلُوا وَادَّخِرُوا وَتَصَدَّقُوا ‏"‏ ‏.‏\hadithno{4431}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:" "Some Bedouins came to Al-Madinah at the time of (Eid) Al-Adha and the Messenger of Allah said: 'Eat, and store (the meat) for three days.' After that they said: 'O Messenger of Allah, the people used to benefit form their sacrifices by melting down the fat, and (also) making water skins from them.' He said: 'Why are you asking?' He said: 'Because you forbade us form keeping the meat of the sacrificial animals.' He said: 'I only forbade that because of the Bedouins who came. (Now) eat it, store it and give it in charity," (Sahih)}}
\hadithdefcmd{nasai}{4432}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَابِسٍ، عَنْ أَبِيهِ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ فَقُلْتُ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ لُحُومِ الأَضَاحِي بَعْدَ ثَلاَثٍ قَالَتْ نَعَمْ أَصَابَ النَّاسَ شِدَّةٌ فَأَحَبَّ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُطْعِمَ الْغَنِيُّ الْفَقِيرَ ثُمَّ قَالَ لَقَدْ رَأَيْتُ آلَ مُحَمَّدٍ صلى الله عليه وسلم يَأْكُلُونَ الْكُرَاعَ بَعْدَ خَمْسَ عَشْرَةَ قُلْتُ مِمَّ ذَاكَ فَضَحِكَتْ فَقَالَتْ مَا شَبِعَ آلُ مُحَمَّدٍ صلى الله عليه وسلم مِنْ خُبْزٍ مَأْدُومٍ ثَلاَثَةَ أَيَّامٍ حَتَّى لَحِقَ بِاللَّهِ عَزَّ وَجَلَّ ‏.‏\hadithno{4432}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Abdur-Rahman bin 'Abis that his father said:"I came in to 'Aishah and said: 'Did the Messenger of Allah forbid (eating) the meat of sacrificial animals after three day?' She said: 'Yes Hardship had befallen the people, and the Messenger of Allah wanted the rich to feed the poor.' Then she said: 'I remember the family of Muhammad eating the trotters after fifteen days. I said: 'Why is that" She laughed and said: 'The family of Muhammad never ate their fill of bread and something to go with it, for three days in row, until he met Allah, the Mighty and Sublime,"' (Sahih)}}
\hadithdefcmd{nasai}{4433}{أَخْبَرَنَا يُوسُفُ بْنُ عِيسَى، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زِيَادِ بْنِ أَبِي الْجَعْدِ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَابِسٍ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ لُحُومِ الأَضَاحِي، قَالَتْ كُنَّا نَخْبَأُ الْكُرَاعَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم شَهْرًا ثُمَّ يَأْكُلُهُ ‏.‏\hadithno{4433}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdur'Rahman bin 'Abis that his father said:"I asked 'Aishah about the meat of the sacrificial animals and she said: 'We used to keep the trotters for the Messenger of Allah for a month, then he would eat them}}
\hadithdefcmd{nasai}{4434}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ ابْنِ عَوْنٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ إِمْسَاكِ الأُضْحِيَةِ فَوْقَ ثَلاَثَةِ أَيَّامٍ ثُمَّ قَالَ ‏ "‏ كُلُوا وَأَطْعِمُوا ‏"‏ ‏.‏\hadithno{4434}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu sa'eed Al-aKhudri said:"The Messenger of Allah forbade keeping the meat of the sacrificial animals for more than three days, then he said: 'Eat and feed other,"' (Sahih)}}
\hadithdefcmd{nasai}{4435}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ مُغِيرَةَ، قَالَ حَدَّثَنَا حُمَيْدُ بْنُ هِلاَلٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُغَفَّلٍ، قَالَ دُلِّيَ جِرَابٌ مِنْ شَحْمٍ يَوْمَ خَيْبَرَ فَالْتَزَمْتُهُ قُلْتُ لاَ أُعْطِي أَحَدًا مِنْهُ شَيْئًا فَالْتَفَتُّ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَبَسَّمُ ‏.‏\hadithno{4435}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Mughaffal said:"A bag of fat was thrown on the day of Khaibar, and I caught it and said: "I will not give anything of this to anyone.' I turned around and saw the Messenger of Allah there, smiling." (Sahih)}}
\hadithdefcmd{nasai}{4436}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ نَاسًا، مِنَ الأَعْرَابِ كَانُوا يَأْتُونَا بِلَحْمٍ وَلاَ نَدْرِي أَذَكَرُوا اسْمَ اللَّهِ عَلَيْهِ أَمْ لاَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اذْكُرُوا اسْمَ اللَّهِ عَزَّ وَجَلَّ عَلَيْهِ وَكُلُوا ‏"‏ ‏.‏\hadithno{4436}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that:some Bedouin people used to bring us meat, and we did not know whether they had mentioned the Name of Allah (when slaughtering it) or not. The Messenger of Allah said: "Messenger of Allah said: "Mention the Name of Allah and eat." (Sahih)}}
\hadithdefcmd{nasai}{4437}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي هَارُونُ بْنُ أَبِي وَكِيعٍ، - وَهُوَ هَارُونُ بْنُ عَنْتَرَةَ - عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ وَلاَ تَأْكُلُوا مِمَّا لَمْ يُذْكَرِ اسْمُ اللَّهِ عَلَيْهِ ‏\}‏ قَالَ خَاصَمَهُمُ الْمُشْرِكُونَ فَقَالُوا مَا ذَبَحَ اللَّهُ فَلاَ تَأْكُلُوهُ وَمَا ذَبَحْتُمْ أَنْتُمْ أَكَلْتُمُوهُ ‏.‏\hadithno{4437}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Harun bin Abi Walki-who is Harun bin 'Antarah -narrated from his father, form Ibn 'Abbas, concerning the saying of Allah, the Mighty and Sublime:"Eat not of that on which Allah's name has not been pronounced" - that he said: "The idolaters argued with them and said: 'Whatever Allah kills you do not eat, and whatever you kill you eat}}
\hadithdefcmd{nasai}{4438}{أَخْبَرَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَقِيَّةُ، عَنْ بَحِيرٍ، عَنْ خَالِدٍ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِي ثَعْلَبَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَحِلُّ الْمُجَثَّمَةُ ‏"‏ ‏.‏\hadithno{4438}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Tha'labah said:"The Messenger of Allah said: An animal that has been taken as a target is not lawful}}
\hadithdefcmd{nasai}{4439}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، عَنْ هِشَامِ بْنِ زَيْدٍ، قَالَ دَخَلْتُ مَعَ أَنَسٍ عَلَى الْحَكَمِ - يَعْنِي ابْنَ أَيُّوبَ - فَإِذَا أُنَاسٌ يَرْمُونَ دَجَاجَةً فِي دَارِ الأَمِيرِ فَقَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُصْبَرَ الْبَهَائِمُ ‏.‏\hadithno{4439}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Hisham bin Zaid said; "Ans and I entered upon Al-Hakam - that it, Ibn Ayyb - and there were some people shooting at a chicken in the house of the governor. He said:'The Messenger of Allah forbade using animals as targets;}}
\hadithdefcmd{nasai}{4440}{أَخْبَرَنَا مُحَمَّدُ بْنُ زُنْبُورٍ الْمَكِّيُّ، قَالَ حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، عَنْ يَزِيدَ، - وَهُوَ ابْنُ الْهَادِ - عَنْ مُعَاوِيَةَ بْنِ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، قَالَ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى أُنَاسٍ وَهُمْ يَرْمُونَ كَبْشًا بِالنَّبْلِ فَكَرِهَ ذَلِكَ وَقَالَ ‏ "‏ لاَ تَمْثُلُوا بِالْبَهَائِمِ ‏"‏ ‏.‏\hadithno{4440}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdullah bin Ja'far said:"The Messenger of Allah passed by some people who were shooting arrows at a ram. He denounced that and said: 'Do not disfigure animals (by using them as targets)." (Sahih)}}
\hadithdefcmd{nasai}{4441}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، قَالَ لَعَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنِ اتَّخَذَ شَيْئًا فِيهِ الرُّوحُ غَرَضًا ‏.‏\hadithno{4441}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah cursed those who take anything that has a soul as a target." (Sahih)}}
\hadithdefcmd{nasai}{4442}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي الْمِنْهَالُ بْنُ عَمْرٍو، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَعَنَ اللَّهُ مَنْ مَثَّلَ بِالْحَيَوَانِ ‏"‏ ‏.‏\hadithno{4442}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said; "I heard the Messenger of Allah say:'May Allah curse the one who disfigures and animal. (Sahih)}}
\hadithdefcmd{nasai}{4443}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنْ شُعْبَةَ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَتَّخِذُوا شَيْئًا فِيهِ الرُّوحُ غَرَضًا ‏"‏ ‏.‏\hadithno{4443}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah said:"Do not take anything that has a soul as a target}}
\hadithdefcmd{nasai}{4444}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْكُوفِيُّ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ هَاشِمٍ، عَنِ الْعَلاَءِ بْنِ صَالِحٍ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَتَّخِذُوا شَيْئًا فِيهِ الرُّوحُ غَرَضًا ‏"‏ ‏.‏\hadithno{4444}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbbas Said:"The messenger of Allah forbade us from using anything with a soul as a target." (Sahih)}}
\hadithdefcmd{nasai}{4445}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ صُهَيْبٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، يَرْفَعُهُ قَالَ ‏"‏ مَنْ قَتَلَ عُصْفُورًا فَمَا فَوْقَهَا بِغَيْرِ حَقِّهَا سَأَلَ اللَّهُ عَزَّ جَلَّ عَنْهَا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ فَمَا حَقُّهَا قَالَ ‏"‏ حَقُّهَا أَنْ تَذْبَحَهَا فَتَأْكُلَهَا وَلاَ تَقْطَعْ رَأْسَهَا فَيُرْمَى بِهَا ‏"‏ ‏.‏\hadithno{4445}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Amr, who attributed it to the Messenger of Allah:"There is no person who kills a small bird or anything larger, for no just reason, but Allah will ask him about it." It was said: "O Messenger of Allah, what does 'just reason mean?" He said: "That you slaughters it and eat it, and o not cut off its head and throw it aside}}
\hadithdefcmd{nasai}{4446}{أَخْبَرَنَا مُحَمَّدُ بْنُ دَاوُدَ الْمِصِّيصِيُّ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، قَالَ حَدَّثَنَا أَبُو عُبَيْدَةَ عَبْدُ الْوَاحِدِ بْنُ وَاصِلٍ، عَنْ خَلَفٍ، - يَعْنِي ابْنَ مِهْرَانَ - قَالَ حَدَّثَنَا عَامِرٌ الأَحْوَلُ، عَنْ صَالِحِ بْنِ دِينَارٍ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، قَالَ سَمِعْتُ الشَّرِيدَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ قَتَلَ عُصْفُورًا عَبَثًا عَجَّ إِلَى اللَّهِ عَزَّ وَجَلَّ يَوْمَ الْقِيَامَةِ يَقُولُ يَا رَبِّ إِنَّ فُلاَنًا قَتَلَنِي عَبَثًا وَلَمْ يَقْتُلْنِي لِمَنْفَعَةٍ ‏"‏ ‏.‏\hadithno{4446}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Amr bin Sharid said:"I heard Sharid say: 'I herd the Messenger of Allah say: Whoever kills a small bird for no reason, it will beseech Allah on the Day of Resurrection saying: O Lord, so and so killed me for no reason. And he did not kill me for any beneficial purpose}}
\hadithdefcmd{nasai}{4447}{أَخْبَرَنِي عُثْمَانُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي سَهْلُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا وُهَيْبُ بْنُ خَالِدٍ، عَنِ ابْنِ طَاوُسٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ عَمْرٍو قَالَ مَرَّةً عَنْ أَبِيهِ، وَقَالَ، مَرَّةً عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى يَوْمَ خَيْبَرَ عَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ وَعَنِ الْجَلاَّلَةِ وَعَنْ رُكُوبِهَا وَعَنْ أَكْلِ لَحْمِهَا ‏.‏\hadithno{4447}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his father Muhammad bin 'Abdullah bin 'Amr - or on one occasion he said:from his father, form his grandfather - the on the Day of Kahaibar, the Messenger of Allah forbade the flesh of domesticated donkeys and of al-Jallalah (animals that eat dung), and (he forbade) riding them and eating their mat}}
\hadithdefcmd{nasai}{4448}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُجَثَّمَةِ وَلَبَنِ الْجَلاَّلَةِ وَالشُّرْبِ مِنْ فِي السِّقَاءِ ‏.‏\hadithno{4448}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah forbade (eating) animals that had been taken as targets, the milk of Al-Jallalah (animals that eat dung), and drinking directly from water skins}}
