% Auto-generated chapter 0 for malik
% Hadiths in this chapter: 18

\hadithdefcmd{malik}{167}{\hadithno{167}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{}}
\hadithdefcmd{malik}{684}{\hadithno{684}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{}}
\hadithdefcmd{malik}{927}{\hadithno{927}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{}}
\hadithdefcmd{malik}{951}{\hadithno{951}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{}}
\hadithdefcmd{malik}{958}{\hadithno{958}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{}}
\hadithdefcmd{malik}{1013}{\hadithno{1013}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{}}
\hadithdefcmd{malik}{1040}{\hadithno{1040}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{}}
\hadithdefcmd{malik}{1090}{\hadithno{1090}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{}}
\hadithdefcmd{malik}{1171}{\hadithno{1171}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{}}
\hadithdefcmd{malik}{1176}{\hadithno{1176}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{}}
\hadithdefcmd{malik}{1191}{\hadithno{1191}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{}}
\hadithdefcmd{malik}{1203}{\hadithno{1203}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{}}
\hadithdefcmd{malik}{1338}{\hadithno{1338}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{}}
\hadithdefcmd{malik}{1492}{\hadithno{1492}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{}}
\hadithdefcmd{malik}{1519}{\hadithno{1519}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{}}
\hadithdefcmd{malik}{1528}{\hadithno{1528}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{}}
\hadithdefcmd{malik}{1583}{\hadithno{1583}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{}}
\hadithdefcmd{malik}{1748}{\hadithno{1748}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{}}
