% Auto-generated chapter 5 for malik
% Hadiths in this chapter: 21

\hadithdefcmd{malik}{225}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اغْتَسَلَ يَوْمَ الْجُمُعَةِ غُسْلَ الْجَنَابَةِ ثُمَّ رَاحَ فِي السَّاعَةِ الأُولَى فَكَأَنَّمَا قَرَّبَ بَدَنَةً وَمَنْ رَاحَ فِي السَّاعَةِ الثَّانِيَةِ فَكَأَنَّمَا قَرَّبَ بَقَرَةً وَمَنْ رَاحَ فِي السَّاعَةِ الثَّالِثَةِ فَكَأَنَّمَا قَرَّبَ كَبْشًا أَقْرَنَ وَمَنْ رَاحَ فِي السَّاعَةِ الرَّابِعَةِ فَكَأَنَّمَا قَرَّبَ دَجَاجَةً وَمَنْ رَاحَ فِي السَّاعَةِ الْخَامِسَةِ فَكَأَنَّمَا قَرَّبَ بَيْضَةً فَإِذَا خَرَجَ الإِمَامُ حَضَرَتِ الْمَلاَئِكَةُ يَسْتَمِعُونَ الذِّكْرَ ‏"‏ ‏.‏\hadithno{225}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Sumayy, the mawla of Abu Bakr ibn Abd ar-Rahman, from Abu Salih as-Sammani from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "If someone does ghusl for major ritual impurity on the day of jumua and then goes in the first part of the time, it is as if he had offered up a camel. If he goes in the second part of the time, it is as if he had offered up a cow. If he goes in the third part of the time, it is as if he had offered up a horned ram. If he goes in the fourth part of the time, it is as if he had offered up a hen. If he goes in the fifth part of the time, it is as if he had offered up an egg. And when the imam comes out, the angels settle down listening to the dhikr (remembrance of Allah)}}
\hadithdefcmd{malik}{226}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ كَانَ يَقُولُ غُسْلُ يَوْمِ الْجُمُعَةِ وَاجِبٌ عَلَى كُلِّ مُحْتَلِمٍ كَغُسْلِ الْجَنَابَةِ ‏.‏\hadithno{226}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Said ibn Abi Said al-Maqburi that Abu Hurayra used to say, "Doing ghusl as prescribed for major ritual impurity is incumbent (wajib) on the day of jumua on every male who has reached puberty}}
\hadithdefcmd{malik}{227}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ قَالَ دَخَلَ رَجُلٌ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم الْمَسْجِدَ يَوْمَ الْجُمُعَةِ وَعُمَرُ بْنُ الْخَطَّابِ يَخْطُبُ فَقَالَ عُمَرُ أَيَّةُ سَاعَةٍ هَذِهِ فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ انْقَلَبْتُ مِنَ السُّوقِ فَسَمِعْتُ النِّدَاءَ فَمَا زِدْتُ عَلَى أَنْ تَوَضَّأْتُ ‏.‏ فَقَالَ عُمَرُ وَالْوُضُوءَ أَيْضًا وَقَدْ عَلِمْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْمُرُ بِالْغُسْلِ ‏.‏\hadithno{227}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Salim ibn Abdullah said, "One of the companions of the Messenger of Allah, may Allah bless him and grant him peace, came into the mosque on the day of jumua and Umar ibn al Khattab was already giving the khutba. Umar said, 'What (kind of) time is this (to arrive)?' He said, Amir al- muminin, I returned from the market and heard the call to prayer, so I did no more than do wudu.' Umar said, 'You only did wudu as well? You know that the Messenger of Allah, may Allah bless him and grant him peace, used to tell people to do ghusl}}
\hadithdefcmd{malik}{228}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ غُسْلُ يَوْمِ الْجُمُعَةِ وَاجِبٌ عَلَى كُلِّ مُحْتَلِمٍ ‏"‏ ‏.‏\hadithno{228}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Safwan ibn Sulaym from Ata ibn Yasar from Abu Said al-Khudri that the Messenger of Allah, may Allah bless him and grant him peace, said, "Ghusl on the day of jumua is incumbent on every male who has reached puberty}}
\hadithdefcmd{malik}{229}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا جَاءَ أَحَدُكُمُ الْجُمُعَةَ فَلْيَغْتَسِلْ ‏"‏ ‏.‏\hadithno{229}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "When you come to jumua, do ghusl." Malik said, "It is not enough for someone to do a ghusl on the day of jumua and intend by it the ghusl for jumua unless he does the ghusl and then sets off. That is because the Messenger of Allah, may Allah bless him and grant him peace, said in the hadith related by Ibn Umar, 'When you come to jumua, do ghusl .' " Malik said, "If someone does ghusl on the day of jumua and intends by it the ghusl of the day of jumua and then sets out, whether early or late, and does something which breaks his wudu, he only has to do wudu and his ghusl remains valid for him}}
\hadithdefcmd{malik}{230}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قُلْتَ لِصَاحِبِكَ أَنْصِتْ وَالإِمَامُ يَخْطُبُ يَوْمَ الْجُمُعَةِ فَقَدْ لَغَوْتَ ‏"‏ ‏.‏\hadithno{230}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Even saying to your companion 'Listen' while the imam is giving the khutba on the day of jumua, is to speak foolishly}}
\hadithdefcmd{malik}{231}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ ثَعْلَبَةَ بْنِ أَبِي مَالِكٍ الْقُرَظِيِّ، أَنَّهُ أَخْبَرَهُ أَنَّهُمْ، كَانُوا فِي زَمَانِ عُمَرَ بْنِ الْخَطَّابِ يُصَلُّونَ يَوْمَ الْجُمُعَةِ حَتَّى يَخْرُجَ عُمَرُ فَإِذَا خَرَجَ عُمَرُ وَجَلَسَ عَلَى الْمِنْبَرِ وَأَذَّنَ الْمُؤَذِّنُونَ - قَالَ ثَعْلَبَةُ - جَلَسْنَا نَتَحَدَّثُ فَإِذَا سَكَتَ الْمُؤَذِّنُونَ وَقَامَ عُمَرُ يَخْطُبُ أَنْصَتْنَا فَلَمْ يَتَكَلَّمْ مِنَّا أَحَدٌ ‏.‏ قَالَ ابْنُ شِهَابٍ فَخُرُوجُ الإِمَامِ يَقْطَعُ الصَّلاَةَ وَكَلاَمُهُ يَقْطَعُ الْكَلاَمَ ‏.‏\hadithno{231}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Thalaba ibn Abi Malik al Quradhi informed him that in the time of Umar ibn al Khattab they used to pray on the day of jumua until Umar came out, and when Umar came out and sat on the mimbar and the muadhdhins called the adhan, they would sit and talk, and then when the muadhdhins were silent and Umar stood to give the khutba, they would pay attention and no-one would speak . Ibn Shihab said, "The imam coming out stops prayer and his speaking stops conversation}}
\hadithdefcmd{malik}{232}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ مَالِكِ بْنِ أَبِي عَامِرٍ، أَنَّ عُثْمَانَ بْنَ عَفَّانَ، كَانَ يَقُولُ فِي خُطْبَتِهِ قَلَّمَا يَدَعُ ذَلِكَ إِذَا خَطَبَ إِذَا قَامَ الإِمَامُ يَخْطُبُ يَوْمَ الْجُمُعَةِ فَاسْتَمِعُوا وَأَنْصِتُوا فَإِنَّ لِلْمُنْصِتِ الَّذِي لاَ يَسْمَعُ مِنَ الْحَظِّ مِثْلَ مَا لِلْمُنْصِتِ السَّامِعِ فَإِذَا قَامَتِ الصَّلاَةُ فَاعْدِلُوا الصُّفُوفَ وَحَاذُوا بِالْمَنَاكِبِ فَإِنَّ اعْتِدَالَ الصُّفُوفِ مِنْ تَمَامِ الصَّلاَةِ ‏.‏ ثُمَّ لاَ يُكَبِّرُ حَتَّى يَأْتِيَهُ رِجَالٌ قَدْ وَكَّلَهُمْ بِتَسْوِيَةِ الصُّفُوفِ فَيُخْبِرُونَهُ أَنْ قَدِ اسْتَوَتْ فَيُكَبِّرُ ‏.‏\hadithno{232}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu'n Nadr, the mawla of Umar ibn Ubaydullah, from Malik ibn Abi Amir that Uthman ibn Affan used to say in khutbas, and he would seldom omit it if he was giving the khutba, "When the imam stands delivering the khutba on the day of jumua, listen and pay attention, for there is the same portion for someone who pays attention but cannot hear as for someone who pays attention and hears. And when the iqama of the prayer is called, straighten your rows and make your shoulders adjacent to each other, because the straightening of the rows is part of the completion of the prayer." Then he would not say the takbir until some men who had been entrusted with straightening the rows came and told him that they were straight. Then he would say the takbir}}
\hadithdefcmd{malik}{233}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، رَأَى رَجُلَيْنِ يَتَحَدَّثَانِ وَالإِمَامُ يَخْطُبُ يَوْمَ الْجُمُعَةِ فَحَصَبَهُمَا أَنِ اصْمُتَا ‏.‏\hadithno{233}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar saw two men talking while the imam was giving the khutba on the day of jumua and he threw pebbles at them to tell them to be quiet}}
\hadithdefcmd{malik}{234}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَجُلاً، عَطَسَ يَوْمَ الْجُمُعَةِ وَالإِمَامُ يَخْطُبُ فَشَمَّتَهُ إِنْسَانٌ إِلَى جَنْبِهِ فَسَأَلَ عَنْ ذَلِكَ سَعِيدَ بْنَ الْمُسَيَّبِ فَنَهَاهُ عَنْ ذَلِكَ وَقَالَ لاَ تَعُدْ ‏.‏\hadithno{234}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that a man sneezed on the day of jumua while the imam was giving the khutba, and a man by his side asked Allah to bless him. Said ibn al Musayyab was asked about it and he forbade the man to do what he had done and said, "Don't do it again}}
\hadithdefcmd{malik}{235}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَأَلَ ابْنَ شِهَابٍ عَنِ الْكَلاَمِ، يَوْمَ الْجُمُعَةِ إِذَا نَزَلَ الإِمَامُ عَنِ الْمِنْبَرِ، قَبْلَ أَنْ يُكَبِّرَ، ‏.‏ فَقَالَ ابْنُ شِهَابٍ لاَ بَأْسَ بِذَلِكَ ‏.‏\hadithno{235}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he asked Ibn Shihab about talking in the jumua after the imam had come down from the mimbar but before he had said the takbir. Ibn Shihab said, "There is no harm in that}}
\hadithdefcmd{malik}{236}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ كَانَ يَقُولُ مَنْ أَدْرَكَ مِنْ صَلاَةِ الْجُمُعَةِ رَكْعَةً فَلْيُصَلِّ إِلَيْهَا أُخْرَى ‏.‏ قَالَ ابْنُ شِهَابٍ وَهِيَ السُّنَّةُ ‏.‏ قَالَ مَالِكٌ وَعَلَى ذَلِكَ أَدْرَكْتُ أَهْلَ الْعِلْمِ بِبَلَدِنَا وَذَلِكَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ مِنَ الصَّلاَةِ رَكْعَةً فَقَدْ أَدْرَكَ الصَّلاَةَ ‏"‏ ‏.‏ قَالَ مَالِكٌ فِي الَّذِي يُصِيبُهُ زِحَامٌ يَوْمَ الْجُمُعَةِ فَيَرْكَعُ وَلاَ يَقْدِرُ عَلَى أَنْ يَسْجُدَ حَتَّى يَقُومَ الإِمَامُ أَوْ يَفْرُغَ الإِمَامُ مِنْ صَلاَتِهِ إِنَّهُ إِنْ قَدَرَ عَلَى أَنْ يَسْجُدَ إِنْ كَانَ قَدْ رَكَعَ فَلْيَسْجُدْ إِذَا قَامَ النَّاسُ وَإِنْ لَمْ يَقْدِرْ عَلَى أَنْ يَسْجُدَ حَتَّى يَفْرُغَ الإِمَامُ مِنْ صَلاَتِهِ فَإِنَّهُ أَحَبُّ إِلَىَّ أَنْ يَبْتَدِئَ صَلاَتَهُ ظُهْرًا أَرْبَعًا ‏.‏\hadithno{236}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Ibn Shihab used to say, "Some one who catches a raka of the jumua prayer should pray another one with it." Ibn Shihab said, "That is the sunna." Malik said, "I saw the people of knowledge in our city doing that. That is because the Messenger of Allah, may Allah bless him and grant him peace, said, 'Whoever catches a raka of the prayer has caught the prayer.' " Malik said, concerning some one who was in a crowd on the day of jumua and did the ruku but was not able to go into sajda until the imam had risen or finished his prayer, "If he is able to do the sajda and has already done the ruku then he should do the sajda when the people stand up. If he is unable to do thesajda until after the imam has finished the prayer, then I prefer that he begins the prayeragain and does the four rakas of dhuhr}}
\hadithdefcmd{malik}{237}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ سَأَلَ ابْنَ شِهَابٍ عَنْ قَوْلِ اللَّهِ، عَزَّ وَجَلَّ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا إِذَا نُودِيَ لِلصَّلاَةِ مِنْ يَوْمِ الْجُمُعَةِ فَاسْعَوْا إِلَى ذِكْرِ اللَّهِ‏\}‏ فَقَالَ ابْنُ شِهَابٍ كَانَ عُمَرُ بْنُ الْخَطَّابِ يَقْرَؤُهَا إِذَا نُودِيَ لِلصَّلاَةِ مِنْ يَوْمِ الْجُمُعَةِ فَامْضُوا إِلَى ذِكْرِ اللَّهِ ‏.‏ قَالَ مَالِكٌ وَإِنَّمَا السَّعْىُ فِي كِتَابِ اللَّهِ الْعَمَلُ وَالْفِعْلُ يَقُولُ اللَّهُ تَبَارَكَ وَتَعَالَى ‏\{‏وَإِذَا تَوَلَّى سَعَى فِي الأَرْضِ‏\}‏ وَقَالَ تَعَالَى ‏\{‏وَأَمَّا مَنْ جَاءَكَ يَسْعَى وَهُوَ يَخْشَى‏\}‏ وَقَالَ ‏\{‏ثُمَّ أَدْبَرَ يَسْعَى‏\}‏ وَقَالَ ‏\{‏إِنَّ سَعْيَكُمْ لَشَتَّى‏\}‏ قَالَ مَالِكٌ فَلَيْسَ السَّعْىُ الَّذِي ذَكَرَ اللَّهُ فِي كِتَابِهِ بِالسَّعْىِ عَلَى الأَقْدَامِ وَلاَ الاِشْتِدَادَ وَإِنَّمَا عَنَى الْعَمَلَ وَالْفِعْلَ ‏.‏\hadithno{237}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik said, "Someone who has a nosebleed on the day of jumua while the imam is giving the khutba and he leaves and does not come back until the imam has finished the prayer, should pray four rakas.'' Malik said that someone who prayed a raka with the imam on the day of jumua, then had a nosebleed and left and came back and the imam had prayed both rakas, should complete the prayer with another raka as long as he had not spoken. Malik said, "If some one has a nosebleed, or something happens to him and he has no alternative but to leave, he does not have to ask permission of the imam if he wants to leave on the day of jumua." Yahya related to me from Malik that he had asked Ibn Shihab about the word of Allah, the Majestic, the Mighty, "O you who accept, when the call is made for the prayer on the day of jumua, make haste to the remembrance of Allah."(Sura 62 ayat 9). Ibn Shihab said, ''Umar ibn al-Khattab used to recite, 'When the call is made for the prayer on the day of jumua, go to the remembrance of Allah.' " Malik said, "Making haste in the Book of Allah is only deed and action. Allah the Blessed, the Exalted, says 'and when he turns away, he acts in the land' (Sura 2 ayat 205), and He, the Exalted, said, 'and as for the one who comes to you acting with fear' (Sura 80 ayat 8), and He said, 'then he turned his back, and acted' (Sura 79 ayat 22),and He said, 'Your deeds are diverse' " (Sura 92 ayat 4). Malik said, "Thus making haste which Allah mentions in His Book is not running on the feet or exertion. It only means deed and actions}}
\hadithdefcmd{malik}{238}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ يَوْمَ الْجُمُعَةِ فَقَالَ ‏ "‏ فِيهِ سَاعَةٌ لاَ يُوَافِقُهَا عَبْدٌ مُسْلِمٌ وَهُوَ قَائِمٌ يُصَلِّي يَسْأَلُ اللَّهَ شَيْئًا إِلاَّ أَعْطَاهُ إِيَّاهُ ‏"‏ ‏.‏ وَأَشَارَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ يُقَلِّلُهَا ‏.‏\hadithno{238}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik said, "If the imam stops off on a journey in a town where jumua is obligatory and he gives a khutba and takes the jumua prayer for them, then the people of the town and any other people present do the jumua prayer with him." Malik said, "If the imam gathers people for prayer while he is travelling in a town where the jumua prayer is not obligatory, then there is no jumua for him, nor for the people of the town, nor for anyone else who joins them for the prayer in congregation, and the people of the town and anyone else who is not travelling should complete the prayer." Malik added, "A traveller does not have to do jumua " Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, mentioned the day of jumua and said, "There is a time in it when Allah gives to a muslim slave standing in prayer whatever he asks for," and the Messenger of Allah, may Allah bless him and grant him peace, indicated with his hand how small it was}}
\hadithdefcmd{malik}{239}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ خَرَجْتُ إِلَى الطُّورِ فَلَقِيتُ كَعْبَ الأَحْبَارِ فَجَلَسْتُ مَعَهُ فَحَدَّثَنِي عَنِ التَّوْرَاةِ وَحَدَّثْتُهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَكَانَ فِيمَا حَدَّثْتُهُ أَنْ قُلْتُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَيْرُ يَوْمٍ طَلَعَتْ عَلَيْهِ الشَّمْسُ يَوْمُ الْجُمُعَةِ فِيهِ خُلِقَ آدَمُ وَفِيهِ أُهْبِطَ مِنَ الْجَنَّةِ وَفِيهِ تِيبَ عَلَيْهِ وَفِيهِ مَاتَ وَفِيهِ تَقُومُ السَّاعَةُ وَمَا مِنْ دَابَّةٍ إِلاَّ وَهِيَ مُصِيخَةٌ يَوْمَ الْجُمُعَةِ مِنْ حِينِ تُصْبِحُ حَتَّى تَطْلُعَ الشَّمْسُ شَفَقًا مِنَ السَّاعَةِ إِلاَّ الْجِنَّ وَالإِنْسَ وَفِيهِ سَاعَةٌ لاَ يُصَادِفُهَا عَبْدٌ مُسْلِمٌ وَهُوَ يُصَلِّي يَسْأَلُ اللَّهَ شَيْئًا إِلاَّ أَعْطَاهُ إِيَّاهُ ‏"‏ ‏.‏ قَالَ كَعْبٌ ذَلِكَ فِي كُلِّ سَنَةٍ يَوْمٌ ‏.‏ فَقُلْتُ بَلْ فِي كُلِّ جُمُعَةٍ ‏.‏ فَقَرَأَ كَعْبٌ التَّوْرَاةَ فَقَالَ صَدَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَلَقِيتُ بَصْرَةَ بْنَ أَبِي بَصْرَةَ الْغِفَارِيَّ فَقَالَ مِنْ أَيْنَ أَقْبَلْتَ فَقُلْتُ مِنَ الطُّورِ ‏.‏ فَقَالَ لَوْ أَدْرَكْتُكَ قَبْلَ أَنْ تَخْرُجَ إِلَيْهِ مَا خَرَجْتَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ تُعْمَلُ الْمَطِيُّ إِلاَّ إِلَى ثَلاَثَةِ مَسَاجِدَ إِلَى الْمَسْجِدِ الْحَرَامِ وَإِلَى مَسْجِدِي هَذَا وَإِلَى مَسْجِدِ إِيلْيَاءَ أَوْ بَيْتِ الْمَقْدِسِ ‏"‏ ‏.‏ يَشُكُّ ‏.‏ قَالَ أَبُو هُرَيْرَةَ ثُمَّ لَقِيتُ عَبْدَ اللَّهِ بْنَ سَلاَمٍ فَحَدَّثْتُهُ بِمَجْلِسِي مَعَ كَعْبِ الأَحْبَارِ وَمَا حَدَّثْتُهُ بِهِ فِي يَوْمِ الْجُمُعَةِ فَقُلْتُ قَالَ كَعْبٌ ذَلِكَ فِي كُلِّ سَنَةٍ يَوْمٌ ‏.‏ قَالَ قَالَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ كَذَبَ كَعْبٌ ‏.‏ فَقُلْتُ ثُمَّ قَرَأَ كَعْبٌ التَّوْرَاةَ فَقَالَ بَلْ هِيَ فِي كُلِّ جُمُعَةٍ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ صَدَقَ كَعْبٌ ‏.‏ ثُمَّ قَالَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ قَدْ عَلِمْتُ أَيَّةَ سَاعَةٍ هِيَ ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَقُلْتُ لَهُ أَخْبِرْنِي بِهَا وَلاَ تَضِنَّ عَلَىَّ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ هِيَ آخِرُ سَاعَةٍ فِي يَوْمِ الْجُمُعَةِ ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَقُلْتُ وَكَيْفَ تَكُونُ آخِرُ سَاعَةٍ فِي يَوْمِ الْجُمُعَةِ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يُصَادِفُهَا عَبْدٌ مُسْلِمٌ وَهُوَ يُصَلِّي ‏"‏ ‏.‏ وَتِلْكَ السَّاعَةُ سَاعَةٌ لاَ يُصَلَّى فِيهَا فَقَالَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ أَلَمْ يَقُلْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ جَلَسَ مَجْلِسًا يَنْتَظِرُ الصَّلاَةَ فَهُوَ فِي صَلاَةٍ حَتَّى يُصَلِّيَ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَقُلْتُ بَلَى ‏.‏ قَالَ فَهُوَ ذَلِكَ ‏.‏\hadithno{239}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yazid ibn Abdullah ibn al-Had from Muhammad ibn Ibrahim ibn al-Harith at-Taymi from Abu Salama ibn Abd ar-Rahman ibn Awf that Abu Hurayra said, "I went out to at-Tur (Mount Sinai) and met Kab al Ahbar and sat with him. He related to me things from the Tawrah and I related to him things from the Messenger of Allah, may Allah bless him and grant him peace. Among the things I related to him was that the Messenger of Allah, may Allah bless him and grant him peace, said, 'The best of days on which the sun rises is the day of jumua. In it Adam was created, and in it he fell from the Garden. In it he was forgiven, and in it he died. In it the Hour occurs, and every moving thing listens from morning till sunset in apprehension of the Hour except jinn and men. In it is a time when Allah gives toa muslim slave standing in prayer whatever he asks for.' Kab said, 'That is one day in every year.' I said, 'No, in every jumua.' Then Kab recited the Tawrah and said, 'The Messenger of Allah has spoken the truth.' " Abu Hurayra continued, "I met Basra ibn Abi Basra al-Ghiffari and he said, 'Where have you come from?' I said, 'From at-Tur.' He said, 'If I had seen you before you left, you would not have gone. I heard the Messenger of Allah, may Allah bless him and grant him peace, say, "Only make a special journey to three mosques:the mosque of the Haram (Makka), this mosque (Madina), and the mosque of Ilya or the Bait al-Maqdis (two names of Jerusalem)." ' " (He was not sure which expression was used.) Abu Hurayra continued, "Then I met Abdullah ibn Salam and I told him that I had sat with Kabal-Ahbar, and I mentioned what I had related to him about the day of jumua, and told him that Kab had said, 'That is one day in every year.' Abdullah ibn Salam said, 'Kab lied,' and I added, 'Kab then recited the Tawrah and said, "No, it is in every jumua.'' ' Abdullah ibn Salam said, 'Kab spoke the truth. 'Then Abdullah ibn Salam said, 'I know what time that is.' " Abu Hurayra continued, "I said to him, 'Let me know it - don't keep it from me.' Abdullah ibn Salam said, 'It is the last period of time in the dayof jumua.' " Abu Hurayra continued, "I said, 'How can it be the last period of time in the day of jumua, when the Messenger of Allah, may Allah bless him and grant him peace, said, "a muslim slave standing in prayer", and that is a time when there is no prayer?' Abdullah ibn Salam replied, 'Didn't the Messenger of Allah, may Allah bless him and grant him peace, say, "Whoever sits waiting for the prayer is in prayer until he prays?" "' Abu Hurayra added, "I said, 'Of course.' He said, 'Then it is that}}
\hadithdefcmd{malik}{240}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ قَالَ ‏ "‏ مَا عَلَى أَحَدِكُمْ لَوِ اتَّخَذَ ثَوْبَيْنِ لِجُمُعَتِهِ سِوَى ثَوْبَىْ مَهْنَتِهِ ‏"‏ ‏.‏\hadithno{240}\hadithgrade{Salim al-Hilali: Hasan Lighairihi}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, said, "There is nothing wrong in wearing two garments which are not work-clothes for jumua}}
\hadithdefcmd{malik}{241}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ لاَ يَرُوحُ إِلَى الْجُمُعَةِ إِلاَّ ادَّهَنَ وَتَطَيَّبَ إِلاَّ أَنْ يَكُونَ حَرَامًا ‏.‏\hadithno{241}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar would never go to jumua without wearing oil and perfume except when it was forbidden (i.e. when he was muhrim)}}
\hadithdefcmd{malik}{242}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ حَزْمٍ، عَمَّنْ حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ كَانَ يَقُولُ لأَنْ يُصَلِّيَ أَحَدُكُمْ بِظَهْرِ الْحَرَّةِ خَيْرٌ لَهُ مِنْ أَنْ يَقْعُدَ حَتَّى إِذَا قَامَ الإِمَامُ يَخْطُبُ جَاءَ يَتَخَطَّى رِقَابَ النَّاسِ يَوْمَ الْجُمُعَةِ ‏.‏ قَالَ مَالِكٌ السُّنَّةُ عِنْدَنَا أَنْ يَسْتَقْبِلَ النَّاسُ الإِمَامَ يَوْمَ الْجُمُعَةِ إِذَا أَرَادَ أَنْ يَخْطُبَ مَنْ كَانَ مِنْهُمْ يَلِي الْقِبْلَةَ وَغَيْرَهَا ‏.‏\hadithno{242}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Abi Bakr ibn Hazm from whoever related it to him that Abu Hurayra used to say, "It is better for a man to pray on the surface of al Harra (a rocky area in Madina) than for him to wait until the imam stands to give the khutba and then come and step over people's necks." Malik said, "The sunna with us is that the people face the imam on the day of jumua when he intends to give the khutba, whether they are near the qibla or elsewhere}}
\hadithdefcmd{malik}{243}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ ضَمْرَةَ بْنِ سَعِيدٍ الْمَازِنِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ الضَّحَّاكَ بْنَ قَيْسٍ، سَأَلَ النُّعْمَانَ بْنَ بَشِيرٍ مَاذَا كَانَ يَقْرَأُ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الْجُمُعَةِ عَلَى إِثْرِ سُورَةِ الْجُمُعَةِ قَالَ كَانَ يَقْرَأُ ‏\{‏هَلْ أَتَاكَ حَدِيثُ الْغَاشِيَةِ‏\}‏\hadithno{243}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Damra ibn Said al-Mazini from Ubaydullah ibn Abdullah ibn Utba ibn Masud that ad-Dahhak ibn Qays asked an-Numan ibn Bashir, "What did the Messenger of Allah, may Allah bless him and grant him peace, use to recite on the day of jumua after suratal-Jumua (Sura 62)?" He said, "He used to recite al-Ghashiya (Sura)}}
\hadithdefcmd{malik}{244}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، - قَالَ مَالِكٌ لاَ أَدْرِي أَعَنِ النَّبِيِّ صلى الله عليه وسلم أَمْ لاَ - أَنَّهُ قَالَ ‏ "‏ مَنْ تَرَكَ الْجُمُعَةَ ثَلاَثَ مَرَّاتٍ مِنْ غَيْرِ عُذْرٍ وَلاَ عِلَّةٍ طَبَعَ اللَّهُ عَلَى قَلْبِهِ ‏"‏ ‏.‏\hadithno{244}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that Safwan ibn Sulaym said, "If anyone omits jumua three times without reason or illness, Allah will set a seal on his heart." (Malik said, "I don't know if it was from the Messenger of Allah, may Allah bless him and grant him peace, or not)}}
\hadithdefcmd{malik}{245}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَطَبَ خُطْبَتَيْنِ يَوْمَ الْجُمُعَةِ وَجَلَسَ بَيْنَهُمَا ‏.‏\hadithno{245}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Jafar ibn Muhammad from his father that the Messenger of Allah, may Allah bless him and grant him peace, gave two khutbas on the day of jumua and sat down between them}}
