% Auto-generated chapter 54 for bukhari
% Hadiths in this chapter: 24

\hadithdefcmd{bukhari}{2712}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّهُ سَمِعَ مَرْوَانَ، وَالْمِسْوَرَ بْنَ مَخْرَمَةَ، رضى الله عنهما يُخْبِرَانِ عَنْ أَصْحَابِ، رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ لَمَّا كَاتَبَ سُهَيْلُ بْنُ عَمْرٍو يَوْمَئِذٍ كَانَ فِيمَا اشْتَرَطَ سُهَيْلُ بْنُ عَمْرٍو عَلَى النَّبِيِّ صلى الله عليه وسلم أَنَّهُ لاَ يَأْتِيكَ مِنَّا أَحَدٌ وَإِنْ كَانَ عَلَى دِينِكَ إِلاَّ رَدَدْتَهُ إِلَيْنَا، وَخَلَّيْتَ بَيْنَنَا وَبَيْنَهُ‏.‏ فَكَرِهَ الْمُؤْمِنُونَ ذَلِكَ، وَامْتَعَضُوا مِنْهُ، وَأَبَى سُهَيْلٌ إِلاَّ ذَلِكَ، فَكَاتَبَهُ النَّبِيُّ صلى الله عليه وسلم عَلَى ذَلِكَ، فَرَدَّ يَوْمَئِذٍ أَبَا جَنْدَلٍ عَلَى أَبِيهِ سُهَيْلِ بْنِ عَمْرٍو، وَلَمْ يَأْتِهِ أَحَدٌ مِنَ الرِّجَالِ إِلاَّ رَدَّهُ فِي تِلْكَ الْمُدَّةِ، وَإِنْ كَانَ مُسْلِمًا، وَجَاءَ الْمُؤْمِنَاتُ مُهَاجِرَاتٍ، وَكَانَتْ أُمُّ كُلْثُومٍ بِنْتُ عُقْبَةَ بْنِ أَبِي مُعَيْطٍ مِمَّنْ خَرَجَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَئِذٍ وَهْىَ عَاتِقٌ، فَجَاءَ أَهْلُهَا يَسْأَلُونَ النَّبِيَّ صلى الله عليه وسلم أَنْ يَرْجِعَهَا إِلَيْهِمْ، فَلَمْ يَرْجِعْهَا إِلَيْهِمْ لِمَا أَنْزَلَ اللَّهُ فِيهِنَّ ‏\{‏إِذَا جَاءَكُمُ الْمُؤْمِنَاتُ مُهَاجِرَاتٍ فَامْتَحِنُوهُنَّ اللَّهُ أَعْلَمُ بِإِيمَانِهِنَّ‏\}‏ إِلَى قَوْلِهِ ‏\{‏وَلاَ هُمْ يَحِلُّونَ لَهُنَّ‏\}‏‏.‏\hadithno{2712}\hadithtrans{Narrated Marwan and al-Miswar bin Makhrama:(from the companions of Allah's Messenger (ﷺ)) When Suhail bin `Amr agreed to the Treaty (of Hudaibiya), one of the things he stipulated then, was that the Prophet (ﷺ) should return to them (i.e. the pagans) anyone coming to him from their side, even if he was a Muslim; and would not interfere between them and that person. The Muslims did not like this condition and got disgusted with it. Suhail did not agree except with that condition. So, the Prophet (ﷺ) agreed to that condition and returned Abu Jandal to his father Suhail bin `Amr. Thenceforward the Prophet (ﷺ) returned everyone in that period (of truce) even if he was a Muslim. During that period some believing women emigrants including Um Kulthum bint `Uqba bin Abu Muait who came to Allah's Messenger (ﷺ) and she was a young lady then. Her relative came to the Prophet (ﷺ) and asked him to return her, but the Prophet (ﷺ) did not return her to them for Allah had revealed the following Verse regarding women: "O you who believe! When the believing women come to you as emigrants. Examine them, Allah knows best as to their belief, then if you know them for true believers, Send them not back to the unbelievers, (for) they are not lawful (wives) for the disbelievers, Nor are the unbelievers lawful (husbands) for them}}
\hadithdefcmd{bukhari}{2713}{قَالَ عُرْوَةُ فَأَخْبَرَتْنِي عَائِشَةُ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَمْتَحِنُهُنَّ بِهَذِهِ الآيَةِ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا إِذَا جَاءَكُمُ الْمُؤْمِنَاتُ مُهَاجِرَاتٍ فَامْتَحِنُوهُنَّ ‏\}‏ إِلَى ‏\{‏غَفُورٌ رَحِيمٌ‏\}‏‏.‏ قَالَ عُرْوَةُ قَالَتْ عَائِشَةُ فَمَنْ أَقَرَّ بِهَذَا الشَّرْطِ مِنْهُنَّ قَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ بَايَعْتُكِ ‏"‏‏.‏ كَلاَمًا يُكَلِّمُهَا بِهِ، وَاللَّهِ مَا مَسَّتْ يَدُهُ يَدَ امْرَأَةٍ قَطُّ فِي الْمُبَايَعَةِ، وَمَا بَايَعَهُنَّ إِلاَّ بِقَوْلِهِ‏.‏\hadithno{2713}\hadithtrans{Narrated `Urwa: Aisha told me, "Allah's Messenger (ﷺ) used to examine them according to this Verse: "O you who believe! When the believing women come to you, as emigrants test them . . . for Allah is Oft- Forgiving, Most Merciful." (60.10-12) Aisha said, "When any of them agreed to that condition Allah's Apostle would say to her, 'I have accepted your pledge of allegiance.' He would only say that, but, by Allah he never touched the hand of any women (i.e. never shook hands with them) while taking the pledge of allegiance and he never took their pledge of allegiance except by his words (only)}}
\hadithdefcmd{bukhari}{2714}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، قَالَ سَمِعْتُ جَرِيرًا ـ رضى الله عنه ـ يَقُولُ بَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَاشْتَرَطَ عَلَىَّ وَالنُّصْحِ لِكُلِّ مُسْلِمٍ‏.‏\hadithno{2714}\hadithtrans{Narrated Jarir:When I gave the pledge of allegiance to Allah's Messenger (ﷺ) and he stipulated that I should give good advice to every Muslim}}
\hadithdefcmd{bukhari}{2715}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، قَالَ حَدَّثَنِي قَيْسُ بْنُ أَبِي حَازِمٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ بَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى إِقَامِ الصَّلاَةِ وَإِيتَاءِ الزَّكَاةِ وَالنُّصْحِ لِكُلِّ مُسْلِمٍ‏.‏\hadithno{2715}\hadithtrans{Narrated Jabir bin `Abdullah:I gave the pledge of allegiance to Allah's Messenger (ﷺ) for offering the prayers perfectly paying the Zakat and giving good advice to every Muslim}}
\hadithdefcmd{bukhari}{2716}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ بَاعَ نَخْلاً قَدْ أُبِّرَتْ فَثَمَرَتُهَا لِلْبَائِعِ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏"‏‏.‏\hadithno{2716}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "If someone sells pollinated date-palms, their fruits will be for the seller, unless the buyer stipulates the contrary}}
\hadithdefcmd{bukhari}{2717}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةََ،ـ رضى الله عنها ـ أَخْبَرَتْهُ أَنَّ بَرِيرَةَ جَاءَتْ عَائِشَةَ تَسْتَعِينُهَا فِي كِتَابَتِهَا، وَلَمْ تَكُنْ قَضَتْ مِنْ كِتَابَتِهَا شَيْئًا، قَالَتْ لَهَا عَائِشَةُ ارْجِعِي إِلَى أَهْلِكِ، فَإِنْ أَحَبُّوا أَنْ أَقْضِيَ عَنْكِ كِتَابَتَكِ، وَيَكُونَ وَلاَؤُكِ لِي فَعَلْتُ‏.‏ فَذَكَرَتْ ذَلِكَ بَرِيرَةُ إِلَى أَهْلِهَا فَأَبَوْا وَقَالُوا إِنْ شَاءَتْ أَنْ تَحْتَسِبَ عَلَيْكِ فَلْتَفْعَلْ، وَيَكُونَ لَنَا وَلاَؤُكِ‏.‏ فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهَا ‏ "‏ ابْتَاعِي فَأَعْتِقِي، فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏\hadithno{2717}\hadithtrans{Narrated `Urwa:Aisha told me that Barirah came to seek her help in writing for emancipation and at that time she had not paid any part of her price. `Aisha said to her, "Go to your masters and if they agree that I will pay your price (and free you) on condition that your Wala' will be for me, I will pay the money." Barirah told her masters about that, but they refused, and said, "If `Aisha wants to do a favor she could, but your Wala will be for us." Aisha informed Allah's Messenger (ﷺ) of that and he said to her, "Buy and manumit Barirah as the Wala' will go to the manumitted}}
\hadithdefcmd{bukhari}{2718}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا زَكَرِيَّاءُ، قَالَ سَمِعْتُ عَامِرًا، يَقُولُ حَدَّثَنِي جَابِرٌ ـ رضى الله عنه أَنَّهُ كَانَ يَسِيرُ عَلَى جَمَلٍ لَهُ قَدْ أَعْيَا، فَمَرَّ النَّبِيُّ صلى الله عليه وسلم فَضَرَبَهُ، فَدَعَا لَهُ، فَسَارَ بِسَيْرٍ لَيْسَ يَسِيرُ مِثْلَهُ ثُمَّ قَالَ ‏"‏ بِعْنِيهِ بِوَقِيَّةٍ ‏"‏‏.‏ قُلْتُ لاَ‏.‏ ثُمَّ قَالَ ‏"‏ بِعْنِيهِ بِوَقِيَّةٍ ‏"‏‏.‏ فَبِعْتُهُ فَاسْتَثْنَيْتُ حُمْلاَنَهُ إِلَى أَهْلِي، فَلَمَّا قَدِمْنَا أَتَيْتُهُ بِالْجَمَلِ، وَنَقَدَنِي ثَمَنَهُ، ثُمَّ انْصَرَفْتُ، فَأَرْسَلَ عَلَى إِثْرِي، قَالَ ‏"‏ مَا كُنْتُ لآخُذَ جَمَلَكَ، فَخُذْ جَمَلَكَ ذَلِكَ فَهْوَ مَالُكَ ‏"‏‏.‏ قَالَ شُعْبَةُ عَنْ مُغِيرَةَ عَنْ عَامِرٍ عَنْ جَابِرٍ أَفْقَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم ظَهْرَهُ إِلَىَ الْمَدِينَةِ‏.‏ وَقَالَ إِسْحَاقُ عَنْ جَرِيرٍ عَنْ مُغِيرَةَ فَبِعْتُهُ عَلَى أَنَّ لِي فَقَارَ ظَهْرِهِ حَتَّى أَبْلُغَ الْمَدِينَةَ‏.‏ وَقَالَ عَطَاءٌ وَغَيْرُهُ لَكَ ظَهْرُهُ إِلَى الْمَدِينَةِ، وَقَالَ مُحَمَّدُ بْنُ الْمُنْكَدِرِ عَنْ جَابِرٍ شَرَطَ ظَهْرَهُ إِلَى الْمَدِينَةِ‏.‏ وَقَالَ زَيْدُ بْنُ أَسْلَمَ عَنْ جَابِرٍ وَلَكَ ظَهْرُهُ حَتَّى تَرْجِعَ‏.‏ وَقَالَ أَبُو الزُّبَيْرِ عَنْ جَابِرٍ أَفْقَرْنَاكَ ظَهْرَهُ إِلَى الْمَدِينَةِ‏.‏ وَقَالَ الأَعْمَشُ عَنْ سَالِمٍ عَنْ جَابِرٍ تَبَلَّغْ عَلَيْهِ إِلَى أَهْلِكَ‏.‏ وَقَالَ عُبَيْدُ اللَّهِ وَابْنُ إِسْحَاقَ عَنْ وَهْبٍ عَنْ جَابِرٍ اشْتَرَاهُ النَّبِيُّ صلى الله عليه وسلم بِوَقِيَّةٍ‏.‏ وَتَابَعَهُ زَيْدُ بْنُ أَسْلَمَ عَنْ جَابِرٍ‏.‏ وَقَالَ ابْنُ جُرَيْجٍ عَنْ عَطَاءٍ وَغَيْرِهِ عَنْ جَابِرٍ أَخَذْتُهُ بِأَرْبَعَةِ دَنَانِيرَ‏.‏ وَهَذَا يَكُونُ وَقِيَّةً عَلَى حِسَابِ الدِّينَارِ بِعَشَرَةِ دَرَاهِمَ‏.‏ وَلَمْ يُبَيِّنِ الثَّمَنَ مُغِيرَةُ عَنِ الشَّعْبِيِّ عَنْ جَابِرٍ، وَابْنُ الْمُنْكَدِرِ وَأَبُو الزُّبَيْرِ عَنْ جَابِرٍ‏.‏ وَقَالَ الأَعْمَشُ عَنْ سَالِمٍ عَنْ جَابِرٍ وَقِيَّةُ ذَهَبٍ‏.‏ وَقَالَ أَبُو إِسْحَاقَ عَنْ سَالِمٍ عَنْ جَابِرٍ بِمِائَتَىْ دِرْهَمٍ‏.‏ وَقَالَ دَاوُدُ بْنُ قَيْسٍ عَنْ عُبَيْدِ اللَّهِ بْنِ مِقْسَمٍ عَنْ جَابِرٍ اشْتَرَاهُ بِطَرِيقِ تَبُوكَ، أَحْسِبُهُ قَالَ بِأَرْبَعِ أَوَاقٍ‏.‏ وَقَالَ أَبُو نَضْرَةَ عَنْ جَابِرٍ اشْتَرَاهُ بِعِشْرِينَ دِينَارًا‏.‏ وَقَوْلُ الشَّعْبِيِّ بِوَقِيَّةٍ أَكْثَرُ‏.‏ الاِشْتِرَاطُ أَكْثَرُ وَأَصَحُّ عِنْدِي‏.‏ قَالَهُ أَبُو عَبْدِ اللَّهِ‏.‏\hadithno{2718}\hadithtrans{Narrated Jabir:While I was riding a (slow) and tired camel, the Prophet (ﷺ) passed by and beat it and prayed for Allah's Blessings for it. The camel became so fast as it had never been before. The Prophet (ﷺ) then said, "Sell it to me for one Uqiyya (of gold)." I said, "No." He again said, "Sell it to me for one Uqiyya (of gold)." I sold it and stipulated that I should ride it to my house. When we reached (Medina) I took that camel to the Prophet (ﷺ) and he gave me its price. I returned home but he sent for me (and when I went to him) he said, "I will not take your camel. Take your camel as a gift for you." (Various narrations are mentioned here with slight variations in expressions relating the condition that Jabir had the right to ride the sold camel up to Medina)}}
\hadithdefcmd{bukhari}{2719}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَتِ الأَنْصَارُ لِلنَّبِيِّ صلى الله عليه وسلم اقْسِمْ بَيْنَنَا وَبَيْنَ إِخْوَانِنَا النَّخِيلَ‏.‏ قَالَ ‏ "‏ لاَ ‏"‏‏.‏ فَقَالَ تَكْفُونَا الْمَئُونَةَ وَنُشْرِكُكُمْ فِي الثَّمَرَةِ‏.‏ قَالُوا سَمِعْنَا وَأَطَعْنَا‏.‏\hadithno{2719}\hadithtrans{Narrated Abu Huraira:The Ansar said to the Prophet, "Divide our date-palms between us and our emigrant brothers." The Prophet said, "No." The Ansar said to the emigrants, "You may do the labor (in our gardens) and we will share the fruits with you." The emigrants said, "We hear and obey}}
\hadithdefcmd{bukhari}{2720}{حَدَّثَنَا مُوسَى، حَدَّثَنَا جُوَيْرِيَةُ بْنُ أَسْمَاءَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ أَعْطَى رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْبَرَ الْيَهُودَ أَنْ يَعْمَلُوهَا وَيَزْرَعُوهَا، وَلَهُمْ شَطْرُ مَا يَخْرُجُ مِنْهَا‏.‏\hadithno{2720}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) gave the land of Khaibar to the Jews on the condition that they would work on it and cultivate it and they would get half of its yield}}
\hadithdefcmd{bukhari}{2721}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَحَقُّ الشُّرُوطِ أَنْ تُوفُوا بِهِ مَا اسْتَحْلَلْتُمْ بِهِ الْفُرُوجَ ‏"‏‏.‏\hadithno{2721}\hadithtrans{Narrated `Uqba bin Amir:Allah's Messenger (ﷺ) said, "From among all the conditions which you have to fulfill, the conditions which make it legal for you to have sexual relations (i.e. the marriage contract) have the greatest right to be fulfilled}}
\hadithdefcmd{bukhari}{2722}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ سَمِعْتُ حَنْظَلَةَ الزُّرَقِيَّ، قَالَ سَمِعْتُ رَافِعَ بْنَ خَدِيجٍ ـ رضى الله عنه ـ يَقُولُ كُنَّا أَكْثَرَ الأَنْصَارِ حَقْلاً، فَكُنَّا نُكْرِي الأَرْضَ، فَرُبَّمَا أَخْرَجَتْ هَذِهِ وَلَمْ تُخْرِجْ ذِهِ، فَنُهِينَا عَنْ ذَلِكَ، وَلَمْ نُنْهَ عَنِ الْوَرِقِ‏.‏\hadithno{2722}\hadithtrans{Narrated Rafi` bin Khadij:We used to work on the fields more than the other Ansar, and we used to rent the land (for the yield of a specific portion of it). But sometimes that portion or the rest of the land did not give any yield, so we were forbidden (by the Prophet (ﷺ) ) to follow such a system, but we were allowed to rent the land for money}}
\hadithdefcmd{bukhari}{2723}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبِيعُ حَاضِرٌ لِبَادٍ، وَلاَ تَنَاجَشُوا، وَلاَ يَزِيدَنَّ عَلَى بَيْعِ أَخِيهِ، وَلاَ يَخْطُبَنَّ عَلَى خِطْبَتِهِ، وَلاَ تَسْأَلِ الْمَرْأَةُ طَلاَقَ أُخْتِهَا لِتَسْتَكْفِئَ إِنَاءَهَا ‏"‏‏.‏\hadithno{2723}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "No town-dweller should sell for a bedouin. Do not practice Najsh (i.e. Do not offer a high price for a thing which you do not want to buy, in order to deceive the people). No Muslim should offer more for a thing already bought by his Muslim brother, nor should he demand the hand of a girl already engaged to another Muslim. A Muslim woman shall not try to bring about The divorce of her sister (i.e. another Muslim woman) in order to take her place herself}}
\hadithdefcmd{bukhari}{2724}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، رضى الله عنهم أَنَّهُمَا قَالاَ إِنَّ رَجُلاً مِنَ الأَعْرَابِ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولَ اللَّهِ أَنْشُدُكَ اللَّهَ إِلاَّ قَضَيْتَ لِي بِكِتَابِ اللَّهِ‏.‏ فَقَالَ الْخَصْمُ الآخَرُ وَهْوَ أَفْقَهُ مِنْهُ نَعَمْ فَاقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ، وَائْذَنْ لِي‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قُلْ ‏"‏‏.‏ قَالَ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا، فَزَنَى بِامْرَأَتِهِ، وَإِنِّي أُخْبِرْتُ أَنَّ عَلَى ابْنِي الرَّجْمَ، فَافْتَدَيْتُ مِنْهُ بِمِائَةِ شَاةٍ وَوَلِيدَةٍ، فَسَأَلْتُ أَهْلَ الْعِلْمِ فَأَخْبَرُونِي أَنَّمَا عَلَى ابْنِي جَلْدُ مِائَةٍ، وَتَغْرِيبُ عَامٍ، وَأَنَّ عَلَى امْرَأَةِ هَذَا الرَّجْمَ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ، الْوَلِيدَةُ وَالْغَنَمُ رَدٌّ، وَعَلَى ابْنِكَ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، اغْدُ يَا أُنَيْسُ إِلَى امْرَأَةِ هَذَا فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا ‏"‏‏.‏ قَالَ فَغَدَا عَلَيْهَا فَاعْتَرَفَتْ، فَأَمَرَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَرُجِمَتْ‏.‏\hadithno{2724}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid Al-Juhani:A bedouin came to Allah's Messenger (ﷺ) and said, "O Allah's apostle! I ask you by Allah to judge My case according to Allah's Laws." His opponent, who was more learned than he, said, "Yes, judge between us according to Allah's Laws, and allow me to speak." Allah's Messenger (ﷺ) said, "Speak." He (i .e. the bedouin or the other man) said, "My son was working as a laborer for this (man) and he committed illegal sexual intercourse with his wife. The people told me that it was obligatory that my son should be stoned to death, so in lieu of that I ransomed my son by paying one hundred sheep and a slave girl. Then I asked the religious scholars about it, and they informed me that my son must be lashed one hundred lashes, and be exiled for one year, and the wife of this (man) must be stoned to death." Allah's Messenger (ﷺ) said, "By Him in Whose Hands my soul is, I will judge between you according to Allah's Laws. The slave-girl and the sheep are to be returned to you, your son is to receive a hundred lashes and be exiled for one year. You, Unais, go to the wife of this (man) and if she confesses her guilt, stone her to death." Unais went to that woman next morning and she confessed. Allah's Messenger (ﷺ) ordered that she be stoned to death}}
\hadithdefcmd{bukhari}{2726}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ أَيْمَنَ الْمَكِّيُّ، عَنْ أَبِيهِ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ دَخَلَتْ عَلَىَّ بَرِيرَةُ وَهْىَ مُكَاتَبَةٌ، فَقَالَتْ يَا أُمَّ الْمُؤْمِنِينَ اشْتَرِينِي فَإِنَّ أَهْلِي يَبِيعُونِي فَأَعْتِقِينِي قَالَتْ نَعَمْ‏.‏ قَالَتْ إِنَّ أَهْلِي لاَ يَبِيعُونِي حَتَّى يَشْتَرِطُوا وَلاَئِي‏.‏ قَالَتْ لاَ حَاجَةَ لِي فِيكِ‏.‏ فَسَمِعَ ذَلِكَ النَّبِيُّ صلى الله عليه وسلم أَوْ بَلَغَهُ، فَقَالَ ‏"‏ مَا شَأْنُ بَرِيرَةَ فَقَالَ اشْتَرِيهَا فَأَعْتِقِيهَا وَلْيَشْتَرِطُوا مَا شَاءُوا ‏"‏‏.‏ قَالَتْ فَاشْتَرَيْتُهَا فَأَعْتَقْتُهَا، وَاشْتَرَطَ أَهْلُهَا وَلاَءَهَا، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الْوَلاَءُ لِمَنْ أَعْتَقَ، وَإِنِ اشْتَرَطُوا مِائَةَ شَرْطٍ ‏"‏‏.‏\hadithno{2726}\hadithtrans{Narrated Aiman Al-Makki:When I visited Aisha she said, "Barirah who had a written contract for her emancipation for a certain amount came to me and said, "O mother of the believers! Buy me and manumit me, as my masters will sell me." Aisha agreed to it. Barirah said, 'My masters will sell me on the condition that my Wala will go to them." Aisha said to her, 'Then I am not in need of you.' The Prophet (ﷺ) heard of that or was told about it and so he asked Aisha, 'What is the problem of Barirah?' He said, 'Buy her and manumit her, no matter what they stipulate.' Aisha added, 'I bought and manumitted her, though her masters had stipulated that her Wala would be for them.' The Prophet (ﷺ) said, The Wala is for the liberator, even if the other stipulated a hundred conditions}}
\hadithdefcmd{bukhari}{2727}{حَدَّثَنَا مُحَمَّدُ بْنُ عَرْعَرَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ التَّلَقِّي، وَأَنْ يَبْتَاعَ الْمُهَاجِرُ لِلأَعْرَابِيِّ، وَأَنْ تَشْتَرِطَ الْمَرْأَةُ طَلاَقَ أُخْتِهَا، وَأَنْ يَسْتَامَ الرَّجُلُ عَلَى سَوْمِ أَخِيهِ، وَنَهَى عَنِ النَّجْشِ، وَعَنِ التَّصْرِيَةِ‏.‏ تَابَعَهُ مُعَاذٌ وَعَبْدُ الصَّمَدِ عَنْ شُعْبَةَ‏.‏ وَقَالَ غُنْدَرٌ وَعَبْدُ الرَّحْمَنِ نُهِيَ‏.‏ وَقَالَ آدَمُ نُهِينَا‏.‏ وَقَالَ النَّضْرُ وَحَجَّاجُ بْنُ مِنْهَالٍ نَهَى‏.‏\hadithno{2727}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) forbade (1) the meeting of the caravan (of goods) on the way, (2) and that a residing person buys for a bedouin, (3) and that a woman stipulates the divorce of the wife of the would-be husband, (4) and that a man tries to cause the cancellation of a bargain concluded by another. He also forbade An-Najsh (see Hadith 824) and that one withholds the milk in the udder of the animal so that he may deceive people on selling it}}
\hadithdefcmd{bukhari}{2728}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا هِشَامٌ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُ قَالَ أَخْبَرَنِي يَعْلَى بْنُ مُسْلِمٍ، وَعَمْرُو بْنُ دِينَارٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، يَزِيدُ أَحَدُهُمَا عَلَى صَاحِبِهِ وَغَيْرُهُمَا قَدْ سَمِعْتُهُ يُحَدِّثُهُ عَنْ سَعِيدِ بْنِ جُبَيْرٍ قَالَ إِنَّا لَعِنْدَ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ حَدَّثَنِي أُبَىُّ بْنُ كَعْبٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مُوسَى رَسُولُ اللَّهِ ‏"‏ فَذَكَرَ الْحَدِيثَ ‏\{‏قَالَ أَلَمْ أَقُلْ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِيَ صَبْرًا‏\}‏ كَانَتِ الأُولَى نِسْيَانًا، وَالْوُسْطَى شَرْطًا، وَالثَّالِثَةُ عَمْدًا ‏\{‏قَالَ لاَ تُؤَاخِذْنِي بِمَا نَسِيتُ وَلاَ تُرْهِقْنِي مِنْ أَمْرِي عُسْرًا‏\}‏‏.‏ ‏\{‏لَقِيَا غُلاَمًا فَقَتَلَهُ‏\}‏ فَانْطَلَقَا فَوَجَدَا جِدَارًا يُرِيدُ أَنْ يَنْقَضَّ فَأَقَامَهُ‏.‏ قَرَأَهَا ابْنُ عَبَّاسٍ أَمَامَهُمْ مَلِكٌ‏.‏\hadithno{2728}\hadithtrans{Narrated Ubai bin Ka`b:Allah's Messenger (ﷺ) said, "Moses the Messenger of Allah," and then he narrated the whole story about him. Al-Khadir said to Moses, "Did not I tell you that you can have no patience with me." (18.72). Moses then violated the agreement for the first time because of forgetfulness, then Moses promised that if he asked Al-Khadir about anything, the latter would have the right to desert him. Moses abided by that condition and on the third occasion he intentionally asked Al-Khadir and caused that condition to be applied. The three occasions referred to above are referred to by the following Verses: "Call me not to account for forgetting And be not hard upon me." (18.73) "Then they met a boy and Khadir killed him." (18.74) "Then they proceeded and found a wall which was on the verge of falling and Khadir set it up straight}}
\hadithdefcmd{bukhari}{2729}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْنِي بَرِيرَةُ فَقَالَتْ كَاتَبْتُ أَهْلِي عَلَى تِسْعِ أَوَاقٍ فِي كُلِّ عَامٍ أُوقِيَّةٌ، فَأَعِينِينِي‏.‏ فَقَالَتْ إِنْ أَحَبُّوا أَنْ أَعُدَّهَا لَهُمْ، وَيَكُونَ وَلاَؤُكِ لِي فَعَلْتُ‏.‏ فَذَهَبَتْ بَرِيرَةُ إِلَى أَهْلِهَا، فَقَالَتْ لَهُمْ، فَأَبَوْا عَلَيْهَا، فَجَاءَتْ مِنْ عِنْدِهِمْ وَرَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ، فَقَالَتْ إِنِّي قَدْ عَرَضْتُ ذَلِكَ عَلَيْهِمْ فَأَبَوْا إِلاَّ أَنْ يَكُونَ الْوَلاَءُ لَهُمْ‏.‏ فَسَمِعَ النَّبِيُّ صلى الله عليه وسلم فَأَخْبَرَتْ عَائِشَةُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ خُذِيهَا وَاشْتَرِطِي لَهُمُ الْوَلاَءَ، فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏ فَفَعَلَتْ عَائِشَةُ، ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّاسِ، فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ، ثُمَّ قَالَ ‏"‏ مَا بَالُ رِجَالٍ يَشْتَرِطُونَ شُرُوطًا لَيْسَتْ فِي كِتَابِ اللَّهِ مَا كَانَ مِنْ شَرْطٍ لَيْسَ فِي كِتَابِ اللَّهِ فَهْوَ بَاطِلٌ، وَإِنْ كَانَ مِائَةَ شَرْطٍ، قَضَاءُ اللَّهِ أَحَقُّ، وَشَرْطُ اللَّهِ أَوْثَقُ، وَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏\hadithno{2729}\hadithtrans{Narrated `Urwa:Aisha said, "Barirah came to me and said, 'My people (masters) have written the contract for my emancipation for nine Awaq ) of gold) to be paid in yearly installments, one Uqiyya per year; so help me." Aisha said (to her), "If your masters agree, I will pay them the whole sum provided the Wala will be for me." Barirah went to her masters and told them about it, but they refused the offer and she returned from them while Allah's Messenger (ﷺ) was sitting. She said, "I presented the offer to them, but they refused unless the Wala' would be for them." When the Prophet (ﷺ) heard that and `Aisha told him about It, he said to her, "Buy Barirah and let them stipulate that her Wala' will be for them, as the Wala' is for the manumitted." `Aisha did so. After that Allah's Messenger (ﷺ) got up amidst the people, Glorified and Praised Allah and said, "What is wrong with some people who stipulate things which are not in Allah's Laws? Any condition which is not in Allah's Laws is invalid even if there were a hundred such conditions. Allah's Rules are the most valid and Allah's Conditions are the most solid. The Wala is for the manumitted}}
\hadithdefcmd{bukhari}{2730}{حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى أَبُو غَسَّانَ الْكِنَانِيُّ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ لَمَّا فَدَعَ أَهْلُ خَيْبَرَ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَامَ عُمَرُ خَطِيبًا فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عَامَلَ يَهُودَ خَيْبَرَ عَلَى أَمْوَالِهِمْ، وَقَالَ ‏"‏ نُقِرُّكُمْ مَا أَقَرَّكُمُ اللَّهُ ‏"‏‏.‏ وَإِنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ خَرَجَ إِلَى مَالِهِ هُنَاكَ فَعُدِيَ عَلَيْهِ مِنَ اللَّيْلِ، فَفُدِعَتْ يَدَاهُ وَرِجْلاَهُ، وَلَيْسَ لَنَا هُنَاكَ عَدُوٌّ غَيْرُهُمْ، هُمْ عَدُوُّنَا وَتُهَمَتُنَا، وَقَدْ رَأَيْتُ إِجْلاَءَهُمْ، فَلَمَّا أَجْمَعَ عُمَرُ عَلَى ذَلِكَ أَتَاهُ أَحَدُ بَنِي أَبِي الْحُقَيْقِ، فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ، أَتُخْرِجُنَا وَقَدْ أَقَرَّنَا مُحَمَّدٌ صلى الله عليه وسلم وَعَامَلَنَا عَلَى الأَمْوَالِ، وَشَرَطَ ذَلِكَ لَنَا فَقَالَ عُمَرُ أَظَنَنْتَ أَنِّي نَسِيتُ قَوْلَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ كَيْفَ بِكَ إِذَا أُخْرِجْتَ مِنْ خَيْبَرَ تَعْدُو بِكَ قَلُوصُكَ، لَيْلَةً بَعْدَ لَيْلَةٍ ‏"‏‏.‏ فَقَالَ كَانَتْ هَذِهِ هُزَيْلَةً مِنْ أَبِي الْقَاسِمِ‏.‏ قَالَ كَذَبْتَ يَا عَدُوَّ اللَّهِ‏.‏ فَأَجْلاَهُمْ عُمَرُ وَأَعْطَاهُمْ قِيمَةَ مَا كَانَ لَهُمْ مِنَ الثَّمَرِ مَالاً وَإِبِلاً وَعُرُوضًا، مِنْ أَقْتَابٍ وَحِبَالٍ وَغَيْرِ ذَلِكَ‏.‏ رَوَاهُ حَمَّادُ بْنُ سَلَمَةَ عَنْ عُبَيْدِ اللَّهِ، أَحْسِبُهُ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم، اخْتَصَرَهُ‏.‏\hadithno{2730}\hadithtrans{Narrated Ibn `Umar:When the people of Khaibar dislocated `Abdullah bin `Umar's hands and feet, `Umar got up delivering a sermon saying, "No doubt, Allah's Messenger (ﷺ) made a contract with the Jews concerning their properties, and said to them, 'We allow you (to stand in your land) as long as Allah allows you.' Now `Abdullah bin `Umar went to his land and was attacked at night, and his hands and feet were dislocated, and as we have no enemies there except those Jews, they are our enemies and the only people whom we suspect, I have made up my mind to exile them." When `Umar decided to carry out his decision, a son of Abu Al-Huqaiq's came and addressed `Umar, "O chief of the believers, will you exile us although Muhammad allowed us to stay at our places, and made a contract with us about our properties, and accepted the condition of our residence in our land?" `Umar said, "Do you think that I have forgotten the statement of Allah's Messenger (ﷺ), i.e.: What will your condition be when you are expelled from Khaibar and your camel will be carrying you night after night?" The Jew replied, "That was a joke from Abul-Qasim." `Umar said, "O the enemy of Allah! You are telling a lie." `Umar then drove them out and paid them the price of their properties in the form of fruits, money, camel saddles and ropes, etc}}
\hadithdefcmd{bukhari}{2732}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، قَالَ أَخْبَرَنِي الزُّهْرِيُّ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، وَمَرْوَانَ، يُصَدِّقُ كُلُّ وَاحِدٍ مِنْهُمَا حَدِيثَ صَاحِبِهِ قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَمَنَ الْحُدَيْبِيَةِ، حَتَّى كَانُوا بِبَعْضِ الطَّرِيقِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ خَالِدَ بْنَ الْوَلِيدِ بِالْغَمِيمِ فِي خَيْلٍ لِقُرَيْشٍ طَلِيعَةً فَخُذُوا ذَاتَ الْيَمِينِ ‏"‏‏.‏ فَوَاللَّهِ مَا شَعَرَ بِهِمْ خَالِدٌ حَتَّى إِذَا هُمْ بِقَتَرَةِ الْجَيْشِ، فَانْطَلَقَ يَرْكُضُ نَذِيرًا لِقُرَيْشٍ، وَسَارَ النَّبِيُّ صلى الله عليه وسلم حَتَّى إِذَا كَانَ بِالثَّنِيَّةِ الَّتِي يُهْبَطُ عَلَيْهِمْ مِنْهَا، بَرَكَتْ بِهِ رَاحِلَتُهُ‏.‏ فَقَالَ النَّاسُ حَلْ حَلْ‏.‏ فَأَلَحَّتْ، فَقَالُوا خَلأَتِ الْقَصْوَاءُ، خَلأَتِ الْقَصْوَاءُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا خَلأَتِ الْقَصْوَاءُ، وَمَا ذَاكَ لَهَا بِخُلُقٍ، وَلَكِنْ حَبَسَهَا حَابِسُ الْفِيلِ، ثُمَّ قَالَ وَالَّذِي نَفْسِي بِيَدِهِ لاَ يَسْأَلُونِي خُطَّةً يُعَظِّمُونَ فِيهَا حُرُمَاتِ اللَّهِ إِلاَّ أَعْطَيْتُهُمْ إِيَّاهَا ‏"‏‏.‏ ثُمَّ زَجَرَهَا فَوَثَبَتْ، قَالَ فَعَدَلَ عَنْهُمْ حَتَّى نَزَلَ بِأَقْصَى الْحُدَيْبِيَةِ، عَلَى ثَمَدٍ قَلِيلِ الْمَاءِ يَتَبَرَّضُهُ النَّاسُ تَبَرُّضًا، فَلَمْ يُلَبِّثْهُ النَّاسُ حَتَّى نَزَحُوهُ، وَشُكِيَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الْعَطَشُ، فَانْتَزَعَ سَهْمًا مِنْ كِنَانَتِهِ، ثُمَّ أَمَرَهُمْ أَنْ يَجْعَلُوهُ فِيهِ، فَوَاللَّهِ مَا زَالَ يَجِيشُ لَهُمْ بِالرِّيِّ حَتَّى صَدَرُوا عَنْهُ، فَبَيْنَمَا هُمْ كَذَلِكَ، إِذْ جَاءَ بُدَيْلُ بْنُ وَرْقَاءَ الْخُزَاعِيُّ فِي نَفَرٍ مِنْ قَوْمِهِ مِنْ خُزَاعَةَ، وَكَانُوا عَيْبَةَ نُصْحِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ أَهْلِ تِهَامَةَ، فَقَالَ إِنِّي تَرَكْتُ كَعْبَ بْنَ لُؤَىٍّ وَعَامِرَ بْنَ لُؤَىٍّ نَزَلُوا أَعْدَادَ مِيَاهِ الْحُدَيْبِيَةِ، وَمَعَهُمُ الْعُوذُ الْمَطَافِيلُ، وَهُمْ مُقَاتِلُوكَ وَصَادُّوكَ عَنِ الْبَيْتِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّا لَمْ نَجِئْ لِقِتَالِ أَحَدٍ، وَلَكِنَّا جِئْنَا مُعْتَمِرِينَ، وَإِنَّ قُرَيْشًا قَدْ نَهِكَتْهُمُ الْحَرْبُ، وَأَضَرَّتْ بِهِمْ، فَإِنْ شَاءُوا مَادَدْتُهُمْ مُدَّةً، وَيُخَلُّوا بَيْنِي وَبَيْنَ النَّاسِ، فَإِنْ أَظْهَرْ فَإِنْ شَاءُوا أَنْ يَدْخُلُوا فِيمَا دَخَلَ فِيهِ النَّاسُ فَعَلُوا، وَإِلاَّ فَقَدْ جَمُّوا، وَإِنْ هُمْ أَبَوْا فَوَالَّذِي نَفْسِي بِيَدِهِ، لأُقَاتِلَنَّهُمْ عَلَى أَمْرِي هَذَا حَتَّى تَنْفَرِدَ سَالِفَتِي، وَلَيُنْفِذَنَّ اللَّهُ أَمْرَهُ ‏"‏‏.‏ فَقَالَ بُدَيْلٌ سَأُبَلِّغُهُمْ مَا تَقُولُ‏.‏ قَالَ فَانْطَلَقَ حَتَّى أَتَى قُرَيْشًا قَالَ إِنَّا قَدْ جِئْنَاكُمْ مِنْ هَذَا الرَّجُلِ، وَسَمِعْنَاهُ يَقُولُ قَوْلاً، فَإِنْ شِئْتُمْ أَنْ نَعْرِضَهُ عَلَيْكُمْ فَعَلْنَا، فَقَالَ سُفَهَاؤُهُمْ لاَ حَاجَةَ لَنَا أَنْ تُخْبِرَنَا عَنْهُ بِشَىْءٍ‏.‏ وَقَالَ ذَوُو الرَّأْىِ مِنْهُمْ هَاتِ مَا سَمِعْتَهُ يَقُولُ‏.‏ قَالَ سَمِعْتُهُ يَقُولُ كَذَا وَكَذَا، فَحَدَّثَهُمْ بِمَا قَالَ النَّبِيُّ صلى الله عليه وسلم‏.‏ فَقَامَ عُرْوَةُ بْنُ مَسْعُودٍ فَقَالَ أَىْ قَوْمِ أَلَسْتُمْ بِالْوَالِدِ قَالُوا بَلَى‏.‏ قَالَ أَوَلَسْتُ بِالْوَلَدِ قَالُوا بَلَى‏.‏ قَالَ فَهَلْ تَتَّهِمُونِي‏.‏ قَالُوا لاَ‏.‏ قَالَ أَلَسْتُمْ تَعْلَمُونَ أَنِّي اسْتَنْفَرْتُ أَهْلَ عُكَاظٍ، فَلَمَّا بَلَّحُوا عَلَىَّ جِئْتُكُمْ بِأَهْلِي وَوَلَدِي وَمَنْ أَطَاعَنِي قَالُوا بَلَى‏.‏ قَالَ فَإِنَّ هَذَا قَدْ عَرَضَ لَكُمْ خُطَّةَ رُشْدٍ، اقْبَلُوهَا وَدَعُونِي آتِهِ‏.‏ قَالُوا ائْتِهِ‏.‏ فَأَتَاهُ فَجَعَلَ يُكَلِّمُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم نَحْوًا مِنْ قَوْلِهِ لِبُدَيْلٍ، فَقَالَ عُرْوَةُ عِنْدَ ذَلِكَ أَىْ مُحَمَّدُ، أَرَأَيْتَ إِنِ اسْتَأْصَلْتَ أَمْرَ قَوْمِكَ هَلْ سَمِعْتَ بِأَحَدٍ مِنَ الْعَرَبِ اجْتَاحَ أَهْلَهُ قَبْلَكَ وَإِنْ تَكُنِ الأُخْرَى، فَإِنِّي وَاللَّهِ لأَرَى وُجُوهًا، وَإِنِّي لأَرَى أَوْشَابًا مِنَ النَّاسِ خَلِيقًا أَنْ يَفِرُّوا وَيَدَعُوكَ‏.‏ فَقَالَ لَهُ أَبُو بَكْرٍ امْصُصْ بَظْرَ اللاَّتِ، أَنَحْنُ نَفِرُّ عَنْهُ وَنَدَعُهُ فَقَالَ مَنْ ذَا قَالُوا أَبُو بَكْرٍ‏.‏ قَالَ أَمَا وَالَّذِي نَفْسِي بِيَدِهِ لَوْلاَ يَدٌ كَانَتْ لَكَ عِنْدِي لَمْ أَجْزِكَ بِهَا لأَجَبْتُكَ‏.‏ قَالَ وَجَعَلَ يُكَلِّمُ النَّبِيَّ صلى الله عليه وسلم فَكُلَّمَا تَكَلَّمَ أَخَذَ بِلِحْيَتِهِ، وَالْمُغِيرَةُ بْنُ شُعْبَةَ قَائِمٌ عَلَى رَأْسِ النَّبِيِّ صلى الله عليه وسلم وَمَعَهُ السَّيْفُ وَعَلَيْهِ الْمِغْفَرُ، فَكُلَّمَا أَهْوَى عُرْوَةُ بِيَدِهِ إِلَى لِحْيَةِ النَّبِيِّ صلى الله عليه وسلم ضَرَبَ يَدَهُ بِنَعْلِ السَّيْفِ، وَقَالَ لَهُ أَخِّرْ يَدَكَ عَنْ لِحْيَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَرَفَعَ عُرْوَةُ رَأْسَهُ فَقَالَ مَنْ هَذَا قَالُوا الْمُغِيرَةُ بْنُ شُعْبَةَ‏.‏ فَقَالَ أَىْ غُدَرُ، أَلَسْتُ أَسْعَى فِي غَدْرَتِكَ وَكَانَ الْمُغِيرَةُ صَحِبَ قَوْمًا فِي الْجَاهِلِيَّةِ، فَقَتَلَهُمْ، وَأَخَذَ أَمْوَالَهُمْ، ثُمَّ جَاءَ فَأَسْلَمَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَمَّا الإِسْلاَمَ فَأَقْبَلُ، وَأَمَّا الْمَالَ فَلَسْتُ مِنْهُ فِي شَىْءٍ ‏"‏‏.‏ ثُمَّ إِنَّ عُرْوَةَ جَعَلَ يَرْمُقُ أَصْحَابَ النَّبِيِّ صلى الله عليه وسلم بِعَيْنَيْهِ‏.‏ قَالَ فَوَاللَّهِ مَا تَنَخَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم نُخَامَةً إِلاَّ وَقَعَتْ فِي كَفِّ رَجُلٍ مِنْهُمْ فَدَلَكَ بِهَا وَجْهَهُ وَجِلْدَهُ، وَإِذَا أَمَرَهُمُ ابْتَدَرُوا أَمْرَهُ، وَإِذَا تَوَضَّأَ كَادُوا يَقْتَتِلُونَ عَلَى وَضُوئِهِ، وَإِذَا تَكَلَّمَ خَفَضُوا أَصْوَاتَهُمْ عِنْدَهُ، وَمَا يُحِدُّونَ إِلَيْهِ النَّظَرَ تَعْظِيمًا لَهُ، فَرَجَعَ عُرْوَةُ إِلَى أَصْحَابِهِ، فَقَالَ أَىْ قَوْمِ، وَاللَّهِ لَقَدْ وَفَدْتُ عَلَى الْمُلُوكِ، وَوَفَدْتُ عَلَى قَيْصَرَ وَكِسْرَى وَالنَّجَاشِيِّ وَاللَّهِ إِنْ رَأَيْتُ مَلِكًا قَطُّ، يُعَظِّمُهُ أَصْحَابُهُ مَا يُعَظِّمُ أَصْحَابُ مُحَمَّدٍ صلى الله عليه وسلم مُحَمَّدًا، وَاللَّهِ إِنْ تَنَخَّمَ نُخَامَةً إِلاَّ وَقَعَتْ فِي كَفِّ رَجُلٍ مِنْهُمْ، فَدَلَكَ بِهَا وَجْهَهُ وَجِلْدَهُ، وَإِذَا أَمَرَهُمُ ابْتَدَرُوا أَمْرَهُ وَإِذَا تَوَضَّأَ كَادُوا يَقْتَتِلُونَ عَلَى وَضُوئِهِ، وَإِذَا تَكَلَّمَ خَفَضُوا أَصْوَاتَهُمْ عِنْدَهُ، وَمَا يُحِدُّونَ إِلَيْهِ النَّظَرَ تَعْظِيمًا لَهُ، وَإِنَّهُ قَدْ عَرَضَ عَلَيْكُمْ خُطَّةَ رُشْدٍ، فَاقْبَلُوهَا‏.‏ فَقَالَ رَجُلٌ مِنْ بَنِي كِنَانَةَ دَعُونِي آتِهِ‏.‏ فَقَالُوا ائْتِهِ‏.‏ فَلَمَّا أَشْرَفَ عَلَى النَّبِيِّ صلى الله عليه وسلم وَأَصْحَابِهِ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا فُلاَنٌ، وَهْوَ مِنْ قَوْمٍ يُعَظِّمُونَ الْبُدْنَ فَابْعَثُوهَا لَهُ ‏"‏‏.‏ فَبُعِثَتْ لَهُ وَاسْتَقْبَلَهُ النَّاسُ يُلَبُّونَ، فَلَمَّا رَأَى ذَلِكَ قَالَ سُبْحَانَ اللَّهِ مَا يَنْبَغِي لِهَؤُلاَءِ أَنْ يُصَدُّوا عَنِ الْبَيْتِ، فَلَمَّا رَجَعَ إِلَى أَصْحَابِهِ قَالَ رَأَيْتُ الْبُدْنَ قَدْ قُلِّدَتْ وَأُشْعِرَتْ، فَمَا أَرَى أَنْ يُصَدُّوا عَنِ الْبَيْتِ‏.‏ فَقَامَ رَجُلٌ مِنْهُمْ يُقَالُ لَهُ مِكْرَزُ بْنُ حَفْصٍ‏.‏ فَقَالَ دَعُونِي آتِهِ‏.‏ فَقَالُوا ائْتِهِ‏.‏ فَلَمَّا أَشْرَفَ عَلَيْهِمْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَذَا مِكْرَزٌ وَهْوَ رَجُلٌ فَاجِرٌ ‏"‏‏.‏ فَجَعَلَ يُكَلِّمُ النَّبِيَّ صلى الله عليه وسلم، فَبَيْنَمَا هُوَ يُكَلِّمُهُ إِذْ جَاءَ سُهَيْلُ بْنُ عَمْرٍو‏.‏ قَالَ مَعْمَرٌ فَأَخْبَرَنِي أَيُّوبُ عَنْ عِكْرِمَةَ، أَنَّهُ لَمَّا جَاءَ سُهَيْلُ بْنُ عَمْرٍو قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَقَدْ سَهُلَ لَكُمْ مِنْ أَمْرِكُمْ ‏"‏‏.‏ قَالَ مَعْمَرٌ قَالَ الزُّهْرِيُّ فِي حَدِيثِهِ فَجَاءَ سُهَيْلُ بْنُ عَمْرٍو فَقَالَ هَاتِ، اكْتُبْ بَيْنَنَا وَبَيْنَكُمْ كِتَابًا، فَدَعَا النَّبِيُّ صلى الله عليه وسلم الْكَاتِبَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏"‏‏.‏ قَالَ سُهَيْلٌ أَمَّا الرَّحْمَنُ فَوَاللَّهِ مَا أَدْرِي مَا هُوَ وَلَكِنِ اكْتُبْ بِاسْمِكَ اللَّهُمَّ‏.‏ كَمَا كُنْتَ تَكْتُبُ‏.‏ فَقَالَ الْمُسْلِمُونَ وَاللَّهِ لاَ نَكْتُبُهَا إِلاَّ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اكْتُبْ بِاسْمِكَ اللَّهُمَّ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ هَذَا مَا قَاضَى عَلَيْهِ مُحَمَّدٌ رَسُولُ اللَّهِ ‏"‏‏.‏ فَقَالَ سُهَيْلٌ وَاللَّهِ لَوْ كُنَّا نَعْلَمُ أَنَّكَ رَسُولُ اللَّهِ مَا صَدَدْنَاكَ عَنِ الْبَيْتِ وَلاَ قَاتَلْنَاكَ، وَلَكِنِ اكْتُبْ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَاللَّهِ إِنِّي لَرَسُولُ اللَّهِ وَإِنْ كَذَّبْتُمُونِي‏.‏ اكْتُبْ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ ‏"‏‏.‏ قَالَ الزُّهْرِيُّ وَذَلِكَ لِقَوْلِهِ ‏"‏ لاَ يَسْأَلُونِي خُطَّةً يُعَظِّمُونَ فِيهَا حُرُمَاتِ اللَّهِ إِلاَّ أَعْطَيْتُهُمْ إِيَّاهَا ‏"‏‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَلَى أَنْ تُخَلُّوا بَيْنَنَا وَبَيْنَ الْبَيْتِ فَنَطُوفَ بِهِ ‏"‏‏.‏ فَقَالَ سُهَيْلٌ وَاللَّهِ لاَ تَتَحَدَّثُ الْعَرَبُ أَنَّا أُخِذْنَا ضُغْطَةً وَلَكِنْ ذَلِكَ مِنَ الْعَامِ الْمُقْبِلِ فَكَتَبَ‏.‏ فَقَالَ سُهَيْلٌ وَعَلَى أَنَّهُ لاَ يَأْتِيكَ مِنَّا رَجُلٌ، وَإِنْ كَانَ عَلَى دِينِكَ، إِلاَّ رَدَدْتَهُ إِلَيْنَا‏.‏ قَالَ الْمُسْلِمُونَ سُبْحَانَ اللَّهِ كَيْفَ يُرَدُّ إِلَى الْمُشْرِكِينَ وَقَدْ جَاءَ مُسْلِمًا فَبَيْنَمَا هُمْ كَذَلِكَ إِذْ دَخَلَ أَبُو جَنْدَلِ بْنُ سُهَيْلِ بْنِ عَمْرٍو يَرْسُفُ فِي قُيُودِهِ، وَقَدْ خَرَجَ مِنْ أَسْفَلِ مَكَّةَ، حَتَّى رَمَى بِنَفْسِهِ بَيْنَ أَظْهُرِ الْمُسْلِمِينَ‏.‏ فَقَالَ سُهَيْلٌ هَذَا يَا مُحَمَّدُ أَوَّلُ مَا أُقَاضِيكَ عَلَيْهِ أَنْ تَرُدَّهُ إِلَىَّ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّا لَمْ نَقْضِ الْكِتَابَ بَعْدُ ‏"‏‏.‏ قَالَ فَوَاللَّهِ إِذًا لَمْ أُصَالِحْكَ عَلَى شَىْءٍ أَبَدًا‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَأَجِزْهُ لِي ‏"‏‏.‏ قَالَ مَا أَنَا بِمُجِيزِهِ لَكَ‏.‏ قَالَ ‏"‏ بَلَى، فَافْعَلْ ‏"‏‏.‏ قَالَ مَا أَنَا بِفَاعِلٍ‏.‏ قَالَ مِكْرَزٌ بَلْ قَدْ أَجَزْنَاهُ لَكَ‏.‏ قَالَ أَبُو جَنْدَلٍ أَىْ مَعْشَرَ الْمُسْلِمِينَ، أُرَدُّ إِلَى الْمُشْرِكِينَ وَقَدْ جِئْتُ مُسْلِمًا أَلاَ تَرَوْنَ مَا قَدْ لَقِيتُ وَكَانَ قَدْ عُذِّبَ عَذَابًا شَدِيدًا فِي اللَّهِ‏.‏ قَالَ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ فَأَتَيْتُ نَبِيَّ اللَّهِ صلى الله عليه وسلم فَقُلْتُ أَلَسْتَ نَبِيَّ اللَّهِ حَقًّا قَالَ ‏"‏ بَلَى ‏"‏‏.‏ قُلْتُ أَلَسْنَا عَلَى الْحَقِّ وَعَدُوُّنَا عَلَى الْبَاطِلِ قَالَ ‏"‏ بَلَى ‏"‏‏.‏ قُلْتُ فَلِمَ نُعْطِي الدَّنِيَّةَ فِي دِينِنَا إِذًا قَالَ ‏"‏ إِنِّي رَسُولُ اللَّهِ، وَلَسْتُ أَعْصِيهِ وَهْوَ نَاصِرِي ‏"‏‏.‏ قُلْتُ أَوَلَيْسَ كُنْتَ تُحَدِّثُنَا أَنَّا سَنَأْتِي الْبَيْتَ فَنَطُوفُ بِهِ قَالَ ‏"‏ بَلَى، فَأَخْبَرْتُكَ أَنَّا نَأْتِيهِ الْعَامَ ‏"‏‏.‏ قَالَ قُلْتُ لاَ‏.‏ قَالَ ‏"‏ فَإِنَّكَ آتِيهِ وَمُطَّوِّفٌ بِهِ ‏"‏‏.‏ قَالَ فَأَتَيْتُ أَبَا بَكْرٍ فَقُلْتُ يَا أَبَا بَكْرٍ، أَلَيْسَ هَذَا نَبِيَّ اللَّهِ حَقًّا قَالَ بَلَى‏.‏ قُلْتُ أَلَسْنَا عَلَى الْحَقِّ وَعَدُوُّنَا عَلَى الْبَاطِلِ قَالَ بَلَى‏.‏ قُلْتُ فَلِمَ نُعْطِي الدَّنِيَّةَ فِي دِينِنَا إِذًا قَالَ أَيُّهَا الرَّجُلُ، إِنَّهُ لَرَسُولُ اللَّهِ صلى الله عليه وسلم وَلَيْسَ يَعْصِي رَبَّهُ وَهْوَ نَاصِرُهُ، فَاسْتَمْسِكْ بِغَرْزِهِ، فَوَاللَّهِ إِنَّهُ عَلَى الْحَقِّ‏.‏ قُلْتُ أَلَيْسَ كَانَ يُحَدِّثُنَا أَنَّا سَنَأْتِي الْبَيْتَ وَنَطُوفُ بِهِ قَالَ بَلَى، أَفَأَخْبَرَكَ أَنَّكَ تَأْتِيهِ الْعَامَ قُلْتُ لاَ‏.‏ قَالَ فَإِنَّكَ آتِيهِ وَمُطَّوِّفٌ بِهِ‏.‏ قَالَ الزُّهْرِيِّ قَالَ عُمَرُ فَعَمِلْتُ لِذَلِكَ أَعْمَالاً‏.‏ قَالَ فَلَمَّا فَرَغَ مِنْ قَضِيَّةِ الْكِتَابِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَصْحَابِهِ ‏"‏ قُومُوا فَانْحَرُوا، ثُمَّ احْلِقُوا ‏"‏‏.‏ قَالَ فَوَاللَّهِ مَا قَامَ مِنْهُمْ رَجُلٌ حَتَّى قَالَ ذَلِكَ ثَلاَثَ مَرَّاتٍ، فَلَمَّا لَمْ يَقُمْ مِنْهُمْ أَحَدٌ دَخَلَ عَلَى أُمِّ سَلَمَةَ، فَذَكَرَ لَهَا مَا لَقِيَ مِنَ النَّاسِ‏.‏ فَقَالَتْ أُمُّ سَلَمَةَ يَا نَبِيَّ اللَّهِ، أَتُحِبُّ ذَلِكَ اخْرُجْ ثُمَّ لاَ تُكَلِّمْ أَحَدًا مِنْهُمْ كَلِمَةً حَتَّى تَنْحَرَ بُدْنَكَ، وَتَدْعُوَ حَالِقَكَ فَيَحْلِقَكَ‏.‏ فَخَرَجَ فَلَمْ يُكَلِّمْ أَحَدًا مِنْهُمْ، حَتَّى فَعَلَ ذَلِكَ نَحَرَ بُدْنَهُ، وَدَعَا حَالِقَهُ فَحَلَقَهُ‏.‏ فَلَمَّا رَأَوْا ذَلِكَ، قَامُوا فَنَحَرُوا، وَجَعَلَ بَعْضُهُمْ يَحْلِقُ بَعْضًا، حَتَّى كَادَ بَعْضُهُمْ يَقْتُلُ بَعْضًا غَمًّا، ثُمَّ جَاءَهُ نِسْوَةٌ مُؤْمِنَاتٌ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا إِذَا جَاءَكُمُ الْمُؤْمِنَاتُ مُهَاجِرَاتٍ فَامْتَحِنُوهُنَّ‏\}‏ حَتَّى بَلَغَ ‏\{‏بِعِصَمِ الْكَوَافِرِ‏\}‏ فَطَلَّقَ عُمَرُ يَوْمَئِذٍ امْرَأَتَيْنِ كَانَتَا لَهُ فِي الشِّرْكِ، فَتَزَوَّجَ إِحْدَاهُمَا مُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ، وَالأُخْرَى صَفْوَانُ بْنُ أُمَيَّةَ، ثُمَّ رَجَعَ النَّبِيُّ صلى الله عليه وسلم إِلَى الْمَدِينَةِ، فَجَاءَهُ أَبُو بَصِيرٍ ـ رَجُلٌ مِنْ قُرَيْشٍ ـ وَهْوَ مُسْلِمٌ فَأَرْسَلُوا فِي طَلَبِهِ رَجُلَيْنِ، فَقَالُوا الْعَهْدَ الَّذِي جَعَلْتَ لَنَا‏.‏ فَدَفَعَهُ إِلَى الرَّجُلَيْنِ، فَخَرَجَا بِهِ حَتَّى بَلَغَا ذَا الْحُلَيْفَةِ، فَنَزَلُوا يَأْكُلُونَ مِنْ تَمْرٍ لَهُمْ، فَقَالَ أَبُو بَصِيرٍ لأَحَدِ الرَّجُلَيْنِ وَاللَّهِ إِنِّي لأَرَى سَيْفَكَ هَذَا يَا فُلاَنُ جَيِّدًا‏.‏ فَاسْتَلَّهُ الآخَرُ فَقَالَ أَجَلْ، وَاللَّهِ إِنَّهُ لَجَيِّدٌ، لَقَدْ جَرَّبْتُ بِهِ ثُمَّ جَرَّبْتُ‏.‏ فَقَالَ أَبُو بَصِيرٍ أَرِنِي أَنْظُرْ إِلَيْهِ، فَأَمْكَنَهُ مِنْهُ، فَضَرَبَهُ حَتَّى بَرَدَ، وَفَرَّ الآخَرُ، حَتَّى أَتَى الْمَدِينَةَ، فَدَخَلَ الْمَسْجِدَ يَعْدُو‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ رَآهُ ‏"‏ لَقَدْ رَأَى هَذَا ذُعْرًا ‏"‏‏.‏ فَلَمَّا انْتَهَى إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ قُتِلَ وَاللَّهِ صَاحِبِي وَإِنِّي لَمَقْتُولٌ، فَجَاءَ أَبُو بَصِيرٍ فَقَالَ يَا نَبِيَّ اللَّهِ، قَدْ وَاللَّهِ أَوْفَى اللَّهُ ذِمَّتَكَ، قَدْ رَدَدْتَنِي إِلَيْهِمْ ثُمَّ أَنْجَانِي اللَّهُ مِنْهُمْ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ وَيْلُ أُمِّهِ مِسْعَرَ حَرْبٍ، لَوْ كَانَ لَهُ أَحَدٌ ‏"‏‏.‏ فَلَمَّا سَمِعَ ذَلِكَ عَرَفَ أَنَّهُ سَيَرُدُّهُ إِلَيْهِمْ، فَخَرَجَ حَتَّى أَتَى سِيفَ الْبَحْرِ‏.‏ قَالَ وَيَنْفَلِتُ مِنْهُمْ أَبُو جَنْدَلِ بْنُ سُهَيْلٍ، فَلَحِقَ بِأَبِي بَصِيرٍ، فَجَعَلَ لاَ يَخْرُجُ مِنْ قُرَيْشٍ رَجُلٌ قَدْ أَسْلَمَ إِلاَّ لَحِقَ بِأَبِي بَصِيرٍ، حَتَّى اجْتَمَعَتْ مِنْهُمْ عِصَابَةٌ، فَوَاللَّهِ مَا يَسْمَعُونَ بِعِيرٍ خَرَجَتْ لِقُرَيْشٍ إِلَى الشَّأْمِ إِلاَّ اعْتَرَضُوا لَهَا، فَقَتَلُوهُمْ، وَأَخَذُوا أَمْوَالَهُمْ، فَأَرْسَلَتْ قُرَيْشٌ إِلَى النَّبِيِّ صلى الله عليه وسلم تُنَاشِدُهُ بِاللَّهِ وَالرَّحِمِ لَمَّا أَرْسَلَ، فَمَنْ أَتَاهُ فَهْوَ آمِنٌ، فَأَرْسَلَ النَّبِيُّ صلى الله عليه وسلم إِلَيْهِمْ، فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏وَهُوَ الَّذِي كَفَّ أَيْدِيَهُمْ عَنْكُمْ وَأَيْدِيَكُمْ عَنْهُمْ بِبَطْنِ مَكَّةَ مِنْ بَعْدِ أَنْ أَظْفَرَكُمْ عَلَيْهِمْ‏\}‏ حَتَّى بَلَغَ ‏\{‏الْحَمِيَّةَ حَمِيَّةَ الْجَاهِلِيَّةِ‏\}‏ وَكَانَتْ حَمِيَّتُهُمْ أَنَّهُمْ لَمْ يُقِرُّوا أَنَّهُ نَبِيُّ اللَّهِ، وَلَمْ يُقِرُّوا بِبِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ، وَحَالُوا بَيْنَهُمْ وَبَيْنَ الْبَيْتِ‏.‏\hadithno{2732}\hadithtrans{Narrated Al-Miswar bin Makhrama and Marwan:(whose narrations attest each other) Allah's Messenger (ﷺ) set out at the time of Al-Hudaibiya (treaty), and when they proceeded for a distance, he said, "Khalid bin Al-Walid leading the cavalry of Quraish constituting the front of the army, is at a place called Al-Ghamim, so take the way on the right." By Allah, Khalid did not perceive the arrival of the Muslims till the dust arising from the march of the Muslim army reached him, and then he turned back hurriedly to inform Quraish. The Prophet (ﷺ) went on advancing till he reached the Thaniya (i.e. a mountainous way) through which one would go to them (i.e. people of Quraish). The she-camel of the Prophet (ﷺ) sat down. The people tried their best to cause the she-camel to get up but in vain, so they said, "Al-Qaswa' (i.e. the she-camel's name) has become stubborn! Al-Qaswa' has become stubborn!" The Prophet (ﷺ) said, "Al-Qaswa' has not become stubborn, for stubbornness is not her habit, but she was stopped by Him Who stopped the elephant." Then he said, "By the Name of Him in Whose Hands my soul is, if they (i.e. the Quraish infidels) ask me anything which will respect the ordinances of Allah, I will grant it to them." The Prophet (ﷺ) then rebuked the she-camel and she got up. The Prophet (ﷺ) changed his way till he dismounted at the farthest end of Al-Hudaibiya at a pit (i.e. well) containing a little water which the people used in small amounts, and in a short while the people used up all its water and complained to Allah's Messenger (ﷺ); of thirst. The Prophet (ﷺ) took an arrow out of his arrow-case and ordered them to put the arrow in that pit. By Allah, the water started and continued sprouting out till all the people quenched their thirst and returned with satisfaction. While they were still in that state, Budail bin Warqa-al-Khuza`i came with some persons from his tribe Khuza`a and they were the advisers of Allah's Messenger (ﷺ) who would keep no secret from him and were from the people of Tihama. Budail said, "I left Ka`b bin Luai and 'Amir bin Luai residing at the profuse water of Al-Hudaibiya and they had milch camels (or their women and children) with them, and will wage war against you, and will prevent you from visiting the Ka`ba." Allah's Messenger (ﷺ) said, "We have not come to fight anyone, but to perform the `Umra. No doubt, the war has weakened Quraish and they have suffered great losses, so if they wish, I will conclude a truce with them, during which they should refrain from interfering between me and the people (i.e. the 'Arab infidels other than Quraish), and if I have victory over those infidels, Quraish will have the option to embrace Islam as the other people do, if they wish; they will at least get strong enough to fight. But if they do not accept the truce, by Allah in Whose Hands my life is, I will fight with them defending my Cause till I get killed, but (I am sure) Allah will definitely make His Cause victorious." Budail said, "I will inform them of what you have said." So, he set off till he reached Quraish and said, "We have come from that man (i.e. Muhammad) whom we heard saying something which we will disclose to you if you should like." Some of the fools among Quraish shouted that they were not in need of this information, but the wiser among them said, "Relate what you heard him saying." Budail said, "I heard him saying so-and-so," relating what the Prophet (ﷺ) had told him. `Urwa bin Mas`ud got up and said, "O people! Aren't you the sons? They said, "Yes." He added, "Am I not the father?" They said, "Yes." He said, "Do you mistrust me?" They said, "No." He said, "Don't you know that I invited the people of `Ukaz for your help, and when they refused I brought my relatives and children and those who obeyed me (to help you)?" They said, "Yes." He said, "Well, this man (i.e. the Prophet) has offered you a reasonable proposal, you'd better accept it and allow me to meet him." They said, "You may meet him." So, he went to the Prophet (ﷺ) and started talking to him. The Prophet (ﷺ) told him almost the same as he had told Budail. Then `Urwa said, "O Muhammad! Won't you feel any scruple in extirpating your relations? Have you ever heard of anyone amongst the Arabs extirpating his relatives before you? On the other hand, if the reverse should happen, (nobody will aid you, for) by Allah, I do not see (with you) dignified people, but people from various tribes who would run away leaving you alone." Hearing that, Abu Bakr abused him and said, "Do you say we would run and leave the Prophet (ﷺ) alone?" `Urwa said, "Who is that man?" They said, "He is Abu Bakr." `Urwa said to Abu Bakr, "By Him in Whose Hands my life is, were it not for the favor which you did to me and which I did not compensate, I would retort on you." `Urwa kept on talking to the Prophet (ﷺ) and seizing the Prophet's beard as he was talking while Al-Mughira bin Shu`ba was standing near the head of the Prophet, holding a sword and wearing a helmet. Whenever `Urwa stretched his hand towards the beard of the Prophet, Al-Mughira would hit his hand with the handle of the sword and say (to `Urwa), "Remove your hand from the beard of Allah's Messenger (ﷺ)." `Urwa raised his head and asked, "Who is that?" The people said, "He is Al-Mughira bin Shu`ba." `Urwa said, "O treacherous! Am I not doing my best to prevent evil consequences of your treachery?" Before embracing Islam Al-Mughira was in the company of some people. He killed them and took their property and came (to Medina) to embrace Islam. The Prophet (ﷺ) said (to him, "As regards your Islam, I accept it, but as for the property I do not take anything of it. (As it was taken through treason). `Urwa then started looking at the Companions of the Prophet. By Allah, whenever Allah's Messenger (ﷺ) spat, the spittle would fall in the hand of one of them (i.e. the Prophet's companions) who would rub it on his face and skin; if he ordered them they would carry his orders immediately; if he performed ablution, they would struggle to take the remaining water; and when they spoke to him, they would lower their voices and would not look at his face constantly out of respect. `Urwa returned to his people and said, "O people! By Allah, I have been to the kings and to Caesar, Khosrau and An- Najashi, yet I have never seen any of them respected by his courtiers as much as Muhammad is respected by his companions. By Allah, if he spat, the spittle would fall in the hand of one of them (i.e. the Prophet's companions) who would rub it on his face and skin; if he ordered them, they would carry out his order immediately; if he performed ablution, they would struggle to take the remaining water; and when they spoke, they would lower their voices and would not look at his face constantly out of respect." `Urwa added, "No doubt, he has presented to you a good reasonable offer, so please accept it." A man from the tribe of Bani Kinana said, "Allow me to go to him," and they allowed him, and when he approached the Prophet and his companions, Allah's Messenger (ﷺ) said, "He is so-and-so who belongs to the tribe that respects the Budn (i.e. camels of the sacrifice). So, bring the Budn in front of him." So, the Budn were brought before him and the people received him while they were reciting Talbiya. When he saw that scene, he said, "Glorified be Allah! It is not fair to prevent these people from visiting the Ka`ba." When he returned to his people, he said, 'I saw the Budn garlanded (with colored knotted ropes) and marked (with stabs on their backs). I do not think it is advisable to prevent them from visiting the Ka`ba." Another person called Mikraz bin Hafs got up and sought their permission to go to Muhammad, and they allowed him, too. When he approached the Muslims, the Prophet (ﷺ) said, "Here is Mikraz and he is a vicious man." Mikraz started talking to the Prophet and as he was talking, Suhail bin `Amr came. When Suhail bin `Amr came, the Prophet (ﷺ) said, "Now the matter has become easy." Suhail said to the Prophet "Please conclude a peace treaty with us." So, the Prophet (ﷺ) called the clerk and said to him, "Write: By the Name of Allah, the most Beneficent, the most Merciful." Suhail said, "As for 'Beneficent,' by Allah, I do not know what it means. So write: By Your Name O Allah, as you used to write previously." The Muslims said, "By Allah, we will not write except: By the Name of Allah, the most Beneficent, the most Merciful." The Prophet (ﷺ) said, "Write: By Your Name O Allah." Then he dictated, "This is the peace treaty which Muhammad, Allah's Messenger (ﷺ) has concluded." Suhail said, "By Allah, if we knew that you are Allah's Messenger (ﷺ) we would not prevent you from visiting the Ka`ba, and would not fight with you. So, write: "Muhammad bin `Abdullah." The Prophet (ﷺ) said, "By Allah! I am the Apostle of Allah even if you people do not believe me. Write: Muhammad bin `Abdullah." (Az-Zuhri said, "The Prophet (ﷺ) accepted all those things, as he had already said that he would accept everything they would demand if it respects the ordinance of Allah, (i.e. by letting him and his companions perform `Umra.)") The Prophet (ﷺ) said to Suhail, "On the condition that you allow us to visit the House (i.e. Ka`ba) so that we may perform Tawaf around it." Suhail said, "By Allah, we will not (allow you this year) so as not to give chance to the 'Arabs to say that we have yielded to you, but we will allow you next year." So, the Prophet (ﷺ) got that written. Then Suhail said, "We also stipulate that you should return to us whoever comes to you from us, even if he embraced your religion." The Muslims said, "Glorified be Allah! How will such a person be returned to the pagans after he has become a Muslim? While they were in this state Abu Jandal bin Suhail bin `Amr came from the valley of Mecca staggering with his fetters and fell down amongst the Muslims. Suhail said, "O Muhammad! This is the very first term with which we make peace with you, i.e. you shall return Abu Jandal to me." The Prophet (ﷺ) said, "The peace treaty has not been written yet." Suhail said, "I will never allow you to keep him." The Prophet (ﷺ) said, "Yes, do." He said, "I won't do.: Mikraz said, "We allow you (to keep him)." Abu Jandal said, "O Muslims! Will I be returned to the pagans though I have come as a Muslim? Don't you see how much I have suffered?" Abu Jandal had been tortured severely for the Cause of Allah. `Umar bin Al-Khattab said, "I went to the Prophet (ﷺ) and said, 'Aren't you truly the Messenger of Allah?' The Prophet (ﷺ) said, 'Yes, indeed.' I said, 'Isn't our Cause just and the cause of the enemy unjust?' He said, 'Yes.' I said, 'Then why should we be humble in our religion?' He said, 'I am Allah's Messenger (ﷺ) and I do not disobey Him, and He will make me victorious.' I said, 'Didn't you tell us that we would go to the Ka`ba and perform Tawaf around it?' He said, 'Yes, but did I tell you that we would visit the Ka`ba this year?' I said, 'No.' He said, 'So you will visit it and perform Tawaf around it.' " `Umar further said, "I went to Abu Bakr and said, 'O Abu Bakr! Isn't he truly Allah's Prophet?' He replied, 'Yes.' I said, 'Then why should we be humble in our religion?' He said, 'Indeed, he is Allah's Messenger (ﷺ) and he does not disobey his Lord, and He will make him victorious. Adhere to him as, by Allah, he is on the right.' I said, 'Was he not telling us that we would go to the Ka`ba and perform Tawaf around it?' He said, 'Yes, but did he tell you that you would go to the Ka`ba this year?' I said, 'No.' He said, "You will go to Ka`ba and perform Tawaf around it." (Az-Zuhri said, " `Umar said, 'I performed many good deeds as expiation for the improper questions I asked them.' ") When the writing of the peace treaty was concluded, Allah's Messenger (ﷺ) said to his companions, "Get up and' slaughter your sacrifices and get your head shaved." By Allah none of them got up, and the Prophet repeated his order thrice. When none of them got up, he left them and went to Um Salama and told her of the people's attitudes towards him. Um Salama said, "O the Prophet of Allah (ﷺ)! Do you want your order to be carried out? Go out and don't say a word to anybody till you have slaughtered your sacrifice and call your barber to shave your head." So, the Prophet (ﷺ) went out and did not talk to anyone of them till he did that, i.e. slaughtered the sacrifice and called his barber who shaved his head. Seeing that, the companions of the Prophet (ﷺ) got up, slaughtered their sacrifices, and started shaving the heads of one another, and there was so much rush that there was a danger of killing each other. Then some believing women came (to the Prophet (ﷺ) ); and Allah revealed the following Divine Verses:-- "O you who believe, when the believing women come to you as emigrants examine them . . ." (60.10) `Umar then divorced two wives of his who were infidels. Later on Muawiya bin Abu Sufyan married one of them, and Safwan bin Umaiya married the other. When the Prophet (ﷺ) returned to Medina, Abu Basir, a new Muslim convert from Quraish came to him. The Infidels sent in his pursuit two men who said (to the Prophet (ﷺ) ), "Abide by the promise you gave us." So, the Prophet (ﷺ) handed him over to them. They took him out (of the City) till they reached Dhul-Hulaifa where they dismounted to eat some dates they had with them. Abu Basir said to one of them, "By Allah, O so-and-so, I see you have a fine sword." The other drew it out (of the scabbard) and said, "By Allah, it is very fine and I have tried it many times." Abu Basir said, "Let me have a look at it." When the other gave it to him, he hit him with it till he died, and his companion ran away till he came to Medina and entered the Mosque running. When Allah's Messenger (ﷺ) saw him he said, "This man appears to have been frightened." When he reached the Prophet (ﷺ) he said, "My companion has been murdered and I would have been murdered too." Abu Basir came and said, "O Allah's Messenger (ﷺ), by Allah, Allah has made you fulfill your obligations by your returning me to them (i.e. the Infidels), but Allah has saved me from them." The Prophet (ﷺ) said, "Woe to his mother! what excellent war kindler he would be, should he only have supporters." When Abu Basir heard that he understood that the Prophet (ﷺ) would return him to them again, so he set off till he reached the seashore. Abu Jandal bin Suhail got himself released from them (i.e. infidels) and joined Abu Basir. So, whenever a man from Quraish embraced Islam he would follow Abu Basir till they formed a strong group. By Allah, whenever they heard about a caravan of Quraish heading towards Sham, they stopped it and attacked and killed them (i.e. infidels) and took their properties. The people of Quraish sent a message to the Prophet (ﷺ) requesting him for the Sake of Allah and Kith and kin to send for (i.e. Abu Basir and his companions) promising that whoever (amongst them) came to the Prophet (ﷺ) would be secure. So the Prophet (ﷺ) sent for them (i.e. Abu Basir's companions) and Allah revealed the following Divine Verses: "And it is He Who Has withheld their hands from you and your hands From them in the midst of Mecca, After He made you the victorious over them. ... the unbelievers had pride and haughtiness, in their hearts ... the pride and haughtiness of the time of ignorance." (48.24-26) And their pride and haughtiness was that they did not confess (write in the treaty) that he (i.e. Muhammad) was the Prophet of Allah and refused to write: "In the Name of Allah, the most Beneficent, the Most Merciful," and they (the mushriks) prevented them (the Muslims) from visiting the House (the Ka`bah)}}
\hadithdefcmd{bukhari}{2733}{وَقَالَ عُقَيْلٌ عَنِ الزُّهْرِيِّ، قَالَ عُرْوَةُ فَأَخْبَرَتْنِي عَائِشَةُ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَمْتَحِنُهُنَّ، وَبَلَغَنَا أَنَّهُ لَمَّا أَنْزَلَ اللَّهُ تَعَالَى أَنْ يَرُدُّوا إِلَى الْمُشْرِكِينَ مَا أَنْفَقُوا عَلَى مَنْ هَاجَرَ مِنْ أَزْوَاجِهِمْ، وَحَكَمَ عَلَى الْمُسْلِمِينَ، أَنْ لاَ يُمَسِّكُوا بِعِصَمِ الْكَوَافِرِ، أَنَّ عُمَرَ طَلَّقَ امْرَأَتَيْنِ قَرِيبَةَ بِنْتَ أَبِي أُمَيَّةَ، وَابْنَةَ جَرْوَلٍ الْخُزَاعِيِّ، فَتَزَوَّجَ قَرِيبَةَ مُعَاوِيَةُ، وَتَزَوَّجَ الأُخْرَى أَبُو جَهْمٍ، فَلَمَّا أَبَى الْكُفَّارُ أَنْ يُقِرُّوا بِأَدَاءِ مَا أَنْفَقَ الْمُسْلِمُونَ عَلَى أَزْوَاجِهِمْ، أَنْزَلَ اللَّهُ تَعَالَى ‏\{‏وَإِنْ فَاتَكُمْ شَىْءٌ مِنْ أَزْوَاجِكُمْ إِلَى الْكُفَّارِ فَعَاقَبْتُمْ‏\}‏ وَالْعَقِبُ مَا يُؤَدِّي الْمُسْلِمُونَ إِلَى مَنْ هَاجَرَتِ امْرَأَتُهُ مِنَ الْكُفَّارِ، فَأَمَرَ أَنْ يُعْطَى مَنْ ذَهَبَ لَهُ زَوْجٌ مِنَ الْمُسْلِمِينَ مَا أَنْفَقَ مِنْ صَدَاقِ نِسَاءِ الْكُفَّارِ اللاَّئِي هَاجَرْنَ، وَمَا نَعْلَمُ أَحَدًا مِنَ الْمُهَاجِرَاتِ ارْتَدَّتْ بَعْدَ إِيمَانِهَا‏.‏ وَبَلَغَنَا أَنَّ أَبَا بَصِيرِ بْنَ أَسِيدٍ الثَّقَفِيَّ قَدِمَ عَلَى النَّبِيِّ صلى الله عليه وسلم مُؤْمِنًا مُهَاجِرًا فِي الْمُدَّةِ، فَكَتَبَ الأَخْنَسُ بْنُ شَرِيقٍ إِلَى النَّبِيِّ صلى الله عليه وسلم يَسْأَلُهُ أَبَا بَصِيرٍ، فَذَكَرَ الْحَدِيثَ‏.‏\hadithno{2733}\hadithtrans{Narrated Az-Zuhri:`Urwa said, "Aisha told me that Allah's Messenger (ﷺ) used to examine the women emigrants. We have been told also that when Allah revealed the order that the Muslims should return to the pagans what they had spent on their wives who emigrated (after embracing Islam) and that the Muslims should not keep unbelieving women as their wives, `Umar divorced two of his wives, Qariba, the daughter of Abu Umayyah and the daughter of Jarwal Al-Khuza`i. Later on Mu`awiya married Qariba and Abu Jahm married the other." When the pagans refused to pay what the Muslims had spent on their wives, Allah revealed: "And if any of your wives have gone from you to the unbelievers and you have an accession (by the coming over of a woman from the other side) (then pay to those whose wives have gone) the equivalent of what they had spent (on their Mahr)." (60.11) So, Allah ordered that the Muslim whose wife has gone, should be given, as a compensation of the Mahr he had given to his wife, from the Mahr of the wives of the pagans who had emigrated deserting their husbands. We do not know any of the women emigrants who deserted Islam after embracing it. We have also been told that Abu Basir bin Asid Ath-Thaqafi came to the Prophet (ﷺ) as a Muslim emigrant during the truce. Al-Akhnas bin Shariq wrote to the Prophet (ﷺ) requesting him to return Abu Basir}}
\hadithdefcmd{bukhari}{2734}{وَقَالَ اللَّيْثُ حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ ذَكَرَ رَجُلاً سَأَلَ بَعْضَ بَنِي إِسْرَائِيلَ أَنْ يُسْلِفَهُ أَلْفَ دِينَارِ، فَدَفَعَهَا إِلَيْهِ إِلَى أَجَلٍ مُسَمًّى‏.‏ وَقَالَ ابْنُ عُمَرَ ـ رضى الله عنهما ـ وَعَطَاءٌ إِذَا أَجَّلَهُ فِي الْقَرْضِ جَازَ‏.‏\hadithno{2734}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) mentioned a person who asked an Israeli man to lend him one-thousand Dinars, and the Israeli lent him the sum for a certain fixed period}}
\hadithdefcmd{bukhari}{2735}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ يَحْيَى، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ أَتَتْهَا بَرِيرَةُ تَسْأَلُهَا فِي كِتَابَتِهَا، فَقَالَتْ إِنْ شِئْتِ أَعْطَيْتُ أَهْلَكِ وَيَكُونُ الْوَلاَءُ لِي‏.‏ فَلَمَّا جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَكَّرْتُهُ ذَلِكَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ابْتَاعِيهَا فَأَعْتِقِيهَا، فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ فَقَالَ ‏"‏ مَا بَالُ أَقْوَامٍ يَشْتَرِطُونَ شُرُوطًا لَيْسَتْ فِي كِتَابِ اللَّهِ مَنِ اشْتَرَطَ شَرْطًا لَيْسَ فِي كِتَابِ اللَّهِ فَلَيْسَ لَهُ، وَإِنِ اشْتَرَطَ مِائَةَ شَرْطٍ ‏"‏‏.‏\hadithno{2735}\hadithtrans{Narrated `Amra:Aisha said that Barirah came to seek her help in the writing of her emancipation. `Aisha said to her, "If you wish, I will pay your masters (your price) and the wala' will be for me." When Allah's Messenger (ﷺ) came, she told him about it. The Prophet (ﷺ) said to her, "Buy her (i.e. Barirah) and manumit (free) her, for the Wala is for the one who manumits." Then Allah's Messenger (ﷺ) ascended the pulpit and said, "What about those people who stipulate conditions which are not in Allah's Laws? Whoever stipulates such conditions as are not in Allah's Laws, then those conditions are invalid even if he stipulated a hundred such conditions}}
\hadithdefcmd{bukhari}{2736}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ لِلَّهِ تِسْعَةً وَتِسْعِينَ اسْمَا مِائَةً إِلاَّ وَاحِدًا مَنْ أَحْصَاهَا دَخَلَ الْجَنَّةَ ‏"‏‏.‏\hadithno{2736}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah has ninety-nine names, i.e. one-hundred minus one, and whoever knows them will go to Paradise." (Please see Hadith No. 419 Vol)}}
\hadithdefcmd{bukhari}{2737}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، حَدَّثَنَا ابْنُ عَوْنٍ، قَالَ أَنْبَأَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، أَصَابَ أَرْضًا بِخَيْبَرَ، فَأَتَى النَّبِيَّ صلى الله عليه وسلم يَسْتَأْمِرُهُ فِيهَا، فَقَالَ يَا رَسُولَ اللَّهِ، إِنِّي أَصَبْتُ أَرْضًا بِخَيْبَرَ، لَمْ أُصِبْ مَالاً قَطُّ أَنْفَسَ عِنْدِي مِنْهُ، فَمَا تَأْمُرُ بِهِ قَالَ ‏ "‏ إِنْ شِئْتَ حَبَسْتَ أَصْلَهَا، وَتَصَدَّقْتَ بِهَا ‏"‏‏.‏ قَالَ فَتَصَدَّقَ بِهَا عُمَرُ أَنَّهُ لاَ يُبَاعُ وَلاَ يُوهَبُ وَلاَ يُورَثُ، وَتَصَدَّقَ بِهَا فِي الْفُقَرَاءِ وَفِي الْقُرْبَى، وَفِي الرِّقَابِ، وَفِي سَبِيلِ اللَّهِ، وَابْنِ السَّبِيلِ، وَالضَّيْفِ، لاَ جُنَاحَ عَلَى مَنْ وَلِيَهَا أَنْ يَأْكُلَ مِنْهَا بِالْمَعْرُوفِ، وَيُطْعِمَ غَيْرَ مُتَمَوِّلٍ‏.‏ قَالَ فَحَدَّثْتُ بِهِ ابْنَ سِيرِينَ فَقَالَ غَيْرَ مُتَأَثِّلٍ مَالاً‏.‏\hadithno{2737}\hadithtrans{Narrated Ibn `Umar:Umar bin Al-Khattab got some land in Khaibar and he went to the Prophet (ﷺ) to consult him about it saying, "O Allah's Messenger (ﷺ) I got some land in Khaibar better than which I have never had, what do you suggest that I do with it?" The Prophet (ﷺ) said, "If you like you can give the land as endowment and give its fruits in charity." So `Umar gave it in charity as an endowment on the condition that it would not be sold nor given to anybody as a present and not to be inherited, but its yield would be given in charity to the poor people, to the Kith and kin, for freeing slaves, for Allah's Cause, to the travelers and guests; and that there would be no harm if the guardian of the endowment ate from it according to his need with good intention, and fed others without storing it for the future}}
