% Auto-generated chapter 30 for tirmidhi
% Hadiths in this chapter: 9

\hadithdefcmd{tirmidhi}{2116}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، قَالَ مَرِضْتُ عَامَ الْفَتْحِ مَرَضًا أَشْفَيْتُ مِنْهُ عَلَى الْمَوْتِ فَأَتَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُنِي فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ لِي مَالاً كَثِيرًا وَلَيْسَ يَرِثُنِي إِلاَّ ابْنَتِي أَفَأُوصِي بِمَالِي كُلِّهِ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قُلْتُ فَثُلُثَىْ مَالِي قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قُلْتُ فَالشَّطْرُ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قُلْتُ فَالثُّلُثُ قَالَ ‏"‏ الثُّلُثُ وَالثُّلُثُ كَثِيرٌ إِنَّكَ إِنْ تَدَعْ وَرَثَتَكَ أَغْنِيَاءَ خَيْرٌ مِنْ أَنْ تَدَعَهُمْ عَالَةً يَتَكَفَّفُونَ النَّاسَ وَإِنَّكَ لَنْ تُنْفِقَ نَفَقَةً إِلاَّ أُجِرْتَ فِيهَا حَتَّى اللُّقْمَةَ تَرْفَعُهَا إِلَى فِي امْرَأَتِكَ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أُخَلَّفُ عَنْ هِجْرَتِي قَالَ ‏"‏ إِنَّكَ لَنْ تُخَلَّفَ بَعْدِي فَتَعْمَلَ عَمَلاً تُرِيدُ بِهِ وَجْهَ اللَّهِ إِلاَّ ازْدَدْتَ بِهِ رِفْعَةً وَدَرَجَةً وَلَعَلَّكَ أَنْ تُخَلَّفَ حَتَّى يَنْتَفِعَ بِكَ أَقْوَامٌ وَيُضَرَّ بِكَ آخَرُونَ اللَّهُمَّ أَمْضِ لأَصْحَابِي هِجْرَتَهُمْ وَلاَ تَرُدَّهُمْ عَلَى أَعْقَابِهِمْ لَكِنِ الْبَائِسُ سَعْدُ ابْنُ خَوْلَةَ يَرْثِي لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ مَاتَ بِمَكَّةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّهُ لَيْسَ لِلرَّجُلِ أَنْ يُوصِيَ بِأَكْثَرَ مِنَ الثُّلُثِ وَقَدِ اسْتَحَبَّ بَعْضُ أَهْلِ الْعِلْمِ أَنْ يَنْقُصَ مِنَ الثُّلُثِ لِقَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالثُّلُثُ كَثِيرٌ ‏"‏ ‏.‏\hadithno{2116}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Amir bin Sa'd bin Abi Waqqas narrated from his father, who said:"I was ill during the year of the Conquest (of Makkah) with an illness bringing me to the brink of death. So The Messenger of Allah (S.A.W) came to visit me, and I said: 'O Messenger of Allah (S.A.W)! Indeed I have a great deal of wealth and I do not have any heirs except my daughter, so should I will all of my wealth?' He said: 'No.' I said: 'Then two-thirds of my wealth?' He said: 'No.' I said: 'Then half?' He said: 'No.' I said: 'Then a third' He said: 'No.' A third and a third is too much. If you leave your heirs without need it is better than to leave them in poverty begging from the people. Indeed you do not do any spending (on your family) except that you are rewarded for it, even the morsel of food you raise to your wife's mouth.'" He said: "I said: 'Will I be left behind from my emigration?' He said: 'You will not be left behind after me,and do righteous deeds intending Allah's Face, except that it will add to your elevation in rank. Perhaps you will remain until some people benefit from you and others will be harmed by you. O Allah! Complete the emigration of my companions and do not turn them on their heels. But the case of Sa'd bin Khawlah is sad.'" the Messenger of Allah (S.A.W) felt sorry for him dying in Makkah}}
\hadithdefcmd{tirmidhi}{2117}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، وَهُوَ جَدُّ هَذَا النَّصْرِ حَدَّثَنَا الأَشْعَثُ بْنُ جَابِرٍ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ حَدَّثَهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الرَّجُلَ لَيَعْمَلُ وَالْمَرْأَةُ بِطَاعَةِ اللَّهِ سِتِّينَ سَنَةً ثُمَّ يَحْضُرُهُمَا الْمَوْتُ فَيُضَارَّانِ فِي الْوَصِيَّةِ فَتَجِبُ لَهُمَا النَّارُ ‏"‏ ‏.‏ ثُمَّ قَرَأَ عَلَىَّ أَبُو هُرَيْرَةَْ ‏:‏ ‏(‏مِنْ بَعْدِ وَصِيَّةٍ يُوصَى بِهَا أَوْ دَيْنٍ غَيْرَ مُضَارٍّ وَصِيَّةً مِنَ اللَّهِ ‏)‏ إِلَى قَوْلِهِ ‏:‏ ‏(‏ ذَلِكَ الْفَوْزُ الْعَظِيمُ ‏)‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَنَصْرُ بْنُ عَلِيٍّ الَّذِي رَوَى عَنِ الأَشْعَثِ بْنِ جَابِرٍ هُوَ جَدُّ نَصْرِ بْنِ عَلِيٍّ الْجَهْضَمِيِّ ‏.‏\hadithno{2117}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (S.A.W) said:"Indeed a man, and a woman, perform deeds in obedience to Allah for sixty years, then death presents itself to them, and they cause such harm in the will that the Fire becomes warranted for them."Then he recited: After payment of legacies he (or she) may have bequeathed or debts, without causing harm. This is a Commandment from Allah. up to His saying: That is the magnificent success}}
\hadithdefcmd{tirmidhi}{2118}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَا حَقُّ امْرِئٍ مُسْلِمٍ يَبِيتُ لَيْلَتَيْنِ وَلَهُ مَا يُوصِي فِيهِ إِلاَّ وَوَصِيَّتُهُ مَكْتُوبَةٌ عِنْدَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ الزُّهْرِيِّ عَنْ سَالِمٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوُهُ ‏.‏\hadithno{2118}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Umar narrated that the Messenger of Allah (S.A.W) said:"It is not right for a Muslim man to spend two nights, having what he would will, without having his will written with him}}
\hadithdefcmd{tirmidhi}{2119}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو قَطَنٍ، عَمْرُو بْنُ الْهَيْثَمِ الْبَغْدَادِيُّ حَدَّثَنَا مَالِكُ بْنُ مِغْوَلٍ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، قَالَ قُلْتُ لاِبْنِ أَبِي أَوْفَى أَوْصَى رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ لاَ ‏.‏ قُلْتُ كَيْفَ كُتِبَتِ الْوَصِيَّةُ وَكَيْفَ أَمَرَ النَّاسَ قَالَ أَوْصَى بِكِتَابِ اللَّهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مَالِكِ بْنِ مِغْوَلٍ ‏.‏\hadithno{2119}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Talhah bin Musarrif said:"I said to Ibn Abi Awfi: Did the Messenger of Allah (S.A.W) leave a will?' He said: 'No' I said: 'How is the will written, and how was it enjoined upon the people?' He said: 'It was ordered in the Book of Allah, Most High}}
\hadithdefcmd{tirmidhi}{2120}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، وَهَنَّادٌ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا شُرَحْبِيلُ بْنُ مُسْلِمٍ الْخَوْلاَنِيُّ، عَنْ أَبِي أُمَامَةَ الْبَاهِلِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي خُطْبَتِهِ عَامَ حَجَّةِ الْوَدَاعِ ‏"‏ إِنَّ اللَّهَ قَدْ أَعْطَى كُلَّ ذِي حَقٍّ حَقَّهُ فَلاَ وَصِيَّةَ لِوَارِثٍ الْوَلَدُ لِلْفِرَاشِ وَلِلْعَاهِرِ الْحَجَرُ وَحِسَابُهُمْ عَلَى اللَّهِ وَمَنِ ادَّعَى إِلَى غَيْرِ أَبِيهِ أَوِ انْتَمَى إِلَى غَيْرِ مَوَالِيهِ فَعَلَيْهِ لَعْنَةُ اللَّهِ التَّابِعَةُ إِلَى يَوْمِ الْقِيَامَةِ لاَ تُنْفِقُ امْرَأَةٌ مِنْ بَيْتِ زَوْجِهَا إِلاَّ بِإِذْنِ زَوْجِهَا ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ وَلاَ الطَّعَامَ قَالَ ‏"‏ ذَلِكَ أَفْضَلُ أَمْوَالِنَا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ الْعَارِيَةُ مُؤَدَّاةٌ وَالْمِنْحَةُ مَرْدُودَةٌ وَالدَّيْنُ مَقْضِيٌّ وَالزَّعِيمُ غَارِمٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَمْرِو بْنِ خَارِجَةَ وَأَنَسِ بْنِ مَالِكٍ ‏.‏ وَهُوَ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ عَنْ أَبِي أُمَامَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏ وَرِوَايَةُ إِسْمَاعِيلَ بْنِ عَيَّاشٍ عَنْ أَهْلِ الْعِرَاقِ وَأَهْلِ الْحِجَازِ لَيْسَ بِذَلِكَ فِيمَا تَفَرَّدَ بِهِ لأَنَّهُ رَوَى عَنْهُمْ مَنَاكِيرَ وَرِوَايَتُهُ عَنْ أَهْلِ الشَّامِ أَصَحُّ هَكَذَا قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ ‏.‏ قَالَ سَمِعْتُ أَحْمَدَ بْنَ الْحَسَنِ يَقُولُ قَالَ أَحْمَدُ بْنُ حَنْبَلٍ إِسْمَاعِيلُ بْنُ عَيَّاشٍ أَصْلَحُ حَدِيثًا مِنْ بَقِيَّةَ وَلِبَقِيَّةَ أَحَادِيثُ مَنَاكِيرُ عَنِ الثِّقَاتِ ‏.‏ وَسَمِعْتُ عَبْدَ اللَّهِ بْنَ عَبْدِ الرَّحْمَنِ يَقُولُ سَمِعْتُ زَكَرِيَّا بْنَ عَدِيٍّ يَقُولُ قَالَ أَبُو إِسْحَاقَ الْفَزَارِيُّ خُذُوا عَنْ بَقِيَّةَ مَا حَدَّثَ عَنِ الثِّقَاتِ وَلاَ تَأْخُذُوا عَنْ إِسْمَاعِيلَ بْنِ عَيَّاشٍ مَا حَدَّثَ عَنِ الثِّقَاتِ وَلاَ عَنْ غَيْرِ الثِّقَاتِ ‏.‏\hadithno{2120}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Ummah said:"During the year of the Farewell Pilgrimage, I heard the Messenger of Allah (S.A.W) saying in the Khutbah: 'Indeed Allah, Most Blessed and Most High, has given the right due to everyone deserving a right. So there is no will for an heir, the child is for the bed, and for the fornicator is the stone, and their reckoning is for Allah, Most High. And whoever claims someone other than his father, or an affiliation with other than his Mawali, then upon him is the continued curse of Allah until the Day of Judgment. The wife is not to spend from her husband's house except with her husband's permission.' They said: 'O Messenger of Allah! Not even food?' He said: 'That is the most virtuous of our wealth.' And he said: 'The borrowed is to be returned, the endowment is to be refunded and the debt is to be repaid, and the guarantor is responsible}}
\hadithdefcmd{tirmidhi}{2121}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ، عَنْ عَمْرِو بْنِ خَارِجَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَطَبَ عَلَى نَاقَتِهِ وَأَنَا تَحْتَ جِرَانِهَا وَهِيَ تَقْصَعُ بِجَرَّتِهَا وَإِنَّ لُعَابَهَا يَسِيلُ بَيْنَ كَتِفَىَّ فَسَمِعْتُهُ يَقُولُ ‏ "‏ إِنَّ اللَّهَ أَعْطَى كُلَّ ذِي حَقٍّ حَقَّهُ وَلاَ وَصِيَّةَ لِوَارِثٍ وَالْوَلَدُ لِلْفِرَاشِ وَلِلْعَاهِرِ الْحَجَرُ وَمَنِ ادَّعَى إِلَى غَيْرِ أَبِيهِ أَوِ انْتَمَى إِلَى غَيْرِ مَوَالِيهِ رَغْبَةً عَنْهُمْ فَعَلَيْهِ لَعْنَةُ اللَّهِ لاَ يَقْبَلُ اللَّهُ مِنْهُ صَرْفًا وَلاَ عَدْلاً ‏"‏ ‏.‏ قَالَ وَسَمِعْتُ أَحْمَدَ بْنَ الْحَسَنِ يَقُولُ قَالَ أَحْمَدُ بْنُ حَنْبَلٍ لاَ أُبَالِي بِحَدِيثِ شَهْرِ بْنِ حَوْشَبٍ ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ عَنْ شَهْرِ بْنِ حَوْشَبٍ فَوَثَّقَهُ وَقَالَ إِنَّمَا يَتَكَلَّمُ فِيهِ ابْنُ عَوْنٍ ثُمَّ رَوَى ابْنُ عَوْنٍ عَنْ هِلاَلِ بْنِ أَبِي زَيْنَبَ عَنْ شَهْرِ بْنِ حَوْشَبٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2121}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Amr bin Kharajah narrated:"The Prophet (s.a.w) gave a Khutbah upon his she-camel, while I was under the front of her neck, and she was chewing her curd, with her saliva dripping between my shoulders. I heard him saying: 'Indeed Allah, Most Blessed and Most High, has given the right due to everyone deserving a right. So there is no will for an heir, the child is for the bed, and for the fornicator is the stone}}
\hadithdefcmd{tirmidhi}{2122}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي إِسْحَاقَ الْهَمْدَانِيِّ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى بِالدَّيْنِ قَبْلَ الْوَصِيَّةِ وَأَنْتُمْ تَقْرَءُونَ الْوَصِيَّةَ قَبْلَ الدَّيْنِ ‏.‏ قَالَ أَبُو عِيسَى وَالْعَمَلُ عَلَى هَذَا عِنْدَ عَامَّةِ أَهْلِ الْعِلْمِ أَنَّهُ يُبْدَأُ بِالدَّيْنِ قَبْلَ الْوَصِيَّةِ ‏.‏\hadithno{2122}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Al-Harith narrated from 'Ali:"The Prophet (s.a.w) judged with the debt before the will, and you people recite the will before the debt}}
\hadithdefcmd{tirmidhi}{2123}{حَدَّثَنَا بُنْدَارٌ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي حَبِيبَةَ الطَّائِيِّ، قَالَ أَوْصَى إِلَىَّ أَخِي بِطَائِفَةٍ مِنْ مَالِهِ فَلَقِيتُ أَبَا الدَّرْدَاءِ فَقُلْتُ إِنَّ أَخِي أَوْصَى إِلَىَّ بِطَائِفَةٍ مِنْ مَالِهِ فَأَيْنَ تَرَى لِي وَضْعَهُ فِي الْفُقَرَاءِ أَوِ الْمَسَاكِينِ أَوِ الْمُجَاهِدِينَ فِي سَبِيلِ اللَّهِ فَقَالَ أَمَّا أَنَا فَلَوْ كُنْتُ لَمْ أَعْدِلْ بِالْمُجَاهِدِينَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَثَلُ الَّذِي يُعْتِقُ عِنْدَ الْمَوْتِ كَمَثَلِ الَّذِي يُهْدِي إِذَا شَبِعَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2123}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Habibah At-Ta'i said:"My brother willed a portion of his wealth to me. So I met Abu Ad-Darda and said: 'My brother has willed a portion of his wealth to me, so where do you suggest that I should give it- to the poor, the needy, or the Mujahidin in Allah's Cause?' He said: 'As for me, then I would not consider them equal to the Mujahidin. I heard the Messenger of Allah (S.A.W) saying: "The parable of the one who frees a slave at the time of his death is that of the one who gives a gift when he is satisfied (fulfilled his needs)}}
\hadithdefcmd{tirmidhi}{2124}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ بَرِيرَةَ جَاءَتْ تَسْتَعِينُ عَائِشَةَ فِي كِتَابَتِهَا وَلَمْ تَكُنْ قَضَتْ مِنْ كِتَابَتِهَا شَيْئًا فَقَالَتْ لَهَا عَائِشَةُ ارْجِعِي إِلَى أَهْلِكِ فَإِنْ أَحَبُّوا أَنْ أَقْضِيَ عَنْكِ كِتَابَتَكِ وَيَكُونَ لِي وَلاَؤُكِ فَعَلْتُ ‏.‏ فَذَكَرَتْ ذَلِكَ بَرِيرَةُ لأَهْلِهَا فَأَبَوْا وَقَالُوا إِنْ شَاءَتْ أَنْ تَحْتَسِبَ عَلَيْكِ وَيَكُونَ لَنَا وَلاَؤُكِ فَلْتَفْعَلْ ‏.‏ فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ابْتَاعِي فَأَعْتِقِي فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا بَالُ أَقْوَامٍ يَشْتَرِطُونَ شُرُوطًا لَيْسَتْ فِي كِتَابِ اللَّهِ مَنِ اشْتَرَطَ شَرْطًا لَيْسَ فِي كِتَابِ اللَّهِ فَلَيْسَ لَهُ وَإِنِ اشْتَرَطَ مِائَةَ مَرَّةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عَائِشَةَ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّ الْوَلاَءَ لِمَنْ أَعْتَقَ ‏.‏\hadithno{2124}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Urwah narrated that :'Aishah had informed him that Barrirah came to her ('Aishah) seeking her help for her writ of emancipation, and she had not yet paid anything for her writ of emancipation. So 'Aishah said to her: 'Return to your people, and if they agree to me paying for your writ of emancipation and that your Wala will be for me, then I will do so." So Barrirah mentioned that to her people and they refused. They said: "If she wants the reward for (freeing) you while the Wala is for us, then let her do it." So I mentioned that to the Messenger of Allah (S.A.W) and the Messenger of Allah (S.A.W) said: "Buy her, then free her, for the Wala is only for the one who frees." Then the Messenger of Allah (S.A.W) stood and said: "What is the case of people who make conditions that are not in Allah's Book? Whoever makes a condition that is not in Allah's Book, then it will not be so for him, even if he were to make a condition a hundred times}}
