% Auto-generated chapter 10 for muslim
% Hadiths in this chapter: 29

\hadithdefcmd{muslim}{2089}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، ح. وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ خَسَفَتِ الشَّمْسُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فَأَطَالَ الْقِيَامَ جِدًّا ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ جِدًّا ثُمَّ رَفَعَ رَأْسَهُ فَأَطَالَ الْقِيَامَ جِدًّا وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ جِدًّا وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ سَجَدَ ثُمَّ قَامَ فَأَطَالَ الْقِيَامَ وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ رَفَعَ رَأْسَهُ فَقَامَ فَأَطَالَ الْقِيَامَ وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ فَأَطَالَ الرُّكُوعَ وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ سَجَدَ ثُمَّ انْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ تَجَلَّتِ الشَّمْسُ فَخَطَبَ النَّاسَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ مِنْ آيَاتِ اللَّهِ وَإِنَّهُمَا لاَ يَنْخَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا رَأَيْتُمُوهُمَا فَكَبِّرُوا وَادْعُوا اللَّهَ وَصَلُّوا وَتَصَدَّقُوا يَا أُمَّةَ مُحَمَّدٍ إِنْ مِنْ أَحَدٍ أَغْيَرَ مِنَ اللَّهِ أَنْ يَزْنِيَ عَبْدُهُ أَوْ تَزْنِيَ أَمَتُهُ يَا أُمَّةَ مُحَمَّدٍ وَاللَّهِ لَوْ تَعْلَمُونَ مَا أَعْلَمُ لَبَكَيْتُمْ كَثِيرًا وَلَضَحِكْتُمْ قَلِيلاً أَلاَ هَلْ بَلَّغْتُ "‏ ‏.‏ وَفِي رِوَايَةِ مَالِكٍ ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ ‏"‏ ‏.‏\hadithno{2089}\hadithtrans{A'isha reported that there was a solar eclipse in the time of the Messenger of Allah (ﷺ). He stood up to pray and prolonged his stand very much. He then bowed and prolonged very much his bowing. He then raised his head and prolonged his stand much, but it was less than the (duration) of the first stand. He then bowed and prolonged bowing much, but it was less than the duration of his first bowing. He then prostrated and then stood up and prolonged the stand, but it was less than the first stand. He then bowed and prolonged his bowing, but it was less than the first bowing. He then lifted his head and then stood up and prolonged his stand, but it was less than the first stand. He then bowed and prolonged bowing and it was less than the first bowing. He then prostrated himself; then he turned about, and the sun had become bright, and he addressed the people. He praised Allah and landed Him and said:The sun and the moon are two signs of Allah; they are not eclipsed on account of anyones death or on account of anyone's birth. So when you see them, glorify and supplicate Allah, observe prayer, give alms. O Ummah of Muhammad, none is more indignant than Allah When His servant or maid commits fornication. O people of Muhammad, by Allah, if you knew what I know, you would weep much and laugh little}}
\hadithdefcmd{muslim}{2090}{حَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، بِهَذَا الإِسْنَادِ وَزَادَ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَإِنَّ الشَّمْسَ وَالْقَمَرَ مِنْ آيَاتِ اللَّهِ ‏"‏ ‏.‏ وَزَادَ أَيْضًا ثُمَّ رَفَعَ يَدَيْهِ فَقَالَ ‏"‏ اللَّهُمَّ هَلْ بَلَّغْتُ ‏"‏ ‏.‏\hadithno{2090}\hadithtrans{This hadith has been narrated by Hisham b. 'Urwa with the same chain of transmitters but with this addition:" Verily the sun and the moon are among the signs of Allah." And similarly this addition was made:" He then lifted his hands and said: O Allah! have I not conveyed it?}}
\hadithdefcmd{muslim}{2091}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَمُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ خَسَفَتِ الشَّمْسُ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْمَسْجِدِ فَقَامَ وَكَبَّرَ وَصَفَّ النَّاسُ وَرَاءَهُ فَاقْتَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم قِرَاءَةً طَوِيلَةً ثُمَّ كَبَّرَ فَرَكَعَ رُكُوعًا طَوِيلاً ثُمَّ رَفَعَ رَأْسَهُ فَقَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏ ثُمَّ قَامَ فَاقْتَرَأَ قِرَاءَةً طَوِيلَةً هِيَ أَدْنَى مِنَ الْقِرَاءَةِ الأُولَى ثُمَّ كَبَّرَ فَرَكَعَ رُكُوعًا طَوِيلاً هُوَ أَدْنَى مِنَ الرُّكُوعِ الأَوَّلِ ثُمَّ قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏ ثُمَّ سَجَدَ - وَلَمْ يَذْكُرْ أَبُو الطَّاهِرِ ثُمَّ سَجَدَ - ثُمَّ فَعَلَ فِي الرَّكْعَةِ الأُخْرَى مِثْلَ ذَلِكَ حَتَّى اسْتَكْمَلَ أَرْبَعَ رَكَعَاتٍ وَأَرْبَعَ سَجَدَاتٍ وَانْجَلَتِ الشَّمْسُ قَبْلَ أَنْ يَنْصَرِفَ ثُمَّ قَامَ فَخَطَبَ النَّاسَ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا رَأَيْتُمُوهَا فَافْزَعُوا لِلصَّلاَةِ ‏"‏ ‏.‏ وَقَالَ أَيْضًا ‏"‏ فَصَلُّوا حَتَّى يُفَرِّجَ اللَّهُ عَنْكُمْ ‏"‏ ‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ رَأَيْتُ فِي مَقَامِي هَذَا كُلَّ شَىْءٍ وُعِدْتُمْ حَتَّى لَقَدْ رَأَيْتُنِي أُرِيدُ أَنْ آخُذَ قِطْفًا مِنَ الْجَنَّةِ حِينَ رَأَيْتُمُونِي جَعَلْتُ أُقَدِّمُ - وَقَالَ الْمُرَادِيُّ أَتَقَدَّمُ - وَلَقَدْ رَأَيْتُ جَهَنَّمَ يَحْطِمُ بَعْضُهَا بَعْضًا حِينَ رَأَيْتُمُونِي تَأَخَّرْتُ وَرَأَيْتُ فِيهَا ابْنَ لُحَىٍّ وَهُوَ الَّذِي سَيَّبَ السَّوَائِبَ ‏"‏ ‏.‏ وَانْتَهَى حَدِيثُ أَبِي الطَّاهِرِ عِنْدَ قَوْلِهِ ‏"‏ فَافْزَعُوا لِلصَّلاَةِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ مَا بَعْدَهُ ‏.‏\hadithno{2091}\hadithtrans{A'isha, the wife of the Messenger of Allah (ﷺ), reported There was an eclipse of the sun during the lifetime of the Messenger of Allah (ﷺ). So, the Messenger of Allah (may peace he upon him) went to the mosque and stood up and glorified Allah, and the people formed themselves in rows behind him. The Messenger of Allah (ﷺ) made a long recital (of the Qur'an) and then pronounced takbir and then observed a long ruku'. He then raised his head and said:Allah listened to him who praised Him: our Lord, praise is due to Thee. He then again stood up and made a long recital, which was less than the first recital. He pronounced takbir and observed a long ruku', and it was less than the first one. He again said: Allah listened to him who praised Him; our Lord, praise is due to Thee. (Abu Tahir, one of the narrators) made no mention of:" He then prostrated himself." He did like this in the second rak'ah, till he completed four rak'ahs and four prostrations and the sun became bright before he deported. He then stood up and addressed people, after lauding Allah as He deserved, and then said: The sun and the moon are two signs among the signs of Allah These do not eclipse either on the death of anyone or on his birth. So when you see them, hasten to prayer. He also said this: Observe prayer till Allah dispels the anxiety (of this extraordinary phenomenon) from you. The Messenger of Allah (ﷺ) said: I saw in my place everything which you have been promised. I even saw myself desiring to pluck a bunch (of grapes) from Paradise (and it was at the time) when you saw me moving forward. And I saw Hell and some of its parts crushing the others, when you saw me moving back; and I saw in it Ibn Luhayy and he was the person who made the she-camels loiter about. In the hadith transmitted by Abu Tahir the words are:" He hastened to prayer," and he made no mention of what follows}}
\hadithdefcmd{muslim}{2092}{وَحَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ قَالَ الأَوْزَاعِيُّ أَبُو عَمْرٍو وَغَيْرُهُ سَمِعْتُ ابْنَ شِهَابٍ الزُّهْرِيَّ، يُخْبِرُ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ الشَّمْسَ، خَسَفَتْ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَعَثَ مُنَادِيًا ‏ "‏ الصَّلاَةَ جَامِعَةً ‏"‏ ‏.‏ فَاجْتَمَعُوا وَتَقَدَّمَ فَكَبَّرَ ‏.‏ وَصَلَّى أَرْبَعَ رَكَعَاتٍ فِي رَكْعَتَيْنِ وَأَرْبَعَ سَجَدَاتٍ ‏.‏\hadithno{2092}\hadithtrans{A'isha reported that there was a solar eclipse during the lifetime of the Messenger of Allah (way peace be upon him) and he sent the announcer (to summon them) for congregational prayer. The people gathered together and he pronounced takbir and he observed four rak'ahs, in the form of two rak'ahs (i. e. he observed two qiyams and two ruku's in one rak'ah) and four prostrations}}
\hadithdefcmd{muslim}{2094}{وَحَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ نَمِرٍ، أَنَّهُ سَمِعَ ابْنَ شِهَابٍ، يُخْبِرُ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم جَهَرَ فِي صَلاَةِ الْخُسُوفِ بِقِرَاءَتِهِ فَصَلَّى أَرْبَعَ رَكَعَاتٍ فِي رَكْعَتَيْنِ وَأَرْبَعَ سَجَدَاتٍ ‏.‏ قَالَ الزُّهْرِيُّ وَأَخْبَرَنِي كَثِيرُ بْنُ عَبَّاسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى أَرْبَعَ رَكَعَاتٍ فِي رَكْعَتَيْنِ وَأَرْبَعَ سَجَدَاتٍ ‏.‏\hadithno{2094}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) recited loudly in the eclipse prayer, and he observed four rak'ahs in the form of two rak'ahs and four prostrations. Zuhri said:Kathir b. 'Abbas narrated on the authority of Ibn 'Abbas that the Messenger of Allah (ﷺ) observed four rak'ahs and four prostrations in two rak'ahs}}
\hadithdefcmd{muslim}{2095}{وَحَدَّثَنَا حَاجِبُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ الزُّبَيْدِيُّ، عَنِ الزُّهْرِيِّ، قَالَ كَانَ كَثِيرُ بْنُ عَبَّاسٍ يُحَدِّثُ أَنَّ ابْنَ عَبَّاسٍ، كَانَ يُحَدِّثُ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ كَسَفَتِ الشَّمْسُ بِمِثْلِ مَا حَدَّثَ عُرْوَةُ عَنْ عَائِشَةَ ‏.‏\hadithno{2095}\hadithtrans{Zuhri said:Kathir b. Abbas used to narrate that Ibn 'Abbas used to relate about the prayer of the Messenger of Allah (ﷺ) in regard to the eclipse of the sun like that what was narrated by 'Urwa on the authority of 'A'isha}}
\hadithdefcmd{muslim}{2096}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ سَمِعْتُ عَطَاءً، يَقُولُ سَمِعْتُ عُبَيْدَ بْنَ عُمَيْرٍ، يَقُولُ حَدَّثَنِي مَنْ، أُصَدِّقُ - حَسِبْتُهُ يُرِيدُ عَائِشَةَ - أَنَّ الشَّمْسَ انْكَسَفَتْ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَامَ قِيَامًا شَدِيدًا يَقُومُ قَائِمًا ثُمَّ يَرْكَعُ ثُمَّ يَقُومُ ثُمَّ يَرْكَعُ ثُمَّ يَقُومُ ثُمَّ يَرْكَعُ رَكْعَتَيْنِ فِي ثَلاَثِ رَكَعَاتٍ وَأَرْبَعِ سَجَدَاتٍ فَانْصَرَفَ وَقَدْ تَجَلَّتِ الشَّمْسُ وَكَانَ إِذَا رَكَعَ قَالَ ‏"‏ اللَّهُ أَكْبَرُ ‏"‏ ‏.‏ ثُمَّ يَرْكَعُ وَإِذَا رَفَعَ رَأْسَهُ قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ فَقَامَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَكْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ وَلَكِنَّهُمَا مِنْ آيَاتِ اللَّهِ يُخَوِّفُ اللَّهُ بِهِمَا عِبَادَهُ فَإِذَا رَأَيْتُمْ كُسُوفًا فَاذْكُرُوا اللَّهَ حَتَّى يَنْجَلِيَا ‏"‏ ‏.‏\hadithno{2096}\hadithtrans{Ata' reported:I heard 'Ubaid b. 'Umair say: It has been narrated to me by one whom I regard as truthful, (the narrator says: I can well guess that he meant 'A'isha) that the sun eclipsed during the lifetime of the Messenger of Allah (ﷺ) and he stood up (in prayer) for a rigorously long time. He then bowed and then stood up and then bowed and then stood up and then bowed, thus observing three ruku's in two rak'ahs and four prostrations. He then departed and the sun brightened. He pronounced" Allah is the Greatest" while bowing. He would then bow and say:" Allah listened to him who praised Him" while lifting up his head. He then stood up, and praised Allah and lauded Him, and then said: The sun and the moon do not eclipse on the death of anyone or on his birth. But both of them are among the signs of Allah with which Allah terrifies His servants. So when you see them under eclipse, remember Allah till they are brightened}}
\hadithdefcmd{muslim}{2097}{وحَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ ، وَمُحَمَّدُ بْنُ الْمُثَنَّى ، قَالَا : حَدَّثَنَا مُعَاذٌ وَهُوَ ابْنُ هِشَامٍ ، حَدَّثَنِي أَبِي ، عَنْ قَتَادَةَ ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ عَنْ عُبَيْدِ بْنِ عُمَيْرٍ ، عَنْ عَائِشَةَ ، أَنَّ نَبِيَّ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ " صَلَّى سِتَّ رَكَعَاتٍ وَأَرْبَعَ سَجَدَاتٍ\hadithno{2097}\hadithtrans{This hadith is narrated thus on the authority of 'A'isha through another chain of transmitters:" The Messenger of Allah (ﷺ) observed six ruku's and four prostration in (two rak'ahs)}}
\hadithdefcmd{muslim}{2098}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ يَحْيَى، عَنْ عَمْرَةَ، أَنَّ يَهُودِيَّةً، أَتَتْ عَائِشَةَ تَسْأَلُهَا فَقَالَتْ أَعَاذَكِ اللَّهُ مِنْ عَذَابِ الْقَبْرِ ‏.‏ قَالَتْ عَائِشَةُ فَقُلْتُ يَا رَسُولَ اللَّهِ يُعَذَّبُ النَّاسُ فِي الْقُبُورِ قَالَتْ عَمْرَةُ فَقَالَتْ عَائِشَةُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَائِذًا بِاللَّهِ ثُمَّ رَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ غَدَاةٍ مَرْكَبًا فَخَسَفَتِ الشَّمْسُ ‏.‏ قَالَتْ عَائِشَةُ فَخَرَجْتُ فِي نِسْوَةٍ بَيْنَ ظَهْرَىِ الْحُجَرِ فِي الْمَسْجِدِ فَأَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ مَرْكَبِهِ حَتَّى انْتَهَى إِلَى مُصَلاَّهُ الَّذِي كَانَ يُصَلِّي فِيهِ فَقَامَ وَقَامَ النَّاسُ وَرَاءَهُ - قَالَتْ عَائِشَةُ - فَقَامَ قِيَامًا طَوِيلاً ثُمَّ رَكَعَ فَرَكَعَ رُكُوعًا طَوِيلاً ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ فَرَكَعَ رُكُوعًا طَوِيلاً وَهُوَ دُونَ ذَلِكَ الرُّكُوعِ ثُمَّ رَفَعَ وَقَدْ تَجَلَّتِ الشَّمْسُ فَقَالَ ‏ "‏ إِنِّي قَدْ رَأَيْتُكُمْ تُفْتَنُونَ فِي الْقُبُورِ كَفِتْنَةِ الدَّجَّالِ ‏"‏ ‏.‏ قَالَتْ عَمْرَةُ فَسَمِعْتُ عَائِشَةَ تَقُولُ فَكُنْتُ أَسْمَعُ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدَ ذَلِكَ يَتَعَوَّذُ مِنْ عَذَابِ النَّارِ وَعَذَابِ الْقَبْرِ ‏.‏\hadithno{2098}\hadithtrans{Amra reported that a Jewess came to 'A'isha to ask (about something) and said:May Allah protect you from the torment of the grave! 'A'isha said: Messenger of Allah, would people be tormented in the graves? The Messenger of Allah (ﷺ) said: (May there be) protection of Allah! The Messenger of Allah (ﷺ) mounted one morning on the ride, and the sun eclipsed. 'A'isha said: I came in the company of the women in the mosque from behind the rooms. The Messenger of Allah (way peace he upon him) dismounted from his ride and came to the place of worship where he used to pray. He stood up (to pray) and the people stood behind him. 'A'isha said: He stood for a long time. He then bowed and it was a long ruku'. He then raised his head and he stood for a long time, less than the first standing. He then bowed and his ruku' was long, but it was less than that (the first) ruku'. He then raised (his head) and the sun had become bright. He (the Holy Prophet) then said: I saw you under trial in the grave like the turmoil of Dajjal. 'Amra said: I heard 'A'isha say: I listened after this to the Messenger of Allah (ﷺ) seeking refuge from the torment of Fire and the torment of the grave}}
\hadithdefcmd{muslim}{2099}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، جَمِيعًا عَنْ يَحْيَى بْنِ سَعِيدٍ، فِي هَذَا الإِسْنَادِ بِمِثْلِ مَعْنَى حَدِيثِ سُلَيْمَانَ بْنِ بِلاَلٍ‏\hadithno{2099}\hadithtrans{This hadith has been narrated by Yahya b. Sa'id with the same chain of transmitters}}
\hadithdefcmd{muslim}{2102}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ، اللَّهِ بْنِ نُمَيْرٍ - وَتَقَارَبَا فِي اللَّفْظِ - قَالَ حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ انْكَسَفَتِ الشَّمْسُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ مَاتَ إِبْرَاهِيمُ ابْنُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ النَّاسُ إِنَّمَا انْكَسَفَتْ لِمَوْتِ إِبْرَاهِيمَ ‏.‏ فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَصَلَّى بِالنَّاسِ سِتَّ رَكَعَاتٍ بِأَرْبَعِ سَجَدَاتٍ بَدَأَ فَكَبَّرَ ثُمَّ قَرَأَ فَأَطَالَ الْقِرَاءَةَ ثُمَّ رَكَعَ نَحْوًا مِمَّا قَامَ ثُمَّ رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ فَقَرَأَ قِرَاءَةً دُونَ الْقِرَاءَةِ الأُولَى ثُمَّ رَكَعَ نَحْوًا مِمَّا قَامَ ثُمَّ رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ فَقَرَأَ قِرَاءَةً دُونَ الْقِرَاءَةِ الثَّانِيَةِ ثُمَّ رَكَعَ نَحْوًا مِمَّا قَامَ ثُمَّ رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ ثُمَّ انْحَدَرَ بِالسُّجُودِ فَسَجَدَ سَجْدَتَيْنِ ثُمَّ قَامَ فَرَكَعَ أَيْضًا ثَلاَثَ رَكَعَاتٍ لَيْسَ فِيهَا رَكْعَةٌ إِلاَّ الَّتِي قَبْلَهَا أَطْوَلُ مِنَ الَّتِي بَعْدَهَا وَرُكُوعُهُ نَحْوًا مِنْ سُجُودِهِ ثُمَّ تَأَخَّرَ وَتَأَخَّرَتِ الصُّفُوفُ خَلْفَهُ حَتَّى انْتَهَيْنَا - وَقَالَ أَبُو بَكْرٍ حَتَّى انْتَهَى إِلَى النِّسَاءِ - ثُمَّ تَقَدَّمَ وَتَقَدَّمَ النَّاسُ مَعَهُ حَتَّى قَامَ فِي مَقَامِهِ فَانْصَرَفَ حِينَ انْصَرَفَ وَقَدْ آضَتِ الشَّمْسُ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ إِنَّمَا الشَّمْسُ وَالْقَمَرُ آيَتَانِ مِنْ آيَاتِ اللَّهِ وَإِنَّهُمَا لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ مِنَ النَّاسِ - وَقَالَ أَبُو بَكْرٍ لِمَوْتِ بَشَرٍ - فَإِذَا رَأَيْتُمْ شَيْئًا مِنْ ذَلِكَ فَصَلُّوا حَتَّى تَنْجَلِيَ مَا مِنْ شَىْءٍ تُوعَدُونَهُ إِلاَّ قَدْ رَأَيْتُهُ فِي صَلاَتِي هَذِهِ لَقَدْ جِيءَ بِالنَّارِ وَذَلِكُمْ حِينَ رَأَيْتُمُونِي تَأَخَّرْتُ مَخَافَةَ أَنْ يُصِيبَنِي مِنْ لَفْحِهَا وَحَتَّى رَأَيْتُ فِيهَا صَاحِبَ الْمِحْجَنِ يَجُرُّ قُصْبَهُ فِي النَّارِ كَانَ يَسْرِقُ الْحَاجَّ بِمِحْجَنِهِ فَإِنْ فُطِنَ لَهُ قَالَ إِنَّمَا تَعَلَّقَ بِمِحْجَنِي ‏.‏ وَإِنْ غُفِلَ عَنْهُ ذَهَبَ بِهِ وَحَتَّى رَأَيْتُ فِيهَا صَاحِبَةَ الْهِرَّةِ الَّتِي رَبَطَتْهَا فَلَمْ تُطْعِمْهَا وَلَمْ تَدَعْهَا تَأْكُلُ مِنْ خَشَاشِ الأَرْضِ حَتَّى مَاتَتْ جُوعًا ثُمَّ جِيءَ بِالْجَنَّةِ وَذَلِكُمْ حِينَ رَأَيْتُمُونِي تَقَدَّمْتُ حَتَّى قُمْتُ فِي مَقَامِي وَلَقَدْ مَدَدْتُ يَدِي وَأَنَا أُرِيدُ أَنْ أَتَنَاوَلَ مِنْ ثَمَرِهَا لِتَنْظُرُوا إِلَيْهِ ثُمَّ بَدَا لِي أَنْ لاَ أَفْعَلَ فَمَا مِنْ شَىْءٍ تُوعَدُونَهُ إِلاَّ قَدْ رَأَيْتُهُ فِي صَلاَتِي هَذِهِ ‏"‏ ‏.‏\hadithno{2102}\hadithtrans{Jabir reported that the sun eclipsed during the lifetime of the Messenger of Allah (ﷺ) on that very day when Ibrahim (the Prophet's son) died. The Apostle of Allah (ﷺ) stood up and led people in (two rak'ahs of) prayer with six ruku's and four prostrations. He commenced (the prayer) with takbir (Allah-o-Akbar) and then recited and prolonged his recital. He then bowed nearly the (length of time) that he stood up. He then raised his head from the ruku' and recited but less than the first recital. He then bowed (to the length of time) that he stood up. He then raised his head from the ruku' and again recited but less than the second recital. He then bowed (to the length of time) that he stood up. He then lifted his head from the ruku'. He then fell in prostration and observed two prostrations. He stood up and then bowed, observing six ruku's like it, without (completing) the rak'ah in them, except (this difference) that the first (qiyam of ruku') was longer than the later one, and the ruku' was nearly (of the same length) as prostration. He then moved backward and the rows behind him also moved backward till we reached the extreme (Abu Bakr said:till he reached near the women) He then moved forward and the people also moved forward along with him till he stood at his (original) place (of worship). He then completed the prayer as it was required to complete and the sun brightened and he said: O people! verily the sun and the moon are among the signs of Allah and they do not eclipse at the death of anyone among people (Abu Bakr said: On the death of any human being). So when you see anything like it (of the nature of eclipse), pray till it is bright. There is nothing which you have been promised (in the next world) but I have seen it in this prayer of mine. Hell was brought to me as you saw me moving back on account of fear lest its heat might affect me; and I saw the owner of the curved staff who dragged his intestines in the fire, and he used to steal (the belongings) of the pilgrims with his curved staff. If he (the owner of the staff) became aware, he would say: It got (accidentally) entangled in my curved staff, but if he was unaware of that, he would take that away. I also saw in it (in Hell) the owner of a cat whom she had tied and did not feed her nor set her free so that she could eat the creatures of the earth, till the cat died of starvation. Paradise was brought to me, and it was on that occasion that you saw me moving forward till I stood at my place (of worship). I stretched my hand as I wanted to catch hold of its fruits so that you may see them. Then I thought of not doing it. Nothing which you have been promised was there that I did not see in this prayer of mine}}
\hadithdefcmd{muslim}{2103}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ، حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامٌ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، قَالَتْ خَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَدَخَلْتُ عَلَى عَائِشَةَ وَهِيَ تُصَلِّي فَقُلْتُ مَا شَأْنُ النَّاسِ يُصَلُّونَ فَأَشَارَتْ بِرَأْسِهَا إِلَى السَّمَاءِ فَقُلْتُ آيَةٌ قَالَتْ نَعَمْ ‏.‏ فَأَطَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْقِيَامَ جِدًّا حَتَّى تَجَلاَّنِي الْغَشْىُ فَأَخَذْتُ قِرْبَةً مِنْ مَاءٍ إِلَى جَنْبِي فَجَعَلْتُ أَصُبُّ عَلَى رَأْسِي أَوْ عَلَى وَجْهِي مِنَ الْمَاءِ - قَالَتْ - فَانْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ تَجَلَّتِ الشَّمْسُ فَخَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّاسَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏ "‏ أَمَّا بَعْدُ مَا مِنْ شَىْءٍ لَمْ أَكُنْ رَأَيْتُهُ إِلاَّ قَدْ رَأَيْتُهُ فِي مَقَامِي هَذَا حَتَّى الْجَنَّةَ وَالنَّارَ وَإِنَّهُ قَدْ أُوحِيَ إِلَىَّ أَنَّكُمْ تُفْتَنُونَ فِي الْقُبُورِ قَرِيبًا أَوْ مِثْلَ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ - لاَ أَدْرِي أَىَّ ذَلِكَ قَالَتْ أَسْمَاءُ - فَيُؤْتَى أَحَدُكُمْ فَيُقَالُ مَا عِلْمُكَ بِهَذَا الرَّجُلِ فَأَمَّا الْمُؤْمِنُ أَوِ الْمُوقِنُ - لاَ أَدْرِي أَىَّ ذَلِكَ قَالَتْ أَسْمَاءُ - فَيَقُولُ هُوَ مُحَمَّدٌ هُوَ رَسُولُ اللَّهِ جَاءَنَا بِالْبَيِّنَاتِ وَالْهُدَى فَأَجَبْنَا وَأَطَعْنَا ‏.‏ ثَلاَثَ مِرَارٍ فَيُقَالُ لَهُ نَمْ قَدْ كُنَّا نَعْلَمُ إِنَّكَ لَتُؤْمِنُ بِهِ فَنَمْ صَالِحًا وَأَمَّا الْمُنَافِقُ أَوِ الْمُرْتَابُ - لاَ أَدْرِي أَىَّ ذَلِكَ قَالَتْ أَسْمَاءُ - فَيَقُولُ لاَ أَدْرِي سَمِعْتُ النَّاسَ يَقُولُونَ شَيْئًا فَقُلْتُ ‏"‏ ‏.‏\hadithno{2103}\hadithtrans{Asma' reported:The sun eclipsed during the lifetime of the Messenger of Allah (ﷺ). As I went to 'A'isha who was busy in prayer. I said: What is the matter with the people that they are praying (a special prayer)? She ('A'isha) pointed towards the sky with her head. I said: Is it (an unusual) sign? She said: Yes. The Messenger of Allah (ﷺ) stood up for prayer for such a long time that I was about to faint. I caught hold of a waterskin lying by my side, and began to pour water over my head, or (began to sprinkle water) on my face. The Messenger of Allah (ﷺ) then finished and the sun had brightened. The Messenger of Allah (ﷺ) then addressed the people, (after) praising Allah and lauding Him, and then said: There was no such thing as I did not see earlier, but I saw it at this very place of mine. I ever saw Paradise and Hell. It was also revealed to me that you would be tried in the graves, as you would he tried something like the turmoil of the Dajjal. Asma' said: I do not know which word he actually used (qariban or mithl), and each one of you would be brought and it would be said: What is your knowledge about this man? If the person is a believer, (Asma' said: I do not know whether it was the word al-Mu'min or al-Mu'qin) he would say: He is Muhammad and he is the Messenger of Allah. He brought to us the clear signs and right guidance. So we responded and obeyed him. (He would repeat this three times), and it would be said to him: You should go to sleep. We already knew that you are a believer in him. So the pious man would go to sleep. So far as the hypocrite or sceptic is concerned (Asma' said: I do not know which word was that: al-Munafiq (hypocrite) or al-Murtad (doubtful) he would say: I do not know. I only uttered whatever I heard people say}}
\hadithdefcmd{muslim}{2106}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا ابْنُ جُرَيْجٍ، حَدَّثَنِي مَنْصُورُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أُمِّهِ، صَفِيَّةَ بِنْتِ شَيْبَةَ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّهَا قَالَتْ فَزِعَ النَّبِيُّ صلى الله عليه وسلم يَوْمًا - قَالَتْ تَعْنِي يَوْمَ كَسَفَتِ الشَّمْسُ - فَأَخَذَ دِرْعًا حَتَّى أُدْرِكَ بِرِدَائِهِ فَقَامَ لِلنَّاسِ قِيَامًا طَوِيلاً لَوْ أَنَّ إِنْسَانًا أَتَى لَمْ يَشْعُرْ أَنَّ النَّبِيَّ صلى الله عليه وسلم رَكَعَ مَا حَدَّثَ أَنَّهُ رَكَعَ مِنْ طُولِ الْقِيَامِ ‏.‏\hadithno{2106}\hadithtrans{Asma' bint Abu Bakr said:The Apostle of Allah (ﷺ) was one day (i. e. on the day when the sun eclipsed) so perturbed that he (in haste) took hold of the outer garment (of a female member of his family) and it was later on that his (own) cloak was sent to him. He stood in prayer along with people for such a long time that if a man came he did not realise that the Messenger of Allah (ﷺ) had observed ruku', as it has been narrated about ruku' in connection with long qiyam}}
\hadithdefcmd{muslim}{2107}{وَحَدَّثَنِي سَعِيدُ بْنُ يَحْيَى الأُمَوِيُّ، حَدَّثَنِي أَبِي، حَدَّثَنَا ابْنُ جُرَيْجٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ وَقَالَ قِيَامًا طَوِيلاً يَقُومُ ثُمَّ يَرْكَعُ وَزَادَ فَجَعَلْتُ أَنْظُرُ إِلَى الْمَرْأَةِ أَسَنَّ مِنِّي وَإِلَى الأُخْرَى هِيَ أَسْقَمُ مِنِّي ‏.‏\hadithno{2107}\hadithtrans{Abu Juraij narrated this hadith with the same chain of transmitters (but with the addition of these words):" It was for a long duration that he (the Holy Prophet) observed qiyam and he would then observe ruku'. (The narrator also added) I (Asma') looked at a woman who was older than I, and at another who was weaker than I}}
\hadithdefcmd{muslim}{2108}{وَحَدَّثَنِي أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا حَبَّانُ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا مَنْصُورٌ، عَنْ أُمِّهِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ كَسَفَتِ الشَّمْسُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَفَزِعَ فَأَخْطَأَ بِدِرْعٍ حَتَّى أُدْرِكَ بِرِدَائِهِ بَعْدَ ذَلِكَ قَالَتْ فَقَضَيْتُ حَاجَتِي ثُمَّ جِئْتُ وَدَخَلْتُ الْمَسْجِدَ فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَائِمًا فَقُمْتُ مَعَهُ فَأَطَالَ الْقِيَامَ حَتَّى رَأَيْتُنِي أُرِيدُ أَنْ أَجْلِسَ ثُمَّ أَلْتَفِتُ إِلَى الْمَرْأَةِ الضَّعِيفَةِ فَأَقُولُ هَذِهِ أَضْعَفُ مِنِّي ‏.‏ فَأَقُومُ فَرَكَعَ فَأَطَالَ الرُّكُوعَ ثُمَّ رَفَعَ رَأْسَهُ فَأَطَالَ الْقِيَامَ حَتَّى لَوْ أَنَّ رَجُلاً جَاءَ خُيِّلَ إِلَيْهِ أَنَّهُ لَمْ يَرْكَعْ ‏.‏\hadithno{2108}\hadithtrans{Asma' daughter of Abu Bakr reported:The sun eclipsed during the lifetime of the Messenger of Allah (ﷺ) ; so he felt perturbed and he, by mistake, took hold of the outer garment of a woman till he was given his own cloak. After this I satisfied my need and then came and entered the mosque. I saw the Messenger of Allah (ﷺ) standing in prayer. I stood along with him. He prolonged his qiyam till I wished to sit down. Then I cast a glance towards an old woman. So I said: She is older than I. I, therefore, kept standing. He (the Holy Prophet) then observed ruku', and prolonged his ruku'. He then raised his head. He then prolonged his qiyam to such an extent that if a person happened to come he would have thought that he had not observed the ruku}}
\hadithdefcmd{muslim}{2109}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ مَيْسَرَةَ، حَدَّثَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ عَطَاءِ، بْنِ يَسَارٍ عَنِ ابْنِ عَبَّاسٍ، قَالَ انْكَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ مَعَهُ فَقَامَ قِيَامًا طَوِيلاً قَدْرَ نَحْوِ سُورَةِ الْبَقَرَةِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ سَجَدَ ثُمَّ قَامَ قِيَامًا طَوِيلاً وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ رَفَعَ فَقَامَ قِيَامًا طَوِيلاً وَهُوَ دُونَ الْقِيَامِ الأَوَّلِ ثُمَّ رَكَعَ رُكُوعًا طَوِيلاً وَهُوَ دُونَ الرُّكُوعِ الأَوَّلِ ثُمَّ سَجَدَ ثُمَّ انْصَرَفَ وَقَدِ انْجَلَتِ الشَّمْسُ فَقَالَ ‏"‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا رَأَيْتُمْ ذَلِكَ فَاذْكُرُوا اللَّهَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ رَأَيْنَاكَ تَنَاوَلْتَ شَيْئًا فِي مَقَامِكَ هَذَا ثُمَّ رَأَيْنَاكَ كَفَفْتَ ‏.‏ فَقَالَ ‏"‏ إِنِّي رَأَيْتُ الْجَنَّةَ فَتَنَاوَلْتُ مِنْهَا عُنْقُودًا وَلَوْ أَخَذْتُهُ لأَكَلْتُمْ مِنْهُ مَا بَقِيَتِ الدُّنْيَا وَرَأَيْتُ النَّارَ فَلَمْ أَرَ كَالْيَوْمِ مَنْظَرًا قَطُّ وَرَأَيْتُ أَكْثَرَ أَهْلِهَا النِّسَاءَ ‏"‏ ‏.‏ قَالُوا بِمَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ بِكُفْرِهِنَّ ‏"‏ ‏.‏ قِيلَ أَيَكْفُرْنَ بِاللَّهِ قَالَ ‏"‏ بِكُفْرِ الْعَشِيرِ وَبِكُفْرِ الإِحْسَانِ لَوْ أَحْسَنْتَ إِلَى إِحْدَاهُنَّ الدَّهْرَ ثُمَّ رَأَتْ مِنْكَ شَيْئًا قَالَتْ مَا رَأَيْتُ مِنْكَ خَيْرًا قَطُّ ‏"‏ ‏.‏\hadithno{2109}\hadithtrans{Ibn 'Abbas reported:There was an eclipse of the sun during the lifetime of the Messenger of Allah (ﷺ). The Messenger of Allah, (ﷺ) prayed accompanied by the people. He stood for a long time, about as long as it would take to recite Surah al-Baqara; then he bowed for a long time; then he raised his head and stood for a long time, but it was less than the first qiyam. He then bowed for a long time but for a shorter while than the first. He then prostrated and then stood for a long time, but it was less than the first qiyam. He then bowed for a long time, but it was less than the first bowing. He then raised (his head) and stood for a long time, but it was less than the first qiyam. He then bowed for a long time but it was less than the first bowing. He then observed prostration, and then he finished, and the sun had cleared (by that time). He (the Holy Prophet) then said: The sun and moon are two signs from the signs of Allah. These two do not eclipse on account of the death of anyone or on account of the birth of anyone. So when you see that, remember Allah. They (his Companions) said: Messenger of Allah, we saw you reach out to something, while you were standing here, then we saw you restrain yourself. He said: I saw Paradise and reached out to a bunch of its grapes; and had I taken it you would have eaten of it as long as the world endured. I saw Hell also. No such (abominable) sight have I ever seen as that which I saw today; and I observed that most of its inhabitants were women. They said: Messenger of Allah, on what account is it so? He said: For their ingratitude or disbelief (bi-kufraihinna). It was said: Do they disbelieve in Allah? He said: (Not for their disbelief in God) but for their ingratitude to their husbands and ingratitude to kindness. If you were to treat one of them kindly for ever, but if she later saw anything (displeasing) in you, she would say: I have never seen any good in you}}
\hadithdefcmd{muslim}{2110}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا إِسْحَاقُ، - يَعْنِي ابْنَ عِيسَى - أَخْبَرَنَا مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، فِي هَذَا الإِسْنَادِ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ثُمَّ رَأَيْنَاكَ تَكَعْكَعْتَ ‏.‏\hadithno{2110}\hadithtrans{This hadith has been narrated on the authority of Zaid b. Aslam with the same chain of transmitters except with this difference that he (the narrator said):" then we saw you keeping aloof (back)}}
\hadithdefcmd{muslim}{2111}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ سُفْيَانَ، عَنْ حَبِيبٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ كَسَفَتِ الشَّمْسُ ثَمَانَ رَكَعَاتٍ فِي أَرْبَعِ سَجَدَاتٍ ‏.‏ وَعَنْ عَلِيٍّ مِثْلُ ذَلِكَ ‏.‏\hadithno{2111}\hadithtrans{Ibn 'Abbas reported:When there was a solar eclipse the Messenger of Allah (way peace be upon him) observed eight ruku's and four prostrations (in two rak'ahs). This has been narrated by 'Ali also}}
\hadithdefcmd{muslim}{2112}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ كِلاَهُمَا عَنْ يَحْيَى الْقَطَّانِ، - قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا يَحْيَى، - عَنْ سُفْيَانَ، قَالَ حَدَّثَنَا حَبِيبٌ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى فِي كُسُوفٍ قَرَأَ ثُمَّ رَكَعَ ثُمَّ قَرَأَ ثُمَّ رَكَعَ ثُمَّ قَرَأَ ثُمَّ رَكَعَ ثُمَّ قَرَأَ ثُمَّ رَكَعَ ثُمَّ سَجَدَ ‏.‏ قَالَ وَالأُخْرَى مِثْلُهَا ‏.‏\hadithno{2112}\hadithtrans{Ibn 'Abbas reported:The Apostle of Allah (ﷺ) observed prayer while it was (solar) eclipse. He recited (the Qur'an in qiyam) and then bowed. He again recited and again bowed. He again recited and again bowed and again recited and again bowed, and then prostrated; and the second (rak'ah) was like this}}
\hadithdefcmd{muslim}{2113}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو النَّضْرِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، - وَهُوَ شَيْبَانُ النَّحْوِيُّ - عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، ح . وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا مُعَاوِيَةُ، بْنُ سَلاَّمٍ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ خَبَرِ عَبْدِ، اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ أَنَّهُ قَالَ لَمَّا انْكَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم نُودِيَ بِـ ‏\{‏ الصَّلاَةَ جَامِعَةً ‏\}‏ فَرَكَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَتَيْنِ فِي سَجْدَةٍ ثُمَّ قَامَ فَرَكَعَ رَكْعَتَيْنِ فِي سَجْدَةٍ ثُمَّ جُلِّيَ عَنِ الشَّمْسِ فَقَالَتْ عَائِشَةُ مَا رَكَعْتُ رُكُوعًا قَطُّ وَلاَ سَجَدْتُ سُجُودًا قَطُّ كَانَ أَطْوَلَ مِنْهُ ‏.‏\hadithno{2113}\hadithtrans{Amr b. al-'As reported:When the sun eclipsed during the lifetime of the Messenger of Allah (ﷺ), they (the people) were called to congregational prayers. The Messenger of Allah (ﷺ) observed two ruku's in one rak'ah. He then stood and observed two ruku's in (the second) rak'ah. The sun then became bright, and 'A'isha said; Never did I observe, ruku' and prostration longer than this (ruku' and prostration)}}
\hadithdefcmd{muslim}{2114}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ يُخَوِّفُ اللَّهُ بِهِمَا عِبَادَهُ وَإِنَّهُمَا لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ مِنَ النَّاسِ فَإِذَا رَأَيْتُمْ مِنْهَا شَيْئًا فَصَلُّوا وَادْعُوا اللَّهَ حَتَّى يُكْشَفَ مَا بِكُمْ ‏"‏ ‏.‏\hadithno{2114}\hadithtrans{Abu Mas'ud al-Ansari reported Allah's Messenger (ﷺ) as saying:Verily the sun and the moon are the two signs among the signs of Allah by which He frightens his servants and they do not eclipse on account of the death of any one of the people. So when you see anything about them, observe prayer, supplicate Allah till it is cleared from you}}
\hadithdefcmd{muslim}{2115}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، وَيَحْيَى بْنُ حَبِيبٍ، قَالاَ حَدَّثَنَا مُعْتَمِرٌ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ أَبِي مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لَيْسَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ مِنَ النَّاسِ وَلَكِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ فَإِذَا رَأَيْتُمُوهُ فَقُومُوا فَصَلُّوا ‏"‏ ‏.‏\hadithno{2115}\hadithtrans{Abu Mas'ud reported that the Messenger of Allah (ﷺ) said:Verily the sun and the moon do not eclipse on account of the death of any one of the people, but they are the two signs among the signs of Allah. So when you see it, stand up and observe prayer}}
\hadithdefcmd{muslim}{2116}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، وَأَبُو أُسَامَةَ وَابْنُ نُمَيْرٍ ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، وَوَكِيعٌ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، وَمَرْوَانُ، كُلُّهُمْ عَنْ إِسْمَاعِيلَ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِ سُفْيَانَ وَوَكِيعٍ انْكَسَفَتِ الشَّمْسُ يَوْمَ مَاتَ إِبْرَاهِيمُ فَقَالَ النَّاسُ انْكَسَفَتْ لِمَوْتِ إِبْرَاهِيمَ ‏.‏\hadithno{2116}\hadithtrans{This hadith has been narrated on the authority of Isma'il with the same chain of transmitters and in the hadith narrated by Sufyan and Waki' (the words are):" The sun eclipsed on the day when Ibrahim died, and the people said: It has eclipsed on the death of Ibrahim}}
\hadithdefcmd{muslim}{2117}{حَدَّثَنَا أَبُو عَامِرٍ الأَشْعَرِيُّ عَبْدُ اللَّهِ بْنُ بَرَّادٍ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ خَسَفَتِ الشَّمْسُ فِي زَمَنِ النَّبِيِّ صلى الله عليه وسلم فَقَامَ فَزِعًا يَخْشَى أَنْ تَكُونَ السَّاعَةُ حَتَّى أَتَى الْمَسْجِدَ فَقَامَ يُصَلِّي بِأَطْوَلِ قِيَامٍ وَرُكُوعٍ وَسُجُودٍ مَا رَأَيْتُهُ يَفْعَلُهُ فِي صَلاَةٍ قَطُّ ثُمَّ قَالَ ‏"‏ إِنَّ هَذِهِ الآيَاتِ الَّتِي يُرْسِلُ اللَّهُ لاَ تَكُونُ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ وَلَكِنَّ اللَّهَ يُرْسِلُهَا يُخَوِّفُ بِهَا عِبَادَهُ فَإِذَا رَأَيْتُمْ مِنْهَا شَيْئًا فَافْزَعُوا إِلَى ذِكْرِهِ وَدُعَائِهِ وَاسْتِغْفَارِهِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ الْعَلاَءِ كَسَفَتِ الشَّمْسُ وَقَالَ ‏"‏ يُخَوِّفُ عِبَادَهُ ‏"‏ ‏.‏\hadithno{2117}\hadithtrans{Abu Musa reported:The sun eclipsed during the time of the Messenger of Allah (ﷺ). He stood in great anxiety fearing that it might be the Doomsday, till he came to the mosque. He stood up to pray with prolonged qiyam, ruku', and prostration which I never saw him doing in prayer; and then he said: These are the signs which Allah sends, not on account of the death of anyone or life of any one, but Allah sends them to frighten thereby His servants. So when you see any such thing, hasten to remember Him, supplicate Him and beg pardon from Him, and in the narration transmitted by Ibn 'Ala the words are:" The sun eclipsed"."" He frightens His servants}}
\hadithdefcmd{muslim}{2118}{وَحَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا الْجُرَيْرِيُّ، عَنْ أَبِي الْعَلاَءِ، حَيَّانَ بْنِ عُمَيْرٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، قَالَ بَيْنَمَا أَنَا أَرْمِي، بِأَسْهُمِي فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذِ انْكَسَفَتِ الشَّمْسُ فَنَبَذْتُهُنَّ وَقُلْتُ لأَنْظُرَنَّ إِلَى مَا يَحْدُثُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فِي انْكِسَافِ الشَّمْسِ الْيَوْمَ فَانْتَهَيْتُ إِلَيْهِ وَهُوَ رَافِعٌ يَدَيْهِ يَدْعُو وَيُكَبِّرُ وَيَحْمَدُ وَيُهَلِّلُ حَتَّى جُلِّيَ عَنِ الشَّمْسِ فَقَرَأَ سُورَتَيْنِ وَرَكَعَ رَكْعَتَيْنِ ‏.‏\hadithno{2118}\hadithtrans{Abd al-Rahman b. Samura said:During the lifetime of Allah's Messenger (ﷺ) I was shooting my arrows in Medina, when an eclipse of the sun took place. I, therefore, threw them away and said, I must see how the Messenger of Allah (ﷺ) acts in a solar eclipse today. When I came to him, he had been supplicating with his hands, raised, pronouncing Allah-o-Akbar, praising Him, acknowledging that He is One God till the eclipse was over, then he recited two surahs and prayed two rak'ahs}}
\hadithdefcmd{muslim}{2119}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، عَنِ الْجُرَيْرِيِّ، عَنْ حَيَّانَ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، - وَكَانَ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ كُنْتُ أَرْتَمِي بِأَسْهُمٍ لِي بِالْمَدِينَةِ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ كَسَفَتِ الشَّمْسُ فَنَبَذْتُهَا فَقُلْتُ وَاللَّهِ لأَنْظُرَنَّ إِلَى مَا حَدَثَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فِي كُسُوفِ الشَّمْسِ قَالَ فَأَتَيْتُهُ وَهُوَ قَائِمٌ فِي الصَّلاَةِ رَافِعٌ يَدَيْهِ فَجَعَلَ يُسَبِّحُ وَيَحْمَدُ وَيُهَلِّلُ وَيُكَبِّرُ وَيَدْعُو حَتَّى حُسِرَ عَنْهَا ‏.‏ قَالَ فَلَمَّا حُسِرَ عَنْهَا قَرَأَ سُورَتَيْنِ وَصَلَّى رَكْعَتَيْنِ ‏.‏\hadithno{2119}\hadithtrans{Abd al-Rahman b. Samura, who was one of the Companions of the Messenger of Allah (ﷺ) said:During the lifetime of Allah's Messenger (ﷺ) I was shooting some of my arrows in Medina, when the sun eclipsed. I threw (the arrows) and said: By Allah, I must see how the Messenger of Allah (ﷺ) acts in solar eclipse. So I came to him and he was standing in prayer, raising his hands, glorifying Him, praising Him, acknowledging His Oneness, declaring His greatness, and supplicating Him, till the sun cleared. When the eclipse was over, he recited two surahs and prayed two rak'ahs}}
\hadithdefcmd{muslim}{2120}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا سَالِمُ بْنُ نُوحٍ، أَخْبَرَنَا الْجُرَيْرِيُّ، عَنْ حَيَّانَ بْنِ، عُمَيْرٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، قَالَ بَيْنَمَا أَنَا أَتَرَمَّى، بِأَسْهُمٍ لِي عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ خَسَفَتِ الشَّمْسُ ‏.‏ ثُمَّ ذَكَرَ نَحْوَ حَدِيثِهِمَا ‏.‏\hadithno{2120}\hadithtrans{Abd al-Rahman b. Samura reported:I was shooting some of my arrows during the lifetime of the Messenger of Allah (ﷺ) that the sun eclipsed. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2121}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ، حَدَّثَهُ عَنْ أَبِيهِ الْقَاسِمِ بْنِ مُحَمَّدِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ، عَنْ عَبْدِ، اللَّهِ بْنِ عُمَرَ أَنَّهُ كَانَ يُخْبِرُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَخْسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ وَلَكِنَّهُمَا آيَةٌ مِنْ آيَاتِ اللَّهِ فَإِذَا رَأَيْتُمُوهُمَا فَصَلُّوا ‏"‏ ‏.‏\hadithno{2121}\hadithtrans{Abdullah b. 'Umar reported that the Messenger of Allah (ﷺ) observed:Verily the sun and the moon do not eclipse on account of the death or life of anyone. They are in fact the signs among the signs of Allah. So when you see them, observe prayer}}
\hadithdefcmd{muslim}{2122}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، قَالاَ حَدَّثَنَا مُصْعَبٌ، - وَهُوَ ابْنُ الْمِقْدَامِ - حَدَّثَنَا زَائِدَةُ، حَدَّثَنَا زِيَادُ بْنُ عِلاَقَةَ، - وَفِي رِوَايَةِ أَبِي بَكْرٍ قَالَ قَالَ زِيَادُ بْنُ عِلاَقَةَ - سَمِعْتُ الْمُغِيرَةَ بْنَ شُعْبَةَ، يَقُولُ انْكَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ مَاتَ إِبْرَاهِيمُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الشَّمْسَ وَالْقَمَرَ آيَتَانِ مِنْ آيَاتِ اللَّهِ لاَ يَنْكَسِفَانِ لِمَوْتِ أَحَدٍ وَلاَ لِحَيَاتِهِ فَإِذَا رَأَيْتُمُوهُمَا فَادْعُوا اللَّهَ وَصَلُّوا حَتَّى يَنْكَشِفَ ‏"‏ ‏.‏\hadithno{2122}\hadithtrans{Ziyad b. 'Ilaqa reported:I heard Mughira b. Shu'ba saying that the sun eclipsed during the lifetime of the Messenger of Allah (ﷺ) on the day when Ibrahim died. Upon this the Messenger of Allah (ﷺ) said: Verily the sun and the moon are the two signs among the signs of Allah. They do not eclipse on account of the death of anyone or on account of the birth of anyone. So when you see them, supplicate Allah, and observe prayer till it is over}}
