% Auto-generated chapter 3 for malik
% Hadiths in this chapter: 75

\hadithdefcmd{malik}{146}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَدْ أَرَادَ أَنْ يَتَّخِذَ خَشَبَتَيْنِ يُضْرَبُ بِهِمَا لِيَجْتَمِعَ النَّاسُ لِلصَّلاَةِ فَأُرِيَ عَبْدُ اللَّهِ بْنُ زَيْدٍ الأَنْصَارِيُّ ثُمَّ مِنْ بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ خَشَبَتَيْنِ فِي النَّوْمِ فَقَالَ إِنَّ هَاتَيْنِ لَنَحْوٌ مِمَّا يُرِيدُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقِيلَ أَلاَ تُؤَذِّنُونَ لِلصَّلاَةِ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ اسْتَيْقَظَ فَذَكَرَ لَهُ ذَلِكَ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالأَذَانِ ‏.‏\hadithno{146}\hadithgrade{Salim al-Hilali: Mursal Sahih Isnaad}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said, "The Messenger of Allah, may Allah bless him and grant him peace, had wanted to take two pieces of wood to strike them together to gather people for the prayer, and Abdullah ibn Zayd al-Ansari, then of the tribe of Harith ibn al-Khazraj, was shown two pieces of wood in his sleep. He said, 'These are close to what the Messenger of Allah, may Allah bless him and grant him peace, wants.' Then it was said, 'Do you not call to the prayer?', so when he woke up he went to the Messenger of Allah, may Allah bless him and grant him peace, and mentioned the dream to him. The Messenger of Allah, may Allah bless him and grant him peace, ordered the adhan}}
\hadithdefcmd{malik}{147}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَمِعْتُمُ النِّدَاءَ فَقُولُوا مِثْلَ مَا يَقُولُ الْمُؤَذِّنُ ‏"‏ ‏.‏\hadithno{147}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Ata ibn Yazid al-Laythi from Abu Said al-Khudri that the Messenger of Allah, may Allah bless him and grant him peace, said, "When you hear the adhan, repeat what the muadhdhin says}}
\hadithdefcmd{malik}{148}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ يَعْلَمُ النَّاسُ مَا فِي النِّدَاءِ وَالصَّفِّ الأَوَّلِ ثُمَّ لَمْ يَجِدُوا إِلاَّ أَنْ يَسْتَهِمُوا عَلَيْهِ لاَسْتَهَمُوا وَلَوْ يَعْلَمُونَ مَا فِي التَّهْجِيرِ لاَسْتَبَقُوا إِلَيْهِ وَلَوْ يَعْلَمُونَ مَا فِي الْعَتَمَةِ وَالصُّبْحِ لأَتَوْهُمَا وَلَوْ حَبْوًا ‏"‏ ‏.‏\hadithno{148}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Sumayy, the mawla of Abu Bakr ibn Abd ar-Rahman, from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "If people knew what was in the adhan and the first row of the prayer and could only draw lots for it, they would draw lots. And if they knew what was in doing dhuhr early, they would race each other to it. And if they knew what was in isha and subh, they would go to them even if they had to crawl}}
\hadithdefcmd{malik}{149}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَعْقُوبَ، عَنْ أَبِيهِ، وَإِسْحَاقَ بْنِ عَبْدِ اللَّهِ، أَنَّهُمَا أَخْبَرَاهُ أَنَّهُمَا، سَمِعَا أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا ثُوِّبَ بِالصَّلاَةِ فَلاَ تَأْتُوهَا وَأَنْتُمْ تَسْعَوْنَ وَأْتُوهَا وَعَلَيْكُمُ السَّكِينَةُ فَمَا أَدْرَكْتُمْ فَصَلُّوا وَمَا فَاتَكُمْ فَأَتِمُّوا فَإِنَّ أَحَدَكُمْ فِي صَلاَةٍ مَا كَانَ يَعْمِدُ إِلَى الصَّلاَةِ ‏"‏ ‏.‏\hadithno{149}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from al-Ala ibn Abd ar-Rahman ibn Yaqub from his father and Ishaq ibn Abdullah that they informed him that they heard Abu Hurayra say, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'When the iqama is called for prayer, do not come to it running, but come with calmness. Pray what you catch and complete what you miss. You are in prayer as long as your aim is the prayer}}
\hadithdefcmd{malik}{150}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ الأَنْصَارِيِّ، ثُمَّ الْمَازِنِيِّ عَنْ أَبِيهِ، أَنَّهُ أَخْبَرَهُ أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ قَالَ لَهُ ‏ "‏ إِنِّي أَرَاكَ تُحِبُّ الْغَنَمَ وَالْبَادِيَةَ فَإِذَا كُنْتَ فِي غَنَمِكَ أَوْ بَادِيَتِكَ فَأَذَّنْتَ بِالصَّلاَةِ فَارْفَعْ صَوْتَكَ بِالنِّدَاءِ فَإِنَّهُ لاَ يَسْمَعُ مَدَى صَوْتِ الْمُؤَذِّنِ جِنٌّ وَلاَ إِنْسٌ وَلاَ شَىْءٌ إِلاَّ شَهِدَ لَهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو سَعِيدٍ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{150}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abd arRahman ibn Abdullah ibn Abd ar-Rahman ibn Abu Sasaca al-Ansari, and later al-Mazini, that his father told him that Abu Said al-Khudri had said to him, "I see that you love sheep and the desert. When you are among your sheep or in your desert, call the prayer and raise your voice in the adhan, because I heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'No jinn or man or anything within range hears the voice of the muadhdhin except that it bears witness for him on the day of rising}}
\hadithdefcmd{malik}{151}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نُودِيَ لِلصَّلاَةِ أَدْبَرَ الشَّيْطَانُ لَهُ ضُرَاطٌ حَتَّى لاَ يَسْمَعَ النِّدَاءَ فَإِذَا قُضِيَ النِّدَاءُ أَقْبَلَ حَتَّى إِذَا ثُوِّبَ بِالصَّلاَةِ أَدْبَرَ حَتَّى إِذَا قُضِيَ التَّثْوِيبُ أَقْبَلَ حَتَّى يَخْطِرَ بَيْنَ الْمَرْءِ وَنَفْسِهِ يَقُولُ اذْكُرْ كَذَا اذْكُرْ كَذَا لِمَا لَمْ يَكُنْ يَذْكُرُ حَتَّى يَظَلَّ الرَّجُلُ إِنْ يَدْرِي كَمْ صَلَّى ‏"‏ ‏.‏\hadithno{151}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "When the call to prayer is made Shaytan retreats, passing wind, so that he will not hear the adhan. When the adhan is completed he comes back, until, when the iqama is said, he retreats again. When the iqama is completed, he comes back, until he comes between a man and his self and says, 'Think of such and such, think of such and such,' which he was not thinking about before, until the man does not know how much he has prayed}}
\hadithdefcmd{malik}{152}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي حَازِمِ بْنِ دِينَارٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، أَنَّهُ قَالَ سَاعَتَانِ يُفْتَحُ لَهُمَا أَبْوَابُ السَّمَاءِ وَقَلَّ دَاعٍ تُرَدُّ عَلَيْهِ دَعْوَتُهُ حَضْرَةُ النِّدَاءِ لِلصَّلاَةِ وَالصَّفُّ فِي سَبِيلِ اللَّهِ ‏.‏\hadithno{152}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu Hazim ibn Dinar that Sahl ibn Sad as-Saidi said, "There are two times when the gates of heaven are opened, and few who make supplication have it returned to them unanswered. They are at the timeof the adhan, and in a rank of people fighting in the way of Allah." Malik was asked whether the adhan on the day of jumua was called before the time had come for the prayer and he said, "It is not called until after the sun has passed the meridian." Malik was asked about doubling the adhan and the iqama, and at what point people had to stand when the iqama for the prayer was called. He said, "I have heard nothing about the adhan and iqama except what I have seen people do. As for the iqama, it is not doubled. That is what the people of knowledge in our region continue to do. As for people standing up when the iqama for the prayer is called, I have not heard of any definite point at which it is begun, and I consider it rather to be according to people's (individual) capacity, for some people are heavy and some are light, and they are not able to be as one man ." Malik was asked about a gathering of people who wished to do the prescribed prayer calling the iqama and not the adhan, and he said, "lt is enough for them. The adhan is only obligatory in mosques where the prayer is said in congregation." Malik was asked about the muadhdhin saying "Peace be upon you" to the imam and calling him to the prayer, and he was asked who was the first person to whom such a greeting was made. He replied, "I have not heard that this greeting occurred in the first community." Yahya said that Malik was asked whether a muadhdhin who called the people to prayer and then waited to see if anyone would come and no one did, so he said the iqama and did the prayer by himself and then people came after he had finished, should repeat the prayer with them. Malik said, "He does not repeat the prayer, and whoever comes after he has finished should do the prayer by himself." Yahya said that Malik was asked about a muadhdhin who called the adhan for a group of people, did voluntary prayers, and then the group of people wanted to do the prayer with some one else saying the iqama. He said, "There is no harm in that. His iqama or somebody else's are the same." Yahya said that Malik said, "The subh prayer is still called before dawn. As for the other prayers, we believe that they should only be called after the time has started}}
\hadithdefcmd{malik}{153}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ الْمُؤَذِّنَ، جَاءَ إِلَى عُمَرَ بْنِ الْخَطَّابِ يُؤْذِنُهُ لِصَلاَةِ الصُّبْحِ فَوَجَدَهُ نَائِمًا فَقَالَ الصَّلاَةُ خَيْرٌ مِنَ النَّوْمِ ‏.‏ فَأَمَرَهُ عُمَرُ أَنْ يَجْعَلَهَا فِي نِدَاءِ الصُّبْحِ ‏.‏\hadithno{153}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that the muadhdhin came to Umar ibn al-Khattab to call him to the subh prayer and found him sleeping, so he said, "Prayer is better than sleep," and Umar ordered him to put that in the adhan for subh}}
\hadithdefcmd{malik}{154}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَمِّهِ أَبِي سُهَيْلِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّهُ قَالَ مَا أَعْرِفُ شَيْئًا مِمَّا أَدْرَكْتُ عَلَيْهِ النَّاسَ إِلاَّ النِّدَاءَ بِالصَّلاَةِ ‏.‏\hadithno{154}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from his paternal uncle Abu Suhayl ibn Malik that his uncle's father said, "I recognise nothing nowadays of what I saw the people (i.e. the companions of the Messenger, may Allah bless him and grant him peace ) doing except the call to prayer}}
\hadithdefcmd{malik}{155}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، سَمِعَ الإِقَامَةَ، وَهُوَ بِالْبَقِيعِ فَأَسْرَعَ الْمَشْىَ إِلَى الْمَسْجِدِ ‏.‏\hadithno{155}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Abdullah ibn Umar heard the iqama while he was in Baqi, so he increased his pace of walking to the mosque}}
\hadithdefcmd{malik}{156}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، أَذَّنَ بِالصَّلاَةِ فِي لَيْلَةٍ ذَاتِ بَرْدٍ وَرِيحٍ فَقَالَ أَلاَ صَلُّوا فِي الرِّحَالِ ثُمَّ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْمُرُ الْمُؤَذِّنَ إِذَا كَانَتْ لَيْلَةٌ بَارِدَةٌ ذَاتُ مَطَرٍ يَقُولُ ‏ "‏ أَلاَ صَلُّوا فِي الرِّحَالِ ‏"‏ ‏.‏\hadithno{156}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar called the adhan on a cold and windy night and included the phrase, "Do the prayer in shelter." Then he said, "The Messenger of Allah, may Allah bless him and grant him peace, used to orderthe muadhdhin to say, 'Do the prayerin shelter' when it was a cold, rainy night}}
\hadithdefcmd{malik}{157}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ لاَ يَزِيدُ عَلَى الإِقَامَةِ فِي السَّفَرِ إِلاَّ فِي الصُّبْحِ فَإِنَّهُ كَانَ يُنَادِي فِيهَا وَيُقِيمُ وَكَانَ يَقُولُ إِنَّمَا الأَذَانُ لِلإِمَامِ الَّذِي يَجْتَمِعُ النَّاسُ إِلَيْهِ ‏.‏\hadithno{157}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that on a journey Abdullah ibn Umar did no more than the iqama, except for subh, when he called both the adhan and the iqama. Abdullah ibn Umar used to say, "The adhan is for an imam whom people join}}
\hadithdefcmd{malik}{158}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّ أَبَاهُ، قَالَ لَهُ إِذَا كُنْتَ فِي سَفَرٍ فَإِنْ شِئْتَ أَنْ تُؤَذِّنَ وَتُقِيمَ فَعَلْتَ وَإِنْ شِئْتَ فَأَقِمْ وَلاَ تُؤَذِّنْ ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ لاَ بَأْسَ أَنْ يُؤَذِّنَ الرَّجُلُ وَهُوَ رَاكِبٌ ‏.‏\hadithno{158}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father said to him, "When you are on a journey you can, if you wish, call the adhan and the iqama, or, if you wish, the iqama and not the adhan." Yahya said that he heard Malik say, "There is no harm in a man calling the adhan while riding}}
\hadithdefcmd{malik}{159}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ كَانَ يَقُولُ مَنْ صَلَّى بِأَرْضِ فَلاَةٍ صَلَّى عَنْ يَمِينِهِ مَلَكٌ وَعَنْ شِمَالِهِ مَلَكٌ فَإِذَا أَذَّنَ وَأَقَامَ الصَّلاَةَ أَوْ أَقَامَ صَلَّى وَرَاءَهُ مِنَ الْمَلاَئِكَةِ أَمْثَالُ الْجِبَالِ ‏.‏\hadithno{159}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab used to say, "Whoever prays on waterless, desolate land - an angel prays on his right and an angel prays on his left. When he calls both the adhan and the iqama for the prayer, or calls out the iqama, angels like mountains pray behind him}}
\hadithdefcmd{malik}{160}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ بِلاَلاً يُنَادِي بِلَيْلٍ فَكُلُوا وَاشْرَبُوا حَتَّى يُنَادِيَ ابْنُ أُمِّ مَكْتُومٍ ‏"‏ ‏.‏\hadithno{160}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "Bilal calls the adhan whilst it is still night so eat and drink until Ibn Umm Maktum calls the adhan}}
\hadithdefcmd{malik}{161}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ بِلاَلاً يُنَادِي بِلَيْلٍ فَكُلُوا وَاشْرَبُوا حَتَّى يُنَادِيَ ابْنُ أُمِّ مَكْتُومٍ ‏"‏ ‏.‏ قَالَ وَكَانَ ابْنُ أُمِّ مَكْتُومٍ رَجُلاً أَعْمَى لاَ يُنَادِي حَتَّى يُقَالَ لَهُ أَصْبَحْتَ أَصْبَحْتَ ‏.‏\hadithno{161}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah that the Messenger of Allah, may Allah bless him and grant him peace, said, "Bilal calls the adhan in the night, so eat and drink until Ibn Umm Maktum calls the adhan." Ibn Umm Maktum was a blind man who did not call the adhan until someone said to him, "The morning has come. The morning has come}}
\hadithdefcmd{malik}{162}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا افْتَتَحَ الصَّلاَةَ رَفَعَ يَدَيْهِ حَذْوَ مَنْكِبَيْهِ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ رَفَعَهُمَا كَذَلِكَ أَيْضًا وَقَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏ وَكَانَ لاَ يَفْعَلُ ذَلِكَ فِي السُّجُودِ ‏.‏\hadithno{162}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah from Abdullah ibn Umar that the Messengerof Allah, may Allah bless him and grant him peace, used to raise his hands to the level of his shoulders when he began the prayer and when he raised his head from the ruku he raised them in the same way, saying, "Allah hears whoever praises him, our Lord and praise belongs to You." He did not raise them in the sujud}}
\hadithdefcmd{malik}{163}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَلِيِّ بْنِ حُسَيْنِ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّهُ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكَبِّرُ فِي الصَّلاَةِ كُلَّمَا خَفَضَ وَرَفَعَ فَلَمْ تَزَلْ تِلْكَ صَلاَتَهُ حَتَّى لَقِيَ اللَّهَ ‏.‏\hadithno{163}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that AIi ibn Husayn ibn Ali ibn Abi Talib said, "The Messenger of Allah, may Allah bless him and grant him peace, used to say, 'Allah is greater' whenever he lowered himself and raised himself, and he continued to pray like that until he met Al lah}}
\hadithdefcmd{malik}{164}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَرْفَعُ يَدَيْهِ فِي الصَّلاَةِ ‏.‏\hadithno{164}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Sa'id from Sulayman ibn Yasar that the Messenger of Allah, may Allah bless him and grant him peace, used to raise his hands in the prayer}}
\hadithdefcmd{malik}{165}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّ أَبَا هُرَيْرَةَ، كَانَ يُصَلِّي لَهُمْ فَيُكَبِّرُ كُلَّمَا خَفَضَ وَرَفَعَ فَإِذَا انْصَرَفَ قَالَ وَاللَّهِ إِنِّي لأَشْبَهُكُمْ بِصَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{165}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Abu Salama ibn Abdar-Rahman ibn Awf that Abu Hurayra used to lead them in prayer and would say "Allah is greater" whenever he lowered himself and raised himself. When he had finished he would say, "By Allah, I am the person whose prayer most resembles the prayer of the Messenger of Allah, may Allah bless him and grant him peace}}
\hadithdefcmd{malik}{166}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يُكَبِّرُ فِي الصَّلاَةِ كُلَّمَا خَفَضَ وَرَفَعَ ‏.‏ وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا افْتَتَحَ الصَّلاَةَ رَفَعَ يَدَيْهِ حَذْوَ مَنْكِبَيْهِ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ رَفَعَهُمَا دُونَ ذَلِكَ ‏.‏\hadithno{166}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah that Abdullah ibn Umar used to say "Allah is greater" in the prayer whenever he lowered himself and raised himself. Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to raise his hands to the level of his shoulders when he began the prayer and when he raised his head from the ruku he would raise them less than that}}
\hadithdefcmd{malik}{168}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي نُعَيْمٍ، وَهْبِ بْنِ كَيْسَانَ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ كَانَ يُعَلِّمُهُمُ التَّكْبِيرَ فِي الصَّلاَةِ ‏.‏ قَالَ فَكَانَ يَأْمُرُنَا أَنْ نُكَبِّرَ كُلَّمَا خَفَضْنَا وَرَفَعْنَا ‏.‏\hadithno{168}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu Nuaym Wahb ibn Kaysan that Jabir ibn Abdullah used to teach them the takbir in the prayer. Abu Nuaym said, "He used to tell us to say 'Allah is greater' whenever we lowered or raised ourselves}}
\hadithdefcmd{malik}{169}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ كَانَ يَقُولُ إِذَا أَدْرَكَ الرَّجُلُ الرَّكْعَةَ فَكَبَّرَ تَكْبِيرَةً وَاحِدَةً أَجْزَأَتْ عَنْهُ تِلْكَ التَّكْبِيرَةُ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ إِذَا نَوَى بِتِلْكَ التَّكْبِيرَةِ افْتِتَاحَ الصَّلاَةِ ‏.‏ وَسُئِلَ مَالِكٌ عَنْ رَجُلٍ دَخَلَ مَعَ الإِمَامِ فَنَسِيَ تَكْبِيرَةَ الاِفْتِتَاحِ وَتَكْبِيرَةَ الرُّكُوعِ حَتَّى صَلَّى رَكْعَةً ثُمَّ ذَكَرَ أَنَّهُ لَمْ يَكُنْ كَبَّرَ تَكْبِيرَةَ الاِفْتِتَاحِ وَلاَ عِنْدَ الرُّكُوعِ وَكَبَّرَ فِي الرَّكْعَةِ الثَّانِيَةِ قَالَ يَبْتَدِئُ صَلاَتَهُ أَحَبُّ إِلَىَّ وَلَوْ سَهَا مَعَ الإِمَامِ عَنْ تَكْبِيرَةِ الاِفْتِتَاحِ وَكَبَّرَ فِي الرُّكُوعِ الأَوَّلِ رَأَيْتُ ذَلِكَ مُجْزِيًا عَنْهُ إِذَا نَوَى بِهَا تَكْبِيرَةَ الاِفْتِتَاحِ ‏.‏ قَالَ مَالِكٌ فِي الَّذِي يُصَلِّي لِنَفْسِهِ فَنَسِيَ تَكْبِيرَةَ الاِفْتِتَاحِ إِنَّهُ يَسْتَأْنِفُ صَلاَتَهُ ‏.‏ وَقَالَ مَالِكٌ فِي إِمَامٍ يَنْسَى تَكْبِيرَةَ الاِفْتِتَاحِ حَتَّى يَفْرُغَ مِنْ صَلاَتِهِ قَالَ أَرَى أَنْ يُعِيدَ وَيُعِيدُ مَنْ خَلْفَهُ الصَّلاَةَ وَإِنْ كَانَ مَنْ خَلْفَهُ قَدْ كَبَّرُوا فَإِنَّهُمْ يُعِيدُونَ ‏.‏\hadithno{169}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Ibn Shihab used to say, "When a man catches the raka he says, 'Allah is greater' once, and that takbir is enough for him." Malik added, "That is if he intended to begin the prayer by that takbir " Malik was asked about a man who began with the imam but forgot the opening takbir and the takbir of the ruku until he had done one raka. Then he remembered that he had not said the takbir at the opening nor in the ruku,so he said the takbir in the second raka. He said, "I prefer that he start his prayer again, but if he forgets the opening takbir with the imam and says the takbir in the first ruku, I consider that enough for him if he intends by it the opening takbir." Malik said, about some one who prayed by himself and forgot the opening takbir, "He begins his prayer afresh ." Malik said, about an imam who forgot the opening takbir until he had finished his prayer, "I think that he should do the prayer again, and those behind him, even if they have said the takbir}}
\hadithdefcmd{malik}{170}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، أَنَّهُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ بِالطُّورِ فِي الْمَغْرِبِ ‏.‏\hadithno{170}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Muhammad ibn Jubayr ibn Mutim that his father said, "I heard the Messenger of Allah, may Allah bless him and grant him peace, recite at-Tur (Sura 52) in the maghrib prayer}}
\hadithdefcmd{malik}{171}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ أُمَّ الْفَضْلِ بِنْتَ الْحَارِثِ، سَمِعَتْهُ وَهُوَ، يَقْرَأُ ‏\{‏وَالْمُرْسَلاَتِ عُرْفًا‏\}‏ فَقَالَتْ لَهُ يَا بُنَىَّ لَقَدْ ذَكَّرْتَنِي بِقِرَاءَتِكَ هَذِهِ السُّورَةَ إِنَّهَا لآخِرُ مَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَأُ بِهَا فِي الْمَغْرِبِ ‏.‏\hadithno{171}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Ubaydullah ibn Abdullah ibn Utba ibn Masud from Abdullah ibn Abbas that Umm al- Fadl bint al-Harith heard him reciting al Mursalat (sura 77) and she said to him, "My son, you have reminded me by reciting this sura that it was what I last heard the Messenger of Allah, may Allah bless him and grant him peace, recite in the maghrib prayer}}
\hadithdefcmd{malik}{172}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى سُلَيْمَانَ بْنِ عَبْدِ الْمَلِكِ عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ قَيْسِ بْنِ الْحَارِثِ، عَنْ أَبِي عَبْدِ اللَّهِ الصُّنَابِحِيِّ، قَالَ قَدِمْتُ الْمَدِينَةَ فِي خِلاَفَةِ أَبِي بَكْرٍ الصِّدِّيقِ فَصَلَّيْتُ وَرَاءَهُ الْمَغْرِبَ فَقَرَأَ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ بِأُمِّ الْقُرْآنِ وَسُورَةٍ سُورَةٍ مِنْ قِصَارِ الْمُفَصَّلِ ثُمَّ قَامَ فِي الثَّالِثَةِ فَدَنَوْتُ مِنْهُ حَتَّى إِنَّ ثِيَابِي لَتَكَادُ أَنْ تَمَسَّ ثِيَابَهُ فَسَمِعْتُهُ قَرَأَ بِأُمِّ الْقُرْآنِ وَبِهَذِهِ الآيَةِ ‏\{‏رَبَّنَا لاَ تُزِغْ قُلُوبَنَا بَعْدَ إِذْ هَدَيْتَنَا وَهَبْ لَنَا مِنْ لَدُنْكَ رَحْمَةً إِنَّكَ أَنْتَ الْوَهَّابُ‏\}‏‏.‏\hadithno{172}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu Ubayd, the mawla of Sulayman ibn Abd alMalik, from Ubada ibn Nusayy from Qays ibn al Harith that Abu Abdullah as-Sunabihi said, "I arrived in Madina in the khalifate of Abu Bakr as-Siddiq, and I prayed maghrib behind him. He recited the umm al Qur'an and two suras from the shorter ones of the mufassal in the first two rakas. Then he stood up in the third and I drew so near to him that my clothes were almost touching his clothes. I heard him reciting the umm al-Qur'an and this ayat, 'Our Lord, do not make our hearts go astray after You have guided us, and give us mercy from Your presence. Surely You are the Giver. ' " (Sura 3 ayat)}}
\hadithdefcmd{malik}{173}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا صَلَّى وَحْدَهُ يَقْرَأُ فِي الأَرْبَعِ جَمِيعًا فِي كُلِّ رَكْعَةٍ بِأُمِّ الْقُرْآنِ وَسُورَةٍ مِنَ الْقُرْآنِ وَكَانَ يَقْرَأُ أَحْيَانًا بِالسُّورَتَيْنِ وَالثَّلاَثِ فِي الرَّكْعَةِ الْوَاحِدَةِ مِنْ صَلاَةِ الْفَرِيضَةِ وَيَقْرَأُ فِي الرَّكْعَتَيْنِ مِنَ الْمَغْرِبِ كَذَلِكَ بِأُمِّ الْقُرْآنِ وَسُورَةٍ سُورَةٍ ‏.‏\hadithno{173}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to recite in all four rakas as when he prayed alone - in every raka the umm al-Qur'an and another sura from the Qur'an. Sometimes he would recite two or three suras in one raka in the obligatory prayer. Similarly, he recited the umm al-Qur'an and two suras in the first two rakas of maghrib}}
\hadithdefcmd{malik}{174}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَدِيِّ بْنِ ثَابِتٍ الأَنْصَارِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّهُ قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْعِشَاءَ فَقَرَأَ فِيهَا بِالتِّينِ وَالزَّيْتُونِ ‏.‏\hadithno{174}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Adi ibn Thabit al-Ansari that al-Barra ibn Azib said, "I prayed isha with the Messenger of Allah, may Allah bless him and grant him peace, and he recited at-Tin (Sura 95) in it}}
\hadithdefcmd{malik}{175}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُبْسِ الْقَسِّيِّ وَعَنْ تَخَتُّمِ الذَّهَبِ وَعَنْ قِرَاءَةِ الْقُرْآنِ فِي الرُّكُوعِ ‏.‏\hadithno{175}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Ibrahim ibn Abdullah ibn Hunayn from hisfatherfromAliibnAbiTalibthattheMessengerof Allah, may Allah bless him and grant him peace, forbade wearing the qassi (an Egyptian garment, stripedwithsilk),wearing gold rings, and reciting the Qur'an in ruku}}
\hadithdefcmd{malik}{176}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، عَنْ أَبِي حَازِمٍ التَّمَّارِ، عَنِ الْبَيَاضِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ عَلَى النَّاسِ وَهُمْ يُصَلُّونَ وَقَدْ عَلَتْ أَصْوَاتُهُمْ بِالْقِرَاءَةِ فَقَالَ ‏ "‏ إِنَّ الْمُصَلِّيَ يُنَاجِي رَبَّهُ فَلْيَنْظُرْ بِمَا يُنَاجِيهِ بِهِ وَلاَ يَجْهَرْ بَعْضُكُمْ عَلَى بَعْضٍ بِالْقُرْآنِ ‏"‏ ‏.‏\hadithno{176}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Muhammad ibn Ibrahim ibn al Harith at-Taymi from Abu Hazim at-Tammar from al Bayadi that the Messenger of Allah, may Allah bless him and grant him peace, came out to the people while they were praying and their voices were raised in the recitation. He said, "When you pray you are talking confidentially to your Lord. So look to what you confide to Him, and do not say the Qur'an out loud so that others hear it}}
\hadithdefcmd{malik}{177}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ قُمْتُ وَرَاءَ أَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ فَكُلُّهُمْ كَانَ لاَ يَقْرَأُ ‏\{‏بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏\}‏ إِذَا افْتَتَحَ الصَّلاَةَ ‏.‏\hadithno{177}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Humayd at-Tawil that Anas ibn Malik said, "I stood behind Abu Bakr and Umar and Uthman and none of them used to recite 'In the name of Allah, the Merciful, the Compassionate' when they began the prayer}}
\hadithdefcmd{malik}{178}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَمِّهِ أَبِي سُهَيْلِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّهُ قَالَ كُنَّا نَسْمَعُ قِرَاءَةَ عُمَرَ بْنِ الْخَطَّابِ عِنْدَ دَارِ أَبِي جَهْمٍ بِالْبَلاَطِ ‏.‏\hadithno{178}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from his paternal uncle Abu Suhayl ibn Malik that his father said, "We heard the recitation of Umar ibn al-Khattab when we were at the home of Abu Jahmin al-Balat." (Al-Balat was a place in Madina between the mosque and the market)}}
\hadithdefcmd{malik}{179}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا فَاتَهُ شَىْءٌ مِنَ الصَّلاَةِ مَعَ الإِمَامِ فِيمَا جَهَرَ فِيهِ الإِمَامُ بِالْقِرَاءَةِ أَنَّهُ إِذَا سَلَّمَ الإِمَامُ - قَامَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَقَرَأَ لِنَفْسِهِ فِيمَا يَقْضِي وَجَهَرَ ‏.‏\hadithno{179}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that when Abdullah ibn Umar missed anything of the prayer in which the imam recited out loud, he would stand up when the imam had said the taslim and recite what he owed out loud to himself}}
\hadithdefcmd{malik}{180}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ رُومَانَ، أَنَّهُ قَالَ كُنْتُ أُصَلِّي إِلَى جَانِبِ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ فَيَغْمِزُنِي فَأَفْتَحُ عَلَيْهِ وَنَحْنُ نُصَلِّي ‏.‏\hadithno{180}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Yazid ibn Ruman said, "I used to pray next to Nafi ibn Jubayr ibn Mutim and he would nudge me to prompt him while we were praying}}
\hadithdefcmd{malik}{181}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ أَبَا بَكْرٍ الصِّدِّيقَ، صَلَّى الصُّبْحَ فَقَرَأَ فِيهَا سُورَةَ الْبَقَرَةِ فِي الرَّكْعَتَيْنِ كِلْتَيْهِمَا ‏.‏\hadithno{181}\hadithgrade{Salim al-Hilali: Mauquf Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that Abu Bakr as-Siddiq prayed subh and recited suratal-Baqara in the two rak'as}}
\hadithdefcmd{malik}{182}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عَامِرِ بْنِ رَبِيعَةَ، يَقُولُ صَلَّيْنَا وَرَاءَ عُمَرَ بْنِ الْخَطَّابِ الصُّبْحَ فَقَرَأَ فِيهَا بِسُورَةِ يُوسُفَ وَسُورَةِ الْحَجِّ قِرَاءَةً بَطِيئَةً فَقُلْتُ وَاللَّهِ إِذًا لَقَدْ كَانَ يَقُومُ حِينَ يَطْلُعُ الْفَجْرُ ‏.‏ قَالَ أَجَلْ ‏.‏\hadithno{182}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father heard Abdullah ibn Amir ibn Rabia say, "We prayed subh behind Umar ibn al-Khattab and he recited suraYusuf (Sura 12) and surat al- Hajj (Sura 22) slowly." I (Hisham's father) said, "By Allah, then it must have been his habit to get up at the crack of dawn." He said, "Of course}}
\hadithdefcmd{malik}{183}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، وَرَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، أَنَّ الْفُرَافِصَةَ بْنَ عُمَيْرٍ الْحَنَفِيَّ، قَالَ مَا أَخَذْتُ سُورَةَ يُوسُفَ إِلاَّ مِنْ قِرَاءَةِ عُثْمَانَ بْنِ عَفَّانَ إِيَّاهَا فِي الصُّبْحِ مِنْ كَثْرَةِ مَا كَانَ يُرَدِّدُهَا لَنَا ‏.‏\hadithno{183}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said and Rabia ibn Abi Abd arRahman from al-Qasim ibn Muhammad that al Furafisa ibn Umayral-Hanafi said, "I only learnt Sura Yusuf (Sura 12) from the recitation of it by Uthman ibn Affan in the subh prayer because of the great number of times he repeated it to us}}
\hadithdefcmd{malik}{184}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقْرَأُ فِي الصُّبْحِ فِي السَّفَرِ بِالْعَشْرِ السُّوَرِ الأُوَلِ مِنَ الْمُفَصَّلِ فِي كُلِّ رَكْعَةٍ بِأُمِّ الْقُرْآنِ وَسُورَةٍ ‏.‏\hadithno{184}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to recite the first ten suras of the mufassal in the subh prayer, and on a journey he would recite the ummal-Qur'an and a sura in every raka}}
\hadithdefcmd{malik}{185}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَعْقُوبَ، أَنَّ أَبَا سَعِيدٍ، مَوْلَى عَامِرِ بْنِ كُرَيْزٍ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَادَى أُبَىَّ بْنَ كَعْبٍ وَهُوَ يُصَلِّي فَلَمَّا فَرَغَ مِنْ صَلاَتِهِ لَحِقَهُ فَوَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ عَلَى يَدِهِ وَهُوَ يُرِيدُ أَنْ يَخْرُجَ مِنْ بَابِ الْمَسْجِدِ فَقَالَ ‏"‏ إِنِّي لأَرْجُو أَنْ لاَ تَخْرُجَ مِنَ الْمَسْجِدِ حَتَّى تَعْلَمَ سُورَةً مَا أَنْزَلَ اللَّهُ فِي التَّوْرَاةِ وَلاَ فِي الإِنْجِيلِ وَلاَ فِي الْقُرْآنِ مِثْلَهَا ‏"‏ ‏.‏ قَالَ أُبَىٌّ فَجَعَلْتُ أُبْطِئُ فِي الْمَشْىِ رَجَاءَ ذَلِكَ ثُمَّ قُلْتُ يَا رَسُولَ اللَّهِ السُّورَةَ الَّتِي وَعَدْتَنِي ‏.‏ قَالَ ‏"‏ كَيْفَ تَقْرَأُ إِذَا افْتَتَحْتَ الصَّلاَةَ ‏"‏ ‏.‏ قَالَ فَقَرَأْتُ ‏\{‏الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ‏\}‏ حَتَّى أَتَيْتُ عَلَى آخِرِهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هِيَ هَذِهِ السُّورَةُ وَهِيَ السَّبْعُ الْمَثَانِي وَالْقُرْآنُ الْعَظِيمُ الَّذِي أُعْطِيتُ ‏"‏ ‏.‏\hadithno{185}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from al-Ala ibn Abd ar-Rahman ibn Yaqub that Abu Said, the mawla of Amir ibn Kuraz told him that the Messenger of Allah, may Allah bless him and grant him peace, called toUbayy ibn Kab while he was praying. When Ubayy had finished his prayer he joined the Messenger of Allah, may Allah bless him and grant him peace, and the Messenger of Allah put his hand upon his hand, and he was intending to leave by the door of the mosque, so the Messenger of Allah, may Allah bless him and grant him peace, said, "I hope that you will not leave the mosque until you know a sura whose like Allah has notsentdown in the Tawrah nor in the Injil nor in the Qur'an." Ubayysaid, "I began to slow down my pace in the hope of that. Then I said, 'Messenger of Allah, the sura you promised me!' He said, 'What do you recite when you begin the prayer?' I recited the Fatiha (Sura 1 ) until I came to the end of it, and the Messengerof Allah, may Allah bless him and grant him peace, said, 'It is this sura, and it is the "seven oft-repeated" and the Great Qur'an which I was given}}
\hadithdefcmd{malik}{186}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي نُعَيْمٍ، وَهْبِ بْنِ كَيْسَانَ أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ مَنْ صَلَّى رَكْعَةً لَمْ يَقْرَأْ فِيهَا بِأُمِّ الْقُرْآنِ فَلَمْ يُصَلِّ إِلاَّ وَرَاءَ الإِمَامِ ‏.‏\hadithno{186}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu Nuaym Wahb ibn Kaysan that he heard Jabir ibn Abdullah say, "Someone who prays a raka without reciting the umm al-Qur'an in it has not done the prayer except behind an imam}}
\hadithdefcmd{malik}{187}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَعْقُوبَ، أَنَّهُ سَمِعَ أَبَا السَّائِبِ، مَوْلَى هِشَامِ بْنِ زُهْرَةَ يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنْ صَلَّى صَلاَةً لَمْ يَقْرَأْ فِيهَا بِأُمِّ الْقُرْآنِ فَهِيَ خِدَاجٌ هِيَ خِدَاجٌ هِيَ خِدَاجٌ غَيْرُ تَمَامٍ ‏"‏ ‏.‏ قَالَ فَقُلْتُ يَا أَبَا هُرَيْرَةَ إِنِّي أَحْيَانًا أَكُونُ وَرَاءَ الإِمَامِ قَالَ فَغَمَزَ ذِرَاعِي ثُمَّ قَالَ اقْرَأْ بِهَا فِي نَفْسِكَ يَا فَارِسِيُّ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ قَالَ اللَّهُ تَبَارَكَ وَتَعَالَى قَسَمْتُ الصَّلاَةَ بَيْنِي وَبَيْنَ عَبْدِي نِصْفَيْنِ فَنِصْفُهَا لِي وَنِصْفُهَا لِعَبْدِي وَلِعَبْدِي مَا سَأَلَ ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَءُوا يَقُولُ الْعَبْدُ ‏\{‏الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ‏\}‏ يَقُولُ اللَّهُ تَبَارَكَ وَتَعَالَى حَمِدَنِي عَبْدِي وَيَقُولُ الْعَبْدُ ‏\{‏الرَّحْمَنِ الرَّحِيمِ‏\}‏ يَقُولُ اللَّهُ أَثْنَى عَلَىَّ عَبْدِي وَيَقُولُ الْعَبْدُ ‏\{‏مَالِكِ يَوْمِ الدِّينِ‏\}‏ يَقُولُ اللَّهُ مَجَّدَنِي عَبْدِي يَقُولُ الْعَبْدُ ‏\{‏إِيَّاكَ نَعْبُدُ وَإِيَّاكَ نَسْتَعِينُ‏\}‏ فَهَذِهِ الآيَةُ بَيْنِي وَبَيْنَ عَبْدِي وَلِعَبْدِي مَا سَأَلَ يَقُولُ الْعَبْدُ ‏\{‏اهْدِنَا الصِّرَاطَ الْمُسْتَقِيمَ صِرَاطَ الَّذِينَ أَنْعَمْتَ عَلَيْهِمْ غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ ‏\}‏ فَهَؤُلاَءِ لِعَبْدِي وَلِعَبْدِي مَا سَأَلَ ‏"‏ ‏.‏\hadithno{187}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from al-Ala ibn Abd ar-Rahman ibn Ya'qub that he heard Abu's-Sa'ib, the mawla of Hisham ibn Zuhra, say he had heard Abu Hurayra say, "I heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'Whoever prays a prayer without reciting the umm al-Qur'an in it, his prayer is aborted, it is aborted, it is aborted, incomplete.' So I said, 'Abu Hurayra, sometimes I am behind the imam.'Hepulled my forearm and said, 'Recite it to yourself, O Persian, for I heard the Messenger of Allah, may Allah bless him and grant him peace, say that Allah the Blessed, the Exalted, said, "I have divided the prayer into two halves between me and my slave. One half of it is for Me and one half of it is for IVly slave, and My slave has what he asks." ' The Messenger of Allah, may Allah bless him and grant him peace, said, "Recite." The slave says, 'Praise be to AIIah, the Lord of theWorlds.' Allah the Blessed, the Exalted, says, 'My slave has praised Me.' The slave says, 'The Merciful, the Compassionate.' Allah says, 'My slave has spoken well of Me.' The slave says, 'Master of the Day of the Deen.' Allah says, 'My slave has glorified Me.' The slave says, 'You alone we worship and You alone we askforhelp.'Allahsays,'This ayat is between Me and My slave, and for My slave is what he asks. 'The slave says, 'Guide us in the straight Path, the Path of those whom You have blessed, not of those with whom You are angry, nor those who are in error. ' Allah says, 'These are for My slaves, and for my slave is what he asks}}
\hadithdefcmd{malik}{188}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَقْرَأُ خَلْفَ الإِمَامِ فِيمَا لاَ يَجْهَرُ فِيهِ الإِمَامُ بِالْقِرَاءَةِ ‏.‏\hadithno{188}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father used to recite behind the imam when the imam did not recite aloud}}
\hadithdefcmd{malik}{189}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، وَعَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ، كَانَ يَقْرَأُ خَلْفَ الإِمَامِ فِيمَا لاَ يَجْهَرُ فِيهِ الإِمَامُ بِالْقِرَاءَةِ ‏.‏\hadithno{189}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said and from Rabia ibn Abi Abd ar Rahman that al-Qasim ibn Muhammad used to recite behind the imam when the imam did not recite aloud}}
\hadithdefcmd{malik}{190}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ رُومَانَ، أَنَّ نَافِعَ بْنَ جُبَيْرِ بْنِ مُطْعِمٍ، كَانَ يَقْرَأُ خَلْفَ الإِمَامِ فِيمَا لاَ يَجْهَرُ فِيهِ بِالْقِرَاءَةِ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي ذَلِكَ ‏.‏\hadithno{190}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yazid ibn Ruman that Nafi ibn Jubayr ibn Mutim used to recite behind the imam when hedid not recite aloud . Malik said, "That is the most preferable to me of what I have heard about the matter}}
\hadithdefcmd{malik}{191}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا سُئِلَ هَلْ يَقْرَأُ أَحَدٌ خَلْفَ الإِمَامِ قَالَ إِذَا صَلَّى أَحَدُكُمْ خَلْفَ الإِمَامِ فَحَسْبُهُ قِرَاءَةُ الإِمَامِ وَإِذَا صَلَّى وَحْدَهُ فَلْيَقْرَأْ ‏.‏ قَالَ وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ لاَ يَقْرَأُ خَلْفَ الإِمَامِ ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ الأَمْرُ عِنْدَنَا أَنْ يَقْرَأَ الرَّجُلُ وَرَاءَ الإِمَامِ فِيمَا لاَ يَجْهَرُ فِيهِ الإِمَامُ بِالْقِرَاءَةِ وَيَتْرُكُ الْقِرَاءَةَ فِيمَا يَجْهَرُ فِيهِ الإِمَامُ بِالْقِرَاءَةِ ‏.‏\hadithno{191}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar, when asked if anyone should recite behind an imam, said, "When you pray behind an imam then the recitation of the imam is enough for you and when you pray on your own you must recite." Nafi added, "Abdullah ibn 'Umar used not to recite behind the imam." Yahya said that he heard Malik say, "The position with us is that aman recites behind the imam when the imam does not recite aloud and he refrains from reciting when the imam recites aloud}}
\hadithdefcmd{malik}{192}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ أُكَيْمَةَ اللَّيْثِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم انْصَرَفَ مِنْ صَلاَةٍ جَهَرَ فِيهَا بِالْقِرَاءَةِ فَقَالَ ‏"‏ هَلْ قَرَأَ مَعِي مِنْكُمْ أَحَدٌ آنِفًا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ نَعَمْ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي أَقُولُ مَا لِي أُنَازَعُ الْقُرْآنَ ‏"‏ ‏.‏ فَانْتَهَى النَّاسُ عَنِ الْقِرَاءَةِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِيمَا جَهَرَ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْقِرَاءَةِ حِينَ سَمِعُوا ذَلِكَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{192}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Ibn Ukayma al-Laythi from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, finished a prayer in which he had recited aloud and asked, "Did any of you recite with me just now?" One man said, "Yes, I did, Messenger of Allah." The Messenger of Allah, may Allah bless him and grant him peace, said, "I was saying to myself, 'Why am I distracted from the Qur'an?' " When the people heard the Messenger of Allah, may Allah bless him and grant him peace, say that, they refrained from reciting with the Messenger of Allah, may Allah bless him and grant him peace, when he recited aloud}}
\hadithdefcmd{malik}{193}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ أَنَّهُمَا أَخْبَرَاهُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَمَّنَ الإِمَامُ فَأَمِّنُوا فَإِنَّهُ مَنْ وَافَقَ تَأْمِينُهُ تَأْمِينَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ آمِينَ ‏.‏\hadithno{193}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Sa'id ibn al- Musayyab and Abu Salama ibn Abd ar-Rahman told him from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "When the imam says 'Amin', say 'Amin', for the one whose 'Amin' coincides with the 'Amin' of the angels - his previous wrong actions are forgiven him." Ibn Shihab said, "The Messenger of Allah, may Allah bless him and grant him peace, used to say 'Aameen' (extending it)}}
\hadithdefcmd{malik}{194}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا قَالَ الإِمَامُ ‏\{‏غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ‏\}‏ فَقُولُوا آمِينَ فَإِنَّهُ مَنْ وَافَقَ قَوْلُهُ قَوْلَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{194}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Sumayy, the mawla of Abu Bakr, from Abu Salih as Samman, from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "When the imam has said, 'not of those with whom You are angry nor of those who are in error,' say 'Amin', for the previous wrong actions of the one whose utterance coincides with that of the angels, are forgiven him}}
\hadithdefcmd{malik}{195}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَالَ أَحَدُكُمْ آمِينَ وَقَالَتِ الْمَلاَئِكَةُ فِي السَّمَاءِ آمِينَ فَوَافَقَتْ إِحْدَاهُمَا الأُخْرَى غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{195}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "When one of you says 'Amin' and the angels in the sky say 'Amin' so that one coincides with the other, his previous wrong actions are forgiven him}}
\hadithdefcmd{malik}{196}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَالَ الإِمَامُ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَقُولُوا اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ فَإِنَّهُ مَنْ وَافَقَ قَوْلُهُ قَوْلَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{196}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Sumayy, the mawla of Abu Bakr, from Abu Salih as-Samman from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "When the imam says, 'Allah hears whoever praises Him,' say 'O Allah! Our Lord, praise be toYou, 'for the previous wrong actions done by the one whose utterance coincides with that of the angels are forgiven}}
\hadithdefcmd{malik}{197}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ مُسْلِمِ بْنِ أَبِي مَرْيَمَ، عَنْ عَلِيِّ بْنِ عَبْدِ الرَّحْمَنِ الْمُعَاوِيِّ، أَنَّهُ قَالَ رَآنِي عَبْدُ اللَّهِ بْنُ عُمَرَ وَأَنَا أَعْبَثُ بِالْحَصْبَاءِ فِي الصَّلاَةِ فَلَمَّا انْصَرَفْتُ نَهَانِي وَقَالَ اصْنَعْ كَمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْنَعُ ‏.‏ فَقُلْتُ وَكَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْنَعُ قَالَ كَانَ إِذَا جَلَسَ فِي الصَّلاَةِ وَضَعَ كَفَّهُ الْيُمْنَى عَلَى فَخِذِهِ الْيُمْنَى وَقَبَضَ أَصَابِعَهُ كُلَّهَا وَأَشَارَ بِأَصْبُعِهِ الَّتِي تَلِي الإِبْهَامَ وَوَضَعَ كَفَّهُ الْيُسْرَى عَلَى فَخِذِهِ الْيُسْرَى وَقَالَ هَكَذَا كَانَ يَفْعَلُ ‏.‏\hadithno{197}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Muslim ibn Abi Maryam that AIi ibn Abd ar-Rahman al-Muawi said, "Abdullah ibn Umar saw me playing with some small pebbles in the prayer. When I finished he forbade me, saying, 'Do as the Messenger of Allah, may Allah bless him and grant him peace, did.' I said, 'What did the Messenger of Allah, may Allah bless him and grant him peace, do?' He said, 'When he sat in the prayer, he placed his right hand on his right thigh and he closed his fist and pointed his index finger, and he placed his left hand on his left thigh. That is what he used to do}}
\hadithdefcmd{malik}{198}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ، وَصَلَّى، إِلَى جَنْبِهِ رَجُلٌ فَلَمَّا جَلَسَ الرَّجُلُ فِي أَرْبَعٍ تَرَبَّعَ وَثَنَى رِجْلَيْهِ فَلَمَّا انْصَرَفَ عَبْدُ اللَّهِ عَابَ ذَلِكَ عَلَيْهِ فَقَالَ الرَّجُلُ فَإِنَّكَ تَفْعَلُ ذَلِكَ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَإِنِّي أَشْتَكِي ‏.‏\hadithno{198}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar that he had seen Abdullah ibn Umar with a man praying at his side. When the man sat in the fourth raka, heput both feet to one side and crossed them. When Abdullah finished, he disapproved of that to him, and the man protested, "But you do the same." Abdullah ibn Umar said, "I am ill}}
\hadithdefcmd{malik}{199}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ صَدَقَةَ بْنِ يَسَارٍ، عَنِ الْمُغِيرَةِ بْنِ حَكِيمٍ، أَنَّهُ رَأَى عَبْدَ اللَّهِ بْنَ عُمَرَ يَرْجِعُ فِي سَجْدَتَيْنِ فِي الصَّلاَةِ عَلَى صُدُورِ قَدَمَيْهِ فَلَمَّا انْصَرَفَ ذَكَرَ لَهُ ذَلِكَ فَقَالَ إِنَّهَا لَيْسَتْ سُنَّةَ الصَّلاَةِ وَإِنَّمَا أَفْعَلُ هَذَا مِنْ أَجْلِ أَنِّي أَشْتَكِي ‏.‏\hadithno{199}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Sadaqa ibn Yasar that al- Mughira ibn Hakim saw Abdullah ibn Umar sit back from the two sajdas of the prayer onto the top of his feet. When he had finished, al- Mughira mentioned it to him, and Abdullah ibn Umar explained, "It is not a sunna of the prayer. I do it because I am ill}}
\hadithdefcmd{malik}{200}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، كَانَ يَرَى عَبْدَ اللَّهِ بْنَ عُمَرَ يَتَرَبَّعُ فِي الصَّلاَةِ إِذَا جَلَسَ قَالَ فَفَعَلْتُهُ وَأَنَا يَوْمَئِذٍ حَدِيثُ السِّنِّ فَنَهَانِي عَبْدُ اللَّهِ وَقَالَ إِنَّمَا سُنَّةُ الصَّلاَةِ أَنْ تَنْصِبَ رِجْلَكَ الْيُمْنَى وَتَثْنِيَ رِجْلَكَ الْيُسْرَى ‏.‏ فَقُلْتُ لَهُ فَإِنَّكَ تَفْعَلُ ذَلِكَ ‏.‏ فَقَالَ إِنَّ رِجْلَىَّ لاَ تَحْمِلاَنِّي ‏.‏\hadithno{200}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim that Abdullah ibn Umar told him that he used to see Abdullah ibn Umar cross his legs in the sitting position of the prayer.He said, "So I did the same, and I was young at the time. Abdullah ibn Umar forbade me and said, 'The sunna of the prayer is that you keep your right foot vertical and lay your left foot down.' I said to him, 'But you do the same (as I did).' He said, 'My feet do not support me}}
\hadithdefcmd{malik}{201}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ، أَرَاهُمُ الْجُلُوسَ فِي التَّشَهُّدِ فَنَصَبَ رِجْلَهُ الْيُمْنَى وَثَنَى رِجْلَهُ الْيُسْرَى وَجَلَسَ عَلَى وَرِكِهِ الأَيْسَرِ وَلَمْ يَجْلِسْ عَلَى قَدَمِهِ ثُمَّ قَالَ أَرَانِي هَذَا عَبْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ وَحَدَّثَنِي أَنَّ أَبَاهُ كَانَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{201}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that al-Qasim ibn Muhammad showed them how to sit in the tashahhud, and he kept his right foot vertical and laid his left foot down, and sat on his left haunch not on his foot. Then he said, "Abdullah ibn Abdullah ibn Umar saw me doing this and related to me that his father used to do the same thing}}
\hadithdefcmd{malik}{202}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدٍ الْقَارِيِّ، أَنَّهُ سَمِعَ عُمَرَ بْنَ الْخَطَّابِ، وَهُوَ عَلَى الْمِنْبَرِ يُعَلِّمُ النَّاسَ التَّشَهُّدَ يَقُولُ قُولُوا التَّحِيَّاتُ لِلَّهِ الزَّاكِيَاتُ لِلَّهِ الطَّيِّبَاتُ الصَّلَوَاتُ لِلَّهِ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏.‏\hadithno{202}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Urwa ibn az- Zubayr from Abd ar-Rahman ibn Abd al-Qari that he heard Umar ibn al- Khattab say, while he was teaching people the tashahhud from the mimbar, "Say, Greetings belong to Allah. Pure actions belong to Allah. Good words and prayers belong to Allah. Peace on you, Prophet, and the mercy of Allah and His blessings. Peace be upon us and on the slaves of Allah who are salihun. I testify that there is no god except Allah. And I testify that Muhammad is His slave and His messenger." 'At-tahiyatu lillah, az-zakiyatu lillah, at-tayibatu wa's-salawatu lillah. As-salamu alayka ayyuha'nnabiyyu wa rahmatu'llahi wa barakatuhu. As-salamu alayna wa ala ibadi'llahi s-salihin. Ash-hadu an la ilaha illa 'llah wa ash-hadu anna Muhammadan abduhu wa rasuluh}}
\hadithdefcmd{malik}{203}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَتَشَهَّدُ فَيَقُولُ بِاسْمِ اللَّهِ التَّحِيَّاتُ لِلَّهِ الصَّلَوَاتُ لِلَّهِ الزَّاكِيَاتُ لِلَّهِ السَّلاَمُ عَلَى النَّبِيِّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ شَهِدْتُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ شَهِدْتُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ ‏.‏ يَقُولُ هَذَا فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ وَيَدْعُو إِذَا قَضَى تَشَهُّدَهُ بِمَا بَدَا لَهُ فَإِذَا جَلَسَ فِي آخِرِ صَلاَتِهِ تَشَهَّدَ كَذَلِكَ أَيْضًا إِلاَّ أَنَّهُ يُقَدِّمُ التَّشَهُّدَ ثُمَّ يَدْعُو بِمَا بَدَا لَهُ فَإِذَا قَضَى تَشَهُّدَهُ وَأَرَادَ أَنْ يُسَلِّمَ قَالَ السَّلاَمُ عَلَى النَّبِيِّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ ‏.‏ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ السَّلاَمُ عَلَيْكُمْ عَنْ يَمِينِهِ ثُمَّ يَرُدُّ عَلَى الإِمَامِ فَإِنْ سَلَّمَ عَلَيْهِ أَحَدٌ عَنْ يَسَارِهِ رَدَّ عَلَيْهِ ‏.‏\hadithno{203}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say the tashahhud saying, "In the name of Allah. Greetings belong to Allah. Prayers belong to Allah. Pure actions belong to Allah. Peace be on the Prophet and the mercy of Allah and His blessings. Peace be on us and on the slaves of Allah who are salihun. I testify that there is no god except Allah. I testify that Muhammad is the Messenger of Allah." "Bismillah, at-tahiyatu lillah, as-salawatu lillah, az-zakiyatu lillah. As-salamu ala'n-nabiyyi wa rahmatullahi wa barakatuhu. As-salamu alayna wa ala ibadi'llahi's-salihin. Shahidtu an la ilaha illallah. Shahidtu anna Muhammadu'r-rasulu'llah." He used to say this after the first two rakas and he would make supplication with whatever seemed fit to him when the tashahhud was completed. When he sat at the end of the prayer, he did the tashahhud in a similar manner, except that after the tashahhud he made supplication with whatever seemed fit to him. When he had completed the tashahhud and intended to say the taslim, he said, "Peace be on the Prophet and His mercy and blessings. Peace be upon us and on the slaves of Allah who are salihun." "As- salamu ala'n-nabiyyi wa rahmatu'llahi wa barakatuhu. As-salamu alayna wa ala ibadi'llahi'ssalihin ." He then said, "Peace be upon you" to his right, and would return the greeting to the imam, and if anyone said "Peace be upon you" from his left he would return the greeting to him}}
\hadithdefcmd{malik}{204}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا كَانَتْ تَقُولُ إِذَا تَشَهَّدَتِ التَّحِيَّاتُ الطَّيِّبَاتُ الصَّلَوَاتُ الزَّاكِيَاتُ لِلَّهِ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏.‏ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ ‏.‏ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ السَّلاَمُ عَلَيْكُمْ ‏.‏\hadithno{204}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim from his father that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, used to say in the tashahhud, "Greetings, good words, prayers, pure actions belong to Allah. I testify that there is no god except Allah, alone without partner, and that Muhammad is His slave and His Messenger. Peace be on you, Prophet, and the mercy of Allah and His blessings. Peace be on us and on the slaves of Allah who are salihun. Peace be upon you." "At-tahiyatu, at- tayibatu, as-salawatu, az-zakiyatu lillah. Ash-hadu an la ilaha illa'llah, wahdahu la sharika lah wa anna Muhammadan abduhu wa rasuluhu. As-salamu alayka ayyuha-n-nabiyyu wa rahmatu-llahi wa barakatuhu. As-salamu alayna wa ala ibadi-llahi's-salihin. As-salamu alaykum}}
\hadithdefcmd{malik}{205}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، أَنَّهُ أَخْبَرَهُ أَنَّ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَانَتْ تَقُولُ إِذَا تَشَهَّدَتِ التَّحِيَّاتُ الطَّيِّبَاتُ الصَّلَوَاتُ الزَّاكِيَاتُ لِلَّهِ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُ اللَّهِ وَرَسُولُهُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ السَّلاَمُ عَلَيْكُمْ ‏.‏\hadithno{205}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said al-Ansari that al-Qasim ibn Muhammad ibn Muhammad told him that A'isha, the wife of the prophet, may Allah bless him and grant him peace, used to say in the tashahhud, "Greetings, good words, prayers, pure actions belong to Allah. I testify that there is no god except Allah, alone without partner, and I testify that Muhammad is the slave of Allah and His Messenger. Peace be upon you, Prophet, and the mercy of Allah and His blessings. Peace be upon us and on the slaves of Allah who are salihun . Peace be upon you . " "At-tahiyatu, at-tayibatu, as- salawatu, az-zakiyatu lillah. Ash-hadu an la ilaha illa'llah, wahdahu la sharika llah wa ash-hadu anna Muhammadan abduhu wa rasuluhu. As- salamu alayka ayyuha-n-nabiyyu wa rahmatu-llahi wa barakatuhu. As- salamu alayna wa ala ibadi-llahi's-salihin. As-salamu alaykum}}
\hadithdefcmd{malik}{206}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَأَلَ ابْنَ شِهَابٍ وَنَافِعًا مَوْلَى ابْنِ عُمَرَ عَنْ رَجُلٍ، دَخَلَ مَعَ الإِمَامِ فِي الصَّلاَةِ وَقَدْ سَبَقَهُ الإِمَامُ بِرَكْعَةٍ أَيَتَشَهَّدُ مَعَهُ فِي الرَّكْعَتَيْنِ وَالأَرْبَعِ وَإِنْ كَانَ ذَلِكَ لَهُ وِتْرًا فَقَالاَ لِيَتَشَهَّدْ مَعَهُ ‏.‏ قَالَ مَالِكٌ وَهُوَ الأَمْرُ عِنْدَنَا ‏.‏\hadithno{206}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he asked Ibn Shihab and Nafi, the mawla of Ibn Umar, whether a man who joined an imam who had already done a raka should say the tashahhud with the imam in the second and fourth rakas, even though these were odd for him? They said, "He should say tashahhud with him." Malik said, "That is the position with us}}
\hadithdefcmd{malik}{207}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَلْقَمَةَ، عَنْ مَلِيحِ بْنِ عَبْدِ اللَّهِ السَّعْدِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ الَّذِي يَرْفَعُ رَأْسَهُ وَيَخْفِضُهُ قَبْلَ الإِمَامِ فَإِنَّمَا نَاصِيَتُهُ بِيَدِ شَيْطَانٍ ‏.‏\hadithno{207}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Muhammad ibn Amr ibn AIqama from Malik ibn Abdullah as-Sadi that Abu Hurayra said, "The one who raises his head and lowers it before the imam - his forelock is in the hand of a shaytan." Malik said, concerning someone who forgot and raised his head before the imam in ruku or sujud, "The sunna of that is to return to bowing or prostrating and not to wait for the imam to come up. What he has done is a mistake, because the Messenger of Allah, may Allah bless him and grant him peace, said, 'The imam is appointed to be followed as a leader, so do not oppose him.' Abu Hurayra said, 'The one who raises his head and lowers it before the imam - his forelock is in the hand of a shaytan}}
\hadithdefcmd{malik}{208}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَيُّوبَ بْنِ أَبِي تَمِيمَةَ السَّخْتِيَانِيِّ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم انْصَرَفَ مِنَ اثْنَتَيْنِ فَقَالَ لَهُ ذُو الْيَدَيْنِ أَقَصُرَتِ الصَّلاَةُ أَمْ نَسِيتَ يَا رَسُولَ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَصَدَقَ ذُو الْيَدَيْنِ ‏"‏ ‏.‏ فَقَالَ النَّاسُ نَعَمْ ‏.‏ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى رَكْعَتَيْنِ أُخْرَيَيْنِ ثُمَّ سَلَّمَ ثُمَّ كَبَّرَ فَسَجَدَ مِثْلَ سُجُودِهِ أَوْ أَطْوَلَ ثُمَّ رَفَعَ ثُمَّ كَبَّرَ فَسَجَدَ مِثْلَ سُجُودِهِ أَوْ أَطْوَلَ ثُمَّ رَفَعَ ‏.‏\hadithno{208}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ayyub ibn Abi Tamima as- Sakhtayani from Muhammad ibn Sirin from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, finished the prayer after two rakas and Dhu'l-Yadayn said to him, "Has the prayer been shortened or have you forgotten, Messenger of Allah?" The Messenger of Allah, may Allah bless him and grant him peace, said, "Has Dhu'l-Yadayn spoken the truth?" The people said, "Yes," and the Messenger of Allah, may Allah bless him and grant him peace, stood and prayed the other two rakas and then said, "Peace be upon you." Then he said, "Allah is greater" and went into a sadja as long as his usual prostrations or longer. Then he came up and said, "Allah is greater" and went into a sajda as long as his usual prostrations or longer and then came up}}
\hadithdefcmd{malik}{209}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ أَبِي سُفْيَانَ، مَوْلَى ابْنِ أَبِي أَحْمَدَ أَنَّهُ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْعَصْرِ فَسَلَّمَ فِي رَكْعَتَيْنِ فَقَامَ ذُو الْيَدَيْنِ فَقَالَ أَقَصُرَتِ الصَّلاَةُ يَا رَسُولَ اللَّهِ أَمْ نَسِيتَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُلُّ ذَلِكَ لَمْ يَكُنْ ‏"‏ ‏.‏ فَقَالَ قَدْ كَانَ بَعْضُ ذَلِكَ يَا رَسُولَ اللَّهِ ‏.‏ فَأَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى النَّاسِ فَقَالَ ‏"‏ أَصَدَقَ ذُو الْيَدَيْنِ ‏"‏ ‏.‏ فَقَالُوا نَعَمْ ‏.‏ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَتَمَّ مَا بَقِيَ مِنَ الصَّلاَةِ ثُمَّ سَجَدَ سَجْدَتَيْنِ بَعْدَ التَّسْلِيمِ وَهُوَ جَالِسٌ ‏.‏\hadithno{209}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Da'ud ibn al-Husayn that Abu Sufyan, the mawla of Ibn Abi Ahmad, said that he heard Abu Hurayra say, "The Messenger of Allah, may Allah bless him and grant him peace, prayed asr and said the taslim after two rakas. Dhu'l-Yadayn stood up and said, 'Has the prayer been shortened, Messenger of Allah, or have you forgotten?' The Messenger of Allah, may Allah bless him and grant him peace, stood up and completed what remained of the prayer, and then, remaining sitting after saying the taslim, he made two prostrations}}
\hadithdefcmd{malik}{210}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ سُلَيْمَانَ بْنِ أَبِي حَثْمَةَ، قَالَ بَلَغَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَكَعَ رَكْعَتَيْنِ مِنْ إِحْدَى صَلاَتَىِ النَّهَارِ - الظُّهْرِ أَوِ الْعَصْرِ - فَسَلَّمَ مِنَ اثْنَتَيْنِ فَقَالَ لَهُ ذُو الشِّمَالَيْنِ أَقَصُرَتِ الصَّلاَةُ يَا رَسُولَ اللَّهِ أَمْ نَسِيتَ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا قَصُرَتِ الصَّلاَةُ وَمَا نَسِيتُ ‏"‏ ‏.‏ فَقَالَ ذُو الشِّمَالَيْنِ قَدْ كَانَ بَعْضُ ذَلِكَ يَا رَسُولَ اللَّهِ ‏.‏ فَأَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى النَّاسِ فَقَالَ ‏"‏ أَصَدَقَ ذُو الْيَدَيْنِ ‏"‏ ‏.‏ فَقَالُوا نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ فَأَتَمَّ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا بَقِيَ مِنَ الصَّلاَةِ ثُمَّ سَلَّمَ ‏.‏\hadithno{210}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Abu Bakr ibn Sulayman ibn Abi Hathma said, "I have heard that the Messenger of Allah, may Allah bless him and grant him peace, prayed two rakas of one of the two day-ti me prayers, dhuhr or asr, and said the taslim after two rakas. Dhu'sh-Shamalayn said to him, 'Has the prayer been shortened, Messenger of Allah, or have you forgotten?' The Messenger of Allah, may Allah bless him and grant him peace, said, 'The prayer has not been shortened and I have not forgotten.' Dhu'shShamalayn said, 'It was certainly one of those, Messenger of Allah.' The Messenger of Allah, may Allah bless him and grant him peace, approached the people and said, 'Has Dh u'sh-Shamalayn spoken the truth?' They said, 'Yes, Messenger of Allah,' and the Messenger of Allah, may Allah bless him and grant him peace, completed what remained of the prayer, and then said, 'Peace be upon you}}
\hadithdefcmd{malik}{211}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَعَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، مِثْلَ ذَلِكَ ‏.‏ قَالَ مَالِكٌ كُلُّ سَهْوٍ كَانَ نُقْصَانًا مِنَ الصَّلاَةِ فَإِنَّ سُجُودَهُ قَبْلَ السَّلاَمِ وَكُلُّ سَهْوٍ كَانَ زِيَادَةً فِي الصَّلاَةِ فَإِنَّ سُجُودَهُ بَعْدَ السَّلاَمِ ‏.‏\hadithno{211}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Said ibn al- Musayyab, and from Abu Salama ibn Abd ar-Rahman, the same as that. Malik said, "Every forgetfulness which decreases from the prayer, prostrations for it come before the greeting, and every forgetfulness which is an addition to the prayer, prostrations for it come after the greeting}}
\hadithdefcmd{malik}{212}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا شَكَّ أَحَدُكُمْ فِي صَلاَتِهِ فَلَمْ يَدْرِ كَمْ صَلَّى أَثَلاَثًا أَمْ أَرْبَعًا فَلْيُصَلِّي رَكْعَةً وَلْيَسْجُدْ سَجْدَتَيْنِ وَهُوَ جَالِسٌ قَبْلَ التَّسْلِيمِ فَإِنْ كَانَتِ الرَّكْعَةُ الَّتِي صَلَّى خَامِسَةً شَفَعَهَا بِهَاتَيْنِ السَّجْدَتَيْنِ وَإِنْ كَانَتْ رَابِعَةً فَالسَّجْدَتَانِ تَرْغِيمٌ لِلشَّيْطَانِ ‏"‏ ‏.‏\hadithno{212}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar that the Messenger of Allah, may Allah bless him and grant him peace, said, "If you are uncertain in the prayer and do not know whether you have prayed three or four rakas, then pray a raka and make two prostrations from the sitting position before the taslim. If the raka that you prayed was the fifth, then you make it even by these two sajdas, and if it was the fourth, then the two prostrations spite Shaytan}}
\hadithdefcmd{malik}{213}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عُمَرَ بْنِ مُحَمَّدِ بْنِ زَيْدٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ إِذَا شَكَّ أَحَدُكُمْ فِي صَلاَتِهِ فَلْيَتَوَخَّ الَّذِي يَظُنُّ أَنَّهُ نَسِيَ مِنْ صَلاَتِهِ فَلْيُصَلِّهِ ثُمَّ لِيَسْجُدْ سَجْدَتَىِ السَّهْوِ وَهُوَ جَالِسٌ ‏.‏\hadithno{213}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Umar ibn Muhammad ibn Zayd from Salim ibn Abdullah that Abdullah ibn Umar used to say, "If you are uncertain in the prayer, estimate what you think you have forgotten of the prayer and repeat it, then do the two sajdas of forgetfulness from the sitting position}}
\hadithdefcmd{malik}{214}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَفِيفِ بْنِ عَمْرٍو السَّهْمِيِّ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّهُ قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ وَكَعْبَ الأَحْبَارِ عَنِ الَّذِي، يَشُكُّ فِي صَلاَتِهِ فَلاَ يَدْرِي كَمْ صَلَّى أَثَلاَثًا أَمْ أَرْبَعًا فَكِلاَهُمَا قَالَ لِيُصَلِّي رَكْعَةً أُخْرَى ثُمَّ لِيَسْجُدْ سَجْدَتَيْنِ وَهُوَ جَالِسٌ ‏.‏\hadithno{214}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Afif ibn Amr as-Sahmi that Ata ibn Yasar said, "I asked Abdullah ibn Amr ibn al-As and Kab al Ahbar about someone who was uncertain in his prayer, and did not know whether he had prayed three or four rakas. Both of them said, 'He should pray another raka and then do two sajdas from the sitting position}}
\hadithdefcmd{malik}{215}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا سُئِلَ عَنِ النِّسْيَانِ، فِي الصَّلاَةِ قَالَ لِيَتَوَخَّ أَحَدُكُمُ الَّذِي يَظُنُّ أَنَّهُ نَسِيَ مِنْ صَلاَتِهِ فَلْيُصَلِّهِ ‏.‏\hadithno{215}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar, when questioned about forgetfulness in the prayer, said, "If you think that you have forgotten part of the prayer, then pray it}}
\hadithdefcmd{malik}{216}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنِ الأَعْرَجِ، عَنْ عَبْدِ اللَّهِ ابْنِ بُحَيْنَةَ، أَنَّهُ قَالَ صَلَّى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَتَيْنِ ثُمَّ قَامَ فَلَمْ يَجْلِسْ فَقَامَ النَّاسُ مَعَهُ فَلَمَّا قَضَى صَلاَتَهُ وَنَظَرْنَا تَسْلِيمَهُ كَبَّرَ ثُمَّ سَجَدَ سَجْدَتَيْنِ وَهُوَ جَالِسٌ قَبْلَ التَّسْلِيمِ ثُمَّ سَلَّمَ ‏.‏\hadithno{216}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from al-Araj that Abdullah ibn Buhayna said, "The Messenger of Allah, may Allah bless him and grant him peace, prayed two rakas with us and then stood without sitting and the people stood with him. When he had finished the prayerand we had seen him say the taslim, he said 'Allah is greater' and did two sajdas from the sitting position and then said the taslim again}}
\hadithdefcmd{malik}{217}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ عَبْدِ اللَّهِ ابْنِ بُحَيْنَةَ، أَنَّهُ قَالَ صَلَّى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم الظُّهْرَ فَقَامَ فِي اثْنَتَيْنِ وَلَمْ يَجْلِسْ فِيهِمَا فَلَمَّا قَضَى صَلاَتَهُ سَجَدَ سَجْدَتَيْنِ ثُمَّ سَلَّمَ بَعْدَ ذَلِكَ ‏.‏\hadithno{217}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Abd ar- Rahman ibn Hurmuz that Abdullah ibn Buhayna said, "The Messengerof Allah, may Allah bless him and grant him peace, prayed dhuhr with us and he stood straight up after two rakas without sitting. When he had finished the prayer, he did two sajdas and then said the taslim after that." Malik said, concerning someone who forgot in his prayer and stood up after he had completed four rakas and recited and then went into ruku and then, when he raised his head from ruku, remembered that he had already completed (his prayer), "He returns to a sitting position and does not do any sajda. If he has already done one sajda I do not think he should do the other. Then when his prayer is finished he does two sajdas from the sitting position after saying the taslim}}
\hadithdefcmd{malik}{218}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَلْقَمَةَ بْنِ أَبِي عَلْقَمَةَ، عَنْ أُمِّهِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ أَهْدَى أَبُو جَهْمِ بْنُ حُذَيْفَةَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم خَمِيصَةً شَامِيَّةً لَهَا عَلَمٌ فَشَهِدَ فِيهَا الصَّلاَةَ فَلَمَّا انْصَرَفَ قَالَ ‏ "‏ رُدِّي هَذِهِ الْخَمِيصَةَ إِلَى أَبِي جَهْمٍ فَإِنِّي نَظَرْتُ إِلَى عَلَمِهَا فِي الصَّلاَةِ فَكَادَ يَفْتِنُنِي ‏"‏ ‏.‏\hadithno{218}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik from AIqama ibn Abi AIqama from his mother that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "Abu Jahm ibn Hudhayfa gave the Messenger of Allah, may Allah bless him and grant him peace, a fine striped garment from Syria and he did the prayer in it. When he had finished he said, 'Give this garment back to Abu Jahm. I lookedat its stripes in the prayer and they almost distracted me}}
\hadithdefcmd{malik}{219}{وَحَدَّثَنِي مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَبِسَ خَمِيصَةً شَامِيَّةً لَهَا عَلَمٌ ثُمَّ أَعْطَاهَا أَبَا جَهْمٍ وَأَخَذَ مِنْ أَبِي جَهْمٍ أَنْبِجَانِيَّةً لَهُ فَقَالَ يَا رَسُولَ اللَّهِ وَلِمَ فَقَالَ ‏ "‏ إِنِّي نَظَرْتُ إِلَى عَلَمِهَا فِي الصَّلاَةِ ‏"‏ ‏.‏\hadithno{219}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Hisham ibn Urwa from his father that the Messenger of Allah, may Allah bless him and grant him peace, wore a fine striped garment f rom Syria, and then gave it to Abu Jahm and took a plain, rough, garment in return. Abu Jahm asked, "Messenger of Allah! Why?" He said, "I looked at its stripes in the prayer}}
\hadithdefcmd{malik}{220}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، أَنَّ أَبَا طَلْحَةَ الأَنْصَارِيَّ، كَانَ يُصَلِّي فِي حَائِطِهِ فَطَارَ دُبْسِيٌّ فَطَفِقَ يَتَرَدَّدُ يَلْتَمِسُ مَخْرَجًا فَأَعْجَبَهُ ذَلِكَ فَجَعَلَ يُتْبِعُهُ بَصَرَهُ سَاعَةً ثُمَّ رَجَعَ إِلَى صَلاَتِهِ فَإِذَا هُوَ لاَ يَدْرِي كَمْ صَلَّى فَقَالَ لَقَدْ أَصَابَتْنِي فِي مَالِي هَذَا فِتْنَةٌ ‏.‏ فَجَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ لَهُ الَّذِي أَصَابَهُ فِي حَائِطِهِ مِنَ الْفِتْنَةِ وَقَالَ يَا رَسُولَ اللَّهِ هُوَ صَدَقَةٌ لِلَّهِ فَضَعْهُ حَيْثُ شِئْتَ ‏.‏\hadithno{220}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Malik related to me from Abdullah ibn Abi Bakr that Abu Talha al- Ansari was praying in his garden when a wild pigeon flew in and began to fly to and fro trying to find a way out. The sight was pleasing to him and he let his eyes follow the bird for a time and then he went back to his prayer but could not remember how much he had prayed. He said, "A trial has befallen me in this property of mine." So he came to the Messenger of Allah, may Allah bless him and grant him peace, and mentioned the trial that had happened to him in his garden and said, "Messenger of Allah, it is a sadaqa for Allah, so dispose of it wherever you wish}}
\hadithdefcmd{malik}{221}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ كَانَ يُصَلِّي فِي حَائِطٍ لَهُ بِالْقُفِّ - وَادٍ مِنْ أَوْدِيَةِ الْمَدِينَةِ - فِي زَمَانِ الثَّمَرِ وَالنَّخْلُ قَدْ ذُلِّلَتْ فَهِيَ مُطَوَّقَةٌ بِثَمَرِهَا فَنَظَرَ إِلَيْهَا فَأَعْجَبَهُ مَا رَأَى مِنْ ثَمَرِهَا ثُمَّ رَجَعَ إِلَى صَلاَتِهِ فَإِذَا هُوَ لاَ يَدْرِي كَمْ صَلَّى فَقَالَ لَقَدْ أَصَابَتْنِي فِي مَالِي هَذَا فِتْنَةٌ ‏.‏ فَجَاءَ عُثْمَانَ بْنَ عَفَّانَ - وَهُوَ يَوْمَئِذٍ خَلِيفَةٌ - فَذَكَرَ لَهُ ذَلِكَ وَقَالَ هُوَ صَدَقَةٌ فَاجْعَلْهُ فِي سُبُلِ الْخَيْرِ ‏.‏ فَبَاعَهُ عُثْمَانُ بْنُ عَفَّانَ بِخَمْسِينَ أَلْفًا فَسُمِّيَ ذَلِكَ الْمَالُ الْخَمْسِينَ ‏.‏\hadithno{221}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr that a man from the Ansar was praying in a garden of his in Quff, one of the valleys of Madina, during the date season and the palms' branches were weighed down with fruit on all sides. He looked at them and what he saw of their fruits amazed him. Then he went back to his prayer and he did not know how much he had prayed. He said, "A trial has befallen me in this property of mine." So he went toUthman ibn Affan, who was the khalifa at the time, and mentioned it to him and said, "It is sadaqa, so give it away in the paths of good." Uthman ibn Affan sold it for fifty thousand and so that property became known as the Fifty}}
