% Auto-generated chapter 17 for bukhari
% Hadiths in this chapter: 13

\hadithdefcmd{bukhari}{1067}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا غُنْدَرٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الأَسْوَدَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَرَأَ النَّبِيُّ صلى الله عليه وسلم النَّجْمَ بِمَكَّةَ فَسَجَدَ فِيهَا، وَسَجَدَ مَنْ مَعَهُ، غَيْرَ شَيْخٍ أَخَذَ كَفًّا مِنْ حَصًى أَوْ تُرَابٍ فَرَفَعَهُ إِلَى جَبْهَتِهِ وَقَالَ يَكْفِينِي هَذَا‏.‏ فَرَأَيْتُهُ بَعْدَ ذَلِكَ قُتِلَ كَافِرًا‏.‏\hadithno{1067}\hadithtrans{Narrated `Abdullah bin Mas`ud:The Prophet (ﷺ) recited Surat an-Najm (53) at Mecca and prostrated while reciting it and those who were with him did the same except an old man who took a handful of small stones or earth and lifted it to his forehead and said, "This is sufficient for me." Later on, I saw him killed as a non-believer}}
\hadithdefcmd{bukhari}{1068}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ فِي الْجُمُعَةِ فِي صَلاَةِ الْفَجْرِ ‏\{‏الم * تَنْزِيلُ‏\}‏ السَّجْدَةَ وَ‏\{‏هَلْ أَتَى عَلَى الإِنْسَانِ‏\}‏\hadithno{1068}\hadithtrans{Narrated Abu Huraira:On Fridays the Prophet (ﷺ) used to recite Alif Lam Mim Tanzil-As-Sajda (in the first rak`a) and Hal ata `alal-insani i.e. Surat ad-Dahr (LXXVI) (in the second rak`a), in the Fajr prayer}}
\hadithdefcmd{bukhari}{1069}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَأَبُو النُّعْمَانِ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ ‏\{‏ص‏\}‏ لَيْسَ مِنْ عَزَائِمِ السُّجُودِ، وَقَدْ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَسْجُدُ فِيهَا‏.‏\hadithno{1069}\hadithtrans{Narrated Ibn `Abbas:The prostration of Sa`d is not a compulsory one but I saw the Prophet (ﷺ) prostrating while reciting it}}
\hadithdefcmd{bukhari}{1070}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَرَأَ سُورَةَ النَّجْمِ فَسَجَدَ بِهَا، فَمَا بَقِيَ أَحَدٌ مِنَ الْقَوْمِ إِلاَّ سَجَدَ، فَأَخَذَ رَجُلٌ مِنَ الْقَوْمِ كَفًّا مِنْ حَصًى أَوْ تُرَابٍ، فَرَفَعَهُ إِلَى وَجْهِهِ وَقَالَ يَكْفِينِي هَذَا، فَلَقَدْ رَأَيْتُهُ بَعْدُ قُتِلَ كَافِرًا‏.‏\hadithno{1070}\hadithtrans{Narrated `Abdullah bin Mas`ud:The Prophet (ﷺ) recited Surat-an-Najm (53) and prostrated while reciting it and all the people prostrated and a man amongst the people took a handful of stones or earth and raised it to his face and said, "This is sufficient for me." Later on I saw him killed as a non-believer}}
\hadithdefcmd{bukhari}{1071}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما أَنَّ النَّبِيَّ صلى الله عليه وسلم سَجَدَ بِالنَّجْمِ وَسَجَدَ مَعَهُ الْمُسْلِمُونَ وَالْمُشْرِكُونَ وَالْجِنُّ وَالإِنْسُ‏.‏ وَرَوَاهُ ابْنُ طَهْمَانَ عَنْ أَيُّوبَ‏.‏\hadithno{1071}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) prostrated while reciting An-Najm and with him prostrated the Muslims, the pagans, the jinns, and all human beings}}
\hadithdefcmd{bukhari}{1072}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ أَبُو الرَّبِيعِ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، قَالَ أَخْبَرَنَا يَزِيدُ بْنُ خُصَيْفَةَ، عَنِ ابْنِ قُسَيْطٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّهُ أَخْبَرَهُ، أَنَّهُ، سَأَلَ زَيْدَ بْنَ ثَابِتٍ ـ رضى الله عنه ـ فَزَعَمَ أَنَّهُ قَرَأَ عَلَى النَّبِيِّ صلى الله عليه وسلم ‏\{‏وَالنَّجْمِ‏\}‏ فَلَمْ يَسْجُدْ فِيهَا‏.‏\hadithno{1072}\hadithtrans{Narrated `Ata' bin Yasar:I asked Zaid bin Thabit about prostration on which he said that he had recited An-Najm before the Prophet, yet he (the Prophet) had not performed a prostration}}
\hadithdefcmd{bukhari}{1073}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ عَبْدِ اللَّهِ بْنِ قُسَيْطٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ قَرَأْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم ‏\{‏وَالنَّجْمِ‏\}‏ فَلَمْ يَسْجُدْ فِيهَا‏.‏\hadithno{1073}\hadithtrans{Narrated Zaid bin Thabit:I recited An-Najm before the Prophet, yet he did not perform a prostration}}
\hadithdefcmd{bukhari}{1074}{حَدَّثَنَا مُسْلِمٌ، وَمُعَاذُ بْنُ فَضَالَةَ، قَالاَ أَخْبَرَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، قَالَ رَأَيْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَرَأَ ‏\{‏إِذَا السَّمَاءُ انْشَقَّتْ‏\}‏ فَسَجَدَ بِهَا فَقُلْتُ يَا أَبَا هُرَيْرَةَ، أَلَمْ أَرَكَ تَسْجُدُ قَالَ لَوْ لَمْ أَرَ النَّبِيَّ صلى الله عليه وسلم يَسْجُدُ لَمْ أَسْجُدْ‏.‏\hadithno{1074}\hadithtrans{Narrated Abu Salama:I saw Abu Huraira reciting Idha-Sama' un-Shaqqat and he prostrated during its recitation. I asked Abu Huraira, "Didn't I see you prostrating?" Abu Huraira said, "Had I not seen the Prophet (ﷺ) prostrating, I would not have prostrated}}
\hadithdefcmd{bukhari}{1075}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ عَلَيْنَا السُّورَةَ فِيهَا السَّجْدَةُ، فَيَسْجُدُ وَنَسْجُدُ، حَتَّى مَا يَجِدُ أَحَدُنَا مَوْضِعَ جَبْهَتِهِ‏.‏\hadithno{1075}\hadithtrans{Narrated Ibn `Umar:When the Prophet (ﷺ) recited a Sura that contained the prostration he would prostrate and we would do the same and some of us (because of the heavy rush) could not find a place for prostration}}
\hadithdefcmd{bukhari}{1076}{حَدَّثَنَا بِشْرُ بْنُ آدَمَ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، قَالَ أَخْبَرَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ السَّجْدَةَ وَنَحْنُ عِنْدَهُ فَيَسْجُدُ وَنَسْجُدُ مَعَهُ فَنَزْدَحِمُ حَتَّى مَا يَجِدُ أَحَدُنَا لِجَبْهَتِهِ مَوْضِعًا يَسْجُدُ عَلَيْهِ‏.‏\hadithno{1076}\hadithtrans{Narrated Ibn `Umar:When the Prophet (ﷺ) recited Surat As-Sajda and we were with him, he would prostrate and we also would prostrate with him and some of us (because of the heavy rush) would not find a place (for our foreheads) to prostrate on}}
\hadithdefcmd{bukhari}{1077}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، قَالَ أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي أَبُو بَكْرِ بْنُ أَبِي مُلَيْكَةَ، عَنْ عُثْمَانَ بْنِ عَبْدِ الرَّحْمَنِ التَّيْمِيِّ، عَنْ رَبِيعَةَ بْنِ عَبْدِ اللَّهِ بْنِ الْهُدَيْرِ التَّيْمِيِّ ـ قَالَ أَبُو بَكْرٍ وَكَانَ رَبِيعَةُ مِنْ خِيَارِ النَّاسِ عَمَّا حَضَرَ رَبِيعَةُ مِنْ عُمَرَ بْنِ الْخَطَّابِ ـ رضى الله عنه ـ قَرَأَ يَوْمَ الْجُمُعَةِ عَلَى الْمِنْبَرِ بِسُورَةِ النَّحْلِ حَتَّى إِذَا جَاءَ السَّجْدَةَ نَزَلَ فَسَجَدَ وَسَجَدَ النَّاسُ، حَتَّى إِذَا كَانَتِ الْجُمُعَةُ الْقَابِلَةُ قَرَأَ بِهَا حَتَّى إِذَا جَاءَ السَّجْدَةَ قَالَ يَا أَيُّهَا النَّاسُ إِنَّا نَمُرُّ بِالسُّجُودِ فَمَنْ سَجَدَ فَقَدْ أَصَابَ، وَمَنْ لَمْ يَسْجُدْ فَلاَ إِثْمَ عَلَيْهِ‏.‏ وَلَمْ يَسْجُدْ عُمَرُ ـ رضى الله عنه‏.‏ وَزَادَ نَافِعٌ عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما إِنَّ اللَّهَ لَمْ يَفْرِضِ السُّجُودَ إِلاَّ أَنْ نَشَاءَ‏.‏\hadithno{1077}\hadithtrans{Narrated Rabi`a:`Umar bin Al-Khattab recited Surat-an-Nahl on a Friday on the pulpit and when he reached the verse of Sajda he got down from the pulpit and prostrated and the people also prostrated. The next Friday `Umar bin Al-Khattab recited the same Sura and when he reached the verse of Sajda he said, "O people! When we recite the verses of Sajda (during the sermon) whoever prostrates does the right thing, yet it is no sin for the one who does not prostrate." And `Umar did not prostrate (that day). Added Ibn `Umar "Allah has not made the prostration of recitation compulsory but if we wish we can do it}}
\hadithdefcmd{bukhari}{1078}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي قَالَ، حَدَّثَنِي بَكْرٌ، عَنْ أَبِي رَافِعٍ، قَالَ صَلَّيْتُ مَعَ أَبِي هُرَيْرَةَ الْعَتَمَةَ فَقَرَأَ ‏\{‏إِذَا السَّمَاءُ انْشَقَّتْ‏\}‏ فَسَجَدَ فَقُلْتُ مَا هَذِهِ قَالَ سَجَدْتُ بِهَا خَلْفَ أَبِي الْقَاسِمِ صلى الله عليه وسلم فَلاَ أَزَالُ أَسْجُدُ فِيهَا حَتَّى أَلْقَاهُ‏.‏\hadithno{1078}\hadithtrans{Narrated Abu Rafi`:I offered the `Isha' prayer behind Abu Huraira and he recited Idhas-Sama' Un-Shaqqat, and prostrated. I said, "What is this?" Abu Huraira said, "I prostrated behind Abul-Qasim and I will do the same till I meet him}}
\hadithdefcmd{bukhari}{1079}{حَدَّثَنَا صَدَقَةُ، قَالَ أَخْبَرَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ السُّورَةَ الَّتِي فِيهَا السَّجْدَةُ فَيَسْجُدُ وَنَسْجُدُ حَتَّى مَا يَجِدُ أَحَدُنَا مَكَانًا لِمَوْضِعِ جَبْهَتِهِ‏.‏\hadithno{1079}\hadithtrans{Narrated Ibn `Umar.:Whenever the Prophet (ﷺ) recited the Sura which contained the prostration of recitation he used to prostrate and then we too, would prostrate and some of us did not find a place for prostration}}
