% Auto-generated chapter 2 for ibnmajah
% Hadiths in this chapter: 39

\hadithdefcmd{ibnmajah}{667}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَأَحْمَدُ بْنُ سِنَانٍ، قَالاَ حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، أَنْبَأَنَا سُفْيَانُ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، حَدَّثَنَا مَخْلَدُ بْنُ يَزِيدَ، عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَسَأَلَهُ عَنْ وَقْتِ الصَّلاَةِ فَقَالَ ‏"‏ صَلِّ مَعَنَا هَذَيْنِ الْيَوْمَيْنِ ‏"‏ ‏.‏ فَلَمَّا زَالَتِ الشَّمْسُ أَمَرَ بِلاَلاً فَأَذَّنَ ثُمَّ أَمَرَهُ فَأَقَامَ الظُّهْرَ ثُمَّ أَمَرَهُ فَأَقَامَ الْعَصْرَ وَالشَّمْسُ مُرْتَفِعَةٌ بَيْضَاءُ نَقِيَّةٌ ثُمَّ أَمَرَهُ فَأَقَامَ الْمَغْرِبَ حِينَ غَابَتِ الشَّمْسُ ثُمَّ أَمَرَهُ فَأَقَامَ الْعِشَاءَ حِينَ غَابَ الشَّفَقُ ثُمَّ أَمَرَهُ فَأَقَامَ الْفَجْرَ حِينَ طَلَعَ الْفَجْرُ فَلَمَّا كَانَ مِنَ الْيَوْمِ الثَّانِي أَمَرَهُ فَأَذَّنَ الظُّهْرَ فَأَبْرَدَ بِهَا وَأَنْعَمَ أَنْ يُبْرِدَ بِهَا ثُمَّ صَلَّى الْعَصْرَ وَالشَّمْسُ مُرْتَفِعَةٌ أَخَّرَهَا فَوْقَ الَّذِي كَانَ وَصَلَّى الْمَغْرِبَ قَبْلَ أَنْ يَغِيبَ الشَّفَقُ وَصَلَّى الْعِشَاءَ بَعْدَمَا ذَهَبَ ثُلُثُ اللَّيْلِ وَصَلَّى الْفَجْرَ فَأَسْفَرَ بِهَا ثُمَّ قَالَ ‏"‏ أَيْنَ السَّائِلُ عَنْ وَقْتِ الصَّلاَةِ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ وَقْتُ صَلاَتِكُمْ بَيْنَ مَا رَأَيْتُمْ ‏"‏ ‏.‏\hadithno{667}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Sulaiman bin Buraidah that his father said:"A man came to the Prophet and asked him about the times of the prayer. He said: 'Pray with us for two days.' When the sun passed its zenith he commanded Bilal to call the Adhan, then he commanded him to give the Iqamah for Zuhr; then he commanded him to give the Iqamah for 'Asr when the sun was high and clearly white. Then he commanded him to give the Iqamah for Maghrib when the sun had set; then he commanded him to give the Iqamah for 'Isha' when the red afterglow had disappeared; then he commanded him to give the Iqamah for Fajr when dawn came. On the following day he commanded him to give the Adhan for Zuhr when the extreme heat had passed and it had cooled down; then he prayed 'Asr when the sun was still high, but he delayed it more than he had done the day before; then he prayed Maghrib before the red afterglow disappeared; he prayed 'Isha' when one-third of the night had passed; and he prayed Fajr at the time when it was already light. Then he said: 'Where is the one who was asking about the times of Prayer?' The man said: 'Here I am, O Messenger of Allah.' He said: 'The times of your prayer are between the times you have seen}}
\hadithdefcmd{ibnmajah}{668}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ كَانَ قَاعِدًا عَلَى مَيَاثِرِ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ فِي إِمَارَتِهِ عَلَى الْمَدِينَةِ وَمَعَهُ عُرْوَةُ بْنُ الزُّبَيْرِ فَأَخَّرَ عُمَرُ الْعَصْرَ شَيْئًا فَقَالَ لَهُ عُرْوَةُ أَمَا إِنَّ جِبْرِيلَ نَزَلَ فَصَلَّى إِمَامَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ فَقَالَ لَهُ عُمَرُ اعْلَمْ مَا تَقُولُ يَا عُرْوَةُ ‏.‏ قَالَ سَمِعْتُ بَشِيرَ بْنَ أَبِي مَسْعُودٍ يَقُولُ سَمِعْتُ أَبَا مَسْعُودٍ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ نَزَلَ جِبْرِيلُ فَأَمَّنِي فَصَلَّيْتُ مَعَهُ ثُمَّ صَلَّيْتَ مَعَهُ ثُمَّ صَلَّيْتُ مَعَهُ ثُمَّ صَلَّيْتُ مَعَهُ ثُمَّ صَلَّيْتُ مَعَهُ ‏"‏ ‏.‏ يَحْسُبُ بِأَصَابِعِهِ خَمْسَ صَلَوَاتٍ ‏.‏\hadithno{668}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Ibn Shihab that:He was sitting on the cushions of 'Umar bin 'Abdul-'Aziz when he was the leader over Al-Madinah, and with him was 'Urwah bin Zubair. "umar delayed 'Asr somewhat, and 'Urwah said to him: "Jibril came down and led the Messenger of Allah in prayer." 'Umar said to him: "Know what you are saying, O 'Urwah!" he said: "I heard Bashir bin Abu Mas'ud saying, 'I heard Abu Mas'ud saying, "I heard the Messenger of Allah saying, 'Jibril came down and led me in prayer, and I prayed with him, then I prayed with him, then I prayed with him, then I prayed with him, then I prayed with him,' and he counted five prayers on his fingers}}
\hadithdefcmd{ibnmajah}{669}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنَّ نِسَاءُ الْمُؤْمِنَاتِ يُصَلِّينَ مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ صَلاَةَ الصُّبْحِ ثُمَّ يَرْجِعْنَ إِلَى أَهْلِهِنَّ فَلاَ يَعْرِفُهُنَّ أَحَدٌ ‏.‏ تَعْنِي مِنَ الْغَلَسِ ‏.‏\hadithno{669}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The believing women used to perform the Subh prayer with the Prophet, then they would go back to their families and no one would recognize them," meaning of the darkness}}
\hadithdefcmd{ibnmajah}{670}{حَدَّثَنَا عُبَيْدُ بْنُ أَسْبَاطِ بْنِ مُحَمَّدٍ الْقُرَشِيُّ، حَدَّثَنَا أَبِي، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ اللَّهِ، وَالأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ \{وَقُرْآنَ الْفَجْرِ إِنَّ قُرْآنَ الْفَجْرِ كَانَ مَشْهُودًا\}‏ قَالَ ‏"‏ تَشْهَدُهُ مَلاَئِكَةُ اللَّيْلِ وَالنَّهَارِ ‏"‏ ‏.‏\hadithno{670}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah recited: And recite the Qur'an during the Fajr. Verily, the recitation of the Qur'an during Fajr is ever witnessed." He said: "It is witnessed by the angels of the night and the day}}
\hadithdefcmd{ibnmajah}{671}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا نَهِيكُ بْنُ يَرِيمَ الأَوْزَاعِيُّ، حَدَّثَنَا مُغِيثُ بْنُ سُمَىٍّ، قَالَ صَلَّيْتُ مَعَ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ الصُّبْحَ بِغَلَسٍ فَلَمَّا سَلَّمَ أَقْبَلْتُ عَلَى ابْنِ عُمَرَ فَقُلْتُ مَا هَذِهِ الصَّلاَةُ قَالَ هَذِهِ صَلاَتُنَا كَانَتْ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَبِي بَكْرٍ وَعُمَرَ فَلَمَّا طُعِنَ عُمَرُ أَسْفَرَ بِهَا عُثْمَانُ ‏.‏\hadithno{671}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mughith bin Sumayi said:"I prayed the Subh with 'Abdullah bin Zubair in the darkness, and when he said the Taslim, I turned to Ibn 'Umar and said: 'What is this prayer?' He said: 'This is how we prayed with the Messenger of Allah and with Abu Bakr and 'Umar. When 'Umar was stabbed, 'Uthman delayed it until there was light}}
\hadithdefcmd{ibnmajah}{672}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ عَجْلاَنَ، سَمِعَ عَاصِمَ بْنَ عُمَرَ بْنِ قَتَادَةَ، - وَجَدُّهُ بَدْرِيٌّ - يُخْبِرُ عَنْ مَحْمُودِ بْنِ لَبِيدٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَصْبِحُوا بِالصُّبْحِ فَإِنَّهُ أَعْظَمُ لِلأَجْرِ أَوْ لأَجْرِكُمْ ‏"‏ ‏.‏ ‏.‏\hadithno{672}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Rafi' bin Khadij that:The Prophet said: "Pray the Subh early, for indeed its reward is greater" or "your reward}}
\hadithdefcmd{ibnmajah}{673}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ يُصَلِّي الظُّهْرَ إِذَا دَحَضَتِ الشَّمْسُ ‏.‏\hadithno{673}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin Samurah that:The Prophet used to pray Zuhr when the sun had passed its zenith}}
\hadithdefcmd{ibnmajah}{674}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَوْفِ بْنِ أَبِي جَمِيلَةَ، عَنْ سَيَّارِ بْنِ سَلاَمَةَ، عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يُصَلِّي صَلاَةَ الْهَجِيرِ الَّتِي تَدْعُونَهَا الظُّهْرَ إِذَا دَحَضَتِ الشَّمْسُ ‏.‏\hadithno{674}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Abu Barzah Al-Aslami said:"The Prophet used to pray the Hajir prayer, which you call 'Zuhr', when the sun had passed its zenith}}
\hadithdefcmd{ibnmajah}{675}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي إِسْحَاقَ، عَنْ حَارِثَةَ بْنِ مُضَرِّبٍ الْعَبْدِيِّ، عَنْ خَبَّابٍ، قَالَ شَكَوْنَا إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حَرَّ الرَّمْضَاءِ فَلَمْ يُشْكِنَا ‏.‏ قَالَ الْقَطَّانُ حَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا عَوْفٌ، نَحْوَهُ ‏.‏\hadithno{675}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Khabbab said:"We complained to the Messenger of Allah about the heat of the sunbaked ground, but he did not respond to our complaint." (Sahih)Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{676}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ سُفْيَانَ، عَنْ زَيْدِ بْنِ جُبَيْرٍ، عَنْ خِشْفِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ شَكَوْنَا إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ حَرَّ الرَّمْضَاءِ فَلَمْ يُشْكِنَا ‏.‏\hadithno{676}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"We complained to the Messenger of Allah about the heat of the sunbaked ground, but he did not respond to our complaint}}
\hadithdefcmd{ibnmajah}{677}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا اشْتَدَّ الْحَرُّ فَأَبْرِدُوا بِالصَّلاَةِ فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{677}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'When it is very hot, then wait for it to cool down before you pray, for intense heat is from the flaring up of the Hell-fire}}
\hadithdefcmd{ibnmajah}{678}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا اشْتَدَّ الْحَرُّ فَأَبْرِدُوا بِالظُّهْرِ فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{678}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah said: "When it is very hot, then wait for it to cool down before you pray, for intense heat is from the flaring up of the Hell-fire}}
\hadithdefcmd{ibnmajah}{679}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَبْرِدُوا بِالظُّهْرِ فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{679}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Sa'eed said:"The Messenger of Allah said: 'Wait for it to cool down before you pray, for intense heat is from the flaring up of the Hell-fire}}
\hadithdefcmd{ibnmajah}{680}{حَدَّثَنَا تَمِيمُ بْنُ الْمُنْتَصِرِ الْوَاسِطِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ، عَنْ شَرِيكٍ، عَنْ بَيَانٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ كُنَّا نُصَلِّي مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ صَلاَةَ الظُّهْرِ بِالْهَاجِرَةِ فَقَالَ لَنَا ‏ "‏ أَبْرِدُوا بِالصَّلاَةِ فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏ ‏.‏\hadithno{680}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Mughirah bin Shu'bah said:We were praying Zuhr with the Messenger of Allah at the time of intense heat (i.e., midday when the sun has just passed its zenith) and he said to us, "Wait for it to cool down before you pray, for intense heat is from the flaring up of the Hell-fire}}
\hadithdefcmd{ibnmajah}{681}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عُمَرَ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَبْرِدُوا بِالظُّهْرِ ‏"‏ ‏.‏\hadithno{681}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'Wait for it to cool down before you pray the Zuhr}}
\hadithdefcmd{ibnmajah}{682}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يُصَلِّي الْعَصْرَ وَالشَّمْسُ مُرْتَفِعَةٌ حَيَّةٌ فَيَذْهَبُ الذَّاهِبُ إِلَى الْعَوَالِي وَالشَّمْسُ مُرْتَفِعَةٌ ‏.‏\hadithno{682}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas bin Malik that:The Messenger of Allah used to pray 'Asr when the sun was still hot and high, and if a person were to go to the suburbs (of Al-Madinah) he would be able to reach it while the sun was still hot and high}}
\hadithdefcmd{ibnmajah}{683}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ صَلَّى النَّبِيُّ ـ صلى الله عليه وسلم ـ الْعَصْرَ وَالشَّمْسُ فِي حُجْرَتِي لَمْ يُظْهِرْهَا الْفَىْءُ بَعْدُ ‏.‏\hadithno{683}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Prophet prayed the 'Asr when the sun was shining into my room and there were no shadows yet}}
\hadithdefcmd{ibnmajah}{684}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَاصِمِ بْنِ بَهْدَلَةَ، عَنْ زِرِّ بْنِ حُبَيْشٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ يَوْمَ الْخَنْدَقِ ‏ "‏ مَلأَ اللَّهُ بُيُوتَهُمْ وَقُبُورَهُمْ نَارًا كَمَا شَغَلُونَا عَنِ الصَّلاَةِ الْوُسْطَى ‏"‏ ‏.‏\hadithno{684}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Ali bin Abu Talib that,:On the Day of Khandaq, the Messenger of Allah said: "May Allah fill their houses and graves with fire, just as they distracted us from the middle prayer}}
\hadithdefcmd{ibnmajah}{685}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، ‏.‏ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ الَّذِي تَفُوتُهُ صَلاَةُ الْعَصْرِ فَكَأَنَّمَا وُتِرَ أَهْلُهُ وَمَالُهُ ‏"‏ ‏.‏\hadithno{685}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah said: "The one who misses the 'Asr prayer, it is as if he has been cheated out of his family and wealth}}
\hadithdefcmd{ibnmajah}{686}{حَدَّثَنَا حَفْصُ بْنُ عَمْرٍو، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، ح وَحَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ طَلْحَةَ، عَنْ زُبَيْدٍ، عَنْ مُرَّةَ، عَنْ عَبْدِ اللَّهِ، قَالَ حَبَسَ الْمُشْرِكُونَ النَّبِيَّ ـ صلى الله عليه وسلم ـ عَنْ صَلاَةِ الْعَصْرِ حَتَّى غَابَتِ الشَّمْسُ فَقَالَ ‏ "‏ حَبَسُونَا عَنْ صَلاَةِ الْوُسْطَى مَلأَ اللَّهُ قُبُورَهُمْ وَبُيُوتَهُمْ نَارًا ‏"‏ ‏.‏\hadithno{686}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdullah said:"The idolaters kept the Prophet from the 'Asr prayer until the sun had set. He said: 'They kept us from performing the middle prayer; may Allah fill their graves and their houses with fire}}
\hadithdefcmd{ibnmajah}{687}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا أَبُو النَّجَاشِيِّ، قَالَ سَمِعْتُ رَافِعَ بْنَ خَدِيجٍ، يَقُولُ كُنَّا نُصَلِّي الْمَغْرِبَ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَيَنْصَرِفُ أَحَدُنَا وَإِنَّهُ لَيَنْظُرُ إِلَى مَوَاقِعِ نَبْلِهِ ‏.‏ حَدَّثَنَا أَبُو يَحْيَى الزَّعْفَرَانِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، نَحْوَهُ ‏.‏\hadithno{687}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Najashi said:"I heard Rafi' bin Khadij say: 'We used to perform the Maghrib at the time of the Messenger of Allah, and one of us would be able to see the places where his arrows would land when shot from his bow.'" (Sahih)Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{688}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، أَنَّهُ كَانَ يُصَلِّي مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ الْمَغْرِبَ إِذَا تَوَارَتْ بِالْحِجَابِ ‏.‏\hadithno{688}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Salamah bin Akwa' that:He used to pray the Maghrib with the Messenger of Allah when the sun set}}
\hadithdefcmd{ibnmajah}{689}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَنْبَأَنَا عَبَّادُ بْنُ الْعَوَّامِ، عَنْ عُمَرَ بْنِ إِبْرَاهِيمَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنِ الأَحْنَفِ بْنِ قَيْسٍ، عَنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَزَالُ أُمَّتِي عَلَى الْفِطْرَةِ مَا لَمْ يُؤَخِّرُوا الْمَغْرِبَ حَتَّى تَشْتَبِكَ النُّجُومُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ بْنُ مَاجَهْ سَمِعْتُ مُحَمَّدَ بْنَ يَحْيَى يَقُولُ اضْطَرَبَ النَّاسُ فِي هَذَا الْحَدِيثِ بِبَغْدَادَ فَذَهَبْتُ أَنَا وَأَبُو بَكْرٍ الأَعْيَنُ إِلَى الْعَوَّامِ بْنِ عَبَّادِ بْنِ الْعَوَّامِ فَأَخْرَجَ إِلَيْنَا أَصْلَ أَبِيهِ فَإِذَا الْحَدِيثُ فِيهِ ‏.‏\hadithno{689}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abbas bin 'Abdul-Muttalib said:"The Messenger of Allah said: 'My Ummah will continue to adhere to the Fitrah so long as they do not delay the Maghrib until the stars have come out." (Hasan)Abu 'Abdullah bin Majah said: I heard Muhammed bin Yahya saying: 'The people in Baghdad were confused in narrating this Hadith. Abu Bakr Al-A'yan and I went to 'Awwam bin 'Abbad bin 'Awwam and he brought out to us the book of his father, and this Hadith was in it}}
\hadithdefcmd{ibnmajah}{690}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، ‏.‏ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ بِتَأْخِيرِ الْعِشَاءِ ‏"‏ ‏.‏\hadithno{690}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah said: "Were it not that it would be too difficult for my Ummah, I would have commanded them to delay the 'Isha}}
\hadithdefcmd{ibnmajah}{691}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَخَّرْتُ صَلاَةَ الْعِشَاءِ إِلَى ثُلُثِ اللَّيْلِ أَوْ نِصْفِ اللَّيْلِ ‏"‏ ‏.‏\hadithno{691}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Were it not that it would be too difficult for my Ummah, I would have delayed the 'Isha' prayer until one third or one half of the night had passed}}
\hadithdefcmd{ibnmajah}{692}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا حُمَيْدٌ، قَالَ سُئِلَ أَنَسُ بْنُ مَالِكٍ هَلِ اتَّخَذَ النَّبِيُّ ـ صلى الله عليه وسلم ـ خَاتَمًا قَالَ نَعَمْ أَخَّرَ لَيْلَةً الْعِشَاءَ الآخِرَةَ إِلَى قَرِيبٍ مِنْ شَطْرِ اللَّيْلِ فَلَمَّا صَلَّى أَقْبَلَ عَلَيْنَا بِوَجْهِهِ فَقَالَ ‏ "‏ إِنَّ النَّاسَ قَدْ صَلَّوْا وَنَامُوا وَإِنَّكُمْ لَنْ تَزَالُوا فِي صَلاَةٍ مَا انْتَظَرْتُمُ الصَّلاَةَ ‏"‏ ‏.‏ قَالَ أَنَسٌ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ خَاتَمِهِ ‏.‏\hadithno{692}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Humaid said:"Anas bin Malik was asked: 'Did the Prophet wear a ring?' He said: 'Yes.' One night he delayed the 'Isha' prayer until almost the middle of the night. When he had prayed, he turned to face us and said: 'The people have prayed and gone to sleep, but you will still be in a state of prayer so long as you are waiting for the (next) prayer.'" (Sahih)Anas said: "It was as if I can see the sparkle from his ring}}
\hadithdefcmd{ibnmajah}{693}{حَدَّثَنَا عِمْرَانُ بْنُ مُوسَى اللَّيْثِيُّ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، حَدَّثَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ صَلاَةَ الْمَغْرِبِ ثُمَّ لَمْ يَخْرُجْ حَتَّى ذَهَبَ شَطْرُ اللَّيْلِ فَخَرَجَ فَصَلَّى بِهِمْ ثُمَّ قَالَ ‏ "‏ إِنَّ النَّاسَ قَدْ صَلَّوْا وَنَامُوا وَأَنْتُمْ لَمْ تَزَالُوا فِي صَلاَةٍ مَا انْتَظَرْتُمُ الصَّلاَةَ وَلَوْلاَ الضَّعِيفُ وَالسَّقِيمُ أَحْبَبْتُ أَنْ أُؤَخِّرَ هَذِهِ الصَّلاَةَ إِلَى شَطْرِ اللَّيْلِ ‏"‏ ‏.‏\hadithno{693}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Sa'eed said:"The Messenger of Allah led us for the Maghrib prayer. Then he did not come out until half the night had passed. Then he came out and led them in prayer, then he said: "The people have prayed and gone to sleep, but you are still in a state of prayer so long as you are waiting for the (next) prayer. Were it not for the weak and the sick, I wanted to delay this prayer until the middle of the night}}
\hadithdefcmd{ibnmajah}{694}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَاجِرِ، عَنْ بُرَيْدَةَ الأَسْلَمِيِّ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي غَزْوَةٍ فَقَالَ ‏ "‏ بَكِّرُوا بِالصَّلاَةِ فِي الْيَوْمِ الْغَيْمِ فَإِنَّهُ مَنْ فَاتَتْهُ صَلاَةُ الْعَصْرِ حَبِطَ عَمَلُهُ ‏"‏ ‏.‏\hadithno{694}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Buraidah Al-Aslami said:"We were with the Messenger of Allah on a campaign, and he said: 'Hasten to perform prayer on a cloudy day, for whoever misses the 'Asr prayer, all his good deeds will be in vain}}
\hadithdefcmd{ibnmajah}{695}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سُئِلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ عَنِ الرَّجُلِ يَغْفُلُ عَنِ الصَّلاَةِ أَوْ يَرْقُدُ عَنْهَا قَالَ ‏ "‏ يُصَلِّيهَا إِذَا ذَكَرَهَا ‏"‏ ‏.‏\hadithno{695}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas bin Malik said:'The Prophet was asked about a man who forgets prayer or sleeps and misses it. He said: 'he performs it when he remembers it}}
\hadithdefcmd{ibnmajah}{696}{حَدَّثَنَا جُبَارَةُ بْنُ الْمُغَلِّسِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ نَسِيَ صَلاَةً فَلْيُصَلِّهَا إِذَا ذَكَرَهَا ‏"‏ ‏.‏\hadithno{696}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah said: 'Whoever forgets a prayer, let him perform it when he remembers it}}
\hadithdefcmd{ibnmajah}{697}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ حِينَ قَفَلَ مِنْ غَزْوَةِ خَيْبَرَ فَسَارَ لَيْلَةً حَتَّى إِذَا أَدْرَكَهُ الْكَرَى عَرَّسَ وَقَالَ لِبِلاَلٍ ‏"‏ اكْلأْ لَنَا اللَّيْلَ ‏"‏ ‏.‏ فَصَلَّى بِلاَلٌ مَا قُدِّرَ لَهُ وَنَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَصْحَابُهُ فَلَمَّا تَقَارَبَ الْفَجْرُ اسْتَنَدَ بِلاَلٌ إِلَى رَاحِلَتِهِ مُوَاجِهَ الْفَجْرِ فَغَلَبَتْ بِلاَلاً عَيْنَاهُ وَهُوَ مُسْتَنِدٌ إِلَى رَاحِلَتِهِ فَلَمْ يَسْتَيْقِظْ بِلاَلٌ وَلاَ أَحَدٌ مِنْ أَصْحَابِهِ حَتَّى ضَرَبَتْهُمُ الشَّمْسُ فَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَوَّلَهُمُ اسْتِيقَاظًا فَفَزِعَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ أَىْ بِلاَلُ ‏"‏ ‏.‏ فَقَالَ بِلاَلٌ أَخَذَ بِنَفْسِي الَّذِي أَخَذَ بِنَفْسِكَ بِأَبِي أَنْتَ وَأُمِّي يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ اقْتَادُوا ‏"‏ ‏.‏ فَاقْتَادُوا رَوَاحِلَهُمْ شَيْئًا ثُمَّ تَوَضَّأَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَمَرَ بِلاَلاً فَأَقَامَ الصَّلاَةَ فَصَلَّى بِهِمُ الصُّبْحَ فَلَمَّا قَضَى النَّبِيُّ ـ صلى الله عليه وسلم ـ الصَّلاَةَ ‏.‏ قَالَ ‏"‏ مَنْ نَسِيَ صَلاَةً فَلْيُصَلِّهَا إِذَا ذَكَرَهَا فَإِنَّ اللَّهَ عَزَّ وَجَلَّ قَالَ ‏\{وَأَقِمِ الصَّلاَةَ لِذِكْرِي\}‏ ‏"‏ ‏.‏ قَالَ وَكَانَ ابْنُ شِهَابٍ يَقْرَؤُهَا ‏\{لِلذِّكْرَى\}‏ ‏.‏\hadithno{697}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that :When the Messenger of Allah was coming back from the battle of Khaibar, night came and he felt sleepy, so he made camp and said to Bilal: "Keep watch for us tonight." Bilal prayed as much as Allah decreed for him, and the Messenger of Allah and his Companions went to sleep. When dawn was approaching, Bilal went to his mount, facing towards the east, watching for the dawn. Then Bilal's eyes grew heavy while he was leaning on his mount (and he slept). Neither Bilal nor any of his Companions woke until they felt the heat of the sun. The Messenger of Allah was the first one to wake up. The Messenger of Allah was startled and said: "O Bilal!" Bilal said: "The same thing happened to me as happened to you. May my father and mother be ransomed for you, O Messenger of Allah!" He said: "Bring your mounts forward a little." So they brought their mounts forward a little (away from that place). Then the Messenger of Allah performed ablution and told Bilal to call the Iqamah for prayer, and he led them in the prayer. When the Prophet finished praying, he said: "Whoever forgets a Salah, let him pray it when he remembers, for Allah says: And perform the prayer for My remembrance." [Ta-Ha: 14] He (one of the narrators) said: "Ibn Shihab used to recite this Verse as meaning, 'when you remember}}
\hadithdefcmd{ibnmajah}{698}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ، عَنْ أَبِي قَتَادَةَ، قَالَ ذَكَرُوا تَفْرِيطَهُمْ فِي النَّوْمِ فَقَالَ نَامُوا حَتَّى طَلَعَتِ الشَّمْسُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيْسَ فِي النَّوْمِ تَفْرِيطٌ إِنَّمَا التَّفْرِيطُ فِي الْيَقَظَةِ فَإِذَا نَسِيَ أَحَدُكُمْ صَلاَةً أَوْ نَامَ عَنْهَا فَلْيُصَلِّهَا إِذَا ذَكَرَهَا وَلِوَقْتِهَا مِنَ الْغَدِ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ رَبَاحٍ فَسَمِعَنِي عِمْرَانُ بْنُ الْحُصَيْنِ، وَأَنَا أُحَدِّثُ، بِالْحَدِيثِ فَقَالَ يَا فَتًى انْظُرْ كَيْفَ تُحَدِّثُ فَإِنِّي شَاهِدٌ لِلْحَدِيثِ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ فَمَا أَنْكَرَ مِنْ حَدِيثِهِ شَيْئًا ‏.‏\hadithno{698}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin Rabah narrated that Abu Qatadah said:"They mentioned negligence because of sleeping too much, and he said: 'They slept until the sun had risen. The Messenger of Allah said: "There is no negligence when oneis sleeping, rather there is negligence when one is awake. If anyone of you forgets to pray, or sleeps and misses a prayer, then let him pray when he remembers, and during its time if it is a day after. (Sahih)'Abdullah bin Rabah said: "Imran bin Husain heard me when I was narrating this Hadith and said: 'O young man, look at how you are narrating the Hadith. I was present at the time of this Hadith with the Messenger of Allah.' And he did not deny anything of the Hadith}}
\hadithdefcmd{ibnmajah}{699}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، أَخْبَرَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، وَعَنْ بُسْرِ بْنِ سَعِيدٍ، وَعَنِ الأَعْرَجِ، يُحَدِّثُونَهُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ أَدْرَكَ مِنَ الْعَصْرِ رَكْعَةً قَبْلَ أَنْ تَغْرُبَ الشَّمْسُ فَقَدْ أَدْرَكَهَا وَمَنْ أَدْرَكَ مِنَ الصُّبْحِ رَكْعَةً قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ فَقَدْ أَدْرَكَهَا ‏"‏ ‏.‏\hadithno{699}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah said: "Whoever catches one Rak'ah of the 'Asr before the sun sets, then he has caught it, and whoever catches one Rak'ah of the Subh before the sun rises, then he has caught it}}
\hadithdefcmd{ibnmajah}{700}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، وَحَرْمَلَةُ بْنُ يَحْيَى الْمِصْرِيَّانِ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ أَدْرَكَ مِنَ الصُّبْحِ رَكْعَةً قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ فَقَدْ أَدْرَكَهَا وَمَنْ أَدْرَكَ مِنَ الْعَصْرِ رَكْعَةً قَبْلَ أَنْ تَغِيبَ الشَّمْسُ فَقَدْ أَدْرَكَهَا ‏"‏ ‏.‏ حَدَّثَنَا جَمِيلُ بْنُ الْحَسَنِ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{700}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Aishah that:The Messeenger of Allah said: "Whoever catches one Rak'ah of the Subh before the sun rises, then he has caught it, and whoever catches one Rak'ah of the 'Asr before the sun sets, then he has caught it." (Sahih)Another chain with similar wording}}
\hadithdefcmd{ibnmajah}{701}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الْوَهَّابِ، قَالُوا حَدَّثَنَا عَوْفٌ، عَنْ أَبِي الْمِنْهَالِ، سَيَّارِ بْنِ سَلاَمَةَ عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَسْتَحِبُّ أَنْ يُؤَخِّرَ الْعِشَاءَ وَكَانَ يَكْرَهُ النَّوْمَ قَبْلَهَا وَالْحَدِيثَ بَعْدَهَا ‏.‏\hadithno{701}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Barzah Al-Aslami said:"The Messenger of Allah used to like to delay the 'Isha', and he disliked sleeping before it, and engaging in conversation after it}}
\hadithdefcmd{ibnmajah}{702}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو نُعَيْمٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ يَعْلَى الطَّائِفِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَا نَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ قَبْلَ الْعِشَاءِ وَلاَ سَمَرَ بَعْدَهَا ‏.‏\hadithno{702}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah did not sleep before the 'Isha' nor stay up (talking) after it}}
\hadithdefcmd{ibnmajah}{703}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ حَبِيبٍ، وَعَلِيُّ بْنُ الْمُنْذِرِ، قَالُوا حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ جَدَبَ لَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ السَّمَرَ بَعْدَ الْعِشَاءِ ‏.‏ قَالَ ابْنُ مَاجَهْ يَعْنِي زَجَرَنَا عَنْهُ نَهَانَا عَنْهُ ‏.‏\hadithno{703}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"The Messenger of Allah rebuked us for staying up (talking) after the 'Isha}}
\hadithdefcmd{ibnmajah}{704}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي لَبِيدٍ، عَنْ أَبِي سَلَمَةَ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لاَ تَغْلِبَنَّكُمُ الأَعْرَابُ عَلَى اسْمِ صَلاَتِكُمْ فَإِنَّهَا الْعِشَاءُ وَإِنَّهُمْ لَيُعْتِمُونَ بِالإِبِلِ ‏"‏ ‏.‏\hadithno{704}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Umar said:"I heard the Messenger of Allah say: 'Do not let the Bedouin make you change the name of your prayer. It is the 'Isha', and they bring their camels in and milk them at nightfall}}
\hadithdefcmd{ibnmajah}{705}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، ح وَحَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدٍ، حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حَرْمَلَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تَغْلِبَنَّكُمُ الأَعْرَابُ عَلَى اسْمِ صَلاَتِكُمْ - زَادَ ابْنُ حَرْمَلَةَ - فَإِنَّمَا هِيَ الْعِشَاءُ وَإِنَّمَا يَقُولُونَ الْعَتَمَةُ لإِعْتَامِهِمْ بِالإِبِلِ ‏"‏ ‏.‏\hadithno{705}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that:The Prophet said: "Do not let the Bedouins make you change the name of your prayer." Ibn Harmalah added: "Rather it is the 'Isha', but they say the 'Atamah because they bring their camels in for milking at that time (when it is dark)}}
