% Auto-generated chapter 38 for abudawud
% Hadiths in this chapter: 12

\hadithdefcmd{abudawud}{4279}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنْ إِسْمَاعِيلَ، - يَعْنِي ابْنَ أَبِي خَالِدٍ - عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يَزَالُ هَذَا الدِّينُ قَائِمًا حَتَّى يَكُونَ عَلَيْكُمُ اثْنَا عَشَرَ خَلِيفَةً كُلُّهُمْ تَجْتَمِعُ عَلَيْهِ الأُمَّةُ ‏"‏ ‏.‏ فَسَمِعْتُ كَلاَمًا مِنَ النَّبِيِّ صلى الله عليه وسلم لَمْ أَفْهَمْهُ قُلْتُ لأَبِي مَا يَقُولُ قَالَ ‏"‏ كُلُّهُمْ مِنْ قُرَيْشٍ ‏"‏ ‏.‏\hadithno{4279}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Samurah: The Prophet (ﷺ) said: The religion will continue to be established till there are twelve caliphs over you, and the whole community will agree on each of them. I then heard from the Prophet (ﷺ) some remarks which I could not understand. I asked my father: What is he saying: He said: all of them will belong to Quraysh}}
\hadithdefcmd{abudawud}{4280}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا دَاوُدُ، عَنْ عَامِرٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يَزَالُ هَذَا الدِّينُ عَزِيزًا إِلَى اثْنَىْ عَشَرَ خَلِيفَةً ‏"‏ ‏.‏ قَالَ فَكَبَّرَ النَّاسُ وَضَجُّوا ثُمَّ قَالَ كَلِمَةً خَفِيَّةً قُلْتُ لأَبِي يَا أَبَةِ مَا قَالَ قَالَ ‏"‏ كُلُّهُمْ مِنْ قُرَيْشٍ ‏"‏ ‏.‏\hadithno{4280}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1821)}\hadithtrans{Narrated Jabir b. Samurah:I heard the Messenger of Allah (ﷺ) say: This religion will continue to be strong till the time of twelve caliphs. The people then uttered: Allah is more great and uproared. He then silently a word which I could not understand. So I said to my father: What did he say, father ? He said: All of them will belong to Quraish}}
\hadithdefcmd{abudawud}{4281}{حَدَّثَنَا ابْنُ نُفَيْلٍ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا زِيَادُ بْنُ خَيْثَمَةَ، حَدَّثَنَا الأَسْوَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، عَنْ جَابِرِ بْنِ سَمُرَةَ، بِهَذَا الْحَدِيثِ زَادَ فَلَمَّا رَجَعَ إِلَى مَنْزِلِهِ أَتَتْهُ قُرَيْشٌ فَقَالُوا ثُمَّ يَكُونُ مَاذَا قَالَ ‏ "‏ ثُمَّ يَكُونُ الْهَرْجُ ‏"‏ ‏.‏\hadithno{4281}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Jabir b. Samurah through a different chain of narrators. This version adds:When he came back to his home. the Quraish came to him and said: Then what will happen ? He said: Then turmoil will prevail}}
\hadithdefcmd{abudawud}{4282}{حَدَّثَنَا مُسَدَّدٌ، أَنَّ عُمَرَ بْنَ عُبَيْدٍ، حَدَّثَهُمْ ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو بَكْرٍ، - يَعْنِي ابْنَ عَيَّاشٍ ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَخْبَرَنَا زَائِدَةُ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ فِطْرٍ، - الْمَعْنَى وَاحِدٌ - كُلُّهُمْ عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لَوْ لَمْ يَبْقَ مِنَ الدُّنْيَا إِلاَّ يَوْمٌ ‏"‏ ‏.‏ قَالَ زَائِدَةُ فِي حَدِيثِهِ ‏"‏ لَطَوَّلَ اللَّهُ ذَلِكَ الْيَوْمَ ‏"‏ ‏.‏ ثُمَّ اتَّفَقُوا ‏"‏ حَتَّى يَبْعَثَ فِيهِ رَجُلاً مِنِّي ‏"‏ ‏.‏ أَوْ ‏"‏ مِنْ أَهْلِ بَيْتِي يُوَاطِئُ اسْمُهُ اسْمِي وَاسْمُ أَبِيهِ اسْمَ أَبِي ‏"‏ ‏.‏ زَادَ فِي حَدِيثِ فِطْرٍ ‏"‏ يَمْلأُ الأَرْضَ قِسْطًا وَعَدْلاً كَمَا مُلِئَتْ ظُلْمًا وَجَوْرًا ‏"‏ ‏.‏ وَقَالَ فِي حَدِيثِ سُفْيَانَ ‏"‏ لاَ تَذْهَبُ أَوْ لاَ تَنْقَضِي الدُّنْيَا حَتَّى يَمْلِكَ الْعَرَبَ رَجُلٌ مِنْ أَهْلِ بَيْتِي يُوَاطِئُ اسْمُهُ اسْمِي ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ لَفْظُ عُمَرَ وَأَبِي بَكْرٍ بِمَعْنَى سُفْيَانَ ‏.‏\hadithno{4282}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Prophet (ﷺ) said: If only one day of this world remained. Allah would lengthen that day (according to the version of Za'idah), till He raised up in it a man who belongs to me or to my family whose father's name is the same as my father's, who will fill the earth with equity and justice as it has been filled with oppression and tyranny (according to the version of Fitr). Sufyan's version says: The world will not pass away before the Arabs are ruled by a man of my family whose name will be the same as mine. Abu Dawud said: The version of 'Umar and Abu Bakr is the same as that of Sufyan}}
\hadithdefcmd{abudawud}{4283}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، حَدَّثَنَا فِطْرٌ، عَنِ الْقَاسِمِ بْنِ أَبِي بَزَّةَ، عَنْ أَبِي الطُّفَيْلِ، عَنْ عَلِيٍّ، - رضى الله تعالى عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ لَمْ يَبْقَ مِنَ الدَّهْرِ إِلاَّ يَوْمٌ لَبَعَثَ اللَّهُ رَجُلاً مِنْ أَهْلِ بَيْتِي يَمْلأُهَا عَدْلاً كَمَا مُلِئَتْ جَوْرًا ‏"‏ ‏.‏\hadithno{4283}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ali ibn AbuTalib: The Prophet (ﷺ) said: If only one day of this time (world) remained, Allah would raise up a man from my family who would fill this earth with justice as it has been filled with oppression}}
\hadithdefcmd{abudawud}{4284}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الرَّقِّيُّ، حَدَّثَنَا أَبُو الْمَلِيحِ الْحَسَنُ بْنُ عُمَرَ، عَنْ زِيَادِ بْنِ بَيَانٍ، عَنْ عَلِيِّ بْنِ نُفَيْلٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْمَهْدِيُّ مِنْ عِتْرَتِي مِنْ وَلَدِ فَاطِمَةَ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ جَعْفَرٍ وَسَمِعْتُ أَبَا الْمَلِيحِ يُثْنِي عَلَى عَلِيِّ بْنِ نُفَيْلٍ وَيَذْكُرُ مِنْهُ صَلاَحًا ‏.‏\hadithno{4284}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: The Prophet (ﷺ) said: The Mahdi will be of my family, of the descendants of Fatimah. Abdullah ibn Ja'far said: I heard AbulMalih praising Ali ibn Nufayl and describing his good qualities}}
\hadithdefcmd{abudawud}{4285}{حَدَّثَنَا سَهْلُ بْنُ تَمَّامِ بْنِ بَزِيعٍ، حَدَّثَنَا عِمْرَانُ الْقَطَّانُ، عَنْ قَتَادَةَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَهْدِيُّ مِنِّي أَجْلَى الْجَبْهَةِ أَقْنَى الأَنْفِ يَمْلأُ الأَرْضَ قِسْطًا وَعَدْلاً كَمَا مُلِئَتْ جَوْرًا وَظُلْمًا يَمْلِكُ سَبْعَ سِنِينَ ‏"‏ ‏.‏\hadithno{4285}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) said: The Mahdi will be of my stock, and will have a broad forehead a prominent nose. He will fill the earth will equity and justice as it was filled with oppression and tyranny, and he will rule for seven years}}
\hadithdefcmd{abudawud}{4286}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ صَالِحٍ أَبِي الْخَلِيلِ، عَنْ صَاحِبٍ، لَهُ عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يَكُونُ اخْتِلاَفٌ عِنْدَ مَوْتِ خَلِيفَةٍ فَيَخْرُجُ رَجُلٌ مِنْ أَهْلِ الْمَدِينَةِ هَارِبًا إِلَى مَكَّةَ فَيَأْتِيهِ نَاسٌ مِنْ أَهْلِ مَكَّةَ فَيُخْرِجُونَهُ وَهُوَ كَارِهٌ فَيُبَايِعُونَهُ بَيْنَ الرُّكْنِ وَالْمَقَامِ وَيُبْعَثُ إِلَيْهِ بَعْثٌ مِنَ الشَّامِ فَيُخْسَفُ بِهِمْ بِالْبَيْدَاءِ بَيْنَ مَكَّةَ وَالْمَدِينَةِ فَإِذَا رَأَى النَّاسُ ذَلِكَ أَتَاهُ أَبْدَالُ الشَّامِ وَعَصَائِبُ أَهْلِ الْعِرَاقِ فَيُبَايِعُونَهُ بَيْنَ الرُّكْنِ وَالْمَقَامِ ثُمَّ يَنْشَأُ رَجُلٌ مِنْ قُرَيْشٍ أَخْوَالُهُ كَلْبٌ فَيَبْعَثُ إِلَيْهِمْ بَعْثًا فَيَظْهَرُونَ عَلَيْهِمْ وَذَلِكَ بَعْثُ كَلْبٍ وَالْخَيْبَةُ لِمَنْ لَمْ يَشْهَدْ غَنِيمَةَ كَلْبٍ فَيَقْسِمُ الْمَالَ وَيَعْمَلُ فِي النَّاسِ بِسُنَّةِ نَبِيِّهِمْ صلى الله عليه وسلم وَيُلْقِي الإِسْلاَمُ بِجِرَانِهِ إِلَى الأَرْضِ فَيَلْبَثُ سَبْعَ سِنِينَ ثُمَّ يُتَوَفَّى وَيُصَلِّي عَلَيْهِ الْمُسْلِمُونَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ بَعْضُهُمْ عَنْ هِشَامٍ ‏"‏ تِسْعَ سِنِينَ ‏"‏ ‏.‏ وَقَالَ بَعْضُهُمْ ‏"‏ سَبْعَ سِنِينَ ‏"‏ ‏.‏\hadithno{4286}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: The Prophet (ﷺ) said: Disagreement will occur at the death of a caliph and a man of the people of Medina will come flying forth to Mecca. Some of the people of Mecca will come to him, bring him out against his will and swear allegiance to him between the Corner and the Maqam. An expeditionary force will then be sent against him from Syria but will be swallowed up in the desert between Mecca and Medina. When the people see that, the eminent saints of Syria and the best people of Iraq will come to him and swear allegiance to him between the Corner and the Maqam. Then there will arise a man of Quraysh whose maternal uncles belong to Kalb and send against them an expeditionary force which will be overcome by them, and that is the expedition of Kalb. Disappointed will be the one who does not receive the booty of Kalb. He will divide the property, and will govern the people by the Sunnah of their Prophet (ﷺ) and establish Islam on Earth. He will remain seven years, then die, and the Muslims will pray over him. Abu Dawud said: Some transmitted from Hisham "nine years" and some "seven years}}
\hadithdefcmd{abudawud}{4287}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَبْدُ الصَّمَدِ، عَنْ هَمَّامٍ، عَنْ قَتَادَةَ، بِهَذَا الْحَدِيثِ وَقَالَ ‏"‏ تِسْعَ سِنِينَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَالَ غَيْرُ مُعَاذٍ عَنْ هِشَامٍ ‏"‏ تِسْعَ سِنِينَ ‏"‏ ‏.‏\hadithno{4287}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Qatadah through a different chain of narrators. This version has "nine years". Abu Dawud said:The other narrators mentioned "nine years" from Hisham except Mu'adh}}
\hadithdefcmd{abudawud}{4288}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا أَبُو الْعَوَّامِ، حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي الْخَلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ أُمِّ سَلَمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ وَحَدِيثُ مُعَاذٍ أَتَمُّ ‏.‏\hadithno{4288}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Umm Salamah from the Prophet (ﷺ) through a different chain of narrators. The tradition of Mu'adh is more perfect}}
\hadithdefcmd{abudawud}{4289}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ عُبَيْدِ اللَّهِ ابْنِ الْقِبْطِيَّةِ، عَنْ أُمِّ سَلَمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِقِصَّةِ جَيْشِ الْخَسْفِ قُلْتُ يَا رَسُولَ اللَّهِ فَكَيْفَ بِمَنْ كَانَ كَارِهًا قَالَ ‏ "‏ يُخْسَفُ بِهِمْ وَلَكِنْ يُبْعَثُ يَوْمَ الْقِيَامَةِ عَلَى نِيَّتِهِ ‏"‏ ‏.‏\hadithno{4289}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2882)}\hadithtrans{Umm salamah reported the Prophet (ﷺ) as saying about the swallowing up an army by the earth. I asked:How will a man who comes against his will (be swallowed up by the earth), Messenger of Allah ? He replied: All will be swallowed up, but each will be raised according to his intention on the Day of Resurrection}}
\hadithdefcmd{abudawud}{4290}{\hadithno{4290}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif}\hadithtrans{}}
