% Auto-generated chapter 69 for bukhari
% Hadiths in this chapter: 22

\hadithdefcmd{bukhari}{5351}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ يَزِيدَ الأَنْصَارِيَّ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، فَقُلْتُ عَنِ النَّبِيِّ فَقَالَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَنْفَقَ الْمُسْلِمُ نَفَقَةً عَلَى أَهْلِهِ وَهْوَ يَحْتَسِبُهَا، كَانَتْ لَهُ صَدَقَةً ‏"‏‏.‏\hadithno{5351}\hadithtrans{Narrated Abu Mas`ud Al-Ansari:The Prophet (ﷺ) said, "When a Muslim spends something on his family intending to receive Allah's reward it is regarded as Sadaqa for him}}
\hadithdefcmd{bukhari}{5352}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ اللَّهُ أَنْفِقْ يَا ابْنَ آدَمَ أُنْفِقْ عَلَيْكَ ‏"‏‏.‏\hadithno{5352}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah said, 'O son of Adam! Spend, and I shall spend on you}}
\hadithdefcmd{bukhari}{5353}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا مَالِكٌ، عَنْ ثَوْرِ بْنِ زَيْدٍ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ السَّاعِي عَلَى الأَرْمَلَةِ وَالْمِسْكِينِ كَالْمُجَاهِدِ فِي سَبِيلِ اللَّهِ، أَوِ الْقَائِمِ اللَّيْلَ الصَّائِمِ النَّهَارَ ‏"‏‏.‏\hadithno{5353}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The one who looks after a widow or a poor person is like a Mujahid (warrior) who fights for Allah's Cause, or like him who performs prayers all the night and fasts all the day}}
\hadithdefcmd{bukhari}{5354}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ سَعْد ٍ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَعُودُنِي وَأَنَا مَرِيضٌ بِمَكَّةَ، فَقُلْتُ لِي مَالٌ أُوصِي بِمَالِي كُلِّهِ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ فَالشَّطْرُ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ فَالثُّلُثُ قَالَ ‏"‏ الثُّلُثُ، وَالثُّلُثُ كَثِيرٌ، أَنْ تَدَعَ وَرَثَتَكَ أَغْنِيَاءَ خَيْرٌ مِنْ أَنْ تَدَعَهُمْ عَالَةً، يَتَكَفَّفُونَ النَّاسَ فِي أَيْدِيهِمْ، وَمَهْمَا أَنْفَقْتَ فَهُوَ لَكَ صَدَقَةٌ حَتَّى اللُّقْمَةَ تَرْفَعُهَا فِي فِي امْرَأَتِكَ، وَلَعَلَّ اللَّهَ يَرْفَعُكَ، يَنْتَفِعُ بِكَ نَاسٌ وَيُضَرُّ بِكَ آخَرُونَ ‏"‏‏.‏\hadithno{5354}\hadithtrans{Narrated Sa`d:The Prophet (ﷺ) visited me at Mecca while I was ill. I said (to him), "I have property; May I bequeath all my property in Allah's Cause?" He said, "No." I said, "Half of it?" He said, "No." I said, "One third of it?" He said, "One-third (is alright), yet it is still too much, for you'd better leave your inheritors wealthy than leave them poor, begging of others. Whatever you spend will be considered a Sadaqa for you, even the mouthful of food you put in the mouth of your wife. Anyhow Allah may let you recover, so that some people may benefit by you and others be harmed by you}}
\hadithdefcmd{bukhari}{5355}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا أَبُو صَالِحٍ، قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَفْضَلُ الصَّدَقَةِ مَا تَرَكَ غِنًى، وَالْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى، وَابْدَأْ بِمَنْ تَعُولُ ‏"‏‏.‏ تَقُولُ الْمَرْأَةُ إِمَّا أَنْ تُطْعِمَنِي وَإِمَّا أَنْ تُطَلِّقَنِي‏.‏ وَيَقُولُ الْعَبْدُ أَطْعِمْنِي وَاسْتَعْمِلْنِي‏.‏ وَيَقُولُ الاِبْنُ أَطْعِمْنِي، إِلَى مَنْ تَدَعُنِي فَقَالُوا يَا أَبَا هُرَيْرَةَ سَمِعْتَ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَ لاَ هَذَا مِنْ كِيسِ أَبِي هُرَيْرَةَ‏.‏\hadithno{5355}\hadithtrans{Narrated Abu Huraira:"The Prophet (ﷺ) said, 'The best alms is that which is given when one is rich, and a giving hand is better than a taking one, and you should start first to support your dependents.' A wife says, 'You should either provide me with food or divorce me.' A slave says, 'Give me food and enjoy my service." A son says, "Give me food; to whom do you leave me?" The people said, "O Abu Huraira! Did you hear that from Allah's Messenger (ﷺ) ?" He said, "No, it is from my own self}}
\hadithdefcmd{bukhari}{5356}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدِ بْنِ مُسَافِرٍ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ الصَّدَقَةِ مَا كَانَ عَنْ ظَهْرِ غِنًى، وَابْدَأْ بِمَنْ تَعُولُ ‏"‏‏.‏\hadithno{5356}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The best alms is that which you give when you are rich, and you should start first to support your dependants}}
\hadithdefcmd{bukhari}{5357}{حَدَّثَنِي مُحَمَّدُ بْنُ سَلاَمٍ، أَخْبَرَنَا وَكِيعٌ، عَنِ ابْنِ عُيَيْنَةَ، قَالَ قَالَ لِي مَعْمَرٌ قَالَ لِي الثَّوْرِيُّ هَلْ سَمِعْتَ فِي الرَّجُلِ يَجْمَعُ لأَهْلِهِ قُوتَ سَنَتِهِمْ أَوْ بَعْضِ السَّنَةِ قَالَ مَعْمَرٌ فَلَمْ يَحْضُرْنِي، ثُمَّ ذَكَرْتُ حَدِيثًا حَدَّثَنَاهُ ابْنُ شِهَابٍ الزُّهْرِيُّ عَنْ مَالِكِ بْنِ أَوْسٍ عَنْ عُمَرَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَبِيعُ نَخْلَ بَنِي النَّضِيرِ، وَيَحْبِسُ لأَهْلِهِ قُوتَ سَنَتِهِمْ‏.‏\hadithno{5357}\hadithtrans{Narrated `Umar:The Prophet (ﷺ) used to sell the dates of the garden of Bani An-Nadir and store for his family so much food as would cover their needs for a whole year}}
\hadithdefcmd{bukhari}{5358}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي مَالِكُ بْنُ أَوْسِ بْنِ الْحَدَثَانِ، وَكَانَ، مُحَمَّدُ بْنُ جُبَيْرِ بْنِ مُطْعِمٍ ذَكَرَ لِي ذِكْرًا مِنْ حَدِيثِهِ، فَانْطَلَقْتُ حَتَّى دَخَلْتُ عَلَى مَالِكِ بْنِ أَوْسٍ فَسَأَلْتُهُ فَقَالَ مَالِكٌ انْطَلَقْتُ حَتَّى أَدْخُلَ عَلَى عُمَرَ، إِذْ أَتَاهُ حَاجِبُهُ يَرْفَا فَقَالَ هَلْ لَكَ فِي عُثْمَانَ وَعَبْدِ الرَّحْمَنِ وَالزُّبَيْرِ وَسَعْدٍ يَسْتَأْذِنُونَ قَالَ نَعَمْ‏.‏ فَأَذِنَ لَهُمْ ـ قَالَ ـ فَدَخَلُوا وَسَلَّمُوا فَجَلَسُوا، ثُمَّ لَبِثَ يَرْفَا قَلِيلاً فَقَالَ لِعُمَرَ هَلْ لَكَ فِي عَلِيٍّ وَعَبَّاسٍ قَالَ نَعَمْ‏.‏ فَأَذِنَ لَهُمَا، فَلَمَّا دَخَلاَ سَلَّمَا وَجَلَسَا، فَقَالَ عَبَّاسٌ يَا أَمِيرَ الْمُؤْمِنِينَ اقْضِ بَيْنِي وَبَيْنَ هَذَا‏.‏ فَقَالَ الرَّهْطُ عُثْمَانُ وَأَصْحَابُهُ يَا أَمِيرَ الْمُؤْمِنِينَ اقْضِ بَيْنَهُمَا، وَأَرِحْ أَحَدَهُمَا مِنَ الآخَرِ‏.‏ فَقَالَ عُمَرُ اتَّئِدُوا أَنْشُدُكُمْ بِاللَّهِ الَّذِي بِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ، هَلْ تَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ نُورَثُ مَا تَرَكْنَا صَدَقَةٌ ‏"‏‏.‏ يُرِيدُ رَسُولُ اللَّهِ صلى الله عليه وسلم نَفْسَهُ‏.‏ قَالَ الرَّهْطُ قَدْ قَالَ ذَلِكَ‏.‏ فَأَقْبَلَ عُمَرُ عَلَى عَلِيٍّ وَعَبَّاسٍ فَقَالَ أَنْشُدُكُمَا بِاللَّهِ هَلْ تَعْلَمَانِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ذَلِكَ قَالاَ قَدْ قَالَ ذَلِكَ‏.‏ قَالَ عُمَرُ فَإِنِّي أُحَدِّثُكُمْ عَنْ هَذَا الأَمْرِ، إِنَّ اللَّهَ كَانَ خَصَّ رَسُولَهُ صلى الله عليه وسلم فِي هَذَا الْمَالِ بِشَىْءٍ لَمْ يُعْطِهِ أَحَدًا غَيْرَهُ، قَالَ اللَّهُ ‏\{‏مَا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِنْهُمْ فَمَا أَوْجَفْتُمْ عَلَيْهِ مِنْ خَيْلٍ‏\}‏ إِلَى قَوْلِهِ ‏\{‏قَدِيرٌ‏\}‏‏.‏ فَكَانَتْ هَذِهِ خَالِصَةً لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَاللَّهِ مَا احْتَازَهَا دُونَكُمْ وَلاَ اسْتَأْثَرَ بِهَا عَلَيْكُمْ، لَقَدْ أَعْطَاكُمُوهَا وَبَثَّهَا فِيكُمْ، حَتَّى بَقِيَ مِنْهَا هَذَا الْمَالُ، فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُنْفِقُ عَلَى أَهْلِهِ نَفَقَةَ سَنَتِهِمْ مِنْ هَذَا الْمَالِ، ثُمَّ يَأْخُذُ مَا بَقِيَ، فَيَجْعَلُهُ مَجْعَلَ مَالِ اللَّهِ، فَعَمِلَ بِذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَيَاتَهُ، أَنْشُدُكُمْ بِاللَّهِ، هَلْ تَعْلَمُونَ ذَلِكَ قَالُوا نَعَمْ‏.‏ قَالَ لِعَلِيٍّ وَعَبَّاسٍ أَنْشُدُكُمَا بِاللَّهِ هَلْ تَعْلَمَانِ ذَلِكَ قَالاَ نَعَمْ‏.‏ ثُمَّ تَوَفَّى اللَّهُ نَبِيَّهُ صلى الله عليه وسلم فَقَالَ أَبُو بَكْرٍ أَنَا وَلِيُّ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَبَضَهَا أَبُو بَكْرٍ يَعْمَلُ فِيهَا بِمَا عَمِلَ بِهِ فِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنْتُمَا حِينَئِذٍ ـ وَأَقْبَلَ عَلَى عَلِيٍّ وَعَبَّاسٍ ـ تَزْعُمَانِ أَنَّ أَبَا بَكْرٍ كَذَا وَكَذَا، وَاللَّهُ يَعْلَمُ أَنَّهُ فِيهَا صَادِقٌ بَارٌّ رَاشِدٌ تَابِعٌ لِلْحَقِّ، ثُمَّ تَوَفَّى اللَّهُ أَبَا بَكْرٍ فَقُلْتُ أَنَا وَلِيُّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ، فَقَبَضْتُهَا سَنَتَيْنِ أَعْمَلُ فِيهَا بِمَا عَمِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ، ثُمَّ جِئْتُمَانِي وَكَلِمَتُكُمَا وَاحِدَةٌ وَأَمْرُكُمَا جَمِيعٌ، جِئْتَنِي تَسْأَلُنِي نَصِيبَكَ مِنِ ابْنِ أَخِيكَ، وَأَتَى هَذَا يَسْأَلُنِي نَصِيبَ امْرَأَتِهِ مِنْ أَبِيهَا، فَقُلْتُ إِنْ شِئْتُمَا دَفَعْتُهُ إِلَيْكُمَا عَلَى أَنَّ عَلَيْكُمَا عَهْدَ اللَّهِ وَمِيثَاقَهُ لَتَعْمَلاَنِ فِيهَا بِمَا عَمِلَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَبِمَا عَمِلَ بِهِ فِيهَا أَبُو بَكْرٍ، وَبِمَا عَمِلْتُ بِهِ فِيهَا، مُنْذُ وُلِّيتُهَا، وَإِلاَّ فَلاَ تُكَلِّمَانِي فِيهَا فَقُلْتُمَا ادْفَعْهَا إِلَيْنَا بِذَلِكَ‏.‏ فَدَفَعْتُهَا إِلَيْكُمَا بِذَلِكَ، أَنْشُدُكُمْ بِاللَّهِ هَلْ دَفَعْتُهَا إِلَيْهِمَا بِذَلِكَ فَقَالَ الرَّهْطُ نَعَمْ‏.‏ قَالَ فَأَقْبَلَ عَلَى عَلِيٍّ وَعَبَّاسٍ فَقَالَ أَنْشُدُكُمَا بِاللَّهِ هَلْ دَفَعْتُهَا إِلَيْكُمَا بِذَلِكَ قَالاَ نَعَمْ‏.‏ قَالَ أَفَتَلْتَمِسَانِ مِنِّي قَضَاءً غَيْرَ ذَلِكَ، فَوَالَّذِي بِإِذْنِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ لاَ أَقْضِي فِيهَا قَضَاءً غَيْرَ ذَلِكَ، حَتَّى تَقُومَ السَّاعَةُ، فَإِنْ عَجَزْتُمَا عَنْهَا فَادْفَعَاهَا فَأَنَا أَكْفِيكُمَاهَا‏.‏\hadithno{5358}\hadithtrans{Narrated Malik bin Aus bin Al-Hadathan:Once I set out to visit `Umar (bin Al-Khattab). (While I was sitting there with him his gate-keeper, Yarfa, came and said, "Uthman `AbdurRahman (bin `Auf), Az-Zubair and Sa`d (bin Abi Waqqas) are seeking permission (to meet you)." `Umar said, "Yes. So he admitted them and they entered, greeted, and sat down. After a short while Yarfa came again and said to `Umar 'Shall I admit `Ali and `Abbas?" `Umar said, "Yes." He admitted them and when they entered, they greeted and sat down. `Abbas said, "O Chief of the Believers! Judge between me and this (`Ali)." The group, `Uthman and his companions Sa`d, 'O Chief of the Believers! Judge between them and relieve one from the other." `Umar said. Wait! I beseech you by Allah, by Whose permission both the Heaven and the Earth stand fast ! Do you know that Allah's Messenger (ﷺ) said. 'We (Apostles) do not bequeath anything to our heirs, but whatever we leave is to be given in charity.' And by that Allah's Messenger (ﷺ) meant himself?" The group said, "He did say so." `Umar then turned towards 'Ali and `Abbas and said. "I beseech you both by Allah, do you know that Allah's Messenger (ﷺ) said that?" They said, 'Yes " `Umar said, "Now, let me talk to you about this matter. Allah favored His Apostle with something of this property (war booty) which He did not give to anybody else. And Allah said:-- 'And what Allah has bestowed on His Apostle (as Fai Booty) from them for which you made no expedition with either cavalry or camelry . . . Allah is Able to do all things.' (59.6) So this property was especially granted to Allah's Messenger (ﷺ). But by Allah he neither withheld it from you, nor did he keep it for himself and deprive you of it, but he gave it all to you and distributed it among you till only this remained out of it. And out of this property Allah's Messenger (ﷺ) used to provide his family with their yearly needs, and whatever remained, he would spend where Allah's Property (the revenues of Zakat) used to be spent. Allah's Messenger (ﷺ) kept on acting like this throughout his lifetime. Now I beseech you by Allah, do you know that?" They said, "Yes." Then `Umar said to `Ali and `Abbas, "I beseech you by Allah, do you both know that?" They said, "Yes." `Umar added, "When Allah had taken His Apostle unto Him, Abu Bakr said, 'I am the successor of Allah's Messenger (ﷺ). So he took charge of that property and did with it the same what Allah's Messenger (ﷺ) used to do, and both of you knew all about it then." Then `Umar turned towards `Ali and `Abbas and said, "You both claim that Abu- Bakr was so-and-so! But Allah knows that he was honest, sincere, pious and right (in that matter). Then Allah caused Abu Bakr to die, and I said, 'I am the successor of Allah's Messenger (ﷺ) and Abu Bakr.' So I kept this property in my possession for the first two years of my rule, and I used to do the same with it as Allah's Messenger (ﷺ) and Abu Bakr used to do. Later both of you (`Ali and `Abbas) came to me with the same claim and the same problem. (O `Abbas!) You came to me demanding your share from (the inheritance of) the son of your brother, and he (`Ali) came to me demanding his wives share from (the inheritance of) her father. So I said to you, 'If you wish I will hand over this property to you, on condition that you both promise me before Allah that you will manage it in the same way as Allah's Messenger (ﷺ) and Abu Bakr did, and as I have done since the beginning of my rule; otherwise you should not speak to me about it.' So you both said, 'Hand over this property to us on this condition.' And on this condition I handed it over to you. I beseech you by Allah, did I hand it over to them on that condition?" The group said, "Yes." `Umar then faced `Ali and `Abbas and said, "I beseech you both by Allah, did I hand it over to you both on that condition?" They both said, "Yes." `Umar added, "Do you want me now to give a decision other than that? By Him with Whose permission (order) both the Heaven and the Earth stand fast, I will never give any decision other than that till the Hour is established! But if you are unable to manage it (that property), then return it to me and I will be sufficient for it on your behalf}}
\hadithdefcmd{bukhari}{5359}{حَدَّثَنَا ابْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ جَاءَتْ هِنْدُ بِنْتُ عُتْبَةَ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سُفْيَانَ رَجُلٌ مِسِّيكٌ، فَهَلْ عَلَىَّ حَرَجٌ أَنْ أُطْعِمَ مِنَ الَّذِي لَهُ عِيَالَنَا قَالَ ‏ "‏ لاَ إِلاَّ بِالْمَعْرُوفِ ‏"‏‏.‏\hadithno{5359}\hadithtrans{Narrated `Aisha:Hind bint `Utba came and said, "O Allah's Messenger (ﷺ)! Abu Sufyan is a miser so is it sinful of me to feed our children from his property?" Allah's Messenger (ﷺ) said, "No except if you take for your needs what is just and reasonable}}
\hadithdefcmd{bukhari}{5360}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَنْفَقَتِ الْمَرْأَةُ مِنْ كَسْبِ زَوْجِهَا عَنْ غَيْرِ أَمْرِهِ فَلَهُ نِصْفُ أَجْرِهِ ‏"‏‏.‏\hadithno{5360}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "If the wife gives of her husband's property (something in charity) without his permission, he will get half the reward}}
\hadithdefcmd{bukhari}{5361}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، قَالَ حَدَّثَنِي الْحَكَمُ، عَنِ ابْنِ أَبِي لَيْلَى، حَدَّثَنَا عَلِيٌّ، أَنَّ فَاطِمَةَ ـ عَلَيْهِمَا السَّلاَمُ ـ أَتَتِ النَّبِيَّ صلى الله عليه وسلم تَشْكُو إِلَيْهِ مَا تَلْقَى فِي يَدِهَا مِنَ الرَّحَى، وَبَلَغَهَا أَنَّهُ جَاءَهُ رَقِيقٌ فَلَمْ تُصَادِفْهُ، فَذَكَرَتْ ذَلِكَ لِعَائِشَةَ، فَلَمَّا جَاءَ أَخْبَرَتْهُ عَائِشَةُ ـ قَالَ ـ فَجَاءَنَا وَقَدْ أَخَذْنَا مَضَاجِعَنَا، فَذَهَبْنَا نَقُومُ فَقَالَ ‏"‏ عَلَى مَكَانِكُمَا ‏"‏‏.‏ فَجَاءَ فَقَعَدَ بَيْنِي وَبَيْنَهَا حَتَّى وَجَدْتُ بَرْدَ قَدَمَيْهِ عَلَى بَطْنِي فَقَالَ ‏"‏ أَلاَ أَدُلُّكُمَا عَلَى خَيْرٍ مِمَّا سَأَلْتُمَا، إِذَا أَخَذْتُمَا مَضَاجِعَكُمَا ـ أَوْ أَوَيْتُمَا إِلَى فِرَاشِكُمَا ـ فَسَبِّحَا ثَلاَثًا وَثَلاَثِينَ، وَاحْمَدَا ثَلاَثًا وَثَلاَثِينَ، وَكَبِّرَا أَرْبَعًا وَثَلاَثِينَ، فَهْوَ خَيْرٌ لَكُمَا مِنْ خَادِمٍ ‏"‏‏.‏\hadithno{5361}\hadithtrans{Narrated `Ali:Fatima went to the Prophet (ﷺ) complaining about the bad effect of the stone hand-mill on her hand. She heard that the Prophet (ﷺ) had received a few slave girls. But (when she came there) she did not find him, so she mentioned her problem to `Aisha. When the Prophet (ﷺ) came, `Aisha informed him about that. `Ali added, "So the Prophet (ﷺ) came to us when we had gone to bed. We wanted to get up (on his arrival) but he said, 'Stay where you are." Then he came and sat between me and her and I felt the coldness of his feet on my `Abdomen. He said, "Shall I direct you to something better than what you have requested? When you go to bed say 'Subhan Allah' thirty-three times, 'Al hamduli l-lah' thirty three times, and Allahu Akbar' thirty four times, for that is better for you than a servant}}
\hadithdefcmd{bukhari}{5362}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ أَبِي يَزِيدَ، سَمِعَ مُجَاهِدًا، سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ أَبِي لَيْلَى، يُحَدِّثُ عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ فَاطِمَةَ ـ عَلَيْهَا السَّلاَمُ ـ أَتَتِ النَّبِيَّ صلى الله عليه وسلم تَسْأَلُهُ خَادِمًا فَقَالَ ‏ "‏ أَلاَ أُخْبِرُكِ مَا هُوَ خَيْرٌ لَكِ مِنْهُ، تُسَبِّحِينَ اللَّهَ عِنْدَ مَنَامِكِ ثَلاَثًا وَثَلاَثِينَ، وَتَحْمَدِينَ اللَّهَ ثَلاَثًا وَثَلاَثِينَ، وَتُكَبِّرِينَ اللَّهَ أَرْبَعًا وَثَلاَثِينَ ‏"‏‏.‏ ـ ثُمَّ قَالَ سُفْيَانُ إِحْدَاهُنَّ أَرْبَعٌ وَثَلاَثُونَ ـ فَمَا تَرَكْتُهَا بَعْدُ، قِيلَ وَلاَ لَيْلَةَ صِفِّينَ قَالَ وَلاَ لَيْلَةَ صِفِّينَ‏.‏\hadithno{5362}\hadithtrans{Narrated `Ali bin Abi Talib:Fatima came to the Prophet (ﷺ) asking for a servant. He said, "May I inform you of something better than that? When you go to bed, recite "Subhan Allah' thirty three times, 'Al hamduli l-lah' thirty three times, and 'Allahu Akbar' thirty four times. `Ali added, 'I have never failed to recite it ever since." Somebody asked, "Even on the night of the battle of Siffin?" He said, "Even on the night of the battle of Siffin}}
\hadithdefcmd{bukhari}{5363}{حَدَّثَنَا مُحَمَّدُ بْنُ عَرْعَرَةَ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، سَأَلْتُ عَائِشَةَ ـ رضى الله عنها ـ مَا كَانَ النَّبِيُّ صلى الله عليه وسلم يَصْنَعُ فِي الْبَيْتِ قَالَتْ كَانَ فِي مِهْنَةِ أَهْلِهِ، فَإِذَا سَمِعَ الأَذَانَ خَرَجَ‏.‏\hadithno{5363}\hadithtrans{Narrated Al-Aswad bin Yazid:I asked `Aisha "What did the Prophet (ﷺ) use to do at home?" She said, "He used to work for his family, and when he heard the Adhan (call for the prayer), he would go out}}
\hadithdefcmd{bukhari}{5364}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ، أَنَّ هِنْدَ بِنْتَ عُتْبَةَ، قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سُفْيَانَ رَجُلٌ شَحِيحٌ، وَلَيْسَ يُعْطِينِي مَا يَكْفِينِي وَوَلَدِي، إِلاَّ مَا أَخَذْتُ مِنْهُ وَهْوَ لاَ يَعْلَمُ فَقَالَ ‏ "‏ خُذِي مَا يَكْفِيكِ وَوَلَدَكِ بِالْمَعْرُوفِ ‏"‏‏.‏\hadithno{5364}\hadithtrans{Narrated `Aisha:Hind bint `Utba said, "O Allah's Messenger (ﷺ)! Abu Sufyan is a miser and he does not give me what is sufficient for me and my children. Can I take of his property without his knowledge?" The Prophet (ﷺ) said, "Take what is sufficient for you and your children, and the amount should be just and reasonable}}
\hadithdefcmd{bukhari}{5365}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، وَأَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ نِسَاءٍ رَكِبْنَ الإِبِلَ نِسَاءُ قُرَيْشٍ ـ وَقَالَ الآخَرُ صَالِحُ نِسَاءِ قُرَيْشٍ ـ أَحْنَاهُ عَلَى وَلَدٍ فِي صِغَرِهِ، وَأَرْعَاهُ عَلَى زَوْجٍ فِي ذَاتِ يَدِهِ ‏"‏‏.‏ وَيُذْكَرُ عَنْ مُعَاوِيَةَ وَابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{5365}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The best women among the camel riders, are the women of Quraish." (Another narrator said) The Prophet (ﷺ) said, "The righteous among the women of Quraish are those who are kind to their young ones and who look after their husband's property}}
\hadithdefcmd{bukhari}{5366}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَبْدُ الْمَلِكِ بْنُ مَيْسَرَةَ، قَالَ سَمِعْتُ زَيْدَ بْنَ وَهْبٍ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ قَالَ آتَى إِلَىَّ النَّبِيُّ صلى الله عليه وسلم حُلَّةً سِيَرَاءَ فَلَبِسْتُهَا، فَرَأَيْتُ الْغَضَبَ فِي وَجْهِهِ فَشَقَّقْتُهَا بَيْنَ نِسَائِي‏.‏\hadithno{5366}\hadithtrans{Narrated `Ali:The Prophet (ﷺ) gave me a silk suit and I wore it, but when I noticed anger on his face, I cut it and distributed it among my women-folk}}
\hadithdefcmd{bukhari}{5367}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرٍو، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ هَلَكَ أَبِي وَتَرَكَ سَبْعَ بَنَاتٍ أَوْ تِسْعَ بَنَاتٍ فَتَزَوَّجْتُ امْرَأَةً ثَيِّبًا فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَزَوَّجْتَ يَا جَابِرُ ‏"‏‏.‏ فَقُلْتُ نَعَمْ‏.‏ فَقَالَ ‏"‏ بِكْرًا أَمْ ثَيِّبًا ‏"‏‏.‏ قُلْتُ بَلْ ثَيِّبًا‏.‏ قَالَ ‏"‏ فَهَلاَّ جَارِيَةً تُلاَعِبُهَا وَتُلاَعِبُكَ، وَتُضَاحِكُهَا وَتُضَاحِكُكَ ‏"‏‏.‏ قَالَ فَقُلْتُ لَهُ إِنَّ عَبْدَ اللَّهِ هَلَكَ وَتَرَكَ بَنَاتٍ، وَإِنِّي كَرِهْتُ أَنْ أَجِيئَهُنَّ بِمِثْلِهِنَّ، فَتَزَوَّجْتُ امْرَأَةً تَقُومُ عَلَيْهِنَّ وَتُصْلِحُهُنَّ‏.‏ فَقَالَ ‏"‏ بَارَكَ اللَّهُ لَكَ ‏"‏‏.‏ أَوْ قَالَ خَيْرًا‏.‏\hadithno{5367}\hadithtrans{Narrated Jabir bin `Abdullah:My father died and left seven or nine girls and I married a matron. Allah's Messenger (ﷺ) said to me, "O Jabir! Have you married?" I said, "Yes." He said, "A virgin or a matron?" I replied, "A matron." he said, "Why not a virgin, so that you might play with her and she with you, and you might amuse her and she amuse you." I said, " `Abdullah (my father) died and left girls, and I dislike to marry a girl like them, so I married a lady (matron) so that she may look after them." On that he said, "May Allah bless you," or "That is good}}
\hadithdefcmd{bukhari}{5368}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ أَتَى النَّبِيَّ صلى الله عليه وسلم رَجُلٌ فَقَالَ هَلَكْتُ‏.‏ قَالَ ‏"‏ وَلِمَ ‏"‏‏.‏ قَالَ وَقَعْتُ عَلَى أَهْلِي فِي رَمَضَانَ‏.‏ قَالَ ‏"‏ فَأَعْتِقْ رَقَبَةً ‏"‏‏.‏ قَالَ لَيْسَ عِنْدِي‏.‏ قَالَ ‏"‏ فَصُمْ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏"‏‏.‏ قَالَ لاَ أَسْتَطِيعُ‏.‏ قَالَ ‏"‏ فَأَطْعِمْ سِتِّينَ مِسْكِينًا ‏"‏‏.‏ قَالَ لاَ أَجِدُ‏.‏ فَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِعَرَقٍ فِيهِ تَمْرٌ فَقَالَ ‏"‏ أَيْنَ السَّائِلُ ‏"‏‏.‏ قَالَ هَا أَنَا ذَا‏.‏ قَالَ ‏"‏ تَصَدَّقْ بِهَذَا ‏"‏‏.‏ قَالَ عَلَى أَحْوَجَ مِنَّا يَا رَسُولَ اللَّهِ فَوَالَّذِي بَعَثَكَ بِالْحَقِّ مَا بَيْنَ لاَبَتَيْهَا أَهْلُ بَيْتٍ أَحْوَجُ مِنَّا فَضَحِكَ النَّبِيُّ صلى الله عليه وسلم حَتَّى بَدَتْ أَنْيَابُهُ قَالَ ‏"‏ فَأَنْتُمْ إِذًا ‏"‏‏.‏\hadithno{5368}\hadithtrans{Narrated Abu Huraira:A man came to the Prophet (ﷺ) and said, "I am ruined!" The Prophet (ﷺ) said, "Why?" He said, "I had sexual intercourse with my wife while fasting (in the month of Ramadan)." The Prophet (ﷺ) said to him, "Manumit a slave (as expiation)." He replied, "I cannot afford that." The Prophet (ﷺ) said, "Then fast for two successive months." He said, "I cannot." The Prophet (ﷺ) said, "Then feed sixty poor persons." He said, "I have nothing to do that." In the meantime a basket full of dates was brought to the Prophet (ﷺ) . He said, "Where is the questioner." The man said, "I am here." The Prophet (ﷺ) said (to him), "Give this (basket of dates) in charity (as expiation)." He said, "O Allah's Messenger (ﷺ)! Shall I give it to poorer people than us? By Him Who sent you with the Truth, there is no family between Medina's two mountains poorer than us." The Prophet (ﷺ) smiled till his pre-molar teeth became visible. He then said, "Then take it}}
\hadithdefcmd{bukhari}{5369}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، أَخْبَرَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ ابْنَةِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قُلْتُ يَا رَسُولَ اللَّهِ هَلْ لِي مِنْ أَجْرٍ فِي بَنِي أَبِي سَلَمَةَ أَنْ أُنْفِقَ عَلَيْهِمْ، وَلَسْتُ بِتَارِكَتِهِمْ هَكَذَا وَهَكَذَا، إِنَّمَا هُمْ بَنِيَّ‏.‏ قَالَ ‏ "‏ نَعَمْ لَكِ أَجْرُ مَا أَنْفَقْتِ عَلَيْهِمْ ‏"‏‏.‏\hadithno{5369}\hadithtrans{Narrated Um Salama:I said, "O Allah's Messenger (ﷺ)! Shall I get a reward (in the Hereafter) if I spend on the children of Abu Salama and do not leave them like this and like this (i.e., poor) but treat them like my children?" The Prophet said, "Yes, you will be rewarded for that which you will spend on them}}
\hadithdefcmd{bukhari}{5370}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ هِنْدُ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سُفْيَانَ رَجُلٌ شَحِيحٌ فَهَلْ عَلَىَّ جُنَاحٌ أَنْ آخُذَ مِنْ مَالِهِ مَا يَكْفِينِي وَبَنِيَّ قَالَ ‏ "‏ خُذِي بِالْمَعْرُوفِ ‏"‏‏.‏\hadithno{5370}\hadithtrans{Narrated `Aisha:Hind (bint `Utba) said, "O Allah's Messenger (ﷺ)! Abu Sufyan is a miser. Is there any harm if I take of his property what will cover me and my children's needs?" The Prophet (ﷺ) said, "Take (according to your needs) in a reasonable manner}}
\hadithdefcmd{bukhari}{5371}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُؤْتَى بِالرَّجُلِ الْمُتَوَفَّى عَلَيْهِ الدَّيْنُ، فَيَسْأَلُ ‏"‏ هَلْ تَرَكَ لِدَيْنِهِ فَضْلاً ‏"‏‏.‏ فَإِنْ حُدِّثَ أَنَّهُ تَرَكَ وَفَاءً صَلَّى، وَإِلاَّ قَالَ لِلْمُسْلِمِينَ ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ ‏"‏‏.‏ فَلَمَّا فَتَحَ اللَّهُ عَلَيْهِ الْفُتُوحَ قَالَ ‏"‏ أَنَا أَوْلَى بِالْمُؤْمِنِينَ مِنْ أَنْفُسِهِمْ، فَمَنْ تُوُفِّيَ مِنَ الْمُؤْمِنِينَ فَتَرَكَ دَيْنًا فَعَلَىَّ قَضَاؤُهُ، وَمَنْ تَرَكَ مَالاً فَلِوَرَثَتِهِ ‏"‏‏.‏\hadithno{5371}\hadithtrans{Narrated Abu Huraira:A dead man in debt used to be brought to Allah's Messenger (ﷺ) who would ask, "Has he left anything to re pay his debts?" If he was informed that he had left something to cover his debts the Prophet (ﷺ) would offer the funeral prayer for him; otherwise he would say to the Muslims present there), "Offer the funeral prayer for your friend:"but when Allah helped the Prophet (ﷺ) to gain victory (on his expeditions), he said, "I am closer to the Believers than themselves, so. if one of the Believers dies in debt, I will repay it, but if he leaves wealth, it will be for his heirs}}
\hadithdefcmd{bukhari}{5372}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ، أَنَّ زَيْنَبَ ابْنَةَ أَبِي سَلَمَةَ، أَخْبَرَتْهُ أَنَّ أُمَّ حَبِيبَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ انْكِحْ أُخْتِي ابْنَةَ أَبِي سُفْيَانَ‏.‏ قَالَ ‏"‏ وَتُحِبِّينَ ذَلِكَ ‏"‏‏.‏ قُلْتُ نَعَمْ لَسْتُ لَكَ بِمُخْلِيَةٍ، وَأَحَبُّ مَنْ شَارَكَنِي فِي الْخَيْرِ أُخْتِي‏.‏ فَقَالَ ‏"‏ إِنَّ ذَلِكَ لاَ يَحِلُّ لِي ‏"‏‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ فَوَاللَّهِ إِنَّا نَتَحَدَّثُ أَنَّكَ تُرِيدُ أَنْ تَنْكِحَ دُرَّةَ ابْنَةَ أَبِي سَلَمَةَ‏.‏ فَقَالَ ‏"‏ ابْنَةَ أُمِّ سَلَمَةَ ‏"‏‏.‏ فَقُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏فَوَاللَّهِ لَوْ لَمْ تَكُنْ رَبِيبَتِي فِي حَجْرِي مَا حَلَّتْ لِي، إِنَّهَا ابْنَةُ أَخِي مِنَ الرَّضَاعَةِ، أَرْضَعَتْنِي وَأَبَا سَلَمَةَ ثُوَيْبَةُ، فَلاَ تَعْرِضْنَ عَلَىَّ بَنَاتِكُنَّ وَلاَ أَخَوَاتِكُنَّ ‏"‏‏.‏ وَقَالَ شُعَيْبٌ عَنِ الزُّهْرِيِّ قَالَ عُرْوَةُ ثُوَيْبَةُ أَعْتَقَهَا أَبُو لَهَبٍ‏.‏\hadithno{5372}\hadithtrans{Narrated Um Habiba:(the wife of the Prophet) I said, "O Allah's Messenger (ﷺ)! Will you marry my sister, the daughter of Abu Sufyan." The Prophet (ﷺ) said, "Do you like that?" I said, "Yes, for I am not your only wife, and the person I like most to share the good with me, is my sister." He said, "That is not lawful for me." I said, "O Allah's Messenger (ﷺ)! We have heard that you want to marry Durra, the daughter of Abu Salama." He said, "You mean the daughter of Um Salama?" I said, "Yes." He said, "Even if she were not my stepdaughter, she is unlawful for me, for she is my foster niece. Thuwaiba suckled me and Abu Salama. So you should not present to me your daughters and sisters." Narrated 'Urwa: Thuwaiba had been a slave girl whom Abu Lahab had emancipated}}
