% Auto-generated chapter 26 for bukhari
% Hadiths in this chapter: 30

\hadithdefcmd{bukhari}{1773}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعُمْرَةُ إِلَى الْعُمْرَةِ كَفَّارَةٌ لِمَا بَيْنَهُمَا، وَالْحَجُّ الْمَبْرُورُ لَيْسَ لَهُ جَزَاءٌ إِلاَّ الْجَنَّةُ ‏"‏‏.‏\hadithno{1773}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "(The performance of) `Umra is an expiation for the sins committed (between it and the previous one). And the reward of Hajj Mabrur (the one accepted by Allah) is nothing except Paradise}}
\hadithdefcmd{bukhari}{1774}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَنَّ عِكْرِمَةَ بْنَ خَالِدٍ، سَأَلَ ابْنَ عُمَرَ ـ رضى الله عنهما ـ عَنِ الْعُمْرَةِ، قَبْلَ الْحَجِّ فَقَالَ لاَ بَأْسَ‏.‏ قَالَ عِكْرِمَةُ قَالَ ابْنُ عُمَرَ اعْتَمَرَ النَّبِيُّ صلى الله عليه وسلم قَبْلَ أَنْ يَحُجَّ‏.‏ وَقَالَ إِبْرَاهِيمُ بْنُ سَعْدٍ عَنِ ابْنِ إِسْحَاقَ حَدَّثَنِي عِكْرِمَةُ بْنُ خَالِدٍ سَأَلْتُ ابْنَ عُمَرَ مِثْلَهُ‏.‏ حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو عَاصِمٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ عِكْرِمَةُ بْنُ خَالِدٍ سَأَلْتُ ابْنَ عُمَرَ ـ رضى الله عنه ـ مِثْلَهُ‏.‏\hadithno{1774}\hadithtrans{Narrated Ibn Juraij:`Ikrima bin Khalid asked Ibn `Umar about performing `Umra before Hajj. Ibn `Umar replied, "There is no harm in it." `Ikrima said, "Ibn `Umar also said, 'The Prophet (ﷺ) had performed `Umra before performing Hajj.'" Narrated `Ikrima bin Khalid: "I asked Ibn `Umar the same (as above)}}
\hadithdefcmd{bukhari}{1776}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، قَالَ دَخَلْتُ أَنَا وَعُرْوَةُ بْنُ الزُّبَيْرِ الْمَسْجِدَ،، فَإِذَا عَبْدُ اللَّهِ بْنُ عُمَرَ ـ رضى الله عنهما ـ جَالِسٌ إِلَى حُجْرَةِ عَائِشَةَ، وَإِذَا نَاسٌ يُصَلُّونَ فِي الْمَسْجِدِ صَلاَةَ الضُّحَى‏.‏ قَالَ فَسَأَلْنَاهُ عَنْ صَلاَتِهِمْ‏.‏ فَقَالَ بِدْعَةٌ‏.‏ ثُمَّ قَالَ لَهُ كَمِ اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ أَرْبَعً إِحْدَاهُنَّ فِي رَجَبٍ، فَكَرِهْنَا أَنْ نَرُدَّ عَلَيْهِ‏.‏ قَالَ وَسَمِعْنَا اسْتِنَانَ، عَائِشَةَ أُمِّ الْمُؤْمِنِينَ فِي الْحُجْرَةِ، فَقَالَ عُرْوَةُ يَا أُمَّاهُ، يَا أُمَّ الْمُؤْمِنِينَ‏.‏ أَلاَ تَسْمَعِينَ مَا يَقُولُ أَبُو عَبْدِ الرَّحْمَنِ‏.‏ قَالَتْ مَا يَقُولُ قَالَ يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اعْتَمَرَ أَرْبَعَ عُمَرَاتٍ إِحْدَاهُنَّ فِي رَجَبٍ‏.‏ قَالَتْ يَرْحَمُ اللَّهُ أَبَا عَبْدِ الرَّحْمَنِ، مَا اعْتَمَرَ عُمْرَةً إِلاَّ وَهُوَ شَاهِدُهُ، وَمَا اعْتَمَرَ فِي رَجَبٍ قَطُّ‏.‏\hadithno{1776}\hadithtrans{Narrated Mujahid:Urwa bin Az-Zubair and I entered the Mosque (of the Prophet) and saw `Abdullah bin `Umar sitting near the dwelling place of Aisha and some people were offering the Duha prayer. We asked him about their prayer and he replied that it was a heresy. He (Urwa) then asked him how many times the Prophet (ﷺ) had performed `Umra. He replied, 'Four times; one of them was in the month of Rajab." We disliked to contradict him. Then we heard `Aisha, the Mother of faithful believers cleaning her teeth with Siwak in the dwelling place. 'Urwa said, "O Mother! O Mother of the believers! Don't you hear what Abu `Abdur Rahman is saying?" She said, "What does he say?" 'Urwa said, "He says that Allah's Messenger (ﷺ) performed four `Umra and one of them was in the month of Rajab." `Aisha said, "May Allah be merciful to Abu `Abdur Rahman! The Prophet (ﷺ) did not perform any `Umra except that he was with him, and he never performed any `Umra in Rajab}}
\hadithdefcmd{bukhari}{1777}{حَدَّثَنَا أَبُو عَاصِمٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، قَالَ سَأَلْتُ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي رَجَبٍ‏.‏\hadithno{1777}\hadithtrans{Narrated 'Urwa bin Az-Zubair:I asked `Aisha (whether the Prophet (ﷺ) had performed `Umra in Rajab). She replied, "Allah's Messenger (ﷺ) never performed any `Umra in Rajab}}
\hadithdefcmd{bukhari}{1778}{حَدَّثَنَا حَسَّانُ بْنُ حَسَّانٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، سَأَلْتُ أَنَسًا ـ رضى الله عنه ـ كَمِ اعْتَمَرَ النَّبِيُّ صلى الله عليه وسلم قَالَ أَرْبَعٌ عُمْرَةُ الْحُدَيْبِيَةِ فِي ذِي الْقَعْدَةِ، حَيْثُ صَدَّهُ الْمُشْرِكُونَ، وَعُمْرَةٌ مِنَ الْعَامِ الْمُقْبِلِ فِي ذِي الْقَعْدَةِ، حَيْثُ صَالَحَهُمْ، وَعُمْرَةُ الْجِعْرَانَةِ إِذْ قَسَمَ غَنِيمَةَ أُرَاهُ حُنَيْنٍ‏.‏ قُلْتُ كَمْ حَجَّ قَالَ وَاحِدَةً‏.‏\hadithno{1778}\hadithtrans{Narrated Qatada:I asked Anas how many times the Prophet (ﷺ) had performed `Umra. He replied, "Four times. 1. `Umra of Hudaibiya in Dhil-Qa'da when the pagans hindered him; 2. `Umra in the following year in Dhil-Qa'da after the peace treaty with them (the pagans); 3. `Umra from Al-Ji'rana where he distributed the war booty." I think he meant the booty (of the battle) of Hunain. I asked, "How many times did he perform Hajj?" He (Anas) replied, "Once}}
\hadithdefcmd{bukhari}{1779}{حَدَّثَنَا أَبُو الْوَلِيدِ، هِشَامُ بْنُ عَبْدِ الْمَلِكِ حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، قَالَ سَأَلْتُ أَنَسًا ـ رضى الله عنه ـ فَقَالَ اعْتَمَرَ النَّبِيُّ صلى الله عليه وسلم حَيْثُ رَدُّوهُ، وَمِنَ الْقَابِلِ عُمْرَةَ الْحُدَيْبِيَةِ، وَعُمْرَةً فِي ذِي الْقَعْدَةِ وَعُمْرَةً مَعَ حَجَّتِهِ‏.‏\hadithno{1779}\hadithtrans{Narrated Qatada:I asked Anas (about the Prophet's `Umra) and he replied, "The Prophet (ﷺ) performed `Umra when the pagans made him return, and Umra of al-Hudaibiya (the next year), and another `Umra in Dhi-l-Qa'da, and another `Umra in combination with his Hajj}}
\hadithdefcmd{bukhari}{1780}{حَدَّثَنَا هُدْبَةُ، حَدَّثَنَا هَمَّامٌ، وَقَالَ، اعْتَمَرَ أَرْبَعَ عُمَرٍ فِي ذِي الْقَعْدَةِ إِلاَّ الَّتِي اعْتَمَرَ مَعَ حَجَّتِهِ عُمْرَتَهُ مِنَ الْحُدَيْبِيَةِ، وَمِنَ الْعَامِ الْمُقْبِلِ، وَمِنَ الْجِعْرَانَةِ، حَيْثُ قَسَمَ غَنَائِمَ حُنَيْنٍ، وَعُمْرَةً مَعَ حَجَّتِهِ‏.‏\hadithno{1780}\hadithtrans{Narrated Hammam:The Prophet (ﷺ) performed four `Umra (three) in Dhi-l-Qa'da except the (one) `Umra which he performed with his Hajj: His `Umra from Al-hudaibiya, and the one of the following year, and the one from Al-Ji'rana where he distributed the booty (of the battle) of Hunain, and another `Umra with his Hajj}}
\hadithdefcmd{bukhari}{1781}{حَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ، حَدَّثَنَا شُرَيْحُ بْنُ مَسْلَمَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ يُوسُفَ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَأَلْتُ مَسْرُوقًا وَعَطَاءً وَمُجَاهِدًا‏.‏ فَقَالُوا اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ذِي الْقَعْدَةِ قَبْلَ أَنْ يَحُجَّ‏.‏ وَقَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ ـ رضى الله عنهما ـ يَقُولُ اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ذِي الْقَعْدَةِ، قَبْلَ أَنْ يَحُجَّ مَرَّتَيْنِ‏.‏\hadithno{1781}\hadithtrans{Narrated Abu 'Is-haq:I asked Masruq, `Ata' and Mujahid (about the `Umra of Allah's Messenger (ﷺ)). They said, "Allah's Messenger (ﷺ) had performed `Umra in Dhi-l-Qa'da before he performed Hajj." I heard Al-Bara' bin `Azib saying, "Allah's Messenger (ﷺ) had performed `Umra in Dhi-l-Qa'da twice before he performed Hajj}}
\hadithdefcmd{bukhari}{1782}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يُخْبِرُنَا يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاِمْرَأَةٍ مِنَ الأَنْصَارِ سَمَّاهَا ابْنُ عَبَّاسٍ، فَنَسِيتُ اسْمَهَا ‏"‏ مَا مَنَعَكِ أَنْ تَحُجِّي مَعَنَا ‏"‏‏.‏ قَالَتْ كَانَ لَنَا نَاضِحٌ فَرَكِبَهُ أَبُو فُلاَنٍ وَابْنُهُ ـ لِزَوْجِهَا وَابْنِهَا ـ وَتَرَكَ نَاضِحًا نَنْضَحُ عَلَيْهِ قَالَ ‏"‏ فَإِذَا كَانَ رَمَضَانُ اعْتَمِرِي فِيهِ فَإِنَّ عُمْرَةً فِي رَمَضَانَ حَجَّةٌ ‏"‏‏.‏ أَوْ نَحْوًا مِمَّا قَالَ‏.‏\hadithno{1782}\hadithtrans{Narrated Ata:I heard Ibn `Abbas saying, "Allah's Messenger (ﷺ) asked an Ansari woman (Ibn `Abbas named her but `Ata' forgot her name), 'What prevented you from performing Hajj with us?' She replied, 'We have a camel and the father of so-and-so and his son (i.e. her husband and her son) rode it and left one camel for us to use for irrigation.' He said (to her), 'Perform `Umra when Ramadan comes, for `Umra in Ramadan is equal to Hajj (in reward),' or said something similar}}
\hadithdefcmd{bukhari}{1783}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُوَافِينَ لِهِلاَلِ ذِي الْحَجَّةِ فَقَالَ لَنَا ‏"‏ مَنْ أَحَبَّ مِنْكُمْ أَنْ يُهِلَّ بِالْحَجِّ فَلْيُهِلَّ وَمَنْ أَحَبَّ أَنْ يُهِلَّ بِعُمْرَةٍ فَلْيُهِلَّ بِعُمْرَةٍ، فَلَوْلاَ أَنِّي أَهْدَيْتُ لأَهْلَلْتُ بِعُمْرَةٍ ‏"‏‏.‏ قَالَتْ فَمِنَّا مَنْ أَهَلَّ بِعُمْرَةٍ، وَمِنَّا مَنْ أَهَلَّ بِحَجٍّ، وَكُنْتُ مِمَّنْ أَهَلَّ بِعُمْرَةٍ، فَأَظَلَّنِي يَوْمُ عَرَفَةَ، وَأَنَا حَائِضٌ، فَشَكَوْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ ارْفُضِي عُمْرَتَكِ، وَانْقُضِي رَأْسَكِ وَامْتَشِطِي، وَأَهِلِّي بِالْحَجِّ ‏"‏‏.‏ فَلَمَّا كَانَ لَيْلَةُ الْحَصْبَةِ أَرْسَلَ مَعِي عَبْدَ الرَّحْمَنِ إِلَى التَّنْعِيمِ، فَأَهْلَلْتُ بِعُمْرَةٍ مَكَانَ عُمْرَتِي‏.‏\hadithno{1783}\hadithtrans{Narrated Aisha:We set out along with Allah's Messenger (ﷺ) shortly before the appearance of the new moon (crescent) of the month of Dhi-l-Hijja and he said to us, "Whoever wants to assume Ihram for Hajj may do so; and whoever wants to assume Ihram for `Umra may do so. Hadn't I brought the Hadi (animal for sacrificing) (with me), I would have assumed Ihram for `Umra." (`Aisha added,): So some of us assumed Ihram for `Umra while the others for Hajj. I was amongst those who assumed Ihram for `Umra. The day of `Arafat approached and I was still menstruating. I complained to the Prophet (ﷺ) (about that) and he said, "Abandon your `Umra, undo and comb your hair, and assume Ihram for Hajj;." When it was the night of Hasba, he sent `Abdur Rahman with me to at-Tan`im and I assumed Ihram for `Umra (and performed it) in lieu of my missed `Umra}}
\hadithdefcmd{bukhari}{1784}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعَ عَمْرَو بْنَ أَوْسٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهُ أَنْ يُرْدِفَ عَائِشَةَ، وَيُعْمِرَهَا مِنَ التَّنْعِيمِ‏.‏ قَالَ سُفْيَانُ مَرَّةً سَمِعْتُ عَمْرًا، كَمْ سَمِعْتُهُ مِنْ عَمْرٍو‏.‏\hadithno{1784}\hadithtrans{Narrated `Amr bin Aus:`Abdur-Rahman bin Abu Bakr told me that the Prophet (ﷺ) had ordered him to let `Aisha ride behind him and to make her perform `Umra from at-Tan`im}}
\hadithdefcmd{bukhari}{1785}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْمَجِيدِ، عَنْ حَبِيبٍ الْمُعَلِّمِ، عَنْ عَطَاءٍ، حَدَّثَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَهَلَّ وَأَصْحَابُهُ بِالْحَجِّ وَلَيْسَ مَعَ أَحَدٍ مِنْهُمْ هَدْىٌ، غَيْرَ النَّبِيِّ صلى الله عليه وسلم وَطَلْحَةَ، وَكَانَ عَلِيٌّ قَدِمَ مِنَ الْيَمَنِ، وَمَعَهُ الْهَدْىُ فَقَالَ أَهْلَلْتُ بِمَا أَهَلَّ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ وَإِنَّ النَّبِيَّ صلى الله عليه وسلم أَذِنَ لأَصْحَابِهِ أَنْ يَجْعَلُوهَا عُمْرَةً، يَطُوفُوا بِالْبَيْتِ، ثُمَّ يُقَصِّرُوا وَيَحِلُّوا، إِلاَّ مَنْ مَعَهُ الْهَدْىُ، فَقَالُوا نَنْطَلِقُ إِلَى مِنًى وَذَكَرُ أَحَدِنَا يَقْطُرُ فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ لَوِ اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ مَا أَهْدَيْتُ، وَلَوْلاَ أَنَّ مَعِي الْهَدْىَ لأَحْلَلْتُ ‏"‏‏.‏ وَأَنَّ عَائِشَةَ حَاضَتْ فَنَسَكَتِ الْمَنَاسِكَ كُلَّهَا، غَيْرَ أَنَّهَا لَمْ تَطُفْ بِالْبَيْتِ قَالَ فَلَمَّا طَهُرَتْ وَطَافَتْ، قَالَتْ يَا رَسُولَ اللَّهِ أَتَنْطَلِقُونَ بِعُمْرَةٍ وَحَجَّةٍ، وَأَنْطَلِقُ بِالْحَجِّ فَأَمَرَ عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ أَنْ يَخْرُجَ مَعَهَا إِلَى التَّنْعِيمِ، فَاعْتَمَرَتْ بَعْدَ الْحَجِّ فِي ذِي الْحَجَّةِ، وَأَنَّ سُرَاقَةَ بْنَ مَالِكِ بْنِ جُعْشُمٍ لَقِيَ النَّبِيَّ صلى الله عليه وسلم وَهُوَ بِالْعَقَبَةِ، وَهُوَ يَرْمِيهَا، فَقَالَ أَلَكُمْ هَذِهِ خَاصَّةً، يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لاَ، بَلْ لِلأَبَدِ ‏"‏‏.‏\hadithno{1785}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) and his companions assumed Ihram for Hajj and none except the Prophet (ﷺ) and Talha had the Hadi with them. `Ali had come from Yemen and he had the Hadi with him. He (`Ali) said, "I have assumed Ihram with an intention like that of Allah's Messenger (ﷺ) has assumed it." The Prophet (ﷺ) ordered his companions to intend the Ihram with which they had come for `Umra, to perform the Tawaf of the Ka`ba (and between Safa and Marwa), to get their hair cut short and then to finish their Ihram with the exception of those who had the Hadi with them. They asked, "Shall we go to Mina and the private organs of some of us are dribbling (if we finish Ihram and have sexual relations with our wives)?" The Prophet heard that and said, "Had I known what I know now, I would not have brought the Hadi. If I did not have the Hadi with me I would have finished my Ihram." `Aisha got her menses and performed all the ceremonies (of Hajj) except the Tawaf . So when she became clean from her menses, and she had performed the Tawaf of the Ka`ba, she said, "O Allah's Messenger (ﷺ)! You (people) are returning with both Hajj and `Umra and I am returning only with Hajj!" So, he ordered `Abdur Rahman bin Abu Bakr to go with her to at-Tan`im. Thus she performed `Umra after the Hajj in the month of Dhi-l-Hijja. Suraqa bin Malik bin Ju'shum met the Prophet (ﷺ) at Al-`Aqaba (Jamrat-ul 'Aqaba) while the latter was stoning it and said, "O Allah's Messenger (ﷺ)! Is this permissible only for you?" The Prophet replied, "No, it is for ever (i.e. it is permissible for all Muslims to perform `Umra before Hajj)}}
\hadithdefcmd{bukhari}{1786}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، حَدَّثَنَا هِشَامٌ، قَالَ أَخْبَرَنِي أَبِي قَالَ، أَخْبَرَتْنِي عَائِشَةُ ـ رضى الله عنها ـ قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُوَافِينَ لِهِلاَلِ ذِي الْحَجَّةِ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَحَبَّ أَنْ يُهِلَّ بِعُمْرَةٍ فَلْيُهِلَّ، وَمَنْ أَحَبَّ أَنْ يُهِلَّ بِحَجَّةِ فَلْيُهِلَّ، وَلَوْلاَ أَنِّي أَهْدَيْتُ لأَهْلَلْتُ بِعُمْرَةٍ ‏"‏‏.‏ فَمِنْهُمْ مَنْ أَهَلَّ بِعُمْرَةٍ، وَمِنْهُمْ مِنْ أَهَلَّ بِحَجَّةٍ، وَكُنْتُ مِمَّنْ أَهَلَّ بِعُمْرَةٍ، فَحِضْتُ قَبْلَ أَنْ أَدْخُلَ مَكَّةَ، فَأَدْرَكَنِي يَوْمُ عَرَفَةَ، وَأَنَا حَائِضٌ، فَشَكَوْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ دَعِي عُمْرَتَكِ، وَانْقُضِي رَأْسَكِ وَامْتَشِطِي، وَأَهِلِّي بِالْحَجِّ ‏"‏‏.‏ فَفَعَلْتُ، فَلَمَّا كَانَتْ لَيْلَةُ الْحَصْبَةِ أَرْسَلَ مَعِي عَبْدَ الرَّحْمَنِ إِلَى التَّنْعِيمِ، فَأَرْدَفَهَا، فَأَهَلَّتْ بِعُمْرَةٍ مَكَانَ عُمْرَتِهَا، فَقَضَى اللَّهُ حَجَّهَا وَعُمْرَتَهَا، وَلَمْ يَكُنْ فِي شَىْءٍ مِنْ ذَلِكَ هَدْىٌ، وَلاَ صَدَقَةٌ، وَلاَ صَوْمٌ‏.‏\hadithno{1786}\hadithtrans{Narrated `Aisha:We set out with Allah's Messenger (ﷺ) shortly before the appearance of the new moon of Dhi-l-Hijja and he said, "Whoever wants to assume Ihram for `Umra may do so, and whoever wants to assume Ihram for Hajj may do so. Had not I brought the Hadi with me, I would have assumed Ihram for `Umra." Some of the people assumed Ihram for `Umra while others for Hajj. I was amongst those who had assumed Ihram for `Umra. I got my menses before entering Mecca, and was menstruating till the day of `Arafat. I complained to Allah's Messenger (ﷺ) about it, he said, "Abandon your `Umra, undo and comb your hair, and assume Ihram for Hajj." So, I did that accordingly. When it was the night of Hasba (day of departure from Mina), the Prophet (ﷺ) sent `Abdur Rahman with me to at-Tan`im. The sub-narrator adds: He (`Abdur-Rahman) let her ride behind him. And she assumed Ihram for `Umra in lieu of the abandoned one. Aisha completed her Hajj and `Umra, and no Hadi, Sadaqa (charity), or fasting was obligatory for her}}
\hadithdefcmd{bukhari}{1787}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، وَعَنِ ابْنِ عَوْنٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، قَالاَ قَالَتْ عَائِشَةُ ـ رضى الله عنها ـ يَا رَسُولَ اللَّهِ يَصْدُرُ النَّاسُ بِنُسُكَيْنِ وَأَصْدُرُ بِنُسُكٍ فَقِيلَ لَهَا ‏ "‏ انْتَظِرِي، فَإِذَا طَهُرْتِ فَاخْرُجِي إِلَى التَّنْعِيمِ، فَأَهِلِّي ثُمَّ ائْتِينَا بِمَكَانِ كَذَا، وَلَكِنَّهَا عَلَى قَدْرِ نَفَقَتِكِ، أَوْ نَصَبِكِ ‏"‏‏.‏\hadithno{1787}\hadithtrans{Narrated Al-Aswad:That `Aisha said, "O Allah's Messenger (ﷺ)! The people are returning after performing the two Nusuks (i.e. Hajj and `Umra) but I am returning with one only?" He said, "Wait till you become clean from your menses and then go to at-Tan`im, assume Ihram (and after performing `Umra) join us at such-and-such a place. But it (i.e. the reward of `Umra) is according to your expenses or the hardship (which you will undergo while performing it)}}
\hadithdefcmd{bukhari}{1788}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا أَفْلَحُ بْنُ حُمَيْدٍ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ خَرَجْنَا مُهِلِّينَ بِالْحَجِّ فِي أَشْهُرِ الْحَجِّ، وَحُرُمِ الْحَجِّ، فَنَزَلْنَا سَرِفَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم لأَصْحَابِهِ ‏"‏ مَنْ لَمْ يَكُنْ مَعَهُ هَدْىٌ، فَأَحَبَّ أَنْ يَجْعَلَهَا عُمْرَةً، فَلْيَفْعَلْ وَمَنْ كَانَ مَعَهُ هَدْىٌ فَلاَ ‏"‏‏.‏ وَكَانَ مَعَ النَّبِيِّ صلى الله عليه وسلم وَرِجَالٍ مِنْ أَصْحَابِهِ ذَوِي قُوَّةٍ الْهَدْىُ، فَلَمْ تَكُنْ لَهُمْ عُمْرَةً، فَدَخَلَ عَلَىَّ النَّبِيُّ صلى الله عليه وسلم وَأَنَا أَبْكِي فَقَالَ ‏"‏ مَا يُبْكِيكِ ‏"‏‏.‏ قُلْتُ سَمِعْتُكَ تَقُولُ لأَصْحَابِكَ مَا قُلْتَ فَمُنِعْتُ الْعُمْرَةَ‏.‏ قَالَ ‏"‏ وَمَا شَأْنُكِ ‏"‏‏.‏ قُلْتُ لاَ أُصَلِّي‏.‏ قَالَ ‏"‏ فَلاَ يَضُرَّكِ أَنْتِ مِنْ بَنَاتِ آدَمَ، كُتِبَ عَلَيْكِ مَا كُتِبَ عَلَيْهِنَّ، فَكُونِي فِي حَجَّتِكِ عَسَى اللَّهُ أَنْ يَرْزُقَكِهَا ‏"‏‏.‏ قَالَتْ فَكُنْتُ حَتَّى نَفَرْنَا مِنْ مِنًى، فَنَزَلْنَا الْمُحَصَّبَ فَدَعَا عَبْدَ الرَّحْمَنِ، فَقَالَ ‏"‏ اخْرُجْ بِأُخْتِكَ الْحَرَمَ، فَلْتُهِلَّ بِعُمْرَةٍ، ثُمَّ افْرُغَا مِنْ طَوَافِكُمَا، أَنْتَظِرْكُمَا هَا هُنَا ‏"‏‏.‏ فَأَتَيْنَا فِي جَوْفِ اللَّيْلِ‏.‏ فَقَالَ ‏"‏ فَرَغْتُمَا ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ فَنَادَى بِالرَّحِيلِ فِي أَصْحَابِهِ، فَارْتَحَلَ النَّاسُ، وَمَنْ طَافَ بِالْبَيْتِ، قَبْلَ صَلاَةِ الصُّبْحِ، ثُمَّ خَرَجَ مُوَجِّهًا إِلَى الْمَدِينَةِ‏.‏\hadithno{1788}\hadithtrans{Narrated `Aisha:We set out assuming the Ihram for Hajj in the months of Hajj towards the sacred precincts of Hajj. We dismounted at Sarif and the Prophet (ﷺ) said to his companions, "Whoever has not got the Hadi with him and likes to make it as `Umra, he should do it, but he who has got the Hadi with him should not do it." The Prophet (ﷺ) and some of his wealthy companions had the Hadi with them, so they did not finish Ihram after performing the `Umra. The Prophet (ﷺ) came to me while I was weeping. He asked me the reason for it. I replied, "I have heard of what you have said to your companions and I cannot do the `Umra." He asked me, "What is the matter with you?" I replied, "I am not praying." He said, "There is no harm in it as you are one of the daughters of Adam and the same is written for you as for others. So, you should perform Hajj and I hope that Allah will enable you to perform the `Umra as well." So, I carried on till we departed from Mina and halted at Al-Mahassab. The Prophet (ﷺ) called `Abdur- Rahman and said, "Go out of the sanctuary with your sister and let her assume Ihram for `Umra, and after both of you have finished the Tawaf I will be waiting for you at this place." We came back at midnight and the Prophet (ﷺ) asked us, "Have you finished?" I replied in the affirmative. He announced the departure and the people set out for the journey and some of them had performed the Tawaf of the Ka`ba before the morning prayer, and after that the Prophet (ﷺ) set out for Medina}}
\hadithdefcmd{bukhari}{1789}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا عَطَاءٌ، قَالَ حَدَّثَنِي صَفْوَانُ بْنُ يَعْلَى بْنِ أُمَيَّةَ يَعْنِي، عَنْ أَبِيهِ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم وَهُوَ بِالْجِعْرَانَةِ وَعَلَيْهِ جُبَّةٌ وَعَلَيْهِ أَثَرُ الْخَلُوقِ أَوْ قَالَ صُفْرَةٍ فَقَالَ كَيْفَ تَأْمُرُنِي أَنْ أَصْنَعَ فِي عُمْرَتِي فَأَنْزَلَ اللَّهُ عَلَى النَّبِيِّ صلى الله عليه وسلم، فَسُتِرَ بِثَوْبٍ وَوَدِدْتُ أَنِّي قَدْ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَقَدْ أُنْزِلَ عَلَيْهِ الْوَحْىُ‏.‏ فَقَالَ عُمَرُ تَعَالَ أَيَسُرُّكَ أَنْ تَنْظُرَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَقَدْ أَنْزَلَ اللَّهُ الْوَحْىَ قُلْتُ نَعَمْ‏.‏ فَرَفَعَ طَرَفَ الثَّوْبِ، فَنَظَرْتُ إِلَيْهِ لَهُ غَطِيطٌ وَأَحْسِبُهُ قَالَ كَغَطِيطِ الْبَكْرِ‏.‏ فَلَمَّا سُرِّيَ عَنْهُ قَالَ ‏ "‏ أَيْنَ السَّائِلُ عَنِ الْعُمْرَةِ اخْلَعْ عَنْكَ الْجُبَّةَ وَاغْسِلْ أَثَرَ الْخَلُوقِ عَنْكَ، وَأَنْقِ الصُّفْرَةَ، وَاصْنَعْ فِي عُمْرَتِكَ كَمَا تَصْنَعُ فِي حَجِّكِ ‏"‏‏.‏\hadithno{1789}\hadithtrans{Narrated Safwan bin Ya`la bin Umaiya from his father who said:"A man came to the Prophet (ﷺ) while he was at Ji'rana. The man was wearing a cloak which had traces of Khaluq or Sufra (a kind of perfume). The man asked (the Prophet (ﷺ) ), 'What do you order me to perform in my `Umra?' So, Allah inspired the Prophet (ﷺ) divinely and he was screened by a piece of cloth. I wished to see the Prophet (ﷺ) being divinely inspired. `Umar said to me, 'Come! Will you be pleased to look at the Prophet (ﷺ) while Allah is inspiring him?' I replied in the affirmative. `Umar lifted one corner of the cloth and I looked at the Prophet (ﷺ) who was snoring. (The sub-narrator thought that he said: The snoring was like that of a camel). When that state was over, the Prophet (ﷺ) asked, "Where is the questioner who asked about `Umra? Put off your cloak and wash away the traces of Khaluq from your body and clean the Sufra (yellow color) and perform in your Umra what you perform in your Hajj (i.e. the Tawaf round the Ka`ba and the Sa`i between Safa and Marwa)}}
\hadithdefcmd{bukhari}{1790}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ قُلْتُ لِعَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَأَنَا يَوْمَئِذٍ حَدِيثُ السِّنِّ أَرَأَيْتِ قَوْلَ اللَّهِ تَبَارَكَ وَتَعَالَى ‏\{‏إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ فَمَنْ حَجَّ الْبَيْتَ أَوِ اعْتَمَرَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا‏\}‏ فَلاَ أُرَى عَلَى أَحَدٍ شَيْئًا أَنْ لاَ يَطَّوَّفَ بِهِمَا‏.‏ فَقَالَتْ عَائِشَةُ كَلاَّ، لَوْ كَانَتْ كَمَا تَقُولُ كَانَتْ فَلاَ جُنَاحَ عَلَيْهِ أَنْ لاَ يَطَّوَّفَ بِهِمَا‏.‏ إِنَّمَا أُنْزِلَتْ هَذِهِ الآيَةُ فِي الأَنْصَارِ كَانُوا يُهِلُّونَ لِمَنَاةَ، وَكَانَتْ مَنَاةُ حَذْوَ قُدَيْدٍ، وَكَانُوا يَتَحَرَّجُونَ أَنْ يَطُوفُوا بَيْنَ الصَّفَا وَالْمَرْوَةِ، فَلَمَّا جَاءَ الإِسْلاَمُ سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ، فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ فَمَنْ حَجَّ الْبَيْتَ أَوِ اعْتَمَرَ فَلاَ جُنَاحَ عَلَيْهِ أَنْ يَطَّوَّفَ بِهِمَا‏\}‏‏.‏ زَادَ سُفْيَانُ وَأَبُو مُعَاوِيَةَ عَنْ هِشَامٍ مَا أَتَمَّ اللَّهُ حَجَّ امْرِئٍ وَلاَ عُمْرَتَهُ لَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ‏.‏\hadithno{1790}\hadithtrans{Narrated Hisham Ibn `Urwa from his father who said:While I was a youngster, I asked `Aisha the wife of the Prophet. "What about the meaning of the Statement of Allah; "Verily! (the mountains) As-Safa and Al Marwa, are among the symbols of Allah. So, it is not harmful if those who perform Hajj or `Umra of the House (Ka`ba at Mecca) to perform the going (Tawaf) between them? (2.158) I understand (from that) that there is no harm if somebody does not perform the Tawaf between them." `Aisha replied, "No, for if it were as you are saying, then the recitation would have been like this: 'It is not harmful not to perform Tawaf between them.' This verse was revealed in connection with the Ansar who used to assume the Ihram for the idol Manat which was put beside a place called Qudaid and those people thought it not right to perform the Tawaf of As- Safa and Al-Marwa. When Islam came, they asked Allah's Messenger (ﷺ) about that, and Allah revealed:-- "Verily! (the mountains) As-Safa and Al-Marwa Are among the symbols of Allah. So, it is not harmful of those who perform Hajj or `Umra of the House (Ka`ba at Mecca) to perform the going (Tawaf) between them." (2.158) Sufyan and Abu Muawiya added from Hisham (from `Aisha): "The Hajj or `Umra of the person who does not perform the going (Tawaf) between As-Safa and Al-Marwa is incomplete in Allah's sight}}
\hadithdefcmd{bukhari}{1792}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنْ جَرِيرٍ، عَنْ إِسْمَاعِيلَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَاعْتَمَرْنَا مَعَهُ فَلَمَّا دَخَلَ مَكَّةَ طَافَ وَطُفْنَا مَعَهُ، وَأَتَى الصَّفَا وَالْمَرْوَةَ وَأَتَيْنَاهَا مَعَهُ، وَكُنَّا نَسْتُرُهُ مِنْ أَهْلِ مَكَّةَ أَنْ يَرْمِيَهُ أَحَدٌ‏.‏ فَقَالَ لَهُ صَاحِبٌ لِي أَكَانَ دَخَلَ الْكَعْبَةَ قَالَ لاَ‏.‏ قَالَ فَحَدِّثْنَا مَا، قَالَ لِخَدِيجَةَ‏.‏ قَالَ ‏ "‏ بَشِّرُوا خَدِيجَةَ بِبَيْتٍ فِي الْجَنَّةِ مِنْ قَصَبٍ لاَ صَخَبَ فِيهِ وَلاَ نَصَبَ ‏"‏‏.‏\hadithno{1792}\hadithtrans{Narrated Isma`il:`Abdullah bin Abu `Aufa said: "Allah's Messenger (ﷺ) performed `Umra and we too performed `Umra along with him. When he entered Mecca he performed the Tawaf (of Ka`ba) and we too performed it along with him, and then he came to the As-Safa and Al-Marwa (i.e. performed the Sai) and we also came to them along with him. We were shielding him from the people of Mecca lest they may hit him with an arrow." A friend of his asked him (i.e. `Abdullah bin `Aufa), "Did the Prophet (ﷺ) enter the Ka`ba (during that `Umra)?" He replied in the negative. Then he said, "What did he (the Prophet (ﷺ) ) say about Khadija?" He (Abdullah bin `Aufa) said, "(He said) 'Give Khadija the good tidings that she will have a palace made of Qasab in Paradise and there will be neither noise nor any trouble in it}}
\hadithdefcmd{bukhari}{1794}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ سَأَلْنَا ابْنَ عُمَرَ ـ رضى الله عنهما ـ عَنْ رَجُلٍ، طَافَ بِالْبَيْتِ فِي عُمْرَةٍ، وَلَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ، أَيَأْتِي امْرَأَتَهُ فَقَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم فَطَافَ بِالْبَيْتِ سَبْعًا، وَصَلَّى خَلْفَ الْمَقَامِ رَكْعَتَيْنِ، وَطَافَ بَيْنَ الصَّفَا وَالْمَرْوَةِ سَبْعًا، وَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏.‏ قَالَ وَسَأَلْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ فَقَالَ لاَ يَقْرَبَنَّهَا حَتَّى يَطُوفَ بَيْنَ الصَّفَا وَالْمَرْوَةِ‏.‏\hadithno{1794}\hadithtrans{Narrated `Amr bin Dinar:We asked Ibn `Umar whether a man who had performed the Tawaf of the Ka`ba but had not performed the Tawaf between As-Safa and Al-Marwa yet, was permitted to have sexual relation with his wife. He replied, "The Prophet (ﷺ) arrived (at Mecca) and circumambulated the Ka`ba seven times and then offered a two rak`at prayer behind Maqam-Ibrahim and then performed the going (Tawaf) between As-Safa and Al-Marwa (seven times) (and verily, in Allah's Messenger (ﷺ) you have a good example." And we asked Jabir bin `Abdullah (the same question) and he replied, "He should not go near her till he has finished the going (Tawaf) between As-Safa and Al-Marwa}}
\hadithdefcmd{bukhari}{1795}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ ـ رضى الله عنه ـ قَالَ قَدِمْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم بِالْبَطْحَاءِ وَهُوَ مُنِيخٌ فَقَالَ ‏"‏ أَحَجَجْتَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ بِمَا أَهْلَلْتَ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ بِإِهْلاَلٍ كَإِهْلاَلِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أَحْسَنْتَ‏.‏ طُفْ بِالْبَيْتِ وَبِالصَّفَا وَالْمَرْوَةِ ثُمَّ أَحِلَّ ‏"‏‏.‏ فَطُفْتُ بِالْبَيْتِ، وَبِالصَّفَا وَالْمَرْوَةِ، ثُمَّ أَتَيْتُ امْرَأَةً مِنْ قَيْسٍ، فَفَلَتْ رَأْسِي، ثُمَّ أَهْلَلْتُ بِالْحَجِّ‏.‏ فَكُنْتُ أُفْتِي بِهِ، حَتَّى كَانَ فِي خِلاَفَةِ عُمَرَ فَقَالَ إِنْ أَخَذْنَا بِكِتَابِ اللَّهِ فَإِنَّهُ يَأْمُرُنَا بِالتَّمَامِ، وَإِنْ أَخَذْنَا بِقَوْلِ النَّبِيِّ صلى الله عليه وسلم فَإِنَّهُ لَمْ يَحِلَّ حَتَّى يَبْلُغَ الْهَدْىُ مَحِلَّهُ‏.‏\hadithno{1795}\hadithtrans{Narrated Abu Musa Al-Ash`ari:I came to the Prophet (ﷺ) at Al-Batha' while his camel was kneeling down and he asked me, "Have you intended to perform the Hajj?" I replied in the affirmative. He asked me, 'With what intention have you assumed Ihram?" I replied, "I have assumed Ihram with the same intention as that of the Prophet. He said, "You have done well. Perform the Tawaf of the Ka`ba and (the Sai) between As-Safa and Al- Marwa and then finish the Ihram." So, I performed the Tawaf around the Ka`ba and the Sai) between As-Safa and Al-Marwa and then went to a woman of the tribe of Qais who cleaned my head from lice. Later I assumed the Ihram for Hajj. I used to give the verdict of doing the same till the caliphate of `Umar who said, "If you follow the Holy Book then it orders you to remain in the state of Ihram till you finish from Hajj, if you follow the Prophet (ﷺ) then he did not finish his Ihram till the Hadi (sacrifice) had reached its place of slaughtering (Hajj-al-Qiran)}}
\hadithdefcmd{bukhari}{1796}{حَدَّثَنَا أَحْمَدُ بْنُ عِيسَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا عَمْرٌو، عَنْ أَبِي الأَسْوَدِ، أَنَّ عَبْدَ اللَّهِ، مَوْلَى أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ حَدَّثَهُ أَنَّهُ، كَانَ يَسْمَعُ أَسْمَاءَ تَقُولُ كُلَّمَا مَرَّتْ بِالْحَجُونِ صَلَّى اللَّهُ عَلَى مُحَمَّدٍ لَقَدْ نَزَلْنَا مَعَهُ هَا هُنَا، وَنَحْنُ يَوْمَئِذٍ خِفَافٌ، قَلِيلٌ ظَهْرُنَا، قَلِيلَةٌ أَزْوَادُنَا، فَاعْتَمَرْتُ أَنَا وَأُخْتِي عَائِشَةُ وَالزُّبَيْرُ وَفُلاَنٌ وَفُلاَنٌ، فَلَمَّا مَسَحْنَا الْبَيْتَ أَحْلَلْنَا، ثُمَّ أَهْلَلْنَا مِنَ الْعَشِيِّ بِالْحَجِّ‏.‏\hadithno{1796}\hadithtrans{Narrated Al-Aswad:`Abdullah the slave of Asma bint Abu Bakr, told me that he used to hear Asma', whenever she passed by Al-Hajun, saying, "May Allah bless His Apostle Muhammad. Once we dismounted here with him, and at that time we were traveling with light luggage; we had a few riding animals and a little food ration. I, my sister, `Aisha, Az-Zubair and such and such persons performed `Umra, and when we had passed our hands over the Ka`ba (i.e. performed Tawaf round the Ka`ba and between As-Safa and Al- Marwa) we finished our Ihram. Later on we assumed Ihram for Hajj the same evening}}
\hadithdefcmd{bukhari}{1797}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَفَلَ مِنْ غَزْوٍ أَوْ حَجٍّ أَوْ عُمْرَةٍ يُكَبِّرُ عَلَى كُلِّ شَرَفٍ مِنَ الأَرْضِ ثَلاَثَ تَكْبِيرَاتٍ، ثُمَّ يَقُولُ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ، لَهُ الْمُلْكُ، وَلَهُ الْحَمْدُ، وَهُوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ، آيِبُونَ تَائِبُونَ عَابِدُونَ سَاجِدُونَ لِرَبِّنَا حَامِدُونَ، صَدَقَ اللَّهُ وَعْدَهُ وَنَصَرَ عَبْدَهُ وَهَزَمَ الأَحْزَابَ وَحْدَهُ ‏"‏‏.‏\hadithno{1797}\hadithtrans{Narrated `Abdullah bin `Umar:Whenever Allah's Messenger (ﷺ) returned from a Ghazwa, Hajj or `Umra, he used to say Takbir thrice at every elevation of the ground and then would say, "None has the right to be worshipped but Allah; He is One and has no partner. All the kingdom is for Him, and all the praises are for Him, and He is Omnipotent. We are returning with repentance, worshipping, prostrating, and praising our Lord. He has kept up His promise and made His slave victorious, and He Alone defeated all the clans of (nonbelievers)}}
\hadithdefcmd{bukhari}{1798}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم مَكَّةَ اسْتَقْبَلَتْهُ أُغَيْلِمَةُ بَنِي عَبْدِ الْمُطَّلِبِ، فَحَمَلَ وَاحِدًا بَيْنَ يَدَيْهِ وَآخَرَ خَلْفَهُ‏.‏\hadithno{1798}\hadithtrans{Narrated Ibn `Abbas:When the Prophet (ﷺ) arrived at Mecca, some boys of the tribe of Bani `Abdul Muttalib went to receive him, and the Prophet (ﷺ) made one of them ride in front of him and the other behind him}}
\hadithdefcmd{bukhari}{1799}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَجَّاجِ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا خَرَجَ إِلَى مَكَّةَ يُصَلِّي فِي مَسْجِدِ الشَّجَرَةِ، وَإِذَا رَجَعَ صَلَّى بِذِي الْحُلَيْفَةِ بِبَطْنِ الْوَادِي وَبَاتَ حَتَّى يُصْبِحَ‏.‏\hadithno{1799}\hadithtrans{Narrated Ibn `Umar:Whenever Allah's Messenger (ﷺ) left for Mecca, he used to pray in the mosque of Ash-Shajra, and when he returned (to Medina), he used to pray in the middle of the valley of Dhul-Hulaifa and used to pass the night there till morning}}
\hadithdefcmd{bukhari}{1800}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هَمَّامٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم لاَ يَطْرُقُ أَهْلَهُ، كَانَ لاَ يَدْخُلُ إِلاَّ غُدْوَةً أَوْ عَشِيَّةً‏.‏\hadithno{1800}\hadithtrans{Narrated Anas:The Prophet (ﷺ) never returned to his family from a journey at night. He used to return either in the morning or in the afternoon}}
\hadithdefcmd{bukhari}{1801}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَارِبٍ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ يَطْرُقَ أَهْلَهُ لَيْلاً‏.‏\hadithno{1801}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) forbade going to one's family at night (on arrival from a journey)}}
\hadithdefcmd{bukhari}{1802}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ أَخْبَرَنِي حُمَيْدٌ، أَنَّهُ سَمِعَ أَنَسًا ـ رضى الله عنه ـ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَدِمَ مِنْ سَفَرٍ، فَأَبْصَرَ دَرَجَاتِ الْمَدِينَةِ أَوْضَعَ نَاقَتَهُ، وَإِنْ كَانَتْ دَابَّةً حَرَّكَهَا‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ زَادَ الْحَارِثُ بْنُ عُمَيْرٍ عَنْ حُمَيْدٍ حَرَّكَهَا مِنْ حُبِّهَا‏.‏ حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ جُدُرَاتٍ‏.‏ تَابَعَهُ الْحَارِثُ بْنُ عُمَيْرٍ‏.‏\hadithno{1802}\hadithtrans{Narrated Humaid:Anas said, "Whenever Allah's Messenger (ﷺ) returned from a journey, he, on seeing the high places of Medina, would make his she-camel proceed faster; and if it were another animal, even then he used to make it proceed faster." Narrated Humaid that the Prophet (ﷺ) used to make it proceed faster out of his love for Medina. Narrated Anas: As above, but mentioned "the walls of Medina" instead of "the high places of Medina." Al-Harith bin `Umar agrees with Anas}}
\hadithdefcmd{bukhari}{1803}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ ـ رضى الله عنه ـ يَقُولُ نَزَلَتْ هَذِهِ الآيَةُ فِينَا، كَانَتِ الأَنْصَارُ إِذَا حَجُّوا فَجَاءُوا لَمْ يَدْخُلُوا مِنْ قِبَلِ أَبْوَابِ بُيُوتِهِمْ، وَلَكِنْ مِنْ ظُهُورِهَا، فَجَاءَ رَجُلٌ مِنَ الأَنْصَارِ، فَدَخَلَ مِنْ قِبَلِ بَابِهِ، فَكَأَنَّهُ عُيِّرَ بِذَلِكَ، فَنَزَلَتْ ‏\{‏وَلَيْسَ الْبِرُّ بِأَنْ تَأْتُوا الْبُيُوتَ مِنْ ظُهُورِهَا وَلَكِنَّ الْبِرَّ مَنِ اتَّقَى وَأْتُوا الْبُيُوتَ مِنْ أَبْوَابِهَا‏\}‏‏.‏\hadithno{1803}\hadithtrans{Narrated Abu 'Is-haq:I heard Al-Bara' saying, "The above Verse was revealed regarding us, for the Ansar on returning from Hajj never entered their houses through the proper doors but from behind. One of the Ansar came and entered through the door and he was taunted for it. Therefore, the following was revealed: -- "It is not righteousness That you enter the houses from the back, But the righteous man is He who fears Allah, Obeys His order and keeps away from What He has forbidden So, enter houses through the proper doors}}
\hadithdefcmd{bukhari}{1804}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا مَالِكٌ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ السَّفَرُ قِطْعَةٌ مِنَ الْعَذَابِ، يَمْنَعُ أَحَدَكُمْ طَعَامَهُ وَشَرَابَهُ وَنَوْمَهُ، فَإِذَا قَضَى نَهْمَتَهُ فَلْيُعَجِّلْ إِلَى أَهْلِهِ ‏"‏‏.‏\hadithno{1804}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Traveling is a kind of torture as it prevents one from eating, drinking and sleeping properly. So, when one's needs are fulfilled, one should return quickly to one's family}}
\hadithdefcmd{bukhari}{1805}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ أَخْبَرَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ أَبِيهِ، قَالَ كُنْتُ مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ بِطَرِيقِ مَكَّةَ، فَبَلَغَهُ عَنْ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ شِدَّةُ وَجَعٍ فَأَسْرَعَ السَّيْرَ، حَتَّى كَانَ بَعْدَ غُرُوبِ الشَّفَقِ نَزَلَ، فَصَلَّى الْمَغْرِبَ وَالْعَتَمَةَ، جَمَعَ بَيْنَهُمَا، ثُمَّ قَالَ إِنِّي رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم إِذَا جَدَّ بِهِ السَّيْرُ أَخَّرَ الْمَغْرِبَ، وَجَمَعَ بَيْنَهُمَا‏.‏\hadithno{1805}\hadithtrans{Narrated Zaid bin Aslam from his father:I was with Ibn `Umar on the way to Mecca, and he got the news that Safiya bint Abu Ubaid was seriously ill. So, he hastened his pace, and when the twilight disappeared, he dismounted and offered the Maghrib and `Isha' prayers together. Then he said, "I saw that whenever the Prophet (ﷺ) had to hasten when traveling, he would delay the Maghrib prayer and join them together (i.e. offer the Maghrib and the `Isha prayers together)}}
