% Auto-generated chapter index for muslim
% Source: ara-muslim.json
% Total hadiths: 7563
% Chapters: 57

\hadithcollectionname{muslim}{Sahih Muslim}

\hadithsectionname{muslim}{0}{Introduction}
\hadithsectionname{muslim}{1}{The Book of Faith}
\hadithsectionname{muslim}{2}{The Book of Purification}
\hadithsectionname{muslim}{3}{The Book of Menstruation}
\hadithsectionname{muslim}{4}{The Book of Prayers }
\hadithsectionname{muslim}{5}{The Book of Mosques and Places of Prayer}
\hadithsectionname{muslim}{6}{The Book of Prayer - Travellers}
\hadithsectionname{muslim}{7}{The Book of Prayer - Friday}
\hadithsectionname{muslim}{8}{The Book of Prayer - Two Eids}
\hadithsectionname{muslim}{9}{The Book of Prayer - Rain}
\hadithsectionname{muslim}{10}{The Book of Prayer - Eclipses}
\hadithsectionname{muslim}{11}{The Book of Prayer - Funerals}
\hadithsectionname{muslim}{12}{The Book of Zakat}
\hadithsectionname{muslim}{13}{The Book of Fasting }
\hadithsectionname{muslim}{14}{The Book of I'tikaf}
\hadithsectionname{muslim}{15}{The Book of Pilgrimage}
\hadithsectionname{muslim}{16}{The Book of Marriage}
\hadithsectionname{muslim}{17}{The Book of Suckling}
\hadithsectionname{muslim}{18}{The Book of Divorce }
\hadithsectionname{muslim}{19}{The Book of Invoking Curses}
\hadithsectionname{muslim}{20}{The Book of Emancipating Slaves}
\hadithsectionname{muslim}{21}{The Book of Transactions}
\hadithsectionname{muslim}{22}{The Book of Musaqah}
\hadithsectionname{muslim}{23}{The Book of the Rules of Inheritance}
\hadithsectionname{muslim}{24}{The Book of Gifts}
\hadithsectionname{muslim}{25}{The Book of Wills}
\hadithsectionname{muslim}{26}{The Book of Vows}
\hadithsectionname{muslim}{27}{The Book of Oaths}
\hadithsectionname{muslim}{28}{The Book of Oaths, Muharibin, Qasas (Retaliation), and Diyat (Blood Money)}
\hadithsectionname{muslim}{29}{The Book of Legal Punishments}
\hadithsectionname{muslim}{30}{The Book of Judicial Decisions}
\hadithsectionname{muslim}{31}{The Book of Lost Property}
\hadithsectionname{muslim}{32}{The Book of Jihad and Expeditions}
\hadithsectionname{muslim}{33}{The Book on Government}
\hadithsectionname{muslim}{34}{The Book of Hunting, Slaughter, and what may be Eaten}
\hadithsectionname{muslim}{35}{The Book of Sacrifices}
\hadithsectionname{muslim}{36}{The Book of Drinks}
\hadithsectionname{muslim}{37}{The Book of Clothes and Adornment}
\hadithsectionname{muslim}{38}{The Book of Manners and Etiquette}
\hadithsectionname{muslim}{39}{The Book of Greetings}
\hadithsectionname{muslim}{40}{The Book Concerning the Use of Correct Words}
\hadithsectionname{muslim}{41}{The Book of Poetry}
\hadithsectionname{muslim}{42}{The Book of Dreams}
\hadithsectionname{muslim}{43}{The Book of Virtues}
\hadithsectionname{muslim}{44}{The Book of the Merits of the Companions}
\hadithsectionname{muslim}{45}{The Book of Virtue, Enjoining Good Manners, and Joining of the Ties of Kinship}
\hadithsectionname{muslim}{46}{The Book of Destiny}
\hadithsectionname{muslim}{47}{The Book of Knowledge}
\hadithsectionname{muslim}{48}{The Book Pertaining to the Remembrance of Allah, Supplication, Repentance and Seeking Forgiveness }
\hadithsectionname{muslim}{49}{The Book of Heart-Melting Traditions}
\hadithsectionname{muslim}{50}{The Book of Repentance}
\hadithsectionname{muslim}{51}{Characteristics of The Hypocrites And Rulings Concerning Them}
\hadithsectionname{muslim}{52}{Characteristics of the Day of Judgment, Paradise, and Hell}
\hadithsectionname{muslim}{53}{The Book of Paradise, its Description, its Bounties and its Inhabitants}
\hadithsectionname{muslim}{54}{The Book of Tribulations and Portents of the Last Hour}
\hadithsectionname{muslim}{55}{The Book of Zuhd and Softening of Hearts }
\hadithsectionname{muslim}{56}{The Book of Commentary on the Qur'an}

\hadithsectionrange{muslim}{0}{1}{92}
\hadithsectionrange{muslim}{1}{93}{533}
\hadithsectionrange{muslim}{2}{534}{678}
\hadithsectionrange{muslim}{3}{679}{836}
\hadithsectionrange{muslim}{4}{837}{1160}
\hadithsectionrange{muslim}{5}{1161}{1569}
\hadithsectionrange{muslim}{6}{1570}{1950}
\hadithsectionrange{muslim}{7}{1951}{2043}
\hadithsectionrange{muslim}{8}{2044}{2069}
\hadithsectionrange{muslim}{9}{2070}{2088}
\hadithsectionrange{muslim}{10}{2089}{2122}
\hadithsectionrange{muslim}{11}{2123}{2262}
\hadithsectionrange{muslim}{12}{2263}{2494}
\hadithsectionrange{muslim}{13}{2495}{2779}
\hadithsectionrange{muslim}{14}{2780}{2790}
\hadithsectionrange{muslim}{15}{2791}{3397}
\hadithsectionrange{muslim}{16}{388}{3567}
\hadithsectionrange{muslim}{17}{3568}{3651}
\hadithsectionrange{muslim}{18}{3652}{3742}
\hadithsectionrange{muslim}{19}{3743}{3769}
\hadithsectionrange{muslim}{20}{3770}{3800}
\hadithsectionrange{muslim}{21}{3801}{3961}
\hadithsectionrange{muslim}{22}{3962}{4139}
\hadithsectionrange{muslim}{23}{4140}{4162}
\hadithsectionrange{muslim}{24}{4163}{4203}
\hadithsectionrange{muslim}{25}{4204}{4234}
\hadithsectionrange{muslim}{26}{4235}{4253}
\hadithsectionrange{muslim}{27}{4254}{4341}
\hadithsectionrange{muslim}{28}{4342}{4397}
\hadithsectionrange{muslim}{29}{4398}{4469}
\hadithsectionrange{muslim}{30}{4470}{4497}
\hadithsectionrange{muslim}{31}{4498}{4518}
\hadithsectionrange{muslim}{32}{4519}{4700}
\hadithsectionrange{muslim}{33}{4701}{4967}
\hadithsectionrange{muslim}{34}{4972}{5063}
\hadithsectionrange{muslim}{35}{5064}{5126}
\hadithsectionrange{muslim}{36}{5114}{5383}
\hadithsectionrange{muslim}{37}{5385}{5585}
\hadithsectionrange{muslim}{38}{5586}{5645}
\hadithsectionrange{muslim}{39}{5646}{5861}
\hadithsectionrange{muslim}{40}{5862}{5884}
\hadithsectionrange{muslim}{41}{5887}{5896}
\hadithsectionrange{muslim}{42}{5897}{5937}
\hadithsectionrange{muslim}{43}{384}{6168}
\hadithsectionrange{muslim}{44}{6169}{6499}
\hadithsectionrange{muslim}{45}{6500}{6722}
\hadithsectionrange{muslim}{46}{6723}{6774}
\hadithsectionrange{muslim}{47}{6775}{6804}
\hadithsectionrange{muslim}{48}{6805}{6936}
\hadithsectionrange{muslim}{49}{6937}{6951}
\hadithsectionrange{muslim}{50}{6952}{7023}
\hadithsectionrange{muslim}{51}{7024}{7044}
\hadithsectionrange{muslim}{52}{7045}{7129}
\hadithsectionrange{muslim}{53}{7130}{7234}
\hadithsectionrange{muslim}{54}{7235}{7416}
\hadithsectionrange{muslim}{55}{7417}{7522}
\hadithsectionrange{muslim}{56}{7523}{7563}

% Chapter index — which .def file to load for each chapter

\hadithchapterfile{muslim}{0}{hadithtext-muslim-ch00.def}{1}{7557}
\hadithchapterfile{muslim}{1}{hadithtext-muslim-ch01.def}{93}{533}
\hadithchapterfile{muslim}{2}{hadithtext-muslim-ch02.def}{534}{678}
\hadithchapterfile{muslim}{3}{hadithtext-muslim-ch03.def}{679}{836}
\hadithchapterfile{muslim}{4}{hadithtext-muslim-ch04.def}{837}{1160}
\hadithchapterfile{muslim}{5}{hadithtext-muslim-ch05.def}{1161}{1569}
\hadithchapterfile{muslim}{6}{hadithtext-muslim-ch06.def}{1570}{1950}
\hadithchapterfile{muslim}{7}{hadithtext-muslim-ch07.def}{1951}{2043}
\hadithchapterfile{muslim}{8}{hadithtext-muslim-ch08.def}{2044}{2069}
\hadithchapterfile{muslim}{9}{hadithtext-muslim-ch09.def}{2070}{2088}
\hadithchapterfile{muslim}{10}{hadithtext-muslim-ch10.def}{2089}{2122}
\hadithchapterfile{muslim}{11}{hadithtext-muslim-ch11.def}{2123}{2262}
\hadithchapterfile{muslim}{12}{hadithtext-muslim-ch12.def}{2263}{2494}
\hadithchapterfile{muslim}{13}{hadithtext-muslim-ch13.def}{2495}{2779}
\hadithchapterfile{muslim}{14}{hadithtext-muslim-ch14.def}{2780}{2790}
\hadithchapterfile{muslim}{15}{hadithtext-muslim-ch15.def}{2791}{3397}
\hadithchapterfile{muslim}{16}{hadithtext-muslim-ch16.def}{388}{3567}
\hadithchapterfile{muslim}{17}{hadithtext-muslim-ch17.def}{3568}{3651}
\hadithchapterfile{muslim}{18}{hadithtext-muslim-ch18.def}{3652}{3742}
\hadithchapterfile{muslim}{19}{hadithtext-muslim-ch19.def}{3743}{3769}
\hadithchapterfile{muslim}{20}{hadithtext-muslim-ch20.def}{3770}{3800}
\hadithchapterfile{muslim}{21}{hadithtext-muslim-ch21.def}{3801}{3961}
\hadithchapterfile{muslim}{22}{hadithtext-muslim-ch22.def}{3962}{4139}
\hadithchapterfile{muslim}{23}{hadithtext-muslim-ch23.def}{4140}{4162}
\hadithchapterfile{muslim}{24}{hadithtext-muslim-ch24.def}{4163}{4203}
\hadithchapterfile{muslim}{25}{hadithtext-muslim-ch25.def}{4204}{4234}
\hadithchapterfile{muslim}{26}{hadithtext-muslim-ch26.def}{4235}{4253}
\hadithchapterfile{muslim}{27}{hadithtext-muslim-ch27.def}{4254}{4341}
\hadithchapterfile{muslim}{28}{hadithtext-muslim-ch28.def}{4342}{4397}
\hadithchapterfile{muslim}{29}{hadithtext-muslim-ch29.def}{4398}{4469}
\hadithchapterfile{muslim}{30}{hadithtext-muslim-ch30.def}{4470}{4497}
\hadithchapterfile{muslim}{31}{hadithtext-muslim-ch31.def}{4498}{4518}
\hadithchapterfile{muslim}{32}{hadithtext-muslim-ch32.def}{4519}{4700}
\hadithchapterfile{muslim}{33}{hadithtext-muslim-ch33.def}{4701}{4967}
\hadithchapterfile{muslim}{34}{hadithtext-muslim-ch34.def}{4972}{5063}
\hadithchapterfile{muslim}{35}{hadithtext-muslim-ch35.def}{5064}{5126}
\hadithchapterfile{muslim}{36}{hadithtext-muslim-ch36.def}{5114}{5383}
\hadithchapterfile{muslim}{37}{hadithtext-muslim-ch37.def}{5385}{5585}
\hadithchapterfile{muslim}{38}{hadithtext-muslim-ch38.def}{5586}{5645}
\hadithchapterfile{muslim}{39}{hadithtext-muslim-ch39.def}{5646}{5861}
\hadithchapterfile{muslim}{40}{hadithtext-muslim-ch40.def}{5862}{5884}
\hadithchapterfile{muslim}{41}{hadithtext-muslim-ch41.def}{5887}{5896}
\hadithchapterfile{muslim}{42}{hadithtext-muslim-ch42.def}{5897}{5937}
\hadithchapterfile{muslim}{43}{hadithtext-muslim-ch43.def}{384}{6168}
\hadithchapterfile{muslim}{44}{hadithtext-muslim-ch44.def}{6169}{6499}
\hadithchapterfile{muslim}{45}{hadithtext-muslim-ch45.def}{6500}{6722}
\hadithchapterfile{muslim}{46}{hadithtext-muslim-ch46.def}{6723}{6774}
\hadithchapterfile{muslim}{47}{hadithtext-muslim-ch47.def}{6775}{6804}
\hadithchapterfile{muslim}{48}{hadithtext-muslim-ch48.def}{6805}{6936}
\hadithchapterfile{muslim}{49}{hadithtext-muslim-ch49.def}{6937}{6951}
\hadithchapterfile{muslim}{50}{hadithtext-muslim-ch50.def}{6952}{7023}
\hadithchapterfile{muslim}{51}{hadithtext-muslim-ch51.def}{7024}{7044}
\hadithchapterfile{muslim}{52}{hadithtext-muslim-ch52.def}{7045}{7129}
\hadithchapterfile{muslim}{53}{hadithtext-muslim-ch53.def}{7130}{7234}
\hadithchapterfile{muslim}{54}{hadithtext-muslim-ch54.def}{7235}{7416}
\hadithchapterfile{muslim}{55}{hadithtext-muslim-ch55.def}{7417}{7522}
\hadithchapterfile{muslim}{56}{hadithtext-muslim-ch56.def}{7523}{7563}
