% Auto-generated chapter 38 for muslim
% Hadiths in this chapter: 59

\hadithdefcmd{muslim}{5586}{حَدَّثَنِي أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ وَابْنُ أَبِي عُمَرَ - قَالَ أَبُو كُرَيْبٍ أَخْبَرَنَا وَقَالَ، ابْنُ أَبِي عُمَرَ حَدَّثَنَا وَاللَّفْظُ، لَهُ - قَالاَ حَدَّثَنَا مَرْوَانُ، - يَعْنِيَانِ الْفَزَارِيَّ - عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ نَادَى رَجُلٌ رَجُلاً بِالْبَقِيعِ يَا أَبَا الْقَاسِمِ ‏.‏ فَالْتَفَتَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي لَمْ أَعْنِكَ إِنَّمَا دَعَوْتُ فُلاَنًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَسَمَّوْا بِاسْمِي وَلاَ تَكَنَّوْا بِكُنْيَتِي ‏"‏ ‏.‏\hadithno{5586}\hadithtrans{Anas reported that person at Baqi' called another person as" Abu'l- Qasim," and Allah's Messenger (ﷺ) turned towards him. He (the person who had uttered these words) said:Messenger of Allah, I did not mean you, but I called such and such (person), whereupon Allah's Messenger (ﷺ) said: You may call yourself by my name, but not by my kunya}}
\hadithdefcmd{muslim}{5587}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ زِيَادٍ، - وَهُوَ الْمُلَقَّبُ بِسَبَلاَنَ - أَخْبَرَنَا عَبَّادُ بْنُ عَبَّادٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، وَأَخِيهِ عَبْدِ اللَّهِ، سَمِعَهُ مِنْهُمَا، سَنَةَ أَرْبَعٍ وَأَرْبَعِينَ وَمِائَةٍ يُحَدِّثَانِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَحَبَّ أَسْمَائِكُمْ إِلَى اللَّهِ عَبْدُ اللَّهِ وَعَبْدُ الرَّحْمَنِ ‏"‏ ‏.‏\hadithno{5587}\hadithtrans{Ibn Umar reported that Allah's Messenger (ﷺ) said:The names dearest to Allah are 'Abdullah and 'Abd al-Rahman}}
\hadithdefcmd{muslim}{5588}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ عُثْمَانُ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ وُلِدَ لِرَجُلٍ مِنَّا غُلاَمٌ فَسَمَّاهُ مُحَمَّدًا فَقَالَ لَهُ قَوْمُهُ لاَ نَدَعُكَ تُسَمِّي بِاسْمِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَانْطَلَقَ بِابْنِهِ حَامِلَهُ عَلَى ظَهْرِهِ فَأَتَى بِهِ النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ وُلِدَ لِي غُلاَمٌ فَسَمَّيْتُهُ مُحَمَّدًا فَقَالَ لِي قَوْمِي لاَ نَدَعُكَ تُسَمِّي بِاسْمِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَسَمَّوْا بِاسْمِي وَلاَ تَكْتَنُوا بِكُنْيَتِي فَإِنَّمَا أَنَا قَاسِمٌ أَقْسِمُ بَيْنَكُمْ ‏"‏ ‏.‏\hadithno{5588}\hadithtrans{Jabir b. 'Abdullah reported that a child was born to a person amongst us and he gave him the name of Muhammad. Thereupon his people said:We will not allow You to give the name of Muhammad (to your child) after the name of Allah's Messenger (ﷺ). He set forth with his son carrying him on his back and came to Allah's Apostle (ﷺ), and said: Allah's Messenger a son has been born to me and I have given him the name after the name of Allah's Messenger (ﷺ), whereupon Allah's Messenger (ﷺ) said: Give him my name but do not give him my kunya, for I am Qasim in the sense that I distribute (the spoils of war) and the dues of Zakat amongst you}}
\hadithdefcmd{muslim}{5589}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا عَبْثَرٌ، عَنْ حُصَيْنٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ وُلِدَ لِرَجُلٍ مِنَّا غُلاَمٌ فَسَمَّاهُ مُحَمَّدًا فَقُلْنَا لاَ نَكْنِيكَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى تَسْتَأْمِرَهُ ‏.‏ قَالَ فَأَتَاهُ فَقَالَ إِنَّهُ وُلِدَ لِي غُلاَمٌ فَسَمَّيْتُهُ بِرَسُولِ اللَّهِ وَإِنَّ قَوْمِي أَبَوْا أَنْ يَكْنُونِي بِهِ حَتَّى تَسْتَأْذِنَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ سَمُّوا بِاسْمِي وَلاَ تَكَنَّوْا بِكُنْيَتِي فَإِنَّمَا بُعِثْتُ قَاسِمًا أَقْسِمُ بَيْنَكُمْ ‏"‏ ‏.‏\hadithno{5589}\hadithtrans{Jabir b. 'Abdullah reported that a child was born to one of the persons amongst us and he decided to give him the name of Muhammad We said:We will not allow you to give the name after the name of Allah's Messenger (ﷺ) until you ask him (the Holy Prophet). So he (that person) came and said (to the Holy Prophet): A child was born in my house and I wanted to give him the name (of Muhammad) after the name of Allah's Messenger, whereas my people did not allow me that I should name him after that (sacred) name until I have asked Allah's Apostle (ﷺ) in this connection, whereupon he said: Give him the name after my name, but do not call him by my kunya, for I have been sent as a Qasim as I distribute amongst you}}
\hadithdefcmd{muslim}{5590}{حَدَّثَنَا رِفَاعَةُ بْنُ الْهَيْثَمِ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي الطَّحَّانَ - عَنْ حُصَيْنٍ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ ‏ "‏ فَإِنَّمَا بُعِثْتُ قَاسِمًا أَقْسِمُ بَيْنَكُمْ ‏"‏ ‏.‏\hadithno{5590}\hadithtrans{This hadith has been reported on the authority of Husain With the same chain of transmitters but no mention is made of these words:" (I have been sent as a distributor), so I distribute amongst you}}
\hadithdefcmd{muslim}{5591}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنِي أَبُو سَعِيدٍ، الأَشَجُّ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَسَمَّوْا بِاسْمِي وَلاَ تَكَنَّوْا بِكُنْيَتِي فَإِنِّي أَنَا أَبُو الْقَاسِمِ أَقْسِمُ بَيْنَكُمْ ‏"‏ ‏.‏ وَفِي رِوَايَةِ أَبِي بَكْرٍ ‏"‏ وَلاَ تَكْتَنُوا ‏"‏ ‏.‏\hadithno{5591}\hadithtrans{Jabir b. Abdullah reported Allah's Messenger (ﷺ) as saying:Give the name after my name, but do not give (the kunya of Abu'l-Qasim after my) kunya, for I am Abu'l-Qasim (in the sense) that I distribute amongst you (the spoils of war) and disseminate the knowledge (of revelation). This hadith has been transmitted on the authority of Abu Bakr but with a slight variation of wording}}
\hadithdefcmd{muslim}{5592}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ إِنَّمَا جُعِلْتُ قَاسِمًا أَقْسِمُ بَيْنَكُمْ ‏"‏ ‏.‏\hadithno{5592}\hadithtrans{This hadith has been reported on the authority of A'mash with the same chain of transmitters but there is a slight variation (of wording) that, instead of the word Bu'ithat (I have been sent), the word ju'ilat (I have been made) has been used}}
\hadithdefcmd{muslim}{5593}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ قَتَادَةَ، عَنْ سَالِمٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ وُلِدَ لَهُ غُلاَمٌ فَأَرَادَ أَنْ يُسَمِّيَهُ مُحَمَّدًا فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَسَأَلَهُ فَقَالَ ‏ "‏ أَحْسَنَتِ الأَنْصَارُ سَمُّوا بِاسْمِي وَلاَ تَكْتَنُوا بِكُنْيَتِي ‏"‏ ‏.‏\hadithno{5593}\hadithtrans{Jabir b. 'Abdullah reported that a child was born to a person from the Ansar and he made up his mind to give him the name of Muhammad. He came to Allah's Apostle (ﷺ) and, asked him (about it), whereupon he said:The Ansar have done well to give the name (to your children) after my name, but do not give them the kunya after my kunya}}
\hadithdefcmd{muslim}{5594}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، كِلاَهُمَا عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ مَنْصُورٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ عَمْرِو بْنِ جَبَلَةَ، حَدَّثَنَا مُحَمَّدٌ يَعْنِي ابْنَ جَعْفَرٍ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، كِلاَهُمَا عَنْ شُعْبَةَ، عَنْ حُصَيْنٍ، ح وَحَدَّثَنِي بِشْرُ، بْنُ خَالِدٍ أَخْبَرَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، كُلُّهُمْ عَنْ سَالِمِ، بْنِ أَبِي الْجَعْدِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالاَ أَخْبَرَنَا النَّضْرُ، بْنُ شُمَيْلٍ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، وَمَنْصُورٍ، وَسُلَيْمَانَ، وَحُصَيْنِ بْنِ عَبْدِ الرَّحْمَنِ، قَالُوا سَمِعْنَا سَالِمَ بْنَ أَبِي الْجَعْدِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِنَحْوِ حَدِيثِ مَنْ ذَكَرْنَا حَدِيثَهُمْ مِنْ قَبْلُ ‏.‏ وَفِي حَدِيثِ النَّضْرِ عَنْ شُعْبَةَ قَالَ وَزَادَ فِيهِ حُصَيْنٌ وَسُلَيْمَانُ قَالَ حُصَيْنٌ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا بُعِثْتُ قَاسِمًا أَقْسِمُ بَيْنَكُمْ ‏"‏ ‏.‏ وَقَالَ سُلَيْمَانُ ‏"‏ فَإِنَّمَا أَنَا قَاسِمٌ أَقْسِمُ بَيْنَكُمْ ‏"‏ ‏.‏\hadithno{5594}\hadithtrans{This hadith has been narrated through different chains of transmitters on the authority of Shu'ba with a slight variation of wording}}
\hadithdefcmd{muslim}{5595}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، جَمِيعًا عَنْ سُفْيَانَ، قَالَ عَمْرٌو حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا ابْنُ الْمُنْكَدِرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ وُلِدَ لِرَجُلٍ مِنَّا غُلاَمٌ فَسَمَّاهُ الْقَاسِمَ فَقُلْنَا لاَ نَكْنِيكَ أَبَا الْقَاسِمِ وَلاَ نُنْعِمُكَ عَيْنًا ‏.‏ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ ‏ "‏ أَسْمِ ابْنَكَ عَبْدَ الرَّحْمَنِ ‏"‏ ‏.‏\hadithno{5595}\hadithtrans{Jabir b. 'Abdullah reported:A child was born in the house of a person amongst us, and he gave him the name of Qasim. We said: We will not allow you (to give the name) to your child as Qasim (and thus adopt the kunya of Abu'l-Qasim) and coal your eyes. He (that person) came to Allah's Apostle (ﷺ) and made a mention of that to him, whereupon he said: Call your son 'Abd al-Rahman}}
\hadithdefcmd{muslim}{5596}{وَحَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامٍ، حَدَّثَنَا يَزِيدُ يَعْنِي ابْنَ زُرَيْعٍ، ح وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - كِلاَهُمَا عَنْ رَوْحِ بْنِ الْقَاسِمِ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، ‏.‏ بِمِثْلِ حَدِيثِ ابْنِ عُيَيْنَةَ غَيْرَ أَنَّهُ لَمْ يَذْكُرْ وَلاَ نُنْعِمُكَ عَيْنًا ‏.‏\hadithno{5596}\hadithtrans{This hadith has been reported on the authority of Ibn Uyaina, but there is no mention of this:" We will not allow you to cool your eyes}}
\hadithdefcmd{muslim}{5597}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، نُمَيْرٍ قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ تَسَمَّوْا بِاسْمِي وَلاَ تَكَنَّوْا بِكُنْيَتِي ‏"‏ ‏.‏ قَالَ عَمْرٌو عَنْ أَبِي هُرَيْرَةَ وَلَمَ يَقُلْ سَمِعْتُ ‏.‏\hadithno{5597}\hadithtrans{Abu Huraira reported that Abu'l-Qasim (ﷺ) said:Give name (to your children) after my name but do not give the kunya (of Abu'l- Qasim) after my kunya. 'Amr reported from Abu Huraira that he did not say that he had heard it directly from Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{5598}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَأَبُو سَعِيدٍ الأَشَجُّ وَمُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ - وَاللَّفْظُ لاِبْنِ نُمَيْرٍ - قَالُوا حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ أَبِيهِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عَلْقَمَةَ بْنِ وَائِلٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ لَمَّا قَدِمْتُ نَجْرَانَ سَأَلُونِي فَقَالُوا إِنَّكُمْ تَقْرَءُونَ يَا أُخْتَ هَارُونَ وَمُوسَى قَبْلَ عِيسَى بِكَذَا وَكَذَا ‏.‏ فَلَمَّا قَدِمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم سَأَلْتُهُ عَنْ ذَلِكَ فَقَالَ ‏ "‏ إِنَّهُمْ كَانُوا يُسَمُّونَ بِأَنْبِيَائِهِمْ وَالصَّالِحِينَ قَبْلَهُمْ ‏"‏ ‏.‏\hadithno{5598}\hadithtrans{Mughira b. Shu'ba reported:When I came to Najran, they (the Christians of Najran) asked me: You read" O sister of Harun" (i. e. Hadrat Maryam) in the Qur'an, whereas Moses was born much before Jesus. When I came back to Allah's Messenger (ﷺ) I asked him about that, whereupon he said: The (people of the old age) used to give names (to their persons) after the names of Apostles and pious persons who had gone before them}}
\hadithdefcmd{muslim}{5599}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالَ أَبُو بَكْرٍ حَدَّثَنَا مُعْتَمِرُ بْنُ، سُلَيْمَانَ عَنِ الرُّكَيْنِ، عَنْ أَبِيهِ، عَنْ سَمُرَةَ، وَقَالَ، يَحْيَى أَخْبَرَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ الرُّكَيْنَ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نُسَمِّيَ رَقِيقَنَا بِأَرْبَعَةِ أَسْمَاءٍ أَفْلَحَ وَرَبَاحٍ وَيَسَارٍ وَنَافِعٍ ‏.‏\hadithno{5599}\hadithtrans{Samura b. Jundub reported:Allah's Messenger (ﷺ) forbade us to give names to our servants as these four names: Aflah (Successful), Rabdh (Profit), Yasar (Wealth), and Nafi' (Beneficial)}}
\hadithdefcmd{muslim}{5600}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الرُّكَيْنِ بْنِ الرَّبِيعِ، عَنْ أَبِيهِ، عَنْ سَمُرَةَ، بْنِ جُنْدَبٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُسَمِّ غُلاَمَكَ رَبَاحًا وَلاَ يَسَارًا وَلاَ أَفْلَحَ وَلاَ نَافِعًا ‏"‏ ‏.‏\hadithno{5600}\hadithtrans{Samura b. Jundub reported AUah's Messenger (ﷺ) as saying:Don't give names to your servants as Rabdh, 'Ya ar, Aflah and Nafi}}
\hadithdefcmd{muslim}{5601}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا مَنْصُورٌ، عَنِ هِلاَلِ بْنِ يَسَافٍ، عَنْ رَبِيعِ بْنِ عُمَيْلَةَ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "أَحَبُّ الْكَلاَمِ إِلَى اللَّهِ أَرْبَعٌ سُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ‏.‏ لاَ يَضُرُّكَ بَأَيِّهِنَّ بَدَأْتَ.‏ وَلاَ تُسَمِّيَنَّ غُلاَمَكَ يَسَارًا وَلاَ رَبَاحًا وَلاَ نَجِيحًا وَلاَ أَفْلَحَ فَإِنَّكَ تَقُولُ أَثَمَّ هُوَ فَلاَ يَكُونُ فَيَقُولُ لاَ‏."‏‏ إِنَّمَا هُنَّ أَرْبَعٌ فَلاَ تَزِيدُنَّ عَلَىَّ ‏.‏\hadithno{5601}\hadithtrans{Samura b. Jundub reported:The Messenger of Allah (peace and blessings of Allah be upon him) said "The dearest phrases to Allah are four: Subhan Allah (Hallowed be Allah), Al-Hamdulillah (Praise be to Allah), La ilaha illa-Allah (There is no deity but Allah), Allahu Akbar (Allah is Greater). There is no harm for you in which of them begin with (while remembering Allah). And do not give these names to your servants: Yasar and Rabah and Najih and Aflah}}
\hadithdefcmd{muslim}{5602}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنِي جَرِيرٌ، ح وَحَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا رَوْحٌ، - وَهْوَ ابْنُ الْقَاسِمِ - ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، كُلُّهُمْ عَنْ مَنْصُورٍ، بِإِسْنَادِ زُهَيْرٍ ‏.‏ فَأَمَّا حَدِيثُ جَرِيرٍ وَرَوْحٍ فَكَمِثْلِ حَدِيثِ زُهَيْرٍ بِقِصَّتِهِ ‏.‏ وَأَمَّا حَدِيثُ شُعْبَةَ فَلَيْسَ فِيهِ إِلاَّ ذِكْرُ تَسْمِيَةِ الْغُلاَمِ وَلَمْ يَذْكُرِ الْكَلاَمَ الأَرْبَعَ ‏.‏\hadithno{5602}\hadithtrans{This hadith has been reported on the authority of Shu'ba and there is no mention but of the fact about giving the name to the servant and there is no mention of the four expressions (of remembrance) and he did not mention the four words}}
\hadithdefcmd{muslim}{5603}{حَدَّثَنَا مُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ أَرَادَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَنْهَى عَنْ أَنْ يُسَمَّى بِيَعْلَى وَبِبَرَكَةَ وَبِأَفْلَحَ وَبِيَسَارٍ وَبِنَافِعٍ وَبِنَحْوِ ذَلِكَ ثُمَّ رَأَيْتُهُ سَكَتَ بَعْدُ عَنْهَا فَلَمْ يَقُلْ شَيْئًا ثُمَّ قُبِضَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَمْ يَنْهَ عَنْ ذَلِكَ ثُمَّ أَرَادَ عُمَرُ أَنْ يَنْهَى عَنْ ذَلِكَ ثُمَّ تَرَكَهُ ‏.‏\hadithno{5603}\hadithtrans{Jabir b. 'Abdullah reported:Allah's Messenger (ﷺ) decided to forbid (his followers) to name persons as Ya'la (Elevated), Baraka (Blessing), Aflah (Successful), Yasar and Nafi', but I saw that he kept silent after that and he did not say anything until Allah's Messenger (ﷺ) died. And he did not forbid (his followers to do this), then 'Umar decided to prohibit (people) from giving these names, but later on gave up the idea}}
\hadithdefcmd{muslim}{5604}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَزُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ بَشَّارٍ قَالُوا حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غَيَّرَ اسْمَ عَاصِيَةَ وَقَالَ ‏ "‏ أَنْتِ جَمِيلَةُ ‏"‏ ‏.‏ قَالَ أَحْمَدُ مَكَانَ أَخْبَرَنِي عَنْ ‏.‏\hadithno{5604}\hadithtrans{Ibn 'Umar reported that Allah's Messenger (ﷺ) changed the name of 'Asiya (Disobedient) and said:You are Jamila (i. e. good and handsome). Ahmad (one of the narrators) narrated it with a slight variation of wording}}
\hadithdefcmd{muslim}{5605}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ ابْنَةً لِعُمَرَ، كَانَتْ يُقَالُ لَهَا عَاصِيَةُ فَسَمَّاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم جَمِيلَةَ ‏.‏\hadithno{5605}\hadithtrans{Ibn 'Umar reported that 'Umar had a daughter who was called 'Asiya. Allah's Messenger (ﷺ) gave her the name of Jamila}}
\hadithdefcmd{muslim}{5606}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لِعَمْرٍو - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، مَوْلَى آلِ طَلْحَةَ عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَتْ جُوَيْرِيَةُ اسْمُهَا بَرَّةَ فَحَوَّلَ رَسُولُ اللَّهِ صلى الله عليه وسلم اسْمَهَا جُوَيْرِيَةَ وَكَانَ يَكْرَهُ أَنْ يُقَالَ خَرَجَ مِنْ عِنْدِ بَرَّةَ ‏.‏ وَفِي حَدِيثِ ابْنِ أَبِي عُمَرَ عَنْ كُرَيْبٍ قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ ‏.‏\hadithno{5606}\hadithtrans{Ibn Abbas reported that the name of Juwairiya (the wife of the Holy Prophet) was Barra (Pious). Allah's Messenger (ﷺ) changed her name to Juwairiya and said:I did not like that it should be said: He had come out from Barra (Pious). The hadith transmitted on the authority of Ibn Abi 'Umar is slightly different from it}}
\hadithdefcmd{muslim}{5607}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالُوا حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَطَاءِ بْنِ أَبِي مَيْمُونَةَ، سَمِعْتُ أَبَا رَافِعٍ، يُحَدِّثُ عَنْ أَبِي، هُرَيْرَةَ ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَطَاءِ بْنِ أَبِي مَيْمُونَةَ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ زَيْنَبَ، كَانَ اسْمُهَا بَرَّةَ فَقِيلَ تُزَكِّي نَفْسَهَا ‏.‏ فَسَمَّاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم زَيْنَبَ ‏.‏ وَلَفْظُ الْحَدِيثِ لِهَؤُلاَءِ دُونَ ابْنِ بَشَّارٍ ‏.‏ وَقَالَ ابْنُ أَبِي شَيْبَةَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ عَنْ شُعْبَةَ ‏.‏\hadithno{5607}\hadithtrans{Abu Huraira reported that the name of Zainab was Barra. It was said of her:She presents herself to be innocent. Allah's Messenger (ﷺ) gave her the name of Zainab}}
\hadithdefcmd{muslim}{5608}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، قَالاَ حَدَّثَنَا الْوَلِيدُ بْنُ كَثِيرٍ، حَدَّثَنِي مُحَمَّدُ بْنُ عَمْرِو بْنِ عَطَاءٍ، حَدَّثَتْنِي زَيْنَبُ، بِنْتُ أُمِّ سَلَمَةَ قَالَتْ كَانَ اسْمِي بَرَّةَ فَسَمَّانِي رَسُولُ اللَّهِ صلى الله عليه وسلم زَيْنَبَ ‏.‏ قَالَتْ وَدَخَلَتْ عَلَيْهِ زَيْنَبُ بِنْتُ جَحْشٍ وَاسْمُهَا بَرَّةُ فَسَمَّاهَا زَيْنَبَ ‏.‏\hadithno{5608}\hadithtrans{Zainab, daughter of Umm Salama, reported:My name first was Barra. Allah's Messenger (ﷺ) gave me the name of Zainab. Then there entered (into the house of Allah's Prophet as a wife) Zainab, daughter of Jahsh, and her name was also Barra, and he gave her the name of Zainab}}
\hadithdefcmd{muslim}{5609}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، قَالَ سَمَّيْتُ ابْنَتِي بَرَّةَ فَقَالَتْ لِي زَيْنَبُ بِنْتُ أَبِي سَلَمَةَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ هَذَا الاِسْمِ وَسُمِّيتُ بَرَّةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تُزَكُّوا أَنْفُسَكُمُ اللَّهُ أَعْلَمُ بِأَهْلِ الْبِرِّ مِنْكُمْ ‏"‏ ‏.‏ فَقَالُوا بِمَ نُسَمِّيهَا قَالَ ‏"‏ سَمُّوهَا زَيْنَبَ ‏"‏ ‏.‏\hadithno{5609}\hadithtrans{Muhammad b. 'Amr b. 'Ata' reported:I had given the name Barra to my daughter. Zainab, daughter of Abu Salama, told me that Allah's' Messenger (ﷺ) had forbidden me to give this name. (She said): I was also called Barra, but Allah's Messenger (ﷺ) said: Don't hold yourself to be pious. It is God alone who knows the people of piety among you. They (the Companions) said: Then, what name should we give to her? He said: Name her as Zainab}}
\hadithdefcmd{muslim}{5610}{حَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، وَأَحْمَدُ بْنُ حَنْبَلٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ - وَاللَّفْظُ لأَحْمَدَ - قَالَ الأَشْعَثِيُّ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ أَخْنَعَ اسْمٍ عِنْدَ اللَّهِ رَجُلٌ تَسَمَّى مَلِكَ الأَمْلاَكِ ‏"‏ ‏.‏ زَادَ ابْنُ أَبِي شَيْبَةَ فِي رِوَايَتِهِ ‏"‏ لاَ مَالِكَ إِلاَّ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏ قَالَ الأَشْعَثِيُّ قَالَ سُفْيَانُ مِثْلُ شَاهَانْ شَاهْ ‏.‏ وَقَالَ أَحْمَدُ بْنُ حَنْبَلٍ سَأَلْتُ أَبَا عَمْرٍو عَنْ أَخْنَعَ فَقَالَ أَوْضَعَ ‏.‏\hadithno{5610}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The vilest name in Allah's sight is Malik al-Amidh (King of Kings). The narration transmitted on the authority of Shaiba (contains these words): There is no king but Allah, the Exalted and Glorious. Sufyan said: Similarly, the word Shahinshah (is also the vilest appellation). Ahmad b. Hanbal said: I asked Abu 'Amr about the meaning of Akhna. He said: The vilest}}
\hadithdefcmd{muslim}{5611}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَغْيَظُ رَجُلٍ عَلَى اللَّهِ يَوْمَ الْقِيَامَةِ وَأَخْبَثُهُ وَأَغْيَظُهُ عَلَيْهِ رَجُلٌ كَانَ يُسَمَّى مَلِكَ الأَمْلاَكِ لاَ مَلِكَ إِلاَّ اللَّهُ ‏"‏ ‏.‏\hadithno{5611}\hadithtrans{Abu Huraira reported from Allah's Messenger (ﷺ) so many ahadith and one of them was this that Allah's Messenger (ﷺ) said:The most wretched person in the sight of Allah on the Day of Resurrection and the worst person and target of His wrath would of the person who is called Malik al-Amlak (the King of Kings) for there is no king but Allah}}
\hadithdefcmd{muslim}{5612}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ، بْنِ مَالِكٍ قَالَ ذَهَبْتُ بِعَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ الأَنْصَارِيِّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ وُلِدَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي عَبَاءَةٍ يَهْنَأُ بَعِيرًا لَهُ فَقَالَ ‏"‏ هَلْ مَعَكَ تَمْرٌ ‏"‏ ‏.‏ فَقُلْتُ نَعَمْ ‏.‏ فَنَاوَلْتُهُ تَمَرَاتٍ فَأَلْقَاهُنَّ فِي فِيهِ فَلاَكَهُنَّ ثُمَّ فَغَرَ فَا الصَّبِيِّ فَمَجَّهُ فِي فِيهِ فَجَعَلَ الصَّبِيُّ يَتَلَمَّظُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ حُبُّ الأَنْصَارِ التَّمْرَ ‏"‏ ‏.‏ وَسَمَّاهُ عَبْدَ اللَّهِ ‏.‏\hadithno{5612}\hadithtrans{Anas b. Malik reported:I took 'Abdullah b. Abi Talha Ansari to Allah's Messenger (ﷺ) at the time of his birth. Allah's Messenger (ﷺ) was at that time wearing a woollen cloak and besmearing the camels with tar. He said: Have you got with you the dates? I said: Yes. He took hold of the dates and put them in his mouth and softened them, then opened the mouth of the infant and put that in it and the child began to lick it. Thereupon Allah's Messenger (ﷺ) said: The Ansar have a liking for the dates, and he (the Holy Prophet) gave him the name of 'Abdullah}}
\hadithdefcmd{muslim}{5613}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا ابْنُ عَوْنٍ، عَنِ ابْنِ، سِيرِينَ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ ابْنٌ لأَبِي طَلْحَةَ يَشْتَكِي فَخَرَجَ أَبُو طَلْحَةَ فَقُبِضَ الصَّبِيُّ فَلَمَّا رَجَعَ أَبُو طَلْحَةَ قَالَ مَا فَعَلَ ابْنِي قَالَتْ أُمُّ سُلَيْمٍ هُوَ أَسْكَنُ مِمَّا كَانَ ‏.‏ فَقَرَّبَتْ إِلَيْهِ الْعَشَاءَ فَتَعَشَّى ثُمَّ أَصَابَ مِنْهَا فَلَمَّا فَرَغَ قَالَتْ وَارُوا الصَّبِيَّ ‏.‏ فَلَمَّا أَصْبَحَ أَبُو طَلْحَةَ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ فَقَالَ ‏"‏ أَعْرَسْتُمُ اللَّيْلَةَ ‏"‏ ‏.‏ قَالَ نَعَمْ قَالَ ‏"‏ اللَّهُمَّ بَارِكْ لَهُمَا ‏"‏ ‏.‏ فَوَلَدَتْ غُلاَمًا فَقَالَ لِي أَبُو طَلْحَةَ احْمِلْهُ حَتَّى تَأْتِيَ بِهِ النَّبِيَّ صلى الله عليه وسلم ‏.‏ فَأَتَى بِهِ النَّبِيَّ صلى الله عليه وسلم وَبَعَثَتْ مَعَهُ بِتَمَرَاتٍ فَأَخَذَهُ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَمَعَهُ شَىْءٌ ‏"‏ ‏.‏ قَالُوا نَعَمْ تَمَرَاتٌ ‏.‏ فَأَخَذَهَا النَّبِيُّ صلى الله عليه وسلم فَمَضَغَهَا ثُمَّ أَخَذَهَا مِنْ فِيهِ فَجَعَلَهَا فِي فِي الصَّبِيِّ ثُمَّ حَنَّكَهُ وَسَمَّاهُ عَبْدَ اللَّهِ ‏.‏\hadithno{5613}\hadithtrans{Anas b. Malik reported that the son of Abu Talha had been ailing. Abu Talha set out (on a journey) and his son breathed his last (in his absence). When Abu Talha came back, he said (to his wife):What about my child? Umm Sulaim (the wife of Abu Talha) said: He is now in a more comfortable state than before. She served him the evening meal and he took it. He then came to her (and had sexual intercourse with her) and when it was all over she said: Make arrangements for the burial of the child. When it was morning. Abu Talha came to Allah's Messenger (ﷺ) and informed him, whereupon he said: Did you spend the night with her. He said: Yes. He (the Holy Prophet) then said: O Allah, bless both of them (and as a result of blessing) she gave birth to a child. Abu Talha said to me (Anas b. Malik) to take the child, (so I took him) and came to Allah's Messenger (ﷺ). She (Umm Sulaim) also had sent some dates (along with the child). Allah's Apostle (ﷺ) took him (the child) (in his lap) and said: Is there anything with you (for Tahnik). They (the Companions) said: Yes. Allah's Apostle (ﷺ) took hold of them (dates and chewed them). He then put them (the chewed dates) in the mouth of the child and then rubbed his palate and gave him the name of 'Abdullah}}
\hadithdefcmd{muslim}{5614}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنْ أَنَسٍ، بِهَذِهِ الْقِصَّةِ نَحْوَ حَدِيثِ يَزِيدَ ‏.‏\hadithno{5614}\hadithtrans{This hadith has been reported on the authority of Anas through another chain of transmit ters}}
\hadithdefcmd{muslim}{5615}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَبْدُ اللَّهِ بْنُ بَرَّادٍ الأَشْعَرِيُّ، وَأَبُو كُرَيْبٍ قَالُوا حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ وُلِدَ لِي غُلاَمٌ فَأَتَيْتُ بِهِ النَّبِيَّ صلى الله عليه وسلم فَسَمَّاهُ إِبْرَاهِيمَ وَحَنَّكَهُ بِتَمْرَةٍ ‏.‏\hadithno{5615}\hadithtrans{Abu Musa reported:A child was born in my house and I brought him to Allah's Apostle (may peace be upod him) and he gave him the name of Ibrahim and he rubbed his palate with dates}}
\hadithdefcmd{muslim}{5616}{حَدَّثَنَا الْحَكَمُ بْنُ مُوسَى أَبُو صَالِحٍ، حَدَّثَنَا شُعَيْبٌ، - يَعْنِي ابْنَ إِسْحَاقَ - أَخْبَرَنِي هِشَامُ بْنُ عُرْوَةَ، حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، وَفَاطِمَةُ بِنْتُ الْمُنْذِرِ بْنِ الزُّبَيْرِ، أَنَّهُمَا قَالاَ خَرَجَتْ أَسْمَاءُ بِنْتُ أَبِي بَكْرٍ حِينَ هَاجَرَتْ وَهِيَ حُبْلَى بِعَبْدِ اللَّهِ بْنِ الزُّبَيْرِ فَقَدِمَتْ قُبَاءً فَنُفِسَتْ بِعَبْدِ اللَّهِ بِقُبَاءٍ ثُمَّ خَرَجَتْ حِينَ نُفِسَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لِيُحَنِّكَهُ فَأَخَذَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْهَا فَوَضَعَهُ فِي حَجْرِهِ ثُمَّ دَعَا بِتَمْرَةٍ قَالَ قَالَتْ عَائِشَةُ فَمَكَثْنَا سَاعَةً نَلْتَمِسُهَا قَبْلَ أَنْ نَجِدَهَا فَمَضَغَهَا ثُمَّ بَصَقَهَا فِي فِيهِ فَإِنَّ أَوَّلَ شَىْءٍ دَخَلَ بَطْنَهُ لَرِيقُ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَتْ أَسْمَاءُ ثُمَّ مَسَحَهُ وَصَلَّى عَلَيْهِ وَسَمَّاهُ عَبْدَ اللَّهِ ثُمَّ جَاءَ وَهُوَ ابْنُ سَبْعِ سِنِينَ أَوْ ثَمَانٍ لِيُبَايِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَمَرَهُ بِذَلِكَ الزُّبَيْرُ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ رَآهُ مُقْبِلاً إِلَيْهِ ثُمَّ بَايَعَهُ ‏.‏\hadithno{5616}\hadithtrans{Urwa b. Zubair and Fatima daughter of Mandhir b. Zubair, reported that Asma' daughter of Abu Bakr was at the time of migration in the family way with 'Abdullah b. Zubair (in her womb). She came to Quba' and gave birth to 'Abdullah at that place and then sent him to Allah's Messenger (ﷺ) so that he should rub his palate with chewed dates. Allah's Messenger (may peace he upon him) took hold of him (the child) and he placed him in his lap and then called for dates. 'A'isha said:Some time was spent before we were able to find them. He (the Holy Prophet) chewed them and then put his saliva in his mouth. The first thing that entered his stomach, was the saliva of Allah's Messenger (ﷺ). Asma' said: He then rubbed him and blessed him and gave him the name of Abdullah. He ('Abdullah) went to him (the Holy Prophet) when he had attained the age of seven or eight years in order to pledge allegiance to Allah's Messenger (ﷺ) as Zubair had commanded him to do. Allah's Messenger (ﷺ) smiled when he saw him coming towards him and then accepted his allegiance}}
\hadithdefcmd{muslim}{5617}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ، أَنَّهَا حَمَلَتْ بِعَبْدِ اللَّهِ بْنِ الزُّبَيْرِ بِمَكَّةَ قَالَتْ فَخَرَجْتُ وَأَنَا مُتِمٌّ، فَأَتَيْتُ الْمَدِينَةَ فَنَزَلْتُ بِقُبَاءٍ فَوَلَدْتُهُ بِقُبَاءٍ ثُمَّ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَوَضَعَهُ فِي حَجْرِهِ ثُمَّ دَعَا بِتَمْرَةٍ فَمَضَغَهَا ثُمَّ تَفَلَ فِي فِيهِ فَكَانَ أَوَّلَ شَىْءٍ دَخَلَ جَوْفَهُ رِيقُ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ حَنَّكَهُ بِالتَّمْرَةِ ثُمَّ دَعَا لَهُ وَبَرَّكَ عَلَيْهِ وَكَانَ أَوَّلَ مَوْلُودٍ وُلِدَ فِي الإِسْلاَمِ ‏.‏\hadithno{5617}\hadithtrans{Asma' reported that she had become pregnant at Mecca with Abdullah b. Zubair (in her womt) and she (further) said:I set out (for migration to Medina) as I was in the advanced stage of pregnancy. I came to Medina and got down at the place known as Quba' and gave birth to a child there. Then I came to Allah's Messenger (may peace he upon him). He placed him (the child) in his lap and then commanded for the dates to be brought. He chewed them and then put the saliva in his mouth. The first thing which went into his stomach was the saliva of Allah's Messenger (ﷺ). He then rubbed his palate with dates and then invoked blessings for him and blessed him. He was the first child who was born in Islam (after Migration)}}
\hadithdefcmd{muslim}{5618}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ عَلِيِّ بْنِ مُسْهِرٍ، عَنْ هِشَامِ، بْنِ عُرْوَةَ عَنْ أَبِيهِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّهَا هَاجَرَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهِيَ حُبْلَى بِعَبْدِ اللَّهِ بْنِ الزُّبَيْرِ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ أَبِي أُسَامَةَ ‏.‏\hadithno{5618}\hadithtrans{Asma', daughter of Abu Bakr, reported that when she migrated to Allah's Messenger (ﷺ) in Medina she was in the family way with Abdullah b. Zubair in her womb}}
\hadithdefcmd{muslim}{5619}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامٌ، - يَعْنِي ابْنَ عُرْوَةَ - عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُؤْتَى بِالصِّبْيَانِ فَيُبَرِّكُ عَلَيْهِمْ وَيُحَنِّكُهُمْ ‏.‏\hadithno{5619}\hadithtrans{A'isha reported that the new-born infants were brought to Allah's Messenger (ﷺ). He blessed them and rubbed their palates with dates}}
\hadithdefcmd{muslim}{5620}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جِئْنَا بِعَبْدِ اللَّهِ بْنِ الزُّبَيْرِ إِلَى النَّبِيِّ صلى الله عليه وسلم يُحَنِّكُهُ فَطَلَبْنَا تَمْرَةً فَعَزَّ عَلَيْنَا طَلَبُهَا ‏.‏\hadithno{5620}\hadithtrans{A'isha reported:We took 'Abdullah b. Zubair to Allah's Apostle (ﷺ) so that he should put saliva in his mouth and we had to make a good deal of effort in order to procure them}}
\hadithdefcmd{muslim}{5621}{حَدَّثَنِي مُحَمَّدُ بْنُ سَهْلٍ التَّمِيمِيُّ، وَأَبُو بَكْرِ بْنُ إِسْحَاقَ قَالاَ حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ مُطَرِّفٍ أَبُو غَسَّانَ - حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ أُتِيَ بِالْمُنْذِرِ بْنِ أَبِي أُسَيْدٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ وُلِدَ فَوَضَعَهُ النَّبِيُّ صلى الله عليه وسلم عَلَى فَخِذِهِ وَأَبُو أُسَيْدٍ جَالِسٌ فَلَهِيَ النَّبِيُّ صلى الله عليه وسلم بِشَىْءٍ بَيْنَ يَدَيْهِ فَأَمَرَ أَبُو أُسَيْدٍ بِابْنِهِ فَاحْتُمِلَ مِنْ عَلَى فَخِذِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَقْلَبُوهُ فَاسْتَفَاقَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَيْنَ الصَّبِيُّ ‏"‏ ‏.‏ فَقَالَ أَبُو أُسَيْدٍ أَقْلَبْنَاهُ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ مَا اسْمُهُ ‏"‏ ‏.‏ قَالَ فُلاَنٌ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ لاَ وَلَكِنِ اسْمُهُ الْمُنْذِرُ ‏"‏ ‏.‏ فَسَمَّاهُ يَوْمَئِذٍ الْمُنْذِرَ ‏.‏\hadithno{5621}\hadithtrans{Sahl b. Sa'd reported that Mundhir b. Aba Usaid was brought to Allah's Messenger (ﷺ) at the time of his birth Allah's. Apostle (ﷺ) placed him on his thigh and Abfi Usaid kept sitting there. Allah's Apostle (ﷺ) had been occupied with something else before him. Abu Usaid commanded his child to be lifted from the lap of Allah's Messenger (ﷺ) and so he was lifted. When Allah's Messenger (ﷺ) had finished the work he said:Where is the child? Abd Usaid said: Allah's Messenger, we took him away. He said: What is his name? He said; Allah's Messenger, it is so and so, whereupon he (the Holy Prophet) said: Nay, his name is Mundhir, and named him Mundhir on that day}}
\hadithdefcmd{muslim}{5622}{حَدَّثَنَا أَبُو الرَّبِيعِ، سُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَبُو التَّيَّاحِ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، ح وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَحْسَنَ النَّاسِ خُلُقًا وَكَانَ لِي أَخٌ يُقَالُ لَهُ أَبُو عُمَيْرٍ - قَالَ أَحْسِبُهُ قَالَ - كَانَ فَطِيمًا - قَالَ - فَكَانَ إِذَا جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَرَآهُ قَالَ ‏ "‏ أَبَا عُمَيْرٍ مَا فَعَلَ النُّغَيْرُ ‏"‏ ‏.‏ قَالَ فَكَانَ يَلْعَبُ بِهِ ‏.‏\hadithno{5622}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) had the sublimest character among mankind. I had a brother who was called Abu 'Umair. I think he was weaned. When Allah's Messenger (may peace he upon him) came to our house he saw him, and said:Abu 'Umair, what has the sparrow done? He (Anas) said that he had been playing with that}}
\hadithdefcmd{muslim}{5623}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْغُبَرِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي عُثْمَانَ، عَنْ أَنَسِ بْنِ، مَالِكٍ قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا بُنَىَّ ‏"‏ ‏.‏\hadithno{5623}\hadithtrans{Anas b Malik reported that Allah's Messenger (ﷺ) addressed me:O My Son}}
\hadithdefcmd{muslim}{5624}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لاِبْنِ أَبِي عُمَرَ - قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنِ الْمُغِيرَةِ، بْنِ شُعْبَةَ قَالَ مَا سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَحَدٌ عَنِ الدَّجَّالِ أَكْثَرَ مِمَّا سَأَلْتُهُ عَنْهُ فَقَالَ لِي ‏"‏ أَىْ بُنَىَّ وَمَا يُنْصِبُكَ مِنْهُ إِنَّهُ لَنْ يَضُرَّكَ ‏"‏ ‏.‏ قَالَ قُلْتُ إِنَّهُمْ يَزْعُمُونَ أَنَّ مَعَهُ أَنْهَارَ الْمَاءِ وَجِبَالَ الْخُبْزِ ‏.‏ قَالَ ‏"‏ هُوَ أَهْوَنُ عَلَى اللَّهِ مِنْ ذَلِكَ ‏"‏ ‏.‏\hadithno{5624}\hadithtrans{Mughira b. Shu'ba reported that none else had asked more questions from Allah's Messenger (ﷺ) about the Dajjal than I, but he simply said in a slight mood):O, myson, why are you worried because of him? He will not harm you. I said: The people think that he would have with him rivers of water and mountains of bread, whereupon he said: He would be more insignificant in the sight of Allah than all these things (belonging to him)}}
\hadithdefcmd{muslim}{5625}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا سُرَيْجُ بْنُ، يُونُسَ حَدَّثَنَا هُشَيْمٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ، رَافِعٍ حَدَّثَنَا أَبُو أُسَامَةَ، كُلُّهُمْ عَنْ إِسْمَاعِيلَ، بِهَذَا الإِسْنَادِ ‏.‏ وَلَيْسَ فِي حَدِيثِ أَحَدٍ مِنْهُمْ قَوْلُ النَّبِيِّ صلى الله عليه وسلم لِلْمُغِيرَةِ ‏ "‏ أَىْ بُنَىَّ ‏"‏ ‏.‏ إِلاَّ فِي حَدِيثِ يَزِيدَ وَحْدَهُ ‏.‏\hadithno{5625}\hadithtrans{This hadith has been reported on the authority of Ismail, with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5626}{حَدَّثَنِي عَمْرُو بْنُ مُحَمَّدِ بْنِ بُكَيْرٍ النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا - وَاللَّهِ، - يَزِيدُ بْنُ خُصَيْفَةَ عَنْ بُسْرِ بْنِ سَعِيدٍ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ كُنْتُ جَالِسًا بِالْمَدِينَةِ فِي مَجْلِسِ الأَنْصَارِ فَأَتَانَا أَبُو مُوسَى فَزِعًا أَوْ مَذْعُورًا ‏.‏ قُلْنَا مَا شَأْنُكَ قَالَ إِنَّ عُمَرَ أَرْسَلَ إِلَىَّ أَنْ آتِيَهُ فَأَتَيْتُ بَابَهُ فَسَلَّمْتُ ثَلاَثًا فَلَمْ يَرُدَّ عَلَىَّ فَرَجَعْتُ فَقَالَ مَا مَنَعَكَ أَنْ تَأْتِيَنَا فَقُلْتُ إِنِّي أَتَيْتُكَ فَسَلَّمْتُ عَلَى بَابِكَ ثَلاَثًا فَلَمْ يَرُدُّوا عَلَىَّ فَرَجَعْتُ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا اسْتَأْذَنَ أَحَدُكُمْ ثَلاَثًا فَلَمْ يُؤْذَنْ لَهُ فَلْيَرْجِعْ ‏"‏ ‏.‏ فَقَالَ عُمَرُ أَقِمْ عَلَيْهِ الْبَيِّنَةَ وَإِلاَّ أَوْجَعْتُكَ ‏.‏ فَقَالَ أُبَىُّ بْنُ كَعْبٍ لاَ يَقُومُ مَعَهُ إِلاَّ أَصْغَرُ الْقَوْمِ ‏.‏ قَالَ أَبُو سَعِيدٍ قُلْتُ أَنَا أَصْغَرُ الْقَوْمِ ‏.‏ قَالَ فَاذْهَبْ بِهِ ‏.‏\hadithno{5626}\hadithtrans{Abu Sa'id Khudri reported:I was sitting in Medina in the company of the Ansar when Abu Musa came trembling with fear. We said to him: What is the matter? He said: 'Umar (Allah be pleased with him) sent for me. I went to him and paid him salutation thrice at (his) door but he made no response to me and so I came back. Thereupon he ('Umar) said: What stood in your way that you did not turn up? I said: I did come to you and paid you salutations at your door three times but I was not given any response, so I came back as the Messenger of Allah (ﷺ) has said: When any one of you seeks permission three times and he is not granted permission, he should come back. Umar said: Bring a witness to support that you say, otherwise I shall take you to task. Ubayy b. Ka'b said: None should stand with him (as a witness) but the youngest amongst the people. Abu Sa'id said: I am the youngest amongst the people, whereupon he said: Then you go with him (to support his contention)}}
\hadithdefcmd{muslim}{5627}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، بِهَذَا الإِسْنَادِ ‏.‏ وَزَادَ ابْنُ أَبِي عُمَرَ فِي حَدِيثِهِ قَالَ أَبُو سَعِيدٍ فَقُمْتُ مَعَهُ فَذَهَبْتُ إِلَى عُمَرَ فَشَهِدْتُ ‏.‏\hadithno{5627}\hadithtrans{This hadith has been narrated on the authority of Yazid b. Khusaifa with the same chain of transmitters but with this addition:Abu Sa'id said: So I stood up, and went to 'Umar and gave witness (to what Abu Musa had said)}}
\hadithdefcmd{muslim}{5628}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، أَنَّ بُسْرَ بْنَ سَعِيدٍ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ كُنَّا فِي مَجْلِسٍ عِنْدَ أُبَىِّ بْنِ كَعْبٍ فَأَتَى أَبُو مُوسَى الأَشْعَرِيُّ مُغْضَبًا حَتَّى وَقَفَ فَقَالَ أَنْشُدُكُمُ اللَّهَ هَلْ سَمِعَ أَحَدٌ مِنْكُمْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الاِسْتِئْذَانُ ثَلاَثٌ فَإِنْ أُذِنَ لَكَ وَإِلاَّ فَارْجِعْ ‏"‏ ‏.‏ قَالَ أُبَىٌّ وَمَا ذَاكَ قَالَ اسْتَأْذَنْتُ عَلَى عُمَرَ بْنِ الْخَطَّابِ أَمْسِ ثَلاَثَ مَرَّاتٍ فَلَمْ يُؤْذَنْ لِي فَرَجَعْتُ ثُمَّ جِئْتُهُ الْيَوْمَ فَدَخَلْتُ عَلَيْهِ فَأَخْبَرْتُهُ أَنِّي جِئْتُ أَمْسِ فَسَلَّمْتُ ثَلاَثًا ثُمَّ انْصَرَفْتُ قَالَ قَدْ سَمِعْنَاكَ وَنَحْنُ حِينَئِذٍ عَلَى شُغْلٍ فَلَوْ مَا اسْتَأْذَنْتَ حَتَّى يُؤْذَنَ لَكَ قَالَ اسْتَأْذَنْتُ كَمَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فَوَاللَّهِ لأُوجِعَنَّ ظَهْرَكَ وَبَطْنَكَ ‏.‏ أَوْ لَتَأْتِيَنَّ بِمَنْ يَشْهَدُ لَكَ عَلَى هَذَا ‏.‏ فَقَالَ أُبَىُّ بْنُ كَعْبٍ فَوَاللَّهِ لاَ يَقُومُ مَعَكَ إِلاَّ أَحْدَثُنَا سِنًّا قُمْ يَا أَبَا سَعِيدٍ ‏.‏ فَقُمْتُ حَتَّى أَتَيْتُ عُمَرَ فَقُلْتُ قَدْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ هَذَا ‏.‏\hadithno{5628}\hadithtrans{Abd Sa'id Khudri reported:We were in the company of Ubayy b. Ka'b that Abu Musa Ash'ari came there in a state of anger. He stood (before us) and said: I ask you to bear witness in the name of Allah whether anyone amongst you heard Allah's Messenger (ﷺ) as saying: Permission (for entering the house) should be sought three times and if permission is granted to you (then get in). otherwise go back. Ubayy b. Ka'b said: What is the iiiatter? He said: I sought permission yesterday from 'Umar b. Khattab three times but he did not permit me, so I came back; then I went to him today and visited him and informed him that I had come to him yesterday and greeted him thrice, then came back, whereupon he said: Yes, we did hear you but be were at that time busy, but why did you not seek permission (further and you must have never gone back until you were permitted to do so). He said: I sought permission (in the manner) that I heard Allah's Messenger (ﷺ) having said (in connection 'With the seeking of permission for entering the house of a stranger). Thereupon he (Hadrat Umar) said: By Allah, I shall torture your back and your stomach unless you bring one who may bear witness to what you state. 'Ubayy b. Ka'b said: By Allah, none should stand with you (to bear testimony) but the youngest amongst us. And he therefore, said to Abu Sa'id: Stand up. So I stood up until I came to Umar and said: I heard Allah's Messenger (ﷺ) say this}}
\hadithdefcmd{muslim}{5629}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ مُفَضَّلٍ - حَدَّثَنَا سَعِيدُ، بْنُ يَزِيدَ عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ أَبَا مُوسَى، أَتَى بَابَ عُمَرَ فَاسْتَأْذَنَ فَقَالَ عُمَرُ وَاحِدَةٌ ‏.‏ ثُمَّ اسْتَأْذَنَ الثَّانِيَةَ فَقَالَ عُمَرُ ثِنْتَانِ ‏.‏ ثُمَّ اسْتَأْذَنَ الثَّالِثَةَ فَقَالَ عُمَرُ ثَلاَثٌ ‏.‏ ثُمَّ انْصَرَفَ فَأَتْبَعَهُ فَرَدَّهُ فَقَالَ إِنْ كَانَ هَذَا شَيْئًا حَفِظْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَهَا وَإِلاَّ فَلأَجْعَلَنَّكَ عِظَةً ‏.‏ قَالَ أَبُو سَعِيدٍ فَأَتَانَا فَقَالَ أَلَمْ تَعْلَمُوا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الاِسْتِئْذَانُ ثَلاَثٌ ‏"‏ ‏.‏ قَالَ فَجَعَلُوا يَضْحَكُونَ - قَالَ - فَقُلْتُ أَتَاكُمْ أَخُوكُمُ الْمُسْلِمُ قَدْ أُفْزِعَ تَضْحَكُونَ انْطَلِقْ فَأَنَا شَرِيكُكَ فِي هَذِهِ الْعُقُوبَةِ ‏.‏ فَأَتَاهُ فَقَالَ هَذَا أَبُو سَعِيدٍ ‏.‏\hadithno{5629}\hadithtrans{Abu Sa'id reported that Abu Musa al-Ash'ari came to the door of 'Umar and sought his permission (to get into his house). Umar said:That is once. He again sought permission for the second time and 'Umar said: It is twice. He again sought permission for the third time and Umar said: It is thrice. He (Abu Musa) then went back. He (Hadrat 'Umar) (sent someone) to pursue him so that he should be brought back. Thereupon he (Hadrat Umar) said: If this act (of yours is in accordance with the command of Allah's Messenger (ﷺ) you have preserved in your mind, then it is all right, otherwise (I shall give you such a severe punishment) that it will serve as an example to others. Abu Sa'id said: Then he (Abu Musa) came to us and said: Do you remember Allah's Messenger (ﷺ) having said this:" Permission is for three times"? They (Companions sitting in that cothpany) began to laugh, whereupon he (Abu Musa) said: There comes to you your Muslim brother who had been perturbed and you laugh. Abu Sa'id said: (Well), you go forth. I shall be your participant in this trouble of yours. So he came to him (Hadrat Umar) and said: Here is Abu Sa'id (to support my statement)}}
\hadithdefcmd{muslim}{5630}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي مَسْلَمَةَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ بْنِ خِرَاشٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، عَنِ الْجُرَيْرِيِّ، وَسَعِيدِ بْنِ يَزِيدَ كِلاَهُمَا عَنْ أَبِي نَضْرَةَ، قَالاَ سَمِعْنَاهُ يُحَدِّثُ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، ‏.‏ بِمَعْنَى حَدِيثِ بِشْرِ بْنِ مُفَضَّلٍ عَنْ أَبِي مَسْلَمَةَ، ‏.‏\hadithno{5630}\hadithtrans{This hadith bu been narrated on the authority of Abu Sa'id Khudri through another chain of transmitters}}
\hadithdefcmd{muslim}{5631}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنِ ابْنِ جُرَيْجٍ، حَدَّثَنَا عَطَاءٌ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، أَنَّ أَبَا مُوسَى، اسْتَأْذَنَ عَلَى عُمَرَ ثَلاَثًا فَكَأَنَّهُ وَجَدَهُ مَشْغُولاً فَرَجَعَ فَقَالَ عُمَرُ أَلَمْ تَسْمَعْ صَوْتَ عَبْدِ اللَّهِ بْنِ قَيْسٍ ائْذَنُوا لَهُ ‏.‏ فَدُعِيَ لَهُ فَقَالَ مَا حَمَلَكَ عَلَى مَا صَنَعْتَ قَالَ إِنَّا كُنَّا نُؤْمَرُ بِهَذَا ‏.‏ قَالَ لَتُقِيمَنَّ عَلَى هَذَا بَيِّنَةً أَوْ لأَفْعَلَنَّ ‏.‏ فَخَرَجَ فَانْطَلَقَ إِلَى مَجْلِسٍ مِنَ الأَنْصَارِ فَقَالُوا لاَ يَشْهَدُ لَكَ عَلَى هَذَا إِلاَّ أَصْغَرُنَا ‏.‏ فَقَامَ أَبُو سَعِيدٍ فَقَالَ كُنَّا نُؤْمَرُ بِهَذَا ‏.‏ فَقَالَ عُمَرُ خَفِيَ عَلَىَّ هَذَا مِنْ أَمْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَلْهَانِي عَنْهُ الصَّفْقُ بِالأَسْوَاقِ ‏.‏\hadithno{5631}\hadithtrans{Ubaid b. Umair reported that Abu Musa brought permission from Umar (to enter the house) three times, and finding him busy came back, whereupon Umar said (to the Inmates of his house):Did you not hear the voice of 'Abdullah b. Qais (the Kunya of Abu Musa Ash'ari)? He was called back. and he (Hadrat 'Umar) said: What did prompt you to do it? Thereupon, he said: This is how we have been commanded to act. He (Hadrat 'Umar) said: Bring evidence (in support of) it, otherwise I shall deal (strictly) with you. So he (Abu Musa) set out and came to the meeting of the Ansar and asked them to bear witness before hadrat Umar about this. They (the Companions present there) said: None but the youngest amongst us would bear out this fact. So Abu Sa'id Khudri (who was the youngest one in that company) said: We have been commanded to do so (while visiting the house of other people). Thereupon 'Umar said: This command of Allah's Messenger (ﷺ) had remained hidden from me up till now due to (my) business in the market}}
\hadithdefcmd{muslim}{5632}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، ح وَحَدَّثَنَا حُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا النَّضْرُ، - يَعْنِي ابْنَ شُمَيْلٍ - قَالاَ جَمِيعًا حَدَّثَنَا ابْنُ جُرَيْجٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ وَلَمْ يَذْكُرْ فِي حَدِيثِ النَّضْرِ أَلْهَانِي عَنْهُ الصَّفْقُ بِالأَسْوَاقِ ‏.‏\hadithno{5632}\hadithtrans{This hadith has been transmitted on the authority of Ibn Juraij, but there is no mention of the words" business in the market}}
\hadithdefcmd{muslim}{5633}{حَدَّثَنَا حُسَيْنُ بْنُ حُرَيْثٍ أَبُو عَمَّارٍ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، أَخْبَرَنَا طَلْحَةُ بْنُ، يَحْيَى عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ جَاءَ أَبُو مُوسَى إِلَى عُمَرَ بْنِ الْخَطَّابِ فَقَالَ السَّلاَمُ عَلَيْكُمْ هَذَا عَبْدُ اللَّهِ بْنُ قَيْسٍ ‏.‏ فَلَمْ يَأْذَنْ لَهُ فَقَالَ السَّلاَمُ عَلَيْكُمْ هَذَا أَبُو مُوسَى السَّلاَمُ عَلَيْكُمْ هَذَا الأَشْعَرِيُّ ‏.‏ ثُمَّ انْصَرَفَ فَقَالَ رُدُّوا عَلَىَّ رُدُّوا عَلَىَّ ‏.‏ فَجَاءَ فَقَالَ يَا أَبَا مُوسَى مَا رَدَّكَ كُنَّا فِي شُغْلٍ ‏.‏ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الاِسْتِئْذَانُ ثَلاَثٌ فَإِنْ أُذِنَ لَكَ وَإِلاَّ فَارْجِعْ ‏"‏ ‏.‏ قَالَ لَتَأْتِيَنِّي عَلَى هَذَا بِبَيِّنَةٍ وَإِلاَّ فَعَلْتُ وَفَعَلْتُ ‏.‏ فَذَهَبَ أَبُو مُوسَى قَالَ عُمَرُ إِنْ وَجَدَ بَيِّنَةً تَجِدُوهُ عِنْدَ الْمِنْبَرِ عَشِيَّةً وَإِنْ لَمْ يَجِدْ بَيِّنَةً فَلَمْ تَجِدُوهُ ‏.‏ فَلَمَّا أَنْ جَاءَ بِالْعَشِيِّ وَجَدُوهُ قَالَ يَا أَبَا مُوسَى مَا تَقُولُ أَقَدْ وَجَدْتَ قَالَ نَعَمْ أُبَىَّ بْنَ كَعْبٍ ‏.‏ قَالَ عَدْلٌ ‏.‏ قَالَ يَا أَبَا الطُّفَيْلِ مَا يَقُولُ هَذَا قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ذَلِكَ يَا ابْنَ الْخَطَّابِ فَلاَ تَكُونَنَّ عَذَابًا عَلَى أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ سُبْحَانَ اللَّهِ إِنَّمَا سَمِعْتُ شَيْئًا فَأَحْبَبْتُ أَنْ أَتَثَبَّتَ ‏.‏\hadithno{5633}\hadithtrans{Abu Musa Ash'ari reported that he went to 'Umar b. Khattab and greeted him by saying:As-Salamu-'Alaikum, here is 'Abdullah b. Qais, but he did not permit him (to get in). He (Abu Musa Ash'ari) again greeted him with as-Salamu-'Alaikum and said: Here is Abu Musa, but he (Hadrat 'Umar) did not permit him (to get in). He again said: As-Salam-u-'Alaikum, (and said) here is Ash'ari, (then receiving no response he came back). He (Hadrat 'Umar) said: Bring him back to me, bring him back to me So he went there (in the presence of Hadrat 'Umar) and he said to him: Abu Musa, what made you go back, while we were busy in some work? He said: I heard Allah's Messenger (may. peace be upon him) as saying: Permission should be sought thrice. And if you are permitted, (then get in), otherwise go back. He said: Bring witness to this fact, otherwise I shall do this and that, i. e. I shall punish you. Abu Musa went away and 'Umar said to him (on his departure): It he (Abu Musa) finds a witness he should meet him by the side of the pulpit in the evening and it he does not find a witness you would not find him there. When it was evening he (Hadrat 'Umar) found him (Abu Musa) there. He (Hadrat 'Umar) said: Abu Musa, have you been able to find a witness to what you have said? He said: Yes. Here is Ubayy bin Ka'b, whereupon he (Hadrat 'Umar) said: Yes, he is an authentic (witness). He (Hadrat 'Umar) said: Abu Tufail (the kunya of Ubayy b. Ka'b), what does he (Abu Musa say? Thereupon he said: Ibn Khattab, I heard Allah's Messenger (ﷺ) as saying so. Do not prove to be a hard (task-master) for the Companions of Allah's Messenger (ﷺ), whereupon he Hadrat 'Umar said: Hallowed be Allah. I had heard something (in this connection), but I wished it to be established (as an undeniable fact)}}
\hadithdefcmd{muslim}{5634}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَدَعَوْتُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ قُلْتُ أَنَا ‏.‏ قَالَ فَخَرَجَ وَهُوَ يَقُولُ ‏"‏ أَنَا أَنَا ‏"‏ ‏.‏\hadithno{5634}\hadithtrans{Jabir b. Abdullah reported:I came to Allah's Apostle (ﷺ) and called him (with a view to seeking permission). whereupon Allah's Apostle (ﷺ) said: Who is it? I said: It is I. Thereupon he (the Holy Prophet) came out saying: It is I. it is I}}
\hadithdefcmd{muslim}{5635}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ أَبُو بَكْرٍ، حَدَّثَنَا - وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ، اللَّهِ قَالَ اسْتَأْذَنْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ فَقُلْتُ أَنَا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَنَا أَنَا ‏"‏ ‏.‏\hadithno{5635}\hadithtrans{Jabir b. Abdullah reported:I sought permission from Allah's Messenger (may peace be upoh him) to see him. He said: Who is it? I said: It is I. Thereupon Allah's Messenger (ﷺ) said: It is I. it is I (these words lead me to no conclusion)}}
\hadithdefcmd{muslim}{5636}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، وَأَبُو عَامِرٍ الْعَقَدِيُّ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي وَهْبُ بْنُ جَرِيرٍ، ح وَحَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ، حَدَّثَنَا بَهْزٌ، كُلُّهُمْ عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِهِمْ كَأَنَّهُ كَرِهَ ذَلِكَ ‏.‏\hadithno{5636}\hadithtrans{This hadith has been transmitted on the authority of Shu'ba with a slight variation of wording and that is:The Prophet (ﷺ) uttered these words: It is I. it is I." in the manner as if he disapproved of this}}
\hadithdefcmd{muslim}{5638}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، - وَاللَّفْظُ لِيَحْيَى - ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ، أَخْبَرَهُ أَنَّ رَجُلاً اطَّلَعَ فِي جُحْرٍ فِي بَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِدْرًى يَحُكُّ بِهِ رَأْسَهُ فَلَمَّا رَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَوْ أَعْلَمُ أَنَّكَ تَنْظُرُنِي لَطَعَنْتُ بِهِ فِي عَيْنِكَ ‏"‏ ‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا جُعِلَ الإِذْنُ مِنْ أَجْلِ الْبَصَرِ ‏"‏ ‏.‏\hadithno{5638}\hadithtrans{Sahl b. Sa'd as-Sa'id reported that a person peeped through the hole of the door of Allah's Messenger (ﷺ), and at that time Allah's Messenger (ﷺ) had with him a scratching instrument with which he had been scratching his head. When Allah's Messenger (ﷺ) saw him. he said:If I were to know that you had been peeping through the door, I would have thrust that into your eyes, and Allah's Messenger (ﷺ) said: Permission is needed as a protection against glance}}
\hadithdefcmd{muslim}{5639}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّأَخْبَرَهُ أَنَّ رَجُلاً اطَّلَعَ مِنْ جُحْرٍ فِي بَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِدْرًى يُرَجِّلُ بِهِ رَأْسَهُ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ أَعْلَمُ أَنَّكَ تَنْظُرُ طَعَنْتُ بِهِ فِي عَيْنِكَ إِنَّمَا جَعَلَ اللَّهُ الإِذْنَ مِنْ أَجْلِ الْبَصَرِ ‏"‏ ‏.‏\hadithno{5639}\hadithtrans{Sahl b. Sa'd as-Sa'idi reported that a person peeped through the hole of the door of Allah's Messenger (ﷺ) and he had with him some pointed thing with which he had been adjusting (the hair of his head). Allah's Messenger (ﷺ) said to him:If I were to know that you had been peeping. I would have thrust it in your eyes. Allah has prescribed seeking permission because of protection against glance}}
\hadithdefcmd{muslim}{5640}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ أَبِي عُمَرَ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا مَعْمَرٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، عَنْ سَهْلِ بْنِ سَعْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ اللَّيْثِ وَيُونُسَ ‏.‏\hadithno{5640}\hadithtrans{This hadith has been transmitted on the authority of Sahl b. Sa'd as-Sa'idi with a slight variation of wording}}
\hadithdefcmd{muslim}{5641}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو كَامِلٍ فُضَيْلُ بْنُ حُسَيْنٍ وَقُتَيْبَةُ بْنُ سَعِيدٍ - وَاللَّفْظُ لِيَحْيَى وَأَبِي كَامِلٍ - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عُبَيْدِ، اللَّهِ بْنِ أَبِي بَكْرٍ عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، اطَّلَعَ مِنْ بَعْضِ حُجَرِ النَّبِيِّ صلى الله عليه وسلم فَقَامَ إِلَيْهِ بِمِشْقَصٍ أَوْ مَشَاقِصَ فَكَأَنِّي أَنْظُرُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَخْتِلُهُ لِيَطْعُنَهُ ‏.‏\hadithno{5641}\hadithtrans{Anas b. Malik reported that a person peeped in some of the holes (in the doors) of Allah's Messenger (ﷺ) (and he found him) standing up (lifting) an arrow or some arrows. The narrator said:I perceived as if Allah's Messenger (ﷺ) was going to pierce (his eyes)}}
\hadithdefcmd{muslim}{5642}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اطَّلَعَ فِي بَيْتِ قَوْمٍ بِغَيْرِ إِذْنِهِمْ فَقَدْ حَلَّ لَهُمْ أَنْ يَفْقَئُوا عَيْنَهُ ‏"‏ ‏.‏\hadithno{5642}\hadithtrans{Abu Huraira reported having heard Allah's Messenger (ﷺ) say:He who peeped into the house of people without their consent, it is permissible for them to put out his eyes}}
\hadithdefcmd{muslim}{5643}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ أَنَّ رَجُلاً اطَّلَعَ عَلَيْكَ بِغَيْرِ إِذْنٍ فَخَذَفْتَهُ بِحَصَاةٍ فَفَقَأْتَ عَيْنَهُ مَا كَانَ عَلَيْكَ مِنْ جُنَاحٍ ‏"‏ ‏.‏\hadithno{5643}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:If a person were to cast a glance in your (house) without permission, and you had in your hand a staff and you would have thrust that in his eyes, there is no harm for you}}
\hadithdefcmd{muslim}{5644}{حَدَّثَنِي قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، كِلاَهُمَا عَنْ يُونُسَ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا يُونُسُ، عَنْ عَمْرِو بْنِ سَعِيدٍ، عَنْ أَبِي زُرْعَةَ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ نَظَرِ الْفُجَاءَةِ فَأَمَرَنِي أَنْ أَصْرِفَ بَصَرِي ‏.‏\hadithno{5644}\hadithtrans{Jarir b. 'Abdullah reported:I asked Allah's Messenger (ﷺ) about the sudden glance (that is cast) on the face (of a non-Mahram). He commanded me that I should turn away my eyes}}
\hadithdefcmd{muslim}{5645}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الأَعْلَى، وَقَالَ، إِسْحَاقُ أَخْبَرَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، كِلاَهُمَا عَنْ يُونُسَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5645}\hadithtrans{This hadith has been narrated on the authority of Yunus through another chain of transmitters}}
