% Auto-generated chapter 11 for malik
% Hadiths in this chapter: 4

\hadithdefcmd{malik}{441}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ رُومَانَ، عَنْ صَالِحِ بْنِ خَوَّاتٍ، عَمَّنْ صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ ذَاتِ الرِّقَاعِ صَلاَةَ الْخَوْفِ أَنَّ طَائِفَةً صَفَّتْ مَعَهُ وَصَفَّتْ طَائِفَةٌ وِجَاهَ الْعَدُوِّ فَصَلَّى بِالَّتِي مَعَهُ رَكْعَةً ثُمَّ ثَبَتَ قَائِمًا وَأَتَمُّوا لأَنْفُسِهِمْ ثُمَّ انْصَرَفُوا فَصَفُّوا وِجَاهَ الْعَدُوِّ وَجَاءَتِ الطَّائِفَةُ الأُخْرَى فَصَلَّى بِهِمُ الرَّكْعَةَ الَّتِي بَقِيَتْ مِنْ صَلاَتِهِ ثُمَّ ثَبَتَ جَالِسًا وَأَتَمُّوا لأَنْفُسِهِمْ ثُمَّ سَلَّمَ بِهِمْ ‏.‏\hadithno{441}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me that Malik said, "The sunna concerning the time of prayer on the ids of Fitr and Adha - and there is no disagreement amongst us about it - is that the imam leaves his house and as soon as he has reached the place of prayer the prayer falls due." Yahya said that Malik was asked whether a man who prayed with the imam could leave before the khutba, and he said, "He should not leave until the imam leaves." Yahya related to me from Malik from Yazid ibn Ruman from Salih ibn Khawwat from someone who had prayed (the prayer of fear) with the Messenger of Allah, may Allah bless him and grant him peace, on the day of Dhat ar-Riqa that one group had formed a row with him and one group had formed a row opposite the enemy. He then prayed one raka with the group he was with, and then remained standing while they finished by themselves. They then left and formed a row opposite the enemy, and then the other group came and he prayed the remaining raka of his prayer with them, and then remained sitting while they finished by themselves. Then he said the taslim with them}}
\hadithdefcmd{malik}{442}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ صَالِحِ بْنِ خَوَّاتٍ، أَنَّ سَهْلَ بْنَ أَبِي حَثْمَةَ، حَدَّثَهُ أَنَّ صَلاَةَ الْخَوْفِ أَنْ يَقُومَ الإِمَامُ وَمَعَهُ طَائِفَةٌ مِنْ أَصْحَابِهِ وَطَائِفَةٌ مُوَاجِهَةٌ الْعَدُوَّ فَيَرْكَعُ الإِمَامُ رَكْعَةً وَيَسْجُدُ بِالَّذِينَ مَعَهُ ثُمَّ يَقُومُ فَإِذَا اسْتَوَى قَائِمًا ثَبَتَ وَأَتَمُّوا لأَنْفُسِهِمُ الرَّكْعَةَ الْبَاقِيَةَ ثُمَّ يُسَلِّمُونَ وَيَنْصَرِفُونَ وَالإِمَامُ قَائِمٌ فَيَكُونُونَ وِجَاهَ الْعَدُوِّ ثُمَّ يُقْبِلُ الآخَرُونَ الَّذِينَ لَمْ يُصَلُّوا فَيُكَبِّرُونَ وَرَاءَ الإِمَامِ فَيَرْكَعُ بِهِمُ الرَّكْعَةَ وَيَسْجُدُ ثُمَّ يُسَلِّمُ فَيَقُومُونَ فَيَرْكَعُونَ لأَنْفُسِهِمُ الرَّكْعَةَ الْبَاقِيَةَ ثُمَّ يُسَلِّمُونَ ‏.‏\hadithno{442}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from al-Qasim ibn Muhammad from Salih ibn Khawwat that Sahl ibn Abi Hathma related to him that the form of the prayer of fear was that the imam stood with a group of his companions, while another group faced the enemy. The imam prayed one raka with them, including the prostration, and then stood. He remained standing while they completed the remaining raka by themselves. They then said the taslim, left, and formed up opposite the enemy while the imam remained standing. Then the others who had not prayed came forward and said the takbir behind the imam and he prayed one raka with them, including the prostration. He then said the taslim, while they stood up and prayed the remaining raka by themselves. Then they said the taslim}}
\hadithdefcmd{malik}{443}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا سُئِلَ عَنْ صَلاَةِ الْخَوْفِ، قَالَ يَتَقَدَّمُ الإِمَامُ وَطَائِفَةٌ مِنَ النَّاسِ فَيُصَلِّي بِهِمُ الإِمَامُ رَكْعَةً وَتَكُونُ طَائِفَةٌ مِنْهُمْ بَيْنَهُ وَبَيْنَ الْعَدُوِّ لَمْ يُصَلُّوا فَإِذَا صَلَّى الَّذِينَ مَعَهُ رَكْعَةً اسْتَأْخَرُوا مَكَانَ الَّذِينَ لَمْ يُصَلُّوا وَلاَ يُسَلِّمُونَ وَيَتَقَدَّمُ الَّذِينَ لَمْ يُصَلُّوا فَيُصَلُّونَ مَعَهُ رَكْعَةً ثُمَّ يَنْصَرِفُ الإِمَامُ وَقَدْ صَلَّى رَكْعَتَيْنِ فَتَقُومُ كُلُّ وَاحِدَةٍ مِنَ الطَّائِفَتَيْنِ فَيُصَلُّونَ لأَنْفُسِهِمْ رَكْعَةً رَكْعَةً بَعْدَ أَنْ يَنْصَرِفَ الإِمَامُ فَيَكُونُ كُلُّ وَاحِدَةٍ مِنَ الطَّائِفَتَيْنِ قَدْ صَلَّوْا رَكْعَتَيْنِ فَإِنْ كَانَ خَوْفًا هُوَ أَشَدَّ مِنْ ذَلِكَ صَلَّوْا رِجَالاً قِيَامًا عَلَى أَقْدَامِهِمْ أَوْ رُكْبَانًا مُسْتَقْبِلِي الْقِبْلَةِ أَوْ غَيْرَ مُسْتَقْبِلِيهَا ‏.‏\hadithno{443}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar, when asked about the fear prayer said, "The imam and a group of people go forward and the imam prays a raka with them, while another group, who have not yet prayed, position themselves between him and the enemy. When those who are with him have prayed a raka they draw back to where those who have not prayed are, and do not say the taslim. Then those who have not prayed come forward and pray a raka with him. Then the imam leaves, as he has now prayed two rakas. Everyone else in the two groups stands and prays a raka by himself after the imam has left. In this way each of the two groups will have prayed two rakas. If the fear is greater than that, then the men pray standing on their feet or mounted, either facing the qibla or otherwise}}
\hadithdefcmd{malik}{444}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ مَا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الظُّهْرَ وَالْعَصْرَ يَوْمَ الْخَنْدَقِ حَتَّى غَابَتِ الشَّمْسُ ‏.‏ قَالَ مَالِكٌ وَحَدِيثُ الْقَاسِمِ بْنِ مُحَمَّدٍ عَنْ صَالِحِ بْنِ خَوَّاتٍ أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي صَلاَةِ الْخَوْفِ ‏.‏\hadithno{444}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Malik said that Nafi said, "I do not believe that Abdullah ibn Umar related it from anyone other than the Messenger of Allah, may Allah bless him and grant him peace." Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab said, "The Messenger of Allah, may Allah bless him and grant him peace, did not pray dhuhr and asr on the day of the Trench until after the sun had set." Malik said, "The hadith of al- Qasim ibn Muhammad from Salih ibn Khawwat is the one I like most out of what I have heard about the fear prayer}}
