% Auto-generated chapter 89 for bukhari
% Hadiths in this chapter: 13

\hadithdefcmd{bukhari}{6940}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ خَالِدِ بْنِ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ هِلاَلِ بْنِ أُسَامَةَ، أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، أَخْبَرَهُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَدْعُو فِي الصَّلاَةِ ‏ "‏ اللَّهُمَّ أَنْجِ عَيَّاشَ بْنَ أَبِي رَبِيعَةَ، وَسَلَمَةَ بْنَ هِشَامٍ، وَالْوَلِيدَ بْنَ الْوَلِيدِ، اللَّهُمَّ أَنْجِ الْمُسْتَضْعَفِينَ مِنَ الْمُؤْمِنِينَ، اللَّهُمَّ اشْدُدْ وَطْأَتَكَ عَلَى مُضَرَ، وَابْعَثْ عَلَيْهِمْ سِنِينَ كَسِنِي يُوسُفَ ‏"‏‏.‏\hadithno{6940}\hadithtrans{Narrated Abi Huraira:The Prophet (ﷺ) used to invoke Allah in his prayer, "O Allah! Save `Aiyash bin Abi Rabi`a and Salama bin Hisham and Al-Walid bin Al-Walid; O Allah! Save the weak among the believers; O Allah! Be hard upon the tribe of Mudar and inflict years (of famine) upon them like the (famine) years of Joseph}}
\hadithdefcmd{bukhari}{6941}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ حَوْشَبٍ الطَّائِفِيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثٌ مَنْ كُنَّ فِيهِ وَجَدَ حَلاَوَةَ الإِيمَانِ أَنْ يَكُونَ اللَّهُ وَرَسُولُهُ أَحَبَّ إِلَيْهِ مِمَّا سِوَاهُمَا، وَأَنْ يُحِبَّ الْمَرْءَ لاَ يُحِبُّهُ إِلاَّ لِلَّهِ، وَأَنْ يَكْرَهَ أَنْ يَعُودَ فِي الْكُفْرِ، كَمَا يَكْرَهُ أَنْ يُقْذَفَ فِي النَّارِ ‏"‏‏.‏\hadithno{6941}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) said, "Whoever possesses the (following) three qualities will have the sweetness of faith (1): The one to whom Allah and His Apostle becomes dearer than anything else; (2) Who loves a person and he loves him only for Allah's Sake; (3) who hates to revert to atheism (disbelief) as he hates to be thrown into the Fire}}
\hadithdefcmd{bukhari}{6942}{حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا عَبَّادٌ، عَنْ إِسْمَاعِيلَ، سَمِعْتُ قَيْسًا، سَمِعْتُ سَعِيدَ بْنَ زَيْدٍ، يَقُولُ لَقَدْ رَأَيْتُنِي وَإِنَّ عُمَرَ مُوثِقِي عَلَى الإِسْلاَمِ، وَلَوِ انْقَضَّ أُحُدٌ مِمَّا فَعَلْتُمْ بِعُثْمَانَ كَانَ مَحْقُوقًا أَنْ يَنْقَضَّ‏.‏\hadithno{6942}\hadithtrans{Narrated Qais:I heard Sa`id bin Zaid saying, "I have seen myself tied and forced by `Umar to leave Islam (Before `Umar himself embraced Islam). And if the mountain of Uhud were to collapse for the evil which you people had done to `Uthman, then Uhud would have the right to do so." (See Hadith No. 202, Vol)}}
\hadithdefcmd{bukhari}{6943}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، حَدَّثَنَا قَيْسٌ، عَنْ خَبَّابِ بْنِ الأَرَتِّ، قَالَ شَكَوْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهْوَ مُتَوَسِّدٌ بُرْدَةً لَهُ فِي ظِلِّ الْكَعْبَةِ فَقُلْنَا أَلاَ تَسْتَنْصِرُ لَنَا أَلاَ تَدْعُو لَنَا‏.‏ فَقَالَ ‏ "‏ قَدْ كَانَ مَنْ قَبْلَكُمْ يُؤْخَذُ الرَّجُلُ فَيُحْفَرُ لَهُ فِي الأَرْضِ فَيُجْعَلُ فِيهَا، فَيُجَاءُ بِالْمِنْشَارِ فَيُوضَعُ عَلَى رَأْسِهِ فَيُجْعَلُ نِصْفَيْنِ، وَيُمَشَّطُ بِأَمْشَاطِ الْحَدِيدِ مَا دُونَ لَحْمِهِ وَعَظْمِهِ، فَمَا يَصُدُّهُ ذَلِكَ عَنْ دِينِهِ، وَاللَّهِ لَيَتِمَّنَّ هَذَا الأَمْرُ، حَتَّى يَسِيرَ الرَّاكِبُ مِنْ صَنْعَاءَ إِلَى حَضْرَمَوْتَ لاَ يَخَافُ إِلاَّ اللَّهَ وَالذِّئْبَ عَلَى غَنَمِهِ، وَلَكِنَّكُمْ تَسْتَعْجِلُونَ ‏"‏‏.‏\hadithno{6943}\hadithtrans{Narrated Khabbab bin Al-Art:We complained to Allah's Messenger (ﷺ) (about our state) while he was leaning against his sheet cloak in the shade of the Ka`ba. We said, "Will you ask Allah to help us? Will you invoke Allah for us?" He said, "Among those who were before you a (believer) used to be seized and, a pit used to be dug for him and then he used to be placed in it. Then a saw used to be brought and put on his head which would be split into two halves. His flesh might be combed with iron combs and removed from his bones, yet, all that did not cause him to revert from his religion. By Allah! This religion (Islam) will be completed (and triumph) till a rider (traveler) goes from San`a' (the capital of Yemen) to Hadramout fearing nobody except Allah and the wolf lest it should trouble his sheep, but you are impatient." (See Hadith No. 191, Vol)}}
\hadithdefcmd{bukhari}{6944}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ بَيْنَمَا نَحْنُ فِي الْمَسْجِدِ إِذْ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ انْطَلِقُوا إِلَى يَهُودَ ‏"‏‏.‏ فَخَرَجْنَا مَعَهُ حَتَّى جِئْنَا بَيْتَ الْمِدْرَاسِ فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَنَادَاهُمْ ‏"‏ يَا مَعْشَرَ يَهُودَ أَسْلِمُوا تَسْلَمُوا ‏"‏‏.‏ فَقَالُوا قَدْ بَلَّغْتَ يَا أَبَا الْقَاسِمِ‏.‏ فَقَالَ ‏"‏ ذَلِكَ أُرِيدُ ‏"‏، ثُمَّ قَالَهَا الثَّانِيَةَ‏.‏ فَقَالُوا قَدْ بَلَّغْتَ يَا أَبَا الْقَاسِمِ‏.‏ ثُمَّ قَالَ الثَّالِثَةَ فَقَالَ ‏"‏ اعْلَمُوا أَنَّ الأَرْضَ لِلَّهِ وَرَسُولِهِ، وَإِنِّي أُرِيدُ أَنْ أُجْلِيَكُمْ، فَمَنْ وَجَدَ مِنْكُمْ بِمَالِهِ شَيْئًا فَلْيَبِعْهُ، وَإِلاَّ فَاعْلَمُوا أَنَّمَا الأَرْضُ لِلَّهِ وَرَسُولِهِ ‏"‏‏.‏\hadithno{6944}\hadithtrans{Narrated Abu Huraira:While we were in the mosque, Allah's Messenger (ﷺ) came out to us and said, "Let us proceed to the Jews." So we went along with him till we reached Bait-al-Midras (a place where the Torah used to be recited and all the Jews of the town used to gather). The Prophet (ﷺ) stood up and addressed them, "O Assembly of Jews! Embrace Islam and you will be safe!" The Jews replied, "O Aba-l-Qasim! You have conveyed Allah's message to us." The Prophet (ﷺ) said, "That is what I want (from you)." He repeated his first statement for the second time, and they said, "You have conveyed Allah's message, O Aba-l- Qasim." Then he said it for the third time and added, "You should Know that the earth belongs to Allah and His Apostle, and I want to exile you fro,,, this land, so whoever among you owns some property, can sell it, otherwise you should know that the Earth belongs to Allah and His Apostle." (See Hadith No. 392, Vol)}}
\hadithdefcmd{bukhari}{6945}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَبْدِ الرَّحْمَنِ، وَمُجَمِّعٍ، ابْنَىْ يَزِيدَ بْنِ جَارِيَةَ الأَنْصَارِيِّ عَنْ خَنْسَاءَ بِنْتِ خِذَامٍ الأَنْصَارِيَّةِ، أَنَّ أَبَاهَا، زَوَّجَهَا وَهْىَ ثَيِّبٌ، فَكَرِهَتْ ذَلِكَ، فَأَتَتِ النَّبِيَّ صلى الله عليه وسلم فَرَدَّ نِكَاحَهَا‏.‏\hadithno{6945}\hadithtrans{Narrated Khansa' bint Khidam Al-Ansariya:That her father gave her in marriage when she was a matron and she disliked that marriage. So she came and (complained) to the Prophets and he declared that marriage invalid. (See Hadith No. 69, Vol)}}
\hadithdefcmd{bukhari}{6946}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ أَبِي عَمْرٍو ـ هُوَ ذَكْوَانُ ـ عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ يُسْتَأْمَرُ النِّسَاءُ فِي أَبْضَاعِهِنَّ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ قُلْتُ فَإِنَّ الْبِكْرَ تُسْتَأْمَرُ فَتَسْتَحِي فَتَسْكُتُ‏.‏ قَالَ ‏"‏ سُكَاتُهَا إِذْنُهَا ‏"‏‏.‏\hadithno{6946}\hadithtrans{Narrated `Aisha:I asked the Prophet, "O Allah's Messenger (ﷺ)! Should the women be asked for their consent to their marriage?" He said, "Yes." I said, "A virgin, if asked, feels shy and keeps quiet." He said, "Her silence means her consent}}
\hadithdefcmd{bukhari}{6947}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرٍ ـ رضى الله عنه ـ أَنَّ رَجُلاً، مِنَ الأَنْصَارِ دَبَّرَ مَمْلُوكًا، وَلَمْ يَكُنْ لَهُ مَالٌ غَيْرُهُ، فَبَلَغَ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ مَنْ يَشْتَرِيهِ مِنِّي ‏"‏‏.‏ فَاشْتَرَاهُ نُعَيْمُ بْنُ النَّحَّامِ بِثَمَانِمِائَةِ دِرْهَمٍ‏.‏ قَالَ فَسَمِعْتُ جَابِرًا يَقُولُ عَبْدًا قِبْطِيًّا مَاتَ عَامَ أَوَّلَ‏.‏\hadithno{6947}\hadithtrans{Narrated Jabir:A man from the Ansar made his slave, a Mudabbar. And apart from that slave he did not have any other property. This news reached Allah's Messenger (ﷺ) and he said, "Who will buy that slave from me?" So Nu'aim bin An-Nahham bought him for 800 Dirham. Jabir added: It was a coptic (Egyptian) slave who died that year}}
\hadithdefcmd{bukhari}{6948}{حَدَّثَنَا حُسَيْنُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَسْبَاطُ بْنُ مُحَمَّدٍ، حَدَّثَنَا الشَّيْبَانِيُّ، سُلَيْمَانُ بْنُ فَيْرُوزَ عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ،‏.‏ قَالَ الشَّيْبَانِيُّ وَحَدَّثَنِي عَطَاءٌ أَبُو الْحَسَنِ السُّوَائِيُّ،، وَلاَ أَظُنُّهُ إِلاَّ ذَكَرَهُ عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ يَحِلُّ لَكُمْ أَنْ تَرِثُوا النِّسَاءَ كَرْهًا‏\}‏ الآيَةَ قَالَ كَانُوا إِذَا مَاتَ الرَّجُلُ كَانَ أَوْلِيَاؤُهُ أَحَقَّ بِامْرَأَتِهِ، إِنْ شَاءَ بَعْضُهُمْ تَزَوَّجَهَا، وَإِنْ شَاءُوا زَوَّجَهَا، وَإِنْ شَاءُوا لَمْ يُزَوِّجْهَا، فَهُمْ أَحَقُّ بِهَا مِنْ أَهْلِهَا، فَنَزَلَتْ هَذِهِ الآيَةُ فِي ذَلِكَ‏.‏\hadithno{6948}\hadithtrans{Narrated Ibn `Abbas:Regarding the Qur'anic Verse: 'O you who believe! You are forbidden to inherit women against their will.' (4.19) The custom (in the Pre-Islamic Period) was that if a man died, his relatives used to have the right to inherit his wife, and if one of them wished, he could marry her, or they could marry her to somebody else, or prevent her from marrying if they wished, for they had more right to dispose of her than her own relatives. Therefore this Verse was revealed concerning this matter}}
\hadithdefcmd{bukhari}{6949}{وَقَالَ اللَّيْثُ حَدَّثَنِي نَافِعٌ، أَنَّ صَفِيَّةَ ابْنَةَ أَبِي عُبَيْدٍ، أَخْبَرَتْهُ أَنَّ عَبْدًا مِنْ رَقِيقِ الإِمَارَةِ وَقَعَ عَلَى وَلِيدَةٍ مِنَ الْخُمُسِ، فَاسْتَكْرَهَهَا حَتَّى افْتَضَّهَا، فَجَلَدَهُ عُمَرُ الْحَدَّ وَنَفَاهُ، وَلَمْ يَجْلِدِ الْوَلِيدَةَ مِنْ أَجْلِ أَنَّهُ اسْتَكْرَهَهَا‏.‏ قَالَ الزُّهْرِيُّ فِي الأَمَةِ الْبِكْرِ، يَفْتَرِعُهَا الْحُرُّ، يُقِيمُ ذَلِكَ الْحَكَمُ مِنَ الأَمَةِ الْعَذْرَاءِ بِقَدْرِ قِيمَتِهَا، وَيُجْلَدُ، وَلَيْسَ فِي الأَمَةِ الثَّيِّبِ فِي قَضَاءِ الأَئِمَّةِ غُرْمٌ، وَلَكِنْ عَلَيْهِ الْحَدُّ‏.‏\hadithno{6949}\hadithtrans{And Safiyya bint 'Ubaid said:"A governmental male-slave tried to seduce a slave-girl from the Khumus of the war booty till he deflowered her by force against her will; therefore 'Umar flogged him according to the law, and exiled him, but he did not flog the female slave because the male-slave had committed illegal sexual intercourse by force, against her will." Az-Zuhri said regarding a virgin slave-girl raped by a free man: The judge has to fine the adulterer as much money as is equal to the price of the female slave and the adulterer has to be flogged (according to the Islamic Law); but if the slave woman is a matron, then, according to the verdict of the Imam, the adulterer is not fined but he has to receive the legal punishment (according to the Islamic Law)}}
\hadithdefcmd{bukhari}{6950}{حَدَّثَنَا أَبُو الْيَمَانِ، حَدَّثَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هَاجَرَ إِبْرَاهِيمُ بِسَارَةَ، دَخَلَ بِهَا قَرْيَةً فِيهَا مَلِكٌ مِنَ الْمُلُوكِ أَوْ جَبَّارٌ مِنَ الْجَبَابِرَةِ، فَأَرْسَلَ إِلَيْهِ أَنْ أَرْسِلْ إِلَىَّ بِهَا‏.‏ فَأَرْسَلَ بِهَا، فَقَامَ إِلَيْهَا فَقَامَتْ تَوَضَّأُ وَتُصَلِّي فَقَالَتِ اللَّهُمَّ إِنْ كُنْتُ آمَنْتُ بِكَ وَبِرَسُولِكَ فَلاَ تُسَلِّطْ عَلَىَّ الْكَافِرَ، فَغُطَّ حَتَّى رَكَضَ بِرِجْلِهِ ‏"‏‏.‏\hadithno{6950}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "(The Prophet) Abraham migrated with his wife Sarah till he reached a town where there was a king or a tyrant who sent a message, to Abraham, ordering him to send Sarah to him. So when Abraham had sent Sarah, the tyrant got up, intending to do evil with her, but she got up and performed ablution and prayed and said, 'O Allah ! If I have believed in You and in Your Apostle, then do not empower this oppressor over me.' So he (the king) had an epileptic fit and started moving his legs violently}}
\hadithdefcmd{bukhari}{6951}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرِ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَالِمًا، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُسْلِمُ أَخُو الْمُسْلِمِ، لاَ يَظْلِمُهُ، وَلاَ يُسْلِمُهُ، وَمَنْ كَانَ فِي حَاجَةِ أَخِيهِ، كَانَ اللَّهُ فِي حَاجَتِهِ ‏"‏‏.‏\hadithno{6951}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "A Muslim is a brother of another Muslim. So he should neither oppress him nor hand him over to an oppressor. And whoever fulfilled the needs of his brother, Allah will fulfill his needs}}
\hadithdefcmd{bukhari}{6952}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ أَبِي بَكْرِ بْنِ أَنَسٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ انْصُرْ أَخَاكَ ظَالِمًا أَوْ مَظْلُومًا ‏"‏‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَنْصُرُهُ إِذَا كَانَ مَظْلُومًا، أَفَرَأَيْتَ إِذَا كَانَ ظَالِمًا كَيْفَ أَنْصُرُهُ قَالَ ‏"‏ تَحْجُزُهُ أَوْ تَمْنَعُهُ مِنَ الظُّلْمِ، فَإِنَّ ذَلِكَ نَصْرُهُ ‏"‏‏.‏\hadithno{6952}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) said, "Help your brother whether he is an oppressor or an oppressed," A man said, "O Allah's Messenger (ﷺ)! I will help him if he is oppressed, but if he is an oppressor, how shall I help him?" The Prophet (ﷺ) said, "By preventing him from oppressing (others), for that is how to help him}}
