% Auto-generated chapter 47 for bukhari
% Hadiths in this chapter: 22

\hadithdefcmd{bukhari}{2483}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّهُ قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْثًا قِبَلَ السَّاحِلِ، فَأَمَّرَ عَلَيْهِمْ أَبَا عُبَيْدَةَ بْنَ الْجَرَّاحِ وَهُمْ ثَلاَثُمِائَةٍ وَأَنَا فِيهِمْ، فَخَرَجْنَا حَتَّى إِذَا كُنَّا بِبَعْضِ الطَّرِيقِ فَنِيَ الزَّادُ، فَأَمَرَ أَبُو عُبَيْدَةَ بِأَزْوَادِ ذَلِكَ الْجَيْشِ فَجُمِعَ ذَلِكَ كُلُّهُ فَكَانَ مِزْوَدَىْ تَمْرٍ، فَكَانَ يُقَوِّتُنَا كُلَّ يَوْمٍ قَلِيلاً قَلِيلاً، حَتَّى فَنِيَ فَلَمْ يَكُنْ يُصِيبُنَا إِلاَّ تَمْرَةٌ تَمْرَةٌ‏.‏ فَقُلْتُ وَمَا تُغْنِي تَمْرَةٌ فَقَالَ لَقَدْ وَجَدْنَا فَقْدَهَا حِينَ فَنِيَتْ‏.‏ قَالَ ثُمَّ انْتَهَيْنَا إِلَى الْبَحْرِ فَإِذَا حُوتٌ مِثْلُ الظَّرِبِ، فَأَكَلَ مِنْهُ ذَلِكَ الْجَيْشُ ثَمَانِيَ عَشْرَةَ لَيْلَةً، ثُمَّ أَمَرَ أَبُو عُبَيْدَةَ بِضِلَعَيْنِ مِنْ أَضْلاَعِهِ فَنُصِبَا، ثُمَّ أَمَرَ بِرَاحِلَةٍ فَرُحِلَتْ ثُمَّ مَرَّتْ تَحْتَهُمَا فَلَمْ تُصِبْهُمَا‏.‏\hadithno{2483}\hadithtrans{Narrated Jabir bin `Abdullah:"Allah's Messenger (ﷺ) sent an army towards the east coast and appointed Abu 'Ubaida bin Al-Jarrah as their chief, and the army consisted of three-hundred men including myself. We marched on till we reached a place where our food was about to finish. Abu- 'Ubaida ordered us to collect all the journey food and it was collected. My (our) journey food was dates. Abu 'Ubaida kept on giving us our daily ration in small amounts from it, till it was exhausted. The share of everyone of us used to be one date only." I said, "How could one date benefit you?" Jabir replied, "We came to know its value when even that too finished." Jabir added, "When we reached the sea-shore, we saw a huge fish which was like a small mountain. The army ate from it for eighteen days. Then Abu 'Ubaida ordered that two of its ribs be fixed and they were fixed in the ground. Then he ordered that a she-camel be ridden and it passed under the two ribs (forming an arch) without touching them}}
\hadithdefcmd{bukhari}{2484}{حَدَّثَنَا بِشْرُ بْنُ مَرْحُومٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ ـ رضى الله عنه ـ قَالَ خَفَّتْ أَزْوَادُ الْقَوْمِ وَأَمْلَقُوا، فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم فِي نَحْرِ إِبِلِهِمْ فَأَذِنَ لَهُمْ، فَلَقِيَهُمْ عُمَرُ فَأَخْبَرُوهُ فَقَالَ مَا بَقَاؤُكُمْ بَعْدَ إِبِلِكُمْ، فَدَخَلَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ مَا بَقَاؤُهُمْ بَعْدَ إِبِلِهِمْ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَادِ فِي النَّاسِ فَيَأْتُونَ بِفَضْلِ أَزْوَادِهِمْ ‏"‏‏.‏ فَبُسِطَ لِذَلِكَ نِطَعٌ، وَجَعَلُوهُ عَلَى النِّطَعِ‏.‏ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَدَعَا وَبَرَّكَ عَلَيْهِ ثُمَّ دَعَاهُمْ بِأَوْعِيَتِهِمْ فَاحْتَثَى النَّاسُ حَتَّى فَرَغُوا، ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ ‏"‏‏.‏\hadithno{2484}\hadithtrans{Narrated Salama:Once (on a journey) our provisions diminished and the people were reduced to poverty. They went to the Prophet (ﷺ) and asked his permission to slaughter their camels, and he agreed. `Umar met them and they told him about it, and he said, "How would you survive after slaughtering your camels?" Then he went to the Prophet and said, "O Allah's Messenger (ﷺ)! How would they survive after slaughtering their camels?" Allah's Messenger (ﷺ) ordered `Umar, "Call upon the people to bring what has remained of their food." A leather sheet was spread and all the food was collected and heaped over it. Allah's Messenger (ﷺ) stood up and invoked Allah to bless it, and then directed all the people to come with their utensils, and they started taking from it till all of them got what was sufficient for them. Allah's Messenger (ﷺ) then said, "I testify that None has the right to be worshipped but Allah, and I am His Messenger}}
\hadithdefcmd{bukhari}{2485}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا أَبُو النَّجَاشِيِّ، قَالَ سَمِعْتُ رَافِعَ بْنَ خَدِيجٍ ـ رضى الله عنه ـ قَالَ كُنَّا نُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم الْعَصْرَ فَنَنْحَرُ جَزُورًا، فَتُقْسَمُ عَشْرَ قِسَمٍ، فَنَأْكُلُ لَحْمًا نَضِيجًا قَبْلَ أَنْ تَغْرُبَ الشَّمْسُ‏.‏\hadithno{2485}\hadithtrans{Narrated Rafi` bin Khadij:We used to offer the `Asr prayer with the Prophet (ﷺ) and slaughter a camel, the meat of which would be divided in ten parts. We would eat the cooked meat before sunset}}
\hadithdefcmd{bukhari}{2486}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا حَمَّادُ بْنُ أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ الأَشْعَرِيِّينَ إِذَا أَرْمَلُوا فِي الْغَزْوِ، أَوْ قَلَّ طَعَامُ عِيَالِهِمْ بِالْمَدِينَةِ جَمَعُوا مَا كَانَ عِنْدَهُمْ فِي ثَوْبٍ وَاحِدٍ، ثُمَّ اقْتَسَمُوهُ بَيْنَهُمْ فِي إِنَاءٍ وَاحِدٍ بِالسَّوِيَّةِ، فَهُمْ مِنِّي وَأَنَا مِنْهُمْ ‏"‏‏.‏\hadithno{2486}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "When the people of Ash`ari tribe ran short of food during the holy battles, or the food of their families in Medina ran short, they would collect all their remaining food in one sheet and then distribute it among themselves equally by measuring it with a bowl. So, these people are from me, and I am from them}}
\hadithdefcmd{bukhari}{2487}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُثَنَّى، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي ثُمَامَةُ بْنُ عَبْدِ اللَّهِ بْنِ أَنَسٍ، أَنَّ أَنَسًا، حَدَّثَهُ أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ كَتَبَ لَهُ فَرِيضَةَ الصَّدَقَةِ الَّتِي فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَمَا كَانَ مِنْ خَلِيطَيْنِ فَإِنَّهُمَا يَتَرَاجَعَانِ بَيْنَهُمَا بِالسَّوِيَّةِ ‏"‏‏.‏\hadithno{2487}\hadithtrans{Narrated Anas:that Abu Bakr As-Siddiq wrote to him the law of Zakat which was made obligatory by Allah's Apostle. He wrote: 'Partners possessing joint property (sheep) have to pay its Zakat equally}}
\hadithdefcmd{bukhari}{2488}{حَدَّثَنَا عَلِيُّ بْنُ الْحَكَمِ الأَنْصَارِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ بْنِ رَافِعِ بْنِ خَدِيجٍ، عَنْ جَدِّهِ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم بِذِي الْحُلَيْفَةِ فَأَصَابَ النَّاسَ جُوعٌ فَأَصَابُوا إِبِلاً وَغَنَمًا‏.‏ قَالَ وَكَانَ النَّبِيُّ صلى الله عليه وسلم فِي أُخْرَيَاتِ الْقَوْمِ فَعَجِلُوا وَذَبَحُوا وَنَصَبُوا الْقُدُورَ، فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم بِالْقُدُورِ فَأُكْفِئَتْ، ثُمَّ قَسَمَ فَعَدَلَ عَشْرَةً مِنَ الْغَنَمِ بِبَعِيرٍ فَنَدَّ مِنْهَا بَعِيرٌ، فَطَلَبُوهُ فَأَعْيَاهُمْ، وَكَانَ فِي الْقَوْمِ خَيْلٌ يَسِيرَةٌ فَأَهْوَى رَجُلٌ مِنْهُمْ بِسَهْمٍ فَحَبَسَهُ اللَّهُ ثُمَّ قَالَ ‏"‏ إِنَّ لِهَذِهِ الْبَهَائِمِ أَوَابِدَ كَأَوَابِدِ الْوَحْشِ فَمَا غَلَبَكُمْ مِنْهَا فَاصْنَعُوا بِهِ هَكَذَا ‏"‏‏.‏ فَقَالَ جَدِّي إِنَّا نَرْجُو ـ أَوْ نَخَافُ ـ الْعَدُوَّ غَدًا، وَلَيْسَتْ مَعَنَا مُدًى أَفَنَذْبَحُ بِالْقَصَبِ‏.‏ قَالَ ‏"‏ مَا أَنْهَرَ الدَّمَ وَذُكِرَ اسْمُ اللَّهِ عَلَيْهِ، فَكُلُوهُ، لَيْسَ السِّنَّ وَالظُّفُرَ، وَسَأُحَدِّثُكُمْ عَنْ ذَلِكَ، أَمَّا السِّنُّ فَعَظْمٌ وَأَمَّا الظُّفُرُ فَمُدَى الْحَبَشَةِ ‏"‏‏.‏\hadithno{2488}\hadithtrans{Narrated 'Abaya bin Rifa'a bin Rafi' bin Khadij:My grandfather said, "We were in the company of the Prophet (ﷺ) at Dhul-Hulaifa. The people felt hungry and captured some camels and sheep (as booty). The Prophet (ﷺ) was behind the people. They hurried and slaughtered the animals and put their meat in pots and started cooking it. (When the Prophet came) he ordered the pots to be upset and then he distributed the animals (of the booty), regarding ten sheep as equal to one camel. One of the camels fled and the people ran after it till they were exhausted. At that time there were few horses. A man threw an arrow at the camel, and Allah stopped the camel with it. The Prophet (ﷺ) said, "Some of these animals are like wild animals, so if you lose control over one of these animals, treat it in this way (i.e. shoot it with an arrow)." Before distributing them among the soldiers my grandfather said, "We may meet the enemies in the future and have no knives; can we slaughter the animals with reeds?" The Prophet (ﷺ) said, "Use whatever causes blood to flow, and eat the animals if the name of Allah has been mentioned on slaughtering them. Do not slaughter with teeth or fingernails and I will tell you why: It is because teeth are bones (i.e. cannot cut properly) and fingernails are the tools used by the Ethiopians (whom we should not imitate for they are infidels)}}
\hadithdefcmd{bukhari}{2489}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا جَبَلَةُ بْنُ سُحَيْمٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ يَقُولُ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ يَقْرُنَ الرَّجُلُ بَيْنَ التَّمْرَتَيْنِ جَمِيعًا، حَتَّى يَسْتَأْذِنَ أَصْحَابَهُ‏.‏\hadithno{2489}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) decreed that one should not eat two dates together at a time unless he gets the permission from his companions (sharing the meal with him)}}
\hadithdefcmd{bukhari}{2490}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ جَبَلَةَ، قَالَ كُنَّا بِالْمَدِينَةِ فَأَصَابَتْنَا سَنَةٌ، فَكَانَ ابْنُ الزُّبَيْرِ يَرْزُقُنَا التَّمْرَ، وَكَانَ ابْنُ عُمَرَ يَمُرُّ بِنَا فَيَقُولُ لاَ تَقْرُنُوا فَإِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الإِقْرَانِ، إِلاَّ أَنْ يَسْتَأْذِنَ الرَّجُلُ مِنْكُمْ أَخَاهُ‏.‏\hadithno{2490}\hadithtrans{Narrated Jabala:"While at Medina we were struck with famine. Ibn Az-Zubair used to provide us with dates as our food. Ibn `Umar used to pass by us and say, "Don't eat two dates together at a time as the Prophet (ﷺ) has forbidden eating two dates together at a time (in a gathering) unless one takes the permission of one's companion brother}}
\hadithdefcmd{bukhari}{2491}{حَدَّثَنَا عِمْرَانُ بْنُ مَيْسَرَةَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ شِقْصًا لَهُ مِنْ عَبْدٍ ـ أَوْ شِرْكًا أَوْ قَالَ نَصِيبًا ـ وَكَانَ لَهُ مَا يَبْلُغُ ثَمَنَهُ بِقِيمَةِ الْعَدْلِ، فَهْوَ عَتِيقٌ، وَإِلاَّ فَقَدْ عَتَقَ مِنْهُ مَا عَتَقَ ‏"‏‏.‏ قَالَ لاَ أَدْرِي قَوْلُهُ عَتَقَ مِنْهُ مَا عَتَقَ‏.‏ قَوْلٌ مِنْ نَافِعٍ أَوْ فِي الْحَدِيثِ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{2491}\hadithtrans{Narrated Nafi`:Ibn `Umar said, "Allah's Messenger (ﷺ) said, 'If one manumits his share of a jointly possessed slave, and can afford the price of the other shares according to the adequate price of the slave, the slave will be completely manumitted; otherwise he will be partially manumitted.' " (Aiyub, a sub-narrator is not sure whether the saying " ... otherwise he will be partially manumitted" was said by Nafi` or the Prophet)}}
\hadithdefcmd{bukhari}{2492}{حَدَّثَنَا بِشْرُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ شَقِيصًا مِنْ مَمْلُوكِهِ فَعَلَيْهِ خَلاَصُهُ فِي مَالِهِ، فَإِنْ لَمْ يَكُنْ لَهُ مَالٌ قُوِّمَ الْمَمْلُوكُ، قِيمَةَ عَدْلٍ ثُمَّ اسْتُسْعِيَ غَيْرَ مَشْقُوقٍ عَلَيْهِ ‏"‏‏.‏\hadithno{2492}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever manumits his share of a jointly possessed slave, it is imperative for him to get that slave manumitted completely by paying the remaining price, and if he does not have sufficient money to manumit him, then the price of the slave should be estimated justly, and he is to be allowed to work and earn the amount that will manumit him (without overburdening him)}}
\hadithdefcmd{bukhari}{2493}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا زَكَرِيَّاءُ، قَالَ سَمِعْتُ عَامِرًا، يَقُولُ سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الْقَائِمِ عَلَى حُدُودِ اللَّهِ وَالْوَاقِعِ فِيهَا كَمَثَلِ قَوْمٍ اسْتَهَمُوا عَلَى سَفِينَةٍ، فَأَصَابَ بَعْضُهُمْ أَعْلاَهَا وَبَعْضُهُمْ أَسْفَلَهَا، فَكَانَ الَّذِينَ فِي أَسْفَلِهَا إِذَا اسْتَقَوْا مِنَ الْمَاءِ مَرُّوا عَلَى مَنْ فَوْقَهُمْ فَقَالُوا لَوْ أَنَّا خَرَقْنَا فِي نَصِيبِنَا خَرْقًا، وَلَمْ نُؤْذِ مَنْ فَوْقَنَا‏.‏ فَإِنْ يَتْرُكُوهُمْ وَمَا أَرَادُوا هَلَكُوا جَمِيعًا، وَإِنْ أَخَذُوا عَلَى أَيْدِيهِمْ نَجَوْا وَنَجَوْا جَمِيعًا ‏"‏‏.‏\hadithno{2493}\hadithtrans{Narrated An-Nu`man bin Bashir:The Prophet (ﷺ) said, "The example of the person abiding by Allah's order and restrictions in comparison to those who violate them is like the example of those persons who drew lots for their seats in a boat. Some of them got seats in the upper part, and the others in the lower. When the latter needed water, they had to go up to bring water (and that troubled the others), so they said, 'Let us make a hole in our share of the ship (and get water) saving those who are above us from troubling them. So, if the people in the upper part left the others do what they had suggested, all the people of the ship would be destroyed, but if they prevented them, both parties would be safe}}
\hadithdefcmd{bukhari}{2494}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ الْعَامِرِيُّ الأُوَيْسِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ، أَنَّهُ سَأَلَ عَائِشَةَ ـ رضى الله عنها ـ وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ عَنِ ابْنِ شِهَابٍ قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ أَنَّهُ سَأَلَ عَائِشَةَ ـ رضى الله عنها ـ عَنْ قَوْلِ اللَّهِ تَعَالَى ‏\{‏وَإِنْ خِفْتُمْ‏\}‏ إِلَى ‏\{‏وَرُبَاعَ‏\}‏‏.‏ فَقَالَتْ يَا ابْنَ أُخْتِي هِيَ الْيَتِيمَةُ تَكُونُ فِي حَجْرِ وَلِيِّهَا تُشَارِكُهُ فِي مَالِهِ، فَيُعْجِبُهُ مَالُهَا وَجَمَالُهَا، فَيُرِيدُ وَلِيُّهَا أَنْ يَتَزَوَّجَهَا بِغَيْرِ أَنْ يُقْسِطَ فِي صَدَاقِهَا، فَيُعْطِيهَا مِثْلَ مَا يُعْطِيهَا غَيْرُهُ، فَنُهُوا أَنْ يَنْكِحُوهُنَّ إِلاَّ أَنْ يُقْسِطُوا لَهُنَّ وَيَبْلُغُوا بِهِنَّ أَعْلَى سُنَّتِهِنَّ مِنَ الصَّدَاقِ، وَأُمِرُوا أَنْ يَنْكِحُوا مَا طَابَ لَهُمْ مِنَ النِّسَاءِ سِوَاهُنَّ‏.‏ قَالَ عُرْوَةُ قَالَتْ عَائِشَةُ ثُمَّ إِنَّ النَّاسَ اسْتَفْتَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدَ هَذِهِ الآيَةِ فَأَنْزَلَ اللَّهُ ‏\{‏وَيَسْتَفْتُونَكَ فِي النِّسَاءِ‏\}‏ إِلَى قَوْلِهِ ‏\{‏وَتَرْغَبُونَ أَنْ تَنْكِحُوهُنَّ‏\}‏ وَالَّذِي ذَكَرَ اللَّهُ أَنَّهُ يُتْلَى عَلَيْكُمْ فِي الْكِتَابِ الآيَةُ الأُولَى الَّتِي قَالَ فِيهَا ‏\{‏وَإِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى فَانْكِحُوا مَا طَابَ لَكُمْ مِنَ النِّسَاءِ‏\}‏ قَالَتْ عَائِشَةُ وَقَوْلُ اللَّهِ فِي الآيَةِ الأُخْرَى ‏\{‏وَتَرْغَبُونَ أَنْ تَنْكِحُوهُنَّ‏\}‏ يَعْنِي هِيَ رَغْبَةُ أَحَدِكُمْ لِيَتِيمَتِهِ الَّتِي تَكُونُ فِي حَجْرِهِ، حِينَ تَكُونُ قَلِيلَةَ الْمَالِ وَالْجَمَالِ، فَنُهُوا أَنْ يَنْكِحُوا مَا رَغِبُوا فِي مَالِهَا وَجَمَالِهَا مِنْ يَتَامَى النِّسَاءِ إِلاَّ بِالْقِسْطِ مِنْ، أَجْلِ رَغْبَتِهِمْ عَنْهُنَّ‏.‏\hadithno{2494}\hadithtrans{Narrated `Urwa bin Az-Zubair:That he had asked `Aisha about the meaning of the Statement of Allah: "If you fear that you shall not Be able to deal justly With the orphan girls, then Marry (Other) women of your choice Two or three or four." (4.3) She said, "O my nephew! This is about the orphan girl who lives with her guardian and shares his property. Her wealth and beauty may tempt him to marry her without giving her an adequate Mahr (bridal-money) which might have been given by another suitor. So, such guardians were forbidden to marry such orphan girls unless they treated them justly and gave them the most suitable Mahr; otherwise they were ordered to marry any other woman." `Aisha further said, "After that verse the people again asked the Prophet (about the marriage with orphan 'girls), so Allah revealed the following verses:-- 'They ask your instruction Concerning the women. Say: Allah Instructs you about them And about what is Recited unto you In the Book, concerning The orphan girls to whom You give not the prescribed portions and yet whom you Desire to marry..." (4.127) What is meant by Allah's Saying:-- 'And about what is Recited unto you is the former verse which goes:-- 'If you fear that you shall not Be able to deal justly With the orphan girls, then Marry (other) women of your choice.' (4.3) `Aisha said, "Allah's saying in the other verse:--'Yet whom you desire to marry' (4.127) means the desire of the guardian to marry an orphan girl under his supervision when she has not much property or beauty (in which case he should treat her justly). The guardians were forbidden to marry their orphan girls possessing property and beauty without being just to them, as they generally refrain from marrying them (when they are neither beautiful nor wealthy)}}
\hadithdefcmd{bukhari}{2495}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ إِنَّمَا جَعَلَ النَّبِيُّ صلى الله عليه وسلم الشُّفْعَةَ فِي كُلِّ مَا لَمْ يُقْسَمْ، فَإِذَا وَقَعَتِ الْحُدُودُ وَصُرِّفَتِ الطُّرُقُ فَلاَ شُفْعَةَ‏.‏\hadithno{2495}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) established the right of Shu'fa (i.e. Preemption) in joint properties; but when the land is divided and the ways are demarcated, then there is no pre-emption}}
\hadithdefcmd{bukhari}{2496}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ قَضَى النَّبِيُّ صلى الله عليه وسلم بِالشُّفْعَةِ فِي كُلِّ مَا لَمْ يُقْسَمْ، فَإِذَا وَقَعَتِ الْحُدُودُ وَصُرِّفَتِ الطُّرُقُ فَلاَ شُفْعَةَ‏.‏\hadithno{2496}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) said, "The right of preemption is valid in every joint property, but when the land is divided and the way is demarcated, then there is no right of pre-emption}}
\hadithdefcmd{bukhari}{2498}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ عُثْمَانَ يَعْنِي ابْنَ الأَسْوَدِ، قَالَ أَخْبَرَنِي سُلَيْمَانُ بْنُ أَبِي مُسْلِمٍ، قَالَ سَأَلْتُ أَبَا الْمِنْهَالِ عَنِ الصَّرْفِ، يَدًا بِيَدٍ فَقَالَ اشْتَرَيْتُ أَنَا وَشَرِيكٌ، لِي شَيْئًا يَدًا بِيَدٍ وَنَسِيئَةً، فَجَاءَنَا الْبَرَاءُ بْنُ عَازِبٍ فَسَأَلْنَاهُ، فَقَالَ فَعَلْتُ أَنَا وَشَرِيكِي زَيْدُ بْنُ أَرْقَمَ، وَسَأَلْنَا النَّبِيَّ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ مَا كَانَ يَدًا بِيَدٍ فَخُذُوهُ، وَمَا كَانَ نَسِيئَةً فَذَرُوهُ ‏"‏‏.‏\hadithno{2498}\hadithtrans{Narrated Sulaiman bin Abu Muslim:I asked Abu Minhal about money exchange from hand to hand. He said, "I and a partner of mine bought something partly in cash and partly on credit." Al-Bara' bin `Azib passed by us and we asked about it. He replied, "I and my partner Zaid bin Al-Arqam did the same and then went to the Prophet (ﷺ) and asked him about it. He said, 'Take what was from hand to hand and leave what was on credit}}
\hadithdefcmd{bukhari}{2499}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جُوَيْرِيَةُ بْنُ أَسْمَاءَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ أَعْطَى رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْبَرَ الْيَهُودَ أَنْ يَعْمَلُوهَا وَيَزْرَعُوهَا وَلَهُمْ شَطْرُ مَا يَخْرُجُ مِنْهَا‏.‏\hadithno{2499}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) rented the land of Khaibar to the Jews on the condition that they would work on it and cultivate it and take half of its yield}}
\hadithdefcmd{bukhari}{2500}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْطَاهُ غَنَمًا يَقْسِمُهَا عَلَى صَحَابَتِهِ ضَحَايَا، فَبَقِيَ عَتُودٌ فَذَكَرَهُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ ضَحِّ بِهِ أَنْتَ ‏"‏‏.‏\hadithno{2500}\hadithtrans{Narrated `Uqba bin 'Amir:that Allah's Messenger (ﷺ) gave him some sheep to distribute among his companions in order to sacrifice them and a kid was left. He told the Prophet (ﷺ) about it and the Prophet (ﷺ) said to him, "Sacrifice it on your behalf}}
\hadithdefcmd{bukhari}{2502}{حَدَّثَنَا أَصْبَغُ بْنُ الْفَرَجِ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي سَعِيدٌ، عَنْ زُهْرَةَ بْنِ مَعْبَدٍ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ هِشَامٍ ـ وَكَانَ قَدْ أَدْرَكَ النَّبِيَّ صلى الله عليه وسلم ـ وَذَهَبَتْ بِهِ أُمُّهُ زَيْنَبُ بِنْتُ حُمَيْدٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ بَايِعْهُ‏.‏ فَقَالَ ‏ "‏ هُوَ صَغِيرٌ ‏"‏‏.‏ فَمَسَحَ رَأْسَهُ وَدَعَا لَهُ‏.‏ وَعَنْ زُهْرَةَ بْنِ مَعْبَدٍ، أَنَّهُ كَانَ يَخْرُجُ بِهِ جَدُّهُ عَبْدُ اللَّهِ بْنُ هِشَامٍ إِلَى السُّوقِ فَيَشْتَرِي الطَّعَامَ فَيَلْقَاهُ ابْنُ عُمَرَ وَابْنُ الزُّبَيْرِ ـ رضى الله عنهم ـ فَيَقُولاَنِ لَهُ أَشْرِكْنَا، فَإِنَّ النَّبِيَّ صلى الله عليه وسلم قَدْ دَعَا لَكَ بِالْبَرَكَةِ فَيَشْرَكُهُمْ، فَرُبَّمَا أَصَابَ الرَّاحِلَةَ كَمَا هِيَ، فَيَبْعَثُ بِهَا إِلَى الْمَنْزِلِ‏.‏\hadithno{2502}\hadithtrans{Narrated `Abdullah bin Hisham:that his mother Zainab bint Humaid took him to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! Take the pledge of allegiance from him." But he said, "He is still too young for the pledge," and passed his hand on his (i.e. `Abdullah's) head and invoked for Allah's blessing for him. Zuhra bin Ma`bad stated that he used to go with his grandfather, `Abdullah bin Hisham, to the market to buy foodstuff. Ibn `Umar and Ibn Az-Zubair would meet him and say to him, "Be our partner, as the Prophet (ﷺ) invoked Allah to bless you." So, he would be their partner, and very often he would win a camel's load and send it home}}
\hadithdefcmd{bukhari}{2503}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا جُوَيْرِيَةُ بْنُ أَسْمَاءَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ شِرْكًا لَهُ فِي مَمْلُوكٍ وَجَبَ عَلَيْهِ أَنْ يُعْتِقَ كُلَّهُ، إِنْ كَانَ لَهُ مَالٌ قَدْرَ ثَمَنِهِ يُقَامُ قِيمَةَ عَدْلٍ وَيُعْطَى شُرَكَاؤُهُ حِصَّتَهُمْ وَيُخَلَّى سَبِيلُ الْمُعْتَقِ ‏"‏‏.‏\hadithno{2503}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "Whoever manumits his share of a jointly possessed slave, it is imperative on him to manumit the slave completely if he has sufficient money to pay the rest of its price which is to be estimated justly. He should pay his partners their shares and release him (the freed one)}}
\hadithdefcmd{bukhari}{2504}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ شِقْصًا لَهُ فِي عَبْدٍ، أُعْتِقَ كُلُّهُ إِنْ كَانَ لَهُ مَالٌ، وَإِلاَّ يُسْتَسْعَ غَيْرَ مَشْقُوقٍ عَلَيْهِ ‏"‏‏.‏\hadithno{2504}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever manumits his share of a jointly possessed slave, it is essential for him to manumit the slave completely if he has sufficient money. Otherwise he should look for some work for the slave (to earn what would enable him to emancipate himself), without overburdening him with work}}
\hadithdefcmd{bukhari}{2506}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، أَخْبَرَنَا عَبْدُ الْمَلِكِ بْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ‏.‏وَعَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهم ـ قَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم صُبْحَ رَابِعَةٍ مِنْ ذِي الْحَجَّةِ مُهِلِّينَ بِالْحَجِّ، لاَ يَخْلِطُهُمْ شَىْءٌ، فَلَمَّا قَدِمْنَا أَمَرَنَا فَجَعَلْنَاهَا عُمْرَةً، وَأَنْ نَحِلَّ إِلَى نِسَائِنَا، فَفَشَتْ فِي ذَلِكَ الْقَالَةُ‏.‏ قَالَ عَطَاءٌ فَقَالَ جَابِرٌ فَيَرُوحُ أَحَدُنَا إِلَى مِنًى وَذَكَرُهُ يَقْطُرُ مَنِيًّا‏.‏ فَقَالَ جَابِرٌ بِكَفِّهِ، فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم فَقَامَ خَطِيبًا فَقَالَ ‏"‏ بَلَغَنِي أَنَّ أَقْوَامًا يَقُولُونَ كَذَا وَكَذَا، وَاللَّهِ لأَنَا أَبَرُّ وَأَتْقَى لِلَّهِ مِنْهُمْ، وَلَوْ أَنِّي اسْتَقْبَلْتُ مِنْ أَمْرِي مَا اسْتَدْبَرْتُ مَا أَهْدَيْتُ، وَلَوْلاَ أَنَّ مَعِي الْهَدْىَ لأَحْلَلْتُ ‏"‏‏.‏ فَقَامَ سُرَاقَةُ بْنُ مَالِكِ بْنِ جُعْشُمٍ فَقَالَ يَا رَسُولَ اللَّهِ هِيَ لَنَا أَوْ لِلأَبَدِ فَقَالَ ‏"‏ لاَ بَلْ لِلأَبَدِ ‏"‏‏.‏ قَالَ وَجَاءَ عَلِيُّ بْنُ أَبِي طَالِبٍ ـ فَقَالَ أَحَدُهُمَا يَقُولُ لَبَّيْكَ بِمَا أَهَلَّ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم‏.‏ وَقَالَ وَقَالَ الآخَرُ لَبَّيْكَ بِحَجَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ـ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يُقِيمَ عَلَى إِحْرَامِهِ، وَأَشْرَكَهُ فِي الْهَدْىِ‏.‏\hadithno{2506}\hadithtrans{Narrated Ibn `Abbas:The Prophet (along with his companions) reached Mecca in the morning of the fourth of Dhul-Hijja assuming Ihram for Hajj only. So when we arrived at Mecca, the Prophet (ﷺ) ordered us to change our intentions of the Ihram for `Umra and that we could finish our Ihram after performing the `Umra and could go to our wives (for sexual intercourse). The people began talking about that. Jabir said surprisingly, "Shall we go to Mina while semen is dribbling from our male organs?" Jabir moved his hand while saying so. When this news reached the Prophet (ﷺ) he delivered a sermon and said, "I have been informed that some peoples were saying so and so; By Allah I fear Allah more than you do, and am more obedient to Him than you. If I had known what I know now, I would not have brought the Hadi (sacrifice) with me and had the Hadi not been with me, I would have finished the Ihram." At that Suraqa bin Malik stood up and asked "O Allah's Messenger (ﷺ)! Is this permission for us only or is it forever?" The Prophet (ﷺ) replied, "It is forever." In the meantime `Ali bin Abu Talib came from Yemen and was saying Labbaik for what the Prophet (ﷺ) has intended. (According to another man, `Ali was saying Labbaik for Hajj similar to Allah's Messenger (ﷺ)). The Prophet (ﷺ) told him to keep on the Ihram and let him share the Hadi with him}}
\hadithdefcmd{bukhari}{2507}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِيهِ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ جَدِّهِ، رَافِعِ بْنِ خَدِيجٍ ـ رضى الله عنه ـ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم بِذِي الْحُلَيْفَةِ مِنْ تِهَامَةَ، فَأَصَبْنَا غَنَمًا وَإِبِلاً، فَعَجِلَ الْقَوْمُ، فَأَغْلَوْا بِهَا الْقُدُورَ، فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَمَرَ بِهَا فَأُكْفِئَتْ، ثُمَّ عَدَلَ عَشْرًا مِنَ الْغَنَمِ بِجَزُورٍ، ثُمَّ إِنَّ بَعِيرًا نَدَّ وَلَيْسَ فِي الْقَوْمِ إِلاَّ خَيْلٌ يَسِيرَةٌ فَرَمَاهُ رَجُلٌ فَحَبَسَهُ بِسَهْمٍ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ لِهَذِهِ الْبَهَائِمِ أَوَابِدَ كَأَوَابِدِ الْوَحْشِ، فَمَا غَلَبَكُمْ مِنْهَا فَاصْنَعُوا بِهِ هَكَذَا ‏"‏‏.‏ قَالَ قَالَ جَدِّي يَا رَسُولَ اللَّهِ إِنَّا نَرْجُو ـ أَوْ نَخَافُ ـ أَنْ نَلْقَى الْعَدُوَّ غَدًا وَلَيْسَ مَعَنَا مُدًى، فَنَذْبَحُ بِالْقَصَبِ فَقَالَ ‏"‏ اعْجَلْ أَوْ أَرْنِي، مَا أَنْهَرَ الدَّمَ وَذُكِرَ اسْمُ اللَّهِ عَلَيْهِ فَكُلُوا، لَيْسَ السِّنَّ وَالظُّفُرَ، وَسَأُحَدِّثُكُمْ عَنْ ذَلِكَ، أَمَّا السِّنُّ فَعَظْمٌ، وَأَمَّا الظُّفُرُ فَمُدَى الْحَبَشَةِ ‏"‏‏.‏\hadithno{2507}\hadithtrans{Narrated Abaya bin Rifaa:My grandfather, Rafi` bin Khadij said, "We were in the valley of Dhul-Hulaifa of Tihama in the company of the Prophet (ﷺ) and had some camels and sheep (of the booty). The people hurried (in slaughtering the animals) and put their meat in the pots and started cooking. Allah's Messenger (ﷺ) came and ordered them to upset the pots, and distributed the booty considering one camel as equal to ten sheep. One of the camels fled and the people had only a few horses, so they got worried. (The camel was chased and) a man stopped the camel by throwing an arrow at it. Allah's Messenger (ﷺ) said, 'Some of these animals are untamed like wild animals, so if anyone of them went out of your control, then you should treat it as you have done now.' " My grandfather said, "O Allah's Messenger (ﷺ)! We fear that we may meet our enemy tomorrow and we have no knives, could we slaughter the animals with reeds?" The Prophet (ﷺ) said, "Yes, or you can use what would make blood flow (slaughter) and you can eat what is slaughtered and the Name of Allah is mentioned at the time of slaughtering. But don't use teeth or fingernails (in slaughtering). I will tell you why, as for teeth, they are bones, and fingernails are used by Ethiopians for slaughtering. (See Hadith)}}
