% Auto-generated chapter 28 for ibnmajah
% Hadiths in this chapter: 51

\hadithdefcmd{ibnmajah}{3200}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ مُطَرِّفًا، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَمَرَ بِقَتْلِ الْكِلاَبِ ثُمَّ قَالَ ‏ "‏ مَا لَهُمْ وَلِلْكِلاَبِ ‏"‏ ‏.‏ ثُمَّ رَخَّصَ لَهُمْ فِي كَلْبِ الصَّيْدِ ‏.‏\hadithno{3200}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah bin Mughaffal that the Messenger of Allah (ﷺ) commanded that dogs be killed, then he said:“What do they use dogs for?” Then he permitted them to keep hunting dogs}}
\hadithdefcmd{ibnmajah}{3201}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ مُطَرِّفًا، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَمَرَ بِقَتْلِ الْكِلاَبِ ثُمَّ قَالَ ‏ "‏ مَا لَهُمْ وَلِلْكِلاَبِ ‏"‏ ‏.‏ ثُمَّ رَخَّصَ لَهُمْ فِي كَلْبِ الزَّرْعِ وَكَلْبِ الْعِينِ ‏.‏ قَالَ بُنْدَارٌ الْعِينُ حِيطَانُ الْمَدِينَةِ ‏.‏\hadithno{3201}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah bin Mughaffal that the Messenger of Allah (ﷺ) commanded that dogs be killed, then he said:“What do they use dogs for?” Then he permitted them to keep farming dogs and dogs of ‘Ein. Bundar said: “The ‘Ein refers to the walls of Al-Madinah.”}}
\hadithdefcmd{ibnmajah}{3202}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، أَنْبَأَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ أَمَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِقَتْلِ الْكِلاَبِ ‏.‏\hadithno{3202}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) commanded that dogs be killed.”}}
\hadithdefcmd{ibnmajah}{3203}{حَدَّثَنَا أَبُو طَاهِرٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَافِعًا صَوْتَهُ يَأْمُرُ بِقَتْلِ الْكِلاَبِ وَكَانَتِ الْكِلاَبُ تُقْتَلُ إِلاَّ كَلْبَ صَيْدٍ أَوْ مَاشِيَةٍ ‏.‏\hadithno{3203}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Salim that his father said:“I heard the Messenger of Allah (ﷺ) raising his voice and commanding that dogs be killed, and dogs were killed, except for hunting dogs or dogs kept for herding livestock.”}}
\hadithdefcmd{ibnmajah}{3204}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنِ اقْتَنَى كَلْبًا فَإِنَّهُ يَنْقُصُ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطٌ إِلاَّ كَلْبَ حَرْثٍ أَوْ مَاشِيَةٍ ‏"‏ ‏.‏\hadithno{3204}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘Whoever keeps a dog, one Qirat will be deducted from him (good) deeds every day, except a dog for farming or herding livestock.”}}
\hadithdefcmd{ibnmajah}{3205}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِي شِهَابٍ، حَدَّثَنِي يُونُسُ بْنُ عُبَيْدٍ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَوْلاَ أَنَّ الْكِلاَبَ أُمَّةٌ مِنَ الأُمَمِ لأَمَرْتُ بِقَتْلِهَا فَاقْتُلُوا مِنْهَا الأَسْوَدَ الْبَهِيمَ وَمَا مِنْ قَوْمٍ اتَّخَذُوا كَلْبًا إِلاَّ كَلْبَ مَاشِيَةٍ أَوْ كَلْبَ صَيْدٍ أَوْ كَلْبَ حَرْثٍ إِلاَّ نَقَصَ مِنْ أُجُورِهِمْ كُلَّ يَوْمٍ قِيرَاطَانِ ‏"‏ ‏.‏\hadithno{3205}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah bin Mughaffal that the Messenger of Allah (ﷺ) said:“Were it not that dogs form one of the communities (or nations – of creatures), I would have commanded that they be killed. But kill those that are all black. There are no people who keep a dog, except for dogs used for herding livestock, hunting or farming, but two Qirat will be deducted from their reward each day.”}}
\hadithdefcmd{ibnmajah}{3206}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، عَنِ السَّائِبِ بْنِ يَزِيدَ، عَنْ سُفْيَانَ بْنِ أَبِي زُهَيْرٍ، قَالَ سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنِ اقْتَنَى كَلْبًا لاَ يُغْنِي عَنْهُ زَرْعًا وَلاَ ضَرْعًا نَقَصَ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطٌ ‏"‏ ‏.‏ فَقِيلَ لَهُ أَنْتَ سَمِعْتَ مِنَ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ إِي وَرَبِّ هَذَا الْمَسْجِدِ ‏.‏\hadithno{3206}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Sufyan bin Abu Zuhair said:“I heard the Prophet (ﷺ) say: ‘Whoever keeps a dog that he does not need for farming or herding, one Qirat will be deducted from his (good) deeds each day.’”}}
\hadithdefcmd{ibnmajah}{3207}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، حَدَّثَنِي رَبِيعَةُ بْنُ يَزِيدَ، أَخْبَرَنِي أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّا بِأَرْضِ أَهْلِ كِتَابٍ نَأْكُلُ فِي آنِيَتِهِمْ وَبِأَرْضِ صَيْدٍ أَصِيدُ بِقَوْسِي وَأَصِيدُ بِكَلْبِيَ الْمُعَلَّمِ وَأَصِيدُ بِكَلْبِيَ الَّذِي لَيْسَ بِمُعَلَّمٍ ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَمَّا مَا ذَكَرْتَ أَنَّكُمْ فِي أَرْضِ أَهْلِ كِتَابٍ فَلاَ تَأْكُلُوا فِي آنِيَتِهِمْ إِلاَّ أَنْ لاَ تَجِدُوا مِنْهَا بُدًّا فَإِنْ لَمْ تَجِدُوا مِنْهَا بُدًّا فَاغْسِلُوهَا وَكُلُوا فِيهَا وَأَمَّا مَا ذَكَرْتَ مِنْ أَمْرِ الصَّيْدِ فَمَا أَصَبْتَ بِقَوْسِكَ فَاذْكُرِ اسْمَ اللَّهِ وَكُلْ وَمَا صِدْتَ بِكَلْبِكَ الْمُعَلَّمِ فَاذْكُرِ اسْمَ اللَّهِ وَكُلْ وَمَا صِدْتَ بِكَلْبِكَ الَّذِي لَيْسَ بِمُعَلَّمٍ فَأَدْرَكْتَ ذَكَاتَهُ فَكُلْ ‏"‏ ‏.‏\hadithno{3207}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Tha’labah Al-Khushani said:“I came to the Messenger of Allah (ﷺ) and said: ‘O Messenger of Allah, we live in a land of the People of the Book and we eat from their vessels. And we live in a land (where there is) game, so I hunt with my bow and with my trained dog and with my untrained dog.’ The Messenger of Allah (ﷺ) said: ‘As for what you say about living in a land of the People of the Book, do not eat from their vessels unless you can find no alternative. If you can fidn no alternative then wash them and eat from them. With regard to what you say about hunting, whatever you catch with your bow, say the Name of Allah over it and eat. Whatever you catch with your trained dog, say the Name of Allah over it and eat. But whatever you catch with your untrained dog, then catch it, slaughter it, then eat.’”}}
\hadithdefcmd{ibnmajah}{3208}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا بَيَانُ بْنُ بِشْرٍ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقُلْتُ إِنَّا قَوْمٌ نَصِيدُ بِهَذِهِ الْكِلاَبِ ‏.‏ قَالَ ‏ "‏ إِذَا أَرْسَلْتَ كِلاَبَكَ الْمُعَلَّمَةَ وَذَكَرْتَ اسْمَ اللَّهِ عَلَيْهَا فَكُلْ مَا أَمْسَكْنَ عَلَيْكَ وَإِنْ قَتَلْنَ إِلاَّ أَنْ يَأْكُلَ الْكَلْبُ فَإِنْ أَكَلَ الْكَلْبُ فَلاَ تَأْكُلْ فَإِنِّي أَخَافُ أَنْ يَكُونَ إِنَّمَا أَمْسَكَ عَلَى نَفْسِهِ وَإِنْ خَالَطَهَا كِلاَبٌ أُخَرُ فَلاَ تَأْكُلْ ‏"‏ ‏.‏ قَالَ ابْنُ مَاجَهْ سَمِعْتُهُ - يَعْنِي عَلِيَّ بْنَ الْمُنْذِرِ - يَقُولُ حَجَجْتُ ثَمَانِيَةً وَخَمْسِينَ حِجَّةً أَكْثَرُهَا رَاجِلٌ ‏.‏\hadithno{3208}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Adi bin Hatim said:“I asked the Messenger of Allah (ﷺ): ‘We are people who hunt with these dogs.’ He said: ‘If you send out your trained dogs and mention the Name of Allah over them, then eat whatever they catch even if they kill it, unless the dog has eaten any of it. If the dog has eaten any of it then do not eat it, for I fear that it will have caught it for itself. And if another dog joins it, then do not eat it.’”}}
\hadithdefcmd{ibnmajah}{3209}{حَدَّثَنَا عَمْرُو بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا وَكِيعٌ، عَنْ شَرِيكٍ، عَنْ حَجَّاجِ بْنِ أَرْطَاةَ، عَنِ الْقَاسِمِ بْنِ أَبِي بَزَّةَ، عَنْ سُلَيْمَانَ الْيَشْكُرِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نُهِينَا عَنْ صَيْدِ، كَلْبِهِمْ وَطَائِرِهِمْ يَعْنِي الْمَجُوسَ ‏.‏\hadithno{3209}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“We were forbidden (to eat) the game caught by their dogs and birds – meaning the Zoroastrians.”}}
\hadithdefcmd{ibnmajah}{3210}{حَدَّثَنَا عَمْرُو بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا وَكِيعٌ، عَنْ سُلَيْمَانَ بْنِ الْمُغِيرَةِ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْكَلْبِ الأَسْوَدِ الْبَهِيمِ فَقَالَ ‏ "‏ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{3210}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Dharr said:“I asked the Messenger of Allah (ﷺ) about the all-black dog and he said: ‘(It is) a devil.’”}}
\hadithdefcmd{ibnmajah}{3211}{حَدَّثَنَا أَبُو عُمَيْرٍ، عِيسَى بْنُ مُحَمَّدٍ النَّحَّاسُ وَعِيسَى بْنُ يُونُسَ الرَّمْلِيُّ قَالاَ حَدَّثَنَا ضَمْرَةُ بْنُ رَبِيعَةَ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كُلْ مَا رَدَّتْ عَلَيْكَ قَوْسُكَ ‏"‏ ‏.‏\hadithno{3211}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Tha’labah that the Prophet (ﷺ) said:“Eat what your bow brings you.”}}
\hadithdefcmd{ibnmajah}{3212}{حَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا مُجَالِدُ بْنُ سَعِيدٍ، عَنْ عَامِرٍ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا قَوْمٌ نَرْمِي ‏.‏ قَالَ ‏ "‏ إِذَا رَمَيْتَ وَخَزَقْتَ فَكُلْ مَا خَزَقْتَ ‏"‏ ‏.‏\hadithno{3212}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Adi bin Hatim said:“I said: ‘O Messenger of Allah, we are people who shoot (arrows).’ He said: ‘If you shoot and pierce (the game), then eat what you pierced.’”}}
\hadithdefcmd{ibnmajah}{3213}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَرْمِي الصَّيْدَ فَيَغِيبُ عَنِّي لَيْلَةً قَالَ ‏ "‏ إِذَا وَجَدْتَ فِيهِ سَهْمَكَ وَلَمْ تَجِدْ فِيهِ شَيْئًا غَيْرَهُ فَكُلْهُ ‏"‏ ‏.‏\hadithno{3213}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Adi bin Hatim said:“I said: ‘O Messenger of Allah, what if I shoot the game but it vanishes at night?’ He said: ‘If you find your arrow in it and you do not find anything else, then eat it.’”}}
\hadithdefcmd{ibnmajah}{3214}{حَدَّثَنَا عَمْرُو بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، قَالاَ حَدَّثَنَا زَكَرِيَّا بْنُ أَبِي زَائِدَةَ، عَنْ عَامِرٍ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الصَّيْدِ بِالْمِعْرَاضِ ‏.‏ قَالَ ‏ "‏ مَا أَصَبْتَ بِحَدِّهِ فَكُلْ وَمَا أَصَبْتَ بِعَرْضِهِ فَهُوَ وَقِيذٌ ‏"‏ ‏.‏\hadithno{3214}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Adi bin Hatim said:“I asked the Messenger of Allah (ﷺ) about hunting with Mi’rad. He said: ‘Whatever it struck with its sharp edge, then eat it, but what is struck with its side is something that has been killed by a violent blow.’”}}
\hadithdefcmd{ibnmajah}{3215}{حَدَّثَنَا عَمْرُو بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا وَكِيعٌ، عَنْ أَبِيهِ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامِ بْنِ الْحَارِثِ النَّخَعِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْمِعْرَاضِ فَقَالَ ‏ "‏ لاَ تَأْكُلْ إِلاَّ أَنْ يَخْزِقَ ‏"‏ ‏.‏\hadithno{3215}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Adi bit Hatim said:“I asked the Messenger of Allah (ﷺ) about Mi’rad. He said: ‘Do not eat unless you pierce (the game).’”}}
\hadithdefcmd{ibnmajah}{3216}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، عَنْ هِشَامِ بْنِ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا قُطِعَ مِنَ الْبَهِيمَةِ وَهِيَ حَيَّةٌ فَمَا قُطِعَ مِنْهَا فَهُوَ مَيْتَةٌ ‏"‏ ‏.‏\hadithno{3216}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) said:“Whatever is cut from an animal hen it is still alive, what is cut from it is Maitah (dead meat).”}}
\hadithdefcmd{ibnmajah}{3217}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا أَبُو بَكْرٍ الْهُذَلِيُّ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ تَمِيمٍ الدَّارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَكُونُ فِي آخِرِ الزَّمَانِ قَوْمٌ يَجُبُّونَ أَسْنِمَةَ الإِبِلِ وَيَقْطَعُونَ أَذْنَابَ الْغَنَمِ أَلاَ فَمَا قُطِعَ مِنْ حَىٍّ فَهُوَ مَيِّتٌ ‏"‏ ‏.‏\hadithno{3217}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Tamim Dari said:“The Messenger of Allah (ﷺ) said: ‘At the end of time there will be people who will cut off camels’ humps and sheep’s tails. But what is cut from a living animal is dead.’”}}
\hadithdefcmd{ibnmajah}{3218}{حَدَّثَنَا أَبُو مُصْعَبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أُحِلَّتْ لَنَا مَيْتَتَانِ الْحُوتُ وَالْجَرَادُ ‏"‏ ‏.‏\hadithno{3218}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah bin ‘Umar that the Messenger of Allah (ﷺ) said:“Two kinds of dead meat have been permitted to us: fish and locusts.”}}
\hadithdefcmd{ibnmajah}{3219}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ وَنَصْرُ بْنُ عَلِيٍّ قَالاَ حَدَّثَنَا زَكَرِيَّا بْنُ يَحْيَى بْنِ عُمَارَةَ، حَدَّثَنَا أَبُو الْعَوَّامِ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ سَلْمَانَ، قَالَ سُئِلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْجَرَادِ فَقَالَ ‏ "‏ أَكْثَرُ جُنُودِ اللَّهِ لاَ آكُلُهُ وَلاَ أُحَرِّمُهُ ‏"‏ ‏.‏\hadithno{3219}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Salman said:“The Messenger of Allah (ﷺ) was asked about locusts. He said: ‘(They are) the most numerous troop of Allah. I neither eat them nor forbid them.’”}}
\hadithdefcmd{ibnmajah}{3220}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي سَعْدٍ الْبَقَّالِ، سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كُنَّ أَزْوَاجُ النَّبِيِّ ـ صلى الله عليه وسلم ـ يَتَهَادَيْنَ الْجَرَادَ عَلَى الأَطْبَاقِ ‏.‏\hadithno{3220}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu (Sa’eed) Baqqal heard Anas bin Malik say:“The wives of the Prophet (ﷺ) used to give each other gifts of locusts on trays.”}}
\hadithdefcmd{ibnmajah}{3221}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ الْحَمَّالُ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا زِيَادُ بْنُ عَبْدِ اللَّهِ بْنِ عُلاَثَةَ، عَنْ مُوسَى بْنِ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، وَأَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ إِذَا دَعَا عَلَى الْجَرَادِ قَالَ ‏"‏ اللَّهُمَّ أَهْلِكْ كِبَارَهُ وَاقْتُلْ صِغَارَهُ وَأَفْسِدْ بَيْضَهُ وَاقْطَعْ دَابِرَهُ وَخُذْ بِأَفْوَاهِهَا عَنْ مَعَايِشِنَا وَأَرْزَاقِنَا إِنَّكَ سَمِيعُ الدُّعَاءِ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ كَيْفَ تَدْعُو عَلَى جُنْدٍ مِنْ أَجْنَادِ اللَّهِ بِقَطْعِ دَابِرِهِ قَالَ ‏"‏ إِنَّ الْجَرَادَ نَثْرَةُ الْحُوتِ فِي الْبَحْرِ ‏"‏ ‏.‏ قَالَ هَاشِمٌ قَالَ زِيَادٌ فَحَدَّثَنِي مَنْ رَأَى الْحُوتَ يَنْثُرُهُ ‏.‏\hadithno{3221}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir and Anas bin Malik that whenever the Messenger of Allah (ﷺ) supplicated against the locusts, he said:“O Allah, destroy their large ones and kill their small ones, spoil their eggs and root them out. Take their mouths away from our livelihood and provision, for You are the One Who hears the prayers.” A man said: “O Messenger of Allah, are you praying against one of the troops of Allah, that they may be rooted out?” He said: “Locusts were sneezed out by the fish in the sea.”}}
\hadithdefcmd{ibnmajah}{3222}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَبِي الْمُهَزِّمِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ خَرَجْنَا مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي حَجَّةٍ أَوْ عُمْرَةٍ فَاسْتَقْبَلَنَا رِجْلٌ مِنْ جَرَادٍ أَوْ ضَرْبٌ مِنْ جَرَادٍ فَجَعَلْنَا نَضْرِبُهُنَّ بِأَسْوَاطِنَا وَنِعَالِنَا فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ كُلُوهُ فَإِنَّهُ مِنْ صَيْدِ الْبَحْرِ ‏"‏ ‏.‏\hadithno{3222}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“We went out with the Prophet (ﷺ) for Hajj or ‘Umrah, and we encountered a swarm of locusts or a type of locust. We started hitting them with out whips and sandals. The Prophet (ﷺ) said: ‘Eat them for they are the game of the sea.’”}}
\hadithdefcmd{ibnmajah}{3223}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَعَبْدُ الرَّحْمَنِ بْنُ عَبْدِ الْوَهَّابِ، قَالاَ حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْفَضْلِ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ قَتْلِ الصُّرَدِ وَالضِّفْدَعِ وَالنَّمْلَةِ وَالْهُدْهُدِ ‏.‏\hadithno{3223}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) forbade killing shrikes*, frogs, ants and hoopoes.”}}
\hadithdefcmd{ibnmajah}{3224}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ قَتْلِ أَرْبَعٍ مِنَ الدَّوَابِّ النَّمْلَةِ وَالنَّحْلِ وَالْهُدْهُدِ وَالصُّرَدِ ‏.‏\hadithno{3224}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) forbade killing four kinds of animals: Ants, bees, hoopoes and shrikes.”}}
\hadithdefcmd{ibnmajah}{3225}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، وَأَحْمَدُ بْنُ عِيسَى الْمِصْرِيَّانِ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ، عَنْ نَبِيِّ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ نَبِيًّا مِنَ الأَنْبِيَاءِ قَرَصَتْهُ نَمْلَةٌ فَأَمَرَ بِقَرْيَةِ النَّمْلِ فَأُحْرِقَتْ فَأَوْحَى اللَّهُ عَزَّ وَجَلَّ إِلَيْهِ فِي أَنْ قَرَصَتْكَ نَمْلَةٌ أَهْلَكْتَ أُمَّةً مِنَ الأُمَمِ تُسَبِّحُ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو صَالِحٍ، حَدَّثَنِي اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، بِإِسْنَادِهِ نَحْوَهُ وَقَالَ قَرَصَتْ ‏.‏\hadithno{3225}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet of Allah (ﷺ) said:“One of the Prophets was bitten by an ant, so he ordered that the ant colony be burned. Then Allah revealed to him: ‘Because one ant bit you, you destroy one of the nations that glorify Allah?’” Another chain reports a similar hadith}}
\hadithdefcmd{ibnmajah}{3226}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، أَنَّ قَرِيبًا، لِعَبْدِ اللَّهِ بْنِ مُغَفَّلٍ خَذَفَ فَنَهَاهُ وَقَالَ إِنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى عَنِ الْخَذْفِ وَقَالَ ‏ "‏ إِنَّهَا لاَ تَصِيدُ صَيْدًا وَلاَ تَنْكَأُ عَدُوًّا وَلَكِنَّهَا تَكْسِرُ السِّنَّ وَتَفْقَأُ الْعَيْنَ ‏"‏ ‏.‏ قَالَ فَعَادَ ‏.‏ فَقَالَ أُحَدِّثُكَ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى عَنْهُ ثُمَّ عُدْتَ لاَ أُكَلِّمُكَ أَبَدًا ‏.‏\hadithno{3226}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Sa’eed bin Jubair that a relative of ‘Abdullah bin Mughaffal threw some small pebbles. He told him not to do that and said:“The Prophet (ﷺ) forbade throwing small pebbles and said: ‘They do not kill any game nor hurt the enemy, but they can break a tooth or put out an eye.’” He did it again, and he (‘Abdullah) said: “I tell you that the Prophet (ﷺ) forbade that and then you go and do it again? I will never speak to you again.”}}
\hadithdefcmd{ibnmajah}{3227}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ بْنُ سَعِيدٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ عُقْبَةَ بْنِ صُهْبَانَ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ نَهَى النَّبِيُّ ـ صلى الله عليه وسلم ـ عَنِ الْخَذْفِ وَقَالَ ‏ "‏ إِنَّهَا لاَ تَقْتُلُ الصَّيْدَ وَلاَ تَنْكِي الْعَدُوَّ وَلَكِنَّهَا تَفْقَأُ الْعَيْنَ وَتَكْسِرُ السِّنَّ ‏"‏ ‏.‏\hadithno{3227}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Abdullah bin Mughaffal said:“The Prophet (ﷺ) forbade throwing small pebbles and said: ‘They do not kill any game or hurt the enemy, but they can break a tooth or put out an eye.’”}}
\hadithdefcmd{ibnmajah}{3228}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جُبَيْرٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أُمِّ شَرِيكٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ أَمَرَهَا بِقَتْلِ الأَوْزَاغِ ‏.‏\hadithno{3228}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Umm Sharik that the Prophet (ﷺ) told her to kill house lizards}}
\hadithdefcmd{ibnmajah}{3229}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ قَتَلَ وَزَغًا فِي أَوَّلِ ضَرْبَةٍ فَلَهُ كَذَا وَكَذَا حَسَنَةً وَمَنْ قَتَلَهَا فِي الثَّانِيَةِ فَلَهُ كَذَا وَكَذَا - أَدْنَى مِنَ الأُولَى - وَمَنْ قَتَلَهَا فِي الضَّرْبَةِ الثَّالِثَةِ فَلَهُ كَذَا وَكَذَا حَسَنَةً - أَدْنَى مِنَ الَّذِي ذَكَرَهُ فِي الْمَرَّةِ الثَّانِيَةِ ‏"‏ ‏.‏\hadithno{3229}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever kills a house lizard with one blow will have such and such a reward. Whoever kills it with two blows will have such and such a reward,” less than the first. “And whoever kills it with three blows will have such and such reward,” less than that mentioned the second time}}
\hadithdefcmd{ibnmajah}{3230}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ لِلْوَزَغِ ‏ "‏ الْفُوَيْسِقَةُ ‏"‏ ‏.‏\hadithno{3230}\hadithgrade{Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) said concerning house lizards:“Vermin.”}}
\hadithdefcmd{ibnmajah}{3231}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، عَنْ جَرِيرِ بْنِ حَازِمٍ، عَنْ نَافِعٍ، عَنْ سَائِبَةَ، - مَوْلاَةِ الْفَاكِهِ بْنِ الْمُغِيرَةِ - أَنَّهَا دَخَلَتْ عَلَى عَائِشَةَ فَرَأَتْ فِي بَيْتِهَا رُمْحًا مَوْضُوعًا فَقَالَتْ يَا أُمَّ الْمُؤْمِنِينَ مَا تَصْنَعِينَ بِهَذَا قَالَتْ نَقْتُلُ بِهِ هَذِهِ الأَوْزَاغَ فَإِنَّ نَبِيَّ اللَّهِ ـ صلى الله عليه وسلم ـ أَخْبَرَنَا أَنَّ إِبْرَاهِيمَ لَمَّا أُلْقِيَ فِي النَّارِ لَمْ تَكُنْ فِي الأَرْضِ دَابَّةٌ إِلاَّ أَطْفَأَتِ النَّارَ غَيْرَ الْوَزَغِ فَإِنَّهَا كَانَتْ تَنْفُخُ عَلَيْهِ فَأَمَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِقَتْلِهِ ‏.‏\hadithno{3231}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sa’ibah, the freed slave woman of Fakih bin Mughirah, that she entered upon ‘Aishah and saw a spear in her house. She said:“O Mother of the Believers, what do you do with this?” She said: “We kill these house lizards with it, for the Prophet of Allah (ﷺ) told us that when Ibrahim was thrown into the fire, there was no beast on earth that did not try to put it out, apart from the house lizard that blew on it. So the Messenger of Allah (ﷺ) commanded that they should be killed.”}}
\hadithdefcmd{ibnmajah}{3232}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَبُو إِدْرِيسَ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى عَنْ أَكْلِ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ ‏.‏ قَالَ الزُّهْرِيُّ وَلَمْ أَسْمَعْ بِهَذَا حَتَّى دَخَلْتُ الشَّامَ ‏.‏\hadithno{3232}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Tha’labah Al-Khushani that the Prophet (ﷺ) forbade eating any predatory animal that has fangs}}
\hadithdefcmd{ibnmajah}{3233}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي حَكِيمٍ، عَنْ عَبِيدَةَ بْنِ سُفْيَانَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ أَكْلُ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ حَرَامٌ ‏"‏ ‏.‏\hadithno{3233}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Eating any predatory animal that has fangs is unlawful.”}}
\hadithdefcmd{ibnmajah}{3234}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ عَلِيِّ بْنِ الْحَكَمِ، عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمَ خَيْبَرَ عَنْ أَكْلِ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ وَعَنْ كُلِّ ذِي مِخْلَبٍ مِنَ الطَّيْرِ ‏.‏\hadithno{3234}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“On the Day of Khaibar, the Messenger of Allah (ﷺ) forbade eating any predatory animal that has fangs and any bird that has talons.”}}
\hadithdefcmd{ibnmajah}{3235}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ وَاضِحٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ الْكَرِيمِ بْنِ أَبِي الْمُخَارِقِ، عَنْ حِبَّانَ بْنِ جَزْءٍ، عَنْ أَخِيهِ، خُزَيْمَةَ بْنِ جَزْءٍ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ جِئْتُكَ لأَسْأَلَكَ عَنْ أَحْنَاشِ الأَرْضِ مَا تَقُولُ فِي الثَّعْلَبِ قَالَ ‏"‏ وَمَنْ يَأْكُلُ الثَّعْلَبَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ مَا تَقُولُ فِي الذِّئْبِ قَالَ ‏"‏ وَيَأْكُلُ الذِّئْبَ أَحَدٌ فِيهِ خَيْرٌ ‏"‏ ‏.‏\hadithno{3235}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Khuzaimah bin Jaz’ said:“I said: ‘O Messenger of Allah, I have come to ask you about the vermin of the earth. What do you say about foxes?’ He said: ‘Who eats foxes?’ I said: ‘O Messenger of Allah, what do you say about wolves?’ He said: ‘Does anyone in whom there is anything good eat wolves?’”}}
\hadithdefcmd{ibnmajah}{3236}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ الْمَكِّيُّ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، عَنِ ابْنِ أَبِي عَمَّارٍ، - وَهُوَ عَبْدُ الرَّحْمَنِ - قَالَ سَأَلْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ عَنِ الضَّبُعِ أَصَيْدٌ هُوَ قَالَ نَعَمْ ‏.‏ قُلْتُ آكُلُهَا قَالَ نَعَمْ ‏.‏ قُلْتُ أَشَىْءٌ سَمِعْتَ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ نَعَمْ ‏.‏\hadithno{3236}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Abu ‘Ammar, who is ‘Abdur-Rahman, said:“I asked Jabir bin ‘Abdullah about hyenas: ‘Are they game (that can be hunted)?’ He said: ‘Yes.’ I said: ‘Can I eat them?’ He said: ‘Yes.’ I said: ‘Is this something that you heard from the Messenger of Allah (ﷺ)?’ He said: ‘Yes.’”}}
\hadithdefcmd{ibnmajah}{3237}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ وَاضِحٍ، عَنِ ابْنِ إِسْحَاقَ، عَنْ عَبْدِ الْكَرِيمِ بْنِ أَبِي الْمُخَارِقِ، عَنْ حِبَّانَ بْنِ جَزْءٍ، عَنْ خُزَيْمَةَ بْنِ جَزْءٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَا تَقُولُ فِي الضَّبُعِ قَالَ ‏ "‏ وَمَنْ يَأْكُلُ الضَّبُعَ ‏"‏ ‏.‏\hadithno{3237}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Khuzaimah bin Jaz’ said:“I said: ‘O Messenger of Allah (ﷺ), what do you say about hyenas?’ He said: ‘Who eats hyenas?’”}}
\hadithdefcmd{ibnmajah}{3238}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ حُصَيْنٍ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ ثَابِتِ بْنِ يَزِيدَ الأَنْصَارِيِّ، قَالَ كُنَّا مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَأَصَابَ النَّاسُ ضِبَابًا فَاشْتَوَوْهَا فَأَكَلُوا مِنْهَا فَأَصَبْتُ مِنْهَا ضَبًّا فَشَوَيْتُهُ ثُمَّ أَتَيْتُ بِهِ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَأَخَذَ جَرِيدَةً فَجَعَلَ يَعُدُّ بِهَا أَصَابِعَهُ فَقَالَ ‏ "‏ إِنَّ أُمَّةً فِي بَنِي إِسْرَائِيلَ مُسِخَتْ دَوَابَّ فِي الأَرْضِ وَإِنِّي لاَ أَدْرِي لَعَلَّهَا هِيَ ‏"‏ ‏.‏ فَقُلْتُ إِنَّ النَّاسَ قَدِ اشْتَوَوْهَا فَأَكَلُوهَا فَلَمْ يَأْكُلْ وَلَمْ يَنْهَ ‏.‏\hadithno{3238}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Thabit bin Yazid Al-Ansari said:“We were with the Prophet (ﷺ) and the people caught a mastigure. They grilled it and ate from it. Then I caught a mastigure so I grilled it and brought it to the Prophet (ﷺ). He took a palm stalk and started counting his finger with it, and said: ‘A nation from among the Children of Israel was turned into beasts of the earth, and I do not know if this is they.’ I said: ‘The people have grilled them and eaten them.’ He did not eat it and he did not forbid it.”}}
\hadithdefcmd{ibnmajah}{3239}{حَدَّثَنَا أَبُو إِسْحَاقَ الْهَرَوِيُّ، إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ حَاتِمٍ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ سُلَيْمَانَ الْيَشْكُرِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ لَمْ يُحَرِّمِ الضَّبَّ وَلَكِنْ قَذِرَهُ وَإِنَّهُ لَطَعَامُ عَامَّةِ الرِّعَاءِ وَإِنَّ اللَّهَ عَزَّ وَجَلَّ لَيَنْفَعُ بِهِ غَيْرَ وَاحِدٍ وَلَوْ كَانَ عِنْدِي لأَكَلْتُهُ ‏.‏ حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ سُلَيْمَانَ، عَنْ جَابِرٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَحْوَهُ ‏.‏\hadithno{3239}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin ‘Abdullah:“The Prophet (ﷺ) did not forbid (eating) mastigures, but he found that distasteful. It is the food of most shepherds, and Allah, the Mighty and Sublime, has benefited more than one person thereby. If I had some I would eat it.” Another chain reports a similar hadith}}
\hadithdefcmd{ibnmajah}{3240}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَادَى رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَجُلٌ مِنْ أَهْلِ الصُّفَّةِ حِينَ انْصَرَفَ مِنَ الصَّلاَةِ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أَرْضَنَا أَرْضٌ مَضَبَّةٌ فَمَا تَرَى فِي الضِّبَابِ قَالَ ‏ "‏ بَلَغَنِي أَنَّهُ أُمَّةٌ مُسِخَتْ ‏"‏ ‏.‏ فَلَمْ يَأْمُرْ بِهِ وَلَمْ يَنْهَ عَنْهُ ‏.‏\hadithno{3240}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“A man from among Ahlus-Suffah called the Messenger of Allah (ﷺ) when he had finished the prayer, saying: ‘O Messenger of Allah! Our land is a land infested with mastigures. What do you think of (eating) mastigures?’ He said: ‘I have heard that a nation was transformed.’ He did not tell us to eat them, and he did not forbid that.”}}
\hadithdefcmd{ibnmajah}{3241}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ الزُّبَيْدِيُّ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ خَالِدِ بْنِ الْوَلِيدِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أُتِيَ بِضَبٍّ مَشْوِيٍّ فَقُرِّبَ إِلَيْهِ فَأَهْوَى بِيَدِهِ لِيَأْكُلَ مِنْهُ فَقَالَ لَهُ مَنْ حَضَرَهُ يَا رَسُولَ اللَّهِ إِنَّهُ لَحْمُ ضَبٍّ ‏.‏ فَرَفَعَ يَدَهُ عَنْهُ فَقَالَ لَهُ خَالِدٌ يَا رَسُولَ اللَّهِ أَحَرَامٌ الضَّبُّ قَالَ ‏ "‏ لاَ وَلَكِنَّهُ لَمْ يَكُنْ بِأَرْضِي فَأَجِدُنِي أَعَافُهُ ‏"‏ ‏.‏ قَالَ فَأَهْوَى خَالِدٌ إِلَى الضَّبِّ فَأَكَلَ مِنْهُ وَرَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَنْظُرُ إِلَيْهِ ‏.‏\hadithno{3241}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Khalid bin Walid that a grilled mastigure was brought to the Messenger of Allah (ﷺ) and placed near him. He stretched out his hand to eat (some of it), then those who were present said:“O Messenger of Allah, it is the flesh of a mastigure.” He took his hand away, and Khalid said to him: “O Messenger of Allah, is a mastigure unlawful?” He said: “No, but it is not found in my land and I find it distasteful.” He said: “Then Khalid bent over the mastigure and ate some of it, and the Messenger of Allah (ﷺ) was looking at him.”}}
\hadithdefcmd{ibnmajah}{3242}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ أُحَرِّمُ ‏"‏ ‏.‏ يَعْنِي الضَّبَّ ‏.‏\hadithno{3242}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“I do not forbid it,” meaning mastigure}}
\hadithdefcmd{ibnmajah}{3243}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مَرَرْنَا بِمَرِّ الظَّهْرَانِ فَأَنْفَجْنَا أَرْنَبًا فَسَعَوْا عَلَيْهَا فَلَغَبُوا فَسَعَيْتُ حَتَّى أَدْرَكْتُهَا فَأَتَيْتُ بِهَا أَبَا طَلْحَةَ فَذَبَحَهَا فَبَعَثَ بِعَجُزِهَا وَوَرِكِهَا إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَبِلَهَا ‏.‏\hadithno{3243}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:We passed by Marr Az-Zahran and startled a rabbit. They chased it but got tired, so I chased it and caught it. I brought it to Abu Talhah who slaughtered it and sent its rump and thigh to the Prophet (ﷺ), who accepted it}}
\hadithdefcmd{ibnmajah}{3244}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، عَنِ الشَّعْبِيِّ، عَنْ مُحَمَّدِ بْنِ صَفْوَانَ، أَنَّهُ مَرَّ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ بِأَرْنَبَيْنِ مُعَلِّقَهُمَا فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَصَبْتُ هَذَيْنِ الأَرْنَبَيْنِ فَلَمْ أَجِدْ حَدِيدَةً أُذَكِّيهِمَا بِهَا فَذَكَّيْتُهُمَا بِمَرْوَةٍ أَفَآكُلُ قَالَ ‏ "‏ كُلْ ‏"‏ ‏.‏\hadithno{3244}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{it was narrated from Muhammad bin Safwan that he passed by the Prophet (ﷺ) with two rabbits hanging down. He said:“O Messenger of Allah, I caught these two rabbits but I cannot find any iron* with which to slaughter them with Marwah** and eat them?” He said: “Eat.”}}
\hadithdefcmd{ibnmajah}{3245}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ وَاضِحٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ الْكَرِيمِ بْنِ أَبِي الْمُخَارِقِ، عَنْ حِبَّانَ بْنِ جَزْءٍ، عَنْ أَخِيهِ، خُزَيْمَةَ بْنِ جَزْءٍ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ جِئْتُكَ لأَسْأَلَكَ عَنْ أَحْنَاشِ الأَرْضِ مَا تَقُولُ فِي الضَّبِّ قَالَ ‏"‏ لاَ آكُلُهُ وَلاَ أُحَرِّمُهُ ‏"‏ ‏.‏ قَالَ قُلْتُ فَإِنِّي آكُلُ مِمَّا لَمْ تُحَرِّمْ وَلِمَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ فُقِدَتْ أُمَّةٌ مِنَ الأُمَمِ وَرَأَيْتُ خَلْقًا رَابَنِي ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ مَا تَقُولُ فِي الأَرْنَبِ قَالَ لاَ آكُلُهُ وَلاَ أُحَرِّمُهُ ‏"‏ ‏.‏ قُلْتُ فَإِنِّي آكُلُ مِمَّا لَمْ تُحَرِّمْ وَلِمَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نُبِّئْتُ أَنَّهَا تَدْمَى ‏"‏ ‏.‏\hadithno{3245}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Khuzaimah bin Jaz’ said:“I said: ‘O Messenger of Allah, I have come to you to ask you about the vermin of the earth. What do you say about mastigures?’ He said: ‘I do not eat them and I do not forbid them.’ I said: ‘I will eat of that which you have not forbidden. But why (do you not eat them), O Messenger of Allah?’ He said: ‘One of the nations was turned into beasts and I looked at this creature and was uncertain.’ I said: ‘O Messenger of Allah, what do you say about rabbits?’ He said: ‘I do not eat them and I do not forbid them.’ I said: ‘I will eat of that which you have not forbidden. But why (do you not eat them), O Messenger of Allah?’ He said: ‘I have been told that it menstruates.’”}}
\hadithdefcmd{ibnmajah}{3246}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، حَدَّثَنِي صَفْوَانُ بْنُ سُلَيْمٍ، عَنْ سَعِيدِ بْنِ سَلَمَةَ، مِنْ آلِ ابْنِ الأَزْرَقِ أَنَّ الْمُغِيرَةَ بْنَ أَبِي بُرْدَةَ، - وَهُوَ مِنْ بَنِي عَبْدِ الدَّارِ - حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْبَحْرُ الطَّهُورُ مَاؤُهُ الْحِلُّ مَيْتَتُهُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ بَلَغَنِي عَنْ أَبِي عُبَيْدَةَ الْجَوَادِ أَنَّهُ قَالَ هَذَا نِصْفُ الْعِلْمِ لأَنَّ الدُّنْيَا بَرٌّ وَبَحْرٌ فَقَدْ أَفْتَاكَ فِي الْبَحْرِ وَبَقِيَ الْبَرُّ ‏.‏\hadithno{3246}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Mughirah bin Abu Burdah, who was of the tribe of Banu ‘Abd-Dar, narrated that he heard Abu Hurairah say:“The Messenger of Allah (ﷺ) said: ‘The water of the sea is a means of purification and its dead meat is permissible.’”}}
\hadithdefcmd{ibnmajah}{3247}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ الطَّائِفِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أُمَيَّةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا أَلْقَى الْبَحْرُ أَوْ جَزَرَ عَنْهُ فَكُلُوهُ وَمَا مَاتَ فِيهِ فَطَفَا فَلاَ تَأْكُلُوهُ ‏"‏ ‏.‏\hadithno{3247}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) said:“Whatever the sea throws out or is left behind when the tide ebbs, eat it, but whatever rises to its surface, do not eat it.’”}}
\hadithdefcmd{ibnmajah}{3248}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ النَّيْسَابُورِيُّ، حَدَّثَنَا الْهَيْثَمُ بْنُ جَمِيلٍ، حَدَّثَنَا شَرِيكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ مَنْ يَأْكُلُ الْغُرَابَ وَقَدْ سَمَّاهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ فَاسِقًا ‏"‏ ‏.‏ وَاللَّهِ مَا هُوَ مِنَ الطَّيِّبَاتِ ‏.‏\hadithno{3248}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn ‘Umar said:“Who eats crows? The Messenger of Allah (ﷺ) called them vermin, By Allah, they are not from among the good and permissible things.”}}
\hadithdefcmd{ibnmajah}{3249}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا الْمَسْعُودِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ بْنِ مُحَمَّدِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ الْحَيَّةُ فَاسِقَةٌ وَالْعَقْرَبُ فَاسِقَةٌ وَالْفَأْرَةُ فَاسِقَةٌ وَالْغُرَابُ فَاسِقٌ ‏"‏ ‏.‏ فَقِيلَ لِلْقَاسِمِ أَيُؤْكَلُ الْغُرَابُ قَالَ مَنْ يَأْكُلُهُ بَعْدَ قَوْلِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ فَاسِقٌ ‏"‏ ‏.‏\hadithno{3249}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) said:“Snakes are vermin, scorpions are vermin, mice are vermin and crows are vermin.”}}
\hadithdefcmd{ibnmajah}{3250}{حَدَّثَنَا الْحُسَيْنُ بْنُ مَهْدِيٍّ، أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا عُمَرُ بْنُ زَيْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ أَكْلِ الْهِرَّةِ وَثَمَنِهَا‏.‏\hadithno{3250}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:“The Messenger of Allah (ﷺ) forbade eating cats and he forbade their price.”}}
