% Auto-generated chapter 5 for tirmidhi
% Hadiths in this chapter: 14

\hadithdefcmd{tirmidhi}{530}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى الْفَزَارِيُّ، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ مِنَ السُّنَّةِ أَنْ تَخْرُجَ، إِلَى الْعِيدِ مَاشِيًا وَأَنْ تَأْكُلَ شَيْئًا قَبْلَ أَنْ تَخْرُجَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ يَسْتَحِبُّونَ أَنْ يَخْرُجَ الرَّجُلُ إِلَى الْعِيدِ مَاشِيًا وَأَنْ يَأْكُلَ شَيْئًا قَبْلَ أَنْ يَخْرُجَ لِصَلاَةِ الْفِطْرِ ‏.‏ قَالَ أَبُو عِيسَى وَيُسْتَحَبُّ أَنْ لاَ يَرْكَبَ إِلاَّ مِنْ عُذْرٍ ‏.‏\hadithno{530}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ali bin Abi Talib narrated:"It is from the SUnnah to leave for the Eid walking, and to eat something before leaving}}
\hadithdefcmd{tirmidhi}{531}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، هُوَ ابْنُ عُمَرَ بْنِ حَفْصِ بْنِ عَاصِمِ بْنِ عُمَرَ بْنِ الْخَطَّابِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ وَعُمَرُ يُصَلُّونَ فِي الْعِيدَيْنِ قَبْلَ الْخُطْبَةِ ثُمَّ يَخْطُبُونَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ صَلاَةَ الْعِيدَيْنِ قَبْلَ الْخُطْبَةِ ‏.‏ وَيُقَالُ إِنَّ أَوَّلَ مَنْ خَطَبَ قَبْلَ الصَّلاَةِ مَرْوَانُ بْنُ الْحَكَمِ ‏.‏\hadithno{531}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated:"Allah's Messenger, Abu Bakr, and Umar would pray during the two Eid before the Khutbah, then they would give the Khutbah}}
\hadithdefcmd{tirmidhi}{532}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم الْعِيدَيْنِ غَيْرَ مَرَّةٍ وَلاَ مَرَّتَيْنِ بِغَيْرِ أَذَانٍ وَلاَ إِقَامَةٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ جَابِرِ بْنِ سَمُرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّهُ لاَ يُؤَذَّنُ لِصَلاَةِ الْعِيدَيْنِ وَلاَ لِشَيْءٍ مِنَ النَّوَافِلِ ‏.‏\hadithno{532}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Jabir bin Samurah narrated:"I prayed the two Eid prayers with the Prophet - not one time, not two times - without and Adhan nor an Iqamah}}
\hadithdefcmd{tirmidhi}{533}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، عَنْ أَبِيهِ، عَنْ حَبِيبِ بْنِ سَالِمٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ فِي الْعِيدَيْنِ وَفِي الْجُمُعَةِ بِـ ‏(‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏)‏ وَ ‏(‏هَلْ أَتَاكَ حَدِيثُ الْغَاشِيَةِ ‏)‏ وَرُبَّمَا اجْتَمَعَا فِي يَوْمٍ وَاحِدٍ فَيَقْرَأُ بِهِمَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي وَاقِدٍ وَسَمُرَةَ بْنِ جُنْدَبٍ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ النُّعْمَانِ بْنِ بَشِيرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَكَذَا رَوَى سُفْيَانُ الثَّوْرِيُّ وَمِسْعَرٌ عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ نَحْوَ حَدِيثِ أَبِي عَوَانَةَ ‏.‏ وَأَمَّا سُفْيَانُ بْنُ عُيَيْنَةَ فَيُخْتَلَفُ عَلَيْهِ فِي الرِّوَايَةِ يُرْوَى عَنْهُ عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ عَنْ أَبِيهِ عَنْ حَبِيبِ بْنِ سَالِمٍ عَنْ أَبِيهِ عَنِ النُّعْمَانِ بْنِ بَشِيرٍ ‏.‏ وَلاَ نَعْرِفُ لِحَبِيبِ بْنِ سَالِمٍ رِوَايَةً عَنْ أَبِيهِ ‏.‏ وَحَبِيبُ بْنُ سَالِمٍ هُوَ مَوْلَى النُّعْمَانِ بْنِ بَشِيرٍ وَرَوَى عَنِ النُّعْمَانِ بْنِ بَشِيرٍ أَحَادِيثَ ‏.‏ وَقَدْ رُوِيَ عَنِ ابْنِ عُيَيْنَةَ عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ نَحْوُ رِوَايَةِ هَؤُلاَءِ ‏.‏ وَرُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَقْرَأُ فِي صَلاَةِ الْعِيدَيْنِ بِـ ‏(‏اقْتَرَبَتِ السَّاعَةُ ‏)‏ وَبِهِ يَقُولُ الشَّافِعِيُّ ‏.‏\hadithno{533}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{An-Numan bin Bashir narrated:"For the two Eid and the Friday prayer, the Prophet would recite: Glorify the Name of your Lord, the Most High, and Has there come to you the narration of the overwhelming? And sometimes they would occur on he same day, so he would recite the two of them}}
\hadithdefcmd{tirmidhi}{534}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ ضَمْرَةَ بْنِ سَعِيدٍ الْمَازِنِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، سَأَلَ أَبَا وَاقِدٍ اللَّيْثِيَّ مَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ بِهِ فِي الْفِطْرِ وَالأَضْحَى قَالَ كَانَ يَقْرَأُ بـــ‏(‏ق والقرآنِ الْمَجِيدِ ‏)‏ ‏(‏اقْتَرَبَتِ السَّاعَةُ وَانْشَقَّ الْقَمَرُ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{534}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ubaidullah bin Abdullah bin Utbah narrated:"Umar bin Al-Khattab asked Abu Waqid Al-Laithi what Allah's Messenger would recite during Al-Fitr and Al-Adha, so he said: 'He would recite: Qaf, By the Glorious Quran and the Hour has drawn near, and the moon has been cleft asunder}}
\hadithdefcmd{tirmidhi}{535}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ ضَمْرَةَ بْنِ سَعِيدٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى وَأَبُو وَاقِدٍ اللَّيْثِيُّ اسْمُهُ الْحَارِثُ بْنُ عَوْفٍ ‏.‏\hadithno{535}\hadithgrade{Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ubaidullah bin Abdullah bin Utbah:There is a another chain with similar narration}}
\hadithdefcmd{tirmidhi}{536}{حَدَّثَنَا مُسْلِمُ بْنُ عَمْرٍو أَبُو عَمْرٍو الْحَذَّاءُ الْمَدِينِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ الصَّائِغُ، عَنْ كَثِيرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَبَّرَ فِي الْعِيدَيْنِ فِي الأُولَى سَبْعًا قَبْلَ الْقِرَاءَةِ وَفِي الآخِرَةِ خَمْسًا قَبْلَ الْقِرَاءَةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَابْنِ عُمَرَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَدِّ كَثِيرٍ حَدِيثٌ حَسَنٌ وَهُوَ أَحْسَنُ شَيْءٍ رُوِيَ فِي هَذَا الْبَابِ عَنِ النَّبِيِّ عَلَيْهِ السَّلاَمُ وَاسْمُهُ عَمْرُو بْنُ عَوْفٍ الْمُزَنِيُّ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ ‏.‏ وَهَكَذَا رُوِيَ عَنْ أَبِي هُرَيْرَةَ أَنَّهُ صَلَّى بِالْمَدِينَةِ نَحْوَ هَذِهِ الصَّلاَةِ وَهُوَ قَوْلُ أَهْلِ الْمَدِينَةِ ‏.‏ وَبِهِ يَقُولُ مَالِكُ بْنُ أَنَسٍ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَرُوِيَ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ أَنَّهُ قَالَ فِي التَّكْبِيرِ فِي الْعِيدَيْنِ تِسْعَ تَكْبِيرَاتٍ فِي الرَّكْعَةِ الأُولَى خَمْسًا قَبْلَ الْقِرَاءَةِ وَفِي الرَّكْعَةِ الثَّانِيَةِ يَبْدَأُ بِالْقِرَاءَةِ ثُمَّ يُكَبِّرُ أَرْبَعًا مَعَ تَكْبِيرَةِ الرُّكُوعِ ‏.‏ وَقَدْ رُوِيَ عَنْ غَيْرِ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم نَحْوُ هَذَا وَهُوَ قَوْلُ أَهْلِ الْكُوفَةِ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ ‏.‏\hadithno{536}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Kathir bin Abdullah narrated from this father, from his grandfather:"The Prophet said the Takbir in the first (Rak'ah) sever (times) before the recitation, and in the last, five (times) before the recitation}}
\hadithdefcmd{tirmidhi}{537}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، يُحَدِّثُ عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ يَوْمَ الْفِطْرِ فَصَلَّى رَكْعَتَيْنِ ثُمَّ لَمْ يُصَلِّ قَبْلَهَا وَلاَ بَعْدَهَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَدْ رَأَى طَائِفَةٌ مِنْ أَهْلِ الْعِلْمِ الصَّلاَةَ بَعْدَ صَلاَةِ الْعِيدَيْنِ وَقَبْلَهَا مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏\hadithno{537}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated:"The Prophet went out on the day of Al-Fitr, so he prayed two Rak'ah, then he did not pray before it nor after it}}
\hadithdefcmd{tirmidhi}{538}{حَدَّثَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا وَكِيعٌ، عَنْ أَبَانَ بْنِ عَبْدِ اللَّهِ الْبَجَلِيِّ، عَنْ أَبِي بَكْرِ بْنِ حَفْصٍ، وَهُوَ ابْنُ عُمَرَ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ عَنِ ابْنِ عُمَرَ، أَنَّهُ خَرَجَ فِي يَوْمِ عِيدٍ فَلَمْ يُصَلِّ قَبْلَهَا وَلاَ بَعْدَهَا وَذَكَرَ أَنَّ النَّبِيَّ صلى الله عليه وسلم فَعَلَهُ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{538}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Bakr bin Hafs - and he is Ibn Umar bin Sa'd bin Abi Waqas - narrated about Ibn Umar, that:"He went out on the day of Eid, and he did not pray before it nor after it. He mentioned that the Prophet did so}}
\hadithdefcmd{tirmidhi}{539}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا مَنْصُورٌ، وَهُوَ ابْنُ زَاذَانَ عَنِ ابْنِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُخْرِجُ الأَبْكَارَ وَالْعَوَاتِقَ وَذَوَاتِ الْخُدُورِ وَالْحُيَّضَ فِي الْعِيدَيْنِ فَأَمَّا الْحُيَّضُ فَيَعْتَزِلْنَ الْمُصَلَّى وَيَشْهَدْنَ دَعْوَةَ الْمُسْلِمِينَ قَالَتْ إِحْدَاهُنَّ يَا رَسُولَ اللَّهِ إِنْ لَمْ يَكُنْ لَهَا جِلْبَابٌ قَالَ ‏ "‏ فَلْتُعِرْهَا أُخْتُهَا مِنْ جَلاَبِيبِهَا ‏"‏ ‏.‏\hadithno{539}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Umm Atiyyah narrated:"Allah's Messenger would order the virgins, the mature women, the secluded and the menstruating to go out for the two Eid. As for the menstruating women, they were to stay away from the Musalla and participate in the Muslims supplications." One of them said: 'O Messenger of Allah! What if she does not have a Jilbab? He said: 'Then let her sis lend her a Jilbab}}
\hadithdefcmd{tirmidhi}{540}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، بِنَحْوِهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ، وَجَابِرٍ، ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أُمِّ عَطِيَّةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا الْحَدِيثِ وَرَخَّصَ لِلنِّسَاءِ فِي الْخُرُوجِ إِلَى الْعِيدَيْنِ وَكَرِهَهُ بَعْضُهُمْ وَرُوِيَ عَنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ أَنَّهُ قَالَ أَكْرَهُ الْيَوْمَ الْخُرُوجَ لِلنِّسَاءِ فِي الْعِيدَيْنِ فَإِنْ أَبَتِ الْمَرْأَةُ إِلاَّ أَنْ تَخْرُجَ فَلْيَأْذَنْ لَهَا زَوْجُهَا أَنْ تَخْرُجَ فِي أَطْمَارِهَا الْخُلْقَانِ وَلاَ تَتَزَيَّنْ فَإِنْ أَبَتْ أَنْ تَخْرُجَ كَذَلِكَ فَلِلزَّوْجِ أَنْ يَمْنَعَهَا عَنِ الْخُرُوجِ ‏.‏ وَيُرْوَى عَنْ عَائِشَةَ رضى الله عنها قَالَتْ لَوْ رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم مَا أَحْدَثَ النِّسَاءُ لَمَنَعَهُنَّ الْمَسْجِدَ كَمَا مُنِعَتْ نِسَاءُ بَنِي إِسْرَائِيلَ ‏.‏ وَيُرْوَى عَنْ سُفْيَانَ الثَّوْرِيِّ أَنَّهُ كَرِهَ الْيَوْمَ الْخُرُوجَ لِلنِّسَاءِ إِلَى الْعِيدِ ‏.‏\hadithno{540}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{There is a similar narration from Umm Atiyyah :with another chain}}
\hadithdefcmd{tirmidhi}{541}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ وَاصِلِ بْنِ عَبْدِ الأَعْلَى الْكُوفِيُّ، وَأَبُو زُرْعَةَ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ الصَّلْتِ، عَنْ فُلَيْحِ بْنِ سُلَيْمَانَ، عَنْ سَعِيدِ بْنِ الْحَارِثِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا خَرَجَ يَوْمَ الْعِيدِ فِي طَرِيقٍ رَجَعَ فِي غَيْرِهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ وَأَبِي رَافِعٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَرَوَى أَبُو تُمَيْلَةَ وَيُونُسُ بْنُ مُحَمَّدٍ هَذَا الْحَدِيثَ عَنْ فُلَيْحِ بْنِ سُلَيْمَانَ عَنْ سَعِيدِ بْنِ الْحَارِثِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏ قَالَ وَقَدِ اسْتَحَبَّ بَعْضُ أَهْلِ الْعِلْمِ لِلإِمَامِ إِذَا خَرَجَ فِي طَرِيقٍ أَنْ يَرْجِعَ فِي غَيْرِهِ اتِّبَاعًا لِهَذَا الْحَدِيثِ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏ وَحَدِيثُ جَابِرٍ كَأَنَّهُ أَصَحُّ ‏.‏\hadithno{541}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated:"When Allah's Messenger would go out on the day of Eid by one route, he would return by another}}
\hadithdefcmd{tirmidhi}{542}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ الْبَزَّارُ الْبَغْدَادِيُّ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، عَنْ ثَوَابِ بْنِ عُتْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم لاَ يَخْرُجُ يَوْمَ الْفِطْرِ حَتَّى يَطْعَمَ وَلاَ يَطْعَمُ يَوْمَ الأَضْحَى حَتَّى يُصَلِّيَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ بُرَيْدَةَ بْنِ حُصَيْبٍ الأَسْلَمِيِّ حَدِيثٌ غَرِيبٌ ‏.‏ وَقَالَ مُحَمَّدٌ لاَ أَعْرِفُ لِثَوَابِ بْنِ عُتْبَةَ غَيْرَ هَذَا الْحَدِيثِ ‏.‏ وَقَدِ اسْتَحَبَّ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ أَنْ لاَ يَخْرُجَ يَوْمَ الْفِطْرِ حَتَّى يَطْعَمَ شَيْئًا وَيُسْتَحَبُّ لَهُ أَنْ يُفْطِرَ عَلَى تَمْرٍ وَلاَ يَطْعَمَ يَوْمَ الأَضْحَى حَتَّى يَرْجِعَ ‏.‏\hadithno{542}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Buraidah narrated from his father:"The Prophet would not leave on the Day of Fitr until he ate, and he would not eat on the day of Adha until he prayed}}
\hadithdefcmd{tirmidhi}{543}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا هُشَيْمٌ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ حَفْصِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُفْطِرُ عَلَى تَمَرَاتٍ يَوْمَ الْفِطْرِ قَبْلَ أَنْ يَخْرُجَ إِلَى الْمُصَلَّى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{543}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated:"The Prophet would have a breakfast of dates on the Day of Fitr before leaving for the Musalla}}
