% Auto-generated chapter 33 for bukhari
% Hadiths in this chapter: 21

\hadithdefcmd{bukhari}{2025}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، عَنْ يُونُسَ، أَنَّ نَافِعًا، أَخْبَرَهُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْتَكِفُ الْعَشْرَ الأَوَاخِرَ مِنْ رَمَضَانَ‏.‏\hadithno{2025}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) used to practice I`tikaf in the last ten days of the month of Ramadan}}
\hadithdefcmd{bukhari}{2026}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَعْتَكِفُ الْعَشْرَ الأَوَاخِرَ مِنْ رَمَضَانَ حَتَّى تَوَفَّاهُ اللَّهُ، ثُمَّ اعْتَكَفَ أَزْوَاجُهُ مِنْ بَعْدِهِ‏.‏\hadithno{2026}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) The Prophet (ﷺ) used to practice I`tikaf in the last ten days of Ramadan till he died and then his wives used to practice I`tikaf after him}}
\hadithdefcmd{bukhari}{2027}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَعْتَكِفُ فِي الْعَشْرِ الأَوْسَطِ مِنْ رَمَضَانَ، فَاعْتَكَفَ عَامًا حَتَّى إِذَا كَانَ لَيْلَةَ إِحْدَى وَعِشْرِينَ، وَهِيَ اللَّيْلَةُ الَّتِي يَخْرُجُ مِنْ صَبِيحَتِهَا مِنِ اعْتِكَافِهِ قَالَ ‏ "‏ مَنْ كَانَ اعْتَكَفَ مَعِي فَلْيَعْتَكِفِ الْعَشْرَ الأَوَاخِرَ، وَقَدْ أُرِيتُ هَذِهِ اللَّيْلَةَ ثُمَّ أُنْسِيتُهَا، وَقَدْ رَأَيْتُنِي أَسْجُدُ فِي مَاءٍ وَطِينٍ مِنْ صَبِيحَتِهَا، فَالْتَمِسُوهَا فِي الْعَشْرِ الأَوَاخِرِ، وَالْتَمِسُوهَا فِي كُلِّ وِتْرٍ ‏"‏‏.‏ فَمَطَرَتِ السَّمَاءُ تِلْكَ اللَّيْلَةَ، وَكَانَ الْمَسْجِدُ عَلَى عَرِيشٍ فَوَكَفَ الْمَسْجِدُ، فَبَصُرَتْ عَيْنَاىَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى جَبْهَتِهِ أَثَرُ الْمَاءِ وَالطِّينِ، مِنْ صُبْحِ إِحْدَى وَعِشْرِينَ‏.‏\hadithno{2027}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) used to practice I`tikaf in the middle ten days of Ramadan and once he stayed in I`tikaf till the night of the twenty-first and it was the night in the morning of which he used to come out of his I`tikaf. The Prophet (ﷺ) said, "Whoever was in I`tikaf with me should stay in I`tikaf for the last ten days, for I was informed (of the date) of the Night (of Qadr) but I have been caused to forget it. (In the dream) I saw myself prostrating in mud and water in the morning of that night. So, look for it in the last ten nights and in the odd ones of them." It rained that night and the roof of the mosque dribbled as it was made of leaf stalks of date-palms. I saw with my own eyes the mark of mud and water on the forehead of the Prophet (i.e. in the morning of the twenty-first)}}
\hadithdefcmd{bukhari}{2028}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصْغِي إِلَىَّ رَأْسَهُ وَهْوَ مُجَاوِرٌ فِي الْمَسْجِدِ، فَأُرَجِّلُهُ وَأَنَا حَائِضٌ‏.‏\hadithno{2028}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to (put) bend his head (out) to me while he was in I`tikaf in the mosque during my monthly periods and I would comb and oil his hair}}
\hadithdefcmd{bukhari}{2029}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، وَعَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ وَإِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُدْخِلُ عَلَىَّ رَأْسَهُ وَهْوَ فِي الْمَسْجِدِ فَأُرَجِّلُهُ، وَكَانَ لاَ يَدْخُلُ الْبَيْتَ إِلاَّ لِحَاجَةٍ، إِذَا كَانَ مُعْتَكِفًا\hadithno{2029}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) Allah's Messenger (ﷺ) used to let his head in (the house) while he was in the mosque and I would comb and oil his hair. When in I`tikaf he used not to enter the house except for a need}}
\hadithdefcmd{bukhari}{2031}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُبَاشِرُنِي وَأَنَا حَائِضٌ‏.‏ وَكَانَ يُخْرِجُ رَأْسَهُ مِنَ الْمَسْجِدِ وَهْوَ مُعْتَكِفٌ فَأَغْسِلُهُ وَأَنَا حَائِضٌ‏.‏\hadithno{2031}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to embrace me during my menses. He also used to put his head out of the mosque while he was in I`tikaf, and I would wash it during my menses}}
\hadithdefcmd{bukhari}{2032}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ عُمَرَ، سَأَلَ النَّبِيَّ صلى الله عليه وسلم قَالَ كُنْتُ نَذَرْتُ فِي الْجَاهِلِيَّةِ أَنْ أَعْتَكِفَ لَيْلَةً فِي الْمَسْجِدِ الْحَرَامِ، قَالَ ‏ "‏ فَأَوْفِ بِنَذْرِكَ ‏"‏‏.‏\hadithno{2032}\hadithtrans{Narrated Ibn `Umar:`Umar asked the Prophet (ﷺ) "I vowed in the Pre-Islamic period of ignorance to stay in I`tikaf for one night in Al-Masjid al-Haram." The Prophet (ﷺ) said to him, "Fulfill your vow}}
\hadithdefcmd{bukhari}{2033}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا يَحْيَى، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَعْتَكِفُ فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ، فَكُنْتُ أَضْرِبُ لَهُ خِبَاءً فَيُصَلِّي الصُّبْحَ ثُمَّ يَدْخُلُهُ، فَاسْتَأْذَنَتْ حَفْصَةُ عَائِشَةَ أَنْ تَضْرِبَ خِبَاءً فَأَذِنَتْ لَهَا، فَضَرَبَتْ خِبَاءً، فَلَمَّا رَأَتْهُ زَيْنَبُ ابْنَةُ جَحْشٍ ضَرَبَتْ خِبَاءً آخَرَ، فَلَمَّا أَصْبَحَ النَّبِيُّ صلى الله عليه وسلم رَأَى الأَخْبِيَةَ فَقَالَ ‏"‏ مَا هَذَا ‏"‏‏.‏ فَأُخْبِرَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ آلْبِرُّ تُرَوْنَ بِهِنَّ ‏"‏‏.‏ فَتَرَكَ الاِعْتِكَافَ ذَلِكَ الشَّهْرَ، ثُمَّ اعْتَكَفَ عَشْرًا مِنْ شَوَّالٍ‏.‏\hadithno{2033}\hadithtrans{Narrated `Amra:Aisha said, "the Prophet (ﷺ) used to practice I`tikaf in the last ten days of Ramadan and I used to pitch a tent for him, and after offering the morning prayer, he used to enter the tent." Hafsa asked the permission of `Aisha to pitch a tent for her and she allowed her and she pitched her tent. When Zainab bint Jahsh saw it, she pitched another tent. In the morning the Prophet (ﷺ) noticed the tents. He said, 'What is this?" He was told of the whole situation. Then the Prophet (ﷺ) said, "Do you think that they intended to do righteousness by doing this?" He therefore abandoned the I`tikaf in that month and practiced I`tikaf for ten days in the month of Shawwal}}
\hadithdefcmd{bukhari}{2034}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَرَادَ أَنْ يَعْتَكِفَ، فَلَمَّا انْصَرَفَ إِلَى الْمَكَانِ الَّذِي أَرَادَ أَنْ يَعْتَكِفَ إِذَا أَخْبِيَةٌ خِبَاءُ عَائِشَةَ، وَخِبَاءُ حَفْصَةَ، وَخِبَاءُ زَيْنَبَ، فَقَالَ ‏ "‏ آلْبِرَّ تَقُولُونَ بِهِنَّ ‏"‏‏.‏ ثُمَّ انْصَرَفَ، فَلَمْ يَعْتَكِفْ، حَتَّى اعْتَكَفَ عَشْرًا مِنْ شَوَّالٍ‏.‏\hadithno{2034}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) intended to practice I`tikaf and when he reached the place where he intended to perform I`tikaf, he saw some tents, the tents of `Aisha, Hafsa and Zainab. So, he said, "Do you consider that they intended to do righteousness by doing this?" And then he went away and did not perform I`tikaf (in Ramadan) but performed it in the month of Shawwal for ten days}}
\hadithdefcmd{bukhari}{2035}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عَلِيُّ بْنُ الْحُسَيْنِ ـ رضى الله عنهما ـ أَنَّ صَفِيَّةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّهَا جَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم تَزُورُهُ فِي اعْتِكَافِهِ فِي الْمَسْجِدِ، فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ، فَتَحَدَّثَتْ عِنْدَهُ سَاعَةً، ثُمَّ قَامَتْ تَنْقَلِبُ، فَقَامَ النَّبِيُّ صلى الله عليه وسلم مَعَهَا يَقْلِبُهَا، حَتَّى إِذَا بَلَغَتْ باب الْمَسْجِدِ عِنْدَ باب أُمِّ سَلَمَةَ مَرَّ رَجُلاَنِ مِنَ الأَنْصَارِ، فَسَلَّمَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُمَا النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَلَى رِسْلِكُمَا إِنَّمَا هِيَ صَفِيَّةُ بِنْتُ حُيَىٍّ ‏"‏‏.‏ فَقَالاَ سُبْحَانَ اللَّهِ يَا رَسُولَ اللَّهِ‏.‏ وَكَبُرَ عَلَيْهِمَا‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ الشَّيْطَانَ يَبْلُغُ مِنَ الإِنْسَانِ مَبْلَغَ الدَّمِ، وَإِنِّي خَشِيتُ أَنْ يَقْذِفَ فِي قُلُوبِكُمَا شَيْئًا ‏"‏‏.‏\hadithno{2035}\hadithtrans{Narrated `Ali bin Al-Husain:Safiya, the wife of the Prophet (ﷺ) told me that she went to Allah's Messenger (ﷺ) to visit him in the mosque while he was in I`tikaf in the last ten days of Ramadan. She had a talk with him for a while, then she got up in order to return home. The Prophet (ﷺ) accompanied her. When they reached the gate of the mosque, opposite the door of Um-Salama, two Ansari men were passing by and they greeted Allah's Apostle . He told them: Do not run away! And said, "She is (my wife) Safiya bint Huyai." Both of them said, "Subhan Allah, (How dare we think of any evil) O Allah's Messenger (ﷺ)!" And they felt it. The Prophet said (to them), "Satan reaches everywhere in the human body as blood reaches in it, (everywhere in one's body). I was afraid lest Satan might insert an evil thought in your minds}}
\hadithdefcmd{bukhari}{2036}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُنِيرٍ، سَمِعَ هَارُونَ بْنَ إِسْمَاعِيلَ، حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، قَالَ سَأَلْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ قُلْتُ هَلْ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَذْكُرُ لَيْلَةَ الْقَدْرِ قَالَ نَعَمِ، اعْتَكَفْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْعَشْرَ الأَوْسَطَ مِنْ رَمَضَانَ ـ قَالَ ـ فَخَرَجْنَا صَبِيحَةَ عِشْرِينَ، قَالَ فَخَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم صَبِيحَةَ عِشْرِينَ فَقَالَ ‏ "‏ إِنِّي أُرِيتُ لَيْلَةَ الْقَدْرِ، وَإِنِّي نُسِّيتُهَا، فَالْتَمِسُوهَا فِي الْعَشْرِ الأَوَاخِرِ فِي وِتْرٍ، فَإِنِّي رَأَيْتُ أَنِّي أَسْجُدُ فِي مَاءٍ وَطِينٍ، وَمَنْ كَانَ اعْتَكَفَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلْيَرْجِعْ ‏"‏‏.‏ فَرَجَعَ النَّاسُ إِلَى الْمَسْجِدِ، وَمَا نَرَى فِي السَّمَاءِ قَزَعَةً ـ قَالَ ـ فَجَاءَتْ سَحَابَةٌ فَمَطَرَتْ، وَأُقِيمَتِ الصَّلاَةُ، فَسَجَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الطِّينِ وَالْمَاءِ، حَتَّى رَأَيْتُ الطِّينَ فِي أَرْنَبَتِهِ وَجَبْهَتِهِ‏.‏\hadithno{2036}\hadithtrans{Narrated Abu Salama bin `Abdur-Rahman:I asked Abu Sa`id Al-Khudri, "Did you hear Allah's Messenger (ﷺ) talking about the Night of Qadr?" He replied in the affirmative and said, "Once we were in I`tikaf with Allah's Messenger (ﷺ) in the middle ten days of (Ramadan) and we came out of it in the morning of the twentieth, and Allah's Messenger (ﷺ)delivered a sermon on the 20th (of Ramadan) and said, 'I was informed (of the date) of the Night of Qadr (in my dream) but had forgotten it. So, look for it in the odd nights of the last ten nights of the month of Ramadan. I saw myself prostrating in mud and water on that night (as a sign of the Night of Qadr). So, whoever had been in I`tikaf with Allah's Messenger (ﷺ) should return for it.' The people returned to the mosque (for I`tikaf). There was no trace of clouds in the sky. But all of a sudden a cloud came and it rained. Then the prayer was established (they stood for the prayer) and Allah's Messenger (ﷺ) prostrated in mud and water and I saw mud over the forehead and the nose of the Prophet}}
\hadithdefcmd{bukhari}{2037}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ خَالِدٍ، عَنْ عِكْرِمَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتِ اعْتَكَفَتْ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم امْرَأَةٌ مِنْ أَزْوَاجِهِ مُسْتَحَاضَةٌ، فَكَانَتْ تَرَى الْحُمْرَةَ وَالصُّفْرَةَ، فَرُبَّمَا وَضَعْنَا الطَّسْتَ تَحْتَهَا وَهْىَ تُصَلِّي‏.‏\hadithno{2037}\hadithtrans{Narrated `Aisha:One of the wives of Allah's Messenger (ﷺ) practiced I`tikaf with him while she had bleeding in between her periods and she would see red (blood) or yellowish traces, and sometimes we put a tray beneath her when she offered the prayer}}
\hadithdefcmd{bukhari}{2038}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَلِيِّ بْنِ الْحُسَيْنِ ـ رضى الله عنهما ـ أَنَّ صَفِيَّةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ‏.‏ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ حَدَّثَنَا هِشَامٌ أَخْبَرَنَا مَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ عَلِيِّ بْنِ الْحُسَيْنِ كَانَ النَّبِيُّ صلى الله عليه وسلم فِي الْمَسْجِدِ، وَعِنْدَهُ أَزْوَاجُهُ، فَرُحْنَ، فَقَالَ لِصَفِيَّةَ بِنْتِ حُيَىٍّ ‏"‏ لاَ تَعْجَلِي حَتَّى أَنْصَرِفَ مَعَكِ ‏"‏‏.‏ وَكَانَ بَيْتُهَا فِي دَارِ أُسَامَةَ، فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم مَعَهَا، فَلَقِيَهُ رَجُلاَنِ مِنَ الأَنْصَارِ، فَنَظَرَا إِلَى النَّبِيِّ صلى الله عليه وسلم ثُمَّ أَجَازَا وَقَالَ لَهُمَا النَّبِيُّ صلى الله عليه وسلم ‏"‏ تَعَالَيَا، إِنَّهَا صَفِيَّةُ بِنْتُ حُيَىٍّ ‏"‏‏.‏ قَالاَ سُبْحَانَ اللَّهِ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ إِنَّ الشَّيْطَانَ يَجْرِي مِنَ الإِنْسَانِ مَجْرَى الدَّمِ، وَإِنِّي خَشِيتُ أَنْ يُلْقِيَ فِي أَنْفُسِكُمَا شَيْئًا ‏"‏‏.‏\hadithno{2038}\hadithtrans{Narrated `Ali bin Al-Husain (from Safiya the Prophet's wife):The wives of the Prophet (ﷺ) were with him in the mosque (while he was in I`tikaf) and then they departed and the Prophet (ﷺ) said to Safiya bint Huyai, "Don't hurry up, for I shall accompany you," (and her dwelling was in the house of Usama). The Prophet (ﷺ) went out and in the meantime two Ansari men met him and they looked at the Prophet (ﷺ) and passed by. The Prophet (ﷺ) said to them, "Come here. She is (my wife) Safiya bint Huyai." They replied, "Subhan Allah, (How dare we think of evil) O Allah's Apostle! (we never expect anything bad from you)." The Prophet (ﷺ) replied, "Satan circulates in the human being as blood circulates in the body, and I was afraid lest Satan might insert an evil thought in your minds}}
\hadithdefcmd{bukhari}{2039}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ أَخْبَرَنِي أَخِي، عَنْ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ أَبِي عَتِيقٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَلِيِّ بْنِ الْحُسَيْنِ ـ رضى الله عنهما ـ أَنَّ صَفِيَّةَ، أَخْبَرَتْهُ‏.‏ حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ الزُّهْرِيَّ، يُخْبِرُ عَنْ عَلِيِّ بْنِ الْحُسَيْنِ، أَنَّ صَفِيَّةَ ـ رضى الله عنها ـ أَتَتِ النَّبِيَّ صلى الله عليه وسلم وَهْوَ مُعْتَكِفٌ، فَلَمَّا رَجَعَتْ مَشَى مَعَهَا، فَأَبْصَرَهُ رَجُلٌ مِنَ الأَنْصَارِ، فَلَمَّا أَبْصَرَهُ دَعَاهُ فَقَالَ ‏ "‏ تَعَالَ هِيَ صَفِيَّةُ ـ وَرُبَّمَا قَالَ سُفْيَانُ هَذِهِ صَفِيَّةُ ـ فَإِنَّ الشَّيْطَانَ يَجْرِي مِنَ ابْنِ آدَمَ مَجْرَى الدَّمِ ‏"‏‏.‏ قُلْتُ لِسُفْيَانَ أَتَتْهُ لَيْلاً قَالَ وَهَلْ هُوَ إِلاَّ لَيْلٌ\hadithno{2039}\hadithtrans{Narrated `Ali bin Al-Husain from Safiya:Safiya went to the Prophet (ﷺ) while he was in I`tikaf. When she returned, the Prophet (ﷺ) accompanied her walking. An Ansari man saw him. When the Prophet (ﷺ) noticed him, he called him and said, "Come here. She is Safiya. (Sufyan a sub-narrator perhaps said that the Prophet (ﷺ) had said, "This is Safiya"). And Satan circulates in the body of Adam's offspring as his blood circulates in it." (A sub-narrator asked Sufyan, "Did Safiya visit him at night?" He said, "Of course, at night)}}
\hadithdefcmd{bukhari}{2040}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُرَيْجٍ، عَنْ سُلَيْمَانَ الأَحْوَلِ، خَالِ ابْنِ أَبِي نَجِيحٍ عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ،‏.‏ قَالَ سُفْيَانُ وَحَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ،‏.‏ قَالَ وَأَظُنُّ أَنَّ ابْنَ أَبِي لَبِيدٍ، حَدَّثَنَا عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ قَالَ اعْتَكَفْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْعَشْرَ الأَوْسَطَ، فَلَمَّا كَانَ صَبِيحَةَ عِشْرِينَ نَقَلْنَا مَتَاعَنَا فَأَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ اعْتَكَفَ فَلْيَرْجِعْ إِلَى مُعْتَكَفِهِ فَإِنِّي رَأَيْتُ هَذِهِ اللَّيْلَةَ، وَرَأَيْتُنِي أَسْجُدُ فِي مَاءٍ وَطِينٍ ‏"‏‏.‏ فَلَمَّا رَجَعَ إِلَى مُعْتَكَفِهِ، وَهَاجَتِ السَّمَاءُ، فَمُطِرْنَا فَوَالَّذِي بَعَثَهُ بِالْحَقِّ لَقَدْ هَاجَتِ السَّمَاءُ مِنْ آخِرِ ذَلِكَ الْيَوْمِ، وَكَانَ الْمَسْجِدُ عَرِيشًا، فَلَقَدْ رَأَيْتُ عَلَى أَنْفِهِ وَأَرْنَبَتِهِ أَثَرَ الْمَاءِ وَالطِّينِ‏.‏\hadithno{2040}\hadithtrans{Narrated Abu Sa`id:We practiced I`tikaf with Allah's Messenger (ﷺ) in the middle ten days (of Ramadan). In the morning of the twentieth (of Ramadan) we shifted our baggage, but Allah's Messenger (ﷺ) came to us and said, "Whoever was in I`tikaf should return to his place of I`tikaf, for I saw (i.e. was informed about the date of) this Night (of Qadr) and saw myself prostrating in mud and water." When I returned to my place the sky was overcast with clouds and it rained. By Him Who sent Muhammad with the Truth, the sky was covered with clouds from the end of that day, and the mosque which was roofed with leafstalks of date palm trees (leaked with rain) and I saw the trace of mud and water over the nose of the Prophet (ﷺ) and its tip}}
\hadithdefcmd{bukhari}{2041}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا مُحَمَّدُ بْنُ فُضَيْلِ بْنِ غَزْوَانَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْتَكِفُ فِي كُلِّ رَمَضَانَ، وَإِذَا صَلَّى الْغَدَاةَ دَخَلَ مَكَانَهُ الَّذِي اعْتَكَفَ فِيهِ ـ قَالَ ـ فَاسْتَأْذَنَتْهُ عَائِشَةُ أَنْ تَعْتَكِفَ فَأَذِنَ لَهَا فَضَرَبَتْ فِيهِ قُبَّةً، فَسَمِعَتْ بِهَا حَفْصَةُ، فَضَرَبَتْ قُبَّةً، وَسَمِعَتْ زَيْنَبُ بِهَا، فَضَرَبَتْ قُبَّةً أُخْرَى، فَلَمَّا انْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الْغَدِ أَبْصَرَ أَرْبَعَ قِبَابٍ، فَقَالَ ‏"‏ مَا هَذَا ‏"‏‏.‏ فَأُخْبِرَ خَبَرَهُنَّ، فَقَالَ ‏"‏ مَا حَمَلَهُنَّ عَلَى هَذَا آلْبِرُّ انْزِعُوهَا فَلاَ أَرَاهَا ‏"‏‏.‏ فَنُزِعَتْ، فَلَمْ يَعْتَكِفْ فِي رَمَضَانَ حَتَّى اعْتَكَفَ فِي آخِرِ الْعَشْرِ مِنْ شَوَّالٍ‏.‏\hadithno{2041}\hadithtrans{Narrated `Amra bint `Abdur-Rahman from `Aisha:Allah's Messenger (ﷺ) used to practice I`tikaf every year in the month of Ramadan. And after offering the morning prayer, he used to enter the place of his I`tikaf. `Aisha asked his permission to let her practice I`tikaf and he allowed her, and so she pitched a tent in the mosque. When Hafsa heard of that, she also pitched a tent (for herself), and when Zainab heard of that, she too pitched another tent. When, in the morning, Allah's Messenger (ﷺ) had finished the morning prayer, he saw four tents and asked, "What is this?" He was informed about it. He then said, "What made them do this? Is it righteousness? Remove the tents, for I do not want to see them." So, the tents were removed. The Prophet (ﷺ) did not perform I`tikaf that year in the month of Ramadan, but did it in the last ten days of Shawwal}}
\hadithdefcmd{bukhari}{2042}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، عَنْ أَخِيهِ، عَنْ سُلَيْمَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عُمَرَ بْنِ الْخَطَّابِ ـ رضى الله عنه ـ أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ إِنِّي نَذَرْتُ فِي الْجَاهِلِيَّةِ أَنْ أَعْتَكِفَ لَيْلَةً فِي الْمَسْجِدِ الْحَرَامِ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَوْفِ نَذْرَكَ ‏"‏‏.‏ فَاعْتَكَفَ لَيْلَةً‏.‏\hadithno{2042}\hadithtrans{Narrated `Abdullah bin `Umar:`Umar bin Al-Khattab said, "O Allah's Messenger (ﷺ)! I vowed in the Pre-Islamic period to perform I`tikaf in Al-Masjid-al-Haram for one night." The Prophet (ﷺ) said, "Fulfill your vow." So, he performed I`tikaf for one night}}
\hadithdefcmd{bukhari}{2043}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ ـ رضى الله عنه ـ نَذَرَ فِي الْجَاهِلِيَّةِ أَنْ يَعْتَكِفَ فِي الْمَسْجِدِ الْحَرَامِ ـ قَالَ أُرَاهُ قَالَ ـ لَيْلَةً قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوْفِ بِنَذْرِكَ ‏"‏‏.‏\hadithno{2043}\hadithtrans{Narrated Ibn `Umar:that `Umar had vowed in the Pre-Islamic period to perform I`tikaf in Al-Masjid-al-Haram. (A subnarrator thinks that `Umar vowed to perform I`tikaf for one night.) Allah's Messenger (ﷺ) said to `Umar, "Fulfill your vow}}
\hadithdefcmd{bukhari}{2044}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو بَكْرٍ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَعْتَكِفُ فِي كُلِّ رَمَضَانَ عَشْرَةَ أَيَّامٍ، فَلَمَّا كَانَ الْعَامُ الَّذِي قُبِضَ فِيهِ اعْتَكَفَ عِشْرِينَ يَوْمًا‏.‏\hadithno{2044}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) used to perform I`tikaf every year in the month of Ramadan for ten days, and when it was the year of his death, he stayed in I`tikaf for twenty days}}
\hadithdefcmd{bukhari}{2045}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ أَبُو الْحَسَنِ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَتْنِي عَمْرَةُ بِنْتُ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ أَنْ يَعْتَكِفَ الْعَشْرَ الأَوَاخِرَ مِنْ رَمَضَانَ، فَاسْتَأْذَنَتْهُ عَائِشَةُ فَأَذِنَ لَهَا، وَسَأَلَتْ حَفْصَةُ عَائِشَةَ أَنْ تَسْتَأْذِنَ لَهَا فَفَعَلَتْ فَلَمَّا رَأَتْ ذَلِكَ زَيْنَبُ ابْنَةُ جَحْشٍ أَمَرَتْ بِبِنَاءٍ فَبُنِيَ لَهَا قَالَتْ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا صَلَّى انْصَرَفَ إِلَى بِنَائِهِ فَبَصُرَ بِالأَبْنِيَةِ فَقَالَ ‏"‏ مَا هَذَا ‏"‏‏.‏ قَالُوا بِنَاءُ عَائِشَةَ وَحَفْصَةَ وَزَيْنَبَ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ آلْبِرَّ أَرَدْنَ بِهَذَا مَا أَنَا بِمُعْتَكِفٍ ‏"‏‏.‏ فَرَجَعَ، فَلَمَّا أَفْطَرَ اعْتَكَفَ عَشْرًا مِنْ شَوَّالٍ‏.‏\hadithno{2045}\hadithtrans{Narrated `Amra bint `Abdur-Rahman from `Aisha:Allah's Messenger (ﷺ) mentioned that he would practice I`tikaf in the last ten days of Ramadan. `Aisha asked his permission to perform I`tikaf and he permitted her. Hafsa asked `Aisha to take his permission for her, and she did so. When Zainab bint Jahsh saw that, she ordered a tent to be pitched for her and it was pitched for her. Allah's Messenger (ﷺ) used to proceed to his tent after the prayer. So, he saw the tents and asked, "What is this?" He was told that those were the tents of Aisha, Hafsa, and Zainab. Allah's Apostle said, "Is it righteousness which they intended by doing so? I am not going to perform I`tikaf." So he returned home. When the fasting month was over, he performed I`tikaf for ten days in the month of Shawwal}}
\hadithdefcmd{bukhari}{2046}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا كَانَتْ تُرَجِّلُ النَّبِيَّ صلى الله عليه وسلم وَهِيَ حَائِضٌ وَهْوَ مُعْتَكِفٌ فِي الْمَسْجِدِ وَهْىَ فِي حُجْرَتِهَا، يُنَاوِلُهَا رَأْسَهُ‏.‏\hadithno{2046}\hadithtrans{Narrated `Urwa:Aisha during her menses used to comb and oil the hair of the Prophet (ﷺ) while he used to be in I`tikaf in the mosque. He would stretch out his head towards her while she was in her chamber}}
