% Auto-generated chapter 19 for nasai
% Hadiths in this chapter: 42

\hadithdefcmd{nasai}{1556}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ لأَهْلِ الْجَاهِلِيَّةِ يَوْمَانِ فِي كُلِّ سَنَةٍ يَلْعَبُونَ فِيهِمَا فَلَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ قَالَ ‏ "‏ كَانَ لَكُمْ يَوْمَانِ تَلْعَبُونَ فِيهِمَا وَقَدْ أَبْدَلَكُمُ اللَّهُ بِهِمَا خَيْرًا مِنْهُمَا يَوْمَ الْفِطْرِ وَيَوْمَ الأَضْحَى ‏"‏ ‏.‏\hadithno{1556}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"The people of the Jahiliyyah had two days each year when they would play. When the Messenger of Allah (ﷺ) came to Al-Madinah he said: 'You had two days when you would play, but Allah (SWT) has given Muslims something instead that is better than them: the day of Al-Fitr and the day of Al-Adha}}
\hadithdefcmd{nasai}{1557}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا أَبُو بِشْرٍ، عَنْ أَبِي عُمَيْرِ بْنِ أَنَسٍ، عَنْ عُمُومَةٍ، لَهُ أَنَّ قَوْمًا، رَأَوُا الْهِلاَلَ فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم فَأَمَرَهُمْ أَنْ يُفْطِرُوا بَعْدَ مَا ارْتَفَعَ النَّهَارُ وَأَنْ يَخْرُجُوا إِلَى الْعِيدِ مِنَ الْغَدِ ‏.‏\hadithno{1557}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Umair bin Anas from his paternal uncles, that :Some people saw the crescent moon and came to the Prophet (ﷺ), and he told them to break their fast after the sun has risen and to go out for 'Eid the (morning of the) following day}}
\hadithdefcmd{nasai}{1558}{أَخْبَرَنَا عَمْرُو بْنُ زُرَارَةَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ حَفْصَةَ، قَالَتْ كَانَتْ أُمُّ عَطِيَّةَ لاَ تَذْكُرُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِلاَّ قَالَتْ بِأَبَا ‏.‏ فَقُلْتُ أَسَمِعْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم يَذْكُرُ كَذَا وَكَذَا فَقَالَتْ نَعَمْ بِأَبَا قَالَ ‏ "‏ لِيَخْرُجِ الْعَوَاتِقُ وَذَوَاتُ الْخُدُورِ وَالْحُيَّضُ وَيَشْهَدْنَ الْعِيدَ وَدَعْوَةَ الْمُسْلِمِينَ وَلْيَعْتَزِلِ الْحُيَّضُ الْمُصَلَّى ‏"‏ ‏.‏\hadithno{1558}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hafsah said:"Umm 'Atiyyah would never mention the Messenger of Allah (ﷺ) without saying: 'May my father be ransomed for him.' I said: 'Did you hear the Messenger of Allah (ﷺ) say such-and-such?' And she said: 'Yes, may my father be ransomed for him.' He said: Let the adolescent girls, women in seclusion and menstruating women come out and attend the 'Eid and supplications of the Muslims, but let the menstruating women keep away from the prayer place}}
\hadithdefcmd{nasai}{1559}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، قَالَ لَقِيتُ أُمَّ عَطِيَّةَ فَقُلْتُ لَهَا هَلْ سَمِعْتِ مِنَ النَّبِيِّ صلى الله عليه وسلم وَكَانَتْ إِذَا ذَكَرَتْهُ قَالَتْ بِأَبَا قَالَ ‏ "‏ أَخْرِجُوا الْعَوَاتِقَ وَذَوَاتِ الْخُدُورِ فَيَشْهَدْنَ الْعِيدَ وَدَعْوَةَ الْمُسْلِمِينَ وَلْيَعْتَزِلِ الْحُيَّضُ مُصَلَّى النَّاسِ ‏"‏ ‏.‏\hadithno{1559}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Muhammad said:"I met Umm 'Atiyyah and said to her: 'Did you hear the Messenger of Allah (ﷺ) say (anything)?' When she mentioned him, she would say: 'May my father be ransomed for him.' (He said) 'Bring out the adolescent girls and the women in seclusion and let them witness goodness and the supplication of the Muslims, but let the menstruating women keep away from the place where the people pray}}
\hadithdefcmd{nasai}{1560}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، وَعَمْرُو بْنُ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ وَجَدَ عُمَرُ بْنُ الْخَطَّابِ - رضى الله تعالى عنه - حُلَّةً مِنْ إِسْتَبْرَقٍ بِالسُّوقِ فَأَخَذَهَا فَأَتَى بِهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ ابْتَعْ هَذِهِ فَتَجَمَّلْ بِهَا لِلْعِيدِ وَالْوَفْدِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا هَذِهِ لِبَاسُ مَنْ لاَ خَلاَقَ لَهُ أَوْ إِنَّمَا يَلْبَسُ هَذِهِ مَنْ لاَ خَلاَقَ لَهُ ‏"‏ ‏.‏ فَلَبِثَ عُمَرُ مَا شَاءَ اللَّهُ ثُمَّ أَرْسَلَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِجُبَّةِ دِيبَاجٍ فَأَقْبَلَ بِهَا حَتَّى جَاءَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ قُلْتَ ‏"‏ إِنَّمَا هَذِهِ لِبَاسُ مَنْ لاَ خَلاَقَ لَهُ ‏"‏ ‏.‏ ثُمَّ أَرْسَلْتَ إِلَىَّ بِهَذِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بِعْهَا وَتُصِبْ بِهَا حَاجَتَكَ ‏"‏ ‏.‏\hadithno{1560}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salim that:His father said: "Umar bin A-Khattab, may Allah be pleased with him, found a Hullah of Istibraq in the market. He took it and brought it to the Messenger of Allah (ﷺ) and said: 'O Messenger of Allah (ﷺ), why don't you buy this and adorn yourself with it for the two 'Eids and when (meeting) the delegations?' The Messenger of Allah (ﷺ) said: 'This is the clothing of one who has no share in the Hereafter,' or: 'This is worn by one who has no share in the Hereafter.' Then as much time passed as Allah (SWT) willed, then the Messenger of Allah (ﷺ) sent to Umar a garment made of Dibaj. He brought it to the Messenger of Allah (ﷺ) and said: 'O Messenger of Allah, you said that this is the clothing of one who has no share in the Hereafter, then you sent this to me?' The Messenger of Allah (ﷺ) said: 'Sell it and use the money for whatever you need}}
\hadithdefcmd{nasai}{1561}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنِ الأَشْعَثِ، عَنِ الأَسْوَدِ بْنِ هِلاَلٍ، عَنْ ثَعْلَبَةَ بْنِ زَهْدَمٍ، أَنَّ عَلِيًّا، اسْتَخْلَفَ أَبَا مَسْعُودٍ عَلَى النَّاسِ فَخَرَجَ يَوْمَ عِيدٍ فَقَالَ يَا أَيُّهَا النَّاسُ إِنَّهُ لَيْسَ مِنَ السُّنَّةِ أَنْ يُصَلَّى قَبْلَ الإِمَامِ ‏.‏\hadithno{1561}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Tha'labah bin Zahdam that:'Ali appointed Abu Mas'ud over the people, then went out on the day of 'Eid and said: 'O people, it is not part of the sunnah to pray before the imam}}
\hadithdefcmd{nasai}{1562}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي عِيدٍ قَبْلَ الْخُطْبَةِ بِغَيْرِ أَذَانٍ وَلاَ إِقَامَةٍ ‏.‏\hadithno{1562}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah (ﷺ) led us in praying on 'Eid before the Khutbah, with no Adhan and no Iqamah}}
\hadithdefcmd{nasai}{1563}{أَخْبَرَنَا مُحَمَّدُ بْنُ عُثْمَانَ، قَالَ حَدَّثَنَا بَهْزٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي زُبَيْدٌ، قَالَ سَمِعْتُ الشَّعْبِيَّ، يَقُولُ حَدَّثَنَا الْبَرَاءُ بْنُ عَازِبٍ، عِنْدَ سَارِيَةٍ مِنْ سَوَارِي الْمَسْجِدِ قَالَ خَطَبَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ النَّحْرِ فَقَالَ ‏"‏ إِنَّ أَوَّلَ مَا نَبْدَأُ بِهِ فِي يَوْمِنَا هَذَا أَنْ نُصَلِّيَ ثُمَّ نَذْبَحَ فَمَنْ فَعَلَ ذَلِكَ فَقَدْ أَصَابَ سُنَّتَنَا وَمَنْ ذَبَحَ قَبْلَ ذَلِكَ فَإِنَّمَا هُوَ لَحْمٌ يُقَدِّمُهُ لأَهْلِهِ ‏"‏ ‏.‏ فَذَبَحَ أَبُو بُرْدَةَ بْنُ نِيَارٍ فَقَالَ يَا رَسُولَ اللَّهِ عِنْدِي جَذَعَةٌ خَيْرٌ مِنْ مُسِنَّةٍ ‏.‏ قَالَ ‏"‏ اذْبَحْهَا وَلَنْ تُوفِيَ عَنْ أَحَدٍ بَعْدَكَ ‏"‏ ‏.‏\hadithno{1563}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Al-Bara' bin 'Azib narrated to us by one of the pillars of the masjid:"The Prophet (ﷺ) delivered a Khutbah on the day of An-Nahr and said: 'The first thing we start with on this day of ours is the prayer, then we offer sacrifice. Whoever does that, he has followed our sunnah, but whoever slaughtered (his sacrifice) before the (prayer), that is just meat that he gave to his family. Abu Burdah bin Niyar had slaughtered his sacrifice and he said: 'O Messenger of Allah (ﷺ), I have a Jadha'ah that is better than a Musinnah.' He said: 'Slaughter it (as a sacrifice), but that will not be sufficient for anyone else (as a sacrifice) after you}}
\hadithdefcmd{nasai}{1564}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ - رضى الله عنهما - كَانُوا يُصَلُّونَ الْعِيدَيْنِ قَبْلَ الْخُطْبَةِ ‏.‏\hadithno{1564}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah (ﷺ), Abu Bakr, 'Umar, may Allah (SWT) be pleased with them, used to offer the 'Eid prayer before the Khutbah}}
\hadithdefcmd{nasai}{1565}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُخْرِجُ الْعَنَزَةَ يَوْمَ الْفِطْرِ وَيَوْمَ الأَضْحَى يُرْكِزُهَا فَيُصَلِّي إِلَيْهَا ‏.‏\hadithno{1565}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that:The Messenger of Allah (ﷺ) used to take out an 'Anazah (a short spear) on the day of Al-Fitr and the day of Al-Adha, plant it in the ground, and pray facing toward it}}
\hadithdefcmd{nasai}{1566}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ سَعِيدٍ، عَنْ زُبَيْدٍ الأَيَامِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، ذَكَرَهُ عَنْ عُمَرَ بْنِ الْخَطَّابِ، - رضى الله عنه - قَالَ صَلاَةُ الأَضْحَى رَكْعَتَانِ وَصَلاَةُ الْفِطْرِ رَكْعَتَانِ وَصَلاَةُ الْمُسَافِرِ رَكْعَتَانِ وَصَلاَةُ الْجُمُعَةِ رَكْعَتَانِ تَمَامٌ لَيْسَ بِقَصْرٍ عَلَى لِسَانِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1566}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Umar bin Al-Khattab said:"The prayer of Al-Adha is two rak'ahs, the prayer of Al-Fitr is two rak'ahs, the prayer of the traveler is two rak'ahs and the jumu'ah prayer is two rak'ahs, complete and not shortened, upon the tongue of the Prophet (ﷺ)}}
\hadithdefcmd{nasai}{1567}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا سُفْيَانُ، قَالَ حَدَّثَنِي ضَمْرَةُ بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، قَالَ خَرَجَ عُمَرُ - رضى الله عنه - يَوْمَ عِيدٍ فَسَأَلَ أَبَا وَاقِدٍ اللَّيْثِيَّ بِأَىِّ شَىْءٍ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ فِي هَذَا الْيَوْمِ فَقَالَ بِـ ‏\{‏ ق ‏\}‏ وَ\{‏ اقْتَرَبَتْ ‏\}‏ ‏.‏\hadithno{1567}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Ubaidullah bin 'Abdullah said:"Umar, may Allah (SWT) be pleased with him, went out on the day of 'Eid and asked Abu Waqid Al-Laithi: 'What did the Prophet (ﷺ) recite on this day?' He said: 'Qaf' and '(The Hour) has drawn near}}
\hadithdefcmd{nasai}{1568}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، عَنْ أَبِيهِ، عَنْ حَبِيبِ بْنِ سَالِمٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي الْعِيدَيْنِ وَيَوْمِ الْجُمُعَةِ بِـ ‏\{‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏\}‏ وَ\{‏ هَلْ أَتَاكَ حَدِيثُ الْغَاشِيَةِ ‏\}‏ وَرُبَّمَا اجْتَمَعَا فِي يَوْمٍ وَاحِدٍ فَيَقْرَأُ بِهِمَا ‏.‏\hadithno{1568}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from An-Nu'man bin Bashir that:The Messenger of Allah (ﷺ) used to recite on the two 'Eids and on Friday: "GLorify the Name of Your Lord, the Most High" and "Has there come to you the narration of The Overwhelming?" Sometimes the two ('Eid and Jumu'ah) occurred on the same day, and he would recite them (these two Surahs)}}
\hadithdefcmd{nasai}{1569}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ أَيُّوبَ، يُخْبِرُ عَنْ عَطَاءٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ أَشْهَدُ أَنِّي شَهِدْتُ الْعِيدَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَدَأَ بِالصَّلاَةِ قَبْلَ الْخُطْبَةِ ثُمَّ خَطَبَ ‏.‏\hadithno{1569}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Ata said:"I heard Ibn 'Abbas say: 'I bear witness that I attended 'Eid with the Messenger of Allah (ﷺ); he started with the prayer before the Khutbah, then he delivered the Khutbah}}
\hadithdefcmd{nasai}{1570}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ مَنْصُورٍ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ النَّحْرِ بَعْدَ الصَّلاَةِ ‏.‏\hadithno{1570}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Bara' bin 'Azib said:"The Messenger of Allah (ﷺ) addressed us on the day of An-Nahr after the prayer." (Sahih)}}
\hadithdefcmd{nasai}{1571}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ أَيُّوبَ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ عَبْدِ اللَّهِ بْنِ السَّائِبِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى الْعِيدَ قَالَ ‏ "‏ مَنْ أَحَبَّ أَنْ يَنْصَرِفَ فَلْيَنْصَرِفْ وَمَنْ أَحَبَّ أَنْ يُقِيمَ لِلْخُطْبَةِ فَلْيُقِمْ ‏"‏ ‏.‏\hadithno{1571}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin As-SA'ib that:The Prophet (ﷺ) offered the 'Eid prayer and said: 'Whoever would like to leave, let him leave, and whoever would like to stay for the Khutbah, let him stay}}
\hadithdefcmd{nasai}{1572}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ إِيَادٍ، عَنْ أَبِيهِ، عَنْ أَبِي رِمْثَةَ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ وَعَلَيْهِ بُرْدَانِ أَخْضَرَانِ ‏.‏\hadithno{1572}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Rimthah said:"I saw the Prophet (ﷺ) delivering the Khutbah, wearing two green Burds}}
\hadithdefcmd{nasai}{1573}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، قَالَ أَخْبَرَنِي إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ أَخِيهِ، عَنْ أَبِي كَاهِلٍ الأَحْمَسِيِّ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ عَلَى نَاقَةٍ وَحَبَشِيٌّ آخِذٌ بِخِطَامِ النَّاقَةِ ‏.‏\hadithno{1573}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Khalil Al-Ahmasi said:"I saw the Prophet (ﷺ) delivering the Khutbah atop a she-camel and an Ethiopian was holding on to the camel's reins}}
\hadithdefcmd{nasai}{1574}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكٍ، قَالَ سَأَلْتُ جَابِرًا أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ قَائِمًا قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ قَائِمًا ثُمَّ يَقْعُدُ قَعْدَةً ثُمَّ يَقُومُ ‏.‏\hadithno{1574}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Simak said:"I asked Jabir: 'Did the Messenger of Allah (ﷺ) deliver the Khutbah standing?' He said: 'The Messenger of Allah (ﷺ) used to deliver the Khutbah standing, then he would sit for a while, then stand up again}}
\hadithdefcmd{nasai}{1575}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، قَالَ حَدَّثَنَا عَطَاءٌ، عَنْ جَابِرٍ، قَالَ شَهِدْتُ الصَّلاَةَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي يَوْمِ عِيدٍ فَبَدَأَ بِالصَّلاَةِ قَبْلَ الْخُطْبَةِ بِغَيْرِ أَذَانٍ وَلاَ إِقَامَةٍ فَلَمَّا قَضَى الصَّلاَةَ قَامَ مُتَوَكِّئًا عَلَى بِلاَلٍ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَوَعَظَ النَّاسَ وَذَكَّرَهُمْ وَحَثَّهُمْ عَلَى طَاعَتِهِ ثُمَّ مَالَ وَمَضَى إِلَى النِّسَاءِ وَمَعَهُ بِلاَلٌ فَأَمَرَهُنَّ بِتَقْوَى اللَّهِ وَوَعَظَهُنَّ وَذَكَّرَهُنَّ وَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ حَثَّهُنَّ عَلَى طَاعَتِهِ ثُمَّ قَالَ ‏"‏ تَصَدَّقْنَ فَإِنَّ أَكْثَرَكُنَّ حَطَبُ جَهَنَّمَ ‏"‏ ‏.‏ فَقَالَتِ امْرَأَةٌ مِنْ سَفِلَةِ النِّسَاءِ سَفْعَاءُ الْخَدَّيْنِ بِمَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ تُكْثِرْنَ الشَّكَاةَ وَتَكْفُرْنَ الْعَشِيرَ ‏"‏ ‏.‏ فَجَعَلْنَ يَنْزِعْنَ قَلاَئِدَهُنَّ وَأَقْرُطَهُنَّ وَخَوَاتِيمَهُنَّ يَقْذِفْنَهُ فِي ثَوْبِ بِلاَلٍ يَتَصَدَّقْنَ بِهِ ‏.‏\hadithno{1575}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"I attended the prayer with the Messenger of Allah (ﷺ) on the day of 'Eid. He started with the prayer before the Khutbah, with no Adhan and no Iqamah. When he finished the prayer, he stood leaning on Bilal, and he praised and glorified Allah (SWT) and exhorted the people, reminding them and urging them to obey Allah (SWT). Then he moved away and went to the women, and Bilal was with him. He commanded them to fear Allah (SWT) and exhorted them and reminded them. He praised and glorified Allah, then he urged them to obey Allah, then he said: 'Give charity, for most of you are the fuel of Hell.' A lowly woman with dark cheeks said: 'Why, O Messenger of Allah?' He said: 'You complain a great deal and are ungrateful to your husbands.' They started taking off their necklaces, earrings and rings, throwing them into Bilal's garment, giving them in charity}}
\hadithdefcmd{nasai}{1576}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ دَاوُدَ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَخْرُجُ يَوْمَ الْفِطْرِ وَيَوْمَ الأَضْحَى إِلَى الْمُصَلَّى فَيُصَلِّي بِالنَّاسِ فَإِذَا جَلَسَ فِي الثَّانِيَةِ وَسَلَّمَ قَامَ فَاسْتَقْبَلَ النَّاسَ بِوَجْهِهِ وَالنَّاسُ جُلُوسٌ فَإِنْ كَانَتْ لَهُ حَاجَةٌ يُرِيدُ أَنْ يَبْعَثَ بَعْثًا ذَكَرَهُ لِلنَّاسِ وَإِلاَّ أَمَرَ النَّاسَ بِالصَّدَقَةِ قَالَ ‏ "‏ تَصَدَّقُوا ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ فَكَانَ مِنْ أَكْثَرِ مَنْ يَتَصَدَّقُ النِّسَاءُ ‏.‏\hadithno{1576}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that:The Messenger of Allah (ﷺ) used to go out to the prayer place on the day of Al-Fitr and the day of Al-Adha and lead the people in prayer. When he sat during the second rak'ah and said the taslim, he stood up and turned to face the people while the people were sitting. If he needed to mention something concerning the dispatch of an army he would tell the people, otherwise he would enjoin the people to give charity. He said: "Give charity" three times, and among those who gave the most charity were the women}}
\hadithdefcmd{nasai}{1577}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قُلْتَ لِصَاحِبِكَ أَنْصِتْ وَالإِمَامُ يَخْطُبُ فَقَدْ لَغَوْتَ ‏"‏ ‏.‏\hadithno{1577}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that:The Messenger of Allah (ﷺ) said: "If you say to your companion: 'Be quiet and listen' when the imam is delivering the Khutbah, you have engaged in idle speech}}
\hadithdefcmd{nasai}{1578}{أَخْبَرَنَا عُتْبَةُ بْنُ عَبْدِ اللَّهِ، قَالَ أَنْبَأَنَا ابْنُ الْمُبَارَكِ، عَنْ سُفْيَانَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي خُطْبَتِهِ يَحْمَدُ اللَّهَ وَيُثْنِي عَلَيْهِ بِمَا هُوَ أَهْلُهُ ثُمَّ يَقُولُ ‏"‏ مَنْ يَهْدِهِ اللَّهُ فَلاَ مُضِلَّ لَهُ وَمَنْ يُضْلِلْهُ فَلاَ هَادِيَ لَهُ إِنَّ أَصْدَقَ الْحَدِيثِ كِتَابُ اللَّهِ وَأَحْسَنَ الْهَدْىِ هَدْىُ مُحَمَّدٍ وَشَرَّ الأُمُورِ مُحْدَثَاتُهَا وَكُلَّ مُحْدَثَةٍ بِدْعَةٌ وَكُلَّ بِدْعَةٍ ضَلاَلَةٌ وَكُلَّ ضَلاَلَةٍ فِي النَّارِ ‏"‏ ‏.‏ ثُمَّ يَقُولُ ‏"‏ بُعِثْتُ أَنَا وَالسَّاعَةُ كَهَاتَيْنِ ‏"‏ ‏.‏ وَكَانَ إِذَا ذَكَرَ السَّاعَةَ احْمَرَّتْ وَجْنَتَاهُ وَعَلاَ صَوْتُهُ وَاشْتَدَّ غَضَبُهُ كَأَنَّهُ نَذِيرُ جَيْشٍ يَقُولُ ‏"‏ صَبَّحَكُمْ مَسَّاكُمْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ مَنْ تَرَكَ مَالاً فَلأَهْلِهِ وَمَنْ تَرَكَ دَيْنًا أَوْ ضِيَاعًا فَإِلَىَّ أَوْ عَلَىَّ وَأَنَا أَوْلَى بِالْمُؤْمِنِينَ ‏"‏ ‏.‏\hadithno{1578}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"In his Khutbah the Messenger of Allah (ﷺ) used to praise Allah as He deserves to be praised, then he would say: 'Whomsoever Allah (SWT) guides, none can lead him astray, and whomsoever Allah sends astray, none can guide. The truest of word is the Book of Allah and best of guidance is the guidance of Muhammad. The worst of things are those that are newly invented; every newly-invented thing is an innovation and every innovation is going astray, and every going astray is in the Fire.' Then he said: 'The Hour and I have been sent like these two.' Whenever he mentioned the Hour, his cheeks would turn red, and he would raise his voice and become angry, as if he were warning of an approaching army and saying: 'An army is coming to attack you in the morning, or in the evening!' (Then he said): 'Whoever leaves behind wealth, it is for his family, and whoever leaves behind a debt or dependents, then these are my responsibility, and I am the most entitled to take care of the believers}}
\hadithdefcmd{nasai}{1579}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا دَاوُدُ بْنُ قَيْسٍ، قَالَ حَدَّثَنِي عِيَاضٌ، عَنْ أَبِي سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَخْرُجُ يَوْمَ الْعِيدِ فَيُصَلِّي رَكْعَتَيْنِ ثُمَّ يَخْطُبُ فَيَأْمُرُ بِالصَّدَقَةِ فَيَكُونُ أَكْثَرَ مَنْ يَتَصَدَّقُ النِّسَاءُ فَإِنْ كَانَتْ لَهُ حَاجَةٌ أَوْ أَرَادَ أَنْ يَبْعَثَ بَعْثًا تَكَلَّمَ وَإِلاَّ رَجَعَ ‏.‏\hadithno{1579}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Sa'eed that:The Messenger of Allah (ﷺ) used to go out on the day of 'Eid and pray two rak'ahs, then he would deliver the Khutbah and enjoin giving charity, and the ones who gave most charity were the women. If he had any exigency or he needed to send an army he would speak of that, if not, he would go back}}
\hadithdefcmd{nasai}{1580}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ هَارُونَ - قَالَ أَنْبَأَنَا حُمَيْدٌ، عَنِ الْحَسَنِ، أَنَّ ابْنَ عَبَّاسٍ، خَطَبَ بِالْبَصْرَةِ فَقَالَ أَدُّوا زَكَاةَ صَوْمِكُمْ فَجَعَلَ النَّاسُ يَنْظُرُ بَعْضُهُمْ إِلَى بَعْضٍ فَقَالَ مَنْ هَا هُنَا مِنْ أَهْلِ الْمَدِينَةِ قُومُوا إِلَى إِخْوَانِكُمْ فَعَلِّمُوهُمْ فَإِنَّهُمْ لاَ يَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَرَضَ صَدَقَةَ الْفِطْرِ عَلَى الصَّغِيرِ وَالْكَبِيرِ وَالْحُرِّ وَالْعَبْدِ وَالذَّكَرِ وَالأُنْثَى نِصْفَ صَاعٍ مِنْ بُرٍّ أَوْ صَاعًا مِنْ تَمْرٍ أَوْ شَعِيرٍ ‏.‏\hadithno{1580}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Al-Hasan that :Ibn 'Abbas gave a Khutbah in Al-Basrah and said: "Pay the zakah of your fasting." The people started looking at one another. He said: "Whoever there is here from the people of Al-Madinah, get up and teach your brothers, for they do not know that the Messenger of Allah (ﷺ) enjoined sadaqat al-fitr on the young and the old, the free and the slave, the male and the female; half a sa' of wheat or a sa' of dried dates or barley}}
\hadithdefcmd{nasai}{1581}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ مَنْصُورٍ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ النَّحْرِ بَعْدَ الصَّلاَةِ ثُمَّ قَالَ ‏"‏ مَنْ صَلَّى صَلاَتَنَا وَنَسَكَ نُسُكَنَا فَقَدْ أَصَابَ النُّسُكَ وَمَنْ نَسَكَ قَبْلَ الصَّلاَةِ فَتِلْكَ شَاةُ لَحْمٍ ‏"‏ ‏.‏ فَقَالَ أَبُو بُرْدَةَ بْنُ نِيَارٍ يَا رَسُولَ اللَّهِ وَاللَّهِ لَقَدْ نَسَكْتُ قَبْلَ أَنْ أَخْرُجَ إِلَى الصَّلاَةِ عَرَفْتُ أَنَّ الْيَوْمَ يَوْمُ أَكْلٍ وَشُرْبٍ فَتَعَجَّلْتُ فَأَكَلْتُ وَأَطْعَمْتُ أَهْلِي وَجِيرَانِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تِلْكَ شَاةُ لَحْمٍ ‏"‏ ‏.‏ قَالَ فَإِنَّ عِنْدِي جَذَعَةً خَيْرٌ مِنْ شَاتَىْ لَحْمٍ فَهَلْ تُجْزِي عَنِّي قَالَ ‏"‏ نَعَمْ وَلَنْ تُجْزِيَ عَنْ أَحَدٍ بَعْدَكَ ‏"‏ ‏.‏\hadithno{1581}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Bara' said:"The Messenger of Allah (ﷺ) addressed us on the day of An-Nahr after the prayer, then he said: 'Whoever prays and offers the sacrifice as we do, his ritual is complete, and whoever offers the sacrifice before the prayer, that is just ordinary meat.' Abu Burdah bin Niyar said: 'O Messenger of Allah (ﷺ), by Allah, we offered the sacrifice before I came out to the prayer, because I knew that today is the day of eating and drinking, so I hastened to do it and I ate of it and fed it to my family and neighbors.' The Messenger of Allah (ﷺ) said: 'That is just a sheep for meat.' He said: 'I have a jadha'ah that is better than two meaty sheep, will that be sufficient (as a sacrifice) for me?' He said: 'Yes, but it will not be sufficient for anyone after you}}
\hadithdefcmd{nasai}{1582}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كُنْتُ أُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم فَكَانَتْ صَلاَتُهُ قَصْدًا وَخُطْبَتُهُ قَصْدًا ‏.‏\hadithno{1582}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir bin Samurah said:"I used to pray with the Prophet (ﷺ) and his prayer was moderate in length and his Khutbah was moderate in length}}
\hadithdefcmd{nasai}{1583}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَخْطُبُ قَائِمًا ثُمَّ يَقْعُدُ قَعْدَةً لاَ يَتَكَلَّمُ فِيهَا ثُمَّ قَامَ فَخَطَبَ خُطْبَةً أُخْرَى فَمَنْ خَبَّرَكَ أَنَّ النَّبِيَّ صلى الله عليه وسلم خَطَبَ قَاعِدًا فَلاَ تُصَدِّقْهُ ‏.‏\hadithno{1583}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir bin Samurah said:"I saw the Messenger of Allah (ﷺ) delivering the Khutbah standing up, then he sat down for a while and did not speak, then he stood up and delivered another Khutbah. Whoever tells you that the Prophet (ﷺ) delivered a Khutbah sitting do not believe him}}
\hadithdefcmd{nasai}{1584}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ قَائِمًا ثُمَّ يَجْلِسُ ثُمَّ يَقُومُ وَيَقْرَأُ آيَاتٍ وَيَذْكُرُ اللَّهَ وَكَانَتْ خُطْبَتُهُ قَصْدًا وَصَلاَتُهُ قَصْدًا ‏.‏\hadithno{1584}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir bin Samurah said:"The Prophet (ﷺ) used to deliver the Khutbah standing, then he would sit down, then he would stand up and recite some verses and remember Allah (SWT). And his Khutbah was moderate in length, and his prayer was moderate in length}}
\hadithdefcmd{nasai}{1585}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبُو تُمَيْلَةَ، عَنِ الْحُسَيْنِ بْنِ وَاقِدٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ بَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ يَخْطُبُ إِذْ أَقْبَلَ الْحَسَنُ وَالْحُسَيْنُ عَلَيْهِمَا السَّلاَمُ عَلَيْهِمَا قَمِيصَانِ أَحْمَرَانِ يَمْشِيَانِ وَيَعْثُرَانِ فَنَزَلَ وَحَمَلَهُمَا فَقَالَ ‏"‏ صَدَقَ اللَّهُ ‏\{‏ إِنَّمَا أَمْوَالُكُمْ وَأَوْلاَدُكُمْ فِتْنَةٌ ‏\}‏ رَأَيْتُ هَذَيْنِ يَمْشِيَانِ وَيَعْثُرَانِ فِي قَمِيصَيْهِمَا فَلَمْ أَصْبِرْ حَتَّى نَزَلْتُ فَحَمَلْتُهُمَا ‏"‏ ‏.‏\hadithno{1585}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Buraidah that:His father said: "While the Messenger of Allah (ﷺ) was on the minbar, Al-Hasan and Al-Husain came,wearing red shirts, walking and stumbling. He came down and picked them up, then said: 'Allah has spoken the truth: Your wealth and your children are only a trial.' I saw these two walking and stumbling in their shirts, and I could not be patient until I went down and picked them up}}
\hadithdefcmd{nasai}{1586}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَابِسٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، قَالَ لَهُ رَجُلٌ شَهِدْتَ الْخُرُوجَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ وَلَوْلاَ مَكَانِي مِنْهُ مَا شَهِدْتُهُ يَعْنِي مِنْ صِغَرِهِ أَتَى الْعَلَمَ الَّذِي عِنْدَ دَارِ كَثِيرِ بْنِ الصَّلْتِ فَصَلَّى ثُمَّ خَطَبَ ثُمَّ أَتَى النِّسَاءَ فَوَعَظَهُنَّ وَذَكَّرَهُنَّ وَأَمَرَهُنَّ أَنْ يَتَصَدَّقْنَ فَجَعَلَتِ الْمَرْأَةُ تُهْوِي بِيَدِهَا إِلَى حَلَقِهَا تُلْقِي فِي ثَوْبِ بِلاَلٍ ‏.‏\hadithno{1586}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abdur-Rahman bin 'Abbas said:"I heard 'Abbas when a man said to him: 'Did you go out (to the Eid prayer) with the Messenger of Allah?' He said: 'Yes, and were it not for my kinship (position) with him I would not have done so'"-meaning due to him being so young- "He (the Prophet (ﷺ)) went to the mark near the house of Kathir bin As-Salt and prayed, then delivered a Khutbah. Then he went to the women. He exhorted them and reminded them and told them to give charity. So a woman would bring her hand near her neck and take off her necklace and put it in the garment of Bilal}}
\hadithdefcmd{nasai}{1587}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ الأَشَجُّ، قَالَ حَدَّثَنَا ابْنُ إِدْرِيسَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ عَدِيٍّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ يَوْمَ الْعِيدِ فَصَلَّى رَكْعَتَيْنِ لَمْ يُصَلِّ قَبْلَهَا وَلاَ بَعْدَهَا ‏.‏\hadithno{1587}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas that:The Prophet (ﷺ) went out on the day of 'Eid and prayed two rak'ahs, and he did not pray before or after them}}
\hadithdefcmd{nasai}{1588}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ وَرْدَانَ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ أَضْحَى وَانْكَفَأَ إِلَى كَبْشَيْنِ أَمْلَحَيْنِ فَذَبَحَهُمَا ‏.‏\hadithno{1588}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:"The Messenger of Allah (ﷺ) addressed us on the day of Al-Adha and went to two black and white rams and slaughtered them}}
\hadithdefcmd{nasai}{1589}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، عَنِ اللَّيْثِ، عَنْ كَثِيرِ بْنِ فَرْقَدٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَذْبَحُ أَوْ يَنْحَرُ بِالْمُصَلَّى ‏.‏\hadithno{1589}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Nafi that:Abdullah (bin Umar) told him that the Messenger of Allah (ﷺ) used to offer sacrifice in the prayer place}}
\hadithdefcmd{nasai}{1590}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، عَنْ جَرِيرٍ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، قُلْتُ عَنْ أَبِيهِ، قَالَ نَعَمْ عَنْ حَبِيبِ بْنِ سَالِمٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي الْجُمُعَةِ وَالْعِيدِ بِـ ‏\{‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏\}‏ وَ ‏\{‏ هَلْ أَتَاكَ حَدِيثُ الْغَاشِيَةِ ‏\}‏ وَإِذَا اجْتَمَعَ الْجُمُعَةُ وَالْعِيدُ فِي يَوْمٍ قَرَأَ بِهِمَا ‏.‏\hadithno{1590}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that An-Nu'man bin Bashir said:"The Messenger of Allah (ﷺ) used to recite: 'Glorify the Name of your Lord, the Most High' and "Has there come to you the narration of The Overwhelming?', on Friday and on 'Eid, and when Friday and 'Eid converged, he would recite them both}}
\hadithdefcmd{nasai}{1591}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا إِسْرَائِيلُ، عَنْ عُثْمَانَ بْنِ الْمُغِيرَةِ، عَنْ إِيَاسِ بْنِ أَبِي رَمْلَةَ، قَالَ سَمِعْتُ مُعَاوِيَةَ، سَأَلَ زَيْدَ بْنَ أَرْقَمَ أَشَهِدْتَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عِيدَيْنِ قَالَ نَعَمْ صَلَّى الْعِيدَ مِنْ أَوَّلِ النَّهَارِ ثُمَّ رَخَّصَ فِي الْجُمُعَةِ ‏.‏\hadithno{1591}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Iyas bin Abi Ramlah said:"I heard Mu'awiyah asking Zaid bin Arqam: 'Did you attend two 'Eids with the Messenger of Allah (ﷺ)?' He said: 'Yes; he prayed 'Eid at the beginning of the day then he granted a concession with regard to jumu'ah}}
\hadithdefcmd{nasai}{1592}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنِي وَهْبُ بْنُ كَيْسَانَ، قَالَ اجْتَمَعَ عِيدَانِ عَلَى عَهْدِ ابْنِ الزُّبَيْرِ فَأَخَّرَ الْخُرُوجَ حَتَّى تَعَالَى النَّهَارُ ثُمَّ خَرَجَ فَخَطَبَ فَأَطَالَ الْخُطْبَةَ ثُمَّ نَزَلَ فَصَلَّى وَلَمْ يُصَلِّ لِلنَّاسِ يَوْمَئِذٍ الْجُمُعَةَ ‏.‏ فَذُكِرَ ذَلِكَ لاِبْنِ عَبَّاسٍ فَقَالَ أَصَابَ السُّنَّةَ ‏.‏\hadithno{1592}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Wahb bin Kaisan said:"Eid and Jumu'ah fell on the same day during the time of Ibn Az-Zubair, so he delayed going out until the sun had risen quite high. Then he went out and delivered a Khutbah, and he made the Khutbah lengthy. Then he came down and prayed, and he did not lead the people in praying jumu'ah that day. Mention of that was made to Ibn 'Abbas and he said: 'He has followed the sunnah}}
\hadithdefcmd{nasai}{1593}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَلَيْهَا وَعِنْدَهَا جَارِيَتَانِ تَضْرِبَانِ بِدُفَّيْنِ فَانْتَهَرَهُمَا أَبُو بَكْرٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ دَعْهُنَّ فَإِنَّ لِكُلِّ قَوْمٍ عِيدًا ‏"‏ ‏.‏\hadithno{1593}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that:The Messenger of Allah (ﷺ) entered upon her and there were two girls with her who were beating the duff. Abu Bakr scolded them, but the Prophet (ﷺ) said: "Leave them, for every people has an 'Eid}}
\hadithdefcmd{nasai}{1594}{أَخْبَرَنَا مُحَمَّدُ بْنُ آدَمَ، عَنْ عَبْدَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَ السُّودَانُ يَلْعَبُونَ بَيْنَ يَدَىِ النَّبِيِّ صلى الله عليه وسلم فِي يَوْمِ عِيدٍ فَدَعَانِي فَكُنْتُ أَطَّلِعُ إِلَيْهِمْ مِنْ فَوْقِ عَاتِقِهِ فَمَا زِلْتُ أَنْظُرُ إِلَيْهِمْ حَتَّى كُنْتُ أَنَا الَّتِي انْصَرَفْتُ ‏.‏\hadithno{1594}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The black people came and played in front of the Prophet (ﷺ) on the day of 'Eid. He called me and I watched them from over his shoulder, and I continued to watch them until I was the one who moved away}}
\hadithdefcmd{nasai}{1595}{أَخْبَرَنَا عَلِيُّ بْنُ خَشْرَمٍ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتُرُنِي بِرِدَائِهِ وَأَنَا أَنْظُرُ إِلَى الْحَبَشَةِ يَلْعَبُونَ فِي الْمَسْجِدِ حَتَّى أَكُونَ أَنَا أَسْأَمُ فَاقْدُرُوا قَدْرَ الْجَارِيَةِ الْحَدِيثَةِ السِّنِّ الْحَرِيصَةِ عَلَى اللَّهْوِ ‏.‏\hadithno{1595}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"I remember the Messenger of Allah (ﷺ) covering me with his Rida' while I was watching the Ethiopians playing in the masjid, until I got bored. So you should understand the keenness of young girls to play}}
\hadithdefcmd{nasai}{1596}{أَخْبَرَنَا إِسْحَاقُ بْنُ مُوسَى، قَالَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ دَخَلَ عُمَرُ وَالْحَبَشَةُ يَلْعَبُونَ فِي الْمَسْجِدِ فَزَجَرَهُمْ عُمَرُ رضى الله عنه فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دَعْهُمْ يَا عُمَرُ فَإِنَّمَا هُمْ بَنُو أَرْفِدَةَ ‏"‏ ‏.‏\hadithno{1596}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"Umar came in when the Ethiopians were playing in the masjid. Umar, may Allah (SWT) be pleased with him, rebuked them, but the Messenger of Allah (ﷺ) said: 'Let them be there, O Umar, for they are Banu Arfidah}}
\hadithdefcmd{nasai}{1597}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصِ بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، أَنَّهُ حَدَّثَهُ أَنَّ عَائِشَةَ حَدَّثَتْهُ أَنَّ أَبَا بَكْرٍ الصِّدِّيقَ دَخَلَ عَلَيْهَا وَعِنْدَهَا جَارِيَتَانِ تَضْرِبَانِ بِالدُّفِّ وَتُغَنِّيَانِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم مُسَجًّى بِثَوْبِهِ - وَقَالَ مَرَّةً أُخْرَى مُتَسَجٍّ ثَوْبَهُ - فَكَشَفَ عَنْ وَجْهِهِ فَقَالَ ‏ "‏ دَعْهُمَا يَا أَبَا بَكْرٍ إِنَّهَا أَيَّامُ عِيدٍ ‏"‏ ‏.‏ وَهُنَّ أَيَّامُ مِنًى وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَئِذٍ بِالْمَدِينَةِ ‏.‏\hadithno{1597}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Urwah that he narrated from Aishah that Abu Bakr As-Siddiq :Entered upon her and there were two girls with her beating the duff and singing, and the Messenger of Allah (ﷺ) was covered with his garment. He uncovered his face and said: "Let them be there, O Abu Bakr, for these are the days of 'Eid." Those were the days of Mina and the Messenger of Allah (ﷺ) was in Al-Madinah on that day}}
