% Auto-generated chapter 46 for tirmidhi
% Hadiths in this chapter: 23

\hadithdefcmd{tirmidhi}{2927}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَخْبَرَنَا يَحْيَى بْنُ سَعِيدٍ الأُمَوِيُّ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَطِّعُ قِرَاءَتَهُ يَقْرَأُ ‏(‏الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ ‏)‏ ثُمَّ يَقِفُ ‏(‏ الرَّحْمَنِ الرَّحِيمِ ‏)‏ ثُمَّ يَقِفُ وَكَانَ يَقْرَؤُهَا ‏(‏مَلِكِ يَوْمِ الدِّينِ ‏)‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَبِهِ يَقْرَأُ أَبُو عُبَيْدٍ وَيَخْتَارُهُ هَكَذَا رَوَى يَحْيَى بْنُ سَعِيدٍ الأُمَوِيُّ وَغَيْرُهُ عَنِ ابْنِ جُرَيْجٍ عَنِ ابْنِ أَبِي مُلَيْكَةَ عَنْ أُمِّ سَلَمَةَ وَلَيْسَ إِسْنَادُهُ بِمُتَّصِلٍ لأَنَّ اللَّيْثَ بْنَ سَعْدٍ رَوَى هَذَا الْحَدِيثَ عَنِ ابْنِ أَبِي مُلَيْكَةَ عَنْ يَعْلَى بْنِ مَمْلَكٍ عَنْ أُمِّ سَلَمَةَ أَنَّهَا وَصَفَتْ قِرَاءَةَ النَّبِيِّ صلى الله عليه وسلم حَرْفًا حَرْفًا وَحَدِيثُ اللَّيْثِ أَصَحُّ وَلَيْسَ فِي حَدِيثِ اللَّيْثِ وَكَانَ يَقْرَأُ ‏(‏مَلِكِ يَوْمِ الدِّينِ ‏)‏ ‏.‏\hadithno{2927}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Abi Mulaikah:that Umm Salamah said: "The Messenger of Allah (ﷺ) would separate recitation reciting: 'Al-Hamdulillahi Rabbil-'Alamin' then he would stop. 'Ar-Rahmanir-Rahim' then he would stop. And he would recite it: 'Maliki Yawmid-Din}}
\hadithdefcmd{tirmidhi}{2928}{حَدَّثَنَا أَبُو بَكْرٍ، مُحَمَّدُ بْنُ أَبَانَ قَالَ حَدَّثَنَا أَيُّوبُ بْنُ سُوَيْدٍ الرَّمْلِيُّ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ - وَأُرَاهُ قَالَ - وَعُثْمَانَ كَانُوا يَقْرَءُونَ ‏(‏مَالِكِ يَوْمِ الدِّينِ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ الزُّهْرِيِّ عَنْ أَنَسِ بْنِ مَالِكٍ إِلاَّ مِنْ حَدِيثِ هَذَا الشَّيْخِ أَيُّوبَ بْنِ سُوَيْدٍ الرَّمْلِيِّ ‏.‏ وَقَدْ رَوَى بَعْضُ أَصْحَابِ الزُّهْرِيِّ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ أَنَّ النَّبِيَّ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ كَانُوا يَقْرَءُونَ ‏(‏مَالِكِ يَوْمِ الدِّينِ ‏)‏ ‏.‏ وَقَدْ رَوَى عَبْدُ الرَّزَّاقِ عَنْ مَعْمَرٍ عَنِ الزُّهْرِيِّ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ أَنَّ النَّبِيَّ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ كَانُوا يَقْرَءُونَ ‏(‏مَالِكِ يَوْمِ الدِّينِ ‏)‏‏.‏\hadithno{2928}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas:that the Prophet (ﷺ), Abu Bakr, and 'Umar - and I think he said - and 'Uthman would recite: "Maaliki Yawmid-Din (1:)}}
\hadithdefcmd{tirmidhi}{2929}{حَدَّثَنَا أَبُو كُرَيْبٍ، قَالَ حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنْ أَبِي عَلِيِّ ابْنِ يَزِيدَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَرَأَ‏(‏أَنَّ النَّفْسَ بِالنَّفْسِ وَالْعَيْنُ بِالْعَيْنِ ‏)‏ حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ يُونُسَ بْنِ يَزِيدَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ وَأَبُو عَلِيِّ بْنُ يَزِيدَ هُوَ أَخُو يُونُسَ بْنِ يَزِيدَ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ قَالَ مُحَمَّدٌ تَفَرَّدَ ابْنُ الْمُبَارَكِ بِهَذَا الْحَدِيثِ عَنْ يُونُسَ بْنِ يَزِيدَ وَهَكَذَا قَرَأَ أَبُو عُبَيْدٍ ‏(‏ وَالْعَيْنُ بِالْعَيْنِ ‏)‏ اتِّبَاعًا لِهَذَا الْحَدِيثِ ‏.‏\hadithno{2929}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas bin Malik:"The Prophet (ﷺ) would recite: 'Anin-nafsu Bin-Nafsi Wal-'Ainu Bil-'Aini'" (From 5:)}}
\hadithdefcmd{tirmidhi}{2930}{حَدَّثَنَا أَبُو كُرَيْبٍ، قَالَ حَدَّثَنَا رِشْدِينُ بْنُ سَعْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ زِيَادِ بْنِ أَنْعُمَ، عَنْ عُتْبَةَ بْنِ حُمَيْدٍ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَرَأَْ ‏(‏هَلْ تَسْتَطِيعُ رَبَّكَ ‏)‏ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ رِشْدِينَ وَلَيْسَ إِسْنَادُهُ بِالْقَوِيِّ ‏.‏ وَرِشْدِينُ بْنُ سَعْدٍ وَالإِفْرِيقِيُّ يُضَعَّفَانِ فِي الْحَدِيثِ ‏.‏\hadithno{2930}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'adh bin Jabal:"The Prophet (ﷺ) would recite: 'Hal Tastati'u Rabbak}}
\hadithdefcmd{tirmidhi}{2931}{حَدَّثَنَا الْحُسَيْنُ بْنُ مُحَمَّدٍ الْبَصْرِيُّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَؤُهَا ‏(‏إِنَّهُ عَمِلَ غَيْرَ صَالِحٍ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ قَدْ رَوَاهُ غَيْرُ وَاحِدٍ عَنْ ثَابِتٍ الْبُنَانِيِّ نَحْوَ هَذَا وَهُوَ حَدِيثُ ثَابِتٍ الْبُنَانِيِّ وَرُوِيَ هَذَا الْحَدِيثُ أَيْضًا عَنْ شَهْرِ بْنِ حَوْشَبٍ عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ ‏.‏ وَسَمِعْتُ عَبْدَ بْنَ حُمَيْدٍ يَقُولُ أَسْمَاءُ بِنْتُ يَزِيدَ هِيَ أُمُّ سَلَمَةَ الأَنْصَارِيَّةُ ‏.‏ قَالَ أَبُو عِيسَى كِلاَ الْحَدِيثَيْنِ عِنْدِي وَاحِدٌ وَقَدْ رَوَى شَهْرُ بْنُ حَوْشَبٍ غَيْرَ حَدِيثٍ عَنْ أُمِّ سَلَمَةَ الأَنْصَارِيَّةِ وَهِيَ أَسْمَاءُ بِنْتُ يَزِيدَ وَقَدْ رُوِيَ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوُ هَذَا ‏.‏\hadithno{2931}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm Salamah:"The Prophet (ﷺ) would recite: 'Innahu 'Amila Ghaira Salih}}
\hadithdefcmd{tirmidhi}{2932}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، قَالَ حَدَّثَنَا وَكِيعٌ وَحَبَّانُ بْنُ هِلاَلٍ، قَالاَ حَدَّثَنَا هَارُونُ النَّحْوِيُّ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أُمِّ سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ هَذِهِ الآيَةَ ‏:‏ ‏(‏إِنَّهُ عَمِلَ غَيْرَ صَالِحٍ ‏)‏‏.‏\hadithno{2932}\hadithgrade{Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm Salamah:"The Messenger of Allah (ﷺ) recited this Ayah: 'Innahu 'Amalun Ghairu Salih'" (11:)}}
\hadithdefcmd{tirmidhi}{2933}{حَدَّثَنَا أَبُو بَكْرِ بْنُ نَافِعٍ، - الْبَصْرِيٌّ - قَالَ حَدَّثَنَا أُمَيَّةُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا أَبُو الْجَارِيَةِ الْعَبْدِيُّ، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَرَأَْ ‏(قَد ‏بَلَغْتَ مِنْ لَدُنِّي عُذْرًا‏)‏ مُثَقَّلَةً ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأُمَيَّةُ بْنُ خَالِدٍ ثِقَةٌ وَأَبُو الْجَارِيَةِ الْعَبْدِيُّ شَيْخٌ مَجْهُولٌ وَ لاَ يُعْرَفُ اسْمُهُ ‏.‏\hadithno{2933}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:from 'Ubayy bin Ka'b, that the Prophet (ﷺ) would recite: "Qad Balaghta Min Ladunni 'Udhra" (18:76) with heaviness (Muthaqqalah - meaning with Tashdid on the Nun in "Ladunni)}}
\hadithdefcmd{tirmidhi}{2934}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، قَالَ حَدَّثَنَا مُعَلَّى بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ دِينَارٍ، عَنْ سَعْدِ بْنِ أَوْسٍ، عَنْ مِصْدَعٍ أَبِي يَحْيَى، عَنِ ابْنِ عَبَّاسٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَرَأَ ‏(‏فِي عَيْنٍ حَمِئَةٍ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَالصَّحِيحُ مَا رُوِيَ عَنِ ابْنِ عَبَّاسٍ قِرَاءَتُهُ ‏.‏ وَيُرْوَى أَنَّ ابْنَ عَبَّاسٍ وَعَمْرَو بْنَ الْعَاصِي اخْتَلَفَا فِي قِرَاءَةِ هَذِهِ الآيَةِ وَارْتَفَعَا إِلَى كَعْبِ الأَحْبَارِ فِي ذَلِكَ فَلَوْ كَانَتْ عِنْدَهُ رِوَايَةٌ عَنِ النَّبِيِّ صلى الله عليه وسلم لاَسْتَغْنَى بِرِوَايَتِهِ وَلَمْ يَحْتَجْ إِلَى كَعْبٍ ‏.‏\hadithno{2934}\hadithgrade{Ahmad Muhammad Shakir: Sahih Matn; Al-Albani: Sahih Matn; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:from Ubay bin Ka'b that the Prophet (ﷺ) recited: "Fi 'Ainin Hami'ah" (18:)}}
\hadithdefcmd{tirmidhi}{2935}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، قَالَ حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، عَنْ سُلَيْمَانَ الأَعْمَشِ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، قَالَ لَمَّا كَانَ يَوْمُ بَدْرٍ ظَهَرَتِ الرُّومُ عَلَى فَارِسَ فَأَعْجَبَ ذَلِكَ الْمُؤْمِنِينَ فَنَزَلَتْ ‏(‏ الم * غُلِبَتِ الرُّومُ ‏)‏ إِلَى قَوْلِهِ ‏(‏يَفْرَحُ الْمُؤْمِنُونَ ‏)‏ قَالَ فَفْرَحَ الْمُؤْمِنُونَ بِظُهُورِ الرُّومِ عَلَى فَارِسَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَيُقْرَأُ غَلَبَتْ وَغُلِبَتْ يَقُولُ كَانَتْ غُلِبَتْ ثُمَّ غَلَبَتْ هَكَذَا قَرَأَ نَصْرُ بْنُ عَلِيٍّ غَلَبَتْ ‏.‏\hadithno{2935}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Sa'eed:"On the Day of (the battle of) Badr, the Romans had a victory over the Persians. So the believers were pleased with that, then the following was revealed: Alif Lam Mim. The Romans have been defeated..." up to His saying: '...the believers will rejoice. (30:1-4)" He said: "So the believers were happy with the victory of the Romans over the Persians}}
\hadithdefcmd{tirmidhi}{2936}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، قَالَ حَدَّثَنَا نُعَيْمُ بْنُ مَيْسَرَةَ النَّحْوِيُّ، عَنْ فُضَيْلِ بْنِ مَرْزُوقٍ، عَنْ عَطِيَّةَ الْعَوْفِيِّ، عَنِ ابْنِ عُمَرَ، أَنَّهُ قَرَأَ عَلَى النَّبِيِّ صلى الله عليه وسلمَ ‏(‏خَلَقَكُمْ مِنْ ضعْفٍ ‏)‏ فَقَالَ مِنْ ضُعْفٍ ‏.‏ حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ فُضَيْلِ بْنِ مَرْزُوقٍ، عَنْ عَطِيَّةَ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ فُضَيْلِ بْنِ مَرْزُوقٍ ‏.‏\hadithno{2936}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Umar:that he recited the following to the Prophet (ﷺ): "Who created you in the weakness (Min Da'f)" So he said: "Min Du'f" (Another chain) with similar in meaning}}
\hadithdefcmd{tirmidhi}{2937}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقْرَأُ ‏(‏فَهَلْ مِنْ مُدَّكِرٍ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2937}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah bin Mas'ud:that the Messenger of Allah (ﷺ) would recite: "Then is there anyone who would remember? (54:)}}
\hadithdefcmd{tirmidhi}{2938}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ الْبَصْرِيُّ ، قَالَ حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ الضُّبَعِيُّ، عَنْ هَارُونَ الأَعْوَرِ، عَنْ بُدَيْلِ بْنِ مَيْسَرَةَ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ ‏(‏فَرُوحٌ وَ رَيْحَانٌ وَ جَنَّةُ نَعِيمٍ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ هَارُونَ الأَعْوَرِ ‏.‏\hadithno{2938}\hadithgrade{Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Aishah:that the Prophet (ﷺ) would recite: "Furuhun Wa Raihanun Wa Jannatu Na'im (56:)}}
\hadithdefcmd{tirmidhi}{2939}{حَدَّثَنَا هَنَّادٌ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ قَدِمْنَا الشَّامَ فَأَتَانَا أَبُو الدَّرْدَاءِ فَقَالَ أَفِيكُمْ أَحَدٌ يَقْرَأُ عَلَىَّ قِرَاءَةَ عَبْدِ اللَّهِ قَالَ فَأَشَارُوا إِلَىَّ فَقُلْتُ نَعَمْ أَنَا ‏.‏ قَالَ كَيْفَ سَمِعْتَ عَبْدَ اللَّهِ يَقْرَأُ هَذِهِ الآيَةَ ‏(وَاللَّيْلِ إِذَا يَغْشَى ‏)‏ قَالَ قُلْتُ سَمِعْتُهُ يَقْرَؤُهَا ‏(‏‏وَاللَّيْلِ إِذَا يَغْشَى ‏)‏ ‏(‏وَالذَّكَر وَالأُنْثَى ‏)‏ فَقَالَ أَبُو الدَّرْدَاءِ وَأَنَا وَاللَّهِ هَكَذَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَؤُهَا وَهَؤُلاَءِ يُرِيدُونَنِي أَنْ أَقْرَأَهَا‏(‏وَمَا خَلَقَ ‏)‏ فَلاَ أُتَابِعُهُمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهَكَذَا قِرَاءَةُ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ‏(‏ وَاللَّيْلِ إِذَا يَغْشَى * وَالنَّهَارِ إِذَا تَجَلَّى * وَالذَّكَرِ وَالأُنْثَى ‏)‏‏.‏\hadithno{2939}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Alqamah:"We arrived in Ash-Sham and we went to Abu Ad-Darda. So he said: 'Is there any among you who can recite for me according to the recitation of 'Abdullah?'" He said: "They pointed to me, so I said: 'Yes, [I (can recite)].' He said: 'How did you hear 'Abdullah recite this Ayah: By the night as it envelopes?'" He said: "I said: 'I heard him recite it: "Wal-Laili Idha Yaghsha, Wadh-Dhakari Wal-Untha" Abu Ad-Darda said: 'Me too, By Allah, this is how I heard the Messenger of Allah (ﷺ) reciting it. But these people want me to recite it: Wa Ma Khalaqa but I will not follow them}}
\hadithdefcmd{tirmidhi}{2940}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ أَقْرَأَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم‏:‏‏(‏ إِنِّي أَنَا الرَّزَّاقُ ذُو الْقُوَّةِ الْمَتِينُ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2940}\hadithgrade{Ahmad Muhammad Shakir: Sahih Matn; Al-Albani: Sahih Matn; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Abdullah:"The Messenger of Allah (ﷺ) recited to me: "Indeed Allah is the Provider, The Possessor of power, the Firm." (51:)}}
\hadithdefcmd{tirmidhi}{2941}{حَدَّثَنَا أَبُو زُرْعَةَ، وَالْفَضْلُ بْنُ أَبِي طَالِبٍ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا الْحَسَنُ بْنُ بِشْرٍ، عَنِ الْحَكَمِ بْنِ عَبْدِ الْمَلِكِ، عَنْ قَتَادَةَ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَرَأَ‏:‏ ‏(‏وَتَرَى النَّاسَ سُكَارَى وَمَا هُمْ بِسُكَارَى ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَهَكَذَا رَوَى الْحَكَمُ بْنُ عَبْدِ الْمَلِكِ عَنْ قَتَادَةَ ‏.‏ وَلاَ نَعْرِفُ لِقَتَادَةَ سَمَاعًا مِنْ أَحَدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ مِنْ أَنَسٍ وَأَبِي الطُّفَيْلِ ‏.‏ وَهَذَا عِنْدِي حَدِيثٌ مُخْتَصَرٌ إِنَّمَا يُرْوَى عَنْ قَتَادَةَ عَنِ الْحَسَنِ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي السَّفَرِ فَقَرَأَ ‏:‏ ‏(‏يَا أَيُّهَا النَّاسُ اتَّقُوا رَبَّكُمْ ‏)‏ الْحَدِيثَ بِطُولِهِ وَحَدِيثُ الْحَكَمِ بْنِ عَبْدِ الْمَلِكِ عِنْدِي مُخْتَصَرٌ مِنْ هَذَا الْحَدِيثِ ‏.‏\hadithno{2941}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Imran bin Husain:"The Prophet (ﷺ) recited: You shall see mankind as if in a drunken state, yet they will not be in a drunken state. (22:)}}
\hadithdefcmd{tirmidhi}{2942}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَخْبَرَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بِئْسَمَا لأَحَدِهِمْ أَوْ لأَحَدِكُمْ أَنْ يَقُولَ نَسِيتُ آيَةَ كَيْتَ وَكَيْتَ بَلْ هُوَ نُسِّيَ فَاسْتَذْكِرُوا الْقُرْآنَ فَوَالَّذِي نَفْسِي بِيَدِهِ لَهُوَ أَشَدُّ تَفَصِّيًا مِنْ صُدُورِ الرِّجَالِ مِنَ النَّعَمِ مِنْ عُقُلِهِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2942}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah:that the Prophet (ﷺ) said: "How horrible it is for one of them - or - one of you to say: "I have forgotten such and such Ayah,' rather he was made to forget. So be mindful of the Qur'an, for - by the One in Whose Hand is my soul - it escapes from men's hearts faster than a camel from its fetter}}
\hadithdefcmd{tirmidhi}{2943}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، وَعَبْدِ الرَّحْمَنِ بْنِ عَبْدٍ الْقَارِيِّ، أَخْبَرَاهُ أَنَّهُمَا، سَمِعَا عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ مَرَرْتُ بِهِشَامِ بْنِ حَكِيمِ بْنِ حِزَامٍ وَهُوَ يَقْرَأُ سُورَةَ الْفُرْقَانِ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْتَمَعْتُ قِرَاءَتَهُ فَإِذَا هُوَ يَقْرَأُ عَلَى حُرُوفٍ كَثِيرَةٍ لَمْ يُقْرِئْنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَكِدْتُ أُسَاوِرُهُ فِي الصَّلاَةِ فَنَظَرْتُهُ حَتَّى سَلَّمَ فَلَمَّا سَلَّمَ لَبَّبْتُهُ بِرِدَائِهِ فَقُلْتُ مَنْ أَقْرَأَكَ هَذِهِ السُّورَةَ الَّتِي سَمِعْتُكَ تَقْرَؤُهَا فَقَالَ أَقْرَأَنِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏.‏ قُلْتُ لَهُ كَذَبْتَ وَاللَّهِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَهُوَ أَقْرَأَنِي هَذِهِ السُّورَةَ الَّتِي تَقْرَؤُهَا ‏.‏ فَانْطَلَقْتُ أَقُودُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي سَمِعْتُ هَذَا يَقْرَأُ سُورَةَ الْفُرْقَانِ عَلَى حُرُوفٍ لَمْ تُقْرِئْنِيهَا وَأَنْتَ أَقْرَأْتَنِي سُورَةَ الْفُرْقَانِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَرْسِلْهُ يَا عُمَرُ اقْرَأْ يَا هِشَامُ ‏"‏ ‏.‏ فَقَرَأَ عَلَيْهِ الْقِرَاءَةَ الَّتِي سَمِعْتُهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏ ‏.‏ ثُمَّ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اقْرَأْ يَا عُمَرُ ‏"‏ ‏.‏ فَقَرَأْتُ بِالْقِرَاءَةَ الَّتِي أَقْرَأَنِي النَّبِيُّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏ ‏.‏ ثُمَّ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ هَذَا الْقُرْآنَ أُنْزِلَ عَلَى سَبْعَةِ أَحْرُفٍ فَاقْرَءُوا مَا تَيَسَّرَ مِنْهُ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى مَالِكُ بْنُ أَنَسٍ عَنِ الزُّهْرِيِّ بِهَذَا الإِسْنَادِ نَحْوَهُ إِلاَّ أَنَّهُ لَمْ يَذْكُرْ فِيهِ الْمِسْوَرَ بْنَ مَخْرَمَةَ ‏.‏\hadithno{2943}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Umar bin Al-Khattab:"I passed by Hisham bin Hakim bin Hizam while he was reciting Surat Al-Furqan during the lifetime of the Messenger of Allah (ﷺ). I listened to his recitation and noticed that he recited it in several different ways, which the Messenger of Allah (ﷺ) had not taught me. I was about to jump over him during his Salat, but waited until he said the Salam. When he had said the Salam, I strangled him with his upper-garment and said: 'Who taught you this Surah which I heard you reciting?' He said: 'The Messenger of Allah (ﷺ) taught it to me.' I said to him: 'You lie! By Allah! The Messenger of Allah (ﷺ) taught me this Surah which you were reciting.' I dragged him to the Messenger of Allah (ﷺ) and said: 'O Messenger of Allah! I heard this one reciting Surat Al-Furqan in a manner different from how you taught me, and you taught me Surat Al-Furqan.' The Prophet (ﷺ) said: 'Release him O 'Umar! Recite O Hisham.' So he recited it for him as I had heard him reciting. Then the Prophet (ﷺ) said to me: 'This is how it was revealed.' Then the Prophet (ﷺ) said to me, 'Recite O 'Umar.' So I recited the recitation which the Prophet (ﷺ) taught me. The Prophet (ﷺ) said: 'This is how it was revealed.' Then the Prophet (ﷺ) said 'Indeed this Qur'an was revealed in seven modes, so recite of it what is easier for you}}
\hadithdefcmd{tirmidhi}{2944}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ عَاصِمٍ، عَنْ زِرِّ بْنِ حُبَيْشٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ لَقِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم جِبْرِيلَ فَقَالَ ‏ "‏ يَا جِبْرِيلُ إِنِّي بُعِثْتُ إِلَى أُمَّةٍ أُمِّيِّينَ مِنْهُمُ الْعَجُوزُ وَالشَّيْخُ الْكَبِيرُ وَالْغُلاَمُ وَالْجَارِيَةُ وَالرَّجُلُ الَّذِي لَمْ يَقْرَأْ كِتَابًا قَطُّ ‏"‏ ‏.‏ قَالَ يَا مُحَمَّدُ إِنَّ الْقُرْآنَ أُنْزِلَ عَلَى سَبْعَةِ أَحْرُفٍ ‏.‏ وَفِي الْبَابِ عَنْ عُمَرَ وَحُذَيْفَةَ بْنِ الْيَمَانِ وَأُمِّ أَيُّوبَ وَهِيَ امْرَأَةُ أَبِي أَيُّوبَ الأَنْصَارِيِّ وَسَمُرَةَ وَابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ وَأَبِي جُهَيْمِ بْنِ الْحَارِثِ بْنِ الصِّمَّةِ وَعَمْرِو بْنِ الْعَاصِ وَأَبِي بَكْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أُبَىِّ بْنِ كَعْبٍ ‏.‏\hadithno{2944}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ubayy bin Ka'b:"The Messenger of Allah (ﷺ) met Jibra'il and said: 'O Jibra'il! I have been sent to an illiterate nation among whom are the elderly woman, the old man, the boy and the girl, and the man who cannot read a book at all.' He said: 'O Muhammad! Indeed the Qur'an was revealed in seven modes}}
\hadithdefcmd{tirmidhi}{2945}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ نَفَّسَ عَنْ أَخِيهِ كُرْبَةً مِنْ كُرَبِ الدُّنْيَا نَفَّسَ اللَّهُ عَنْهُ كُرْبَةً مِنْ كُرَبِ يَوْمِ الْقِيَامَةِ وَمَنْ سَتَرَ مُسْلِمًا سَتَرَهُ اللَّهُ فِي الدُّنْيَا وَالآخِرَةِ وَمَنْ يَسَّرَ عَلَى مُعْسِرٍ يَسَّرَ اللَّهُ عَلَيْهِ فِي الدُّنْيَا وَالآخِرَةِ وَاللَّهُ فِي عَوْنِ الْعَبْدِ مَا كَانَ الْعَبْدُ فِي عَوْنِ أَخِيهِ وَمَنْ سَلَكَ طَرِيقًا يَلْتَمِسُ فِيهِ عِلْمًا سَهَّلَ اللَّهُ لَهُ طَرِيقًا إِلَى الْجَنَّةِ وَمَا قَعَدَ قَوْمٌ فِي مَسْجِدٍ يَتْلُونَ كِتَابَ اللَّهِ وَيَتَدَارَسُونَهُ بَيْنَهُمْ إِلاَّ نَزَلَتْ عَلَيْهِمُ السَّكِينَةُ وَغَشِيَتْهُمُ الرَّحْمَةُ وَحَفَّتْهُمُ الْمَلاَئِكَةُ وَمَنْ أَبْطَأَ بِهِ عَمَلُهُ لَمْ يُسْرِعْ بِهِ نَسَبُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رَوَى غَيْرُ وَاحِدٍ عَنِ الأَعْمَشِ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ هَذَا الْحَدِيثِ وَرَوَى أَسْبَاطُ بْنُ مُحَمَّدٍ عَنِ الأَعْمَشِ قَالَ حُدِّثْتُ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ فَذَكَرَ بَعْضَ هَذَا الْحَدِيثِ ‏.‏\hadithno{2945}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Whoever alleviates a burden among the burdens of the world for his brother, Allah alleviates a burden among the burdens of the Day of Judgement for him. And whoever covers (the faults) of a Muslim, Allah covers him in the world and in the Hereafter. And whoever makes things easy for one in dire straits, Allah makes things easy for him in the world and the Hereafter. Allah is helping as long as the (His) Slave is helping his brother. And whoever takes a path to gain knowledge, Allah makes a path to Paradise easy for him. And no people sit in a Masjid reciting Allah's Book, studying it among themselves, except that tranquility descends upon them and they are enveloped in the mercy, and surrounded by the angels. And whoever is slow in his deeds, his lineage shall not speed him up}}
\hadithdefcmd{tirmidhi}{2946}{حَدَّثَنَا عُبَيْدُ بْنُ أَسْبَاطِ بْنِ مُحَمَّدٍ الْقُرَشِيُّ، قَالَ حَدَّثَنَا أَبِي، عَنْ مُطَرِّفٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي بُرْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ فِي كَمْ أَقْرَأُ الْقُرْآنَ قَالَ ‏"‏ اخْتِمْهُ فِي شَهْرٍ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ اخْتِمْهُ فِي عِشْرِينَ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ اخْتِمْهُ فِي خَمْسَةَ عَشَرَ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ اخْتِمْهُ فِي عَشْرٍ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ اخْتِمْهُ فِي خَمْسٍ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ ‏.‏ قَالَ فَمَا رَخَّصَ لِي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ يُسْتَغْرَبُ مِنْ حَدِيثِ أَبِي بُرْدَةَ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَرُوِيَ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لَمْ يَفْقَهْ مَنْ قَرَأَ الْقُرْآنَ فِي أَقَلَّ مِنْ ثَلاَثٍ ‏"‏ ‏.‏ وَرُوِيَ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ ‏"‏ اقْرَإِ الْقُرْآنَ فِي أَرْبَعِينَ ‏"‏ ‏.‏ قَالَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ وَلاَ نُحِبُّ لِلرَّجُلِ أَنْ يَأْتِيَ عَلَيْهِ أَكْثَرُ مِنْ أَرْبَعِينَ يَوْمًا وَلَمْ يَقْرَإِ الْقُرْآنَ لِهَذَا الْحَدِيثِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لاَ يُقْرَأُ الْقُرْآنُ فِي أَقَلَّ مِنْ ثَلاَثٍ لِلْحَدِيثِ الَّذِي رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَرَخَّصَ فِيهِ بَعْضُ أَهْلِ الْعِلْمِ وَرُوِيَ عَنْ عُثْمَانَ بْنِ عَفَّانَ أَنَّهُ كَانَ يَقْرَأُ الْقُرْآنَ فِي رَكْعَةٍ يُوتِرُ بِهَا وَرُوِيَ عَنْ سَعِيدِ بْنِ جُبَيْرٍ أَنَّهُ قَرَأَ الْقُرْآنَ فِي رَكْعَةٍ فِي الْكَعْبَةِ وَالتَّرْتِيلُ فِي الْقِرَاءَةِ أَحَبُّ إِلَى أَهْلِ الْعِلْمِ ‏.‏\hadithno{2946}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdullah bin 'Amr :"I said: 'O Messenger of Allah! In how much time may I recite the Qur'an?' He said: 'Complete it in one month.' I said: 'I am able to do more than that.' He said: 'Then complete it in twenty (days).' I said: 'I am able to do more than that.' He said: 'Then finish it in fifteen (days).' I said: 'I am able to do more than that.' He said: 'Finish it in ten (days).' I said: 'I am able to do more than that.' He said: 'Finish it in five (days).' I said: 'I am able to do more than that.'" He ('Abdullah bin 'Amr) said: "But he did not permit me}}
\hadithdefcmd{tirmidhi}{2947}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي النَّضْرِ الْبَغْدَادِيُّ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ، هُوَ ابْنُ شَقِيقٍ عَنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنْ سِمَاكِ بْنِ الْفَضْلِ، عَنْ وَهْبِ بْنِ مُنَبِّهٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ ‏ "‏ اقْرَإِ الْقُرْآنَ فِي أَرْبَعِينَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَ قَدْ رَوَى بَعْضُهُمْ عَنْ مَعْمَرٍ عَنْ سِمَاكِ بْنِ الْفَضْلِ عَنْ وَهْبِ بْنِ مُنَبِّهٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ عَبْدَ اللَّهِ بْنَ عَمْرٍو أَنْ يَقْرَأَ الْقُرْآنَ فِي أَرْبَعِينَ ‏.‏\hadithno{2947}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Abdullah bin 'Amr:that the Prophet (ﷺ) said: "Recite the Qur'an in forty (days)}}
\hadithdefcmd{tirmidhi}{2948}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، قَالَ حَدَّثَنَا الْهَيْثَمُ بْنُ الرَّبِيعِ، قَالَ حَدَّثَنَا صَالِحٌ الْمُرِّيُّ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَىُّ الْعَمَلِ أَحَبُّ إِلَى اللَّهِ قَالَ ‏"‏ الْحَالُّ الْمُرْتَحِلُ ‏"‏ ‏.‏ قَالَ وَمَا الْحَالُّ الْمُرْتَحِلُ قَالَ ‏"‏ الَّذِي يَضْرِبُ مِنْ أَوَّلِ الْقُرْآنِ إِلَى آخِرِهِ كُلَّمَا حَلَّ ارْتَحَلَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ ابْنِ عَبَّاسٍ إِلاَّ مِنْ هَذَا الْوَجْهِ وَإِسْنَادُهُ لَيْسَ بِالْقَوِيِّ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا صَالِحٌ الْمُرِّيُّ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِمَعْنَاهُ وَلَمْ يَذْكُرْ فِيهِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا عِنْدِي أَصَحُّ مِنْ حَدِيثِ نَصْرِ بْنِ عَلِيٍّ عَنِ الْهَيْثَمِ بْنِ الرَّبِيعِ ‏.‏\hadithno{2948}\hadithgrade{Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:"A man said 'O Messenger of Allah! Which deed is most virtuous to Allah?' He said: 'Al-Hallul-Murtahil'' He said: 'What is Al-Hallul-Murtahil?' He said: 'The one who recites from the beginning of the Qur'an to the end of it, every time he sets out (on a trip)}}
\hadithdefcmd{tirmidhi}{2949}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَمْ يَفْقَهْ مَنْ قَرَأَ الْقُرْآنَ فِي أَقَلَّ مِنْ ثَلاَثٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{2949}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Abdullah bin 'Amr:that the Prophet (ﷺ) said: "He who recites the Qur'an in less than three (days), he does not understand it}}
