% Auto-generated chapter 8 for malik
% Hadiths in this chapter: 39

\hadithdefcmd{malik}{287}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةُ الْجَمَاعَةِ تَفْضُلُ صَلاَةَ الْفَذِّ بِسَبْعٍ وَعِشْرِينَ دَرَجَةً ‏"‏ ‏.‏\hadithno{287}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "Prayer in congregation is better than the prayer of a man by himself by twenty-seven degrees}}
\hadithdefcmd{malik}{288}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةُ الْجَمَاعَةِ أَفْضَلُ مِنْ صَلاَةِ أَحَدِكُمْ وَحْدَهُ بِخَمْسَةٍ وَعِشْرِينَ جُزْءًا ‏"‏ ‏.‏\hadithno{288}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Said ibn al- Musayyab from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Prayer in congregation is better than the prayer of one of you on his own by twenty-five parts}}
\hadithdefcmd{malik}{289}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَقَدْ هَمَمْتُ أَنْ آمُرَ بِحَطَبٍ فَيُحْطَبَ ثُمَّ آمُرَ بِالصَّلاَةِ فَيُؤَذَّنَ لَهَا ثُمَّ آمُرَ رَجُلاً فَيَؤُمَّ النَّاسَ ثُمَّ أُخَالِفَ إِلَى رِجَالٍ فَأُحَرِّقَ عَلَيْهِمْ بُيُوتَهُمْ\hadithno{289}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'zZinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "By Him in whose hand myself is! I had in mind to order firewood to be collected, then to order the prayer to be called, and to appoint a man to lead the people in prayer, and then to come up behind certain men and burn their houses down about them! By Him in whose hand myself is! If one of them knew that he would find a meaty bone or two good legs of meat, he would be present at isha}}
\hadithdefcmd{malik}{290}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ بُسْرِ بْنِ سَعِيدٍ، أَنَّ زَيْدَ بْنَ ثَابِتٍ، قَالَ أَفْضَلُ الصَّلاَةِ صَلاَتُكُمْ فِي بُيُوتِكُمْ إِلاَّ صَلاَةَ الْمَكْتُوبَةِ ‏.‏\hadithno{290}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu'n-Nadr, the mawla of Umar ibn Ubaydullah from Yusr ibn Said that Zayd ibn Thabit said, "The most excellent prayer is your prayer in your house, except for the prescribed prayers}}
\hadithdefcmd{malik}{291}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حَرْمَلَةَ الأَسْلَمِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَنَا وَبَيْنَ الْمُنَافِقِينَ شُهُودُ الْعِشَاءِ وَالصُّبْحِ لاَ يَسْتَطِيعُونَهُمَا ‏"‏ ‏.‏ أَوْ نَحْوَ هَذَا ‏.‏\hadithno{291}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn Harmala al- Aslami from Said ibn al-Musayyab that the Messenger of Allah, may Allah bless him and grant him peace, said, "What separates us from the hypocrites is being present at isha and subh. They cannot do it," or words to that effect}}
\hadithdefcmd{malik}{292}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَمَا رَجُلٌ يَمْشِي بِطَرِيقٍ إِذْ وَجَدَ غُصْنَ شَوْكٍ عَلَى الطَّرِيقِ فَأَخَّرَهُ فَشَكَرَ اللَّهُ لَهُ فَغَفَرَ لَهُ ‏"‏ ‏.‏ وَقَالَ ‏"‏ الشُّهَدَاءُ خَمْسَةٌ الْمَطْعُونُ وَالْمَبْطُونُ وَالْغَرِقُ وَصَاحِبُ الْهَدْمِ وَالشَّهِيدُ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ وَقَالَ ‏"‏ لَوْ يَعْلَمُ النَّاسُ مَا فِي النِّدَاءِ وَالصَّفِّ الأَوَّلِ ثُمَّ لَمْ يَجِدُوا إِلاَّ أَنْ يَسْتَهِمُوا عَلَيْهِ لاَسْتَهَمُوا وَلَوْ يَعْلَمُونَ مَا فِي التَّهْجِيرِ لاَسْتَبَقُوا إِلَيْهِ وَلَوْ يَعْلَمُونَ مَا فِي الْعَتَمَةِ وَالصُّبْحِ لأَتَوْهُمَا وَلَوْ حَبْوًا ‏"‏ ‏.‏\hadithno{292}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Sumayy, the mawla of Abu Bakr ibn Abd ar-Rahman from Abu Salih from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "If a man who is walking along a road finds a branch of thorns on the road and removes it, Allah thanks him for doing it and forgives him." He also said, "Martyrs are five:the one killed by a plague, the one killed by a disease of the belly, the one who drowns, the one killed by a collapsing building, and the martyr in the path of Allah.' He also said, "If people knew what there was in the call to prayer and the first row, and they could find no other way except to draw lots for it, they would draw lots for it. And if they knew what there was in doing dhuhr at its time, they would race each other to it. And if they knew what there was in the prayers of isha and maghrib, they would come to them even if they had to crawl}}
\hadithdefcmd{malik}{293}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ سُلَيْمَانَ بْنِ أَبِي حَثْمَةَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، فَقَدَ سُلَيْمَانَ بْنَ أَبِي حَثْمَةَ فِي صَلاَةِ الصُّبْحِ وَأَنَّ عُمَرَ بْنَ الْخَطَّابِ غَدَا إِلَى السُّوقِ - وَمَسْكَنُ سُلَيْمَانَ بَيْنَ السُّوقِ وَالْمَسْجِدِ النَّبَوِيِّ - فَمَرَّ عَلَى الشِّفَاءِ أُمِّ سُلَيْمَانَ فَقَالَ لَهَا لَمْ أَرَ سُلَيْمَانَ فِي الصُّبْحِ فَقَالَتْ إِنَّهُ بَاتَ يُصَلِّي فَغَلَبَتْهُ عَيْنَاهُ ‏.‏ فَقَالَ عُمَرُ لأَنْ أَشْهَدَ صَلاَةَ الصُّبْحِ فِي الْجَمَاعَةِ أَحَبُّ إِلَىَّ مِنْ أَنْ أَقُومَ لَيْلَةً ‏.‏\hadithno{293}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Abu Bakr ibn Sulayman ibn Abi Hathma that Umar ibn al-Khattab missed Sulayman ibn Abi Hathma in the subh prayer. In the morning he went to the market, and Sulayman's house was between the market and the Prophet's mosque. He passed ash-Shifa, Sulayman's mother, and said to her, "I did not see Sulayman at subh." She replied, "He spent the night in prayer and his eyes overcame him. Umar said, "I would rather be present at subh than stand the whole night in prayer}}
\hadithdefcmd{malik}{294}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ الأَنْصَارِيِّ، أَنَّهُ قَالَ جَاءَ عُثْمَانُ بْنُ عَفَّانَ إِلَى صَلاَةِ الْعِشَاءِ فَرَأَى أَهْلَ الْمَسْجِدِ قَلِيلاً فَاضْطَجَعَ فِي مُؤَخَّرِ الْمَسْجِدِ يَنْتَظِرُ النَّاسَ أَنْ يَكْثُرُوا فَأَتَاهُ ابْنُ أَبِي عَمْرَةَ فَجَلَسَ إِلَيْهِ فَسَأَلَهُ مَنْ هُوَ فَأَخْبَرَهُ فَقَالَ مَا مَعَكَ مِنَ الْقُرْآنِ فَأَخْبَرَهُ ‏.‏ فَقَالَ لَهُ عُثْمَانُ مَنْ شَهِدَ الْعِشَاءَ فَكَأَنَّمَا قَامَ نِصْفَ لَيْلَةٍ وَمَنْ شَهِدَ الصُّبْحَ فَكَأَنَّمَا قَامَ لَيْلَةً ‏.‏\hadithno{294}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Muhammad ibn Ibrahim that Abd ar-Rahman ibn Abi Amra al-Ansari said that Uthman ibn Affan came to the isha prayer and seeing only a few people in the mosque, he lay down at the back of the mosque to wait for the number of people to increase. Ibn Abi Amra went and sat down beside him and Uthman asked him who he was, so he told him. Uthman said, "What have you memorised of the Qur'an?", and he told him. Uthman said, "If someone is present at isha, it is as if he had stood in prayer for half a night, and if some one is present at subh, it is as if he had stood in prayer for a whole night}}
\hadithdefcmd{malik}{295}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ رَجُلٍ، مِنْ بَنِي الدِّيلِ يُقَالُ لَهُ بُسْرُ بْنُ مِحْجَنٍ عَنْ أَبِيهِ، مِحْجَنٍ أَنَّهُ كَانَ فِي مَجْلِسٍ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأُذِّنَ بِالصَّلاَةِ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى ثُمَّ رَجَعَ وَمِحْجَنٌ فِي مَجْلِسِهِ لَمْ يُصَلِّ مَعَهُ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مَنَعَكَ أَنْ تُصَلِّيَ مَعَ النَّاسِ أَلَسْتَ بِرَجُلٍ مُسْلِمٍ ‏"‏ ‏.‏ فَقَالَ بَلَى يَا رَسُولَ اللَّهِ وَلَكِنِّي قَدْ صَلَّيْتُ فِي أَهْلِي ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا جِئْتَ فَصَلِّ مَعَ النَّاسِ وَإِنْ كُنْتَ قَدْ صَلَّيْتَ ‏"‏ ‏.‏\hadithno{295}\hadithgrade{Salim al-Hilali: Hasan Lighairihi}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from a man of the Bani'd-Dil called Busr ibn Mihjan from his father Mihjan that he was in a gathering with the Messenger of Allah, may Allah bless him and grant him peace, and the call to prayer was made. The Messenger of Allah, may Allah bless him and grant him peace, rose and prayed and then returned. Mihjan remained sitting and did not pray with him. The Messenger of Allah, may Allah bless him and grant him peace, said, "What prevented you from praying with the people? Aren't you a muslim?" He said, "Of course, Messenger of Allah, but I have already prayed with my family." The Messenger of Allah, may Allah bless him and grant him peace, said, "When you come, pray with the people, even if you have prayed already}}
\hadithdefcmd{malik}{296}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ رَجُلاً، سَأَلَ عَبْدَ اللَّهِ بْنَ عُمَرَ فَقَالَ إِنِّي أُصَلِّي فِي بَيْتِي ثُمَّ أُدْرِكُ الصَّلاَةَ مَعَ الإِمَامِ أَفَأُصَلِّي مَعَهُ فَقَالَ لَهُ عَبْدُ اللَّهِ بْنُ عُمَرَ نَعَمْ ‏.‏ فَقَالَ الرَّجُلُ أَيَّتَهُمَا أَجْعَلُ صَلاَتِي فَقَالَ لَهُ ابْنُ عُمَرَ أَوَذَلِكَ إِلَيْكَ إِنَّمَا ذَلِكَ إِلَى اللَّهِ يَجْعَلُ أَيَّتَهُمَا شَاءَ ‏.‏\hadithno{296}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that a man asked Abdullah ibn Umar, "Sometimes I pray in my house, and then catch the prayer with the imam. Should I pray with him?" Abdullah ibn Umar said to him, "Yes," and the man said, "Which of them do I make my prayer?" Abdullah ibn Umar said, "Is that up to you? It is up to Allah. He will decide on whichever of them He wishes}}
\hadithdefcmd{malik}{297}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ رَجُلاً، سَأَلَ سَعِيدَ بْنَ الْمُسَيَّبِ فَقَالَ إِنِّي أُصَلِّي فِي بَيْتِي ثُمَّ آتِي الْمَسْجِدَ فَأَجِدُ الإِمَامَ يُصَلِّي أَفَأُصَلِّي مَعَهُ فَقَالَ سَعِيدٌ نَعَمْ ‏.‏ فَقَالَ الرَّجُلُ فَأَيُّهُمَا صَلاَتِي فَقَالَ سَعِيدٌ أَوَأَنْتَ تَجْعَلُهُمَا إِنَّمَا ذَلِكَ إِلَى اللَّهِ ‏.‏\hadithno{297}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that a man asked Said ibn al-Musayyab, "I pray in my house, and then I come to the mosque and find the imam praying. Should I pray with him?" Said said, "Yes," and the man said, "Which of them is my prayer?" Said said, "Are you the one to decide that? That is up to Allah}}
\hadithdefcmd{malik}{298}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَفِيفٍ السَّهْمِيِّ، عَنْ رَجُلٍ، مِنْ بَنِي أَسَدٍ أَنَّهُ سَأَلَ أَبَا أَيُّوبَ الأَنْصَارِيَّ فَقَالَ إِنِّي أُصَلِّي فِي بَيْتِي ثُمَّ آتِي الْمَسْجِدَ فَأَجِدُ الإِمَامَ يُصَلِّي أَفَأُصَلِّي مَعَهُ فَقَالَ أَبُو أَيُّوبَ نَعَمْ فَصَلِّ مَعَهُ فَإِنَّ مَنْ صَنَعَ ذَلِكَ فَإِنَّ لَهُ سَهْمَ جَمْعٍ أَوْ مِثْلَ سَهْمِ جَمْعٍ ‏.‏\hadithno{298}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Afif as-Sahmi that a man from the tribe of Bani Asad asked Abu Ayyub al-Ansari. "Sometimes I pray in my house, and then come to the mosque and find the imam praying. Should I pray with him?" Abu Ayyub said, "Yes, pray with him, for some one who does so has the reward of the group, or the equivalent of the reward of the group}}
\hadithdefcmd{malik}{299}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ مَنْ صَلَّى الْمَغْرِبَ أَوِ الصُّبْحَ ثُمَّ أَدْرَكَهُمَا مَعَ الإِمَامِ فَلاَ يَعُدْ لَهُمَا ‏.‏ قَالَ مَالِكٌ وَلاَ أَرَى بَأْسًا أَنْ يُصَلِّيَ مَعَ الإِمَامِ مَنْ كَانَ قَدْ صَلَّى فِي بَيْتِهِ إِلاَّ صَلاَةَ الْمَغْرِبِ فَإِنَّهُ إِذَا أَعَادَهَا كَانَتْ شَفْعًا ‏.‏\hadithno{299}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "Someone who prays maghrib or subh and then catches them with the imam should not repeat them." Malik said, "I do not see any harm in someone who has already prayed in his house praying with the imam, except for maghrib, because if he repeats it, he makes it even}}
\hadithdefcmd{malik}{300}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا صَلَّى أَحَدُكُمْ بِالنَّاسِ فَلْيُخَفِّفْ فَإِنَّ فِيهِمُ الضَّعِيفَ وَالسَّقِيمَ وَالْكَبِيرَ وَإِذَا صَلَّى أَحَدُكُمْ لِنَفْسِهِ فَلْيُطَوِّلْ مَا شَاءَ ‏"‏ ‏.‏\hadithno{300}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "When you lead people in the prayer, make it short, because there are among them some people who are weak, ill and old. But when you pray on your own, make it as long as you wish}}
\hadithdefcmd{malik}{301}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّهُ قَالَ قُمْتُ وَرَاءَ عَبْدِ اللَّهِ بْنِ عُمَرَ فِي صَلاَةٍ مِنَ الصَّلَوَاتِ وَلَيْسَ مَعَهُ أَحَدٌ غَيْرِي فَخَالَفَ عَبْدُ اللَّهِ بِيَدِهِ فَجَعَلَنِي حِذَاءَهُ ‏.‏\hadithno{301}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Nafi said, "I stood behind Abdullah ibn Umar in one of the prayers when there was no one else with him, and he reached behind with his hand and placed me beside him}}
\hadithdefcmd{malik}{302}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ رَجُلاً، كَانَ يَؤُمُّ النَّاسَ بِالْعَقِيقِ فَأَرْسَلَ إِلَيْهِ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ فَنَهَاهُ ‏.‏ قَالَ مَالِكٌ وَإِنَّمَا نَهَاهُ لأَنَّهُ كَانَ لاَ يُعْرَفُ أَبُوهُ ‏.‏\hadithno{302}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that a man used to lead the people in prayer in al-Aqiq (a place near Madina), and Umar ibn Abd al-Aziz sent a message to him forbidding him to do so. Malik said, "He only forbade him because his father was not known}}
\hadithdefcmd{malik}{303}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَكِبَ فَرَسًا فَصُرِعَ فَجُحِشَ شِقُّهُ الأَيْمَنُ فَصَلَّى صَلاَةً مِنَ الصَّلَوَاتِ وَهُوَ قَاعِدٌ وَصَلَّيْنَا وَرَاءَهُ قُعُودًا فَلَمَّا انْصَرَفَ قَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ فَإِذَا صَلَّى قَائِمًا فَصَلُّوا قِيَامًا وَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا رَفَعَ فَارْفَعُوا وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ فَقُولُوا رَبَّنَا وَلَكَ الْحَمْدُ وَإِذَا صَلَّى جَالِسًا فَصَلُّوا جُلُوسًا أَجْمَعُونَ ‏"‏ ‏.‏\hadithno{303}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Anas ibn Malik that the Messenger of Allah, may Allah bless him and grant him peace, fell off his horse when riding, and his right side was scraped, so he did one of the prayers sitting, and we prayed behind him sitting. When he left, he said, "The imam is appointed to be followed. If he prays standing, then pray standing, and when he goes into ruku, go into ruku, and when he rises, rise, and when he says, 'Allah hears whoever praises him,' say, 'Our Lord, praise belongs to You,' and if he prays sitting, then all of you pray sitting}}
\hadithdefcmd{malik}{304}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ شَاكٍ فَصَلَّى جَالِسًا وَصَلَّى وَرَاءَهُ قَوْمٌ قِيَامًا فَأَشَارَ إِلَيْهِمْ أَنِ اجْلِسُوا فَلَمَّا انْصَرَفَ قَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ فَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا رَفَعَ فَارْفَعُوا وَإِذَا صَلَّى جَالِسًا فَصَلُّوا جُلُوسًا ‏"‏ ‏.‏\hadithno{304}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "The Messenger of Allah, may Allah bless him and grant him peace, prayed while he was ill. He prayed sitting, and some people prayed behind him standing, and he indicated to them to sit down. When he left, he said, 'The imam is only appointed to be followed. When he goes into ruku, go into ruku and when he rises, rise and if he prays sitting, pray sitting}}
\hadithdefcmd{malik}{305}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ فِي مَرَضِهِ فَأَتَى فَوَجَدَ أَبَا بَكْرٍ وَهُوَ قَائِمٌ يُصَلِّي بِالنَّاسِ فَاسْتَأْخَرَ أَبُو بَكْرٍ فَأَشَارَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ كَمَا أَنْتَ فَجَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى جَنْبِ أَبِي بَكْرٍ فَكَانَ أَبُو بَكْرٍ يُصَلِّي بِصَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ جَالِسٌ وَكَانَ النَّاسُ يُصَلُّونَ بِصَلاَةِ أَبِي بَكْرٍ ‏.‏\hadithno{305}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that the Messenger of Allah, may Allah bless him and grant him peace, came out during his illness, and approached and found Abu Bakr standing, leading the people in prayer. Abu Bakr began to go back, but the Messenger of Allah, may Allah bless him and grant him peace, indicated to him to stay where he was. The Messenger of Allah, may Allah bless him and grant him peace, sat by the side of Abu Bakr, and Abu Bakr prayed following the prayer of the Messenger of Allah, may Allah bless him and grant him peace, who was sitting, and the people prayed following the prayer of Abu Bakr}}
\hadithdefcmd{malik}{306}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ إِسْمَاعِيلَ بْنِ مُحَمَّدِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ مَوْلًى، لِعَمْرِو بْنِ الْعَاصِ - أَوْ لِعَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ - عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةُ أَحَدِكُمْ وَهُوَ قَاعِدٌ مِثْلُ نِصْفِ صَلاَتِهِ وَهُوَ قَائِمٌ ‏"‏ ‏.‏\hadithno{306}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ismail ibn Muhammad ibn Said ibn Abi Waqqas from a mawla of Amr ibn al-As or of Abdullah ibn Amr ibn al-As that the Messenger of Allah, may Allah bless him and grant him peace, said, "The prayer of one of you sitting down is only equal to half the prayer of one of you when he is standing}}
\hadithdefcmd{malik}{307}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّهُ قَالَ لَمَّا قَدِمْنَا الْمَدِينَةَ نَالَنَا وَبَاءٌ مِنْ وَعْكِهَا شَدِيدٌ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى النَّاسِ وَهُمْ يُصَلُّونَ فِي سُبْحَتِهِمْ قُعُودًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صَلاَةُ الْقَاعِدِ مِثْلُ نِصْفِ صَلاَةِ الْقَائِمِ ‏"‏ ‏.‏\hadithno{307}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Abdullah ibn Amr ibn al As said, "When we arrived at Madina we were struck down by a severe epidemic which debilitated us greatly. The Messenger of Allah, may Allah bless him and grant him peace, came out to the people while they were praying nawafil prayers sitting down. The Messenger of Allah, may Allah bless him and grant him peace, said, 'The prayer of the one sitting is equal to only half the prayer of the one standing}}
\hadithdefcmd{malik}{308}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنِ السَّائِبِ بْنِ يَزِيدَ، عَنِ الْمُطَّلِبِ بْنِ أَبِي وَدَاعَةَ السَّهْمِيِّ، عَنْ حَفْصَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى فِي سُبْحَتِهِ قَاعِدًا قَطُّ حَتَّى كَانَ قَبْلَ وَفَاتِهِ بِعَامٍ فَكَانَ يُصَلِّي فِي سُبْحَتِهِ قَاعِدًا وَيَقْرَأُ بِالسُّورَةِ فَيُرَتِّلُهَا حَتَّى تَكُونَ أَطْوَلَ مِنْ أَطْوَلَ مِنْهَا ‏.‏\hadithno{308}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from as-Sa'ib ibn Yazid from al Muttalib ibn Abi Wadaa as-Sahmi that Hafsa, the wife of the Prophet, may Allah bless him and grant him peace, said, "I never saw the Messenger of Allah, may Allah bless him and grant him peace, praying nawafil sitting, until a year before his death, when he began to pray them sitting. He would recite the sura with a measured slowness so that it would seem to be longer than other suras which were actually longer than it}}
\hadithdefcmd{malik}{309}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا أَخْبَرَتْهُ أَنَّهَا لَمْ تَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي صَلاَةَ اللَّيْلِ قَاعِدًا قَطُّ حَتَّى أَسَنَّ فَكَانَ يَقْرَأُ قَاعِدًا حَتَّى إِذَا أَرَادَ أَنْ يَرْكَعَ قَامَ فَقَرَأَ نَحْوًا مِنْ ثَلاَثِينَ أَوْ أَرْبَعِينَ آيَةً ثُمَّ رَكَعَ ‏.‏\hadithno{309}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, told him that she had never seen the Messenger of Allah, may Allah bless him and grant him peace, doing night prayers sitting down until he was getting on in years. He would recite sitting down until when he wanted to go into ruku, he would stand up and recite about thirty or forty ayats and then go into ruku}}
\hadithdefcmd{malik}{310}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْمَدَنِيِّ، وَعَنْ أَبِي النَّضْرِ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي جَالِسًا فَيَقْرَأُ وَهُوَ جَالِسٌ فَإِذَا بَقِيَ مِنْ قِرَاءَتِهِ قَدْرُ مَا يَكُونُ ثَلاَثِينَ أَوْ أَرْبَعِينَ آيَةً قَامَ فَقَرَأَ وَهُوَ قَائِمٌ ثُمَّ رَكَعَ وَسَجَدَ ثُمَّ صَنَعَ فِي الرَّكْعَةِ الثَّانِيَةِ مِثْلَ ذَلِكَ ‏.‏\hadithno{310}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Yazid al-Madani and from Abu'n Nadr from Abu Salama ibn Abd ar-Rahman from A'isha, the wife of the Prophet, may Allah bless him and grant him peace, that the Messenger of Allah, may Allah bless him and grant him peace, used to pray sitting. He would recite sitting, and then, when about thirty or forty ayats of what he was reciting remained, he would stand up and recite standing and then go into ruku and sajda. He would do the same in the second raka}}
\hadithdefcmd{malik}{311}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، وَسَعِيدَ بْنَ الْمُسَيَّبِ، كَانَا يُصَلِّيَانِ النَّافِلَةَ وَهُمَا مُحْتَبِيَانِ ‏.‏\hadithno{311}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Urwa ibn az-Zubayr and Said ibn al-Musayyab used to pray voluntary prayers sitting}}
\hadithdefcmd{malik}{312}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي يُونُسَ، مَوْلَى عَائِشَةَ أُمِّ الْمُؤْمِنِينَ أَنَّهُ قَالَ أَمَرَتْنِي عَائِشَةُ أَنْ أَكْتُبَ لَهَا مُصْحَفًا ثُمَّ قَالَتْ إِذَا بَلَغْتَ هَذِهِ الآيَةَ فَآذِنِّي ‏\{‏حَافِظُوا عَلَى الصَّلَوَاتِ وَالصَّلاَةِ الْوُسْطَى وَقُومُوا لِلَّهِ قَانِتِينَ‏\}‏ فَلَمَّا بَلَغْتُهَا آذَنْتُهَا فَأَمْلَتْ عَلَىَّ حَافِظُوا عَلَى الصَّلَوَاتِ وَالصَّلاَةِ الْوُسْطَى وَصَلاَةِ الْعَصْرِ وَقُومُوا لِلَّهِ قَانِتِينَ قَالَتْ عَائِشَةُ سَمِعْتُهَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{312}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from al-Qaqa ibn Hakim that Abu Yunus, the mawla of A'isha, umm al-muminin said, ''A'isha ordered me to write out a Qur'an for her. She said, 'When you reach this ayat, let me know, "Guard the prayers carefully and the middle prayer and stand obedient to Allah." ' When I reached it I told her, and she dictated to me, 'Guard the prayers carefully and the middle prayer and the asr prayer and stand obedient to Allah.' A'isha said, 'I heard it from the Messenger of Allah, may Allah bless him and grant him peace}}
\hadithdefcmd{malik}{313}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَمْرِو بْنِ رَافِعٍ، أَنَّهُ قَالَ كُنْتُ أَكْتُبُ مُصْحَفًا لِحَفْصَةَ أُمِّ الْمُؤْمِنِينَ فَقَالَتْ إِذَا بَلَغْتَ هَذِهِ الآيَةَ فَآذِنِّي ‏\{‏حَافِظُوا عَلَى الصَّلَوَاتِ وَالصَّلاَةِ الْوُسْطَى وَقُومُوا لِلَّهِ قَانِتِينَ ‏\}‏ فَلَمَّا بَلَغْتُهَا آذَنْتُهَا فَأَمْلَتْ عَلَىَّ حَافِظُوا عَلَى الصَّلَوَاتِ وَالصَّلاَةِ الْوُسْطَى وَصَلاَةِ الْعَصْرِ وَقُومُوا لِلَّهِ قَانِتِينَ ‏.‏\hadithno{313}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that Amr ibn Rafi said, "I was writing a Qur'an for Hafsa, umm al-muminin, and she said, 'When you reach this ayat, let me know, "Guard the prayers carefully and the middle prayer and stand obedient to Allah." When I reached it I told her and she dictated to me, 'Guard the prayers carefully and the middle prayer and the asr prayer and stand obedient to Allah}}
\hadithdefcmd{malik}{314}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنِ ابْنِ يَرْبُوعٍ الْمَخْزُومِيِّ، أَنَّهُ قَالَ سَمِعْتُ زَيْدَ بْنَ ثَابِتٍ، يَقُولُ الصَّلاَةُ الْوُسْطَى صَلاَةُ الظُّهْرِ ‏.‏\hadithno{314}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Da'ud ibn al-Husayn that Ibn Yarbu al-Makhzumi said, "I heard Zayd ibn Thabit say, 'The middle prayer is the prayer of dhuhr}}
\hadithdefcmd{malik}{315}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ، وَعَبْدَ اللَّهِ بْنَ عَبَّاسٍ، كَانَا يَقُولاَنِ الصَّلاَةُ الْوُسْطَى صَلاَةُ الصُّبْحِ ‏.‏ قَالَ مَالِكٌ وَقَوْلُ عَلِيٍّ وَابْنِ عَبَّاسٍ أَحَبُّ مَا سَمِعْتُ إِلَىَّ فِي ذَلِكَ ‏.‏\hadithno{315}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that AIi ibn Abi Talib and Abdullah ibn Abbas used to say, "The middle prayer is the prayer of subh." Malik said, "Out of all that I have heard about the matter, I prefer what Ali ibn Abi Talib and Abdullah ibn Abbas said}}
\hadithdefcmd{malik}{316}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِي ثَوْبٍ وَاحِدٍ مُشْتَمِلاً بِهِ فِي بَيْتِ أُمِّ سَلَمَةَ وَاضِعًا طَرَفَيْهِ عَلَى عَاتِقَيْهِ ‏.‏\hadithno{316}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that Umar ibn Abi Salama saw the Messenger of Allah, may Allah bless him and grant him peace, praying in one garment in the house of Umm Salama. He was completely covered by it, and had put both ends over his shoulders}}
\hadithdefcmd{malik}{317}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ سَائِلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّلاَةِ فِي ثَوْبٍ وَاحِدٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوَلِكُلِّكُمْ ثَوْبَانِ ‏"‏ ‏.‏\hadithno{317}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Said ibn al- Musayyab from Abu Hurayra that some one asked the Messenger of Allah, may Allah bless him and grant him peace about praying in one garment. The Messenger of Allah, may Allah bless him and grant him peace, said, "Do you all have two garments?}}
\hadithdefcmd{malik}{318}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ سُئِلَ أَبُو هُرَيْرَةَ هَلْ يُصَلِّي الرَّجُلُ فِي ثَوْبٍ وَاحِدٍ فَقَالَ نَعَمْ ‏.‏ فَقِيلَ لَهُ هَلْ تَفْعَلُ أَنْتَ ذَلِكَ فَقَالَ نَعَمْ إِنِّي لأُصَلِّي فِي ثَوْبٍ وَاحِدٍ وَإِنَّ ثِيَابِي لَعَلَى الْمِشْجَبِ ‏.‏\hadithno{318}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Said ibn al- Musayyab said that Abu Hurayra was asked, "May a man pray in one garment?" He said, "Yes." The man then said to him "Do you do that?" and he replied, "Yes, I pray in one garment while my clothes are on the clothes-rack}}
\hadithdefcmd{malik}{319}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ، كَانَ يُصَلِّي فِي الثَّوْبِ الْوَاحِدِ ‏.‏\hadithno{319}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Jabir ibn Abdullah used to pray in one garment}}
\hadithdefcmd{malik}{320}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّ مُحَمَّدَ بْنَ عَمْرِو بْنِ حَزْمٍ، كَانَ يُصَلِّي فِي الْقَمِيصِ الْوَاحِدِ ‏.‏\hadithno{320}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Rabia ibn Abi Abd ar-Rahman that Muhammad ibn Amr ibn Hazm used to pray in a single long shirt}}
\hadithdefcmd{malik}{321}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَمْ يَجِدْ ثَوْبَيْنِ فَلْيُصَلِّي فِي ثَوْبٍ وَاحِدٍ مُلْتَحِفًا بِهِ فَإِنْ كَانَ الثَّوْبُ قَصِيرًا فَلْيَتَّزِرْ بِهِ ‏"‏ ‏.‏\hadithno{321}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that he had heard from Jabir ibn Abdullah that the Messenger of Allah, may Allah bless him and grant him peace, said, "Let anyone who cannot find two garments pray in one garment and wrap himself in it, and if the garment is short, let him wrap it around his waist." Malik said, "In my view it is preferable for someone who prays in a single shirt to put a garment or a turban over his shoulders}}
\hadithdefcmd{malik}{322}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَانَتْ تُصَلِّي فِي الدِّرْعِ وَالْخِمَارِ ‏.‏\hadithno{322}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, used to pray in a shift and head-covering}}
\hadithdefcmd{malik}{323}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ زَيْدِ بْنِ قُنْفُذٍ، عَنْ أُمِّهِ، أَنَّهَا سَأَلَتْ أُمَّ سَلَمَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم مَاذَا تُصَلِّي فِيهِ الْمَرْأَةُ مِنَ الثِّيَابِ فَقَالَتْ تُصَلِّي فِي الْخِمَارِ وَالدِّرْعِ السَّابِغِ إِذَا غَيَّبَ ظُهُورَ قَدَمَيْهَا ‏.‏\hadithno{323}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Muhammad ibn Zayd ibn Qunfudh that his mother asked Umm Salama, the wife of the Prophet, may Allah bless him and grant him peace, "What clothes can a woman wear in prayer?" She said, "She can pray in a shift that reaches down and covers the top of her feet}}
\hadithdefcmd{malik}{324}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ الثِّقَةِ، عِنْدَهُ عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ الأَسْوَدِ الْخَوْلاَنِيِّ، وَكَانَ، فِي حَجْرِ مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ مَيْمُونَةَ كَانَتْ تُصَلِّي فِي الدِّرْعِ وَالْخِمَارِ لَيْسَ عَلَيْهَا إِزَارٌ ‏.‏\hadithno{324}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from a reliable source from Bukayr ibn Abdullah ibn al-Ashajj from Busr ibn Said that when Ubaydullah ibn al-Aswad al-Khawlani was in the room of Maimuna, the wife of the Prophet, may Allah bless him and grant him peace, she used to pray in a shift and head-covering, without a waist-wrapper}}
\hadithdefcmd{malik}{325}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ امْرَأَةً، اسْتَفْتَتْهُ فَقَالَتْ إِنَّ الْمِنْطَقَ يَشُقُّ عَلَىَّ أَفَأُصَلِّي فِي دِرْعٍ وَخِمَارٍ فَقَالَ نَعَمْ إِذَا كَانَ الدِّرْعُ سَابِغًا ‏.‏\hadithno{325}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that a woman asked him for a decision, saying, "Waist-wrappers are painful to me. Can I pray in a shift and head-covering?" He replied, "Yes, if the shift is long}}
