% Auto-generated chapter 17 for abudawud
% Hadiths in this chapter: 18

\hadithdefcmd{abudawud}{2844}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اتَّخَذَ كَلْبًا إِلاَّ كَلْبَ مَاشِيَةٍ أَوْ صَيْدٍ أَوْ زَرْعٍ انْتَقَصَ مِنْ أَجْرِهِ كُلَّ يَوْمٍ قِيرَاطٌ ‏"‏ ‏.‏\hadithno{2844}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (1575)}\hadithtrans{Narrated Abu Hurairah:The Prophet (ﷺ) as saying: If anyone gets a dog, except a sheeping or hunting or a farm dog, a qirat of his reward will be deducted daily}}
\hadithdefcmd{abudawud}{2845}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ، حَدَّثَنَا يُونُسُ، عَنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْلاَ أَنَّ الْكِلاَبَ أُمَّةٌ مِنَ الأُمَمِ لأَمَرْتُ بِقَتْلِهَا فَاقْتُلُوا مِنْهَا الأَسْوَدَ الْبَهِيمَ ‏"‏ ‏.‏\hadithno{2845}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mughaffal: The Prophet (ﷺ) said: Were dogs not a species of creature I should command that they all be killed; but kill every pure black one}}
\hadithdefcmd{abudawud}{2846}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أَمَرَ نَبِيُّ اللَّهِ صلى الله عليه وسلم بِقَتْلِ الْكِلاَبِ حَتَّى إِنْ كَانَتِ الْمَرْأَةُ تَقْدَمُ مِنَ الْبَادِيَةِ - يَعْنِي بِالْكَلْبِ - فَنَقْتُلُهُ ثُمَّ نَهَانَا عَنْ قَتْلِهَا وَقَالَ ‏ "‏ عَلَيْكُمْ بِالأَسْوَدِ ‏"‏ ‏.‏\hadithno{2846}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1572)}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet of Allah (ﷺ) ordered to kill dogs, and we were even killing a dog which a woman brought with her from the desert. Afterwards he forbade to kill them, saying: Confine yourselves to the type which is black}}
\hadithdefcmd{abudawud}{2847}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامٍ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم قُلْتُ إِنِّي أُرْسِلُ الْكِلاَبَ الْمُعَلَّمَةَ فَتُمْسِكُ عَلَىَّ أَفَآكُلُ قَالَ ‏"‏ إِذَا أَرْسَلْتَ الْكِلاَبَ الْمُعَلَّمَةَ وَذَكَرْتَ اسْمَ اللَّهِ فَكُلْ مِمَّا أَمْسَكْنَ عَلَيْكَ ‏"‏ ‏.‏ قُلْتُ وَإِنْ قَتَلْنَ قَالَ ‏"‏ وَإِنْ قَتَلْنَ مَا لَمْ يَشْرَكْهَا كَلْبٌ لَيْسَ مِنْهَا ‏"‏ ‏.‏ قُلْتُ أَرْمِي بِالْمِعْرَاضِ فَأُصِيبُ أَفَآكُلُ قَالَ ‏"‏ إِذَا رَمَيْتَ بِالْمِعْرَاضِ وَذَكَرْتَ اسْمَ اللَّهِ فَأَصَابَ فَخَزَقَ فَكُلْ وَإِنْ أَصَابَ بِعَرْضِهِ فَلاَ تَأْكُلْ ‏"‏ ‏.‏\hadithno{2847}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5477) Sahih Muslim (1929)}\hadithtrans{Narrated 'Abi b. Hatim:I asked the Prophet (ﷺ) ,and said: I set off my trained dogs, and they catch (something) for me: may I eat (it)? He said: When you set off trained dogs and mention Allah's name, eat what they catch for you. I said: Even if they killed (the game)? He said: Even if they killed (the game) as long as another dog does not join it. I said: I shoot with a featherless arrow, and it strikes the target, may I eat (it) ? He said: If you shoot with a featherless arrow and mention Allah's name, and it strikes the aim, and pierce it, eat it ; and if it strikes with its middle, do not eat (it)}}
\hadithdefcmd{abudawud}{2848}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ بَيَانٍ، عَنْ عَامِرٍ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم قُلْتُ إِنَّا نَصِيدُ بِهَذِهِ الْكِلاَبِ فَقَالَ لِي ‏ "‏ إِذَا أَرْسَلْتَ كِلاَبَكَ الْمُعَلَّمَةَ وَذَكَرْتَ اسْمَ اللَّهِ عَلَيْهَا فَكُلْ مِمَّا أَمْسَكْنَ عَلَيْكَ وَإِنْ قَتَلَ إِلاَّ أَنْ يَأْكُلَ الْكَلْبُ فَإِنْ أَكَلَ الْكَلْبُ فَلاَ تَأْكُلْ فَإِنِّي أَخَافُ أَنْ يَكُونَ إِنَّمَا أَمْسَكَهُ عَلَى نَفْسِهِ ‏"‏ ‏.‏\hadithno{2848}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5484) Sahih Muslim (1929)}\hadithtrans{Narrated 'Adi b. Hatim:I asked the Messenger of Allah. I said: We hunt with these dogs. He replied: When you set off your dog and mention Allah's name over it, eat what it catches for you, even if it kills it, except that the dog has eaten (any of it); if the dog has eaten (any of it), do not eat, for Im afraid it has caught it only for itself}}
\hadithdefcmd{abudawud}{2849}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَمَيْتَ بِسَهْمِكَ وَذَكَرْتَ اسْمَ اللَّهِ فَوَجَدْتَهُ مِنَ الْغَدِ وَلَمْ تَجِدْهُ فِي مَاءٍ وَلاَ فِيهِ أَثَرٌ غَيْرَ سَهْمِكَ فَكُلْ وَإِذَا اخْتَلَطَ بِكِلاَبِكَ كَلْبٌ مِنْ غَيْرِهَا فَلاَ تَأْكُلْ لاَ تَدْرِي لَعَلَّهُ قَتَلَهُ الَّذِي لَيْسَ مِنْهَا ‏"‏ ‏.‏\hadithno{2849}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5484) Sahih Muslim (1929)}\hadithtrans{Narrated 'Adi b. Hatim:The Prophet (ﷺ) as saying: When you shoot your arrow and mention Allah's name, and you find it (the game) after a day, and you do not find it in water, and you find in it only the mark of you arrow, eat (it). But if another dog joins your dogs, do not eat it, for you do not know maybe the one which was not yours has killed it}}
\hadithdefcmd{abudawud}{2850}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، أَخْبَرَنِي عَاصِمٌ الأَحْوَلُ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا وَقَعَتْ رَمِيَّتُكَ فِي مَاءٍ فَغَرِقَ فَمَاتَ فَلاَ تَأْكُلْ ‏"‏ ‏.‏\hadithno{2850}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5484) Sahih Muslim (1929)}\hadithtrans{Narrated 'Adi b. Hatim:The Prophet (ﷺ) as saying: When the animal at which you shot falls in water, is drowned, and dies, do not eat}}
\hadithdefcmd{abudawud}{2851}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، حَدَّثَنَا مُجَالِدٌ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ مَا عَلَّمْتَ مِنْ كَلْبٍ أَوْ بَازٍ ثُمَّ أَرْسَلْتَهُ وَذَكَرْتَ اسْمَ اللَّهِ فَكُلْ مِمَّا أَمْسَكَ عَلَيْكَ ‏"‏ ‏.‏ قُلْتُ وَإِنْ قَتَلَ قَالَ ‏"‏ إِذَا قَتَلَهُ وَلَمْ يَأْكُلْ مِنْهُ شَيْئًا فَإِنَّمَا أَمْسَكَهُ عَلَيْكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الْبَازُ إِذَا أَكَلَ فَلاَ بَأْسَ بِهِ وَالْكَلْبُ إِذَا أَكَلَ كُرِهَ وَإِنْ شَرِبَ الدَّمَ فَلاَ بَأْسَ بِهِ ‏.‏\hadithno{2851}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Narrated Adi ibn Hatim: The Prophet (ﷺ) said: Eat what ever is caught for you by a dog or a hawk you have trained and set off when you have mentioned Allah's name. I said: (Does this apply) if it killed (the animal)? He said: When it kills it without eating any of it, for it caught it only for you. Abu Dawud said: If a hawk eats any of it, there is no harm (in eating it). If a dog eats it, it is disapproved (to eat the meat). If it drinks blood, there is no harm (in eating it)}}
\hadithdefcmd{abudawud}{2852}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا دَاوُدُ بْنُ عَمْرٍو، عَنْ بُسْرِ بْنِ عُبَيْدِ اللَّهِ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي صَيْدِ الْكَلْبِ ‏ "‏ إِذَا أَرْسَلْتَ كَلْبَكَ وَذَكَرْتَ اسْمَ اللَّهِ فَكُلْ وَإِنْ أَكَلَ مِنْهُ وَكُلْ مَا رَدَّتْ عَلَيْكَ يَدَاكَ ‏"‏ ‏.‏\hadithno{2852}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuTha'labah al-Khushani: The Messenger of Allah (ﷺ) said about the game hunted by a dog: If you set off your dog and have mentioned Allah's name, eat (it), even if it eats any of it; and eat what your hands return you}}
\hadithdefcmd{abudawud}{2853}{حَدَّثَنَا الْحُسَيْنُ بْنُ مُعَاذِ بْنِ خُلَيْفٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا دَاوُدُ، عَنْ عَامِرٍ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ أَحَدُنَا يَرْمِي الصَّيْدَ فَيَقْتَفِي أَثَرَهُ الْيَوْمَيْنِ وَالثَّلاَثَةَ ثُمَّ يَجِدُهُ مَيِّتًا وَفِيهِ سَهْمُهُ أَيَأْكُلُ قَالَ ‏"‏ نَعَمْ إِنْ شَاءَ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ يَأْكُلُ إِنْ شَاءَ ‏"‏ ‏.‏\hadithno{2853}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Adi ibn Hatim: Messenger of Allah, one of us shoots at the game, and follows its mark for two or three days, and then finds it dead, and there is his arrow (pierced) in it, may he eat it? He said: Yes, if he wishes, or he said: he may eat if he wishes}}
\hadithdefcmd{abudawud}{2854}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي السَّفَرِ، عَنِ الشَّعْبِيِّ، قَالَ قَالَ عَدِيُّ بْنُ حَاتِمٍ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنِ الْمِعْرَاضِ فَقَالَ ‏"‏ إِذَا أَصَابَ بِحَدِّهِ فَكُلْ وَإِذَا أَصَابَ بِعَرْضِهِ فَلاَ تَأْكُلْ فَإِنَّهُ وَقِيذٌ ‏"‏ ‏.‏ قُلْتُ أُرْسِلُ كَلْبِي ‏.‏ قَالَ ‏"‏ إِذَا سَمَّيْتَ فَكُلْ وَإِلاَّ فَلاَ تَأْكُلْ وَإِنْ أَكَلَ مِنْهُ فَلاَ تَأْكُلْ فَإِنَّمَا أَمْسَكَ لِنَفْسِهِ ‏"‏ ‏.‏ فَقَالَ أُرْسِلُ كَلْبِي فَأَجِدُ عَلَيْهِ كَلْبًا آخَرَ فَقَالَ ‏"‏ لاَ تَأْكُلْ لأَنَّكَ إِنَّمَا سَمَّيْتَ عَلَى كَلْبِكَ ‏"‏ ‏.‏\hadithno{2854}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (175) Sahih Muslim (1929)}\hadithtrans{Narrated 'Adi b. Hatim:I asked Prophet (ﷺ) about featherless arrow. He said: If it strikes with its end, eat, and if it strikes with the middle part of it, do not eat, for it died by a violent blow. I said: I set off my dog? He replies: If you mention Allah's name, eat, otherwise do not eat. If it eats any of it, do not eat, for it caught for itself. He asked: I set off my dog, and I find with it another dog ? He replied: Do not eat, because you mentioned Allah's name on your dog}}
\hadithdefcmd{abudawud}{2855}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، قَالَ سَمِعْتُ رَبِيعَةَ بْنَ يَزِيدَ الدِّمَشْقِيَّ، يَقُولُ أَخْبَرَنِي أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ، عَائِذُ اللَّهِ قَالَ سَمِعْتُ أَبَا ثَعْلَبَةَ الْخُشَنِيَّ، يَقُولُ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أَصِيدُ بِكَلْبِي الْمُعَلَّمِ وَبِكَلْبِي الَّذِي لَيْسَ بِمُعَلَّمٍ قَالَ ‏ "‏ مَا صِدْتَ بِكَلْبِكَ الْمُعَلَّمِ فَاذْكُرِ اسْمَ اللَّهِ وَكُلْ وَمَا اصَّدْتَ بِكَلْبِكَ الَّذِي لَيْسَ بِمُعَلَّمٍ فَأَدْرَكْتَ ذَكَاتَهُ فَكُلْ ‏"‏ ‏.‏\hadithno{2855}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5488) Sahih Muslim (1930)}\hadithtrans{Narrated Abu Taa'labat b. al-Khushani:I said: Messenger of Allah, I hunt with my trained dog, and with my untrained dog? He said: 'What you hunt with your trained dog, mention Allah's names (on it) and eat; and what you hunt with your untrained dog, and you find in a position that you slaughter it, then eat}}
\hadithdefcmd{abudawud}{2856}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى، حَدَّثَنَا بَقِيَّةُ، عَنِ الزُّبَيْدِيِّ، حَدَّثَنَا يُونُسُ بْنُ سَيْفٍ، حَدَّثَنَا أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ، حَدَّثَنِي أَبُو ثَعْلَبَةَ الْخُشَنِيُّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَبَا ثَعْلَبَةَ كُلْ مَا رَدَّتْ عَلَيْكَ قَوْسُكَ وَكَلْبُكَ ‏"‏ ‏.‏ زَادَ عَنِ ابْنِ حَرْبٍ ‏"‏ الْمُعَلَّمُ وَيَدُكَ فَكُلْ ذَكِيًّا وَغَيْرَ ذَكِيٍّ ‏"‏ ‏.‏\hadithno{2856}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated AbuTha'labah al-Khushani: The Messenger of Allah (ﷺ) said to me: AbuTha'labah, eat what returns to you by your bow and your dog. Ibn Harb's version adds: "The trained (dog), and your hand, then eat, whether it has been slaughtered or not slaughtered}}
\hadithdefcmd{abudawud}{2857}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمِنْهَالِ الضَّرِيرِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا حَبِيبٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ أَعْرَابِيًّا، يُقَالُ لَهُ أَبُو ثَعْلَبَةَ قَالَ يَا رَسُولَ اللَّهِ إِنَّ لِي كِلاَبًا مُكَلَّبَةً فَأَفْتِنِي فِي صَيْدِهَا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنْ كَانَ لَكَ كِلاَبٌ مُكَلَّبَةٌ فَكُلْ مِمَّا أَمْسَكْنَ عَلَيْكَ ‏"‏ ‏.‏ قَالَ ذَكِيًّا أَوْ غَيْرَ ذَكِيٍّ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَإِنْ أَكَلَ مِنْهُ قَالَ ‏"‏ وَإِنْ أَكَلَ مِنْهُ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ أَفْتِنِي فِي قَوْسِي ‏.‏ قَالَ ‏"‏ كُلْ مَا رَدَّتْ عَلَيْكَ قَوْسُكَ ‏"‏ ‏.‏ قَالَ ‏"‏ ذَكِيًّا أَوْ غَيْرَ ذَكِيٍّ ‏"‏ ‏.‏ قَالَ وَإِنْ تَغَيَّبَ عَنِّي قَالَ ‏"‏ وَإِنْ تَغَيَّبَ عَنْكَ مَا لَمْ يَصِلَّ أَوْ تَجِدَ فِيهِ أَثَرًا غَيْرَ سَهْمِكَ ‏"‏ ‏.‏ قَالَ أَفْتِنِي فِي آنِيَةِ الْمَجُوسِ إِنِ اضْطُرِرْنَا إِلَيْهَا ‏.‏ قَالَ ‏"‏ اغْسِلْهَا وَكُلْ فِيهَا ‏"‏ ‏.‏\hadithno{2857}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: There was a bedouin called AbuTha'labah. He said: Messenger of Allah, I have trained dogs, so tell me your opinion about (eating) the animal they hunt. The Prophet (ﷺ) said: If you have trained dogs, then eat what they catch for you. He asked: Whether it is slaughtered or not? He replied: Yes. He asked: Does it apply even if it eats any of it? He replied: Even if it eats any of it. He again asked: Messenger of Allah, tell me your opinion about my bow (i.e. the game hunted by arrow). He said: Eat what your bow returns to you, whether it is slaughtered or not. He asked: If it goes out of my sight? He replied: Even if it goes out of your sight, provided it has no stench, or you find a mark on it other than the mark of your arrow. He asked: Tell me about the use of the vessels of the Magians when we are forced to use them. He replied: Wash them and eat in them}}
\hadithdefcmd{abudawud}{2858}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي وَاقِدٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَا قُطِعَ مِنَ الْبَهِيمَةِ وَهِيَ حَيَّةٌ فَهِيَ مَيْتَةٌ ‏"‏ ‏.‏\hadithno{2858}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuWaqid: The Prophet (ﷺ) said: Whatever is cut off of an animal when it is alive is dead}}
\hadithdefcmd{abudawud}{2859}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنِي أَبُو مُوسَى، عَنْ وَهْبِ بْنِ مُنَبِّهٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم - وَقَالَ مَرَّةً سُفْيَانُ وَلاَ أَعْلَمُهُ إِلاَّ عَنِ النَّبِيِّ صلى الله عليه وسلم - وَقَالَ ‏ "‏ مَنْ سَكَنَ الْبَادِيَةَ جَفَا وَمَنِ اتَّبَعَ الصَّيْدَ غَفَلَ وَمَنْ أَتَى السُّلْطَانَ افْتُتِنَ ‏"‏ ‏.‏\hadithno{2859}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: (the narrator Sufyan said: I do not know but that it [the tradition] has been transmitted from the Prophet (ﷺ): He who lives in the desert will become rude; he who pursues the game will be negligent, and he who visits a king will be perverted}}
\hadithdefcmd{abudawud}{2860}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا الْحَسَنُ بْنُ الْحَكَمِ النَّخَعِيُّ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ شَيْخٍ، مِنَ الأَنْصَارِ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى مُسَدَّدٍ قَالَ ‏"‏ وَمَنْ لَزِمَ السُّلْطَانَ افْتُتِنَ ‏"‏ ‏.‏ زَادَ ‏"‏ وَمَا ازْدَادَ عَبْدٌ مِنَ السُّلْطَانِ دُنُوًّا إِلاَّ ازْدَادَ مِنَ اللَّهِ بُعْدًا ‏"‏ ‏.‏\hadithno{2860}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: He said: He who sticks to a king is perverted. This version adds: The nearer a servant (of Allah) goes to a king, the farther he keeps away from Allah}}
\hadithdefcmd{abudawud}{2861}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا حَمَّادُ بْنُ خَالِدٍ الْخَيَّاطُ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا رَمَيْتَ الصَّيْدَ فَأَدْرَكْتَهُ بَعْدَ ثَلاَثِ لَيَالٍ وَسَهْمُكَ فِيهِ فَكُلْهُ مَا لَمْ يُنْتِنْ ‏"‏ ‏.‏\hadithno{2861}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1931)}\hadithtrans{Narrated AbuTha'labah al-Khushani: The Prophet (ﷺ) said: When you shoot your arrow (and the animal goes out of your sight) and you come three days later on it, and in it there is your arrow, then eat provided it has not stench}}
