% Auto-generated chapter 18 for nasai
% Hadiths in this chapter: 27

\hadithdefcmd{nasai}{1529}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَشْعَثِ بْنِ أَبِي الشَّعْثَاءِ، عَنِ الأَسْوَدِ بْنِ هِلاَلٍ، عَنْ ثَعْلَبَةَ بْنِ زَهْدَمٍ، قَالَ كُنَّا مَعَ سَعِيدِ بْنِ الْعَاصِي بِطَبَرِسْتَانَ وَمَعَنَا حُذَيْفَةُ بْنُ الْيَمَانِ فَقَالَ أَيُّكُمْ صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْخَوْفِ فَقَالَ حُذَيْفَةُ أَنَا فَوَصَفَ فَقَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْخَوْفِ بِطَائِفَةٍ رَكْعَةً صَفٍّ خَلْفَهُ وَطَائِفَةٍ أُخْرَى بَيْنَهُ وَبَيْنَ الْعَدُوِّ فَصَلَّى بِالطَّائِفَةِ الَّتِي تَلِيهِ رَكْعَةً ثُمَّ نَكَصَ هَؤُلاَءِ إِلَى مَصَافِّ أُولَئِكَ وَجَاءَ أُولَئِكَ فَصَلَّى بِهِمْ رَكْعَةً ‏.‏\hadithno{1529}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Tha'labah bin Zahdam said:"We were with Sa'eed bin Al-'Asi in Tabaristan, and Hudhaifah bin Al-Yaman was with us. He said: 'Which of you offered the fear prayer with the Messenger of Allah (ﷺ)?' Hudhaifah said: 'I did', and he described it. He said: 'The Messenger of Allah (ﷺ) offered the fear prayer, leading one group who had formed rows behind him in praying one rak'ah, while the other group was between him and the enemy. So he led the group that was near him in praying one rak'ah, then they left and took the place of others, and the others came and he led them in praying one rak'ah}}
\hadithdefcmd{nasai}{1530}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي أَشْعَثُ بْنُ سُلَيْمٍ، عَنِ الأَسْوَدِ بْنِ هِلاَلٍ، عَنْ ثَعْلَبَةَ بْنِ زَهْدَمٍ، قَالَ كُنَّا مَعَ سَعِيدِ بْنِ الْعَاصِي بِطَبَرِسْتَانَ فَقَالَ أَيُّكُمْ صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْخَوْفِ فَقَالَ حُذَيْفَةُ أَنَا ‏.‏ فَقَامَ حُذَيْفَةُ فَصَفَّ النَّاسُ خَلْفَهُ صَفَّيْنِ صَفًّا خَلْفَهُ وَصَفًّا مُوَازِيَ الْعَدُوِّ فَصَلَّى بِالَّذِي خَلْفَهُ رَكْعَةً ثُمَّ انْصَرَفَ هَؤُلاَءِ إِلَى مَكَانِ هَؤُلاَءِ وَجَاءَ أُولَئِكَ فَصَلَّى بِهِمْ رَكْعَةً وَلَمْ يَقْضُوا ‏.‏\hadithno{1530}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Tha'labah bin Zahdam said:"We were with Sa'eed bin Al-'Asi in Tabaristan, and Hudhaifah bin Al-Yaman was with us. He said: 'Which of you offered the fear prayer with the Messenger of Allah (ﷺ)?' Hudhaifah said: 'I did.' So Hudhaifah stood and the people formed two rows behind him, one row behind him and one row facing the enemy. He led those who were behind him in praying one rak'ah, then they went and took the place of the others, and the others came and he led them in praying one rak'ah, and they did not make it up}}
\hadithdefcmd{nasai}{1531}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي الرُّكَيْنُ بْنُ الرَّبِيعِ، عَنِ الْقَاسِمِ بْنِ حَسَّانٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ صَلاَةِ حُذَيْفَةَ ‏.‏\hadithno{1531}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated from Zaid bin Thabit:A prayer like that of Hudhaifah was narrated from Zaid bin Thabit from the Prophet (ﷺ)}}
\hadithdefcmd{nasai}{1532}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ بُكَيْرِ بْنِ الأَخْنَسِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ فَرَضَ اللَّهُ الصَّلاَةَ عَلَى لِسَانِ نَبِيِّكُمْ صلى الله عليه وسلم فِي الْحَضَرِ أَرْبَعًا وَفِي السَّفَرِ رَكْعَتَيْنِ وَفِي الْخَوْفِ رَكْعَةً ‏.‏\hadithno{1532}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Abbas said:"Allah (SWT) enjoined the prayer on the tongue of your Prophet (ﷺ): four (rak'ahs) while a resident, two rak'ahs while traveling, and one rak'ah during times of fear}}
\hadithdefcmd{nasai}{1533}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي أَبُو بَكْرِ بْنُ أَبِي الْجَهْمِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى بِذِي قَرَدٍ وَصَفَّ النَّاسُ خَلْفَهُ صَفَّيْنِ صَفًّا خَلْفَهُ وَصَفًّا مُوَازِيَ الْعَدُوِّ فَصَلَّى بِالَّذِينَ خَلْفَهُ رَكْعَةً ثُمَّ انْصَرَفَ هَؤُلاَءِ إِلَى مَكَانِ هَؤُلاَءِ وَجَاءَ أُولَئِكَ فَصَلَّى بِهِمْ رَكْعَةً وَلَمْ يَقْضُوا ‏.‏\hadithno{1533}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that:The Messenger of Allah (ﷺ) prayed at Dhi Qarad and the people formed two rows behind him, one row behind him and one row facing the enemy. He led those who were behind him in praying one rak'ah, then they went and took the place of the others, and the others came and he led them in praying one rak'ah, and they did not make it up}}
\hadithdefcmd{nasai}{1534}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرٍ، عَنْ مُحَمَّدٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَامَ النَّاسُ مَعَهُ فَكَبَّرَ وَكَبَّرُوا ثُمَّ رَكَعَ وَرَكَعَ أُنَاسٌ مِنْهُمْ ثُمَّ سَجَدَ وَسَجَدُوا ثُمَّ قَامَ إِلَى الرَّكْعَةِ الثَّانِيَةِ فَتَأَخَّرَ الَّذِينَ سَجَدُوا مَعَهُ وَحَرَسُوا إِخْوَانَهُمْ وَأَتَتِ الطَّائِفَةُ الأُخْرَى فَرَكَعُوا مَعَ النَّبِيِّ صلى الله عليه وسلم وَسَجَدُوا وَالنَّاسُ كُلُّهُمْ فِي صَلاَةٍ يُكَبِّرُونَ وَلَكِنْ يَحْرُسُ بَعْضُهُمْ بَعْضًا ‏.‏\hadithno{1534}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Ubaidullah bin Abdullah bin Utbah that:'Abdullah bin 'Abbas said: "The Messenger of Allah (ﷺ) stood and the people stood with him, and he said the takbir and they said the takbir. Then he bowed, and some of them bowed, then he prostrated and they prostrated, then he stood for the second rak'ah and those who had prostrated with him moved back and guarded their brothers, and the other group came and bowed and prostrated with the Prophet (ﷺ). All the people were praying and saying the takbir, but they were guarding one another}}
\hadithdefcmd{nasai}{1535}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَمِّي، قَالَ حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، قَالَ حَدَّثَنِي دَاوُدُ بْنُ الْحُصَيْنِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَا كَانَتْ صَلاَةُ الْخَوْفِ إِلاَّ سَجْدَتَيْنِ كَصَلاَةِ أَحْرَاسِكُمْ هَؤُلاَءِ الْيَوْمَ خَلْفَ أَئِمَّتِكُمْ هَؤُلاَءِ إِلاَّ أَنَّهَا كَانَتْ عُقَبًا قَامَتْ طَائِفَةٌ مِنْهُمْ وَهُمْ جَمِيعًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَسَجَدَتْ مَعَهُ طَائِفَةٌ مِنْهُمْ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَامُوا مَعَهُ جَمِيعًا ثُمَّ رَكَعَ وَرَكَعُوا مَعَهُ جَمِيعًا ثُمَّ سَجَدَ فَسَجَدَ مَعَهُ الَّذِينَ كَانُوا قِيَامًا أَوَّلَ مَرَّةٍ فَلَمَّا جَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالَّذِينَ سَجَدُوا مَعَهُ فِي آخِرِ صَلاَتِهِمْ سَجَدَ الَّذِينَ كَانُوا قِيَامًا لأَنْفُسِهِمْ ثُمَّ جَلَسُوا فَجَمَعَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالتَّسْلِيمِ ‏.‏\hadithno{1535}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"The fear prayer was no more than two prostrations like the prayer of these guards of yours today behind the Imams of yours, except that it was one group after another. One group stood, although they were all behind the Messenger of Allah (ﷺ), and one group prostrated with him, then the Messenger of Allah (ﷺ) stood up and they all stood with him. Then he bowed and they all bowed with him, then he prostrated and those who had been standing the first time prostrated with him. When the Messenger of Allah (ﷺ) and those who had prostrated with him at the end of their prayer sat, those who had been standing prostrated by themselves, then they sat and the Messenger of Allah (ﷺ) said the taslim with all of them}}
\hadithdefcmd{nasai}{1536}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ صَالِحِ بْنِ خَوَّاتٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى بِهِمْ صَلاَةَ الْخَوْفِ فَصَفَّ صَفًّا خَلْفَهُ وَصَفًّا مُصَافُّو الْعَدُوِّ فَصَلَّى بِهِمْ رَكْعَةً ثُمَّ ذَهَبَ هَؤُلاَءِ وَجَاءَ أُولَئِكَ فَصَلَّى بِهِمْ رَكْعَةً ثُمَّ قَامُوا فَقَضَوْا رَكْعَةً رَكْعَةً ‏.‏\hadithno{1536}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salih bin Khawwat, from Sahl bin Abi Hathmah that:The Messenger of Allah (ﷺ) led them in offering the fear prayer. Some formed a row behind him and some formed a row facing the enemy. He led them in praying one rak'ah, then they moved away and the others came, and he led them in praying one rak'ah, then they got up and each (group) made up the other rak'ah}}
\hadithdefcmd{nasai}{1537}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ رُومَانَ، عَنْ صَالِحِ بْنِ خَوَّاتٍ، عَمَّنْ صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ ذَاتِ الرِّقَاعِ صَلاَةَ الْخَوْفِ أَنَّ طَائِفَةً صَفَّتْ مَعَهُ وَطَائِفَةٌ وُجَاهَ الْعَدُوِّ فَصَلَّى بِالَّذِينَ مَعَهُ رَكْعَةً ثُمَّ ثَبَتَ قَائِمًا وَأَتَمُّوا لأَنْفُسَهِمْ ثُمَّ انْصَرَفُوا فَصَفُّوا وُجَاهَ الْعَدُوِّ وَجَاءَتِ الطَّائِفَةُ الأُخْرَى فَصَلَّى بِهِمُ الرَّكْعَةَ الَّتِي بَقِيَتْ مِنْ صَلاَتِهِ ثُمَّ ثَبَتَ جَالِسًا وَأَتَمُّوا لأَنْفُسِهِمْ ثُمَّ سَلَّمَ بِهِمْ ‏.‏\hadithno{1537}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salih bin Khawwat from one who had prayed the fear prayer with the Messenger of Allah (ﷺ) on the day of Dhat Ar-Riqa' that:One group had formed a row behind him and another group faced the enemy. He led those who were with him in praying one rak'ah, then he remained standing and they completed the prayer by themselves. Then they moved away and formed a row facing the enemy, and the other group came and he led them in praying the rak'ah that was left for him, then he remained sitting while they completed the prayer by themselves, then he said the taslim with them}}
\hadithdefcmd{nasai}{1538}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، عَنْ يَزِيدَ بْنِ زُرَيْعٍ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى بِإِحْدَى الطَّائِفَتَيْنِ رَكْعَةً وَالطَّائِفَةُ الأُخْرَى مُوَاجِهَةُ الْعَدُوِّ ثُمَّ انْطَلَقُوا فَقَامُوا فِي مَقَامِ أُولَئِكَ وَجَاءَ أُولَئِكَ فَصَلَّى بِهِمْ رَكْعَةً أُخْرَى ثُمَّ سَلَّمَ عَلَيْهِمْ فَقَامَ هَؤُلاَءِ فَقَضُوا رَكْعَتَهُمْ وَقَامَ هَؤُلاَءِ فَقَضُوا رَكْعَتَهُمْ ‏.‏\hadithno{1538}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim from his father, that:The Messenger of Allah (ﷺ) led one of the two groups in praying one rak'ah while the other group was facing the enemy, then they moved away and took the place of the others, and the others came and he led them in praying the other rak'ah, then he said the salam and they stood up and made up the other rak'ah, and the others stood up and made up the other rak'ah}}
\hadithdefcmd{nasai}{1539}{أَخْبَرَنِي كَثِيرُ بْنُ عُبَيْدٍ، عَنْ بَقِيَّةَ، عَنْ شُعَيْبٍ، قَالَ حَدَّثَنِي الزُّهْرِيُّ، قَالَ حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قِبَلَ نَجْدٍ فَوَازَيْنَا الْعَدُوَّ وَصَافَفْنَاهُمْ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِنَا فَقَامَتْ طَائِفَةٌ مِنَّا مَعَهُ وَأَقْبَلَ طَائِفَةٌ عَلَى الْعَدُوِّ فَرَكَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَنْ مَعَهُ رَكْعَةً وَسَجَدَ سَجْدَتَيْنِ ثُمَّ انْصَرَفُوا فَكَانُوا مَكَانَ أُولَئِكَ الَّذِينَ لَمْ يُصَلُّوا وَجَاءَتِ الطَّائِفَةُ الَّتِي لَمْ تُصَلِّ فَرَكَعَ بِهِمْ رَكْعَةً وَسَجْدَتَيْنِ ثُمَّ سَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَامَ كُلُّ رَجُلٍ مِنَ الْمُسْلِمِينَ فَرَكَعَ لِنَفْسِهِ رَكْعَةً وَسَجْدَتَيْنِ ‏.‏\hadithno{1539}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Salim bin 'Abdullah narrated that his father said:"I went out on a campaign with the Messenger of Allah (ﷺ) toward Najd. We confronted the enemy and formed ranks facing them. The Messenger of Allah (ﷺ) stood up and led us in prayer. Some of us stood with him and some of us faced the enemy. The Messenger of Allah (ﷺ) bowed and those who were with him bowed, and prostrated twice. Then they moved away and took the place of the others, and the other group who had not prayed came and he led them in bowing once and prostrating twice. Then the Messenger of Allah (ﷺ) said the salam and each of the Muslims stood up and bowed once, and prostrated twice individually}}
\hadithdefcmd{nasai}{1540}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحِيمِ الْبَرْقِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ يُوسُفَ، قَالَ أَنْبَأَنَا سَعِيدُ بْنُ عَبْدِ الْعَزِيزِ، عَنِ الزُّهْرِيِّ، قَالَ كَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ يُحَدِّثُ أَنَّهُ صَلَّى صَلاَةَ الْخَوْفِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ كَبَّرَ النَّبِيُّ صلى الله عليه وسلم وَصَفَّ خَلْفَهُ طَائِفَةٌ مِنَّا وَأَقْبَلَتْ طَائِفَةٌ عَلَى الْعَدُوِّ فَرَكَعَ بِهِمُ النَّبِيُّ صلى الله عليه وسلم رَكْعَةً وَسَجْدَتَيْنِ ثُمَّ انْصَرَفُوا وَأَقْبَلُوا عَلَى الْعَدُوِّ وَجَاءَتِ الطَّائِفَةُ الأُخْرَى فَصَلُّوا مَعَ النَّبِيِّ صلى الله عليه وسلم فَفَعَلَ مِثْلَ ذَلِكَ ثُمَّ سَلَّمَ ثُمَّ قَامَ كُلُّ رَجُلٍ مِنَ الطَّائِفَتَيْنِ فَصَلَّى لِنَفْسِهِ رَكْعَةً وَسَجْدَتَيْنِ ‏.‏\hadithno{1540}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Az-Zuhri said:"Abdullah bin 'Umar used to narrate that he offered the fear prayer with the Messenger of Allah (ﷺ). He said: 'The Prophet (ﷺ) said the takbir and one group of us formed a row behind him while the other group faced the enemy. The Prophet (ﷺ) led them in bowing once and prostrating twice, then they moved away and faced the enemy, and the other group came and prayed with the Prophet (ﷺ), doing likewise. Then he said the taslim, then each man of both groups stood and prayed by himself, bowing once and prostrating twice}}
\hadithdefcmd{nasai}{1541}{أَخْبَرَنِي عِمْرَانُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ الْمُبَارَكِ، قَالَ أَنْبَأَنَا الْهَيْثَمُ بْنُ حُمَيْدٍ، عَنِ الْعَلاَءِ، وَأَبِي، أَيُّوبَ عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْخَوْفِ قَامَ فَكَبَّرَ فَصَلَّى خَلْفَهُ طَائِفَةٌ مِنَّا وَطَائِفَةٌ مُوَاجِهَةَ الْعَدُوِّ فَرَكَعَ بِهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَةً وَسَجَدَ سَجْدَتَيْنِ ثُمَّ انْصَرَفُوا وَلَمْ يُسَلِّمُوا وَأَقْبَلُوا عَلَى الْعَدُوِّ فَصَفُّوا مَكَانَهُمْ وَجَاءَتِ الطَّائِفَةُ الأُخْرَى فَصَفُّوا خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصَلَّى بِهِمْ رَكْعَةً وَسَجْدَتَيْنِ ثُمَّ سَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ أَتَمَّ رَكْعَتَيْنِ وَأَرْبَعَ سَجَدَاتٍ ثُمَّ قَامَتِ الطَّائِفَتَانِ فَصَلَّى كُلُّ إِنْسَانٍ مِنْهُمْ لِنَفْسِهِ رَكْعَةً وَسَجْدَتَيْنِ ‏.‏ قَالَ أَبُو بَكْرِ بْنُ السُّنِّيِّ الزُّهْرِيُّ سَمِعَ مِنِ ابْنِ عُمَرَ حَدِيثَيْنِ وَلَمْ يَسْمَعْ هَذَا مِنْهُ ‏.‏\hadithno{1541}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin Umar said:"The Messenger of Allah (ﷺ) offered the fear prayer. He stood and said the takbir, and a group of us prayed behind him while another group was facing the enemy. The Messenger of Allah (ﷺ) bowed once and prostrated twice with them, then they moved away but did not say the taslim. They went to face the enemy and lined up in their places, and the other group came and formed a row behind the Messenger of Allah (ﷺ), and he led them in praying, bowing once and prostrating twice. Then the Messenger of Allah (ﷺ) said the taslim and he had bowed twice and prostrated four times. Then the two groups stood up and each man prayed by himself, bowing once and prostrating twice." Abu Bakr IB As-Sunni said: "Az-Zuhri heard two hadiths from Ibn 'Umar, and he did not hear this from him}}
\hadithdefcmd{nasai}{1542}{أَخْبَرَنَا عَبْدُ الأَعْلَى بْنُ وَاصِلِ بْنِ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ سُفْيَانَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْخَوْفِ فِي بَعْضِ أَيَّامِهِ فَقَامَتْ طَائِفَةٌ مَعَهُ وَطَائِفَةٌ بِإِزَاءِ الْعَدُوِّ فَصَلَّى بِالَّذِينَ مَعَهُ رَكْعَةً ثُمَّ ذَهَبُوا وَجَاءَ الآخَرُونَ فَصَلَّى بِهِمْ رَكْعَةً ثُمَّ قَضَتِ الطَّائِفَتَانِ رَكْعَةً رَكْعَةً ‏.‏\hadithno{1542}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah (ﷺ) offered the fear prayer during one of his battles. One group stood with him and another group faced the enemy. He led those who were with him in praying one rak'ah, then they went away and the others came, and he led them in praying one rak'ah. Then each group made up one rak'ah}}
\hadithdefcmd{nasai}{1543}{أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ فَضَالَةَ بْنِ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا حَيْوَةُ، وَذَكَرَ، آخَرَ قَالاَ حَدَّثَنَا أَبُو الأَسْوَدِ، أَنَّهُ سَمِعَ عُرْوَةَ بْنَ الزُّبَيْرِ، يُحَدِّثُ عَنْ مَرْوَانَ بْنِ الْحَكَمِ، أَنَّهُ سَأَلَ أَبَا هُرَيْرَةَ هَلْ صَلَّيْتَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْخَوْفِ فَقَالَ أَبُو هُرَيْرَةَ نَعَمْ ‏.‏ قَالَ مَتَى قَالَ عَامَ غَزْوَةِ نَجْدٍ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِصَلاَةِ الْعَصْرِ وَقَامَتْ مَعَهُ طَائِفَةٌ وَطَائِفَةٌ أُخْرَى مُقَابِلَ الْعَدُوِّ وَظُهُورُهُمْ إِلَى الْقِبْلَةِ فَكَبَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَكَبَّرُوا جَمِيعًا الَّذِينَ مَعَهُ وَالَّذِينَ يُقَابِلُونَ الْعَدُوَّ ثُمَّ رَكَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَةً وَاحِدَةً وَرَكَعَتْ مَعَهُ الطَّائِفَةُ الَّتِي تَلِيهِ ثُمَّ سَجَدَ وَسَجَدَتِ الطَّائِفَةُ الَّتِي تَلِيهِ وَالآخَرُونَ قِيَامٌ مُقَابِلَ الْعَدُوِّ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَامَتِ الطَّائِفَةُ الَّتِي مَعَهُ فَذَهَبُوا إِلَى الْعَدُوِّ فَقَابَلُوهُمْ وَأَقْبَلَتِ الطَّائِفَةُ الَّتِي كَانَتْ مُقَابِلَ الْعَدُوِّ فَرَكَعُوا وَسَجَدُوا وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ كَمَا هُوَ ثُمَّ قَامُوا فَرَكَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَةً أُخْرَى وَرَكَعُوا مَعَهُ وَسَجَدَ وَسَجَدُوا مَعَهُ ثُمَّ أَقْبَلَتِ الطَّائِفَةُ الَّتِي كَانَتْ مُقَابِلَ الْعَدُوِّ فَرَكَعُوا وَسَجَدُوا وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَاعِدٌ وَمَنْ مَعَهُ ثُمَّ كَانَ السَّلاَمُ فَسَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَسَلَّمُوا جَمِيعًا فَكَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم رَكْعَتَانِ وَلِكُلِّ رَجُلٍ مِنَ الطَّائِفَتَيْنِ رَكْعَتَانِ رَكْعَتَانِ ‏.‏\hadithno{1543}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Marwan bin Al-Hakam that:He asked Abu Hurairah: "Did you offer the fear prayer with the Messenger of Allah (ﷺ)?" Abu Hurairah said: "Yes." He asked: "When?" He said: "In the year of the campaign to Najd. The Messenger of Allah (ﷺ) stood up to pray 'Asr and a group stood with him, and another group as facing the enemy, with their backs toward the Qiblah. The Messenger of Allah (ﷺ) said the takbir, and they all said the takbir, those who were with him and those who were with him facing the enemy. Then the Messenger of Allah (ﷺ) bowed once and the group that was with him bowed, then he and the group that was with him prostrated twice, while the others were standing facing the enemy. Then the Messenger of Allah (ﷺ) stood up and the group that was with him stood and went to face the enemy, and the group that had been facing the enemy came and bowed and prostrated while the Messenger of Allah (ﷺ) was standing there. Then they stood up, and the Messenger of Allah (ﷺ) bowed again, and they bowed and prostrated with him. Then the group that had been facing the enemy came and bowed and prostrated, while the Messenger of Allah (ﷺ) and those who were with him were sitting. Then the Messenger of Allah (ﷺ) said the taslim and they all said the taslim. So the Messenger of Allah (ﷺ) had prayed two rak'ahs and each of the two groups had prayed two rak'ahs}}
\hadithdefcmd{nasai}{1544}{أَخْبَرَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، قَالَ حَدَّثَنِي عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ عُبَيْدٍ الْهُنَائِيُّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ شَقِيقٍ، قَالَ حَدَّثَنَا أَبُو هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَازِلاً بَيْنَ ضَجْنَانَ وَعُسْفَانَ مُحَاصِرَ الْمُشْرِكِينَ فَقَالَ الْمُشْرِكُونَ إِنَّ لِهَؤُلاَءِ صَلاَةً هِيَ أَحَبُّ إِلَيْهِمْ مِنْ أَبْنَائِهِمْ وَأَبْكَارِهِمْ أَجْمِعُوا أَمْرَكُمْ ثُمَّ مِيلُوا عَلَيْهِمْ مَيْلَةً وَاحِدَةً فَجَاءَ جِبْرِيلُ عَلَيْهِ السَّلاَمُ فَأَمَرَهُ أَنْ يَقْسِمَ أَصْحَابَهُ نِصْفَيْنِ فَيُصَلِّيَ بِطَائِفَةٍ مِنْهُمْ وَطَائِفَةٌ مُقْبِلُونَ عَلَى عَدُوِّهِمْ قَدْ أَخَذُوا حِذْرَهُمْ وَأَسْلِحَتَهُمْ فَيُصَلِّيَ بِهِمْ رَكْعَةً ثُمَّ يَتَأَخَّرَ هَؤُلاَءِ وَيَتَقَدَّمَ أُولَئِكَ فَيُصَلِّيَ بِهِمْ رَكْعَةً تَكُونُ لَهُمْ مَعَ النَّبِيِّ صلى الله عليه وسلم رَكْعَةً رَكْعَةً وَلِلنَّبِيِّ صلى الله عليه وسلم رَكْعَتَانِ ‏.‏\hadithno{1544}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah said:"The Messenger of Allah (ﷺ) was camping between Dajnan and 'Usfan, besieging the idolaters. The idolaters said: 'These people have a prayer that is dearer to them than their sons and daughters. Plan it, then strike them with a single heavy blow.' Jibril, peace be upon him, came and told the Messenger of Allah (ﷺ) to divide his companions into two groups, then lead one group in prayer while the others faced the enemy, on guard and with weapons at the ready. So he led them in praying one rak'ah, then they moved back and the others moved forward, and he led them in praying on rak'ah, so that each one of them had prayed one rak'ah with the Prophet (ﷺ) and the Prophet (ﷺ) had prayed two rak'ahs}}
\hadithdefcmd{nasai}{1545}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ، عَنْ حَجَّاجِ بْنِ مُحَمَّدٍ، عَنْ شُعْبَةَ، عَنِ الْحَكَمِ، عَنْ يَزِيدَ الْفَقِيرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى بِهِمْ صَلاَةَ الْخَوْفِ فَقَامَ صَفٌّ بَيْنَ يَدَيْهِ وَصَفٌّ خَلْفَهُ صَلَّى بِالَّذِينَ خَلْفَهُ رَكْعَةً وَسَجْدَتَيْنِ ثُمَّ تَقَدَّمَ هَؤُلاَءِ حَتَّى قَامُوا فِي مَقَامِ أَصْحَابِهِمْ وَجَاءَ أُولَئِكَ فَقَامُوا مَقَامَ هَؤُلاَءِ وَصَلَّى بِهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَةً وَسَجْدَتَيْنِ ثُمَّ سَلَّمَ فَكَانَتْ لِلنَّبِيِّ صلى الله عليه وسلم رَكْعَتَانِ وَلَهُمْ رَكْعَةٌ ‏.‏\hadithno{1545}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah that:The Messenger of Allah (ﷺ) led them in offering the fear prayer. One row stood in front of him and another row stood behind him. He led those who were behind in prayer, bowing once and prostrating twice, then they moved forward until they took the place of their companions, and the others came and took their place, and the Messenger of Allah (ﷺ) led them in prayer, bowing once and prostrating twice, then he said the taslim, so the Prophet (ﷺ) had prayed two rak'ahs and they had prayed one}}
\hadithdefcmd{nasai}{1546}{أَخْبَرَنَا أَحْمَدُ بْنُ الْمِقْدَامِ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ الْمَسْعُودِيُّ، قَالَ أَنْبَأَنِي يَزِيدُ الْفَقِيرُ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأُقِيمَتِ الصَّلاَةُ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَامَتْ خَلْفَهُ طَائِفَةٌ وَطَائِفَةٌ مُوَاجِهَةَ الْعَدُوِّ فَصَلَّى بِالَّذِينَ خَلْفَهُ رَكْعَةً وَسَجَدَ بِهِمْ سَجْدَتَيْنِ ثُمَّ إِنَّهُمُ انْطَلَقُوا فَقَامُوا مَقَامَ أُولَئِكَ الَّذِينَ كَانُوا فِي وَجْهِ الْعَدُوِّ وَجَاءَتْ تِلْكَ الطَّائِفَةُ فَصَلَّى بِهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَةً وَسَجَدَ بِهِمْ سَجْدَتَيْنِ ثُمَّ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَلَّمَ فَسَلَّمَ الَّذِينَ خَلْفَهُ وَسَلَّمَ أُولَئِكَ ‏.‏\hadithno{1546}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir bin Abdullah said:"We were with the Messenger of Allah (ﷺ) and the Iqamah for prayer was said. The Messenger of Allah (ﷺ) stood up and one group stood behind him while another group faced the enemy. He led those who were behind him in prayer, bowing once and prostrating twice. Then they went and took the place of those who had been facing the enemy, and that group came and the Messenger of Allah (ﷺ) led them in prayer, bowing once and prostrating twice. Then the Messenger of Allah (ﷺ) said the taslim and those who were behind him said the taslim, as did the other group}}
\hadithdefcmd{nasai}{1547}{أَخْبَرَنَا عَلِيُّ بْنُ الْحُسَيْنِ الدِّرْهَمِيُّ، وَإِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالاَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ شَهِدْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْخَوْفِ فَقُمْنَا خَلْفَهُ صَفَّيْنِ وَالْعَدُوُّ بَيْنَنَا وَبَيْنَ الْقِبْلَةِ فَكَبَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَبَّرْنَا وَرَكَعَ وَرَكَعْنَا وَرَفَعَ وَرَفَعْنَا فَلَمَّا انْحَدَرَ لِلسُّجُودِ سَجَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالَّذِينَ يَلُونَهُ وَقَامَ الصَّفُّ الثَّانِي حِينَ رَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالصَّفُّ الَّذِينَ يَلُونَهُ ثُمَّ سَجَدَ الصَّفُّ الثَّانِي حِينَ رَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي أَمْكِنَتِهِمْ ثُمَّ تَأَخَّرَ الصَّفُّ الَّذِينَ كَانُوا يَلُونَ النَّبِيَّ صلى الله عليه وسلم وَتَقَدَّمَ الصَّفُّ الآخَرُ فَقَامَ فِي مَقَامِهِمْ وَقَامَ هَؤُلاَءِ فِي مَقَامِ الآخَرِينَ قِيَامًا وَرَكَعَ النَّبِيُّ صلى الله عليه وسلم وَرَكَعْنَا ثُمَّ رَفَعَ وَرَفَعْنَا فَلَمَّا انْحَدَرَ لِلسُّجُودِ سَجَدَ الَّذِينَ يَلُونَهُ وَالآخَرُونَ قِيَامٌ فَلَمَّا رَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالَّذِينَ يَلُونَهُ سَجَدَ الآخَرُونَ ثُمَّ سَلَّمَ ‏.‏\hadithno{1547}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"We witnessed the fear prayer with the Messenger of Allah (ﷺ). We stood behind him in two rows, and the enemy was between us and the Qiblah. The Messenger of Allah (ﷺ) said the takbir. He bowed and we bowed, and he stood up again and we stood up. When he went down in prostration, the Messenger of Allah (ﷺ) and those who were closest to him prostrated, and the second row remained standing until the Messenger of Allah (ﷺ) and the row closest to him stood up. Then the second row prostrated when the Messenger of Allah (ﷺ) had stood up, where they were. Then the row that had been closest to the Prophet (ﷺ) moved back and the second row moved forward, each standing in the place where the other had been. The Prophet (ﷺ) bowed and we bowed, then he stood up and we stood up, and when he went down in prostration, those who were closest to him prostrated and the others remained standing. When the Messenger of Allah (ﷺ) and those who were closest to him sat up, the others prostrated, then he said the taslim}}
\hadithdefcmd{nasai}{1548}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِنَخْلٍ وَالْعَدُوُّ بَيْنَنَا وَبَيْنَ الْقِبْلَةِ فَكَبَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَكَبَّرُوا جَمِيعًا ثُمَّ رَكَعَ فَرَكَعُوا جَمِيعًا ثُمَّ سَجَدَ النَّبِيُّ صلى الله عليه وسلم وَالصَّفُّ الَّذِي يَلِيهِ وَالآخَرُونَ قِيَامٌ يَحْرُسُونَهُمْ فَلَمَّا قَامُوا سَجَدَ الآخَرُونَ مَكَانَهُمُ الَّذِينَ كَانُوا فِيهِ ثُمَّ تَقَدَّمَ هَؤُلاَءِ إِلَى مَصَافِّ هَؤُلاَءِ فَرَكَعَ فَرَكَعُوا جَمِيعًا ثُمَّ رَفَعَ فَرَفَعُوا جَمِيعًا ثُمَّ سَجَدَ النَّبِيُّ صلى الله عليه وسلم وَالصَّفُّ الَّذِينَ يَلُونَهُ وَالآخَرُونَ قِيَامٌ يَحْرُسُونَهُمْ فَلَمَّا سَجَدُوا وَجَلَسُوا سَجَدَ الآخَرُونَ مَكَانَهُمْ ثُمَّ سَلَّمَ ‏.‏ قَالَ جَابِرٌ كَمَا يَفْعَلُ أُمَرَاؤُكُمْ ‏.‏\hadithno{1548}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"We were with the Prophet (ﷺ) in a palm grove and the enemy was between us and the Qiblah. The Messenger of Allah (ﷺ) said the takbir and we all said the takbir. Then he bowed and we all bowed. Then the Prophet (ﷺ) and the row that was closest to him prostrated, while the others remained standing, guarding us. When we stood up, the others prostrated where we were, then they moved forward and he bowed and they all bowed, then he stood up and they all stood up. Then the Prophet (ﷺ) and the row that was closest to him prostrated, and the others remained standing, guarding them. When they had prostrated and were sitting, the others prostrated where they were, then he said the salam." Jabir said: "As your leaders do}}
\hadithdefcmd{nasai}{1549}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، قَالَ سَمِعْتُ مُجَاهِدًا، يُحَدِّثُ عَنْ أَبِي عَيَّاشٍ الزُّرَقِيِّ، قَالَ شُعْبَةُ كَتَبَ بِهِ إِلَىَّ وَقَرَأْتُهُ عَلَيْهِ وَسَمِعْتُهُ مِنْهُ يُحَدِّثُ وَلَكِنِّي حَفِظْتُهُ قَالَ ابْنُ بَشَّارٍ فِي حَدِيثِهِ حِفْظِي مِنَ الْكِتَابِ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ مُصَافَّ الْعَدُوِّ بِعُسْفَانَ وَعَلَى الْمُشْرِكِينَ خَالِدُ بْنُ الْوَلِيدِ فَصَلَّى بِهِمُ النَّبِيُّ صلى الله عليه وسلم الظُّهْرَ قَالَ الْمُشْرِكُونَ إِنَّ لَهُمْ صَلاَةً بَعْدَ هَذِهِ هِيَ أَحَبُّ إِلَيْهِمْ مِنْ أَمْوَالِهِمْ وَأَبْنَائِهِمْ فَصَلَّى بِهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم الْعَصْرَ فَصَفَّهُمْ صَفَّيْنِ خَلْفَهُ فَرَكَعَ بِهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم جَمِيعًا فَلَمَّا رَفَعُوا رُءُوسَهُمْ سَجَدَ بِالصَّفِّ الَّذِي يَلِيهِ وَقَامَ الآخَرُونَ فَلَمَّا رَفَعُوا رُءُوسَهُمْ مِنَ السُّجُودِ سَجَدَ الصَّفُّ الْمُؤَخَّرُ بِرُكُوعِهِمْ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ تَأَخَّرَ الصَّفُّ الْمُقَدَّمُ وَتَقَدَّمَ الصَّفُّ الْمُؤَخَّرُ فَقَامَ كُلُّ وَاحِدٍ مِنْهُمْ فِي مَقَامِ صَاحِبِهِ ثُمَّ رَكَعَ بِهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم جَمِيعًا فَلَمَّا رَفَعُوا رُءُوسَهُمْ مِنَ الرُّكُوعِ سَجَدَ الصَّفُّ الَّذِي يَلِيهِ وَقَامَ الآخَرُونَ فَلَمَّا فَرَغُوا مِنْ سُجُودِهِمْ سَجَدَ الآخَرُونَ ثُمَّ سَلَّمَ النَّبِيُّ صلى الله عليه وسلم عَلَيْهِمْ ‏.‏\hadithno{1549}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Shu'bah narrated from Mansur who said:"I heard Mujahid narrating from Abu Ayyash Az-Zuraqi"- Shu'bah said: "He had written it for me, and I read it before him, and I heard him narrating it; rather, I even memorized it." Ibn Bashshar said: "I memorized it from the book"- "The Prophet (ﷺ) was drawing up ranks facing the enemy in 'Usfan when the idolaters were led by Khalid bin Al-Walid. The Prophet (ﷺ) led them in praying Zuhr. The idolaters said: 'They have a prayer after this that is dearer to them than their wealth and sons.' Then the Messenger of Allah (ﷺ) led them in praying 'Asr. He divided them into two rows, behind him. He led them all in bowing, then when they raised their heads he led the row that was closest to him in prostrating, while the others remained standing. When they raised their heads from prostration, the second row prostrated, as they had already bowed with the Messenger of Allah (ﷺ). Then the front row moved forward, so each of them took the place of his companion. Then the Messenger of Allah (ﷺ) led them all in bowing, then when they raised their heads from bowing, the row that was closest to him prostrated while the others remained standing, then when they had finished prostrating, the others prostrated, then the Prophet (ﷺ) said the taslim for all of them together}}
\hadithdefcmd{nasai}{1550}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ، قَالَ حَدَّثَنَا مَنْصُورٌ، عَنْ مُجَاهِدٍ، عَنْ أَبِي عَيَّاشٍ الزُّرَقِيِّ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِعُسْفَانَ فَصَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الظُّهْرِ وَعَلَى الْمُشْرِكِينَ يَوْمَئِذٍ خَالِدُ بْنُ الْوَلِيدِ فَقَالَ الْمُشْرِكُونَ لَقَدْ أَصَبْنَا مِنْهُمْ غِرَّةً وَلَقَدْ أَصَبْنَا مِنْهُمْ غَفْلَةً ‏.‏ فَنَزَلَتْ - يَعْنِي صَلاَةَ الْخَوْفِ - بَيْنَ الظُّهْرِ وَالْعَصْرِ فَصَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْعَصْرِ فَفَرَّقَنَا فِرْقَتَيْنِ فِرْقَةً تُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم وَفِرْقَةً يَحْرُسُونَهُ فَكَبَّرَ بِالَّذِينَ يَلُونَهُ وَالَّذِينَ يَحْرُسُونَهُمْ ثُمَّ رَكَعَ فَرَكَعَ هَؤُلاَءِ وَأُولَئِكَ جَمِيعًا ثُمَّ سَجَدَ الَّذِينَ يَلُونَهُ وَتَأَخَّرَ هَؤُلاَءِ وَالَّذِينَ يَلُونَهُ وَتَقَدَّمَ الآخَرُونَ فَسَجَدُوا ثُمَّ قَامَ فَرَكَعَ بِهِمْ جَمِيعًا الثَّانِيَةَ بِالَّذِينَ يَلُونَهُ وَبِالَّذِينَ يَحْرُسُونَهُ ثُمَّ سَجَدَ بِالَّذِينَ يَلُونَهُ ثُمَّ تَأَخَّرُوا فَقَامُوا فِي مَصَافِّ أَصْحَابِهِمْ وَتَقَدَّمَ الآخَرُونَ فَسَجَدُوا ثُمَّ سَلَّمَ عَلَيْهِمْ فَكَانَتْ لِكُلِّهِمْ رَكْعَتَانِ رَكْعَتَانِ مَعَ إِمَامِهِمْ وَصَلَّى مَرَّةً بِأَرْضِ بَنِي سُلَيْمٍ ‏.‏\hadithno{1550}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu 'Ayyash Al-Zuraqi said:"We were with the Messenger of Allah (ﷺ) in 'Usfan and the Messenger of Allah (ﷺ) led us in praying Zuhr. The idolaters were led that day by Khalid bin Al-Walid, and the idolaters said: 'We have caught them unawares.' Then the fear prayer was revealed between Zuhr and 'Asr. The Messenger of Allah (ﷺ) led us in praying 'Asr and divided us into two groups, a group that prayed with the Prophet (ﷺ) and a group that guarded him. He said takbir with those who were closest to him and those who were guarding them, then he bowed and both groups bowed with him. Then those who were closest to him prostrated. Then they moved back and the others moved forward and prostrated. Then he stood and led them all in bowing, those who were closest to him and those who were guarding him. Then he led those who were closest to him in prostrating, then they moved back and took the place of their companions and the others came forward and prostrated. Then he said the taslim so each group had prayed two rak'ahs with their imam. And he offered the fear prayer once in the land of Banu Sulaym}}
\hadithdefcmd{nasai}{1551}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، وَإِسْمَاعِيلُ بْنُ مَسْعُودٍ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا خَالِدٌ، عَنْ أَشْعَثَ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى بِالْقَوْمِ فِي الْخَوْفِ رَكْعَتَيْنِ ثُمَّ سَلَّمَ ثُمَّ صَلَّى بِالْقَوْمِ الآخَرِينَ رَكْعَتَيْنِ ثُمَّ سَلَّمَ فَصَلَّى النَّبِيُّ صلى الله عليه وسلم أَرْبَعًا ‏.‏\hadithno{1551}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Bakrah that:The Messenger of Allah (ﷺ) led the people in offering the fear prayer, two rak'ahs. Then he said the taslim and led others in offering the fear prayer, then he said the taslim. So the Prophet (ﷺ) had prayed four rak'ahs}}
\hadithdefcmd{nasai}{1552}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى بِطَائِفَةٍ مِنْ أَصْحَابِهِ رَكْعَتَيْنِ ثُمَّ سَلَّمَ ثُمَّ صَلَّى بِآخَرِينَ أَيْضًا رَكْعَتَيْنِ ثُمَّ سَلَّمَ ‏.‏\hadithno{1552}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin 'Abdullah that:The Prophet (ﷺ) led a group of his companions in praying two rak'ahs, then he said the taslim, then he led some others in praying two rak'ahs, then he said the taslim}}
\hadithdefcmd{nasai}{1553}{أَخْبَرَنَا أَبُو حَفْصٍ، عَمْرُو بْنُ عَلِيٍّ قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ صَالِحِ بْنِ خَوَّاتٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، فِي صَلاَةِ الْخَوْفِ قَالَ يَقُومُ الإِمَامُ مُسْتَقْبِلَ الْقِبْلَةِ وَتَقُومُ طَائِفَةٌ مِنْهُمْ مَعَهُ وَطَائِفَةٌ قِبَلَ الْعَدُوِّ وَوُجُوهُهُمْ إِلَى الْعَدُوِّ فَيَرْكَعُ بِهِمْ رَكْعَةً وَيَرْكَعُونَ لأَنْفُسِهِمْ وَيَسْجُدُونَ سَجْدَتَيْنِ فِي مَكَانِهِمْ وَيَذْهَبُونَ إِلَى مَقَامِ أُولَئِكَ وَيَجِيءُ أُولَئِكَ فَيَرْكَعُ بِهِمْ وَيَسْجُدُ بِهِمْ سَجْدَتَيْنِ فَهِيَ لَهُ ثِنْتَانِ وَلَهُمْ وَاحِدَةٌ ثُمَّ يَرْكَعُونَ رَكْعَةً رَكْعَةً وَيَسْجُدُونَ سَجْدَتَيْنِ ‏.‏\hadithno{1553}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Sahl bin Abi Hathmah said concerning the fear prayer:"The imam should stand up facing the Qiblah and some of them should stand with him while the others stand facing the enemy. Then he should pray one rak'ah with them and they should pray another rak'ah by themselves, and prostrate twice where they are. Then they should go to where the others are and the others should come and he should lead them in bowing once and prostrating twice, so it will be two rak'ahs for him and one for them. Then they should bow once and prostrate twice (by themselves, to make up the other rak'ah)}}
\hadithdefcmd{nasai}{1554}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا يُونُسُ، عَنِ الْحَسَنِ، قَالَ حَدَّثَ جَابِرُ بْنُ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى بِأَصْحَابِهِ صَلاَةَ الْخَوْفِ فَصَلَّتْ طَائِفَةٌ مَعَهُ وَطَائِفَةٌ وُجُوهُهُمْ قِبَلَ الْعَدُوِّ فَصَلَّى بِهِمْ رَكْعَتَيْنِ ثُمَّ قَامُوا مَقَامَ الآخَرِينَ وَجَاءَ الآخَرُونَ فَصَلَّى بِهِمْ رَكْعَتَيْنِ ثُمَّ سَلَّمَ ‏.‏\hadithno{1554}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir bin 'Abdullah narrated that :The Messenger of Allah (ﷺ) led his companions in offering the fear prayer. One group prayed with him while the other was facing the enemy. He led them in praying two rak'ahs, then they went and took the place of the others, and the others came and he led them in praying two rak'ahs, then he said the taslim}}
\hadithdefcmd{nasai}{1555}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا الأَشْعَثُ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى صَلاَةَ الْخَوْفِ بِالَّذِينَ خَلْفَهُ رَكْعَتَيْنِ وَالَّذِينَ جَاءُوا بَعْدُ رَكْعَتَيْنِ فَكَانَتْ لِلنَّبِيِّ صلى الله عليه وسلم أَرْبَعَ رَكَعَاتٍ وَلِهَؤُلاَءِ رَكْعَتَيْنِ رَكْعَتَيْنِ ‏.‏\hadithno{1555}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Bakrah that:The Prophet (ﷺ) offered the fear prayer with those who were behind him, praying two rak'ahs (with them) and two rak'ahs with those who came after them, so the Prophet (ﷺ) prayed four rak'ahs and the others each prayed two rak'ahs}}
