% Auto-generated chapter 13 for ibnmajah
% Hadiths in this chapter: 67

\hadithdefcmd{ibnmajah}{2308}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَلَّى بْنُ مَنْصُورٍ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، عَنْ عُثْمَانَ بْنِ مُحَمَّدٍ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ جُعِلَ قَاضِيًا بَيْنَ النَّاسِ فَقَدْ ذُبِحَ بِغَيْرِ سِكِّينٍ ‏"‏ ‏.‏\hadithno{2308}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Whoever is appointed judge between the people, he has been slaughtered without a knife.”}}
\hadithdefcmd{ibnmajah}{2309}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ عَبْدِ الأَعْلَى، عَنْ بِلاَلِ بْنِ أَبِي مُوسَى، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَأَلَ الْقَضَاءَ وُكِلَ إِلَى نَفْسِهِ وَمَنْ جُبِرَ عَلَيْهِ نَزَلَ إِلَيْهِ مَلَكٌ فَسَدَّدَهُ ‏"‏ ‏.‏\hadithno{2309}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“Whoever asks to be appointed a judge, will be entrusted to himself, but “Whoever asks to be appointed a judge, will be entrusted to himself, but whoever is forced to accept position, an angel will come down to him and guide him.' ”}}
\hadithdefcmd{ibnmajah}{2310}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَعْلَى، وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي الْبَخْتَرِيِّ، عَنْ عَلِيٍّ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْيَمَنِ فَقُلْتُ يَا رَسُولَ اللَّهِ تَبْعَثُنِي وَأَنَا شَابٌّ أَقْضِي بَيْنَهُمْ وَلاَ أَدْرِي مَا الْقَضَاءُ قَالَ فَضَرَبَ فِي صَدْرِي بِيَدِهِ ثُمَّ قَالَ ‏ "‏ اللَّهُمَّ اهْدِ قَلْبَهُ وَثَبِّتْ لِسَانَهُ ‏"‏ ‏.‏ قَالَ فَمَا شَكَكْتُ بَعْدُ فِي قَضَاءٍ بَيْنَ اثْنَيْنِ ‏.‏\hadithno{2310}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:“The Messenger of Allah (ﷺ) sent me to Yemen. I said: 'O Messenger of Allah, you are sending me to judge between them while I am a young man, and I do not know how to judge.' He struck me on the chest with his hand and said: 'O Allah, guide his heart and make his tongue steadfast.' And after that I never doubted in passing judgment between two people.”}}
\hadithdefcmd{ibnmajah}{2311}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، حَدَّثَنَا مُجَالِدٌ، عَنْ عَامِرٍ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ حَاكِمٍ يَحْكُمُ بَيْنَ النَّاسِ إِلاَّ جَاءَ يَوْمَ الْقِيَامَةِ وَمَلَكٌ آخِذٌ بِقَفَاهُ ثُمَّ يَرْفَعُ رَأْسَهُ إِلَى السَّمَاءِ فَإِنْ قَالَ أَلْقِهِ أَلْقَاهُ فِي مَهْوَاةٍ أَرْبَعِينَ خَرِيفًا ‏"‏ ‏.‏\hadithno{2311}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah said:“The Messenger of Allah (ﷺ) said: “There is no judge who judges between the people but on the Day of Resurrection an angel will come and take hold of the back of his head towards the sky and if it said: “Throw him, “he will throw into an abyss the depth of forty autumns (years).' ”}}
\hadithdefcmd{ibnmajah}{2312}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِلاَلٍ، عَنْ عِمْرَانَ الْقَطَّانِ، عَنْ حُسَيْنٍ، - يَعْنِي ابْنَ عِمْرَانَ - عَنْ أَبِي إِسْحَاقَ الشَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ مَعَ الْقَاضِي مَا لَمْ يَجُرْ فَإِذَا جَارَ وَكَلَهُ إِلَى نَفْسِهِ ‏"‏ ‏.‏\hadithno{2312}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin Abu Awfa that the Messenger of Allah (ﷺ) said:“Allah is with the judge so long as he is not unjust, but if he rules unjustly, He entrusts him to himself.”}}
\hadithdefcmd{ibnmajah}{2313}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ خَالِهِ الْحَارِثِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَعْنَةُ اللَّهِ عَلَى الرَّاشِي وَالْمُرْتَشِي ‏"‏ ‏.‏\hadithno{2313}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that the Messenger of Allah (ﷺ) said:“The curse of Allah is upon the one who offers a bribe and the one who takes it.”}}
\hadithdefcmd{ibnmajah}{2314}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، حَدَّثَنَا يَزِيدُ بْنُ عَبْدِ اللَّهِ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي قَيْسٍ، - مَوْلَى عَمْرِو بْنِ الْعَاصِ - عَنْ عَمْرِو بْنِ الْعَاصِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا حَكَمَ الْحَاكِمُ فَاجْتَهَدَ فَأَصَابَ فَلَهُ أَجْرَانِ وَإِذَا حَكَمَ فَاجْتَهَدَ فَأَخْطَأَ فَلَهُ أَجْرٌ ‏"‏ ‏.‏ قَالَ يَزِيدُ فَحَدَّثْتُ بِهِ أَبَا بَكْرِ بْنَ عَمْرِو بْنِ حَزْمٍ، فَقَالَ هَكَذَا حَدَّثَنِيهِ أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَة‏.‏َ\hadithno{2314}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Amr bin 'As that he heard the Messenger of Allah (ﷺ) say:“When the judge passes a judgement and does his best and gets it right, he will have two rewards, and if he passes a judgement and does his best and gets it wrong, he will have one reward.” (Sahih) Yazid (one of narrators) said : “So I Narrated it to Abu Bakr bin 'Amr bin Hazm. He said: 'This is how it was narrated to me by Abu Salamah from Abu Hurairah.'”}}
\hadithdefcmd{ibnmajah}{2315}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ تَوْبَةَ، حَدَّثَنَا خَلَفُ بْنُ خَلِيفَةَ، حَدَّثَنَا أَبُو هَاشِمٍ، قَالَ لَوْلاَ حَدِيثُ ابْنِ بُرَيْدَةَ عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْقُضَاةُ ثَلاَثَةٌ اثْنَانِ فِي النَّارِ وَوَاحِدٌ فِي الْجَنَّةِ رَجُلٌ عَلِمَ الْحَقَّ فَقَضَى بِهِ فَهُوَ فِي الْجَنَّةِ وَرَجُلٌ قَضَى لِلنَّاسِ عَلَى جَهْلٍ فَهُوَ فِي النَّارِ وَرَجُلٌ جَارَ فِي الْحُكْمِ فَهُوَ فِي النَّارِ ‏"‏ ‏.‏ لَقُلْنَا إِنَّ الْقَاضِيَ إِذَا اجْتَهَدَ فَهُوَ فِي الْجَنَّةِ ‏.‏\hadithno{2315}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hashim said:“Were it not for the Hadith of Ibn Buraidah from his father, from the Prophet (ﷺ) who said: 'Judges are of three types, two of whom will be in Hell and one will be in Paradise. The man who knows the truth and rules in accordance with it, will be in Paradise. The man who passes judgment on the people in ignorance will be in Hell' - we would have said that if the judge does his best he will be in Paradise.”}}
\hadithdefcmd{ibnmajah}{2316}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، وَأَحْمَدُ بْنُ ثَابِتٍ الْجَحْدَرِيُّ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، أَنَّهُ سَمِعَ عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقْضِي الْقَاضِي بَيْنَ اثْنَيْنِ وَهُوَ غَضْبَانُ ‏"‏ ‏.‏ قَالَ هِشَامٌ لاَ يَنْبَغِي لِلْحَاكِمِ أَنْ يَقْضِيَ بَيْنَ اثْنَيْنِ وَهُوَ غَضْبَانُ ‏.‏\hadithno{2316}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdul-Malik bin 'Umair that he heard 'Abdur-Rahman bin Abu Bakrah (narrate) from his father that the Messenger of Allah (ﷺ) said:“Let the judge (Qadi) not pass a judgment when he is angry.”}}
\hadithdefcmd{ibnmajah}{2317}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّكُمْ تَخْتَصِمُونَ إِلَىَّ وَإِنَّمَا أَنَا بَشَرٌ وَلَعَلَّ بَعْضَكُمْ أَنْ يَكُونَ أَلْحَنَ بِحُجَّتِهِ مِنْ بَعْضٍ وَإِنَّمَا أَقْضِي بَيْنَكُمْ عَلَى نَحْوٍ مِمَّا أَسْمَعُ مِنْكُمْ فَمَنْ قَضَيْتُ لَهُ مِنْ حَقِّ أَخِيهِ شَيْئًا فَلاَ يَأْخُذْهُ فَإِنَّمَا أَقْطَعُ لَهُ قِطْعَةً مِنَ النَّارِ يَأْتِي بِهَا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2317}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Umm Salamah that the Messenger of Allah (ﷺ) said:“You refer your disputes to me and I am only human. Perhaps some of you may be more eloquent in presenting your case than others, so I rule in your favor because of what I hear from you. If I pass a judgement in favor of one of you that detracts from his brother's rights, then he should not take it, because it is a piece of fire that is given to him which he will bring forth on the Day Resurrection.”}}
\hadithdefcmd{ibnmajah}{2318}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا أَنَا بَشَرٌ وَلَعَلَّ بَعْضَكُمْ أَنْ يَكُونَ أَلْحَنَ بِحُجَّتِهِ مِنْ بَعْضٍ فَمَنْ قَطَعْتُ لَهُ مِنْ حَقِّ أَخِيهِ قِطْعَةً فَإِنَّمَا أَقْطَعُ لَهُ قِطْعَةً مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{2318}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“I am only human, and some of you may be more eloquent in presenting your case than others. If I pass a judgement in his favor that detracts from his brother's rights, I am giving him a piece of fire.”}}
\hadithdefcmd{ibnmajah}{2319}{حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ بْنِ عَبْدِ الْوَارِثِ بْنِ سَعِيدٍ أَبُو عُبَيْدَةَ، حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي أَبِي، حَدَّثَنِي الْحُسَيْنُ بْنُ ذَكْوَانَ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، قَالَ حَدَّثَنِي يَحْيَى بْنُ يَعْمُرَ، أَنَّ أَبَا الأَسْوَدِ الدِّيلِيَّ، حَدَّثَهُ عَنْ أَبِي ذَرٍّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ ادَّعَى مَا لَيْسَ لَهُ فَلَيْسَ مِنَّا وَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{2319}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Dharr that he heard the Messenger of Allah (ﷺ) say:“Whoever claims something that does not belong to him; he is not one of us, so let him take his place in Hell.”}}
\hadithdefcmd{ibnmajah}{2320}{حَدَّثَنَا مُحَمَّدُ بْنُ ثَعْلَبَةَ بْنِ سَوَاءٍ، حَدَّثَنِي عَمِّي، مُحَمَّدُ بْنُ سَوَاءٍ عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ مَطَرٍ الْوَرَّاقِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعَانَ عَلَى خُصُومَةٍ بِظُلْمٍ - أَوْ يُعِينُ عَلَى ظُلْمٍ - لَمْ يَزَلْ فِي سَخَطِ اللَّهِ حَتَّى يَنْزِعَ ‏"‏ ‏.‏\hadithno{2320}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:“Whoever takes the wrongdoer's side in a dispute or supports wrongdoing, he will remain subject to the wrath of Allah until he gives it up.”}}
\hadithdefcmd{ibnmajah}{2321}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا ابْنُ جُرَيْجٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ يُعْطَى النَّاسُ بِدَعْوَاهُمُ ادَّعَى نَاسٌ دِمَاءَ رِجَالٍ وَأَمْوَالَهُمْ وَلَكِنِ الْيَمِينُ عَلَى الْمُدَّعَى عَلَيْهِ ‏"‏ ‏.‏\hadithno{2321}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah (ﷺ) said:“If the people were given what they claimed, some would have claimed the lives and property of men. But the one the claim is made against is obliged to swear an oath.”}}
\hadithdefcmd{ibnmajah}{2322}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، وَأَبُو مُعَاوِيَةَ قَالاَ حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنِ الأَشْعَثِ بْنِ قَيْسٍ، قَالَ كَانَ بَيْنِي وَبَيْنَ رَجُلٍ مِنَ الْيَهُودِ أَرْضٌ فَجَحَدَنِي فَقَدَّمْتُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ لَكَ بَيِّنَةٌ ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ قَالَ لِلْيَهُودِيِّ ‏"‏ احْلِفْ ‏"‏ ‏.‏ قُلْتُ إِذًا يَحْلِفَ فَيَذْهَبَ بِمَالِي ‏.‏ فَأَنْزَلَ اللَّهُ سُبْحَانَهُ ‏\{إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً\}‏ إِلَى آخِرِ الآيَةِ ‏.‏\hadithno{2322}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ash'ath bin Qais Said:“There was a dispute between myself and a Jewish man concerning some land, and he denied me my rights so I brought him to the Prophet (ﷺ). The Messenger of Allah (ﷺ) said to me: 'Do you have proof' I said: 'No.’ He said to the Jews, 'Swear an oath.' I said: 'If he swears an oath he will take my property.' Then Allah, Glorious is He, revealed: 'Verily, those who purchase a small gain at the cost of Allah's covenant and their oaths, they shall have no portion in the Hereafter (Paradise). Neither will Allah neither speak to them nor look at them on the Day of Resurrection nor will He purifies them, and they shall have a painful torment.'”}}
\hadithdefcmd{ibnmajah}{2323}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا وَكِيعٌ، وَأَبُو مُعَاوِيَةَ قَالاَ حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ عَلَى يَمِينٍ وَهُوَ فِيهَا فَاجِرٌ يَقْتَطِعُ بِهَا مَالَ امْرِئٍ مُسْلِمٍ لَقِيَ اللَّهَ وَهُوَ عَلَيْهِ غَضْبَانُ ‏"‏ ‏.‏\hadithno{2323}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin Mas'ud that the Messenger of Allah (ﷺ) said:“Whoever swears a false oath in order to seize the wealth of a Muslim unlawfully, he will meet Allah when He is angry with him.”}}
\hadithdefcmd{ibnmajah}{2324}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ، أَنَّهُ سَمِعَ أَخَاهُ عَبْدَ اللَّهِ بْنَ كَعْبٍ، أَنَّ أَبَا أُمَامَةَ الْحَارِثِيَّ، حَدَّثَهُ أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يَقْتَطِعُ رَجُلٌ حَقَّ امْرِئٍ مُسْلِمٍ بِيَمِينِهِ إِلاَّ حَرَّمَ اللَّهُ عَلَيْهِ الْجَنَّةَ وَأَوْجَبَ لَهُ النَّارَ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ يَا رَسُولَ اللَّهِ وَإِنْ كَانَ شَيْئًا يَسِيرًا قَالَ ‏"‏ وَإِنْ كَانَ سِوَاكًا مِنْ أَرَاكٍ ‏"‏ ‏.‏\hadithno{2324}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Umamah Al-Harithi narrated that he heard the Messenger of Allah (ﷺ) say:“No man seizes the wealth of a Muslim unlawfully by means of his (false) oath, but Allah will deny Paradise to him and will doom him to Hell.” A man among the people said: “O Messenger of Allah, even if it is something small?” He said: “Even if it is a twig of an Arak tree.”}}
\hadithdefcmd{ibnmajah}{2325}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ ثَابِتٍ الْجَحْدَرِيُّ، حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا هَاشِمُ بْنُ هَاشِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ نِسْطَاسٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَلَفَ بِيَمِينٍ آثِمَةٍ عِنْدَ مِنْبَرِي هَذَا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ وَلَوْ عَلَى سِوَاكٍ أَخْضَرَ ‏"‏ ‏.‏\hadithno{2325}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah that the Messenger of Allah (ﷺ) said:'Whoever swears a false oath near this pulpit of mine, let him take his place in Hell, even if it is for a green twig.”}}
\hadithdefcmd{ibnmajah}{2326}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَزَيْدُ بْنُ أَخْزَمَ، قَالاَ حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، حَدَّثَنَا الْحَسَنُ بْنُ يَزِيدَ بْنِ فَرُّوخَ، - قَالَ مُحَمَّدُ بْنُ يَحْيَى وَهُوَ أَبُو يُونُسَ الْقَوِيُّ - قَالَ سَمِعْتُ أَبَا سَلَمَةَ، يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحْلِفُ عِنْدَ هَذَا الْمِنْبَرِ عَبْدٌ وَلاَ أَمَةٌ عَلَى يَمِينٍ آثِمَةٍ وَلَوْ عَلَى سِوَاكٍ رَطْبٍ إِلاَّ وَجَبَتْ لَهُ النَّارُ ‏"‏ ‏.‏\hadithno{2326}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Muhammad bin Yahya, who is Abu Yunus Al-Qawi, said:I heard Abu Salamah say: I heard Abu Hurairah say: “The Messenger of Allah (ﷺ) said: 'No man or woman swears a false oath beside this pulpit, even if it is for a fresh twig, but he will be doomed to Hell.”}}
\hadithdefcmd{ibnmajah}{2327}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَعَا رَجُلاً مِنْ عُلَمَاءِ الْيَهُودِ فَقَالَ ‏ "‏ أَنْشُدُكَ بِاللَّهِ الَّذِي أَنْزَلَ التَّوْرَاةَ عَلَى مُوسَى ‏"‏ ‏.‏\hadithno{2327}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Bara' bin 'Azib that the Messenger of Allah (ﷺ) called one of the Jewish scholars and said:“ Swear by the One Who sent the Torah (Tawrah) down to Musa.”}}
\hadithdefcmd{ibnmajah}{2328}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ مُجَالِدٍ، أَنْبَأَنَا عَامِرٌ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِيَهُودِيَّيْنِ ‏ "‏ نَشَدْتُكُمَا بِاللَّهِ الَّذِي أَنْزَلَ التَّوْرَاةَ عَلَى مُوسَى عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏\hadithno{2328}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin 'Abdullah that the Messenger of Allah (ﷺ) said to two Jews:“Swear by Allah Who sent the Tawrah down to Musa, peace be upon him.”}}
\hadithdefcmd{ibnmajah}{2329}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ خِلاَسٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ ذَكَرَ أَنَّ رَجُلَيْنِ، ادَّعَيَا دَابَّةً وَلَمْ يَكُنْ بَيْنَهُمَا بَيِّنَةٌ فَأَمَرَهُمَا النَّبِيُّ صلى الله عليه وسلم أَنْ يَسْتَهِمَا عَلَى الْيَمِينِ ‏.‏\hadithno{2329}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that:he said that two men laid claim to an animal, and neither of them had any proof, so the Prophet (ﷺ) commanded them to cast lots as to which of them should swear an oath}}
\hadithdefcmd{ibnmajah}{2330}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، وَمُحَمَّدُ بْنُ مَعْمَرٍ، وَزُهَيْرُ بْنُ مُحَمَّدٍ، قَالُوا حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنْ أَبِي مُوسَى، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اخْتَصَمَ إِلَيْهِ رَجُلاَنِ بَيْنَهُمَا دَابَّةٌ وَلَيْسَ لِوَاحِدٍ مِنْهُمَا بَيِّنَةٌ فَجَعَلَهَا بَيْنَهُمَا نِصْفَيْنِ ‏.‏\hadithno{2330}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Musa that :two men referred a dispute to the Messenger of Allah (ﷺ) concerning an animal, and neither of them had proof, so he ruled that it should be divided in half}}
\hadithdefcmd{ibnmajah}{2331}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا حَجَّاجٌ، عَنْ سَعِيدِ بْنِ عُبَيْدِ بْنِ زَيْدِ بْنِ عُقْبَةَ، عَنْ أَبِيهِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا ضَاعَ لِلرَّجُلِ مَتَاعٌ أَوْ سُرِقَ لَهُ مَتَاعٌ فَوَجَدَهُ فِي يَدِ رَجُلٍ يَبِيعُهُ فَهُوَ أَحَقُّ بِهِ وَيَرْجِعُ الْمُشْتَرِي عَلَى الْبَائِعِ بِالثَّمَنِ ‏"‏ ‏.‏\hadithno{2331}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Samurah bin Jundub that the Messenger of Allah (ﷺ) said:“If a man loses something, or it is stolen from him, and he finds it in the possession of a man who bought it, then he has more right to it, and the one who bought it should ask for his money back from the one who sold it to him.' ”}}
\hadithdefcmd{ibnmajah}{2332}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ ابْنَ مُحَيِّصَةَ الأَنْصَارِيَّ، أَخْبَرَهُ أَنَّ نَاقَةً لِلْبَرَاءِ كَانَتْ ضَارِيَةً دَخَلَتْ فِي حَائِطِ قَوْمٍ فَأَفْسَدَتْ فِيهِ فَكُلِّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِيهَا فَقَضَى أَنَّ حِفْظَ الأَمْوَالِ عَلَى أَهْلِهَا بِالنَّهَارِ وَعَلَى أَهْلِ الْمَوَاشِي مَا أَصَابَتْ مَوَاشِيهِمْ بِاللَّيْلِ ‏.‏ حَدَّثَنَا الْحَسَنُ بْنُ عَلِيِّ بْنِ عَفَّانَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى، عَنِ الزُّهْرِيِّ، عَنْ حَرَامِ بْنِ مُحَيِّصَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ نَاقَةً، لآلِ الْبَرَاءِ أَفْسَدَتْ شَيْئًا فَقَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{2332}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn Shihab that :Ibn Muhayyisah Al-Ansari told him that a she-camel belonging to Bara used to wander free. It entered a garden belonging to some people and caused some damage. The Messenger of Allah (ﷺ) was told of that, and he ruled that property was to be protected by its owners of livestock were responsible for any damage caused by their animals during the night}}
\hadithdefcmd{ibnmajah}{2333}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكُ بْنُ عَبْدِ اللَّهِ، عَنْ قَيْسِ بْنِ وَهْبٍ، عَنْ رَجُلٍ، مِنْ بَنِي سُوَاءَةَ قَالَ قُلْتُ لِعَائِشَةَ أَخْبِرِينِي عَنْ خُلُقِ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَتْ أَوَمَا تَقْرَأُ الْقُرْآنَ ‏\{وَإِنَّكَ لَعَلَى خُلُقٍ عَظِيمٍ\}‏ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَعَ أَصْحَابِهِ فَصَنَعْتُ لَهُ طَعَامًا وَصَنَعَتْ حَفْصَةُ لَهُ طَعَامًا ‏.‏ قَالَتْ فَسَبَقَتْنِي حَفْصَةُ فَقُلْتُ لِلْجَارِيَةِ انْطَلِقِي فَأَكْفِئِي قَصْعَتَهَا فَلَحِقَتْهَا وَقَدْ هَوَتْ أَنْ تَضَعَ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَكْفَأَتْهَا فَانْكَسَرَتِ الْقَصْعَةُ وَانْتَشَرَ الطَّعَامُ ‏.‏ قَالَتْ فَجَمَعَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَا فِيهَا مِنَ الطَّعَامِ عَلَى النِّطَعِ فَأَكَلُوا ثُمَّ بَعَثَ بِقَصْعَتِي فَدَفَعَهَا إِلَى حَفْصَةَ فَقَالَ ‏"‏ خُذُوا ظَرْفًا مَكَانَ ظَرْفِكُمْ ‏"‏ ‏.‏ قَالَتْ فَمَا رَأَيْتُ ذَلِكَ فِي وَجْهِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2333}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that a man from Banu Suwa'ah said:'I said to 'Aishah: Tell me about the character of the Messenger of Allah (ﷺ).' She said: 'Have you not read the Qur'an: “And verily, you (O Mohammed \{SAW\}) are on an exalted (standard of) character?” She said: 'The Messenger of Allah (ﷺ) was with his Companions, and I made some food for him, and Hafsah made some food for him, but Hafash got there before me. So I said to the slave girl: “Overturn her bowl.” She went and caught up with her, and she was about to put (the bowl) in front of the Messenger of Allah (ﷺ). She overturned it and the bowl broke, scattering the food. The Messenger of Allah (ﷺ) gathered the pieces and the food on the leather mat and they ate. Then he sent for my bowl and gave it to Hafsah, and said: “Take this pot in place of your pot, and eat what is in it.” And I did not see any expression of anger on the face of the Messenger of Allah (ﷺ).' ”}}
\hadithdefcmd{ibnmajah}{2334}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم عِنْدَ إِحْدَى أُمَّهَاتِ الْمُؤْمِنِينَ فَأَرْسَلَتْ أُخْرَى بِقَصْعَةٍ فِيهَا طَعَامٌ فَضَرَبَتْ يَدَ الرَّسُولِ فَسَقَطَتِ الْقَصْعَةُ فَانْكَسَرَتْ فَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْكِسْرَتَيْنِ فَضَمَّ إِحْدَاهُمَا إِلَى الأُخْرَى فَجَعَلَ يَجْمَعُ فِيهَا الطَّعَامَ وَيَقُولُ ‏ "‏ غَارَتْ أُمُّكُمْ كُلُوا ‏"‏ ‏.‏ فَأَكَلُوا حَتَّى جَاءَتْ بِقَصْعَتِهَا الَّتِي فِي بَيْتِهَا فَدَفَعَ الْقَصْعَةَ الصَّحِيحَةَ إِلَى الرَّسُولِ وَتَرَكَ الْمَكْسُورَةَ فِي بَيْتِ الَّتِي كَسَرَتْهَا ‏.‏\hadithno{2334}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas bin Malik said:“The Prophet (ﷺ) was with one of the Mothers of the Believers (his wives) and another (wife) sent a bowl containing food. She (the first wife) struck the hand of the Messenger of (ﷺ) and the bowl fell and broke. The Messenger of Allah (ﷺ) took the two pieces and put them back together, then he started gathering up the food and putting it in (the bowl). He said: 'Your mother was jealous. Eat.' So they ate, and she (the wife who broke the bowl) brought the bowl that was in her house and gave the intact bowl to the Messenger (ﷺ), who left the broken bowl in the house of the one who broke it.”}}
\hadithdefcmd{ibnmajah}{2335}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَأْذَنَ أَحَدَكُمْ جَارُهُ أَنْ يَغْرِزَ خَشَبَةً فِي جِدَارِهِ فَلاَ يَمْنَعْهُ ‏"‏ ‏.‏ فَلَمَّا حَدَّثَهُمْ أَبُو هُرَيْرَةَ طَأْطَئُوا رُءُوسَهُمْ فَلَمَّا رَآهُمْ قَالَ مَالِي أَرَاكُمْ عَنْهَا مُعْرِضِينَ وَاللَّهِ لأَرْمِيَنَّ بِهَا بَيْنَ أَكْتَافِكُمْ ‏.‏\hadithno{2335}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:“The Prophet (ﷺ): 'When anyone of you asks his neighbor for permission to fix a piece of wood to his wall, he should not refuse him. 'When Abu Hurairah told them this, they lowered their heads, and when he saw them he said: 'Why do I see you turning away from it? By Allah, I will force you to accept it.' ”}}
\hadithdefcmd{ibnmajah}{2336}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، أَنَّ هِشَامَ بْنَ يَحْيَى، أَخْبَرَهُ أَنَّ عِكْرِمَةَ بْنَ سَلَمَةَ أَخْبَرَهُ أَنَّ أَخَوَيْنِ مِنْ بَلْمُغِيرَةَ أَعْتَقَ أَحَدُهُمَا أَنْ لاَ يَغْرِزَ خَشَبًا فِي جِدَارِهِ فَأَقْبَلَ مُجَمِّعُ بْنُ يَزِيدَ وَرِجَالٌ كَثِيرٌ مِنَ الأَنْصَارِ فَقَالُوا نَشْهَدُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمْنَعْ أَحَدُكُمْ جَارَهُ أَنْ يَغْرِزَ خَشَبَةً فِي جِدَارِهِ ‏"‏ ‏.‏ فَقَالَ يَا أَخِي إِنَّكَ مَقْضِيٌّ لَكَ عَلَىَّ وَقَدْ حَلَفْتُ فَاجْعَلْ أُسْطُوَانًا دُونَ حَائِطِي أَوْ جِدَارِي فَاجْعَلْ عَلَيْهِ خَشَبَكَ ‏.‏\hadithno{2336}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Ikrimah bin Salamh narrated that :there were two brothers from among the sons of Mughirah. One of them swore an oath to set a slave free if the other one fixed a piece of wood to his wall. Mujammi' bin Yazid and many men from among the Ansar came and said: “We bear witness that the Messenger of Allah (ﷺ) said: 'None of you should refuse to let his neighbor fix a piece of wood to his wall.' ” He said: 'O my brother, judgment has been passed in your favor against me, but I have sworn an oath.' So go ahead and fix your wood to my wall.”}}
\hadithdefcmd{ibnmajah}{2337}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ لَهِيعَةَ، عَنْ أَبِي الأَسْوَدِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمْنَعْ أَحَدُكُمْ جَارَهُ أَنْ يَضَعَ خَشَبَةً عَلَى جِدَارِهِ ‏"‏ ‏.‏\hadithno{2337}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Prophet (ﷺ) said:“No one of you should refuse to let his neighbor fix a piece of wood to his wall.”}}
\hadithdefcmd{ibnmajah}{2338}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا مُثَنَّى بْنُ سَعِيدٍ الضُّبَعِيُّ، عَنْ قَتَادَةَ، عَنْ بَشِيرِ بْنِ كَعْبٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اجْعَلُوا الطَّرِيقَ سَبْعَةَ أَذْرُعٍ ‏"‏ ‏.‏\hadithno{2338}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Make the path seven forearms length wide.”}}
\hadithdefcmd{ibnmajah}{2339}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ عُمَرَ بْنِ هَيَّاجٍ، قَالاَ حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا اخْتَلَفْتُمْ فِي الطَّرِيقِ فَاجْعَلُوهُ سَبْعَةَ أَذْرُعٍ ‏"‏ ‏.‏\hadithno{2339}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah (ﷺ) said:“When you dispute concerning a path, make it seven forearms length wide.' ”}}
\hadithdefcmd{ibnmajah}{2340}{حَدَّثَنَا عَبْدُ رَبِّهِ بْنُ خَالِدٍ النُّمَيْرِيُّ أَبُو الْمُغَلِّسِ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، حَدَّثَنَا إِسْحَاقُ بْنُ يَحْيَى بْنِ الْوَلِيدِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى أَنْ ‏ "‏ لاَ ضَرَرَ وَلاَ ضِرَارَ ‏"‏ ‏.‏\hadithno{2340}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Ubadah bin Samit that the Messenger of Allah (ﷺ) ruled:“There should be neither harming nor reciprocating harm.”}}
\hadithdefcmd{ibnmajah}{2341}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ جَابِرٍ الْجُعْفِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ ضَرَرَ وَلاَ ضِرَارَ ‏"‏ ‏.‏\hadithno{2341}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that the Messenger of Allah (ﷺ) said:“There should be neither harming nor reciprocating harm.”}}
\hadithdefcmd{ibnmajah}{2342}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ لُؤْلُؤَةَ، عَنْ أَبِي صِرْمَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ ضَارَّ أَضَرَّ اللَّهُ بِهِ وَمَنْ شَاقَّ شَقَّ اللَّهُ عَلَيْهِ ‏"‏ ‏.‏\hadithno{2342}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sirmah that the Messenger of Allah (ﷺ) said:“Whoever harms others, Allah (SWT) will harm him; and whoever causes hardship to other Allah will cause hardship to him.”}}
\hadithdefcmd{ibnmajah}{2343}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَعَمَّارُ بْنُ خَالِدٍ الْوَاسِطِيُّ، قَالاَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ دَهْثَمِ بْنِ قُرَّانٍ، عَنْ نِمْرَانَ بْنِ جَارِيَةَ، عَنْ أَبِيهِ، أَنَّ قَوْمًا، اخْتَصَمُوا إِلَى النَّبِيِّ صلى الله عليه وسلم فِي خُصٍّ كَانَ بَيْنَهُمْ فَبَعَثَ حُذَيْفَةَ يَقْضِي بَيْنَهُمْ فَقَضَى لِلَّذِينَ يَلِيهِمُ الْقِمْطُ فَلَمَّا رَجَعَ إِلَى النَّبِيِّ صلى الله عليه وسلم أَخْبَرَهُ فَقَالَ ‏ "‏ أَصَبْتَ وَأَحْسَنْتَ ‏"‏ ‏.‏\hadithno{2343}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Nimran bin Jariyah, from his father, that :some people referred a dispute to the Prophet (ﷺ) about a hut, so that he could judge between them. He sent Hudhaifah to judge between them, and he ruled in favor of those who had the rope (with which the hut was blinded together). When he went back to the Prophet (ﷺ) he told him (what he had done) and he said: “You did the right thing, and you did well.”}}
\hadithdefcmd{ibnmajah}{2344}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا بِيعَ الْبَيْعُ مِنْ رَجُلَيْنِ فَالْبَيْعُ لِلأَوَّلِ ‏"‏ ‏.‏ قَالَ أَبُو الْوَلِيدِ فِي هَذَا الْحَدِيثِ إِبْطَالُ الْخَلاَصِ ‏.‏\hadithno{2344}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ('Uqbah bin 'Amir or) Samurah bin Jundub that :the Messenger of Allah (ﷺ) said: “If a product is sold to two men, it is for the one who was first.”}}
\hadithdefcmd{ibnmajah}{2345}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَجُلاً، كَانَ لَهُ سِتَّةُ مَمْلُوكِينَ لَيْسَ لَهُ مَالٌ غَيْرُهُمْ فَأَعْتَقَهُمْ عِنْدَ مَوْتِهِ فَجَزَّأَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَعْتَقَ اثْنَيْنِ وَأَرَقَّ أَرْبَعَةً ‏.‏\hadithno{2345}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Imran bin Husain that :a man had six slaves, and he did not have any other wealth apart from them, and he set them free when he died. The Messenger of Allah (ﷺ) divided them into groups, set two free and left four as slaves}}
\hadithdefcmd{ibnmajah}{2346}{حَدَّثَنَا جَمِيلُ بْنُ الْحَسَنِ الْعَتَكِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ خِلاَسٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلَيْنِ، تَدَارَءَا فِي بَيْعٍ لَيْسَ لِوَاحِدٍ مِنْهُمَا بَيِّنَةٌ فَأَمَرَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَسْتَهِمَا عَلَى الْيَمِينِ أَحَبَّا ذَلِكَ أَمْ كَرِهَا ‏.‏\hadithno{2346}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that :two men disputed concerning a transaction, and neither of them had proof. The Messenger of Allah commanded them to draw lots as to which of them should swear an oath, whether they liked it or not}}
\hadithdefcmd{ibnmajah}{2347}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ يَمَانٍ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا سَافَرَ أَقْرَعَ بَيْنَ نِسَائِهِ ‏.‏\hadithno{2347}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that :when the Prophet (ﷺ) traveled, he would cast lots among his wives (to decide which one would accompany him)}}
\hadithdefcmd{ibnmajah}{2348}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا الثَّوْرِيُّ، عَنْ صَالِحٍ الْهَمْدَانِيِّ، عَنِ الشَّعْبِيِّ، عَنْ عَبْدِ خَيْرٍ الْحَضْرَمِيِّ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ أُتِيَ عَلِيُّ بْنُ أَبِي طَالِبٍ وَهُوَ بِالْيَمَنِ فِي ثَلاَثَةٍ قَدْ وَقَعُوا عَلَى امْرَأَةٍ فِي طُهْرٍ وَاحِدٍ فَسَأَلَ اثْنَيْنِ فَقَالَ أَتُقِرَّانِ لِهَذَا بِالْوَلَدِ فَقَالاَ لاَ ‏.‏ ثُمَّ سَأَلَ اثْنَيْنِ فَقَالَ أَتُقِرَّانِ لِهَذَا بِالْوَلَدِ فَقَالاَ لاَ ‏.‏ فَجَعَلَ كُلَّمَا سَأَلَ اثْنَيْنِ أَتُقِرَّانِ لِهَذَا بِالْوَلَدِ قَالاَ لاَ ‏.‏ فَأَقْرَعَ بَيْنَهُمْ وَأَلْحَقَ الْوَلَدَ بِالَّذِي أَصَابَتْهُ الْقُرْعَةُ وَجَعَلَ عَلَيْهِ ثُلُثَىِ الدِّيَةِ فَذُكِرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَضَحِكَ حَتَّى بَدَتْ نَوَاجِذُهُ ‏.‏\hadithno{2348}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Zaid bin Arqam said:“A case was brought to 'Ali bin Abu Talib when he was in Yemen, concerning three men who had intercourse with a woman during one period of being free from menses. He asked two of them: “Do you affirm that this child belongs to (the third man)?” And they said: “No.” He asked another two of them: “Do you affirm that this child belongs to (the third man)?” And they said: “No.” Every time he asked two of them whether they affirmed that the child belonged to the third, they would say no. So he cast lots between them, and attributed the child to the one whose name was chosen in this manner, and obliged him to pay two thirds of the Diyah. The Prophet (ﷺ) was told of this, and he smiled so broadly that his back teeth became visible}}
\hadithdefcmd{ibnmajah}{2349}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ مَسْرُورًا وَهُوَ يَقُولُ ‏"‏ يَا عَائِشَةُ أَلَمْ تَرَىْ أَنَّ مُجَزِّزًا الْمُدْلِجِيَّ دَخَلَ عَلَىَّ فَرَأَى أُسَامَةَ وَزَيْدًا عَلَيْهِمَا قَطِيفَةٌ قَدْ غَطَّيَا رُءُوسَهُمَا وَقَدْ بَدَتْ أَقْدَامُهُمَا فَقَالَ ‏"‏ إِنَّ هَذِهِ الأَقْدَامَ بَعْضُهَا مِنْ بَعْضٍ ‏"‏ ‏.‏\hadithno{2349}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:“The Messenger of Allah (ﷺ) came in one day looking happy, and said: 'O 'Aishah, did you not see that Mujazziz Al-Mudliji entered upon me and saw Usamah and Zaid. There was a blanket over them and their faces were covered but their feet were exposed, and he said: 'These feet belong to one another'.”}}
\hadithdefcmd{ibnmajah}{2350}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا إِسْرَائِيلُ، حَدَّثَنَا سِمَاكُ بْنُ حَرْبٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ قُرَيْشًا، أَتَوُا امْرَأَةً كَاهِنَةً فَقَالُوا لَهَا أَخْبِرِينَا أَشْبَهَنَا أَثَرًا بِصَاحِبِ الْمَقَامِ ‏.‏ فَقَالَتْ إِنْ أَنْتُمْ جَرَرْتُمْ كِسَاءً عَلَى هَذِهِ السِّهْلَةِ ثُمَّ مَشَيْتُمْ عَلَيْهَا أَنْبَأْتُكُمْ ‏.‏ قَالَ فَجَرُّوا كِسَاءً ثُمَّ مَشَى النَّاسُ عَلَيْهَا فَأَبْصَرَتْ أَثَرَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَتْ هَذَا أَقْرَبُكُمْ إِلَيْهِ شَبَهًا ‏.‏ ثُمَّ مَكَثُوا بَعْدَ ذَلِكَ عِشْرِينَ سَنَةً أَوْ مَا شَاءَ اللَّهُ ثُمَّ بَعَثَ اللَّهُ مُحَمَّدًا صلى الله عليه وسلم ‏.‏\hadithno{2350}\hadithgrade{Al-Albani: Munkar Daif; Muhammad Fouad Abd al-Baqi: Munkar Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that :the Quraish went to a sorceress and they said to her: “Tell us whose footprints most resemble those of the owner of Al-Maqam (the station of Ibrahim).” She said: “If you spread a piece of cloth over this soft earth and walk over it, I will tell you.” So they spread out a piece of cloth and the people walked over it. She saw the footprints of the Messenger of Allah (ﷺ) and said: “This one most closely resembles him among you.” After that twenty years passed, of as long as Allah willed, then Allah sent Muhammad (ﷺ) (i.e., missioned him as the Prophet)}}
\hadithdefcmd{ibnmajah}{2351}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ زِيَادِ بْنِ سَعْدٍ، عَنْ هِلاَلِ بْنِ أَبِي مَيْمُونَةَ، عَنْ أَبِي مَيْمُونَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَيَّرَ غُلاَمًا بَيْنَ أَبِيهِ وَأُمِّهِ وَقَالَ ‏ "‏ يَا غُلاَمُ هَذِهِ أُمُّكَ وَهَذَا أَبُوكَ ‏"‏ ‏.‏\hadithno{2351}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that :the Prophet (ﷺ) gave a child the choice between his father and his mother (i.e., which parent to live with). He said: “O boy, this is your mother and this is your father.”}}
\hadithdefcmd{ibnmajah}{2352}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ عُثْمَانَ الْبَتِّيِّ، عَنْ عَبْدِ الْحَمِيدِ بْنِ سَلَمَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ أَبَوَيْهِ، اخْتَصَمَا إِلَى النَّبِيِّ صلى الله عليه وسلم أَحَدُهُمَا كَافِرٌ وَالآخَرُ مُسْلِمٌ فَخَيَّرَهُ فَتَوَجَّهَ إِلَى الْكَافِرِ فَقَالَ ‏ "‏ اللَّهُمَّ اهْدِهِ ‏"‏ ‏.‏ فَتَوَجَّهَ إِلَى الْمُسْلِمِ فَقَضَى لَهُ بِهِ ‏.‏\hadithno{2352}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdul-Hamid bin Salamah, from his father, from his grandfather, that :his parents referred their dispute to the Prophet (ﷺ), and one of them was a disbeliever. He (the Prophet (ﷺ)) said: “O Allah, guide him,” and he turned towards the Muslim, and he ruled that he should go with that parent}}
\hadithdefcmd{ibnmajah}{2353}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا كَثِيرُ بْنُ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عَوْفٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الصُّلْحُ جَائِزٌ بَيْنَ الْمُسْلِمِينَ إِلاَّ صُلْحًا حَرَّمَ حَلاَلاً أَوْ أَحَلَّ حَرَامًا ‏"‏ ‏.‏\hadithno{2353}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Kathir bin 'Abdullah bin 'Amr bin 'Awf narrated from his father that his grandfather said:“I heard the Messenger of Allah (ﷺ) say: 'Reconciling between Muslims is permissible, except reconciliation that forbids something that is allowed, or allows something that is forbidden.'”}}
\hadithdefcmd{ibnmajah}{2354}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، كَانَ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي عُقْدَتِهِ ضَعْفٌ وَكَانَ يُبَايِعُ وَأَنَّ أَهْلَهُ أَتَوُا النَّبِيَّ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ احْجُرْ عَلَيْهِ ‏.‏ فَدَعَاهُ النَّبِيُّ صلى الله عليه وسلم فَنَهَاهُ عَنْ ذَلِكَ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي لاَ أَصْبِرُ عَنِ الْبَيْعِ ‏.‏ فَقَالَ ‏ "‏ إِذَا بَايَعْتَ فَقُلْ هَا وَلاَ خِلاَبَةَ ‏"‏ ‏.‏\hadithno{2354}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik that :there was a man at the time of the Messenger of Allah (ﷺ) whose mental faculties were lacking, and he used to buy and sell. His family came to the Prophet (ﷺ) and said, “O Messenger of Allah, stop him.” So The Prophet (ﷺ) called him, and told him not to do that. He said: “O Messenger of Allah (ﷺ), I cannot bear to be away from business.” He said, “If you engage in a transaction then say: “Take it (i.e., the goods) and don't cheat (me).' ”}}
\hadithdefcmd{ibnmajah}{2355}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانٍ، قَالَ هُوَ جَدِّي مُنْقِذُ بْنُ عَمْرٍو وَكَانَ رَجُلاً قَدْ أَصَابَتْهُ آمَّةٌ فِي رَأْسِهِ فَكَسَرَتْ لِسَانَهُ وَكَانَ لاَ يَدَعُ عَلَى ذَلِكَ التِّجَارَةَ وَكَانَ لاَ يَزَالُ يُغْبَنُ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ لَهُ ‏ "‏ إِذَا أَنْتَ بَايَعْتَ فَقُلْ لاَ خِلاَبَةَ ‏.‏ ثُمَّ أَنْتَ فِي كُلِّ سِلْعَةٍ ابْتَعْتَهَا بِالْخِيَارِ ثَلاَثَ لَيَالٍ فَإِنْ رَضِيتَ فَأَمْسِكْ وَإِنْ سَخِطْتَ فَارْدُدْهَا عَلَى صَاحِبِهَا ‏"‏ ‏.‏\hadithno{2355}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Muhammad bin Yahya bin Habban said:“My grandfather was Munqidh bin 'Amr. He was a man who had suffered a head wound and lost the power of speech, but that did not stop him from engaging in trade. He was always being cheated, so he went to the Prophet (ﷺ) and told him about that. He said to him: 'When you buy something, say: “There should be no intention of cheating,” and for every product you buy, you have the choice for three nights. If you are pleased with it, keep it, and if you are displeased then return it.'”}}
\hadithdefcmd{ibnmajah}{2356}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ بْنِ سَعْدٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ أُصِيبَ رَجُلٌ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ثِمَارٍ ابْتَاعَهَا فَكَثُرَ دَيْنُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَصَدَّقُوا عَلَيْهِ ‏"‏ ‏.‏ فَتَصَدَّقَ النَّاسُ عَلَيْهِ فَلَمْ يَبْلُغْ ذَلِكَ وَفَاءَ دَيْنِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خُذُوا مَا وَجَدْتُمْ وَلَيْسَ لَكُمْ إِلاَّ ذَلِكَ ‏"‏ ‏.‏ يَعْنِي الْغُرَمَاءَ ‏.‏\hadithno{2356}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:“At the time of the Messenger of Allah (ﷺ), a man suffered loss of some fruit that he had purchase, and his debts increased. The Messenger of Allah (ﷺ) said: 'Give him charity.' So the people gave him charity, but that was not enough to pay off his debts. The Messenger of Allah (ﷺ) said: “Take what you find, but you have no right to more than that, meaning his creditors.”}}
\hadithdefcmd{ibnmajah}{2357}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُسْلِمِ بْنِ هُرْمُزٍ، عَنْ سَلَمَةَ الْمَكِّيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَلَعَ مُعَاذَ بْنَ جَبَلٍ مِنْ غُرَمَائِهِ ثُمَّ اسْتَعْمَلَهُ عَلَى الْيَمَنِ فَقَالَ مُعَاذٌ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَخْلَصَنِي بِمَالِي ثُمَّ اسْتَعْمَلَنِي ‏.‏\hadithno{2357}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin 'Abdullah that :the Messenger of Allah (ﷺ) rid Mu'adh bin Jabal of his creditors, then he appointed him governor of Yemen. Mu'adh said: “The Messenger of Allah (ﷺ) settled my debts with my creditors using what wealth I had, then he appointed me as governor.”}}
\hadithdefcmd{ibnmajah}{2358}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، جَمِيعًا عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ وَجَدَ مَتَاعَهُ بِعَيْنِهِ عِنْدَ رَجُلٍ قَدْ أَفْلَسَ فَهُوَ أَحَقُّ بِهِ مِنْ غَيْرِهِ ‏"‏ ‏.‏\hadithno{2358}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever finds his exact property with a man who has become bankrupt, and then he has more right to it than anyone else.”}}
\hadithdefcmd{ibnmajah}{2359}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا رَجُلٍ بَاعَ سِلْعَةً فَأَدْرَكَ سِلْعَتَهُ بِعَيْنِهَا عِنْدَ رَجُلٍ وَقَدْ أَفْلَسَ وَلَمْ يَكُنْ قَبَضَ مِنْ ثَمَنِهَا شَيْئًا فَهِيَ لَهُ ‏.‏ وَإِنْ كَانَ قَبَضَ مِنْ ثَمَنِهَا شَيْئًا فَهُوَ أُسْوَةُ الْغُرَمَاءِ ‏"‏ ‏.‏\hadithno{2359}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Any man who sells a product with the man who has become bankrupt, and he has not taken any of its price, it belongs to him, but if he had taken any of its price, then he is like any other creditor.”}}
\hadithdefcmd{ibnmajah}{2360}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، وَعَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، قَالاَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ أَبِي الْمُعْتَمِرِ بْنِ عَمْرِو بْنِ رَافِعٍ، عَنِ ابْنِ خَلْدَةَ الزُّرَقِيِّ، وَكَانَ، قَاضِيًا بِالْمَدِينَةِ قَالَ جِئْنَا أَبَا هُرَيْرَةَ فِي صَاحِبٍ لَنَا قَدْ أَفْلَسَ فَقَالَ هَذَا الَّذِي قَضَى فِيهِ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَيُّمَا رَجُلٍ مَاتَ أَوْ أَفْلَسَ فَصَاحِبُ الْمَتَاعِ أَحَقُّ بِمَتَاعِهِ إِذَا وَجَدَهُ بِعَيْنِهِ ‏"‏ ‏.‏\hadithno{2360}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn Khaldah, who was a judge in Al-Madinah, said:We came to Abu Hurairah and asked him about a companion of ours who had become bankrupt. He said: “This is what the Prophet (ﷺ) ruled: 'Any man who dies or becomes bankrupt, the owner of the product has more right to it, if he finds the exact thing.”}}
\hadithdefcmd{ibnmajah}{2361}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا الْيَمَانُ بْنُ عَدِيٍّ، حَدَّثَنِي الزَّبِيدِيُّ، مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا امْرِئٍ مَاتَ وَعِنْدَهُ مَالُ امْرِئٍ بِعَيْنِهِ اقْتَضَى مِنْهُ شَيْئًا أَوْ لَمْ يَقْتَضِ فَهُوَ أُسْوَةُ الْغُرَمَاءِ ‏"‏ ‏.‏\hadithno{2361}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Any man who dies and has the property of another man, whether he paid something towards it or not, (the owner of those goods) is like any other creditor.”}}
\hadithdefcmd{ibnmajah}{2362}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَعَمْرُو بْنُ رَافِعٍ، قَالاَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ السَّلْمَانِيِّ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَىُّ النَّاسِ خَيْرٌ قَالَ ‏ "‏ قَرْنِي ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ يَجِيءُ قَوْمٌ تَبْدُرُ شَهَادَةُ أَحَدِهِمْ يَمِينَهُ وَيَمِينُهُ شَهَادَتَهُ ‏"‏ ‏.‏\hadithno{2362}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Mas'ud said:“The Messenger of Allah (ﷺ) was asked, 'Which of the people are best?' He said: 'My generation, then those that follow them, then those that follow them. Then there will come people whose testimony precedes their oath and whose oath precedes their testimony.”}}
\hadithdefcmd{ibnmajah}{2363}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، حَدَّثَنَا جَرِيرٌ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ خَطَبَنَا عُمَرُ بْنُ الْخَطَّابِ بِالْجَابِيَةِ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ فِينَا مِثْلَ مُقَامِي فِيكُمْ فَقَالَ ‏ "‏ احْفَظُونِي فِي أَصْحَابِي ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ يَفْشُو الْكَذِبُ حَتَّى يَشْهَدَ الرَّجُلُ وَمَا يُسْتَشْهَدُ وَيَحْلِفَ وَمَا يُسْتَحْلَفُ ‏"‏ ‏.‏\hadithno{2363}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jabir bin Samurah said:'Umar bin Khattab addressed us at Jabiyah and said: “The Messenger of Allah (ﷺ) stood up among us as I stand among you, and said: 'Honor my Companions for my sake, then those who come after them, then those who come after them. Then lying will prevail until a man will give testimony without being asked to do so, and he will swear an oath without being asked to do so.' ”}}
\hadithdefcmd{ibnmajah}{2364}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ الْجُعْفِيُّ، قَالاَ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ الْعُكْلِيُّ، أَخْبَرَنِي أُبَىُّ بْنُ عَبَّاسِ بْنِ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، حَدَّثَنِي أَبُو بَكْرِ بْنُ عَمْرِو بْنِ حَزْمٍ، حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عُثْمَانَ بْنِ عَفَّانَ، حَدَّثَنِي خَارِجَةُ بْنُ زَيْدِ بْنِ ثَابِتٍ، أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي عَمْرَةَ الأَنْصَارِيُّ، أَنَّهُ سَمِعَ زَيْدَ بْنَ خَالِدٍ الْجُهَنِيَّ، يَقُولُ إِنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ خَيْرُ الشُّهُودِ مَنْ أَدَّى شَهَادَتَهُ قَبْلَ أَنْ يُسْأَلَهَا ‏"‏ ‏.‏\hadithno{2364}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Zaid bin Khalid Al-Juhani said that he heard the Messenger of Allah (ﷺ) say:“The best of witnesses is the one who gives his testimony before he is asked for it.”}}
\hadithdefcmd{ibnmajah}{2365}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ يُوسُفَ الْجُبَيْرِيُّ، وَجَمِيلُ بْنُ الْحَسَنِ الْعَتَكِيُّ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ مَرْوَانَ الْعِجْلِيُّ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي نَضْرَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ تَلاَ هَذِهِ الآيَةَ ‏\{‏يَا أَيُّهَا الَّذِينَ آمَنُوا إِذَا تَدَايَنْتُمْ بِدَيْنٍ إِلَى أَجَلٍ مُسَمًّى ‏\}‏ حَتَّى بَلَغَ ‏\{‏فَإِنْ أَمِنَ بَعْضُكُمْ بَعْضًا‏\}‏ فَقَالَ هَذِهِ نَسَخَتْ مَا قَبْلَهَا ‏.‏\hadithno{2365}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that :Abu Sa'eed Al-Khudri recited this Verse: “O you who believe! When you contract a debt for a fixed period...” until: “then if one of you entrusts the other.” Then he said: “This abrogates what came before.”}}
\hadithdefcmd{ibnmajah}{2366}{حَدَّثَنَا أَيُّوبُ بْنُ مُحَمَّدٍ الرَّقِّيُّ، حَدَّثَنَا مَعْمَرُ بْنُ سُلَيْمَانَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ أَرْطَاةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَجُوزُ شَهَادَةُ خَائِنٍ وَلاَ خَائِنَةٍ وَلاَ مَحْدُودٍ فِي الإِسْلاَمِ وَلاَ ذِي غِمْرٍ عَلَى أَخِيهِ ‏"‏ ‏.‏\hadithno{2366}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Amr bin Shuaib from his father that his grandfather said:“The Testimony of a man or woman who is treacherous, or of one who has been subjected to one of the Haad punishments of Islam, or of one who bears a grudge against his brother, is not permissible.”}}
\hadithdefcmd{ibnmajah}{2367}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي نَافِعُ بْنُ يَزِيدَ، عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَجُوزُ شَهَادَةُ بَدَوِيٍّ عَلَى صَاحِبِ قَرْيَةٍ ‏"‏ ‏.‏\hadithno{2367}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) say:“The testimony of a Bedouin against a town-dweller is not permissible.”}}
\hadithdefcmd{ibnmajah}{2368}{حَدَّثَنَا أَبُو مُصْعَبٍ الْمَدِينِيُّ، أَحْمَدُ بْنُ عَبْدِ اللَّهِ الزُّهْرِيُّ وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى بِالْيَمِينِ مَعَ الشَّاهِدِ ‏.‏\hadithno{2368}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that:the Messenger of Allah (ﷺ) passed judgment on the basis of an oath (from the claimant) along with a (single) witness. [This is in the absence of two witnesses]}}
\hadithdefcmd{ibnmajah}{2369}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى بِالْيَمِينِ مَعَ الشَّاهِدِ ‏.‏\hadithno{2369}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir that:the Prophet (ﷺ) passed judgement on the basis of an oath (from the claimant) along with a (single) witness}}
\hadithdefcmd{ibnmajah}{2370}{حَدَّثَنَا أَبُو إِسْحَاقَ الْهَرَوِيُّ، إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ حَاتِمٍ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْحَارِثِ الْمَخْزُومِيُّ، حَدَّثَنَا سَيْفُ بْنُ سُلَيْمَانَ الْمَكِّيُّ، أَخْبَرَنِي قَيْسُ بْنُ سَعْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالشَّاهِدِ وَالْيَمِينِ ‏.‏\hadithno{2370}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn 'Abbas said:“The Messenger of Allah (ﷺ) passed judgement on the basis of a witness along with an oath by the claimant}}
\hadithdefcmd{ibnmajah}{2371}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا جُوَيْرِيَةُ بْنُ أَسْمَاءَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، - مَوْلَى الْمُنْبَعِثِ - عَنْ رَجُلٍ، مِنْ أَهْلِ مِصْرَ عَنْ سُرَّقٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَجَازَ شَهَادَةَ الرَّجُلِ وَيَمِينَ الطَّالِبِ ‏.‏\hadithno{2371}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Surraq that :the Prophet (ﷺ) allowed the testimony of a man along with the oath of the claimant}}
\hadithdefcmd{ibnmajah}{2372}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا سُفْيَانُ الْعُصْفُرِيُّ، عَنْ أَبِيهِ، عَنْ حَبِيبِ بْنِ النُّعْمَانِ الأَسَدِيِّ، عَنْ خُرَيْمِ بْنِ فَاتِكٍ الأَسَدِيِّ، قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم الصُّبْحَ فَلَمَّا انْصَرَفَ قَامَ قَائِمًا فَقَالَ ‏"‏ عُدِلَتْ شَهَادَةُ الزُّورِ بِالإِشْرَاكِ بِاللَّهِ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ثُمَّ تَلاَ هَذِهِ الآيَةَ ‏\{‏وَاجْتَنِبُوا قَوْلَ الزُّورِ حُنَفَاءَ لِلَّهِ غَيْرَ مُشْرِكِينَ بِه‏\}‏‏.‏\hadithno{2372}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Khuraim bin Fatik Al-Asadi said that :the Prophet(ﷺ) prayed the Morning prayer, and when he had finished, he stood up and said: “Bearing false witness is equivalent to associating others with Allah,” three times. Then he recited this Verse: “And shun lying speech (false statements), Hunafa' Lillah (i.e., worshiping none but Allah), not associating partners (in worship) to Him.”}}
\hadithdefcmd{ibnmajah}{2373}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْفُرَاتِ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏\{‏لَنْ تَزُولَ قَدَمُ شَاهِدِ الزُّورِ حَتَّى يُوجِبَ اللَّهُ لَهُ النَّارَ‏\}‏‏.‏\hadithno{2373}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:'The one who bears false witness will not move away (on the Day of Resurrection) until Allah condemns him to Hell.' ”}}
\hadithdefcmd{ibnmajah}{2374}{حَدَّثَنَا مُحَمَّدُ بْنُ طَرِيفٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ مُجَالِدٍ، عَنْ عَامِرٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَجَازَ شَهَادَةَ أَهْلِ الْكِتَابِ بَعْضِهِمْ عَلَى بَعْضٍ ‏.‏ ‏\hadithno{2374}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin 'Abdullah that :the Messenger of Allah (ﷺ) allowed the People of the Book to testify against one another}}
