% Auto-generated chapter 46 for malik
% Hadiths in this chapter: 10

\hadithdefcmd{malik}{1623}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَحَاجَّ آدَمُ وَمُوسَى فَحَجَّ آدَمُ مُوسَى قَالَ لَهُ مُوسَى أَنْتَ آدَمُ الَّذِي أَغْوَيْتَ النَّاسَ وَأَخْرَجْتَهُمْ مِنَ الْجَنَّةِ فَقَالَ لَهُ آدَمُ أَنْتَ مُوسَى الَّذِي أَعْطَاهُ اللَّهُ عِلْمَ كُلِّ شَىْءٍ وَاصْطَفَاهُ عَلَى النَّاسِ بِرِسَالَتِهِ قَالَ نَعَمْ ‏.‏ قَالَ أَفَتَلُومُنِي عَلَى أَمْرٍ قَدْ قُدِّرَ عَلَىَّ قَبْلَ أَنْ أُخْلَقَ ‏"‏ ‏.‏\hadithno{1623}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Adam and Musa argued and Adam got the better of Musa. Musa rebuked Adam, 'You are Adam who led people astray and brought them out of the Garden.' Adam said to him, 'You are Musa to whom Allah gave knowledge of everything and whom he chose above people with His message.' He said, 'Yes.' He said, 'Do you then censure me for a matter which was decreed for me before I was created?}}
\hadithdefcmd{malik}{1624}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ عَبْدِ الْحَمِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ زَيْدِ بْنِ الْخَطَّابِ، أَنَّهُ أَخْبَرَهُ عَنْ مُسْلِمِ بْنِ يَسَارٍ الْجُهَنِيِّ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، سُئِلَ عَنْ هَذِهِ الآيَةِ، ‏\{‏وَإِذْ أَخَذَ رَبُّكَ مِنْ بَنِي آدَمَ مِنْ ظُهُورِهِمْ ذُرِّيَّتَهُمْ وَأَشْهَدَهُمْ عَلَى أَنْفُسِهِمْ أَلَسْتُ بِرَبِّكُمْ قَالُوا بَلَى شَهِدْنَا أَنْ تَقُولُوا يَوْمَ الْقِيَامَةِ إِنَّا كُنَّا عَنْ هَذَا غَافِلِينَ‏\}‏ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُسْأَلُ عَنْهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى خَلَقَ آدَمَ ثُمَّ مَسَحَ ظَهْرَهُ بِيَمِينِهِ فَاسْتَخْرَجَ مِنْهُ ذُرِّيَّةً فَقَالَ خَلَقْتُ هَؤُلاَءِ لِلْجَنَّةِ وَبِعَمَلِ أَهْلِ الْجَنَّةِ يَعْمَلُونَ ثُمَّ مَسَحَ ظَهْرَهُ فَاسْتَخْرَجَ مِنْهُ ذُرِّيَّةً فَقَالَ خَلَقْتُ هَؤُلاَءِ لِلنَّارِ وَبِعَمَلِ أَهْلِ النَّارِ يَعْمَلُونَ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ فَفِيمَ الْعَمَلُ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ إِذَا خَلَقَ الْعَبْدَ لِلْجَنَّةِ اسْتَعْمَلَهُ بِعَمَلِ أَهْلِ الْجَنَّةِ حَتَّى يَمُوتَ عَلَى عَمَلٍ مِنْ أَعْمَالِ أَهْلِ الْجَنَّةِ فَيُدْخِلَهُ بِهِ الْجَنَّةَ وَإِذَا خَلَقَ الْعَبْدَ لِلنَّارِ اسْتَعْمَلَهُ بِعَمَلِ أَهْلِ النَّارِ حَتَّى يَمُوتَ عَلَى عَمَلٍ مِنْ أَعْمَالِ أَهْلِ النَّارِ فَيُدْخِلَهُ بِهِ النَّارَ ‏"‏ ‏.‏\hadithno{1624}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Zayd ibn Abi Unaysa that Abd al-Hamid ibn Abd ar-Rahman ibn Zayd ibn al-Khattab informed him from Muslim ibn Yasar al-Juhani that Umar ibn al-Khattab was asked about this ayat - "When your Lord took their progeny from the Banu Adam from their backs and made them testify against themselves. 'Am I not your Lord?' They said, 'Yes, we bear witness' Lest you should say on the Day of Rising, 'We were heedless of that.'" (Sura 7 ayat 172) Umar ibn al-Khattab said, "I heard the Messenger of Allah, may Allah bless him and grant him peace, being asked about it. The Messenger of Allah, may Allah bless him and grant him peace, said, 'Allah, the Blessed, the Exalted, created Adam. Then He stroked his back with His right hand, and progeny issued from it. He said, "I created these for the Garden and they will act with the behaviour of the people of the Garden." Then He stroked his back again and brought forth progeny from him. He said, "I created these for the Fire and they will act with the behaviour of the people of the Fire." 'A man said, 'Messenger of Allah! Then of what value are deeds?' The Messenger of Allah, may Allah bless him and grant him peace, answered, 'When Allah creates a slave for the Garden, he makes him use the behaviour of the people of the Garden, so that he dies on one of the actions of the people of the Garden and by it He brings him into the Garden. When He creates a slave for the Fire, He makes him use the behaviour of the people of the Fire, so that he dies on one of the actions of the people of the Fire, and by it, He brings him into the Fire}}
\hadithdefcmd{malik}{1625}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَرَكْتُ فِيكُمْ أَمْرَيْنِ لَنْ تَضِلُّوا مَا تَمَسَّكْتُمْ بِهِمَا كِتَابَ اللَّهِ وَسُنَّةَ نَبِيِّهِ ‏"‏ ‏.‏\hadithno{1625}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that he heard that the Messenger of Allah, may Allah bless him and grant him peace, said, "I have left two matters with you. As long as you hold to them, you will not go the wrong way. They are the Book of Allah and the Sunna of His Prophet}}
\hadithdefcmd{malik}{1626}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زِيَادِ بْنِ سَعْدٍ، عَنْ عَمْرِو بْنِ مُسْلِمٍ، عَنْ طَاوُسٍ الْيَمَانِيِّ، أَنَّهُ قَالَ أَدْرَكْتُ نَاسًا مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُونَ كُلُّ شَىْءٍ بِقَدَرٍ ‏.‏ قَالَ طَاوُسٌ وَسَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ شَىْءٍ بِقَدَرٍ حَتَّى الْعَجْزِ وَالْكَيْسِ أَوِ الْكَيْسِ وَالْعَجْزِ ‏"‏ ‏.‏\hadithno{1626}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ziyad ibn Sad from Amr ibn Muslim that Tawus al-Yamani said, "I found some of the companions of the Messenger of Allah, may Allah bless him and grant him peace, saying 'Everything is by decree.' " Tawus added, "I heard Abdullah ibn Umar say that The Messenger of Allah, may Allah bless him and grant him peace. said, 'Everything is by decree - even incapacity and ability,' (or 'ability and incapacity)}}
\hadithdefcmd{malik}{1627}{وَحَدَّثَنِي مَالِكٌ، عَنْ زِيَادِ بْنِ سَعْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، أَنَّهُ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، يَقُولُ فِي خُطْبَتِهِ إِنَّ اللَّهَ هُوَ الْهَادِي وَالْفَاتِنُ ‏.‏\hadithno{1627}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Ziyad ibn Sad that Amr ibn Dinar said, "I heard Abdullah ibn az-Zubayr say in a khutba, 'Allah - He is the Guider and the One Who Tempts Away}}
\hadithdefcmd{malik}{1628}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَمِّهِ أَبِي سُهَيْلِ بْنِ مَالِكٍ، أَنَّهُ قَالَ كُنْتُ أَسِيرُ مَعَ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ فَقَالَ مَا رَأْيُكَ فِي هَؤُلاَءِ الْقَدَرِيَّةِ فَقُلْتُ رَأْيِي أَنْ تَسْتَتِيبَهُمْ فَإِنْ تَابُوا وَإِلاَّ عَرَضْتَهُمْ عَلَى السَّيْفِ ‏.‏ فَقَالَ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ وَذَلِكَ رَأْيِي ‏.‏ قَالَ مَالِكٌ وَذَلِكَ رَأْيِي ‏.‏\hadithno{1628}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that his paternal uncle, Abu Suhayl ibn Malik said, "I was a prisoner with Umar ibn Abd al-Aziz. He said, 'What do you think about these Qadariyya (fatalists)?' I said, 'My opinion is that one should ask them to turn from wrong action, if they will do so. If not, subject them to the sword.' Umar ibn Abd al- Aziz said, 'That is my opinion. Malik added, "That is my opinion also}}
\hadithdefcmd{malik}{1629}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَسْأَلِ الْمَرْأَةُ طَلاَقَ أُخْتِهَا لِتَسْتَفْرِغَ صَحْفَتَهَا وَلِتَنْكِحَ فَإِنَّمَا لَهَا مَا قُدِّرَ لَهَا ‏"‏ ‏.‏\hadithno{1629}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "A woman should not ask for the divorce of her sister to make her plate empty and in order to marry. She has what is decreed for her}}
\hadithdefcmd{malik}{1630}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ زِيَادٍ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ الْقُرَظِيِّ، قَالَ قَالَ مُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ وَهُوَ عَلَى الْمِنْبَرِ أَيُّهَا النَّاسُ إِنَّهُ لاَ مَانِعَ لِمَا أَعْطَى اللَّهُ وَلاَ مُعْطِيَ لِمَا مَنَعَ اللَّهُ وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْهُ الْجَدُّ مَنْ يُرِدِ اللَّهُ بِهِ خَيْرًا يُفَقِّهْهُ فِي الدِّينِ ‏.‏ ثُمَّ قَالَ مُعَاوِيَةُ سَمِعْتُ هَؤُلاَءِ الْكَلِمَاتِ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى هَذِهِ الأَعْوَادِ ‏.‏\hadithno{1630}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yazid ibn Ziyad that Muhammad ibn Kab al-Quradhi said, ''Muawiya ibn Abi Sufyan said from the mimbar, 'O people! Nothing keeps away what Allah gives and nothing gives what Allah keeps away. The earnestness of the earnest one does not profit him. When Allah desires good for him, he gives him understanding in the deen.' Then Muawiya said, 'I heard these words from the Messenger of Allah, may Allah bless him and grant him peace, on these blocks of wood}}
\hadithdefcmd{malik}{1631}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّهُ كَانَ يُقَالُ الْحَمْدُ لِلَّهِ الَّذِي خَلَقَ كُلَّ شَىْءٍ كَمَا يَنْبَغِي الَّذِي لاَ يَعْجَلُ شَىْءٌ أَنَاهُ وَقَدَّرَهُ حَسْبِيَ اللَّهُ وَكَفَى سَمِعَ اللَّهُ لِمَنْ دَعَا لَيْسَ وَرَاءَ اللَّهِ مَرْمَى ‏.‏\hadithno{1631}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that this was said "Praise be to Allah who created everything as is necessary, who does not hasten anything He defers and determines. Allah is enough for me and sufficient. Allah hears whoever makes dua to him. Allah does not have a goal}}
\hadithdefcmd{malik}{1632}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّهُ كَانَ يُقَالُ إِنَّ أَحَدًا لَنْ يَمُوتَ حَتَّى يَسْتَكْمِلَ رِزْقَهُ فَأَجْمِلُوا فِي الطَّلَبِ ‏.‏\hadithno{1632}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he heard that this was said "No one will die until his provision is completed for him, so behave correctly in your seeking it}}
