% Auto-generated chapter 6 for bukhari
% Hadiths in this chapter: 37

\hadithdefcmd{bukhari}{294}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ، قَالَ سَمِعْتُ الْقَاسِمَ، يَقُولُ سَمِعْتُ عَائِشَةَ، تَقُولُ خَرَجْنَا لاَ نَرَى إِلاَّ الْحَجَّ، فَلَمَّا كُنَّا بِسَرِفَ حِضْتُ، فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَبْكِي قَالَ ‏"‏ مَا لَكِ أَنُفِسْتِ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ إِنَّ هَذَا أَمْرٌ كَتَبَهُ اللَّهُ عَلَى بَنَاتِ آدَمَ، فَاقْضِي مَا يَقْضِي الْحَاجُّ، غَيْرَ أَنْ لاَ تَطُوفِي بِالْبَيْتِ ‏"‏‏.‏ قَالَتْ وَضَحَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ نِسَائِهِ بِالْبَقَرِ‏.‏\hadithno{294}\hadithtrans{Narrated Al-Qasim:`Aisha said, "We set out with the sole intention of performing Hajj and when we reached Sarif, (a place six miles from Mecca) I got my menses. Allah's Messenger (ﷺ) came to me while I was weeping. He said 'What is the matter with you? Have you got your menses?' I replied, 'Yes.' He said, 'This is a thing which Allah has ordained for the daughters of Adam. So do what all the pilgrims do with the exception of the Tawaf (Circumambulation) round the Ka`ba." `Aisha added, "Allah's Messenger (ﷺ) sacrificed cows on behalf of his wives}}
\hadithdefcmd{bukhari}{295}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أُرَجِّلُ رَأْسَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا حَائِضٌ‏.‏\hadithno{295}\hadithtrans{Narrated `Aisha:While in menses, I used to comb the hair of Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{296}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، قَالَ أَخْبَرَنَا هِشَامُ بْنُ يُوسُفَ، أَنَّ ابْنَ جُرَيْجٍ، أَخْبَرَهُمْ قَالَ أَخْبَرَنِي هِشَامٌ، عَنْ عُرْوَةَ، أَنَّهُ سُئِلَ أَتَخْدُمُنِي الْحَائِضُ أَوْ تَدْنُو مِنِّي الْمَرْأَةُ وَهْىَ جُنُبٌ فَقَالَ عُرْوَةُ كُلُّ ذَلِكَ عَلَىَّ هَيِّنٌ، وَكُلُّ ذَلِكَ تَخْدُمُنِي، وَلَيْسَ عَلَى أَحَدٍ فِي ذَلِكَ بَأْسٌ، أَخْبَرَتْنِي عَائِشَةُ أَنَّهَا كَانَتْ تُرَجِّلُ ـ تَعْنِي ـ رَأْسَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهِيَ حَائِضٌ، وَرَسُولُ اللَّهِ صلى الله عليه وسلم حِينَئِذٍ مُجَاوِرٌ فِي الْمَسْجِدِ، يُدْنِي لَهَا رَأْسَهُ وَهْىَ فِي حُجْرَتِهَا، فَتُرَجِّلُهُ وَهْىَ حَائِضٌ‏.‏\hadithno{296}\hadithtrans{Narrated `Urwa:A person asked me, "Can a woman in menses serve me? And can a Junub woman come close to me?" I replied, "All this is easy for me. All of them can serve me, and there is no harm for any other person to do the same. `Aisha told me that she used to comb the hair of Allah's Messenger (ﷺ) while she was in her menses, and he was in I`tikaf (in the mosque). He would bring his head near her in her room and she would comb his hair, while she used to be in her menses}}
\hadithdefcmd{bukhari}{297}{حَدَّثَنَا أَبُو نُعَيْمٍ الْفَضْلُ بْنُ دُكَيْنٍ، سَمِعَ زُهَيْرًا، عَنْ مَنْصُورٍ ابْنِ صَفِيَّةَ، أَنَّ أُمَّهُ، حَدَّثَتْهُ أَنَّ عَائِشَةَ حَدَّثَتْهَا أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَّكِئُ فِي حَجْرِي وَأَنَا حَائِضٌ، ثُمَّ يَقْرَأُ الْقُرْآنَ‏.‏\hadithno{297}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to lean on my lap and recite Qur'an while I was in menses}}
\hadithdefcmd{bukhari}{298}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، أَنَّ زَيْنَبَ ابْنَةَ أُمِّ سَلَمَةَ، حَدَّثَتْهُ أَنَّ أُمَّ سَلَمَةَ حَدَّثَتْهَا قَالَتْ، بَيْنَا أَنَا مَعَ النَّبِيِّ، صلى الله عليه وسلم مُضْطَجِعَةً فِي خَمِيصَةٍ إِذْ حِضْتُ، فَانْسَلَلْتُ فَأَخَذْتُ ثِيَابَ حِيضَتِي قَالَ ‏ "‏ أَنُفِسْتِ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ فَدَعَانِي فَاضْطَجَعْتُ مَعَهُ فِي الْخَمِيلَةِ‏.‏\hadithno{298}\hadithtrans{Narrated Um Salama:While I was laying with the Prophet (ﷺ) under a single woolen sheet, I got the menses. I slipped away and put on the clothes for menses. He said, "Have you got "Nifas" (menses)?" I replied, "Yes." He then called me and made me lie with him under the same sheet}}
\hadithdefcmd{bukhari}{301}{حَدَّثَنَا قَبِيصَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَالنَّبِيُّ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ، كِلاَنَا جُنُبٌ‏.‏ وَكَانَ يَأْمُرُنِي فَأَتَّزِرُ، فَيُبَاشِرُنِي وَأَنَا حَائِضٌ‏.‏ وَكَانَ يُخْرِجُ رَأْسَهُ إِلَىَّ وَهُوَ مُعْتَكِفٌ، فَأَغْسِلُهُ وَأَنَا حَائِضٌ‏.‏\hadithno{301}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) and I used to take a bath from a single pot while we were Junub. During the menses, he used to order me to put on an Izar (dress worn below the waist) and used to fondle me. While in I`tikaf, he used to bring his head near me and I would wash it while I used to be in my periods (menses)}}
\hadithdefcmd{bukhari}{302}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ خَلِيلٍ، قَالَ أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، قَالَ أَخْبَرَنَا أَبُو إِسْحَاقَ ـ هُوَ الشَّيْبَانِيُّ ـ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ إِحْدَانَا إِذَا كَانَتْ حَائِضًا، فَأَرَادَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُبَاشِرَهَا، أَمَرَهَا أَنْ تَتَّزِرَ فِي فَوْرِ حَيْضَتِهَا ثُمَّ يُبَاشِرُهَا‏.‏ قَالَتْ وَأَيُّكُمْ يَمْلِكُ إِرْبَهُ كَمَا كَانَ النَّبِيُّ صلى الله عليه وسلم يَمْلِكُ إِرْبَهُ‏.‏ تَابَعَهُ خَالِدٌ وَجَرِيرٌ عَنِ الشَّيْبَانِيِّ‏.‏\hadithno{302}\hadithtrans{Narrated `Abdur-Rahman bin Al-Aswad:(on the authority of his father) `Aisha said: "Whenever Allah's Messenger (ﷺ) wanted to fondle anyone of us during her periods (menses), he used to order her to put on an Izar and start fondling her." `Aisha added, "None of you could control his sexual desires as the Prophet (ﷺ) could}}
\hadithdefcmd{bukhari}{303}{حَدَّثَنَا أَبُو النُّعْمَانِ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ، قَالَ حَدَّثَنَا الشَّيْبَانِيُّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ شَدَّادٍ، قَالَ سَمِعْتُ مَيْمُونَةَ، كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يُبَاشِرَ امْرَأَةً مِنْ نِسَائِهِ أَمَرَهَا فَاتَّزَرَتْ وَهْىَ حَائِضٌ‏.‏ وَرَوَاهُ سُفْيَانُ عَنِ الشَّيْبَانِيِّ‏.‏\hadithno{303}\hadithtrans{Narrated Maimuna:When ever Allah's Messenger (ﷺ) wanted to fondle any of his wives during the periods (menses), he used to ask her to wear an Izar}}
\hadithdefcmd{bukhari}{304}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، قَالَ أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ أَخْبَرَنِي زَيْدٌ ـ هُوَ ابْنُ أَسْلَمَ ـ عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي أَضْحًى ـ أَوْ فِطْرٍ ـ إِلَى الْمُصَلَّى، فَمَرَّ عَلَى النِّسَاءِ فَقَالَ ‏"‏ يَا مَعْشَرَ النِّسَاءِ تَصَدَّقْنَ، فَإِنِّي أُرِيتُكُنَّ أَكْثَرَ أَهْلِ النَّارِ ‏"‏‏.‏ فَقُلْنَ وَبِمَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ تُكْثِرْنَ اللَّعْنَ، وَتَكْفُرْنَ الْعَشِيرَ، مَا رَأَيْتُ مِنْ نَاقِصَاتِ عَقْلٍ وَدِينٍ أَذْهَبَ لِلُبِّ الرَّجُلِ الْحَازِمِ مِنْ إِحْدَاكُنَّ ‏"‏‏.‏ قُلْنَ وَمَا نُقْصَانُ دِينِنَا وَعَقْلِنَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أَلَيْسَ شَهَادَةُ الْمَرْأَةِ مِثْلَ نِصْفِ شَهَادَةِ الرَّجُلِ ‏"‏‏.‏ قُلْنَ بَلَى‏.‏ قَالَ ‏"‏ فَذَلِكَ مِنْ نُقْصَانِ عَقْلِهَا، أَلَيْسَ إِذَا حَاضَتْ لَمْ تُصَلِّ وَلَمْ تَصُمْ ‏"‏‏.‏ قُلْنَ بَلَى‏.‏ قَالَ ‏"‏ فَذَلِكَ مِنْ نُقْصَانِ دِينِهَا ‏"‏‏.‏\hadithno{304}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Once Allah's Messenger (ﷺ) went out to the Musalla (to offer the prayer) of `Id-al-Adha or Al-Fitr prayer. Then he passed by the women and said, "O women! Give alms, as I have seen that the majority of the dwellers of Hell-fire were you (women)." They asked, "Why is it so, O Allah's Messenger (ﷺ) ?" He replied, "You curse frequently and are ungrateful to your husbands. I have not seen anyone more deficient in intelligence and religion than you. A cautious sensible man could be led astray by some of you." The women asked, "O Allah's Messenger (ﷺ)! What is deficient in our intelligence and religion?" He said, "Is not the evidence of two women equal to the witness of one man?" They replied in the affirmative. He said, "This is the deficiency in her intelligence. Isn't it true that a woman can neither pray nor fast during her menses?" The women replied in the affirmative. He said, "This is the deficiency in her religion}}
\hadithdefcmd{bukhari}{305}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم لاَ نَذْكُرُ إِلاَّ الْحَجَّ، فَلَمَّا جِئْنَا سَرِفَ طَمِثْتُ، فَدَخَلَ عَلَىَّ النَّبِيُّ صلى الله عليه وسلم وَأَنَا أَبْكِي فَقَالَ ‏\{‏مَا يُبْكِيكِ‏\}‏‏.‏ قُلْتُ لَوَدِدْتُ وَاللَّهِ أَنِّي لَمْ أَحُجَّ الْعَامَ‏.‏ قَالَ ‏\{‏لَعَلَّكِ نُفِسْتِ‏\}‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏ "‏ فَإِنَّ ذَلِكَ شَىْءٌ كَتَبَهُ اللَّهُ عَلَى بَنَاتِ آدَمَ، فَافْعَلِي مَا يَفْعَلُ الْحَاجُّ، غَيْرَ أَنْ لاَ تَطُوفِي بِالْبَيْتِ حَتَّى تَطْهُرِي ‏"‏‏.‏\hadithno{305}\hadithtrans{Narrated `Aisha:We set out with the Prophet (ﷺ) for Hajj and when we reached Sarif I got my menses. When the Prophet (ﷺ) came to me, I was weeping. He asked, "Why are you weeping?" I said, "I wish if I had not performed Hajj this year." He asked, "May be that you got your menses?" I replied, "Yes." He then said, "This is the thing which Allah has ordained for all the daughters of Adam. So do what all the pilgrims do except that you do not perform the Tawaf round the Ka`ba till you are clean}}
\hadithdefcmd{bukhari}{306}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ قَالَتْ فَاطِمَةُ بِنْتُ أَبِي حُبَيْشٍ لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ إِنِّي لاَ أَطْهُرُ، أَفَأَدَعُ الصَّلاَةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا ذَلِكِ عِرْقٌ وَلَيْسَ بِالْحَيْضَةِ، فَإِذَا أَقْبَلَتِ الْحَيْضَةُ فَاتْرُكِي الصَّلاَةَ، فَإِذَا ذَهَبَ قَدْرُهَا فَاغْسِلِي عَنْكِ الدَّمَ وَصَلِّي ‏"‏‏.‏\hadithno{306}\hadithtrans{Narrated `Aisha:Fatima bint Abi Hubaish said to Allah's Messenger (ﷺ), "O Allah's Messenger (ﷺ)! I do not become clean (from bleeding). Shall I give up my prayers?" Allah's Messenger (ﷺ) replied: "No, because it is from a blood vessel and not the menses. So when the real menses begins give up your prayers and when it (the period) has finished wash the blood off your body (take a bath) and offer your prayers}}
\hadithdefcmd{bukhari}{307}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامٍ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّهَا قَالَتْ سَأَلَتِ امْرَأَةٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ، أَرَأَيْتَ إِحْدَانَا إِذَا أَصَابَ ثَوْبَهَا الدَّمُ مِنَ الْحَيْضَةِ، كَيْفَ تَصْنَعُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَصَابَ ثَوْبَ إِحْدَاكُنَّ الدَّمُ مِنَ الْحَيْضَةِ، فَلْتَقْرُصْهُ ثُمَّ لِتَنْضَحْهُ بِمَاءٍ، ثُمَّ لِتُصَلِّي فِيهِ ‏"‏‏.‏\hadithno{307}\hadithtrans{Narrated Asma' bint Abi Bakr:A woman asked Allah's Messenger (ﷺ), "O Allah's Messenger (ﷺ)! What should we do, if the blood of menses falls on our clothes?" Allah's Messenger (ﷺ) replied, "If the blood of menses falls on the garment of anyone of you, she must take hold of the blood spot, rub it, and wash it with water and then pray in (with it)}}
\hadithdefcmd{bukhari}{308}{حَدَّثَنَا أَصْبَغُ، قَالَ أَخْبَرَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، حَدَّثَهُ عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ إِحْدَانَا تَحِيضُ، ثُمَّ تَقْتَرِصُ الدَّمَ مِنْ ثَوْبِهَا عِنْدَ طُهْرِهَا فَتَغْسِلُهُ، وَتَنْضَحُ عَلَى سَائِرِهِ، ثُمَّ تُصَلِّي فِيهِ‏.‏\hadithno{308}\hadithtrans{Narrated `Aisha:Whenever anyone of us got her menses, she, on becoming clean, used to take hold of the blood spot and rub the blood off her garment, and pour water over it and wash that portion thoroughly and sprinkle water over the rest of the garment. After that she would pray in (with) it}}
\hadithdefcmd{bukhari}{309}{حَدَّثَنَا إِسْحَاقُ، قَالَ حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ خَالِدٍ، عَنْ عِكْرِمَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اعْتَكَفَ مَعَهُ بَعْضُ نِسَائِهِ وَهْىَ مُسْتَحَاضَةٌ تَرَى الدَّمَ، فَرُبَّمَا وَضَعَتِ الطَّسْتَ تَحْتَهَا مِنَ الدَّمِ‏.‏ وَزَعَمَ أَنَّ عَائِشَةَ رَأَتْ مَاءَ الْعُصْفُرِ فَقَالَتْ كَأَنَّ هَذَا شَىْءٌ كَانَتْ فُلاَنَةُ تَجِدُهُ‏.‏\hadithno{309}\hadithtrans{Narrated `Aisha:Once one of the wives of the Prophet (ﷺ) did I`tikaf along with him and she was getting bleeding in between her periods. She used to see the blood (from her private parts) and she would perhaps put a dish under her for the blood. (The sub-narrator `Ikrima added, `Aisha once saw the liquid of safflower and said, "It looks like what so and so used to have)}}
\hadithdefcmd{bukhari}{310}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ خَالِدٍ، عَنْ عِكْرِمَةَ، عَنْ عَائِشَةَ، قَالَتِ اعْتَكَفَتْ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم امْرَأَةٌ مِنْ أَزْوَاجِهِ، فَكَانَتْ تَرَى الدَّمَ وَالصُّفْرَةَ، وَالطَّسْتُ تَحْتَهَا وَهْىَ تُصَلِّي‏.‏\hadithno{310}\hadithtrans{Narrated `Aisha:"One of the wives of Allah's Messenger (ﷺ) joined him in I`tikaf and she noticed blood and yellowish discharge (from her private parts) and put a dish under her when she prayed}}
\hadithdefcmd{bukhari}{311}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا مُعْتَمِرٌ، عَنْ خَالِدٍ، عَنْ عِكْرِمَةَ، عَنْ عَائِشَةَ، أَنَّ بَعْضَ، أُمَّهَاتِ الْمُؤْمِنِينَ اعْتَكَفَتْ وَهْىَ مُسْتَحَاضَةٌ‏.‏\hadithno{311}\hadithtrans{Narrated `Aisha:One of the mothers of the faithful believers (i.e. the wives of the Prophet (ﷺ) ) did I`tikaf while she was having bleeding in between her periods}}
\hadithdefcmd{bukhari}{312}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَافِعٍ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، قَالَ قَالَتْ عَائِشَةُ مَا كَانَ لإِحْدَانَا إِلاَّ ثَوْبٌ وَاحِدٌ تَحِيضُ فِيهِ، فَإِذَا أَصَابَهُ شَىْءٌ مِنْ دَمٍ، قَالَتْ بِرِيقِهَا فَقَصَعَتْهُ بِظُفْرِهَا‏.‏\hadithno{312}\hadithtrans{Narrated `Aisha:None of us had more than a single garment and we used to have our menses while wearing it. Whenever it got soiled with blood of menses we used to apply saliva to the blood spot and rub off the blood with our nails}}
\hadithdefcmd{bukhari}{313}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الْوَهَّابِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ حَفْصَةَ ـ قَالَ أَبُو عَبْدِ اللَّهِ أَوْ هِشَامِ بْنِ حَسَّانَ عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ ـ قَالَتْ كُنَّا نُنْهَى أَنْ نُحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ، إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا، وَلاَ نَكْتَحِلَ وَلاَ نَتَطَيَّبَ وَلاَ نَلْبَسَ ثَوْبًا مَصْبُوغًا إِلاَّ ثَوْبَ عَصْبٍ، وَقَدْ رُخِّصَ لَنَا عِنْدَ الطُّهْرِ إِذَا اغْتَسَلَتْ إِحْدَانَا مِنْ مَحِيضِهَا فِي نُبْذَةٍ مِنْ كُسْتِ أَظْفَارٍ، وَكُنَّا نُنْهَى عَنِ اتِّبَاعِ الْجَنَائِزِ‏.‏ قَالَ رَوَاهُ هِشَامُ بْنُ حَسَّانَ عَنْ حَفْصَةَ عَنْ أُمِّ عَطِيَّةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{313}\hadithtrans{Narrated Um-`Atiya:We were forbidden to mourn for a dead person for more than three days except in the case of a husband for whom mourning was allowed for four months and ten days. (During that time) we were not allowed to put kohl (Antimony eye power) in our eyes or to use perfumes or to put on colored clothes except a dress made of `Asb (a kind of Yemen cloth, very coarse and rough). We were allowed very light perfumes at the time of taking a bath after menses and also we were forbidden to go with the funeral procession}}
\hadithdefcmd{bukhari}{314}{حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ مَنْصُورِ ابْنِ صَفِيَّةَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، سَأَلَتِ النَّبِيَّ صلى الله عليه وسلم عَنْ غُسْلِهَا مِنَ الْمَحِيضِ، فَأَمَرَهَا كَيْفَ تَغْتَسِلُ قَالَ ‏"‏ خُذِي فِرْصَةً مِنْ مِسْكٍ فَتَطَهَّرِي بِهَا ‏"‏‏.‏ قَالَتْ كَيْفَ أَتَطَهَّرُ قَالَ ‏"‏ تَطَهَّرِي بِهَا ‏"‏‏.‏ قَالَتْ كَيْفَ قَالَ ‏"‏ سُبْحَانَ اللَّهِ تَطَهَّرِي ‏"‏‏.‏ فَاجْتَبَذْتُهَا إِلَىَّ فَقُلْتُ تَتَبَّعِي بِهَا أَثَرَ الدَّمِ‏.‏\hadithno{314}\hadithtrans{Narrated `Aisha:A woman asked the Prophet (ﷺ) about the bath which is taken after finishing from the menses. The Prophet (ﷺ) told her what to do and said, "Purify yourself with a piece of cloth scented with musk." The woman asked, "How shall I purify myself with it?" He said, "Subhan Allah! Purify yourself (with it)." I pulled her to myself and said, "Rub the place soiled with blood with it}}
\hadithdefcmd{bukhari}{315}{حَدَّثَنَا مُسْلِمٌ، قَالَ حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا مَنْصُورٌ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، مِنَ الأَنْصَارِ قَالَتْ لِلنَّبِيِّ صلى الله عليه وسلم كَيْفَ أَغْتَسِلُ مِنَ الْمَحِيضِ قَالَ ‏"‏ خُذِي فِرْصَةً مُمَسَّكَةً، فَتَوَضَّئِي ثَلاَثًا ‏"‏‏.‏ ثُمَّ إِنَّ النَّبِيَّ صلى الله عليه وسلم اسْتَحْيَا فَأَعْرَضَ بِوَجْهِهِ أَوْ قَالَ ‏"‏ تَوَضَّئِي بِهَا ‏"‏ فَأَخَذْتُهَا فَجَذَبْتُهَا فَأَخْبَرْتُهَا بِمَا يُرِيدُ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{315}\hadithtrans{Narrated `Aisha:An Ansari woman asked the Prophet (ﷺ) how to take a bath after finishing from the menses. He replied, "Take a piece of cloth perfumed with musk and clean the private parts with it thrice." The Prophet (ﷺ) felt shy and turned his face. So I pulled her to me and told her what the Prophet (ﷺ) meant}}
\hadithdefcmd{bukhari}{316}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، قَالَتْ أَهْلَلْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ، فَكُنْتُ مِمَّنْ تَمَتَّعَ، وَلَمْ يَسُقِ الْهَدْىَ، فَزَعَمَتْ أَنَّهَا حَاضَتْ، وَلَمْ تَطْهُرْ حَتَّى دَخَلَتْ لَيْلَةُ عَرَفَةَ فَقَالَتْ يَا رَسُولَ اللَّهِ، هَذِهِ لَيْلَةُ عَرَفَةَ، وَإِنَّمَا كُنْتُ تَمَتَّعْتُ بِعُمْرَةٍ‏.‏ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ انْقُضِي رَأْسَكِ، وَامْتَشِطِي، وَأَمْسِكِي عَنْ عُمْرَتِكِ ‏"‏‏.‏ فَفَعَلْتُ، فَلَمَّا قَضَيْتُ الْحَجَّ أَمَرَ عَبْدَ الرَّحْمَنِ لَيْلَةَ الْحَصْبَةِ فَأَعْمَرَنِي مِنَ التَّنْعِيمِ مَكَانَ عُمْرَتِي الَّتِي نَسَكْتُ‏.‏\hadithno{316}\hadithtrans{Narrated `Aisha:In the last Hajj of Allah's Messenger (ﷺ) assumed the Ihram for Hajj along with Allah's Apostle. I was one of those who intended Tamattu` (to perform Hajj and `Umra) and did not take the Hadi (animal for sacrifice) with me. I got my menses and was not clean till the night of `Arafa I said, "O Allah's Apostle! It is the night of the day of `Arafat and I intended to perform the Hajj Tamattu` with `Umra. Allah's Messenger (ﷺ) told me to undo my hair and comb it and to postpone the `Umra. I did the same and completed the Hajj. On the night of Al-Hasba (i.e. place outside Mecca where the pilgrims go after finishing all the ceremonies of Hajj at Mina) he (the Prophet) ordered `Abdur Rahman (`Aisha's brother) to take me to at-Tan`im to assume the Ihram for `Umra in lieu of that of Hajj-at-Tamattu` which I had intended to perform}}
\hadithdefcmd{bukhari}{317}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مُوَافِينَ لِهِلاَلِ ذِي الْحِجَّةِ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَحَبَّ أَنْ يُهِلَّ بِعُمْرَةٍ فَلْيُهْلِلْ، فَإِنِّي لَوْلاَ أَنِّي أَهْدَيْتُ لأَهْلَلْتُ بِعُمْرَةٍ ‏"‏‏.‏ فَأَهَلَّ بَعْضُهُمْ بِعُمْرَةٍ، وَأَهَلَّ بَعْضُهُمْ بِحَجٍّ، وَكُنْتُ أَنَا مِمَّنْ أَهَلَّ بِعُمْرَةٍ، فَأَدْرَكَنِي يَوْمُ عَرَفَةَ وَأَنَا حَائِضٌ، فَشَكَوْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ دَعِي عُمْرَتَكِ، وَانْقُضِي رَأْسَكِ وَامْتَشِطِي، وَأَهِلِّي بِحَجٍّ ‏"‏‏.‏ فَفَعَلْتُ حَتَّى إِذَا كَانَ لَيْلَةُ الْحَصْبَةِ أَرْسَلَ مَعِي أَخِي عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ، فَخَرَجْتُ إِلَى التَّنْعِيمِ، فَأَهْلَلْتُ بِعُمْرَةٍ مَكَانَ عُمْرَتِي‏.‏ قَالَ هِشَامٌ وَلَمْ يَكُنْ فِي شَىْءٍ مِنْ ذَلِكَ هَدْىٌ وَلاَ صَوْمٌ وَلاَ صَدَقَةٌ‏.‏\hadithno{317}\hadithtrans{Narrated `Aisha:On the 1st of Dhul-Hijja we set out with the intention of performing Hajj. Allah's Messenger (ﷺ) said, "Any one who likes to assume the Ihram for `Umra he can do so. Had I not brought the Hadi with me, I would have assumed the Ihram for `Umra. "Some of us assumed the Ihram for `Umra while the others assumed the Ihram for Hajj. I was one of those who assumed the Ihram for `Umra. I got menses and kept on menstruating until the day of `Arafat and complained of that to the Prophet. He told me to postpone my `Umra, undo and comb my hair, and to assume the Ihram of Hajj and I did so. On the night of Hasba, he sent my brother `Abdur-Rahman bin Abi Bakr with me to at-Tan`im, where I assumed the Ihram for `Umra in lieu of the previous one. Hisham said, "For that (`Umra) no Hadi, fasting or alms were required}}
\hadithdefcmd{bukhari}{318}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ ـ عَزَّ وَجَلَّ ـ وَكَّلَ بِالرَّحِمِ مَلَكًا يَقُولُ يَا رَبِّ نُطْفَةٌ، يَا رَبِّ عَلَقَةٌ، يَا رَبِّ مُضْغَةٌ‏.‏ فَإِذَا أَرَادَ أَنْ يَقْضِيَ خَلْقَهُ قَالَ أَذَكَرٌ أَمْ أُنْثَى شَقِيٌّ أَمْ سَعِيدٌ فَمَا الرِّزْقُ وَالأَجَلُ فَيُكْتَبُ فِي بَطْنِ أُمِّهِ ‏"‏‏.‏\hadithno{318}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "At every womb Allah appoints an angel who says, 'O Lord! A drop of semen, O Lord! A clot. O Lord! A little lump of flesh." Then if Allah wishes (to complete) its creation, the angel asks, (O Lord!) Will it be a male or female, a wretched or a blessed, and how much will his provision be? And what will his age be?' So all that is written while the child is still in the mother's womb}}
\hadithdefcmd{bukhari}{319}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ، فَمِنَّا مَنْ أَهَلَّ بِعُمْرَةٍ، وَمِنَّا مَنْ أَهَلَّ بِحَجٍّ، فَقَدِمْنَا مَكَّةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَحْرَمَ بِعُمْرَةٍ وَلَمْ يُهْدِ فَلْيُحْلِلْ، وَمَنْ أَحْرَمَ بِعُمْرَةٍ وَأَهْدَى فَلاَ يَحِلُّ حَتَّى يَحِلَّ بِنَحْرِ هَدْيِهِ، وَمَنْ أَهَلَّ بِحَجٍّ فَلْيُتِمَّ حَجَّهُ ‏"‏‏.‏ قَالَتْ فَحِضْتُ فَلَمْ أَزَلْ حَائِضًا حَتَّى كَانَ يَوْمُ عَرَفَةَ، وَلَمْ أُهْلِلْ إِلاَّ بِعُمْرَةٍ، فَأَمَرَنِي النَّبِيُّ صلى الله عليه وسلم أَنْ أَنْقُضَ رَأْسِي وَأَمْتَشِطَ، وَأُهِلَّ بِحَجٍّ، وَأَتْرُكَ الْعُمْرَةَ، فَفَعَلْتُ ذَلِكَ حَتَّى قَضَيْتُ حَجِّي، فَبَعَثَ مَعِي عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ، وَأَمَرَنِي أَنْ أَعْتَمِرَ مَكَانَ عُمْرَتِي مِنَ التَّنْعِيمِ‏.‏\hadithno{319}\hadithtrans{Narrated `Urwa:`Aisha said, "We set out with the Prophet (ﷺ) in his last Hajj. Some of us intended to perform `Umra while others Hajj. When we reached Mecca, Allah's Messenger (ﷺ) said, 'Those who had assumed the Ihram for `Umra and had not brought the Hadi should finish his Ihram and whoever had assumed the Ihram for `Umra and brought the Hadi should not finish the Ihram till he has slaughtered his Hadi and whoever had assumed the Ihram for Hajj should complete his Hajj." `Aisha further said, "I got my periods (menses) and kept on menstruating till the day of `Arafat, and I had assumed the Ihram for `Umra only (Tamattu`). The Prophet (ﷺ) ordered me to undo and comb my head hair and assume the Ihram for Hajj only and leave the `Umra. I did the same till I completed the Hajj. Then the Prophet (ﷺ) sent `Abdur Rahman bin Abi Bakr with me and ordered me to perform `Umra from at-Tan`im in lieu of the missed `Umra}}
\hadithdefcmd{bukhari}{320}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ فَاطِمَةَ بِنْتَ أَبِي حُبَيْشٍ، كَانَتْ تُسْتَحَاضُ فَسَأَلَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ ذَلِكِ عِرْقٌ، وَلَيْسَتْ بِالْحَيْضَةِ، فَإِذَا أَقْبَلَتِ الْحَيْضَةُ فَدَعِي الصَّلاَةَ، وَإِذَا أَدْبَرَتْ فَاغْتَسِلِي وَصَلِّي ‏"‏‏.‏\hadithno{320}\hadithtrans{Narrated `Aisha:Fatima bint Abi Hubaish used to have bleeding in between the periods, so she asked the Prophet (ﷺ) about it. He replied, "The bleeding is from a blood vessel and not the menses. So give up the prayers when the (real) menses begins and when it has finished, take a bath and start praying}}
\hadithdefcmd{bukhari}{321}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا هَمَّامٌ، قَالَ حَدَّثَنَا قَتَادَةُ، قَالَ حَدَّثَتْنِي مُعَاذَةُ، أَنَّ امْرَأَةً، قَالَتْ لِعَائِشَةَ أَتَجْزِي إِحْدَانَا صَلاَتَهَا إِذَا طَهُرَتْ فَقَالَتْ أَحَرُورِيَّةٌ أَنْتِ كُنَّا نَحِيضُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَلاَ يَأْمُرُنَا بِهِ‏.‏ أَوْ قَالَتْ فَلاَ نَفْعَلُهُ‏.‏\hadithno{321}\hadithtrans{Narrated Mu`adha:A woman asked `Aisha, "Should I offer the prayers that which I did not offer because of menses" `Aisha said, "Are you from the Huraura' (a town in Iraq?) We were with the Prophet (ﷺ) and used to get our periods but he never ordered us to offer them (the Prayers missed during menses)." `Aisha perhaps said, "We did not offer them}}
\hadithdefcmd{bukhari}{322}{حَدَّثَنَا سَعْدُ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ زَيْنَبَ ابْنَةِ أَبِي سَلَمَةَ، حَدَّثَتْهُ أَنَّ أُمَّ سَلَمَةَ قَالَتْ حِضْتُ وَأَنَا مَعَ النَّبِيِّ، صلى الله عليه وسلم فِي الْخَمِيلَةِ، فَانْسَلَلْتُ فَخَرَجْتُ مِنْهَا، فَأَخَذْتُ ثِيَابَ حِيضَتِي فَلَبِسْتُهَا، فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنُفِسْتِ ‏"‏‏.‏ قُلْتُ نَعَمْ، فَدَعَانِي فَأَدْخَلَنِي مَعَهُ فِي الْخَمِيلَةِ‏.‏ قَالَتْ وَحَدَّثَتْنِي أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُقَبِّلُهَا وَهُوَ صَائِمٌ، وَكُنْتُ أَغْتَسِلُ أَنَا وَالنَّبِيُّ صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ مِنَ الْجَنَابَةِ‏.‏\hadithno{322}\hadithtrans{Narrated Zainab bint Abi Salama:Um-Salama said, "I got my menses while I was lying with the Prophet (ﷺ) under a woolen sheet. So I slipped away, took the clothes for menses and put them on. Allah's Messenger (ﷺ) said, 'Have you got your menses?' I replied, 'Yes.' Then he called me and took me with him under the woolen sheet." Um Salama further said, "The Prophet (ﷺ) used to kiss me while he was fasting. The Prophet (ﷺ) and I used to take the bath of Janaba from a single pot}}
\hadithdefcmd{bukhari}{323}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ زَيْنَبَ ابْنَةِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ بَيْنَا أَنَا مَعَ النَّبِيِّ، صلى الله عليه وسلم مُضْطَجِعَةً فِي خَمِيلَةٍ حِضْتُ، فَانْسَلَلْتُ فَأَخَذْتُ ثِيَابَ حِيضَتِي فَقَالَ ‏ "‏ أَنُفِسْتِ ‏"‏‏.‏ فَقُلْتُ نَعَمْ‏.‏ فَدَعَانِي فَاضْطَجَعْتُ مَعَهُ فِي الْخَمِيلَةِ‏.‏\hadithno{323}\hadithtrans{Narrated Um Salama:While I was lying with the Prophet (ﷺ) under a woolen sheet, I got my menses. I slipped away and put on the clothes for menses. The Prophet (ﷺ) said, "Have you got your menses?" I replied, "Yes." He called me and I slept with him under the woolen sheet}}
\hadithdefcmd{bukhari}{324}{حَدَّثَنَا مُحَمَّدٌ ـ هُوَ ابْنُ سَلاَمٍ ـ قَالَ أَخْبَرَنَا عَبْدُ الْوَهَّابِ، عَنْ أَيُّوبَ، عَنْ حَفْصَةَ، قَالَتْ كُنَّا نَمْنَعُ عَوَاتِقَنَا أَنْ يَخْرُجْنَ فِي الْعِيدَيْنِ، فَقَدِمَتِ امْرَأَةٌ فَنَزَلَتْ قَصْرَ بَنِي خَلَفٍ، فَحَدَّثَتْ عَنْ أُخْتِهَا، وَكَانَ زَوْجُ أُخْتِهَا غَزَا مَعَ النَّبِيِّ صلى الله عليه وسلم ثِنْتَىْ عَشَرَةَ، وَكَانَتْ أُخْتِي مَعَهُ فِي سِتٍّ‏.‏ قَالَتْ كُنَّا نُدَاوِي الْكَلْمَى، وَنَقُومُ عَلَى الْمَرْضَى، فَسَأَلَتْ أُخْتِي النَّبِيَّ صلى الله عليه وسلم أَعَلَى إِحْدَانَا بَأْسٌ إِذَا لَمْ يَكُنْ لَهَا جِلْبَابٌ أَنْ لاَ تَخْرُجَ قَالَ ‏"‏ لِتُلْبِسْهَا صَاحِبَتُهَا مِنْ جِلْبَابِهَا، وَلْتَشْهَدِ الْخَيْرَ وَدَعْوَةَ الْمُسْلِمِينَ ‏"‏‏.‏ فَلَمَّا قَدِمَتْ أُمُّ عَطِيَّةَ سَأَلْتُهَا أَسَمِعْتِ النَّبِيَّ صلى الله عليه وسلم قَالَتْ بِأَبِي نَعَمْ ـ وَكَانَتْ لاَ تَذْكُرُهُ إِلاَّ قَالَتْ بِأَبِي ـ سَمِعْتُهُ يَقُولُ ‏"‏ يَخْرُجُ الْعَوَاتِقُ وَذَوَاتُ الْخُدُورِ، أَوِ الْعَوَاتِقُ ذَوَاتُ الْخُدُورِ وَالْحُيَّضُ، وَلْيَشْهَدْنَ الْخَيْرَ وَدَعْوَةَ الْمُؤْمِنِينَ، وَيَعْتَزِلُ الْحُيَّضُ الْمُصَلَّى ‏"‏‏.‏ قَالَتْ حَفْصَةُ فَقُلْتُ الْحُيَّضُ فَقَالَتْ أَلَيْسَ تَشْهَدُ عَرَفَةَ وَكَذَا وَكَذَا\hadithno{324}\hadithtrans{Narrated Aiyub:Hafsa said, 'We used to forbid our young women to go out for the two `Id prayers. A woman came and stayed at the palace of Bani Khalaf and she narrated about her sister whose husband took part in twelve holy battles along with the Prophet (ﷺ) and her sister was with her husband in six (out of these twelve). She (the woman's sister) said, "We used to treat the wounded, look after the patients and once I asked the Prophet, 'Is there any harm for any of us to stay at home if she doesn't have a veil?' He said, 'She should cover herself with the veil of her companion and should participate in the good deeds and in the religious gathering of the Muslims.' When Um `Atiya came I asked her whether she had heard it from the Prophet. She replied, "Yes. May my father be sacrificed for him (the Prophet)! (Whenever she mentioned the Prophet (ﷺ) she used to say, 'May my father be sacrificed for him) I have heard the Prophet (ﷺ) saying, 'The unmarried young virgins and the mature girl who stay often screened or the young unmarried virgins who often stay screened and the menstruating women should come out and participate in the good deeds as well as the religious gathering of the faithful believers but the menstruating women should keep away from the Musalla (praying place).' " Hafsa asked Um `Atiya surprisingly, "Do you say the menstruating women?" She replied, "Doesn't a menstruating woman attend `Arafat (Hajj) and such and such (other deeds)?}}
\hadithdefcmd{bukhari}{325}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي رَجَاءٍ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ سَمِعْتُ هِشَامَ بْنَ عُرْوَةَ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ،‏.‏ أَنَّ فَاطِمَةَ بِنْتَ أَبِي حُبَيْشٍ، سَأَلَتِ النَّبِيَّ صلى الله عليه وسلم قَالَتْ إِنِّي أُسْتَحَاضُ فَلاَ أَطْهُرُ، أَفَأَدَعُ الصَّلاَةَ فَقَالَ ‏ "‏ لاَ، إِنَّ ذَلِكِ عِرْقٌ، وَلَكِنْ دَعِي الصَّلاَةَ قَدْرَ الأَيَّامِ الَّتِي كُنْتِ تَحِيضِينَ فِيهَا، ثُمَّ اغْتَسِلِي وَصَلِّي ‏"‏‏.‏\hadithno{325}\hadithtrans{Narrated `Aisha:Fatima bint Abi Hubaish asked the Prophet, "I got persistent bleeding (in between the periods) and do not become clean. Shall I give up prayers?" He replied, "No, this is from a blood vessel. Give up the prayers only for the days on which you usually get the menses and then take a bath and offer your prayers}}
\hadithdefcmd{bukhari}{326}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ كُنَّا لاَ نَعُدُّ الْكُدْرَةَ وَالصُّفْرَةَ شَيْئًا‏.‏\hadithno{326}\hadithtrans{Narrated Um `Atiya:We never considered yellowish discharge as a thing of importance (as menses)}}
\hadithdefcmd{bukhari}{327}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنِي ابْنُ أَبِي ذِئْبٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، وَعَنْ عَمْرَةَ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ أُمَّ حَبِيبَةَ اسْتُحِيضَتْ سَبْعَ سِنِينَ، فَسَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ، فَأَمَرَهَا أَنْ تَغْتَسِلَ فَقَالَ ‏ "‏ هَذَا عِرْقٌ ‏"‏‏.‏ فَكَانَتْ تَغْتَسِلُ لِكُلِّ صَلاَةٍ‏.‏\hadithno{327}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) Um Habiba got bleeding in between the periods for seven years. She asked Allah's Messenger (ﷺ) about it. He ordered her to take a bath (after the termination of actual periods) and added that it was (from) a blood vessel. So she used to take a bath for every prayer}}
\hadithdefcmd{bukhari}{328}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ أَبِيهِ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ، إِنَّ صَفِيَّةَ بِنْتَ حُيَىٍّ قَدْ حَاضَتْ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَعَلَّهَا تَحْبِسُنَا، أَلَمْ تَكُنْ طَافَتْ مَعَكُنَّ ‏"‏‏.‏ فَقَالُوا بَلَى‏.‏ قَالَ ‏"‏ فَاخْرُجِي ‏"‏‏.‏\hadithno{328}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) I told Allah's Messenger (ﷺ) that Safiya bint Huyai had got her menses. He said, "She will probably delay us. Did she perform Tawaf (Al-Ifada) with you?" We replied, "Yes." On that the Prophet (ﷺ) told her to depart}}
\hadithdefcmd{bukhari}{330}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، قَالَ حَدَّثَنَا وُهَيْبٌ، عَنْ عَبْدِ اللَّهِ بْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ رُخِّصَ لِلْحَائِضِ أَنْ تَنْفِرَ، إِذَا حَاضَتْ‏.‏ وَكَانَ ابْنُ عُمَرَ يَقُولُ فِي أَوَّلِ أَمْرِهِ إِنَّهَا لاَ تَنْفِرُ‏.‏ ثُمَّ سَمِعْتُهُ يَقُولُ تَنْفِرُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ لَهُنَّ‏.‏\hadithno{330}\hadithtrans{Narrated Ibn `Abbas:A woman is allowed to leave (go back home) if she gets menses (after Tawaf-Al-Ifada). Ibn `Umar formerly used to say that she should not leave but later on I heard him saying, "She may leave, since Allah's Messenger (ﷺ) gave them the permission to leave (after Tawaf-Al-Ifada)}}
\hadithdefcmd{bukhari}{331}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، عَنْ زُهَيْرٍ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا أَقْبَلَتِ الْحَيْضَةُ فَدَعِي الصَّلاَةَ، وَإِذَا أَدْبَرَتْ فَاغْسِلِي عَنْكِ الدَّمَ وَصَلِّي ‏"‏‏.‏\hadithno{331}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said to me, "Give up the prayer when your menses begin and when it has finished, wash the blood off your body (take a bath) and start praying}}
\hadithdefcmd{bukhari}{332}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي سُرَيْجٍ، قَالَ أَخْبَرَنَا شَبَابَةُ، قَالَ أَخْبَرَنَا شُعْبَةُ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، أَنَّ امْرَأَةً، مَاتَتْ فِي بَطْنٍ، فَصَلَّى عَلَيْهَا النَّبِيُّ صلى الله عليه وسلم فَقَامَ وَسَطَهَا‏.‏\hadithno{332}\hadithtrans{Narrated Samura bin Jundub:The Prophet (ﷺ) offered the funeral prayer for the dead body of a woman who died during delivery (i.e. childbirth) and he stood by the middle of her body}}
\hadithdefcmd{bukhari}{333}{حَدَّثَنَا الْحَسَنُ بْنُ مُدْرِكٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ حَمَّادٍ، قَالَ أَخْبَرَنَا أَبُو عَوَانَةَ ـ اسْمُهُ الْوَضَّاحُ ـ مِنْ كِتَابِهِ قَالَ أَخْبَرَنَا سُلَيْمَانُ الشَّيْبَانِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، قَالَ سَمِعْتُ خَالَتِي، مَيْمُونَةَ ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا كَانَتْ تَكُونُ حَائِضًا لاَ تُصَلِّي، وَهْىَ مُفْتَرِشَةٌ بِحِذَاءِ مَسْجِدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهْوَ يُصَلِّي عَلَى خُمْرَتِهِ، إِذَا سَجَدَ أَصَابَنِي بَعْضُ ثَوْبِهِ‏.‏\hadithno{333}\hadithtrans{Narrated Maimuna:(the wife of the Prophet) During my menses, I never prayed, but used to sit on the mat beside the mosque of Allah's Messenger (ﷺ). He used to offer the prayer on his sheet and in prostration some of his clothes used to touch me}}
