% Auto-generated chapter 0 for nasai
% Hadiths in this chapter: 82

\hadithdefcmd{nasai}{3857}{\hadithno{3857}\hadithgrade{Abu Ghuddah: Daif Muquf; Al-Albani: Daif Muquf}\hadithtrans{}}
\hadithdefcmd{nasai}{3858}{\hadithno{3858}\hadithgrade{Abu Ghuddah: Sahih Maqtu; Al-Albani: Sahih Maqtu}\hadithtrans{}}
\hadithdefcmd{nasai}{3859}{\hadithno{3859}\hadithgrade{Abu Ghuddah: Sahih Maqtu; Al-Albani: Sahih Maqtu}\hadithtrans{}}
\hadithdefcmd{nasai}{3860}{\hadithno{3860}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu}\hadithtrans{}}
\hadithdefcmd{nasai}{3861}{\hadithno{3861}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu}\hadithtrans{}}
\hadithdefcmd{nasai}{3862}{\hadithno{3862}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3863}{\hadithno{3863}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3864}{\hadithno{3864}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3865}{\hadithno{3865}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3866}{\hadithno{3866}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3867}{\hadithno{3867}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3868}{\hadithno{3868}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3869}{\hadithno{3869}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3870}{\hadithno{3870}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3871}{\hadithno{3871}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3872}{\hadithno{3872}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3873}{\hadithno{3873}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3874}{\hadithno{3874}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3875}{\hadithno{3875}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3876}{\hadithno{3876}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3877}{\hadithno{3877}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3878}{\hadithno{3878}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3879}{\hadithno{3879}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith}\hadithtrans{}}
\hadithdefcmd{nasai}{3880}{\hadithno{3880}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith}\hadithtrans{}}
\hadithdefcmd{nasai}{3881}{\hadithno{3881}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3882}{\hadithno{3882}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3883}{\hadithno{3883}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3884}{\hadithno{3884}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3885}{\hadithno{3885}\hadithgrade{Abu Ghuddah: Hasan Sahih Isnaad; Al-Albani: Hasan Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3886}{\hadithno{3886}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3887}{\hadithno{3887}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3888}{\hadithno{3888}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3889}{\hadithno{3889}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3890}{\hadithno{3890}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3891}{\hadithno{3891}\hadithgrade{Al-Albani: Daif}\hadithtrans{}}
\hadithdefcmd{nasai}{3892}{\hadithno{3892}\hadithgrade{Abu Ghuddah: Sahih Maqtu; Al-Albani: Sahih Maqtu}\hadithtrans{}}
\hadithdefcmd{nasai}{3893}{\hadithno{3893}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3894}{\hadithno{3894}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan}\hadithtrans{}}
\hadithdefcmd{nasai}{3895}{\hadithno{3895}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3896}{\hadithno{3896}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3897}{\hadithno{3897}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3898}{\hadithno{3898}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3899}{\hadithno{3899}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3900}{\hadithno{3900}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3901}{\hadithno{3901}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3902}{\hadithno{3902}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3903}{\hadithno{3903}\hadithgrade{Al-Albani: Daif}\hadithtrans{}}
\hadithdefcmd{nasai}{3904}{\hadithno{3904}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3905}{\hadithno{3905}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3906}{\hadithno{3906}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3907}{\hadithno{3907}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3908}{\hadithno{3908}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3909}{\hadithno{3909}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3910}{\hadithno{3910}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3911}{\hadithno{3911}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3912}{\hadithno{3912}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3913}{\hadithno{3913}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3914}{\hadithno{3914}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3915}{\hadithno{3915}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Daif}\hadithtrans{}}
\hadithdefcmd{nasai}{3916}{\hadithno{3916}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3917}{\hadithno{3917}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3918}{\hadithno{3918}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3919}{\hadithno{3919}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3920}{\hadithno{3920}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3921}{\hadithno{3921}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith}\hadithtrans{}}
\hadithdefcmd{nasai}{3922}{\hadithno{3922}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3923}{\hadithno{3923}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3924}{\hadithno{3924}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3925}{\hadithno{3925}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3926}{\hadithno{3926}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh}\hadithtrans{}}
\hadithdefcmd{nasai}{3927}{\hadithno{3927}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif}\hadithtrans{}}
\hadithdefcmd{nasai}{3928}{\hadithno{3928}\hadithgrade{Al-Albani: Sahih Isnaad Maqtu}\hadithtrans{}}
\hadithdefcmd{nasai}{3929}{\hadithno{3929}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3930}{\hadithno{3930}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{nasai}{3931}{\hadithno{3931}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3932}{\hadithno{3932}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad}\hadithtrans{}}
\hadithdefcmd{nasai}{3933}{\hadithno{3933}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf}\hadithtrans{}}
\hadithdefcmd{nasai}{3934}{\hadithno{3934}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu}\hadithtrans{}}
\hadithdefcmd{nasai}{3935}{\hadithno{3935}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu}\hadithtrans{}}
\hadithdefcmd{nasai}{3936}{\hadithno{3936}\hadithgrade{Abu Ghuddah: Daif Isnaad Maqtu; Al-Albani: Daif Isnaad Maqtu}\hadithtrans{}}
\hadithdefcmd{nasai}{3937}{\hadithno{3937}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif}\hadithtrans{}}
\hadithdefcmd{nasai}{3938}{\hadithno{3938}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu}\hadithtrans{}}
