% Auto-generated chapter 38 for nasai
% Hadiths in this chapter: 16

\hadithdefcmd{nasai}{4133}{أَخْبَرَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ الْحَمَّالُ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ الزُّهْرِيِّ، عَنْ يَزِيدَ بْنِ هُرْمُزَ، أَنَّ نَجْدَةَ الْحَرُورِيَّ، حِينَ خَرَجَ فِي فِتْنَةِ ابْنِ الزُّبَيْرِ أَرْسَلَ إِلَى ابْنِ عَبَّاسٍ يَسْأَلُهُ عَنْ سَهْمِ ذِي الْقُرْبَى لِمَنْ تُرَاهُ قَالَ هُوَ لَنَا لِقُرْبَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَسَمَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم لَهُمْ وَقَدْ كَانَ عُمَرُ عَرَضَ عَلَيْنَا شَيْئًا رَأَيْنَاهُ دُونَ حَقِّنَا فَأَبَيْنَا أَنْ نَقْبَلَهُ وَكَانَ الَّذِي عَرَضَ عَلَيْهِمْ أَنْ يُعِينَ نَاكِحَهُمْ وَيَقْضِيَ عَنْ غَارِمِهِمْ وَيُعْطِيَ فَقِيرَهُمْ وَأَبَى أَنْ يَزِيدَهُمْ عَلَى ذَلِكَ ‏.‏\hadithno{4133}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Yazid bin Hurmuz that:when Najdah Al-Haruriyyah rebelled during the Fitnah of Ibn Zubayr, he sent word to Ibn 'Abbas asking him about the share of the relatives (of the Messenger of Allah) -to whom did he think it should be given? He replied: "It is for us, because of our blood ties to the Messenger of Allah allocated it to them, but 'Umar offered us something we thought was less than what was our due, and we refused to accept it. What he offered to them who wanted to get married, and to help the debtors pay off their debts, and he gave to their indigent. But he refused to give them more than that}}
\hadithdefcmd{nasai}{4134}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ هَارُونَ - قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، وَمُحَمَّدِ بْنِ عَلِيٍّ، عَنْ يَزِيدَ بْنِ هُرْمُزَ، قَالَ كَتَبَ نَجْدَةُ إِلَى ابْنِ عَبَّاسٍ يَسْأَلُهُ عَنْ سَهْمِ، ذِي الْقُرْبَى لِمَنْ هُوَ قَالَ يَزِيدُ بْنُ هُرْمُزَ وَأَنَا كَتَبْتُ كِتَابَ ابْنِ عَبَّاسٍ إِلَى نَجْدَةَ كَتَبْتُ إِلَيْهِ كَتَبْتَ تَسْأَلُنِي عَنْ سَهْمِ ذِي الْقُرْبَى لِمَنْ هُوَ وَهُوَ لَنَا أَهْلَ الْبَيْتِ وَقَدْ كَانَ عُمَرُ دَعَانَا إِلَى أَنْ يُنْكِحَ مِنْهُ أَيِّمَنَا وَيُحْذِيَ مِنْهُ عَائِلَنَا وَيَقْضِيَ مِنْهُ عَنْ غَارِمِنَا فَأَبَيْنَا إِلاَّ أَنْ يُسَلِّمَهُ لَنَا وَأَبَى ذَلِكَ فَتَرَكْنَاهُ عَلَيْهِ ‏.‏\hadithno{4134}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Yazid bin Hurmuz said:"Najdah wrote to Ibn 'Abbas and asked him about the share of the relatives (of the Messenger of Allah), to whom should it be given?" Yazid bin Hurmuz said:"I wrote down the letter of Ibn 'Abbas to Najdah in which he said; You have written asking me about the share of the relatives (of the Messenger of Allah), to whom should it be given? It is for us, the members of the household (Ahl Al-Bait). 'Umar used to offer to help the single among us (to get married), and to give some to our poor and to pay off the debts of our debtors. We insisted that he should given it to us, but he refused, and we left it at that}}
\hadithdefcmd{nasai}{4135}{أَخْبَرَنَا عَمْرُو بْنُ يَحْيَى، قَالَ حَدَّثَنَا مَحْبُوبٌ، - يَعْنِي ابْنَ مُوسَى - قَالَ أَنْبَأَنَا أَبُو إِسْحَاقَ، - وَهُوَ الْفَزَارِيُّ - عَنِ الأَوْزَاعِيِّ، قَالَ كَتَبَ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ إِلَى عُمَرَ بْنِ الْوَلِيدِ كِتَابًا فِيهِ وَقَسْمُ أَبِيكَ لَكَ الْخُمُسُ كُلُّهُ وَإِنَّمَا سَهْمُ أَبِيكَ كَسَهْمِ رَجُلٍ مِنَ الْمُسْلِمِينَ وَفِيهِ حَقُّ اللَّهِ وَحَقُّ الرَّسُولِ وَذِي الْقُرْبَى وَالْيَتَامَى وَالْمَسَاكِينِ وَابْنِ السَّبِيلِ فَمَا أَكْثَرَ خُصَمَاءَ أَبِيكَ يَوْمَ الْقِيَامَةِ فَكَيْفَ يَنْجُو مَنْ كَثُرَتْ خُصَمَاؤُهُ وَإِظْهَارُكَ الْمَعَازِفَ وَالْمِزْمَارَ بِدْعَةٌ فِي الإِسْلاَمِ وَلَقَدْ هَمَمْتُ أَنْ أَبْعَثَ إِلَيْكَ مَنْ يَجُزُّ جُمَّتَكَ جُمَّةَ السُّوءِ ‏.‏\hadithno{4135}\hadithgrade{Abu Ghuddah: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Al-Awza'i said:"Umar bin 'Abdul-'Aziz wrote a letter to 'Umar bin Al-Walid in which he said: 'The share that your father gave to you was the entire Khumus,[1] but the share that your father is entitled to is the same as that of any man among the Muslims, on which is due the rights of Allah and His Messenger, and of relatives, orphans, the poor and wayfarers. How many will dispute with your father on the Day of Resurrection! How can he be saved who has so many disputants? And your openly allowing musical instruments and wind instruments is an innovation in Islam. I was thinking of sending someone to you who would cut off your evil long hair}}
\hadithdefcmd{nasai}{4136}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا نَافِعُ بْنُ يَزِيدَ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ جُبَيْرَ بْنَ مُطْعِمٍ، حَدَّثَهُ أَنَّهُ، جَاءَ هُوَ وَعُثْمَانُ بْنُ عَفَّانَ رَسُولَ اللَّهِ صلى الله عليه وسلم يُكَلِّمَانِهِ فِيمَا قَسَمَ مِنْ خُمُسِ حُنَيْنٍ بَيْنَ بَنِي هَاشِمٍ وَبَنِي الْمُطَّلِبِ بْنِ عَبْدِ مَنَافٍ فَقَالاَ يَا رَسُولَ اللَّهِ قَسَمْتَ لإِخْوَانِنَا بَنِي الْمُطَّلِبِ بْنِ عَبْدِ مَنَافٍ وَلَمْ تُعْطِنَا شَيْئًا وَقَرَابَتُنَا مِثْلُ قَرَابَتِهِمْ ‏.‏ فَقَالَ لَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا أَرَى هَاشِمًا وَالْمُطَّلِبَ شَيْئًا وَاحِدًا ‏"‏ ‏.‏ قَالَ جُبَيْرُ بْنُ مُطْعِمٍ وَلَمْ يَقْسِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم لِبَنِي عَبْدِ شَمْسٍ وَلاَ لِبَنِي نَوْفَلٍ مِنْ ذَلِكَ الْخُمُسِ شَيْئًا كَمَا قَسَمَ لِبَنِي هَاشِمٍ وَبَنِي الْمُطَّلِبِ ‏.‏\hadithno{4136}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Sa'eed bin Al-Musayyab narrated that Jubair bin Mut'im told him:"He and 'Uthman bin 'Affan came to the Messenger of Allah to speak to him about what he had distributed of the Khumus of Hunain to Banu Hashim and Banu Al-Muttalib bin 'Abd Manaf. They said: 'O Messenger of Allah, you distributed it to our brothers; Banu Al-Muttalib bin 'Abd Manaf, and you did not give us anything, and our relationship to you in the same as theirs. 'The Messenger of Allah said to them: 'I see that Hashim and Al-Muttalib are the same." Jubair bin Mut'im said: "The Messenger of Allah did not allocate anything to Banu 'Abd Shams or Banu Nawfal from that Khumus, as he allocated to Banu Hashim and Banu Al-Muttalib}}
\hadithdefcmd{nasai}{4137}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالَ أَنْبَأَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، قَالَ لَمَّا قَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَهْمَ ذِي الْقُرْبَى بَيْنَ بَنِي هَاشِمٍ وَبَنِي الْمُطَّلِبِ أَتَيْتُهُ أَنَا وَعُثْمَانُ بْنُ عَفَّانَ فَقُلْنَا يَا رَسُولَ اللَّهِ هَؤُلاَءِ بَنُو هَاشِمٍ لاَ نُنْكِرُ فَضْلَهُمْ لِمَكَانِكَ الَّذِي جَعَلَكَ اللَّهُ بِهِ مِنْهُمْ أَرَأَيْتَ بَنِي الْمُطَّلِبِ أَعْطَيْتَهُمْ وَمَنَعْتَنَا فَإِنَّمَا نَحْنُ وَهُمْ مِنْكَ بِمَنْزِلَةٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّهُمْ لَمْ يُفَارِقُونِي فِي جَاهِلِيَّةٍ وَلاَ إِسْلاَمٍ إِنَّمَا بَنُو هَاشِمٍ وَبَنُو الْمُطَّلِبِ شَىْءٌ وَاحِدٌ ‏"‏ ‏.‏ وَشَبَّكَ بَيْنَ أَصَابِعِهِ ‏.‏\hadithno{4137}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jubair bin Mut'im said:"When the Messenger of Allah distributed the share for his relatives to Banu Hashim and BanuA-Muttalib, I came to himwith 'Uthman bin 'Affan and we said: 'O Messenger of Allah, no one denies the virtue of Banu Hashim because of the relationship between you and them. But how come you have given (a share) to Banu Al-Muttalib and not to us? They and we share the same degree of relationship to you. 'The Messenger of Allah said: "They did not abandon me during the Jahiliyyah or in Islam. Banu Hashim and Banu Al-Muttalib are the same thing, and he interlaced his fingers}}
\hadithdefcmd{nasai}{4138}{أَخْبَرَنَا عَمْرُو بْنُ يَحْيَى بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا مَحْبُوبٌ، - يَعْنِي ابْنَ مُوسَى - قَالَ أَنْبَأَنَا أَبُو إِسْحَاقَ، - وَهُوَ الْفَزَارِيُّ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَيَّاشٍ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ مَكْحُولٍ، عَنْ أَبِي سَلاَّمٍ، عَنْ أَبِي أُمَامَةَ الْبَاهِلِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ أَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ حُنَيْنٍ وَبَرَةً مِنْ جَنْبِ بَعِيرٍ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ إِنَّهُ لاَ يَحِلُّ لِي مِمَّا أَفَاءَ اللَّهُ عَلَيْكُمْ قَدْرَ هَذِهِ إِلاَّ الْخُمُسُ وَالْخُمُسُ مَرْدُودٌ عَلَيْكُمْ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ اسْمُ أَبِي سَلاَّمٍ مَمْطُورٌ وَهُوَ حَبَشِيٌّ وَاسْمُ أَبِي أُمَامَةَ صُدَىُّ بْنُ عَجْلاَنَ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{4138}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ubadah bin Al-Samit said:"On the day of Hunain the Messenger of Allah took a hair from the side of a camel and said: 'O you people, it is not permissible for me to take even the equivalent of this from the Fay' that Allah has bestowed upon you, except the Khumus, and the Khumus will come back to you." (Sahih) Abu 'Abdur-Rahman (An-Nasa'i) said: Abu Sallam's name is Mamtur and he is Ethiopian, and Abu Umamah's name is Sudai bin 'Ajlan}}
\hadithdefcmd{nasai}{4139}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَى بَعِيرًا فَأَخَذَ مِنْ سَنَامِهِ وَبَرَةً بَيْنَ إِصْبَعَيْهِ ثُمَّ قَالَ ‏ "‏ إِنَّهُ لَيْسَ لِي مِنَ الْفَىْءِ شَىْءٌ وَلاَ هَذِهِ إِلاَّ الْخُمُسُ وَالْخُمُسُ مَرْدُودٌ فِيكُمْ ‏"‏ ‏.‏\hadithno{4139}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather, that:the Messenger of Allah went to a camel, and took a hair from its hump between his fingers and said: "I am not entitled to take anything from the Fay, not even this, except the Khumus, and the Khumus will come back to you}}
\hadithdefcmd{nasai}{4140}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، - يَعْنِي ابْنَ دِينَارٍ - عَنِ الزُّهْرِيِّ، عَنْ مَالِكِ بْنِ أَوْسِ بْنِ الْحَدَثَانِ، عَنْ عُمَرَ، قَالَ كَانَتْ أَمْوَالُ بَنِي النَّضِيرِ مِمَّا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِمَّا لَمْ يُوجِفِ الْمُسْلِمُونَ عَلَيْهِ بِخَيْلٍ وَلاَ رِكَابٍ فَكَانَ يُنْفِقُ عَلَى نَفْسِهِ مِنْهَا قُوتَ سَنَةٍ وَمَا بَقِيَ جَعَلَهُ فِي الْكُرَاعِ وَالسِّلاَحِ عُدَّةً فِي سَبِيلِ اللَّهِ ‏.‏\hadithno{4140}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Umar said:"The wealth of Banu An-Nadir was among the Fay' that Allah bestowed upon His Messenger, in cases where the Muslims did not go out on and expedition with horses and camels. From it he kept for himself food for one year, and what was left he spent on cavalry and weapons equipment for the cause of Allah}}
\hadithdefcmd{nasai}{4141}{أَخْبَرَنَا عَمْرُو بْنُ يَحْيَى بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا مَحْبُوبٌ، - يَعْنِي ابْنَ مُوسَى - قَالَ أَنْبَأَنَا أَبُو إِسْحَاقَ، - هُوَ الْفَزَارِيُّ - عَنْ شُعَيْبِ بْنِ أَبِي حَمْزَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ فَاطِمَةَ، أَرْسَلَتْ إِلَى أَبِي بَكْرٍ تَسْأَلُهُ مِيرَاثَهَا مِنَ النَّبِيِّ صلى الله عليه وسلم مِنْ صَدَقَتِهِ وَمِمَّا تَرَكَ مِنْ خُمُسِ خَيْبَرَ قَالَ أَبُو بَكْرٍ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نُورَثُ ‏"‏ ‏.‏\hadithno{4141}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that:Fatimah sent word to Abu Bakr asking for her inheritance from the Prophet, from his charity and what was left of the Khumus of Khaibar. Abu Bakar said: "The Messenger of Allah said: 'We are not inherited from}}
\hadithdefcmd{nasai}{4142}{أَخْبَرَنَا عَمْرُو بْنُ يَحْيَى، قَالَ حَدَّثَنَا مَحْبُوبٌ، قَالَ أَنْبَأَنَا أَبُو إِسْحَاقَ، عَنْ زَائِدَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ وَاعْلَمُوا أَنَّمَا غَنِمْتُمْ مِنْ شَىْءٍ فَأَنَّ لِلَّهِ خُمُسَهُ وَلِلرَّسُولِ وَلِذِي الْقُرْبَى ‏\}‏ قَالَ خُمُسُ اللَّهِ وَخُمُسُ رَسُولِهِ وَاحِدٌ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَحْمِلُ مِنْهُ وَيُعْطِي مِنْهُ وَيَضَعُهُ حَيْثُ شَاءَ وَيَصْنَعُ بِهِ مَا شَاءَ ‏.‏\hadithno{4142}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mursal; Al-Albani: Sahih Isnaad Mursal; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Ata' said concerning the saying of Allah, the Mighty and Sublime:"And know that whatever of spoils of war that you may gain, verily, (1/5th) of it is assigned to Allah, and to the Messenger, and to the near relatives (of the Messenger (Muhammad)" "The Khumus (one-fifth) of Allah and of His Messenger is the same. The Messenger of Allah used to provide mounts (for jihad) with it, and give some (to the poor), and distribute it however he wanted, and do with it whatever he wanted}}
\hadithdefcmd{nasai}{4143}{أَخْبَرَنَا عَمْرُو بْنُ يَحْيَى بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا مَحْبُوبٌ، - يَعْنِي ابْنَ مُوسَى - قَالَ أَنْبَأَنَا أَبُو إِسْحَاقَ، - هُوَ الْفَزَارِيُّ - عَنْ سُفْيَانَ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، قَالَ سَأَلْتُ الْحَسَنَ بْنَ مُحَمَّدٍ عَنْ قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ وَاعْلَمُوا أَنَّمَا غَنِمْتُمْ مِنْ شَىْءٍ فَأَنَّ لِلَّهِ خُمُسَهُ ‏\}‏ قَالَ هَذَا مَفَاتِحُ كَلاَمِ اللَّهِ الدُّنْيَا وَالآخِرَةُ لِلَّهِ قَالَ اخْتَلَفُوا فِي هَذَيْنِ السَّهْمَيْنِ بَعْدَ وَفَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم سَهْمِ الرَّسُولِ وَسَهْمِ ذِي الْقُرْبَى فَقَالَ قَائِلٌ سَهْمُ الرَّسُولِ صلى الله عليه وسلم لِلْخَلِيفَةِ مِنْ بَعْدِهِ وَقَالَ قَائِلٌ سَهْمُ ذِي الْقُرْبَى لِقَرَابَةِ الرَّسُولِ صلى الله عليه وسلم وَقَالَ قَائِلٌ سَهْمُ ذِي الْقُرْبَى لِقَرَابَةِ الْخَلِيفَةِ فَاجْتَمَعَ رَأْيُهُمْ عَلَى أَنْ جَعَلُوا هَذَيْنِ السَّهْمَيْنِ فِي الْخَيْلِ وَالْعُدَّةِ فِي سَبِيلِ اللَّهِ فَكَانَا فِي ذَلِكَ خِلاَفَةَ أَبِي بَكْرٍ وَعُمَرَ ‏.‏\hadithno{4143}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mursal; Al-Albani: Sahih Isnaad Mursal; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Qais bin Muslim said:" Iasked Al-Hasan bin Muhammad about the saying of Allah, the Might and Sublime: 'and know that whatever of spoils of war that you may gain, verily, one-fifth of it is assigned to Allah. He said: 'This is the key to the Speech of Allah. This world and the Hereafter belling to Allah. He said: 'They differed concerning these two shares after the death of the Messenger of Allah, the share of the Messenger and the share of the near relatives (of the Messenger of Allah). Some said that the share of the near relatives was for the relatives of the Messenger, and some said that the share of the near relatives was for the relatives of the Khalifah. Then they agreed that these two shares should be spent on horses and equipment in the cause of Allah, and they were allocated for this purpose during the Khalifah of Abu Bakr and' Umar}}
\hadithdefcmd{nasai}{4144}{أَخْبَرَنَا عَمْرُو بْنُ يَحْيَى بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا مَحْبُوبٌ، قَالَ أَنْبَأَنَا أَبُو إِسْحَاقَ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، قَالَ سَأَلْتُ يَحْيَى بْنَ الْجَزَّارِ عَنْ هَذِهِ الآيَةِ، ‏\{‏ وَاعْلَمُوا أَنَّمَا غَنِمْتُمْ مِنْ شَىْءٍ فَأَنَّ لِلَّهِ خُمُسَهُ وَلِلرَّسُولِ ‏\}‏ قَالَ قُلْتُ كَمْ كَانَ لِلنَّبِيِّ صلى الله عليه وسلم مِنَ الْخُمُسِ قَالَ خُمُسُ الْخُمُسِ ‏.‏\hadithno{4144}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mursal; Al-Albani: Sahih Isnaad Mursal; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Musa bin Abi 'Aishah said:"I asked Yahya bin Al-Jazzar about this Verse: and know that whatever of spoils of war that you may gain, verily, one-fifth of it is assigned to Allah, and to the Messenger". He said: "I said: 'How much of the Khumus did he Prophet take?' He said: 'One-fifth of the Khumus}}
\hadithdefcmd{nasai}{4145}{أَخْبَرَنَا عَمْرُو بْنُ يَحْيَى بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا مَحْبُوبٌ، قَالَ أَنْبَأَنَا أَبُو إِسْحَاقَ، عَنْ مُطَرِّفٍ، قَالَ سُئِلَ الشَّعْبِيُّ عَنْ سَهْمِ النَّبِيِّ، صلى الله عليه وسلم وَصَفِيِّهِ فَقَالَ أَمَّا سَهْمُ النَّبِيِّ صلى الله عليه وسلم فَكَسَهْمِ رَجُلٍ مِنَ الْمُسْلِمِينَ وَأَمَّا سَهْمُ الصَّفِيِّ فَغُرَّةٌ تُخْتَارُ مِنْ أَىِّ شَىْءٍ شَاءَ ‏.‏\hadithno{4145}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mursal; Al-Albani: Sahih Isnaad Mursal; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Mutarrif said:"Ash-Shabi was asked about the share of the Prophet and what he chose for himself. He said: 'The share of the Prophet was like the share of any Muslim man, and what he chose for himself was something precious; he chose whatever he wanted to}}
\hadithdefcmd{nasai}{4146}{أَخْبَرَنَا عَمْرُو بْنُ يَحْيَى، قَالَ حَدَّثَنَا مَحْبُوبٌ، قَالَ أَنْبَأَنَا أَبُو إِسْحَاقَ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، عَنْ يَزِيدَ بْنِ الشِّخِّيرِ، قَالَ بَيْنَا أَنَا مَعَ، مُطَرِّفٍ بِالْمِرْبَدِ إِذْ دَخَلَ رَجُلٌ مَعَهُ قِطْعَةُ أُدْمٍ قَالَ كَتَبَ لِي هَذِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَهَلْ أَحَدٌ مِنْكُمْ يَقْرَأُ قَالَ قُلْتُ أَنَا أَقْرَأُ فَإِذَا فِيهَا ‏ "‏ مِنْ مُحَمَّدٍ النَّبِيِّ صلى الله عليه وسلم لِبَنِي زُهَيْرِ بْنِ أُقَيْشٍ أَنَّهُمْ إِنْ شَهِدُوا أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ وَفَارَقُوا الْمُشْرِكِينَ وَأَقَرُّوا بِالْخُمُسِ فِي غَنَائِمِهِمْ وَسَهْمِ النَّبِيِّ صلى الله عليه وسلم وَصَفِيِّهِ فَإِنَّهُمْ آمِنُونَ بِأَمَانِ اللَّهِ وَرَسُولِهِ ‏"‏ ‏.‏\hadithno{4146}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Yazid bin Ash-Shikhkhir said:"While I was with Mutarrif in Al-Mirbad, a man came in carrying a piece of leather and said: 'This was written to me by the Messenger of Allah. Is there anyone among you who can read?' I said: 'I can read.' And it was (a letter) from Muhammad the Prophet to Banu Zuhair bin Uqaish, who had testified to Lailah illallah, and that Muhammad is the Messenger of Allah, and had left the idolaters, and had agreed to give the Khumus from their spoils of the Prophet, and wheatever he chose for himself, so they became safe and secure by the covenant of Allah and His Messenger}}
\hadithdefcmd{nasai}{4147}{أَخْبَرَنَا عَمْرُو بْنُ يَحْيَى بْنِ الْحَارِثِ، قَالَ أَنْبَأَنَا مَحْبُوبٌ، قَالَ أَنْبَأَنَا أَبُو إِسْحَاقَ، عَنْ شَرِيكٍ، عَنْ خُصَيْفٍ، عَنْ مُجَاهِدٍ، قَالَ الْخُمُسُ الَّذِي لِلَّهِ وَلِلرَّسُولِ كَانَ لِلنَّبِيِّ صلى الله عليه وسلم وَقَرَابَتِهِ لاَ يَأْكُلُونَ مِنَ الصَّدَقَةِ شَيْئًا فَكَانَ لِلنَّبِيِّ صلى الله عليه وسلم خُمُسُ الْخُمُسِ وَلِذِي قَرَابَتِهِ خُمُسُ الْخُمُسِ وَلِلْيَتَامَى مِثْلُ ذَلِكَ وَلِلْمَسَاكِينِ مِثْلُ ذَلِكَ وَلاِبْنِ السَّبِيلِ مِثْلُ ذَلِكَ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ قَالَ اللَّهُ جَلَّ ثَنَاؤُهُ ‏\{‏ وَاعْلَمُوا أَنَّمَا غَنِمْتُمْ مِنْ شَىْءٍ فَأَنَّ لِلَّهِ خُمُسَهُ وَلِلرَّسُولِ وَلِذِي الْقُرْبَى وَالْيَتَامَى وَالْمَسَاكِينِ وَابْنِ السَّبِيلِ ‏\}‏ وَقَوْلُهُ عَزَّ وَجَلَّ لِلَّهِ ابْتِدَاءُ كَلاَمٍ لأَنَّ الأَشْيَاءَ كُلَّهَا لِلَّهِ عَزَّ وَجَلَّ وَلَعَلَّهُ إِنَّمَا اسْتَفْتَحَ الْكَلاَمَ فِي الْفَىْءِ وَالْخُمُسِ بِذِكْرِ نَفْسِهِ لأَنَّهَا أَشْرَفُ الْكَسْبِ وَلَمْ يَنْسُبِ الصَّدَقَةَ إِلَى نَفْسِهِ عَزَّ وَجَلَّ لأَنَّهَا أَوْسَاخُ النَّاسِ وَاللَّهُ تَعَالَى أَعْلَمُ وَقَدْ قِيلَ يُؤْخَذُ مِنَ الْغَنِيمَةِ شَىْءٌ فَيُجْعَلُ فِي الْكَعْبَةِ وَهُوَ السَّهْمُ الَّذِي لِلَّهِ عَزَّ وَجَلَّ وَسَهْمُ النَّبِيِّ صلى الله عليه وسلم إِلَى الإِمَامِ يَشْتَرِي الْكُرَاعَ مِنْهُ وَالسِّلاَحَ وَيُعْطِي مِنْهُ مَنْ رَأَى مِمَّنْ رَأَى فِيهِ غَنَاءً وَمَنْفَعَةً لأَهْلِ الإِسْلاَمِ وَمِنْ أَهْلِ الْحَدِيثِ وَالْعِلْمِ وَالْفِقْهِ وَالْقُرْآنِ وَسَهْمٌ لِذِي الْقُرْبَى وَهُمْ بَنُو هَاشِمٍ وَبَنُو الْمُطَّلِبِ بَيْنَهُمُ الْغَنِيُّ مِنْهُمْ وَالْفَقِيرُ وَقَدْ قِيلَ إِنَّهُ لِلْفَقِيرِ مِنْهُمْ دُونَ الْغَنِيِّ كَالْيَتَامَى وَابْنِ السَّبِيلِ وَهُوَ أَشْبَهُ الْقَوْلَيْنِ بِالصَّوَابِ عِنْدِي وَاللَّهُ تَعَالَى أَعْلَمُ وَالصَّغِيرُ وَالْكَبِيرُ وَالذَّكَرُ وَالأُنْثَى سَوَاءٌ لأَنَّ اللَّهَ عَزَّ وَجَلَّ جَعَلَ ذَلِكَ لَهُمْ وَقَسَّمَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فِيهِمْ وَلَيْسَ فِي الْحَدِيثِ أَنَّهُ فَضَّلَ بَعْضَهُمْ عَلَى بَعْضٍ وَلاَ خِلاَفَ نَعْلَمُهُ بَيْنَ الْعُلَمَاءِ فِي رَجُلٍ لَوْ أَوْصَى بِثُلُثِهِ لِبَنِي فُلاَنٍ أَنَّهُ بَيْنَهُمْ وَأَنَّ الذَّكَرَ وَالأُنْثَى فِيهِ سَوَاءٌ إِذَا كَانُوا يُحْصَوْنَ فَهَكَذَا كُلُّ شَىْءٍ صُيِّرَ لِبَنِي فُلاَنٍ أَنَّهُ بَيْنَهُمْ بِالسَّوِيَّةِ إِلاَّ أَنْ يُبَيِّنَ ذَلِكَ الآمِرُ بِهِ وَاللَّهُ وَلِيُّ التَّوْفِيقِ وَسَهْمٌ لِلْيَتَامَى مِنَ الْمُسْلِمِينَ وَسَهْمٌ لِلْمَسَاكِينِ مِنَ الْمُسْلِمِينَ وَسَهْمٌ لاِبْنِ السَّبِيلِ مِنَ الْمُسْلِمِينَ وَلاَ يُعْطَى أَحَدٌ مِنْهُمْ سَهْمُ مِسْكِينٍ وَسَهْمُ ابْنِ السَّبِيلِ وَقِيلَ لَهُ خُذْ أَيَّهُمَا شِئْتَ وَالأَرْبَعَةُ أَخْمَاسٍ يَقْسِمُهَا الإِمَامُ بَيْنَ مَنْ حَضَرَ الْقِتَالَ مِنَ الْمُسْلِمِينَ الْبَالِغِينَ ‏.‏\hadithno{4147}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Mujahid said:"The Khumus that is for Allah and His Messenger was for the Prophet and His relatives; they did not take anything from the Sadaqah. The Prophet was allocated one-fifth of the Khumus; his relatives were allocated one-fifth of the Khumus; the same was allocated to orphans, the poor and they wayfarers." (Da 'if) Abu Abdur-Rahman (An-Nasi) said: Allah, the Majestic is he and Praised, said: "And know that whatever of spoils of war that you may gain, verily, one-fifth of it is assigned to Allah, and to the Messenger, and to the near relatives ( of the Messenger (Muhammad)), (and also) the orphans, Al-Masakin (the Poor) and the wayfarer." His, the Mighty and Sublime, saying to Allah starts the speech since everything is of Allah, the Mighty and Sublime, saying to Allah starts the speech since everything is of Allah, the Mighty and Sublime. And perhaps He only oened His speech about the Fay and the Khumus, mentioning Himself, because that is the noblest of earnings. And He did not attribute Sadaqah to Himself, the Mighty and Sublime, because that is the dirt of people. And Allah knows best. It was said that something should be taken form the spoils of war and placed inside the Kabah, and this is the share that is for Allah, the Mighty and Sublime. The share of the Messenger is to be given to the imam to buy horses and weapons, and to give to whomever he thinks will benefit the people of Islam, and to the people of Hadith, Knowledge, Fiqh and the Quran. The share that is for near relatives should be given to Banu Hashim and Banu Al-Muttablib, rich and poor alike, or it was said that it should be given to the poor among them and not to the rich, such as orphans and wayfarers. This is the view that is more appropriate in my view, and Allah knows best. And the young and the old, male and female, are equal in that, because Allah, the mighty and sublime, has allocated it to them and the Messenger of Allah distributed it among them, and there is nothing in the Hadith to indicate that he preferred some of them over others. And there is no scholarly dispute, as far as we know, to suggest that if a man bequeaths one-third of his wealth to such a tribe, to be distributed out among them equally, that it should be done otherwise, unless the giver stipulated otherwise. And Allah is the source of strength. And (there is) a share for the orphans among the Muslims, and a share for the poor among the Muslims, and a share for the wayfarers among the Muslims. No one should be given both a share for the poor and a share for the wayfarer; it is to be said to him: "Take whichever of them you want." And the other four-fifths are to be divided by the imam among those adult Muslims who were present in the battle. (Daif)}}
\hadithdefcmd{nasai}{4148}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ إِبْرَاهِيمَ - عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ بْنِ خَالِدٍ، عَنْ مَالِكِ بْنِ أَوْسِ بْنِ الْحَدَثَانِ، قَالَ جَاءَ الْعَبَّاسُ وَعَلِيٌّ إِلَى عُمَرَ يَخْتَصِمَانِ فَقَالَ الْعَبَّاسُ اقْضِ بَيْنِي وَبَيْنَ هَذَا ‏.‏ فَقَالَ النَّاسُ افْصِلْ بَيْنَهُمَا ‏.‏ فَقَالَ عُمَرُ لاَ أَفْصِلُ بَيْنَهُمَا قَدْ عَلِمَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ نُورَثُ مَا تَرَكْنَا صَدَقَةٌ ‏"‏ ‏.‏ قَالَ فَقَالَ الزُّهْرِيُّ وَلِيَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخَذَ مِنْهَا قُوتَ أَهْلِهِ وَجَعَلَ سَائِرَهُ سَبِيلَهُ سَبِيلَ الْمَالِ ثُمَّ وَلِيَهَا أَبُو بَكْرٍ بَعْدَهُ ثُمَّ وُلِّيتُهَا بَعْدَ أَبِي بَكْرٍ فَصَنَعْتُ فِيهَا الَّذِي كَانَ يَصْنَعُ ثُمَّ أَتَيَانِي فَسَأَلاَنِي أَنْ أَدْفَعَهَا إِلَيْهِمَا عَلَى أَنْ يَلِيَاهَا بِالَّذِي وَلِيَهَا بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالَّذِي وَلِيَهَا بِهِ أَبُو بَكْرٍ وَالَّذِي وُلِّيتُهَا بِهِ فَدَفَعْتُهَا إِلَيْهِمَا وَأَخَذْتُ عَلَى ذَلِكَ عُهُودَهُمَا ثُمَّ أَتَيَانِي يَقُولُ هَذَا اقْسِمْ لِي بِنَصِيبِي مِنِ ابْنِ أَخِي ‏.‏ وُيَقُولُ هَذَا اقْسِمْ لِي بِنَصِيبِي مِنِ امْرَأَتِي ‏.‏ وَإِنْ شَاءَا أَنْ أَدْفَعَهَا إِلَيْهِمَا عَلَى أَنْ يَلِيَاهَا بِالَّذِي وَلِيَهَا بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالَّذِي وَلِيَهَا بِهِ أَبُو بَكْرٍ وَالَّذِي وُلِّيتُهَا بِهِ دَفَعْتُهَا إِلَيْهِمَا وَإِنْ أَبَيَا كُفِيَا ذَلِكَ ثُمَّ قَالَ ‏\{‏ وَاعْلَمُوا أَنَّمَا غَنِمْتُمْ مِنْ شَىْءٍ فَأَنَّ لِلَّهِ خُمُسَهُ وَلِلرَّسُولِ وَلِذِي الْقُرْبَى وَالْيَتَامَى وَالْمَسَاكِينِ وَابْنِ السَّبِيلِ ‏\}‏ هَذَا لِهَؤُلاَءِ ‏\{‏ إِنَّمَا الصَّدَقَاتُ لِلْفُقَرَاءِ وَالْمَسَاكِينِ وَالْعَامِلِينَ عَلَيْهَا وَالْمُؤَلَّفَةِ قُلُوبُهُمْ وَفِي الرِّقَابِ وَالْغَارِمِينَ وَفِي سَبِيلِ اللَّهِ ‏\}‏ هَذِهِ لِهَؤُلاَءِ ‏\{‏ وَمَا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِنْهُمْ فَمَا أَوْجَفْتُمْ عَلَيْهِ مِنْ خَيْلٍ وَلاَ رِكَابٍ ‏\}‏ قَالَ الزُّهْرِيُّ هَذِهِ لِرَسُولِ اللَّهِ صلى الله عليه وسلم خَاصَّةً قُرًى عَرَبِيَّةً فَدَكُ كَذَا وَكَذَا ‏\{‏ مَا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِنْ أَهْلِ الْقُرَى فَلِلَّهِ وَلِلرَّسُولِ وَلِذِي الْقُرْبَى وَالْيَتَامَى وَالْمَسَاكِينِ وَابْنِ السَّبِيلِ ‏\}‏ وَ ‏\{‏ لِلْفُقَرَاءِ الْمُهَاجِرِينَ الَّذِينَ أُخْرِجُوا مِنْ دِيَارِهِمْ وَأَمْوَالِهِمْ ‏\}‏ ‏\{‏ وَالَّذِينَ تَبَوَّءُوا الدَّارَ وَالإِيمَانَ مِنْ قَبْلِهِمْ ‏\}‏ ‏\{‏ وَالَّذِينَ جَاءُوا مِنْ بَعْدِهِمْ ‏\}‏ فَاسْتَوْعَبَتْ هَذِهِ الآيَةُ النَّاسَ فَلَمْ يَبْقَ أَحَدٌ مِنَ الْمُسْلِمِينَ إِلاَّ لَهُ فِي هَذَا الْمَالِ حَقٌّ - أَوْ قَالَ حَظٌّ - إِلاَّ بَعْضَ مَنْ تَمْلِكُونَ مِنْ أَرِقَّائِكُمْ وَلَئِنْ عِشْتُ إِنْ شَاءَ اللَّهُ لَيَأْتِيَنَّ عَلَى كُلِّ مُسْلِمٍ حَقُّهُ أَوْ قَالَ حَظُّهُ ‏.‏\hadithno{4148}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Malik bin Aws bin Al-Hadathan said:"Al-Abbas and Ali came to 'Umar with a dispute. Al-Abbas said: 'Pass judgment between him and I.' the people said: 'Pass judgment between them.' 'Umar said: 'I will not pass judgment between them. They know that the Messenger of Allah said: We are not inherited from, what we leave behind is charity. He said: And (in this narration of it) Az-Zuhri said: 'It (the Khumus) was under the control of the Messenger of Allah , and he took provision for himself and for his family from it, and disposed to the rest of it as he disposed of other wealth (belonging to the Muslims). Then Abu Bakr took control of it, then I took control of it after Abu Bakr, and I did with it what he sued to do. Then these two came to me and asked me to give it to them so that they could dispose of it as the Messenger of Allah disposed of it, and as Abu Bakr disposed of it, and as I disposed of it. So I gave it to them and I took promises from them that they would take proper care of it. Then they came to me and this one said. Give me my share from my brothers son: and this one said: Give me my share from my wife. If they want me to give it to them on the condition that they would dispose of it in the same manner as the Messenger of Allah did, and as Abu Bakr did, and as I did, I would give it to them, but if they refuse, then they do not have to worry about it.' Then he said: 'And know that whatever of spoils of war that you may gain, verily, one-fifth of it is assigned to Allah, and to the Messenger, and to the near relatives (of the Messenger (Muhammad), (and also) the orphans, Al-Masakin (the poor) and the wayfarer' (Al-Anfal 8:41) this if for them. 'As-Sadaqat (here it means Zakah) are only for the Fuqara (poor), and Al-Masakin (the poor) and those employed to collect (the funds); and to attract the hearts of those who have been inclined (toward Islam); and to free the captives; and for those in debt; and for Allah's cause (I.e. for Mujahidun - those fighting in a holy battle)' - this is for them. 'And what Allah gave as booty (Fay') to His Messenger (Muhammad) from them - for this you made no expeditin with either cavalry or camels.' Az-Zuhri said: This applies exclusively to the Messenger of Allah and refers to an 'Arab village called Fadak, and so on. What Allah gave as booty (Fay') to His Messenger (Muhammad) from the people of the townships - it is for Allah, His Messenger (Muhammad), the kindred (of Messenger Muhammad), the orphans, Al-Masakin (the poor), and the wayfarer (And there is also a share in this booty) for the poor emigrants, who were expelled from their homes and their property And (it is also for) those who, before them, had homes (in Al-Madinah) and had adopted the Faith And those who came after them. These is no one left among the Muslims but he has some rights to this wealth, except for some of the slaved whom you own. If I live, if Allah wills, I will give every Muslim his right." Or he said: "His share}}
