% Auto-generated chapter 50 for bukhari
% Hadiths in this chapter: 6

\hadithdefcmd{bukhari}{2560}{وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ عُرْوَةُ قَالَتْ عَائِشَةُ ـ رضى الله عنها ـ إِنَّ بَرِيرَةَ دَخَلَتْ عَلَيْهَا تَسْتَعِينُهَا فِي كِتَابَتِهَا وَعَلَيْهَا خَمْسَةُ أَوَاقٍ، نُجِّمَتْ عَلَيْهَا فِي خَمْسِ سِنِينَ، فَقَالَتْ لَهَا عَائِشَةُ وَنَفِسَتْ فِيهَا أَرَأَيْتِ إِنْ عَدَدْتُ لَهُمْ عَدَّةً وَاحِدَةً، أَيَبِيعُكِ أَهْلُكِ، فَأُعْتِقَكِ، فَيَكُونَ وَلاَؤُكِ لِي فَذَهَبَتْ بَرِيرَةُ إِلَى أَهْلِهَا، فَعَرَضَتْ ذَلِكَ عَلَيْهِمْ فَقَالُوا لاَ إِلاَّ أَنْ يَكُونَ لَنَا الْوَلاَءُ‏.‏ قَالَتْ عَائِشَةُ فَدَخَلْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ‏.‏ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اشْتَرِيهَا فَأَعْتِقِيهَا، فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا بَالُ رِجَالٍ يَشْتَرِطُونَ شُرُوطًا لَيْسَتْ فِي كِتَابِ اللَّهِ، مَنِ اشْتَرَطَ شَرْطًا لَيْسَ فِي كِتَابِ اللَّهِ فَهْوَ بَاطِلٌ، شَرْطُ اللَّهِ أَحَقُّ وَأَوْثَقُ ‏"‏‏.‏\hadithno{2560}\hadithtrans{Narrated 'Aishah (ra) that Barira came to seek her help in writing of emancipation and she had to pay five Uqiya (of gold) by five yearly installments. 'Aishah said to her, "Do you think that if I pay the whole sum at once, your masters will sell you to me, and I will free you and your Wala' will be for me." Barira went to her masters and told them about that offer. They said that they would not agree to it unless her Wala' would be for them. 'Aishah further said, "I went to Allah's Messenger (ﷺ) and told him about it." Allah's Messenger (ﷺ) said to her, "Buy Barira and manumit her and the Wala' will be for the liberator." Allah's Messenger (ﷺ) then got up and said, "What about those people who stipulate conditions that are not present in Allah's Laws? If anybody stipulates a condition which is not in Allah's Laws, then what he stipulates is invalid. Allah's Condition (Laws) are the truth and are more solid}}
\hadithdefcmd{bukhari}{2561}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ أَخْبَرَتْهُ أَنَّ بَرِيرَةَ جَاءَتْ تَسْتَعِينُهَا فِي كِتَابَتِهَا، وَلَمْ تَكُنْ قَضَتْ مِنْ كِتَابَتِهَا شَيْئًا، قَالَتْ لَهَا عَائِشَةُ ارْجِعِي إِلَى أَهْلِكِ، فَإِنْ أَحَبُّوا أَنْ أَقْضِيَ عَنْكِ كِتَابَتَكِ، وَيَكُونَ وَلاَؤُكِ لِي فَعَلْتُ‏.‏ فَذَكَرَتْ ذَلِكَ بَرِيرَةُ لأَهْلِهَا فَأَبَوْا وَقَالُوا إِنْ شَاءَتْ أَنْ تَحْتَسِبَ عَلَيْكِ فَلْتَفْعَلْ، وَيَكُونَ وَلاَؤُكِ لَنَا، فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ابْتَاعِي فَأَعْتِقِي، فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏ قَالَ ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا بَالُ أُنَاسٍ يَشْتَرِطُونَ شُرُوطًا لَيْسَتْ فِي كِتَابِ اللَّهِ مَنِ اشْتَرَطَ شَرْطًا لَيْسَ فِي كِتَابِ اللَّهِ فَلَيْسَ لَهُ، وَإِنْ شَرَطَ مِائَةَ مَرَّةٍ، شَرْطُ اللَّهِ أَحَقُّ وَأَوْثَقُ ‏"‏‏.‏\hadithno{2561}\hadithtrans{Narrated `Urwa:That `Aisha told him that Barirah came to seek her help in her writing of emancipation (for a certain sum) and that time she had not paid anything of it. `Aisha said to her, "Go back to your masters, and if they agree that I will pay the amount of your writing of emancipation and get your Wala', I will do so." Barirah informed her masters of that but they refused and said, "If she (i.e. `Aisha) is seeking Allah's reward, then she can do so, but your Wala' will be for us." `Aisha mentioned that to Allah's Apostle who said to her, "Buy and manumit (free) her, as the Wala' is for the liberator." Allah's Messenger (ﷺ) then got up and said, "What about the people who stipulate conditions which are not present in Allah's Laws? Whoever imposes conditions which are not present in Allah's Laws, then those conditions will be invalid, even if he imposed these conditions a hundred times. Allah's conditions (Laws) are the truth and are more solid}}
\hadithdefcmd{bukhari}{2562}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ أَرَادَتْ عَائِشَةُ أُمُّ الْمُؤْمِنِينَ أَنْ تَشْتَرِيَ جَارِيَةً لِتُعْتِقَهَا، فَقَالَ أَهْلُهَا عَلَى أَنَّ وَلاَءَهَا لَنَا‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَمْنَعُكِ ذَلِكِ، فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏\hadithno{2562}\hadithtrans{Narrated `Abdullah bin `Umar:Aisha wanted to buy a slave-girl in order to manumit her. The girl's masters stipulated that her Wala' would be for them. Allah's Messenger (ﷺ) said (to `Aisha), "What they stipulate should not stop you, for the Wala' is for the liberator}}
\hadithdefcmd{bukhari}{2563}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ جَاءَتْ بَرِيرَةُ فَقَالَتْ إِنِّي كَاتَبْتُ أَهْلِي عَلَى تِسْعِ أَوَاقٍ، فِي كُلِّ عَامٍ وَقِيَّةٌ، فَأَعِينِينِي‏.‏ فَقَالَتْ عَائِشَةُ إِنْ أَحَبَّ أَهْلُكِ أَنْ أَعُدَّهَا لَهُمْ عَدَّةً وَاحِدَةً، وَأُعْتِقَكِ فَعَلْتُ، وَيَكُونَ وَلاَؤُكِ لِي‏.‏ فَذَهَبَتْ إِلَى أَهْلِهَا، فَأَبَوْا ذَلِكَ عَلَيْهَا، فَقَالَتْ إِنِّي قَدْ عَرَضْتُ ذَلِكَ عَلَيْهِمْ، فَأَبَوْا إِلاَّ أَنْ يَكُونَ الْوَلاَءُ لَهُمْ‏.‏ فَسَمِعَ بِذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَأَلَنِي فَأَخْبَرْتُهُ، فَقَالَ ‏"‏ خُذِيهَا، فَأَعْتِقِيهَا، وَاشْتَرِطِي لَهُمُ الْوَلاَءَ، فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏ قَالَتْ عَائِشَةُ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّاسِ، فَحَمِدَ اللَّهَ، وَأَثْنَى عَلَيْهِ، ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ، فَمَا بَالُ رِجَالٍ مِنْكُمْ يَشْتَرِطُونَ شُرُوطًا لَيْسَتْ فِي كِتَابِ اللَّهِ فَأَيُّمَا شَرْطٍ لَيْسَ فِي كِتَابِ اللَّهِ فَهْوَ بَاطِلٌ، وَإِنْ كَانَ مِائَةَ شَرْطٍ، فَقَضَاءُ اللَّهِ أَحَقُّ، وَشَرْطُ اللَّهِ أَوْثَقُ، مَا بَالُ رِجَالٍ مِنْكُمْ يَقُولُ أَحَدُهُمْ أَعْتِقْ يَا فُلاَنُ وَلِيَ الْوَلاَءُ إِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏\hadithno{2563}\hadithtrans{Narrated Aisha:Barirah came (to `Aisha) and said, "I have made a contract of emancipation with my masters for nine Uqiyas (of gold) to be paid in yearly installments. Therefore, I seek your help." `Aisha said, "If your masters agree, I will pay them the sum at once and free you on condition that your Wala' will be for me." Barirah went to her masters but they refused that offer. She (came back) and said, "I presented to them the offer but they refused, unless the Wala' was for them." Allah's Messenger (ﷺ) heard of that and asked me about it, and I told him about it. On that he said, "Buy and manumit her and stipulate that the Wala' should be for you, as Wala' is for the liberator." `Aisha added, "Allah's Messenger (ﷺ) then got up amongst the people, Glorified and Praised Allah, and said, 'Then after: What about some people who impose conditions which are not present in Allah's Laws? So, any condition which is not present in Allah's Laws is invalid even if they were one-hundred conditions. Allah's ordinance is the truth, and Allah's condition is stronger and more solid. Why do some men from you say, O so-and-so! manumit the slave but the Wala will be for me? Verily, the Wala is for the liberator}}
\hadithdefcmd{bukhari}{2564}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّ بَرِيرَةَ، جَاءَتْ تَسْتَعِينُ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ ـ رضى الله عنها ـ فَقَالَتْ لَهَا إِنْ أَحَبَّ أَهْلُكِ أَنْ أَصُبَّ لَهُمْ ثَمَنَكِ صَبَّةً وَاحِدَةً فَأُعْتِقَكِ فَعَلْتُ‏.‏ فَذَكَرَتْ بَرِيرَةُ ذَلِكَ لأَهْلِهَا، فَقَالُوا لاَ‏.‏ إِلاَّ أَنْ يَكُونَ وَلاَؤُكِ لَنَا‏.‏ قَالَ مَالِكٌ قَالَ يَحْيَى فَزَعَمَتْ عَمْرَةُ أَنَّ عَائِشَةَ ذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ اشْتَرِيهَا وَأَعْتِقِيهَا، فَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏‏.‏\hadithno{2564}\hadithtrans{Narrated `Amra bint `Abdur-Rahman:Barirah went to Aisha, the mother of the faithful believers to seek her help in her emancipation Aisha said to her, "If your masters agree, I will pay them your price in a lump sum and manumit (free) you." Barirah mentioned that offer to her masters but they refused to sell her unless the Wala' was for them. `Aisha told Allah's Messenger (ﷺ) about it. He said, "Buy and manumit her as the Wala' is for the liberator}}
\hadithdefcmd{bukhari}{2565}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ أَيْمَنَ، قَالَ حَدَّثَنِي أَبِي أَيْمَنُ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ ـ رضى الله عنها ـ فَقُلْتُ كُنْتُ غُلاَمًا لِعُتْبَةَ بْنِ أَبِي لَهَبٍ، وَمَاتَ وَوَرِثَنِي بَنُوهُ، وَإِنَّهُمْ بَاعُونِي مِنَ ابْنِ أَبِي عَمْرٍو، فَأَعْتَقَنِي ابْنُ أَبِي عَمْرٍو، وَاشْتَرَطَ بَنُو عُتْبَةَ الْوَلاَءَ‏.‏ فَقَالَتْ دَخَلَتْ بَرِيرَةُ وَهْىَ مُكَاتَبَةٌ فَقَالَتِ اشْتَرِينِي وَأَعْتِقِينِي‏.‏ قَالَتْ نَعَمْ‏.‏ قَالَتْ لاَ يَبِيعُونِي حَتَّى يَشْتَرِطُوا وَلاَئِي‏.‏ فَقَالَتْ لاَ حَاجَةَ لِي بِذَلِكَ‏.‏ فَسَمِعَ بِذَلِكَ النَّبِيُّ صلى الله عليه وسلم أَوْ بَلَغَهُ، فَذَكَرَ لِعَائِشَةَ، فَذَكَرَتْ عَائِشَةُ مَا قَالَتْ لَهَا، فَقَالَ ‏"‏ اشْتَرِيهَا وَأَعْتِقِيهَا، وَدَعِيهِمْ يَشْتَرِطُونَ مَا شَاءُوا ‏"‏‏.‏ فَاشْتَرَتْهَا عَائِشَةُ فَأَعْتَقَتْهَا وَاشْتَرَطَ أَهْلُهَا الْوَلاَءَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الْوَلاَءُ لِمَنْ أَعْتَقَ، وَإِنِ اشْتَرَطُوا مِائَةَ شَرْطٍ ‏"‏‏.‏\hadithno{2565}\hadithtrans{Narrated `Abdul Wahid bin Aiman:I went to `Aisha and said, "I was the slave of `Utba bin Abu Lahab. "Utba died and his sons became my masters who sold me to Ibn Abu `Amr who manumitted me. The sons of `Utba stipulated that my Wala' should be for them." `Aisha said, "Barirah came to me and she was given the writing of emancipation by her masters and she asked me to buy and manumit her. I agreed to it, but Barirah told me that her masters would not sell her unless her Wala' was for them." `Aisha said, "I am not in need of that." When the Prophet (ﷺ) heard that, or he was told about it, he asked `Aisha about it. `Aisha mentioned what Barirah had told her. The Prophet (ﷺ) said, "Buy and manumit (free) her and let them stipulate whatever they like." So, `Aisha bought and manumitted her and her masters stipulated that her Wala' should be for them." The Prophet;, said, "The Wala' will be for the liberator even if they stipulated a hundred conditions}}
