% Auto-generated chapter 15 for nasai
% Hadiths in this chapter: 26

\hadithdefcmd{nasai}{1433}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، عَنِ ابْنِ أَبِي عَمَّارٍ، عَنْ عَبْدِ اللَّهِ بْنِ بَابَيْهِ، عَنْ يَعْلَى بْنِ أُمَيَّةَ، قَالَ قُلْتُ لِعُمَرَ بْنِ الْخَطَّابِ ‏\{‏ لَيْسَ عَلَيْكُمْ جُنَاحٌ أَنْ تَقْصُرُوا، مِنَ الصَّلاَةِ إِنْ خِفْتُمْ أَنْ يَفْتِنَكُمُ الَّذِينَ كَفَرُوا ‏\}‏ فَقَدْ أَمِنَ النَّاسُ ‏.‏ فَقَالَ عُمَرُ رضى الله عنه عَجِبْتُ مِمَّا عَجِبْتَ مِنْهُ فَسَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏"‏ صَدَقَةٌ تَصَدَّقَ اللَّهُ بِهَا عَلَيْكُمْ فَاقْبَلُوا صَدَقَتَهُ ‏"‏ ‏.‏\hadithno{1433}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ya'la bin Umayyah said:"I said to 'Umar bin Al-Khattab: 'There is no sin on you if you shorten salah and if you fear that the disbelievers may put you in trial (attack you). But now the people are safe.' 'Umar said: 'I wondered the same thing, so I asked the Messenger of Allah (ﷺ) about that and he said: This is a favor from Allah (SWT) to you, so accept His favor}}
\hadithdefcmd{nasai}{1434}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أُمَيَّةَ بْنِ عَبْدِ اللَّهِ بْنِ خَالِدٍ، أَنَّهُ قَالَ لِعَبْدِ اللَّهِ بْنِ عُمَرَ إِنَّا نَجِدُ صَلاَةَ الْحَضَرِ وَصَلاَةَ الْخَوْفِ فِي الْقُرْآنِ وَلاَ نَجِدُ صَلاَةَ السَّفَرِ فِي الْقُرْآنِ ‏.‏ فَقَالَ لَهُ ابْنُ عُمَرَ يَا ابْنَ أَخِي إِنَّ اللَّهَ عَزَّ وَجَلَّ بَعَثَ إِلَيْنَا مُحَمَّدًا صلى الله عليه وسلم وَلاَ نَعْلَمُ شَيْئًا وَإِنَّمَا نَفْعَلُ كَمَا رَأَيْنَا مُحَمَّدًا صلى الله عليه وسلم يَفْعَلُ ‏.‏\hadithno{1434}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Umayyah bin 'Abdullah bin Khalid that:He said to 'Abdullah bin 'Umar: "We find (mention of) prayer when one is at home (i.e., not traveling) and prayer at times of fear in the Qur'an, but we do not find any mention in the Qur'an of prayer when traveling. Ibn Umar said to him: 'O son of my brother, Allah (SWT) send Muhammad (ﷺ) to us when we did not know anything, and all we should do is to do that which we saw Muhammad (ﷺ) doing}}
\hadithdefcmd{nasai}{1435}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنْ مَنْصُورِ بْنِ زَاذَانَ، عَنِ ابْنِ سِيرِينَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ مِنْ مَكَّةَ إِلَى الْمَدِينَةِ لاَ يَخَافُ إِلاَّ رَبَّ الْعَالَمِينَ يُصَلِّي رَكْعَتَيْنِ ‏.‏\hadithno{1435}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that:The Messenger of Allah (ﷺ) set out from Makkah to Al-Madinah, fearing nothing but the Lord of the worlds, and praying two rak'ahs}}
\hadithdefcmd{nasai}{1436}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنَّا نَسِيرُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بَيْنَ مَكَّةَ وَالْمَدِينَةِ لاَ نَخَافُ إِلاَّ اللَّهَ عَزَّ وَجَلَّ نُصَلِّي رَكْعَتَيْنِ ‏.‏\hadithno{1436}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"We used to travel with the Messenger of Allah (ﷺ) between Makkah and Al-Madinah, fearing nothing but Allah, the Mighty and Sublime, and praying two rak'ahs}}
\hadithdefcmd{nasai}{1437}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ يَزِيدَ بْنِ خُمَيْرٍ، قَالَ سَمِعْتُ حَبِيبَ بْنَ عُبَيْدٍ، يُحَدِّثُ عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنِ ابْنِ السِّمْطِ، قَالَ رَأَيْتُ عُمَرَ بْنَ الْخَطَّابِ يُصَلِّي بِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ فَسَأَلْتُهُ عَنْ ذَلِكَ، فَقَالَ إِنَّمَا أَفْعَلُ كَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُ ‏.‏\hadithno{1437}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn Al-Simt said:"I saw 'Umar bin Al-Khattab praying two rak'ahs in Dhul-Hulaifah and I asked him about that. He said: 'I am simply doing that which I saw the Messenger of Allah (ﷺ) doing}}
\hadithdefcmd{nasai}{1438}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، عَنْ أَنَسٍ، قَالَ خَرَجْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْمَدِينَةِ إِلَى مَكَّةَ فَلَمْ يَزَلْ يَقْصُرُ حَتَّى رَجَعَ فَأَقَامَ بِهَا عَشْرًا ‏.‏\hadithno{1438}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas said:"I went out with the Messenger of Allah (ﷺ) from Al-Madinah to Mekkah, and he continued to shorten his prayers, and he stayed there for ten days}}
\hadithdefcmd{nasai}{1439}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ الْحَسَنِ بْنِ شَقِيقٍ، قَالَ أَبِي أَنْبَأَنَا أَبُو حَمْزَةَ، - وَهُوَ السُّكَّرِيُّ - عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي السَّفَرِ رَكْعَتَيْنِ وَمَعَ أَبِي بَكْرٍ رَكْعَتَيْنِ وَمَعَ عُمَرَ رَكْعَتَيْنِ رضى الله عنهما ‏.‏\hadithno{1439}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah said:"I prayed two rak'ahs with the Messenger of Allah (ﷺ) on a journey, and two rak'ahs with Abu Bakr, and two rak'ahs with 'Umar, may Allah (SWT) be pleased with them both}}
\hadithdefcmd{nasai}{1440}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ سُفْيَانَ، - وَهُوَ ابْنُ حَبِيبٍ - عَنْ شُعْبَةَ، عَنْ زُبَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عُمَرَ، قَالَ صَلاَةُ الْجُمُعَةِ رَكْعَتَانِ وَالْفِطْرِ رَكْعَتَانِ وَالنَّحْرِ رَكْعَتَانِ وَالسَّفَرِ رَكْعَتَانِ تَمَامٌ غَيْرُ قَصْرٍ عَلَى لِسَانِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1440}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Umar said:"The prayer for jumu'ah is two rak'ahs, and for Al-Fitr is two rak'ahs, and for An-Nahr is two rak'ahs, and for traveling is two rak'ahs, complete and not shortened, on the tongue of the Prophet (ﷺ)}}
\hadithdefcmd{nasai}{1441}{أَخْبَرَنِي مُحَمَّدُ بْنُ وَهْبٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنِي أَبُو عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنِي زَيْدٌ، عَنْ أَيُّوبَ، - وَهُوَ ابْنُ عَائِذٍ - عَنْ بُكَيْرِ بْنِ الأَخْنَسِ، عَنْ مُجَاهِدٍ أَبِي الْحَجَّاجِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ فُرِضَتْ صَلاَةُ الْحَضَرِ عَلَى لِسَانِ نَبِيِّكُمْ صلى الله عليه وسلم أَرْبَعًا وَصَلاَةُ السَّفَرِ رَكْعَتَيْنِ وَصَلاَةُ الْخَوْفِ رَكْعَةً ‏.‏\hadithno{1441}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The prayer of the resident was enjoined on the tongue of your Prophet (ﷺ), four (rak'ahs), and the prayer of the traveler is two rak'ahs, and the prayer of fear is one rak'ah}}
\hadithdefcmd{nasai}{1442}{أَخْبَرَنَا يَعْقُوبُ بْنُ مَاهَانَ، قَالَ حَدَّثَنَا الْقَاسِمُ بْنُ مَالِكٍ، عَنْ أَيُّوبَ بْنِ عَائِذٍ، عَنْ بُكَيْرِ بْنِ الأَخْنَسِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّ اللَّهَ عَزَّ وَجَلَّ فَرَضَ الصَّلاَةَ عَلَى لِسَانِ نَبِيِّكُمْ صلى الله عليه وسلم فِي الْحَضَرِ أَرْبَعًا وَفِي السَّفَرِ رَكْعَتَيْنِ وَفِي الْخَوْفِ رَكْعَةً ‏.‏\hadithno{1442}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"Allah, the Mighty and Sublime, enjoined the prayer on the tongue of your Prophet (ﷺ): While a resident four (rak'ahs), while traveling two, and at times of fear one}}
\hadithdefcmd{nasai}{1443}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، فِي حَدِيثِهِ عَنْ خَالِدِ بْنِ الْحَارِثِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ مُوسَى، - وَهُوَ ابْنُ سَلَمَةَ - قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ كَيْفَ أُصَلِّي بِمَكَّةَ إِذَا لَمْ أُصَلِّ فِي جَمَاعَةٍ قَالَ رَكْعَتَيْنِ سُنَّةَ أَبِي الْقَاسِمِ صلى الله عليه وسلم ‏.‏\hadithno{1443}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Qatadah said:"I heard Muas- bin Salamah-say: 'I said to Ibn 'Abbas: How should I pray in Makkah if I do not pray in congregation? He said: Two rak'ahs, the sunnah of Abu Al-Qasim}}
\hadithdefcmd{nasai}{1444}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا سَعِيدٌ، قَالَ حَدَّثَنَا قَتَادَةُ، أَنَّ مُوسَى بْنَ سَلَمَةَ، حَدَّثَهُمْ أَنَّهُ، سَأَلَ ابْنَ عَبَّاسٍ قُلْتُ تَفُوتُنِي الصَّلاَةُ فِي جَمَاعَةٍ وَأَنَا بِالْبَطْحَاءِ، مَا تَرَى أَنْ أُصَلِّيَ، قَالَ رَكْعَتَيْنِ سُنَّةَ أَبِي الْقَاسِمِ صلى الله عليه وسلم ‏.‏\hadithno{1444}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Musa bin Salamah narrated that he asked Ibn 'Abbas:"I missed the prayer in congregation when I was in Al-Batha; how do you think I should pray?" He said: "Two rak'ahs, the sunnah of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{1445}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ حَارِثَةَ بْنِ وَهْبٍ الْخُزَاعِيِّ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم بِمِنًى آمَنَ مَا كَانَ النَّاسُ وَأَكْثَرَهُ رَكْعَتَيْنِ ‏.‏\hadithno{1445}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Harithah bin Wahab Al-Khuza'i said:"I prayed two rak'ahs with the Prophet (ﷺ) in Mina when the people were more secure and greater in number}}
\hadithdefcmd{nasai}{1446}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، ح وَأَنْبَأَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ أَخْبَرَنِي أَبُو إِسْحَاقَ، عَنْ حَارِثَةَ بْنِ وَهْبٍ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِنًى أَكْثَرَ مَا كَانَ النَّاسُ وَآمَنَهُ رَكْعَتَيْنِ ‏.‏\hadithno{1446}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Harithah bin Wahab said:"The Messenger of Allah (ﷺ) led us in prayer in Mina, two rak'ahs, when the people were greater in number and more secure}}
\hadithdefcmd{nasai}{1447}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ بُكَيْرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي سُلَيْمٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِنًى وَمَعَ أَبِي بَكْرٍ وَعُمَرَ رَكْعَتَيْنِ وَمَعَ عُثْمَانَ رَكْعَتَيْنِ صَدْرًا مِنْ إِمَارَتِهِ ‏.‏\hadithno{1447}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Anas bin Malik that he said:"I prayed two rak'ahs with the Messenger of Allah (ﷺ) in Mina, and with Abu Bakr and 'Umar, and two rak'ahs with 'Uthman at the beginning of his Caliphate}}
\hadithdefcmd{nasai}{1448}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ، عَنِ الأَعْمَشِ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ يَزِيدَ، ح وَأَنْبَأَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، - رضى الله عنه - قَالَ صَلَّيْتُ بِمِنًى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم رَكْعَتَيْنِ ‏.‏\hadithno{1448}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah (ﷺ) said:"I prayed two rak'ahs in Mina with the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{1449}{أَخْبَرَنَا عَلِيُّ بْنُ خَشْرَمٍ، قَالَ حَدَّثَنَا عِيسَى، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ صَلَّى عُثْمَانُ بِمِنًى أَرْبَعًا حَتَّى بَلَغَ ذَلِكَ عَبْدَ اللَّهِ فَقَالَ لَقَدْ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم رَكْعَتَيْنِ ‏.‏\hadithno{1449}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdur-Rahman bin Yazid said:"Uthman prayer four (rak'ahs) in Mina until news of that reached 'Abdullah who said: 'I prayed two rak'ahs with the Messenger of Allah (ﷺ)}}
\hadithdefcmd{nasai}{1450}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ أَنْبَأَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم بِمِنًى رَكْعَتَيْنِ وَمَعَ أَبِي بَكْرٍ - رضى الله عنه - رَكْعَتَيْنِ وَمَعَ عُمَرَ - رضى الله عنه - رَكْعَتَيْنِ ‏.‏\hadithno{1450}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"I prayed two rak'ahs with the Messenger of Allah (ﷺ) in Mina, and two rak'ahs with Abu Bakr, may Allah (SWT) be pleased with him, and two rak'ahs with Umar, may Allah (ﷺ) be pleased with him}}
\hadithdefcmd{nasai}{1451}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِنًى رَكْعَتَيْنِ وَصَلاَّهَا أَبُو بَكْرٍ رَكْعَتَيْنِ وَصَلاَّهَا عُمَرُ رَكْعَتَيْنِ وَصَلاَّهَا عُثْمَانُ صَدْرًا مِنْ خِلاَفَتِهِ ‏.‏\hadithno{1451}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ubaidullah bin 'Abdullah bin Umar narrated that:His father said: "The Messenger of Allah (ﷺ) prayed two rak'ahs in Mina, and Abu Bakr prayed two rak'ahs, and Umar prayed two rak'ahs, and Uthman prayed (two rak'ahs) at the beginning of his Khilafah}}
\hadithdefcmd{nasai}{1452}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ أَنْبَأَنَا يَحْيَى بْنُ أَبِي إِسْحَاقَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْمَدِينَةِ إِلَى مَكَّةَ فَكَانَ يُصَلِّي بِنَا رَكْعَتَيْنِ حَتَّى رَجَعْنَا ‏.‏ قُلْتُ هَلْ أَقَامَ بِمَكَّةَ قَالَ نَعَمْ أَقَمْنَا بِهَا عَشْرًا ‏.‏\hadithno{1452}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Yahya bin Abi Ishaq that :Anas bin Malik said: " We went out with the Messenger of Allah (ﷺ) from Al-Madinah to Makkah and he used to lead us in praying two rak'ahs until we came back." I (Yahya) said: "Did he stay in Makkah?" He (Anas) said: "Yes, we stayed there for ten days}}
\hadithdefcmd{nasai}{1453}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ الأَسْوَدِ الْبَصْرِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ رَبِيعَةَ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَقَامَ بِمَكَّةَ خَمْسَةَ عَشَرَ يُصَلِّي رَكْعَتَيْنِ رَكْعَتَيْنِ ‏.‏\hadithno{1453}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Abbas that:The Messenger of Allah (ﷺ) stayed in Makkah (for fifteen days), praying each prayer with two rak'ahs}}
\hadithdefcmd{nasai}{1454}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ زَنْجَوَيْهِ، عَنْ عَبْدِ الرَّزَّاقِ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي إِسْمَاعِيلُ بْنُ مُحَمَّدِ بْنِ سَعْدٍ، أَنَّ حُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ، أَخْبَرَهُ أَنَّ السَّائِبَ بْنَ يَزِيدَ أَخْبَرَهُ أَنَّهُ، سَمِعَ الْعَلاَءَ بْنَ الْحَضْرَمِيِّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَمْكُثُ الْمُهَاجِرُ بَعْدَ قَضَاءِ نُسُكِهِ ثَلاَثًا ‏"‏ ‏.‏\hadithno{1454}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Al-'Ala bin Al-Hadrami said:"The Messenger of Allah (ﷺ) said: 'The Muhajir may stay for three days after completing his rituals}}
\hadithdefcmd{nasai}{1455}{أَخْبَرَنَا أَبُو عَبْدِ الرَّحْمَنِ، قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، فِي حَدِيثِهِ عَنْ سُفْيَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدٍ، عَنِ السَّائِبِ بْنِ يَزِيدَ، عَنِ الْعَلاَءِ بْنِ الْحَضْرَمِيِّ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَمْكُثُ الْمُهَاجِرُ بِمَكَّةَ بَعْدَ نُسُكِهِ ثَلاَثًا ‏"‏ ‏.‏\hadithno{1455}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Al-'Ala bin Al-Hadrami said:"The Prophet (ﷺ) said: 'The Muhajir may stay for three days after his rituals}}
\hadithdefcmd{nasai}{1456}{أَخْبَرَنِي أَحْمَدُ بْنُ يَحْيَى الصُّوفِيُّ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا الْعَلاَءُ بْنُ زُهَيْرٍ الأَزْدِيُّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الأَسْوَدِ، عَنْ عَائِشَةَ، أَنَّهَا اعْتَمَرَتْ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْمَدِينَةِ إِلَى مَكَّةَ حَتَّى إِذَا قَدِمَتْ مَكَّةَ قَالَتْ يَا رَسُولَ اللَّهِ بِأَبِي أَنْتَ وَأُمِّي قَصَرْتَ وَأَتْمَمْتُ وَأَفْطَرْتَ وَصُمْتُ ‏.‏ قَالَ ‏ "‏ أَحْسَنْتِ يَا عَائِشَةُ ‏"‏ ‏.‏ وَمَا عَابَ عَلَىَّ ‏.‏\hadithno{1456}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that:She performed Umrah with the Messenger of Allah (ﷺ), traveling from Al-Madinah to Makkah. Then, when she came to Makkah, she said: "O Messenger of Allah (ﷺ), may my father and mother be ransomed for you, you shortened you prayers and I offered them in full, you did not fast and I fasted. He said: 'Well done, O 'Aishah!' and he did not criticize me}}
\hadithdefcmd{nasai}{1457}{أَخْبَرَنِي أَحْمَدُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا الْعَلاَءُ بْنُ زُهَيْرٍ، قَالَ حَدَّثَنَا وَبَرَةُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ كَانَ ابْنُ عُمَرَ لاَ يَزِيدُ فِي السَّفَرِ عَلَى رَكْعَتَيْنِ لاَ يُصَلِّي قَبْلَهَا وَلاَ بَعْدَهَا ‏.‏ فَقِيلَ لَهُ مَا هَذَا قَالَ هَكَذَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَصْنَعُ ‏.‏\hadithno{1457}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Wabarah bin Abdur-Rahman said:"Ibn 'Umar did not offer more than two rak'ahs when traveling, and he did not offer any prayer before or after that. It was said to him: 'What is this?' He said: 'This is what I saw the Messenger of Allah (ﷺ) doing}}
\hadithdefcmd{nasai}{1458}{أَخْبَرَنِي نُوحُ بْنُ حَبِيبٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عِيسَى بْنُ حَفْصِ بْنِ عَاصِمٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، كُنْتُ مَعَ ابْنِ عُمَرَ فِي سَفَرٍ فَصَلَّى الظُّهْرَ وَالْعَصْرَ رَكْعَتَيْنِ ثُمَّ انْصَرَفَ إِلَى طِنْفِسَةٍ لَهُ فَرَأَى قَوْمًا يُسَبِّحُونَ قَالَ مَا يَصْنَعُ هَؤُلاَءِ قُلْتُ يُسَبِّحُونَ ‏.‏ قَالَ لَوْ كُنْتُ مُصَلِّيًا قَبْلَهَا أَوْ بَعْدَهَا لأَتْمَمْتُهَا صَحِبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَكَانَ لاَ يَزِيدُ فِي السَّفَرِ عَلَى الرَّكْعَتَيْنِ وَأَبَا بَكْرٍ حَتَّى قُبِضَ وَعُمَرَ وَعُثْمَانَ - رضى الله عنهم - كَذَلِكَ ‏.‏\hadithno{1458}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Eisa bin Hafs bin 'Asim said:"My father told me: 'I was with Ibn Umar on a journey, and he prayed Zuhr and 'Asr with two rak'ahs each, then he went and sat on his carpet. He saw some people offering voluntary prayers and said: What are these people doing? I said: They are offering voluntary prayers. He said: If I had wanted to pray before and after (the obligatory prayer) I would have offered it in full. I accompanied the Messenger of Allah (ﷺ) and he did not pray more than two rak'ahs when traveling, and Abu Bakr (did likewise) until he died, as did 'Umar and 'Uthman, may Allah (SWT) be pleased with them all}}
