% Auto-generated chapter 49 for muslim
% Hadiths in this chapter: 15

\hadithdefcmd{muslim}{6937}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا الْمُعْتَمِرُ، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ أَخْبَرَنَا جَرِيرٌ، كُلُّهُمْ عَنْ سُلَيْمَانَ التَّيْمِيِّ، ح وَحَدَّثَنَا أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ - وَاللَّفْظُ لَهُ - حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قُمْتُ عَلَى بَابِ الْجَنَّةِ فَإِذَا عَامَّةُ مَنْ دَخَلَهَا الْمَسَاكِينُ وَإِذَا أَصْحَابُ الْجَدِّ مَحْبُوسُونَ إِلاَّ أَصْحَابَ النَّارِ فَقَدْ أُمِرَ بِهِمْ إِلَى النَّارِ وَقُمْتُ عَلَى بَابِ النَّارِ فَإِذَا عَامَّةُ مَنْ دَخَلَهَا النِّسَاءُ ‏"‏ ‏.‏\hadithno{6937}\hadithtrans{Usama b. Zaid reported that Allah's Messenger (way peace be upon him) said:I stood at the door of Paradise and I found that the overwhelming majority of those who entered therein was that of poor persons and the wealthy persons were detained to get into that. The denizens of Hell were commanded to get into Hell, and I stood upon the door of Fire and the majority amongst them who entered there was that of women}}
\hadithdefcmd{muslim}{6938}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ أَبِي رَجَاءٍ، الْعُطَارِدِيِّ قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ قَالَ مُحَمَّدٌ صلى الله عليه وسلم ‏ "‏ اطَّلَعْتُ فِي الْجَنَّةِ فَرَأَيْتُ أَكْثَرَ أَهْلِهَا الْفُقَرَاءَ وَاطَّلَعْتُ فِي النَّارِ فَرَأَيْتُ أَكْثَرَ أَهْلِهَا النِّسَاءَ ‏"‏ ‏.‏\hadithno{6938}\hadithtrans{Ibn Abbas reported that Allah's Messenger (ﷺ) said:I had a chance to look into the Paradise and I found that majority of the people was poor and I looked into the Fire and there I found the majority constituted by women}}
\hadithdefcmd{muslim}{6939}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الثَّقَفِيُّ، أَخْبَرَنَا أَيُّوبُ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6939}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Abbas through another chain of transmitters}}
\hadithdefcmd{muslim}{6940}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا أَبُو الأَشْهَبِ، حَدَّثَنَا أَبُو رَجَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اطَّلَعَ فِي النَّارِ ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ أَيُّوبَ ‏.‏\hadithno{6940}\hadithtrans{Ibn 'Abbas reported that Allah's Messenger (ﷺ) stated like this:He looked into the Fire of Hell. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{6941}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، سَمِعَ أَبَا رَجَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ مِثْلَهُ ‏.‏\hadithno{6941}\hadithtrans{This hadith is narrated likewise through another chain of transmitters}}
\hadithdefcmd{muslim}{6942}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، قَالَ كَانَ لِمُطَرِّفِ بْنِ عَبْدِ اللَّهِ امْرَأَتَانِ فَجَاءَ مِنْ عِنْدِ إِحْدَاهُمَا فَقَالَتِ الأُخْرَى جِئْتَ مِنْ عِنْدِ فُلاَنَةَ فَقَالَ جِئْتُ مِنْ عِنْدِ عِمْرَانَ بْنِ حُصَيْنٍ فَحَدَّثَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَقَلَّ سَاكِنِي الْجَنَّةِ النِّسَاءُ ‏"‏ ‏.‏\hadithno{6942}\hadithtrans{Imran b. Husain reported that Allah's Messenger (ﷺ) said:Amongst the inmates of Paradise the women would form a minority}}
\hadithdefcmd{muslim}{6943}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ بْنِ عَبْدِ الْحَمِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ مُطَرِّفًا، يُحَدِّثُ أَنَّهُ كَانَتْ لَهُ امْرَأَتَانِ بِمَعْنَى حَدِيثِ مُعَاذٍ ‏.‏\hadithno{6943}\hadithtrans{This hadith has been narrated on the authority of Mutarrif through another chain of transmitters}}
\hadithdefcmd{muslim}{6944}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْكَرِيمِ أَبُو زُرْعَةَ، حَدَّثَنَا ابْنُ بُكَيْرٍ، حَدَّثَنِي يَعْقُوبُ بْنُ، عَبْدِ الرَّحْمَنِ عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ كَانَ مِنْ دُعَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ زَوَالِ نِعْمَتِكَ وَتَحَوُّلِ عَافِيَتِكَ وَفُجَاءَةِ نِقْمَتِكَ وَجَمِيعِ سَخَطِكَ ‏"‏ ‏.‏\hadithno{6944}\hadithtrans{Abdullah b. Umar reported that Allah's Messenger (ﷺ) supplicated in these words:" O Allah, I seek refuge in Thee from the withdrawal of Thine blessing and the change of Thine protection (from me) and from the sudden wrath of Thine, and from every displeasure of Thine}}
\hadithdefcmd{muslim}{6945}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا سُفْيَانُ، وَمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا تَرَكْتُ بَعْدِي فِتْنَةً هِيَ أَضَرُّ عَلَى الرِّجَالِ مِنَ النِّسَاءِ ‏"‏ ‏.‏\hadithno{6945}\hadithtrans{Usama b. Zaid reported Allah's Messenger (ﷺ) as saying:I have not left after me any (chance) of turmoil more injurious to men than the harm done to the men because of women}}
\hadithdefcmd{muslim}{6946}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، وَسُوَيْدُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، جَمِيعًا عَنِ الْمُعْتَمِرِ، قَالَ ابْنُ مُعَاذٍ حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ قَالَ أَبِي حَدَّثَنَا أَبُو عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدِ بْنِ حَارِثَةَ، وَسَعِيدِ بْنِ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ، أَنَّهُمَا حَدَّثَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَا تَرَكْتُ بَعْدِي فِي النَّاسِ فِتْنَةً أَضَرَّ عَلَى الرِّجَالِ مِنَ النِّسَاءِ ‏"‏ ‏.‏\hadithno{6946}\hadithtrans{Usama b. Zaid b. Harith and Sa'id b. Zaid b. 'Amr b. Naufal both reported Allah's Messenger (ﷺ) as saying:I have not left after me turmoil for the people but the harm done to men by women}}
\hadithdefcmd{muslim}{6947}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، كُلُّهُمْ عَنْ سُلَيْمَانَ التَّيْمِيِّ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6947}\hadithtrans{This hadith has been narrated on the authority of Sulaiman Taimi with the same chain of transmitters}}
\hadithdefcmd{muslim}{6948}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي مَسْلَمَةَ، قَالَ سَمِعْتُ أَبَا نَضْرَةَ، يُحَدِّثُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الدُّنْيَا حُلْوَةٌ خَضِرَةٌ وَإِنَّ اللَّهَ مُسْتَخْلِفُكُمْ فِيهَا فَيَنْظُرُ كَيْفَ تَعْمَلُونَ فَاتَّقُوا الدُّنْيَا وَاتَّقُوا النِّسَاءَ فَإِنَّ أَوَّلَ فِتْنَةِ بَنِي إِسْرَائِيلَ كَانَتْ فِي النِّسَاءِ ‏"‏ ‏.‏ وَفِي حَدِيثِ ابْنِ بَشَّارٍ ‏"‏ لِيَنْظُرَ كَيْفَ تَعْمَلُونَ ‏"‏ ‏.‏\hadithno{6948}\hadithtrans{Abu Sa'id Khudri reported that Allah's Messenger (ﷺ) said:The world is sweet and green (alluring) and verily Allah is going to install you as vicegerent in it in order to see how you act. So avoid the allurement of women: verily, the first trial for the people of Isra'il was caused by women. And in the hadith transmitted on the authority of Ibn Bashshar the words are:" So that He should see how you act}}
\hadithdefcmd{muslim}{6949}{حَدَّثَنِي مُحَمَّدُ بْنُ إِسْحَاقَ الْمُسَيَّبِيُّ، حَدَّثَنِي أَنَسٌ، - يَعْنِي ابْنَ عِيَاضٍ أَبَا ضَمْرَةَ - عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ بَيْنَمَا ثَلاَثَةُ نَفَرٍ يَتَمَشَّوْنَ أَخَذَهُمُ الْمَطَرُ فَأَوَوْا إِلَى غَارٍ فِي جَبَلٍ فَانْحَطَّتْ عَلَى فَمِ غَارِهِمْ صَخْرَةٌ مِنَ الْجَبَلِ فَانْطَبَقَتْ عَلَيْهِمْ فَقَالَ بَعْضُهُمْ لِبَعْضٍ انْظُرُوا أَعْمَالاً عَمِلْتُمُوهَا صَالِحَةً لِلَّهِ فَادْعُوا اللَّهَ تَعَالَى بِهَا لَعَلَّ اللَّهَ يَفْرُجُهَا عَنْكُمْ ‏.‏ فَقَالَ أَحَدُهُمُ اللَّهُمَّ إِنَّهُ كَانَ لِي وَالِدَانِ شَيْخَانِ كَبِيرَانِ وَامْرَأَتِي وَلِيَ صِبْيَةٌ صِغَارٌ أَرْعَى عَلَيْهِمْ فَإِذَا أَرَحْتُ عَلَيْهِمْ حَلَبْتُ فَبَدَأْتُ بِوَالِدَىَّ فَسَقَيْتُهُمَا قَبْلَ بَنِيَّ وَأَنَّهُ نَأَى بِي ذَاتَ يَوْمٍ الشَّجَرُ فَلَمْ آتِ حَتَّى أَمْسَيْتُ فَوَجَدْتُهُمَا قَدْ نَامَا فَحَلَبْتُ كَمَا كُنْتُ أَحْلُبُ فَجِئْتُ بِالْحِلاَبِ فَقُمْتُ عِنْدَ رُءُوسِهِمَا أَكْرَهُ أَنْ أُوقِظَهُمَا مِنْ نَوْمِهِمَا وَأَكْرَهُ أَنْ أَسْقِيَ الصِّبْيَةَ قَبْلَهُمَا وَالصِّبْيَةُ يَتَضَاغَوْنَ عِنْدَ قَدَمَىَّ فَلَمْ يَزَلْ ذَلِكَ دَأْبِي وَدَأْبَهُمْ حَتَّى طَلَعَ الْفَجْرُ فَإِنْ كُنْتَ تَعْلَمُ أَنِّي فَعَلْتُ ذَلِكَ ابْتِغَاءَ وَجْهِكَ فَافْرُجْ لَنَا مِنْهَا فُرْجَةً نَرَى مِنْهَا السَّمَاءَ ‏.‏ فَفَرَجَ اللَّهُ مِنْهَا فُرْجَةً فَرَأَوْا مِنْهَا السَّمَاءَ ‏.‏ وَقَالَ الآخَرُ اللَّهُمَّ إِنَّهُ كَانَتْ لِيَ ابْنَةُ عَمٍّ أَحْبَبْتُهَا كَأَشَدِّ مَا يُحِبُّ الرِّجَالُ النِّسَاءَ وَطَلَبْتُ إِلَيْهَا نَفْسَهَا فَأَبَتْ حَتَّى آتِيَهَا بِمِائَةِ دِينَارٍ فَتَعِبْتُ حَتَّى جَمَعْتُ مِائَةَ دِينَارٍ فَجِئْتُهَا بِهَا فَلَمَّا وَقَعْتُ بَيْنَ رِجْلَيْهَا قَالَتْ يَا عَبْدَ اللَّهِ اتَّقِ اللَّهَ وَلاَ تَفْتَحِ الْخَاتَمَ إِلاَّ بِحَقِّهِ ‏.‏ فَقُمْتُ عَنْهَا فَإِنْ كُنْتَ تَعْلَمُ أَنِّي فَعَلْتُ ذَلِكَ ابْتِغَاءَ وَجْهِكَ فَافْرُجْ لَنَا مِنْهَا فُرْجَةً ‏.‏ فَفَرَجَ لَهُمْ ‏.‏ وَقَالَ الآخَرُ اللَّهُمَّ إِنِّي كُنْتُ اسْتَأْجَرْتُ أَجِيرًا بِفَرَقِ أَرُزٍّ فَلَمَّا قَضَى عَمَلَهُ قَالَ أَعْطِنِي حَقِّي ‏.‏ فَعَرَضْتُ عَلَيْهِ فَرَقَهُ فَرَغِبَ عَنْهُ فَلَمْ أَزَلْ أَزْرَعُهُ حَتَّى جَمَعْتُ مِنْهُ بَقَرًا وَرِعَاءَهَا فَجَاءَنِي فَقَالَ اتَّقِ اللَّهَ وَلاَ تَظْلِمْنِي حَقِّي ‏.‏ قُلْتُ اذْهَبْ إِلَى تِلْكَ الْبَقَرِ وَرِعَائِهَا فَخُذْهَا ‏.‏ فَقَالَ اتَّقِ اللَّهَ وَلاَ تَسْتَهْزِئْ بِي ‏.‏ فَقُلْتُ إِنِّي لاَ أَسْتَهْزِئُ بِكَ خُذْ ذَلِكَ الْبَقَرَ وَرِعَاءَهَا ‏.‏ فَأَخَذَهُ فَذَهَبَ بِهِ فَإِنْ كُنْتَ تَعْلَمُ أَنِّي فَعَلْتُ ذَلِكَ ابْتِغَاءَ وَجْهِكَ فَافْرُجْ لَنَا مَا بَقِيَ ‏.‏ فَفَرَجَ اللَّهُ مَا بَقِيَ ‏.‏\hadithno{6949}\hadithtrans{Abdullah b. 'Umar reported that Allah's Messenger (ﷺ) said:Three persons set out on a journey. They were overtaken by rain and they had to find protection in a mountain cave where at its mouth there fell a rock of that mountain and thus blocked them altogether. One of them said to the others: Look to your good deeds that you performed for the sake of Allah and then supplicate Allah, the Exalted, that He might rescue you (from this trouble). One of them said: 0 Allah, I had my parents who were old and my wife and my small children also. I tended the flock and when I came back to them in the evening, I milked them (the sheep, goats, cows, etc.) and first served that milk to my parents. One day I was obliged to go out to a distant place in search of fodder and I could not come back before evening and found them (the parents) asleep. I milked the animals as I used to milk and brought milk to them and stood by their heads avoiding to disturb them from sleep and I did not deem it advisable to serve milk to my children before serving them. My children wept near my feet. I remained there in that very state and my parents too until it was morning. And (0 Allah) if Thou art aware that I did this in order to seek Thine pleasure, grant us riddance from this trouble. (The rock slipped a bit) that they could see the sky. The second one said: 0 Allah, I had a female cousin whom I loved more than the men love the women. I wanted to have sexual intercourse with her; she refused but on the condition of getting one hundred dinirs. It was with very great difficulty that I could collect one hundred dinirs and then paid them to her and when I was going to have a sexual intercourse with her, that she said: Servant of Allah, fear Allah and do not break the seal (of chastity) but by lawful means. I got up. 0 Allah, if Thou art aware that I did this in order to seek Thine pleasure, rid us from this trouble. The situation was somewhat eased for them. The third one said: Allah, I employed a workman for a measure of rice. After he had finished his work I gave him his dues (in the form of) a measure of rice, but he did not accept them. I used these rice as seeds, and that gave a bumper crop and I became rich enough to have cows and flocks (in my possession). He came to me and said: Fear Allah, and commit no crueltv upon me in regard to my dues. I said to him: Takeaway this flock of cows and sheep. He said: Fear Allah and do not make a fun of me. I said: I am not making a fun of you. You take the cows and the flocks. So he took them. 0 Allah, if Thou art aware that I did it for Thine pleasure, case the situation for us. And Allah relieved them from the rest of the trouble}}
\hadithdefcmd{muslim}{6950}{وَحَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ، جُرَيْجٍ أَخْبَرَنِي مُوسَى بْنُ عُقْبَةَ، ح وَحَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنِي أَبُو كُرَيْبٍ، وَمُحَمَّدُ بْنُ طَرِيفٍ الْبَجَلِيُّ، قَالاَ حَدَّثَنَا ابْنُ فُضَيْلٍ، حَدَّثَنَا أَبِي وَرَقَبَةُ بْنُ مَسْقَلَةَ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَحَسَنٌ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالُوا حَدَّثَنَا يَعْقُوبُ، - يَعْنُونَ ابْنَ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحِ بْنِ كَيْسَانَ، كُلُّهُمْ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ أَبِي ضَمْرَةَ عَنْ مُوسَى بْنِ عُقْبَةَ وَزَادُوا فِي حَدِيثِهِمْ ‏"‏ وَخَرَجُوا يَمْشُونَ ‏"‏ ‏.‏ وَفِي حَدِيثِ صَالِحٍ ‏"‏ يَتَمَاشَوْنَ ‏"‏ ‏.‏ إِلاَّ عُبَيْدَ اللَّهِ فَإِنَّ فِي حَدِيثِهِ ‏"‏ وَخَرَجُوا ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ بَعْدَهَا شَيْئًا ‏.‏\hadithno{6950}\hadithtrans{This hadith has been transmitted on the authority of Musa b. 'Uqba but with a slight variation of wording}}
\hadithdefcmd{muslim}{6951}{حَدَّثَنِي مُحَمَّدُ بْنُ سَهْلٍ التَّمِيمِيُّ، وَعَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ بَهْرَامَ، وَأَبُو بَكْرِ بْنُ إِسْحَاقَ قَالَ ابْنُ سَهْلٍ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ انْطَلَقَ ثَلاَثَةُ رَهْطٍ مِمَّنْ كَانَ قَبْلَكُمْ حَتَّى آوَاهُمُ الْمَبِيتُ إِلَى غَارٍ ‏"‏ ‏.‏ وَاقْتَصَّ الْحَدِيثَ بِمَعْنَى حَدِيثِ نَافِعٍ عَنِ ابْنِ عُمَرَ غَيْرَ أَنَّهُ قَالَ قَالَ رَجُلٌ مِنْهُمُ ‏"‏ اللَّهُمَّ كَانَ لِي أَبَوَانِ شَيْخَانِ كَبِيرَانِ فَكُنْتُ لاَ أَغْبُقُ قَبْلَهُمَا أَهْلاً وَلاَ مَالاً ‏"‏ ‏.‏ وَقَالَ ‏"‏ فَامْتَنَعَتْ مِنِّي حَتَّى أَلَمَّتْ بِهَا سَنَةٌ مِنَ السِّنِينَ فَجَاءَتْنِي فَأَعْطَيْتُهَا عِشْرِينَ وَمِائَةَ دِينَارٍ ‏"‏ ‏.‏ وَقَالَ ‏"‏ فَثَمَّرْتُ أَجْرَهُ حَتَّى كَثُرَتْ مِنْهُ الأَمْوَالُ فَارْتَعَجَتْ ‏"‏ ‏.‏ وَقَالَ ‏"‏ فَخَرَجُوا مِنَ الْغَارِ يَمْشُونَ\hadithno{6951}\hadithtrans{Abdullah b 'Umar reported:I heard Allah's Messenger (ﷺ) as saying: Three persons belonging to the earlier Ummahs set out on a journey until they had to spend a night in a cave. The rest of the hadith is the same and the additional words are:" A person amongst them said: O Allah, I had my aged parents and I served them milk before I (served that) to my wife, children and my servants." And in case of the second one, the words are: "She avoided me until she was hard pressed because of famine and she came to me and I gave her one hundred and twenty dinars." And in case of the third one (the words are):" I invested his wages, and it brought profit and, as a result thereof, the merchandise increased and there was an abundance of goods." And he (the narrator said) that they got out of the cave and began to walk}}
