% Auto-generated chapter 33 for abudawud
% Hadiths in this chapter: 11

\hadithdefcmd{abudawud}{4009}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنْ أَبِي عُذْرَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ دُخُولِ الْحَمَّامَاتِ ثُمَّ رَخَّصَ لِلرِّجَالِ أَنْ يَدْخُلُوهَا فِي الْمَيَازِرِ ‏.‏\hadithno{4009}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) forbade to enter the hot baths. He then permitted men to enter them in lower garments}}
\hadithdefcmd{abudawud}{4010}{حَدَّثَنَا مُحَمَّدُ بْنُ قُدَامَةَ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، - جَمِيعًا - عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، - قَالَ ابْنُ الْمُثَنَّى - عَنْ أَبِي الْمَلِيحِ، قَالَ دَخَلَ نِسْوَةٌ مِنْ أَهْلِ الشَّامِ عَلَى عَائِشَةَ - رضى الله عنها - فَقَالَتْ مِمَّنْ أَنْتُنَّ قُلْنَ مِنْ أَهْلِ الشَّامِ ‏.‏ قَالَتْ لَعَلَّكُنَّ مِنَ الْكُورَةِ الَّتِي تَدْخُلُ نِسَاؤُهَا الْحَمَّامَاتِ قُلْنَ نَعَمْ ‏.‏ قَالَتْ أَمَا إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنِ امْرَأَةٍ تَخْلَعُ ثِيَابَهَا فِي غَيْرِ بَيْتِهَا إِلاَّ هَتَكَتْ مَا بَيْنَهَا وَبَيْنَ اللَّهِ تَعَالَى ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا حَدِيثُ جَرِيرٍ وَهُوَ أَتَمُّ وَلَمْ يَذْكُرْ جَرِيرٌ أَبَا الْمَلِيحِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4010}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: AbulMalih said: Some women of Syria came to Aisha. She asked them: From whom are you? They replied: From the people of Syria. She said: Perhaps you belong to the place where women enter hot baths (for washing ). The said: Yes. She said: I heard the Messenger of Allah (ﷺ) say: If a woman puts off her clothes in a place other than her house, she tears the veil between her and Allah, the Exalted. Abu Dawud said: This is the tradition narrated by Jarir, and it is more perfect. Jarir did not mention Abu al-Malih. He said (on the authority of 'A'ishah) that the Messenger of Allah (ﷺ) said}}
\hadithdefcmd{abudawud}{4011}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زِيَادِ بْنِ أَنْعَمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ رَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّهَا سَتُفْتَحُ لَكُمْ أَرْضُ الْعَجَمِ وَسَتَجِدُونَ فِيهَا بُيُوتًا يُقَالُ لَهَا الْحَمَّامَاتُ فَلاَ يَدْخُلَنَّهَا الرِّجَالُ إِلاَّ بِالأُزُرِ وَامْنَعُوهَا النِّسَاءَ إِلاَّ مَرِيضَةً أَوْ نُفَسَاءَ ‏"‏ ‏.‏\hadithno{4011}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: After some time the lands of the non-Arabs will be conquered for you, and there you will find houses called hammamat (hot baths). so men should not enter them (to wash) except in lower garments, and forbid the women to enter them except a sick or one who is in a child-bed}}
\hadithdefcmd{abudawud}{4012}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ نُفَيْلٍ، حَدَّثَنَا زُهَيْرٌ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ الْعَرْزَمِيِّ، عَنْ عَطَاءٍ، عَنْ يَعْلَى، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً يَغْتَسِلُ بِالْبَرَازِ بِلاَ إِزَارٍ فَصَعِدَ الْمِنْبَرَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ حَيِيٌّ سِتِّيرٌ يُحِبُّ الْحَيَاءَ وَالسَّتْرَ فَإِذَا اغْتَسَلَ أَحَدُكُمْ فَلْيَسْتَتِرْ ‏"‏ ‏.‏\hadithno{4012}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ya'la: The Messenger of Allah (ﷺ) saw a man washing in a public place without a lower garment. So he mounted the pulpit, praised and extolled Allah and said: Allah is characterised by modesty and concealment. So when any of you washes, he should conceal himself}}
\hadithdefcmd{abudawud}{4013}{حَدَّثَنَا مُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ، حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ يَعْلَى، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏.‏ قَالَ أَبُو دَاوُدَ الأَوَّلُ أَتَمُّ ‏.‏\hadithno{4013}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Ya'la from the Prophet (ﷺ) through a different chain of narrators. Abu Dawud said:The former is more perfect}}
\hadithdefcmd{abudawud}{4014}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، عَنْ زُرْعَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ جَرْهَدٍ، عَنْ أَبِيهِ، - قَالَ كَانَ جَرْهَدٌ هَذَا مِنْ أَصْحَابِ الصُّفَّةِ - قَالَ جَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَنَا وَفَخِذِي مُنْكَشِفَةٌ فَقَالَ ‏ "‏ أَمَا عَلِمْتَ أَنَّ الْفَخِذَ عَوْرَةٌ ‏"‏ ‏.‏\hadithno{4014}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jarhad: The Messenger of Allah (ﷺ) sat with us and my thigh was uncovered. He said: Do you not know that thigh is a private part ?}}
\hadithdefcmd{abudawud}{4015}{حَدَّثَنَا عَلِيُّ بْنُ سَهْلٍ الرَّمْلِيُّ، حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أُخْبِرْتُ عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَكْشِفْ فَخِذَكَ وَلاَ تَنْظُرْ إِلَى فَخِذِ حَىٍّ وَلاَ مَيِّتٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا الْحَدِيثُ فِيهِ نَكَارَةٌ ‏.‏\hadithno{4015}\hadithgrade{Al-Albani: Very Daif; Muhammad Muhyi Al-Din Abdul Hamid: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The Prophet (ﷺ) said: Do not uncover you thigh, and do not look at the thigh of the living and the dead. Abu Dawud said: This tradition disagrees with the generally reported traditions (nakarah)}}
\hadithdefcmd{abudawud}{4016}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الأُمَوِيُّ، عَنْ عُثْمَانَ بْنِ حَكِيمٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلٍ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ حَمَلْتُ حَجَرًا ثَقِيلاً فَبَيْنَا أَمْشِي فَسَقَطَ عَنِّي ثَوْبِي فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خُذْ عَلَيْكَ ثَوْبَكَ وَلاَ تَمْشُوا عُرَاةً ‏"‏ ‏.‏\hadithno{4016}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (341)}\hadithtrans{Narrated Al-Miswar b. Makhramah:I lifted a heavy stone. While I was walking my garment fell down. The Messenger of Allah (ﷺ) said to me: Take you garment upon you, and do not walk naked}}
\hadithdefcmd{abudawud}{4017}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، نَحْوَهُ عَنْ بَهْزِ بْنِ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ عَوْرَاتُنَا مَا نَأْتِي مِنْهَا وَمَا نَذَرُ قَالَ ‏"‏ احْفَظْ عَوْرَتَكَ إِلاَّ مِنْ زَوْجَتِكَ أَوْ مَا مَلَكَتْ يَمِينُكَ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِذَا كَانَ الْقَوْمُ بَعْضُهُمْ فِي بَعْضٍ قَالَ ‏"‏ إِنِ اسْتَطَعْتَ أَنْ لاَ يَرَيَنَّهَا أَحَدٌ فَلاَ يَرَيَنَّهَا ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِذَا كَانَ أَحَدُنَا خَالِيًا قَالَ ‏"‏ اللَّهُ أَحَقُّ أَنْ يُسْتَحْيَا مِنْهُ مِنَ النَّاسِ ‏"‏ ‏.‏\hadithno{4017}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bahz b. Hakim said that his father told on the authority of his grandfather:I said: Messenger of Allah, from whom should we conceal our private parts and to whom can we show? He replied: conceal your private parts except from your wife and from whom your right hands possess (slave-girls). I then asked: Messenger of Allah, (what should we do), if the people are assembled together? He replied: If it is within your power that no one looks at it, then no one should look at it. I then asked: Messenger of Allah if one of us is alone, (what should he do)? He replied: Allah is more entitled than people that bashfulness should be shown to him}}
\hadithdefcmd{abudawud}{4018}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَنْظُرُ الرَّجُلُ إِلَى عُرْيَةِ الرَّجُلِ وَلاَ الْمَرْأَةُ إِلَى عُرْيَةِ الْمَرْأَةِ وَلاَ يُفْضِي الرَّجُلُ إِلَى الرَّجُلِ فِي ثَوْبٍ وَاحِدٍ وَلاَ تُفْضِي الْمَرْأَةُ إِلَى الْمَرْأَةِ فِي ثَوْبٍ ‏"‏ ‏.‏\hadithno{4018}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (338)}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) said: A man should not look at the private parts of another man, and a woman should not look at the private parts of another woman. A man should not lie with another man without wearing lower garment under one cover; and a woman should not be lie with another woman without wearing lower garment under one cover}}
\hadithdefcmd{abudawud}{4019}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا ابْنُ عُلَيَّةَ، عَنِ الْجُرَيْرِيِّ، ح وَحَدَّثَنَا مُؤَمَّلُ بْنُ هِشَامٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ رَجُلٍ، مِنَ الطُّفَاوَةِ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُفْضِيَنَّ رَجُلٌ إِلَى رَجُلٍ وَلاَ امْرَأَةٌ إِلَى امْرَأَةٍ إِلاَّ وَلَدًا أَوْ وَالِدًا ‏"‏ ‏.‏ قَالَ وَذَكَرَ الثَّالِثَةَ فَنَسِيتُهَا ‏.‏\hadithno{4019}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: A man should not lie with another man and a woman should not lie with another woman without covering their private parts except a child or a father. He also mentioned a third thing which I forgot}}
