% Auto-generated chapter 95 for bukhari
% Hadiths in this chapter: 21

\hadithdefcmd{bukhari}{7246}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، حَدَّثَنَا مَالِكٌ، قَالَ أَتَيْنَا النَّبِيَّ صلى الله عليه وسلم وَنَحْنُ شَبَبَةٌ مُتَقَارِبُونَ، فَأَقَمْنَا عِنْدَهُ عِشْرِينَ لَيْلَةً، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَفِيقًا، فَلَمَّا ظَنَّ أَنَّا قَدِ اشْتَهَيْنَا أَهْلَنَا أَوْ قَدِ اشْتَقْنَا سَأَلَنَا عَمَّنْ تَرَكْنَا بَعْدَنَا فَأَخْبَرْنَاهُ قَالَ ‏ "‏ ارْجِعُوا إِلَى أَهْلِيكُمْ، فَأَقِيمُوا فِيهِمْ، وَعَلِّمُوهُمْ، وَمُرُوهُمْ ـ وَذَكَرَ أَشْيَاءَ أَحْفَظُهَا أَوْ لاَ أَحْفَظُهَا ـ وَصَلُّوا كَمَا رَأَيْتُمُونِي أُصَلِّي، فَإِذَا حَضَرَتِ الصَّلاَةُ فَلْيُؤَذِّنْ لَكُمْ أَحَدُكُمْ، وَلْيَؤُمَّكُمْ أَكْبَرُكُمْ ‏"‏‏.‏\hadithno{7246}\hadithtrans{Narrated Malik:We came to the Prophet (ﷺ) and we were young men nearly of equal ages and we stayed with him for twenty nights. Allah's Messenger (ﷺ) was a very kind man and when he realized our longing for our families, he asked us about those whom we had left behind. When we informed him, he said, "Go back to your families and stay with them and teach them (religion) and order them (to do good deeds). The Prophet (ﷺ) mentioned things some of which I remembered and some I did not. Then he said, "Pray as you have seen me praying, and when it is the time of prayer, one of you should pronounce the call (Adhan) for the prayer and the eldest of you should lead the prayer}}
\hadithdefcmd{bukhari}{7247}{حَدَّثَنَا مُسَدَّدٌ، عَنْ يَحْيَى، عَنِ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ، عَنِ ابْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَمْنَعَنَّ أَحَدَكُمْ أَذَانُ بِلاَلٍ مِنْ سَحُورِهِ، فَإِنَّهُ يُؤَذِّنُ ـ أَوْ قَالَ يُنَادِي ـ لِيَرْجِعَ قَائِمَكُمْ، وَيُنَبِّهَ نَائِمَكُمْ، وَلَيْسَ الْفَجْرُ أَنْ يَقُولَ هَكَذَا ـ وَجَمَعَ يَحْيَى كَفَّيْهِ ـ حَتَّى يَقُولَ هَكَذَا ‏"‏‏.‏ وَمَدَّ يَحْيَى إِصْبَعَيْهِ السَّبَّابَتَيْنِ‏.‏\hadithno{7247}\hadithtrans{Narrated Ibn Mas`ud:Allah's Messenger (ﷺ) said, "The (call for prayer) Adhan of Bilal should not stop anyone of you from taking his Suhur for he pronounces the Adhan in order that whoever among you is praying the night prayer, may return (to eat his Suhur) and whoever among you is sleeping, may get up, for it is not yet dawn (when it is like this)." (Yahya, the sub-narrator stretched his two index fingers side ways)}}
\hadithdefcmd{bukhari}{7248}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ بِلاَلاً يُنَادِي بِلَيْلٍ، فَكُلُوا وَاشْرَبُوا حَتَّى يُنَادِيَ ابْنُ أُمِّ مَكْتُومٍ ‏"‏‏.‏\hadithno{7248}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "Bilal pronounces the Adhan at night so that you may eat and drink till Ibn Um Maktum pronounces the Adhan (for the Fajr prayer)}}
\hadithdefcmd{bukhari}{7249}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ صَلَّى بِنَا النَّبِيُّ صلى الله عليه وسلم الظُّهْرَ خَمْسًا فَقِيلَ أَزِيدَ فِي الصَّلاَةِ قَالَ ‏ "‏ وَمَا ذَاكَ ‏"‏‏.‏ قَالُوا صَلَّيْتَ خَمْسًا‏.‏ فَسَجَدَ سَجْدَتَيْنِ بَعْدَ مَا سَلَّمَ‏.‏\hadithno{7249}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) led us in Zuhr prayer and prayer five rak`at. Somebody asked him whether the prayer had been increased." He (the Prophet (ﷺ) ) said, "And what is that?" They (the people) replied, "You have prayed five rak`at." Then the Prophet (ﷺ) offered two prostrations (of Sahu) after he had finished his prayer with the Taslim}}
\hadithdefcmd{bukhari}{7250}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم انْصَرَفَ مِنِ اثْنَتَيْنِ فَقَالَ لَهُ ذُو الْيَدَيْنِ أَقَصُرَتِ الصَّلاَةُ يَا رَسُولَ اللَّهِ، أَمْ نَسِيتَ فَقَالَ ‏ "‏ أَصَدَقَ ذُو الْيَدَيْنِ ‏"‏‏.‏ فَقَالَ النَّاسُ نَعَمْ‏.‏ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى رَكْعَتَيْنِ أُخْرَيَيْنِ، ثُمَّ سَلَّمَ، ثُمَّ كَبَّرَ، ثُمَّ سَجَدَ مِثْلَ سُجُودِهِ أَوْ أَطْوَلَ، ثُمَّ رَفَعَ، ثُمَّ كَبَّرَ، فَسَجَدَ مِثْلَ سُجُودِهِ، ثُمَّ رَفَعَ‏.‏\hadithno{7250}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) finished his prayer after offerings two rak`at only. Dhul-Yaddain asked him whether the prayer had been reduced, or you had forgotten?" The Prophet (ﷺ) said, "Is Dhul-Yaddain speaking the truth?" The people said, "Yes." Then Allah's Messenger (ﷺ) stood up and performed another two rak`at and then finished prayer with Taslim, and then said the Takbir and performed a prostration similar to or longer than his ordinary prostrations; then he raised his head, said Takbir and prostrated and then raised his head (Sahu prostrations)}}
\hadithdefcmd{bukhari}{7251}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ بَيْنَا النَّاسُ بِقُبَاءٍ فِي صَلاَةِ الصُّبْحِ إِذْ جَاءَهُمْ آتٍ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أُنْزِلَ عَلَيْهِ اللَّيْلَةَ قُرْآنٌ، وَقَدْ أُمِرَ أَنْ يَسْتَقْبِلَ الْكَعْبَةَ فَاسْتَقْبِلُوهَا‏.‏ وَكَانَتْ وُجُوهُهُمْ إِلَى الشَّأْمِ فَاسْتَدَارُوا إِلَى الْكَعْبَةِ‏.‏\hadithno{7251}\hadithtrans{Narrated `Abdullah bin `Umar:While the people were at Quba offering the morning prayer, suddenly a person came to them saying, "Tonight Divine Inspiration has been revealed to Allah's Messenger (ﷺ) and he has been ordered to face the Ka`ba (in prayers): therefore you people should face it." There faces were towards Sham, so they turned their faces towards the Ka`ba (at Mecca)}}
\hadithdefcmd{bukhari}{7252}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ صَلَّى نَحْوَ بَيْتِ الْمَقْدِسِ سِتَّةَ عَشَرَ، أَوْ سَبْعَةَ عَشَرَ شَهْرًا، وَكَانَ يُحِبُّ أَنْ يُوَجَّهَ إِلَى الْكَعْبَةِ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏قَدْ نَرَى تَقَلُّبَ وَجْهِكَ فِي السَّمَاءِ فَلَنُوَلِّيَنَّكَ قِبْلَةً تَرْضَاهَا‏\}‏ فَوُجِّهَ نَحْوَ الْكَعْبَةِ، وَصَلَّى مَعَهُ رَجُلٌ الْعَصْرَ، ثُمَّ خَرَجَ فَمَرَّ عَلَى قَوْمٍ مِنَ الأَنْصَارِ فَقَالَ هُوَ يَشْهَدُ أَنَّهُ صَلَّى مَعَ النَّبِيِّ صلى الله عليه وسلم وَأَنَّهُ قَدْ وُجِّهَ إِلَى الْكَعْبَةِ‏.‏ فَانْحَرَفُوا وَهُمْ رُكُوعٌ فِي صَلاَةِ الْعَصْرِ‏.‏\hadithno{7252}\hadithtrans{Narrated Al-Bara':When Allah's Messenger (ﷺ) arrived at Medina, he prayed facing Jerusalem for sixteen or seventeen months but he wished that he would be ordered to face the Ka`ba. So Allah revealed: -- 'Verily! We have seen the turning of your face towards the heaven; surely we shall turn you to a prayer direction (Qibla) that shall please you.' (2.144) Thus he was directed towards the Ka`ba. A man prayed the `Asr prayer with the Prophet (ﷺ) and then went out, and passing by some people from the Ansar, he said, "I testify. that I have prayed with the Prophet (ﷺ) and he (the Prophet) has prayed facing the Ka`ba." Thereupon they, who were bowing in the `Asr prayer, turned towards the Ka`ba}}
\hadithdefcmd{bukhari}{7253}{حَدَّثَنِي يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ كُنْتُ أَسْقِي أَبَا طَلْحَةَ الأَنْصَارِيَّ وَأَبَا عُبَيْدَةَ بْنَ الْجَرَّاحِ وَأُبَىَّ بْنَ كَعْبٍ شَرَابًا مِنْ فَضِيخٍ وَهْوَ تَمْرٌ فَجَاءَهُمْ آتٍ فَقَالَ إِنَّ الْخَمْرَ قَدْ حُرِّمَتْ‏.‏ فَقَالَ أَبُو طَلْحَةَ يَا أَنَسُ قُمْ إِلَى هَذِهِ الْجِرَارِ فَاكْسِرْهَا، قَالَ أَنَسٌ فَقُمْتُ إِلَى مِهْرَاسٍ لَنَا فَضَرَبْتُهَا بِأَسْفَلِهِ حَتَّى انْكَسَرَتْ‏.‏\hadithno{7253}\hadithtrans{Narrated Anas bin Malik:I used to offer drinks prepared from infused dates to Abu Talha Al-Ansari, Abu 'Ubada bin Al Jarrah and Ubai bin Ka`b. Then a person came to them and said, "All alcoholic drinks have been prohibited." Abu Talha then said, "O Anas! Get up and break all these jars." So I got up and took a mortar belonging to us, and hit the jars with its lower part till they broke}}
\hadithdefcmd{bukhari}{7254}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ صِلَةَ، عَنْ حُذَيْفَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لأَهْلِ نَجْرَانَ ‏ "‏ لأَبْعَثَنَّ إِلَيْكُمْ رَجُلاً أَمِينًا حَقَّ أَمِينٍ ‏"‏‏.‏ فَاسْتَشْرَفَ لَهَا أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم فَبَعَثَ أَبَا عُبَيْدَةَ‏.‏\hadithno{7254}\hadithtrans{Narrated Hudhaifa:The Prophet (ﷺ) said to the people of Najran, "I will send to you an honest person who is really trustworthy." The Companion, of the Prophet (ﷺ) each desired to be that person, but the Prophet (ﷺ) sent Abu 'Ubaida}}
\hadithdefcmd{bukhari}{7255}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لِكُلِّ أُمَّةٍ أَمِينٌ، وَأَمِينُ هَذِهِ الأُمَّةِ أَبُو عُبَيْدَةَ ‏"‏‏.‏\hadithno{7255}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "For every nation there is an Amin (honest, trustworthy person) and the Amin of this nation is Abu 'Ubaida}}
\hadithdefcmd{bukhari}{7256}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عُبَيْدِ بْنِ حُنَيْنٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عُمَرَ ـ رضى الله عنهم ـ قَالَ وَكَانَ رَجُلٌ مِنَ الأَنْصَارِ إِذَا غَابَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَشَهِدْتُهُ أَتَيْتُهُ بِمَا يَكُونُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَإِذَا غِبْتُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَشَهِدَ أَتَانِي بِمَا يَكُونُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{7256}\hadithtrans{Narrated `Umar:There was a man from the Ansar (who was a friend of mine). If he was not present in the company of Allah's Messenger (ﷺ) I used to be present with Allah's Messenger (ﷺ), I would tell him what I used to hear from Allah's Messenger (ﷺ), and when I was absent from Allah's Messenger (ﷺ) he used to be present with him, and he would tell me what he used to hear from Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{7257}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ زُبَيْدٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ جَيْشًا وَأَمَّرَ عَلَيْهِمْ رَجُلاً، فَأَوْقَدَ نَارًا وَقَالَ ادْخُلُوهَا‏.‏ فَأَرَادُوا أَنْ يَدْخُلُوهَا، وَقَالَ آخَرُونَ إِنَّمَا فَرَرْنَا مِنْهَا، فَذَكَرُوا لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ لِلَّذِينَ أَرَادُوا أَنْ يَدْخُلُوهَا ‏"‏ لَوْ دَخَلُوهَا لَمْ يَزَالُوا فِيهَا إِلَى يَوْمِ الْقِيَامَةِ ‏"‏‏.‏ وَقَالَ لِلآخَرِينَ ‏"‏ لاَ طَاعَةَ فِي مَعْصِيَةٍ، إِنَّمَا الطَّاعَةُ فِي الْمَعْرُوفِ ‏"‏‏.‏\hadithno{7257}\hadithtrans{Narrated `Ali:The Prophet (ﷺ) , sent an army and appointed some man their commander The man made a fire and then said (to the soldiers), "Enter it." Some of them intended to enter it while some others said, 'We have run away from it (i.e., embraced Islam to save ourselves from the 'fire')." They mentioned that to the Prophet, and he said about people who had intended to enter the fire. ''If they had entered it, they would have remained In it till the Day of Resurrection.'' Then he said to others, "No obedience for evil deeds, obedience is required only in what is good}}
\hadithdefcmd{bukhari}{7259}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ أَبَا هُرَيْرَةَ وَزَيْدَ بْنَ خَالِدٍ أَخْبَرَاهُ أَنَّ رَجُلَيْنِ اخْتَصَمَا إِلَى النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{7259}\hadithtrans{Narrated Abu Huraira and Zaid bin Khalid:Two men sued each other before the Prophet}}
\hadithdefcmd{bukhari}{7260}{وَحَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ بَيْنَمَا نَحْنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ قَامَ رَجُلٌ مِنَ الأَعْرَابِ فَقَالَ يَا رَسُولَ اللَّهِ اقْضِ لِي بِكِتَابِ اللَّهِ‏.‏ فَقَامَ خَصْمُهُ فَقَالَ صَدَقَ يَا رَسُولَ اللَّهِ، اقْضِ لَهُ بِكِتَابِ اللَّهِ، وَأْذَنْ لِي‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قُلْ ‏"‏‏.‏ فَقَالَ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا ـ وَالْعَسِيفُ الأَجِيرُ ـ فَزَنَى بِامْرَأَتِهِ فَأَخْبَرُونِي أَنَّ عَلَى ابْنِي الرَّجْمَ، فَافْتَدَيْتُ مِنْهُ بِمِائَةٍ مِنَ الْغَنَمِ وَوَلِيدَةٍ، ثُمَّ سَأَلْتُ أَهْلَ الْعِلْمِ فَأَخْبَرُونِي أَنَّ عَلَى امْرَأَتِهِ الرَّجْمَ، وَأَنَّمَا عَلَى ابْنِي جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ‏.‏ فَقَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ، أَمَّا الْوَلِيدَةُ وَالْغَنَمُ فَرُدُّوهَا، وَأَمَّا ابْنُكَ فَعَلَيْهِ جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ، وَأَمَّا أَنْتَ يَا أُنَيْسُ ـ لِرَجُلٍ مِنْ أَسْلَمَ ـ فَاغْدُ عَلَى امْرَأَةِ هَذَا، فَإِنِ اعْتَرَفَتْ فَارْجُمْهَا ‏"‏‏.‏ فَغَدَا عَلَيْهَا أُنَيْسٌ فَاعْتَرَفَتْ فَرَجَمَهَا‏.‏\hadithno{7260}\hadithtrans{Narrated Abu Huraira:While we were with Allah's Messenger (ﷺ) a bedouin got up and said, "O Allah's Messenger (ﷺ)! Settle my case according to Allah's Book (Laws)." Then his opponent got up and said, "O Allah's Messenger (ﷺ)! He has said the truth! Settle his case according to Allah's Book (Laws.) and allow me to speak," He said, "My son was a laborer for this man and he committed illegal sexual intercourse with his wife. The people told me that my son should be stoned to death but I ransomed him with one-hundred sheep and a slave girl. Then I asked the religious learned people and they told me that his wife should be stoned to death and my son should receive one-hundred lashes and be sentenced to one year of exile.' The Prophet (ﷺ) said, "By Him in Whose Hands my life is, I will judge between you according to Allah's Book (Laws): As for the slave girl and the sheep, they are to be returned; and as for your son, he shall receive onehundred lashes and will be exiled for one year. You, O Unais!" addressing a man from Bani Aslam, "Go tomorrow morning to the wife of this (man) and if she confesses, then stone her to death." The next morning Unais went to the wife and she confessed, and he stoned her to death}}
\hadithdefcmd{bukhari}{7261}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا ابْنُ الْمُنْكَدِرِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ نَدَبَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ الْخَنْدَقِ فَانْتَدَبَ الزُّبَيْرُ، ثُمَّ نَدَبَهُمْ فَانْتَدَبَ الزُّبَيْرُ، ثُمَّ نَدَبَهُمْ فَانْتَدَبَ الزُّبَيْرُ فَقَالَ ‏ "‏ لِكُلِّ نَبِيٍّ حَوَارِيٌّ وَحَوَارِيِّ الزُّبَيْرُ ‏"‏‏.‏ قَالَ سُفْيَانُ حَفِظْتُهُ مِنِ ابْنِ الْمُنْكَدِرِ‏.‏ وَقَالَ لَهُ أَيُّوبُ يَا أَبَا بَكْرٍ حَدِّثْهُمْ عَنْ جَابِرٍ، فَإِنَّ الْقَوْمَ يُعْجِبُهُمْ أَنْ تُحَدِّثَهُمْ عَنْ جَابِرٍ‏.‏ فَقَالَ فِي ذَلِكَ الْمَجْلِسِ سَمِعْتُ جَابِرًا فَتَابَعَ بَيْنَ أَحَادِيثَ سَمِعْتُ جِابِرًا، قُلْتُ لِسُفْيَانَ فَإِنَّ الثَّوْرِيَّ يَقُولُ يَوْمَ قُرَيْظَةَ فَقَالَ كَذَا حَفِظْتُهُ كَمَا أَنَّكَ جَالِسٌ يَوْمَ الْخَنْدَقِ‏.‏ قَالَ سُفْيَانُ هُوَ يَوْمٌ وَاحِدٌ‏.‏ وَتَبَسَّمَ سُفْيَانُ‏.‏\hadithno{7261}\hadithtrans{Narrated Jabir bin `Abdullah:On the day of (the battle of) the Trench, the Prophet (ﷺ) called the people (to bring news about the enemy). Az-Zubair responded to his call. He called them again and Az-Zubair responded to his call again; then he called them for the third time and again Az-Zubair responded to his call whereupon the Prophet said, "Every prophet has his Hawairi (helper), and Az-Zubair is my Hawari}}
\hadithdefcmd{bukhari}{7262}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي مُوسَى، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ حَائِطًا وَأَمَرَنِي بِحِفْظِ الْبَابِ فَجَاءَ رَجُلٌ يَسْتَأْذِنُ فَقَالَ ‏"‏ ائْذَنْ لَهُ، وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏‏.‏ فَإِذَا أَبُو بَكْرٍ، ثُمَّ جَاءَ عُمَرُ فَقَالَ ‏"‏ ائْذَنْ لَهُ، وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏‏.‏ ثُمَّ جَاءَ عُثْمَانُ فَقَالَ ‏"‏ ائْذَنْ لَهُ، وَبَشِّرْهُ بِالْجَنَّةِ ‏"‏‏.‏\hadithno{7262}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) entered a garden and told me to guard its gate. Then a man came and asked permission to enter. The Prophet, said, "Permit him and give him the good news that he will enter Paradise." Behold! It was Abu Bakr. Then `Umar came, and the Prophet (ﷺ) said, "Admit him and give him the good news that he will enter Paradise." Then `Uthman came and the Prophet (ﷺ) said, "Admit him and give him the good news that he will enter Paradise}}
\hadithdefcmd{bukhari}{7263}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى، عَنْ عُبَيْدِ بْنِ حُنَيْنٍ، سَمِعَ ابْنَ عَبَّاسٍ، عَنْ عُمَرَ ـ رضى الله عنهم ـ قَالَ جِئْتُ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مَشْرُبَةٍ لَهُ، وَغُلاَمٌ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَسْوَدُ عَلَى رَأْسِ الدَّرَجَةِ فَقُلْتُ قُلْ هَذَا عُمَرُ بْنُ الْخَطَّابِ فَأَذِنَ لِي‏.‏\hadithno{7263}\hadithtrans{Narrated `Umar:I came and behold, Allah's Messenger (ﷺ) was staying on a Mashroba (attic room) and a black slave of Allah's Messenger (ﷺ) was at the top if its stairs. I said to him, "(Tell the Prophet) that here is `Umar bin Al- Khattab (asking for permission to enter)." Then he admitted me}}
\hadithdefcmd{bukhari}{7264}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنِي اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ بِكِتَابِهِ إِلَى كِسْرَى، فَأَمَرَهُ أَنْ يَدْفَعَهُ إِلَى عَظِيمِ الْبَحْرَيْنِ، يَدْفَعُهُ عَظِيمُ الْبَحْرَيْنِ إِلَى كِسْرَى، فَلَمَّا قَرَأَهُ كِسْرَى مَزَّقَهُ، فَحَسِبْتُ أَنَّ ابْنَ الْمُسَيَّبِ قَالَ فَدَعَا عَلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُمَزَّقُوا كُلَّ مُمَزَّقٍ‏.‏\hadithno{7264}\hadithtrans{Narrated `Abdullah bin `Abbas:Allah's Messenger (ﷺ) sent a letter to Khosrau and told his messenger to give it first to the ruler of Bahrain, and tell him to deliver it to Khosrau. When Khosrau had read it, he tore it into pieces. (Az-Zuhri said: I think Ibn Al-Musaiyab said, "Allah's Messenger (ﷺ) invoked Allah to tear them (Khosrau and his followers) into pieces}}
\hadithdefcmd{bukhari}{7265}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، حَدَّثَنَا سَلَمَةُ بْنُ الأَكْوَعِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِرَجُلٍ مِنْ أَسْلَمَ ‏ "‏ أَذِّنْ فِي قَوْمِكَ ـ أَوْ فِي النَّاسِ ـ يَوْمَ عَاشُورَاءَ أَنَّ مَنْ أَكَلَ فَلْيُتِمَّ بَقِيَّةَ يَوْمِهِ، وَمَنْ لَمْ يَكُنْ أَكَلَ فَلْيَصُمْ ‏"‏‏.‏\hadithno{7265}\hadithtrans{Narrated Salama bin Al-Akwa`:Allah's Messenger (ﷺ) said to a man from the tribe of Al-Aslam, "Proclaim among your people (or the people) on the day of 'Ashura' (tenth of Muharram), 'Whosoever has eaten anything should fast for the rest of the day; and whoever has not eaten anything, should complete his fast}}
\hadithdefcmd{bukhari}{7266}{حَدَّثَنَا عَلِيُّ بْنُ الْجَعْدِ، أَخْبَرَنَا شُعْبَةُ،‏.‏ وَحَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا النَّضْرُ، أَخْبَرَنَا شُعْبَةُ، عَنْ أَبِي جَمْرَةَ، قَالَ كَانَ ابْنُ عَبَّاسٍ يُقْعِدُنِي عَلَى سَرِيرِهِ فَقَالَ إِنَّ وَفْدَ عَبْدِ الْقَيْسِ لَمَّا أَتَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنِ الْوَفْدُ ‏"‏‏.‏ قَالُوا رَبِيعَةُ‏.‏ قَالَ ‏"‏ مَرْحَبًا بِالْوَفْدِ وَالْقَوْمِ، غَيْرَ خَزَايَا وَلاَ نَدَامَى ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ إِنَّ بَيْنَنَا وَبَيْنَكَ كُفَّارَ مُضَرَ، فَمُرْنَا بِأَمْرٍ نَدْخُلُ بِهِ الْجَنَّةَ، وَنُخْبِرُ بِهِ مَنْ وَرَاءَنَا فَسَأَلُوا عَنِ الأَشْرِبَةِ، فَنَهَاهُمْ عَنْ أَرْبَعٍ وَأَمَرَهُمْ بِأَرْبَعٍ أَمَرَهُمْ بِالإِيمَانِ بِاللَّهِ قَالَ ‏"‏ هَلْ تَدْرُونَ مَا الإِيمَانُ بِاللَّهِ ‏"‏‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ شَهَادَةُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ، وَإِقَامُ الصَّلاَةِ، وَإِيتَاءُ الزَّكَاةِ ـ وَأَظُنُّ فِيهِ ـ صِيَامُ رَمَضَانَ، وَتُؤْتُوا مِنَ الْمَغَانِمِ الْخُمُسَ ‏"‏‏.‏ وَنَهَاهُمْ عَنِ الدُّبَّاءِ، وَالْحَنْتَمِ، وَالْمُزَفَّتِ، وَالنَّقِيرِ، وَرُبَّمَا قَالَ الْمُقَيَّرِ‏.‏ قَالَ ‏"‏ احْفَظُوهُنَّ، وَأَبْلِغُوهُنَّ مَنْ وَرَاءَكُمْ ‏"‏‏.‏\hadithno{7266}\hadithtrans{Narrated Ibn `Abbas:When the delegate of `Abd Al-Qais came to Allah's Messenger (ﷺ), he said, "Who are the delegate?" They said, "The delegate are from the tribe of Rabi`a." The Prophet (ﷺ) said, "Welcome, O the delegate, and welcome! O people! Neither you will have any disgrace nor will you regret." They said, "O Allah's Apostle! Between you and us there are the infidels of the tribe of Mudar, so please order us to do something good (religious deeds) that by acting on them we may enter Paradise, and that we may inform (our people) whom we have left behind, about it." They also asked (the Prophet) about drinks. He forbade them from four things and ordered them to do four things. He ordered them to believe in Allah, and asked them, "Do you know what is meant by belief in Allah?" They said, "Allah and His Apostle know best." He said, ''To testify that none has the right to be worshipped except Allah, the One, Who has no partners with Him, and that Muhammad is Allah's Messenger (ﷺ); and to offer prayers perfectly and to pay Zakat." (the narrator thinks that fasting in Ramadan is included), "and to give one-fifth of the war booty (to the state)." Then he forbade four (drinking utensils): Ad-Duba', Al56 Hantam, Al-Mazaffat and An-Naqir, or probably, Al-Muqaiyar. And then the Prophet (ﷺ) said, "Remember all these things by heart and preach it to those whom you have left behind}}
\hadithdefcmd{bukhari}{7267}{حَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ تَوْبَةَ الْعَنْبَرِيِّ، قَالَ قَالَ لِي الشَّعْبِيُّ أَرَأَيْتَ حَدِيثَ الْحَسَنِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَقَاعَدْتُ ابْنَ عُمَرَ قَرِيبًا مِنْ سَنَتَيْنِ أَوْ سَنَةٍ وَنِصْفٍ فَلَمْ أَسْمَعْهُ يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم غَيْرَ هَذَا قَالَ كَانَ نَاسٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فِيهِمْ سَعْدٌ فَذَهَبُوا يَأْكُلُونَ مِنْ لَحْمٍ، فَنَادَتْهُمُ امْرَأَةٌ مِنْ بَعْضِ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم إِنَّهُ لَحْمُ ضَبٍّ فَأَمْسَكُوا، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُوا ـ أَوِ اطْعَمُوا ـ فَإِنَّهُ حَلاَلٌ ـ أَوْ قَالَ لاَ بَأْسَ بِهِ‏.‏ شَكَّ فِيهِ ـ وَلَكِنَّهُ لَيْسَ مِنْ طَعَامِي ‏"‏‏.‏\hadithno{7267}\hadithtrans{Narrated Tauba Al-`Anbari:Ash-'Shu`bi asked me, "Did you notice how Al-Hasan used to narrate Hadiths from the Prophets? I stayed with Ibn `Umar for about two or one-and-half years and I did not hear him narrating any thing from the Prophet (ﷺ) except his (Hadith): He (Ibn `Umar) said, "Some of the companions of the Prophet (ﷺ) including Sa`d, were going to eat meat, but one of the wives of the Prophet (ﷺ) called them, saying, 'It is the meat of a Mastigure.' The people then stopped eating it. On that Allah's Messenger (ﷺ) said, 'Carry on eating, for it is lawful.' Or said, 'There is no harm in eating it, but it is not from my meals}}
