% Auto-generated chapter 42 for muslim
% Hadiths in this chapter: 40

\hadithdefcmd{muslim}{5897}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - وَاللَّفْظُ لاِبْنِ أَبِي عُمَرَ - حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، قَالَ كُنْتُ أَرَى الرُّؤْيَا أُعْرَى مِنْهَا غَيْرَ أَنِّي لاَ أُزَمَّلُ حَتَّى لَقِيتُ أَبَا قَتَادَةَ فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الرُّؤْيَا مِنَ اللَّهِ وَالْحُلْمُ مِنَ الشَّيْطَانِ فَإِذَا حَلَمَ أَحَدُكُمْ حُلْمًا يَكْرَهُهُ فَلْيَنْفُثْ عَنْ يَسَارِهِ ثَلاَثًا وَلْيَتَعَوَّذْ بِاللَّهِ مِنْ شَرِّهَا فَإِنَّهَا لَنْ تَضُرَّهُ ‏"‏ ‏.‏\hadithno{5897}\hadithtrans{Abu Salama reported:I used to see dreams (and was so much perturbed) that I began to quiver and have temperature, but did not cover myself with a mantle. I met Abu Qatada and made a mention of that to him. He said: I heard Allah's Messenger (ﷺ) as saying: A good vision comes from Allah and a (bad) dream (hulm) from devil. So when one of you sees a bad dream (hulm) which he does not like, he should spit on his left side thrice and seek refuge with Allah from its evil; then it will not harm him}}
\hadithdefcmd{muslim}{5898}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، مَوْلَى آلِ طَلْحَةَ وَعَبْدِ رَبِّهِ وَيَحْيَى ابْنَىْ سَعِيدٍ وَمُحَمَّدِ بْنِ عَمْرِو بْنِ عَلْقَمَةَ عَنْ أَبِي سَلَمَةَ عَنْ أَبِي قَتَادَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ مِثْلَهُ وَلَمْ يَذْكُرْ فِي حَدِيثِهِمْ قَوْلَ أَبِي سَلَمَةَ كُنْتُ أَرَى الرُّؤْيَا أُعْرَى مِنْهَا غَيْرَ أَنِّي لاَ أُزَمَّلُ ‏.‏\hadithno{5898}\hadithtrans{This hadith has been narrated on the authority of Abu Qatada, but there is no mention of the words of Abu Salama:"I saw dreams (which perturbed me) but I did not cover myself with a mantle}}
\hadithdefcmd{muslim}{5899}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ وَعَبْدُ بْنُ حُمَيْدٍ قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ وَلَيْسَ فِي حَدِيثِهِمَا أُعْرَى مِنْهَا ‏.‏ وَزَادَ فِي حَدِيثِ يُونُسَ ‏ "‏ فَلْيَبْصُقْ عَلَى يَسَارِهِ حِينَ يَهُبُّ مِنْ نَوْمِهِ ثَلاَثَ مَرَّاتٍ ‏"‏ ‏.‏\hadithno{5899}\hadithtrans{This hadith has been reported on the authority of Zuhri with the same chain of transmitters, but it does not contain the words:"I felt disturbed because of that," and there is an addition of these words in the hadith transmitted on the authority of Yunus: "Then spit thrice on the left side when you get up from sleep}}
\hadithdefcmd{muslim}{5900}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، يَقُولُ سَمِعْتُ أَبَا قَتَادَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الرُّؤْيَا مِنَ اللَّهِ وَالْحُلْمُ مِنَ الشَّيْطَانِ فَإِذَا رَأَى أَحَدُكُمْ شَيْئًا يَكْرَهُهُ فَلْيَنْفِثْ عَنْ يَسَارِهِ ثَلاَثَ مَرَّاتٍ وَلْيَتَعَوَّذْ بِاللَّهِ مِنْ شَرِّهَا فَإِنَّهَا لَنْ تَضُرَّهُ ‏"‏ ‏.‏ فَقَالَ إِنْ كُنْتُ لأَرَى الرُّؤْيَا أَثْقَلَ عَلَىَّ مِنْ جَبَلٍ فَمَا هُوَ إِلاَّ أَنْ سَمِعْتُ بِهَذَا الْحَدِيثِ فَمَا أُبَالِيهَا ‏.‏\hadithno{5900}\hadithtrans{Abu Qatada reported Allah's Messenger (ﷺ) as saying:A good vision is from Allah and a bad dream (hulm) is from the satan; so if one of you sees anything (in a dream) which he dislikes, he should spit on his left side thrice and seek refuge with Allah from its evil, and then it will never harm him. Abu Salama said: I used to see dreams weighing more heavily upon me than a mountain; but since I heard this hadith I don't care for it (its burden)}}
\hadithdefcmd{muslim}{5901}{وَحَدَّثَنَاهُ قُتَيْبَةُ، وَمُحَمَّدُ بْنُ رُمْحٍ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ يَعْنِي الثَّقَفِيَّ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، كُلُّهُمْ عَنْ يَحْيَى بْنِ سَعِيدٍ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِ الثَّقَفِيِّ قَالَ أَبُو سَلَمَةَ فَإِنْ كُنْتُ لأَرَى الرُّؤْيَا ‏.‏ وَلَيْسَ فِي حَدِيثِ اللَّيْثِ وَابْنِ نُمَيْرٍ قَوْلُ أَبِي سَلَمَةَ إِلَى آخِرِ الْحَدِيثِ ‏.‏ وَزَادَ ابْنُ رُمْحٍ فِي رِوَايَةِ هَذَا الْحَدِيثِ ‏ "‏ وَلْيَتَحَوَّلْ عَنْ جَنْبِهِ الَّذِي كَانَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{5901}\hadithtrans{Abu Salama reported:I used to see dreams, but the hadith transmitted on the authority of Laith b. Nu`man, the words of Abu Salama at the concluding part of the hadith are not mentioned. Ibn Rumh has reported in the hadith: "He (one who sleeps) should change the side on which he had been lying before}}
\hadithdefcmd{muslim}{5902}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي قَتَادَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الرُّؤْيَا الصَّالِحَةُ مِنَ اللَّهِ وَالرُّؤْيَا السَّوْءُ مِنَ الشَّيْطَانِ فَمَنْ رَأَى رُؤْيَا فَكَرِهَ مِنْهَا شَيْئًا فَلْيَنْفِثْ عَنْ يَسَارِهِ وَلْيَتَعَوَّذْ بِاللَّهِ مِنَ الشَّيْطَانِ لاَ تَضُرُّهُ وَلاَ يُخْبِرْ بِهَا أَحَدًا فَإِنْ رَأَى رُؤْيَا حَسَنَةً فَلْيُبْشِرْ وَلاَ يُخْبِرْ إِلاَّ مَنْ يُحِبُّ ‏"‏ ‏.‏\hadithno{5902}\hadithtrans{Abu Qatada reported Allah's Messenger (ﷺ) as saying:The good vision are from Allah and the evil dreams are from the satan. If one sees a dream which one does not like, one should spit on one's left side and seek the refuge of Allah from the satan; it will not do one any harm, and one should not disclose it to anyone and if one sees a good vision one should feel pleased but should not disclose it to anyone but whom one loves}}
\hadithdefcmd{muslim}{5903}{حَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، وَأَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ أَبِي سَلَمَةَ، قَالَ إِنْ كُنْتُ لأَرَى الرُّؤْيَا تُمْرِضُنِي - قَالَ - فَلَقِيتُ أَبَا قَتَادَةَ فَقَالَ وَأَنَا كُنْتُ لأَرَى الرُّؤْيَا فَتُمْرِضُنِي حَتَّى سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الرُّؤْيَا الصَّالِحَةُ مِنَ اللَّهِ فَإِذَا رَأَى أَحَدُكُمْ مَا يُحِبُّ فَلاَ يُحَدِّثُ بِهَا إِلاَّ مَنْ يُحِبُّ وَإِنْ رَأَى مَا يَكْرَهُ فَلْيَتْفِلْ عَنْ يَسَارِهِ ثَلاَثًا وَلْيَتَعَوَّذْ بِاللَّهِ مِنْ شَرِّ الشَّيْطَانِ وَشَرِّهَا وَلاَ يُحَدِّثْ بِهَا أَحَدًا فَإِنَّهَا لَنْ تَضُرَّهُ ‏"‏ ‏.‏\hadithno{5903}\hadithtrans{Abu Salama reported:I used to see (such horrible dreams) that I fell ill. I saw Abu Qatada who also said: I used to see dreams which made me sick until I heard Allah's Messenger (ﷺ) as saying: Good dreams are from Allah, so if any one of you sees which he likes he should not disclose it to one but whom he loves, but if he sees something which he does not like he should spit on his left side thrice and seek refuge with Allah from the mischief of the Satan and its mischief (i.e. of the dream), and he should not relate it to anyone, then it would not harm him}}
\hadithdefcmd{muslim}{5904}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي، الزُّبَيْرِ عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا رَأَى أَحَدُكُمُ الرُّؤْيَا يَكْرَهُهَا فَلْيَبْصُقْ عَنْ يَسَارِهِ ثَلاَثًا وَلْيَسْتَعِذْ بِاللَّهِ مِنَ الشَّيْطَانِ ثَلاَثًا وَلْيَتَحَوَّلْ عَنْ جَنْبِهِ الَّذِي كَانَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{5904}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) as saying:If anyone sees a dream which he does not like, he should spit on his left side three times, and seek refuge with Allah from the Satan three times, and let him turn over from the side on which he was sleeping}}
\hadithdefcmd{muslim}{5905}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا اقْتَرَبَ الزَّمَانُ لَمْ تَكَدْ رُؤْيَا الْمُسْلِمِ تَكْذِبُ وَأَصْدَقُكُمْ رُؤْيَا أَصْدَقُكُمْ حَدِيثًا وَرُؤْيَا الْمُسْلِمِ جُزْءٌ مِنْ خَمْسٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ وَالرُّؤْيَا ثَلاَثَةٌ فَرُؤْيَا الصَّالِحَةِ بُشْرَى مِنَ اللَّهِ وَرُؤْيَا تَحْزِينٌ مِنَ الشَّيْطَانِ وَرُؤْيَا مِمَّا يُحَدِّثُ الْمَرْءُ نَفْسَهُ فَإِنْ رَأَى أَحَدُكُمْ مَا يَكْرَهُ فَلْيَقُمْ فَلْيُصَلِّ وَلاَ يُحَدِّثْ بِهَا النَّاسَ ‏"‏ ‏.‏ قَالَ ‏"‏ وَأُحِبُّ الْقَيْدَ وَأَكْرَهُ الْغُلَّ وَالْقَيْدُ ثَبَاتٌ فِي الدِّينِ ‏"‏ ‏.‏ فَلاَ أَدْرِي هُوَ فِي الْحَدِيثِ أَمْ قَالَهُ ابْنُ سِيرِينَ ‏.‏\hadithno{5905}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When the time draws near (when the Resurrection is near) a believer's dream can hardly be false. And the truest vision will be of one who is himself the most truthful in speech, for the vision of a Muslim is the forty-fifth part of Prophecy, and dreams are of three types: one good dream which is a sort of good tidings from Allah; the evil dream which causes pain is from the satan; and the third one is a suggestion of one's own mind; so if any one of you sees a dream which he does not like he should stand up and offer prayer and he should not relate it to people, and he said: I would love to see fetters (in the dream), but I dislike wearing of necklace, for the fetters is (an indication of) one's steadfastness in religion. The narrator said: I do not know whether this is a part of the hadith or the words of Ibn Sirin}}
\hadithdefcmd{muslim}{5906}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ وَقَالَ فِي الْحَدِيثِ قَالَ أَبُو هُرَيْرَةَ فَيُعْجِبُنِي الْقَيْدُ وَأَكْرَهُ الْغُلَّ وَالْقَيْدُ ثَبَاتٌ فِي الدِّينِ ‏.‏ وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ رُؤْيَا الْمُؤْمِنِ جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{5906}\hadithtrans{Abu Huraira reported:I love to see fetters but I hate necklace (in a dream), for fetters signifies one's steadfastness in religion, and he also reported Allah's Messenger (ﷺ) as saying: The vision of a believer is forty-sixth part of Prophecy}}
\hadithdefcmd{muslim}{5907}{حَدَّثَنِي أَبُو الرَّبِيعِ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - حَدَّثَنَا أَيُّوبُ، وَهِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ إِذَا اقْتَرَبَ الزَّمَانُ ‏.‏ وَسَاقَ الْحَدِيثَ وَلَمْ يَذْكُرْ فِيهِ النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{5907}\hadithtrans{This hadith has been transmitted on the authority of Abu Huraira and the words are:"When the time draws near," the rest of the hadith is the same}}
\hadithdefcmd{muslim}{5908}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنَا أَبِي، عَنْ قَتَادَةَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَأَدْرَجَ فِي الْحَدِيثِ قَوْلَهُ وَأَكْرَهُ الْغُلَّ ‏.‏ إِلَى تَمَامِ الْكَلاَمِ وَلَمْ يَذْكُرِ ‏ "‏ الرُّؤْيَا جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{5908}\hadithtrans{Muhammad b. Sirin reported from Abu Huraira a hadith from Allah's Apostle (ﷺ) and he mentioned in his hadith his words:"I dislike shackles," up to the end of his statement, but he made no mention of this: "A vision is a forty-sixth part of Prophecy}}
\hadithdefcmd{muslim}{5909}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَأَبُو دَاوُدَ ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، كُلُّهُمْ عَنْ شُعْبَةَ، ح وَحَدَّثَنَا عُبَيْدُ، اللَّهِ بْنُ مُعَاذٍ - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رُؤْيَا الْمُؤْمِنِ جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{5909}\hadithtrans{Ubada b. as-Samit reported Allah's Messenger (ﷺ) as saying:The vision of a believer is the forty-sixth part of Prophecy}}
\hadithdefcmd{muslim}{5910}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ، بْنِ مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ ذَلِكَ ‏.‏\hadithno{5910}\hadithtrans{This hadith has been narrated on the authority of Anas b. Malik through another chain of transmitters}}
\hadithdefcmd{muslim}{5911}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ، الْمُسَيَّبِ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ رُؤْيَا الْمُؤْمِنِ جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{5911}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Verily the vision of a believer is one of the forty-sixth part of Prophecy}}
\hadithdefcmd{muslim}{5912}{وَحَدَّثَنَا إِسْمَاعِيلُ بْنُ الْخَلِيلِ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ رُؤْيَا الْمُسْلِمِ يَرَاهَا أَوْ تُرَى لَهُ ‏"‏ ‏.‏ وَفِي حَدِيثِ ابْنِ مُسْهِرٍ ‏"‏ الرُّؤْيَا الصَّالِحَةُ جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{5912}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The vision of a Muslim which he sees or which is shown to him, and in the hadith transmitted on the authority of Ibn Mushir (the words are): "The pious dream is the forty-sixth part of Prophecy}}
\hadithdefcmd{muslim}{5913}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ سَمِعْتُ أَبِي يَقُولُ، حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رُؤْيَا الرَّجُلِ الصَّالِحِ جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{5913}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The vision of a pious man is the forty-sixth part of Prophecy}}
\hadithdefcmd{muslim}{5914}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا عَلِيٌّ، - يَعْنِي ابْنَ الْمُبَارَكِ - ح وَحَدَّثَنَا أَحْمَدُ بْنُ الْمُنْذِرِ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا حَرْبٌ، - يَعْنِي ابْنَ شَدَّادٍ - كِلاَهُمَا عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5914}\hadithtrans{This hadith has been narrated on the authority of Yahya b. Abu Kathir with the same chain of transmitters}}
\hadithdefcmd{muslim}{5915}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ عَبْدِ اللَّهِ بْنِ يَحْيَى بْنِ أَبِي كَثِيرٍ عَنْ أَبِيهِ ‏.‏\hadithno{5915}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{5916}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، قَالاَ جَمِيعًا حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الرُّؤْيَا الصَّالِحَةُ جُزْءٌ مِنْ سَبْعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{5916}\hadithtrans{Ibn `Umar reported Allah's Messenger (ﷺ) as saying:The pious dreams are the seventieth part of Prophecy}}
\hadithdefcmd{muslim}{5917}{وَحَدَّثَنَاهُ ابْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5917}\hadithtrans{This hadith has been reported on the authority of `Ubaidullah with the same chain of transmitters}}
\hadithdefcmd{muslim}{5918}{وَحَدَّثَنَاهُ قُتَيْبَةُ، وَابْنُ، رُمْحٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا ابْنُ رَافِعٍ، حَدَّثَنَا ابْنُ، أَبِي فُدَيْكٍ أَخْبَرَنَا الضَّحَّاكُ، - يَعْنِي ابْنَ عُثْمَانَ - كِلاَهُمَا عَنْ نَافِعٍ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِ اللَّيْثِ قَالَ نَافِعٌ حَسِبْتُ أَنَّ ابْنَ عُمَرَ قَالَ ‏ "‏ جُزْءٌ مِنْ سَبْعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏\hadithno{5918}\hadithtrans{A hadith like this has been reported on the authority of Nafi` with the same chain of transmitters (and the words are):"I think Ibn `Umar said: The seventieth part from Prophecy}}
\hadithdefcmd{muslim}{5919}{حَدَّثَنَا أَبُو الرَّبِيعِ، سُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - حَدَّثَنَا أَيُّوبُ، وَهِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ رَآنِي فِي الْمَنَامِ فَقَدْ رَآنِي فَإِنَّ الشَّيْطَانَ لاَ يَتَمَثَّلُ بِي ‏"‏ ‏.‏\hadithno{5919}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who saw me in a dream in fact saw me, for the satan does not appear in my form}}
\hadithdefcmd{muslim}{5920}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ، شِهَابٍ حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ رَآنِي فِي الْمَنَامِ فَسَيَرَانِي فِي الْيَقَظَةِ أَوْ لَكَأَنَّمَا رَآنِي فِي الْيَقَظَةِ لاَ يَتَمَثَّلُ الشَّيْطَانُ بِي ‏"‏ ‏.‏\hadithno{5920}\hadithtrans{Abu Huraira reported:I heard Allah's Messenger (ﷺ) as saying: He who saw me in a dream would soon see me in the state of wakefulness, or as if he saw me in a state of wakefulness, for the satan does not appear in my form}}
\hadithdefcmd{muslim}{5921}{وَقَالَ فَقَالَ أَبُو سَلَمَةَ قَالَ أَبُو قَتَادَةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ رَآنِي فَقَدْ رَأَى الْحَقَّ ‏"‏ ‏.‏\hadithno{5921}\hadithtrans{Abu Qatada reported Allah's Messenger (ﷺ) as saying:He who saw me in dream in fact saw the truth (what is true)}}
\hadithdefcmd{muslim}{5922}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَخِي الزُّهْرِيِّ، حَدَّثَنَا عَمِّي، ‏.‏ فَذَكَرَ الْحَدِيثَيْنِ جَمِيعًا بِإِسْنَادَيْهِمَا سَوَاءً مِثْلَ حَدِيثِ يُونُسَ ‏.‏\hadithno{5922}\hadithtrans{The above two hadith have been narrated likewise through another chain of transmitters}}
\hadithdefcmd{muslim}{5923}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي، الزُّبَيْرِ عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ رَآنِي فِي النَّوْمِ فَقَدْ رَآنِي إِنَّهُ لاَ يَنْبَغِي لِلشَّيْطَانِ أَنْ يَتَمَثَّلَ فِي صُورَتِي ‏"‏ ‏.‏ وَقَالَ ‏"‏ إِذَا حَلَمَ أَحَدُكُمْ فَلاَ يُخْبِرْ أَحَدًا بِتَلَعُّبِ الشَّيْطَانِ بِهِ فِي الْمَنَامِ ‏"‏ ‏.‏\hadithno{5923}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) as saying:He who saw me in sleep in fact saw me, for it is not possible for the satan to appear in my form; and he also said: When any one of you sees a hulm he should not inform anyone, for it is a sort of vain sport of devil in the state of sleep}}
\hadithdefcmd{muslim}{5924}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، حَدَّثَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ رَآنِي فِي النَّوْمِ فَقَدْ رَآنِي فَإِنَّهُ لاَ يَنْبَغِي لِلشَّيْطَانِ أَنْ يَتَشَبَّهَ بِي ‏"‏ ‏.‏\hadithno{5924}\hadithtrans{Jabir b. `Abdullah reported Allah's Messenger (ﷺ) as saying:He who saw me in a dream in fact saw me, for the satan cannot assume my form}}
\hadithdefcmd{muslim}{5925}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي، الزُّبَيْرِ عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ لأَعْرَابِيٍّ جَاءَهُ فَقَالَ إِنِّي حَلَمْتُ أَنَّ رَأْسِي قُطِعَ فَأَنَا أَتَّبِعُهُ فَزَجَرَهُ النَّبِيُّ صلى الله عليه وسلم وَقَالَ ‏ "‏ لاَ تُخْبِرْ بِتَلَعُّبِ الشَّيْطَانِ بِكَ فِي الْمَنَامِ ‏"‏ ‏.‏\hadithno{5925}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) as saying:There came to him (the Holy Prophet) a desert Arab and said: I saw in a dream that I had been beheaded and I had been following it (the severed head). Allah's Apostle (ﷺ) reprimanded him saying: Do not inform about the vain sporting of devil with you during the night}}
\hadithdefcmd{muslim}{5926}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ رَأَيْتُ فِي الْمَنَامِ كَأَنَّ رَأْسِي ضُرِبَ فَتَدَحْرَجَ فَاشْتَدَدْتُ عَلَى أَثَرِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلأَعْرَابِيِّ ‏"‏ لاَ تُحَدِّثِ النَّاسَ بِتَلَعُّبِ الشَّيْطَانِ بِكَ فِي مَنَامِكَ ‏"‏ ‏.‏ وَقَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم بَعْدُ يَخْطُبُ فَقَالَ ‏"‏ لاَ يُحَدِّثَنَّ أَحَدُكُمْ بِتَلَعُّبِ الشَّيْطَانِ بِهِ فِي مَنَامِهِ ‏"‏ ‏.‏\hadithno{5926}\hadithtrans{Jabir reported that there came to Allah's Apostle (ﷺ) a desert Arab and said:Allah's Messenger, I saw in the state of sleep as if my head had been cut off and I had been moving on haltingly after it. Thereupon Allah's Messenger (ﷺ) said to that desert Arab: Do not narrate to the people the vain sporting of satan with you in your sleep and (the narrator) also said: I heard Allah's Messenger (ﷺ) in his subsequent address: None amongst you should narrate the vain sporting of devil with him in the dream}}
\hadithdefcmd{muslim}{5927}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ رَأَيْتُ فِي الْمَنَامِ كَأَنَّ رَأْسِي قُطِعَ ‏.‏ قَالَ فَضَحِكَ النَّبِيُّ صلى الله عليه وسلم وَقَالَ ‏"‏ إِذَا لَعِبَ الشَّيْطَانُ بِأَحَدِكُمْ فِي مَنَامِهِ فَلاَ يُحَدِّثْ بِهِ النَّاسَ ‏"‏ ‏.‏ وَفِي رِوَايَةِ أَبِي بَكْرٍ ‏"‏ إِذَا لُعِبَ بِأَحَدِكُمْ ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ الشَّيْطَانَ ‏.‏\hadithno{5927}\hadithtrans{Jabir reported that a person came to Allah's Apostle (ﷺ) and said:Allah's Messenger, I have seen in the state of sleep as if my head had been cut off. Thereupon Allah's Apostle (ﷺ) laughed and said: When the satan plays with any one of you in the state of sleep, do not mention it to the people; and in the hadith transmitted by Abu Bakr (the words are): "If one of you is played with, and he did not make any mention of the word: "Satan}}
\hadithdefcmd{muslim}{5928}{حَدَّثَنَا حَاجِبُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، أَخْبَرَنِي الزُّهْرِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، أَنَّ ابْنَ عَبَّاسٍ، أَوْ أَبَا هُرَيْرَةَ كَانَ يُحَدِّثُ أَنَّ رَجُلاً، أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم ح وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَخْبَرَهُ أَنَّ ابْنَ عَبَّاسٍ كَانَ يُحَدِّثُ أَنَّ رَجُلاً أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَرَى اللَّيْلَةَ فِي الْمَنَامِ ظُلَّةً تَنْطِفُ السَّمْنَ وَالْعَسَلَ فَأَرَى النَّاسَ يَتَكَفَّفُونَ مِنْهَا بِأَيْدِيهِمْ فَالْمُسْتَكْثِرُ وَالْمُسْتَقِلُّ وَأَرَى سَبَبًا وَاصِلاً مِنَ السَّمَاءِ إِلَى الأَرْضِ فَأَرَاكَ أَخَذْتَ بِهِ فَعَلَوْتَ ثُمَّ أَخَذَ بِهِ رَجُلٌ مِنْ بَعْدِكَ فَعَلاَ ثُمَّ أَخَذَ بِهِ رَجُلٌ آخَرُ فَعَلاَ ثُمَّ أَخَذَ بِهِ رَجُلٌ آخَرُ فَانْقَطَعَ بِهِ ثُمَّ وُصِلَ لَهُ فَعَلاَ ‏.‏ قَالَ أَبُو بَكْرٍ يَا رَسُولَ اللَّهِ بِأَبِي أَنْتَ وَاللَّهِ لَتَدَعَنِّي فَلأَعْبُرَنَّهَا ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اعْبُرْهَا ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ أَمَّا الظُّلَّةُ فَظُلَّةُ الإِسْلاَمِ وَأَمَّا الَّذِي يَنْطِفُ مِنَ السَّمْنِ وَالْعَسَلِ فَالْقُرْآنُ حَلاَوَتُهُ وَلِينُهُ وَأَمَّا مَا يَتَكَفَّفُ النَّاسُ مِنْ ذَلِكَ فَالْمُسْتَكْثِرُ مِنَ الْقُرْآنِ وَالْمُسْتَقِلُّ وَأَمَّا السَّبَبُ الْوَاصِلُ مِنَ السَّمَاءِ إِلَى الأَرْضِ فَالْحَقُّ الَّذِي أَنْتَ عَلَيْهِ تَأْخُذُ بِهِ فَيُعْلِيكَ اللَّهُ بِهِ ثُمَّ يَأْخُذُ بِهِ رَجُلٌ مِنْ بَعْدِكَ فَيَعْلُو بِهِ ثُمَّ يَأْخُذُ بِهِ رَجُلٌ آخَرُ فَيَعْلُو بِهِ ثُمَّ يَأْخُذُ بِهِ رَجُلٌ آخَرُ فَيَنْقَطِعُ بِهِ ثُمَّ يُوصَلُ لَهُ فَيَعْلُو بِهِ ‏.‏ فَأَخْبِرْنِي يَا رَسُولَ اللَّهِ بِأَبِي أَنْتَ أَصَبْتُ أَمْ أَخْطَأْتُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَصَبْتَ بَعْضًا وَأَخْطَأْتَ بَعْضًا ‏"‏ ‏.‏ قَالَ فَوَاللَّهِ يَا رَسُولَ اللَّهِ لَتُحَدِّثَنِّي مَا الَّذِي أَخْطَأْتُ قَالَ ‏"‏ لاَ تُقْسِمْ ‏"‏ ‏.‏\hadithno{5928}\hadithtrans{It is reported either on the authority of Ibn `Abbas or on the authority of Abu Huraira that a person came to Allah's Messenger (ﷺ) and said:Allah's Messenger, I saw while I was sleeping during the night (this vision) that there was a canopy from which butter and honey were trickling and I also saw people collecting them in the palms of their hands, some more, some less, and I also saw a rope connecting the earth with the sky and I saw you catching hold of it and rising towards the heaven; then another person after you catching hold of it and rising towards (Heaven); then another person catching hold of it, but it was broken while it was rejoined for him and he also climbed up. Abu Bakr said: Allah's Messenger, may my father be sacrificed for you, by Allah, allow me to interpret it. Allah's Messenger (ﷺ) said: Well, give its interpretation. Thereupon Abu Bakr said: The canopy signifies the canopy of Islam and that what trickles out of it in the form of butter and honey is the Holy Qur'an and its sweetness and softness and what the people get hold of it in their palms implies major portion of the Qur'an or the small portion; and so far as the rope joining the sky with the earth is concerned, it is the Truth by which you stood (in the worldly life) and by which Allah would raise you (to Heaven). Then the person after you would take hold of it and he would also climb up with the help of it. Then another person would take hold of it and climb up with the help of it. Then another person would take hold of it and it would be broken; then it would be rejoined for him and he would climb up with the help of it. Allah's Messenger, may my father be taken as a ransom for you, tell me whether I have interpreted it correctly or I have made an error. Allah's Messenger (ﷺ) said: You have interpreted a part of it correctly and you have erred in interpreting a part of it. Thereupon he said: Allah's Messenger, by Allah, tell me that part where I have committed an error. Thereupon he said: Don't take an oath}}
\hadithdefcmd{muslim}{5929}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ رَجُلٌ النَّبِيَّ صلى الله عليه وسلم مُنْصَرَفَهُ مِنْ أُحُدٍ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي رَأَيْتُ هَذِهِ اللَّيْلَةَ فِي الْمَنَامِ ظُلَّةً تَنْطِفُ السَّمْنَ وَالْعَسَلَ ‏.‏ بِمَعْنَى حَدِيثِ يُونُسَ ‏.‏\hadithno{5929}\hadithtrans{Ibn `Abbas reported that there came to Allah's Apostle (ﷺ) a person as he was returning from Uhud and he said:Allah's Messenger, I saw in sleep during the night a canopy trickling butter and honey; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{5930}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ، اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ عَنِ ابْنِ عَبَّاسٍ، أَوْ أَبِي هُرَيْرَةَ قَالَ عَبْدُ الرَّزَّاقِ كَانَ مَعْمَرٌ أَحْيَانًا يَقُولُ عَنِ ابْنِ عَبَّاسٍ وَأَحْيَانًا يَقُولُ عَنْ أَبِي هُرَيْرَةَ أَنَّ رَجُلاً أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنِّي أَرَى اللَّيْلَةَ ظُلَّةً ‏.‏ بِمَعْنَى حَدِيثِهِمْ ‏.‏\hadithno{5930}\hadithtrans{It is reported either on the authority of Ibn 'Abbas or on that of Abu Huraira that a person came to Allah's Messenger (ﷺ) and said:Verily I saw during the night a canopy; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{5931}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُلَيْمَانُ، - وَهُوَ ابْنُ كَثِيرٍ - عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ مِمَّا يَقُولُ لأَصْحَابِهِ ‏ "‏ مَنْ رَأَى مِنْكُمْ رُؤْيَا فَلْيَقُصَّهَا أَعْبُرْهَا لَهُ ‏"‏ ‏.‏ قَالَ فَجَاءَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ رَأَيْتُ ظُلَّةً ‏.‏ بِنَحْوِ حَدِيثِهِمْ ‏.‏\hadithno{5931}\hadithtrans{Ibn `Abbas reported that Allah's Messenger (ﷺ) used to say to his Companions:He who amongst you sees a vision should narrate it and I would interpret it for him, and a person came and said: Allah's Messenger, I saw a canopy. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{5932}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَأَيْتُ ذَاتَ لَيْلَةٍ فِيمَا يَرَى النَّائِمُ كَأَنَّا فِي دَارِ عُقْبَةَ بْنِ رَافِعٍ فَأُتِينَا بِرُطَبٍ مِنْ رُطَبِ ابْنِ طَابٍ فَأَوَّلْتُ الرِّفْعَةَ لَنَا فِي الدُّنْيَا وَالْعَاقِبَةَ فِي الآخِرَةِ وَأَنَّ دِينَنَا قَدْ طَابَ ‏"‏ ‏.‏\hadithno{5932}\hadithtrans{Anas b. Malik reported Allah's Messenger (ﷺ) as saying:I saw during the night that which a person sees during the sleep as if we are in the house of `Uqba b. Rafi` that there was brought to us the fresh dates of Ibn Tab. I interpreted it as the sublimity for us in the world and good ending in the Hereafter and that our religion is good}}
\hadithdefcmd{muslim}{5933}{وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، أَخْبَرَنِي أَبِي، حَدَّثَنَا صَخْرُ بْنُ جُوَيْرِيَةَ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَرَانِي فِي الْمَنَامِ أَتَسَوَّكُ بِسِوَاكٍ فَجَذَبَنِي رَجُلاَنِ أَحَدُهُمَا أَكْبَرُ مِنَ الآخَرِ فَنَاوَلْتُ السِّوَاكَ الأَصْغَرَ مِنْهُمَا فَقِيلَ لِي كَبِّرْ ‏.‏ فَدَفَعْتُهُ إِلَى الأَكْبَرِ ‏"‏ ‏.‏\hadithno{5933}\hadithtrans{Abdullah b. `Umar reported Allah's Messenger (ﷺ) as saying:I saw in a dream that I was using miswak and two persons contended to get it from me, one being older than the other one. I gave the miswak to the younger one. It was said to me to give that to the older one and I gave it to the older one}}
\hadithdefcmd{muslim}{5934}{حَدَّثَنَا أَبُو عَامِرٍ عَبْدُ اللَّهِ بْنُ بَرَّادٍ الأَشْعَرِيُّ، وَأَبُو كُرَيْبٍ مُحَمَّدُ بْنُ الْعَلاَءِ - وَتَقَارَبَا فِي اللَّفْظِ - قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، جَدِّهِ عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ رَأَيْتُ فِي الْمَنَامِ أَنِّي أُهَاجِرُ مِنْ مَكَّةَ إِلَى أَرْضٍ بِهَا نَخْلٌ فَذَهَبَ وَهَلِي إِلَى أَنَّهَا الْيَمَامَةُ أَوْ هَجَرُ فَإِذَا هِيَ الْمَدِينَةُ يَثْرِبُ وَرَأَيْتُ فِي رُؤْيَاىَ هَذِهِ أَنِّي هَزَزْتُ سَيْفًا فَانْقَطَعَ صَدْرُهُ فَإِذَا هُوَ مَا أُصِيبَ مِنَ الْمُؤْمِنِينَ يَوْمَ أُحُدٍ ثُمَّ هَزَزْتُهُ أُخْرَى فَعَادَ أَحْسَنَ مَا كَانَ فَإِذَا هُوَ مَا جَاءَ اللَّهُ بِهِ مِنَ الْفَتْحِ وَاجْتِمَاعِ الْمُؤْمِنِينَ وَرَأَيْتُ فِيهَا أَيْضًا بَقَرًا وَاللَّهُ خَيْرٌ فَإِذَا هُمُ النَّفَرُ مِنَ الْمُؤْمِنِينَ يَوْمَ أُحُدٍ وَإِذَا الْخَيْرُ مَا جَاءَ اللَّهُ بِهِ مِنَ الْخَيْرِ بَعْدُ وَثَوَابُ الصِّدْقِ الَّذِي آتَانَا اللَّهُ بَعْدُ يَوْمَ بَدْرٍ ‏"‏ ‏.‏\hadithno{5934}\hadithtrans{Abu Musa reported Allah's Messenger (ﷺ) as saying:I dreamt (while asleep) that I was about to migrate from Mecca to a land abounding in palm trees and I guessed that it would be Yamama or Hajar, but it was the city of Yathrib (the old name of Medina), and I saw in this dream of mine that I was brandishing a sword and its upper end was broken and this is what fell (in the form of misfortune to the believers on the Day of Uhud). I brandished (the sword) for the second time and it became all right and this is what came to be true when Allah granted us victory and solidarity of the believers. And I saw therein cows also and Allah is the Doer of good. These meant the group from amongst the believers on the Day of Uhud and the goodness which Allah brought after that and the reward of attestation of his Truth which Allah brought to us after the Day of Badr}}
\hadithdefcmd{muslim}{5936}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَيْنَا أَنَا نَائِمٌ أُتِيتُ خَزَائِنَ الأَرْضِ فَوَضَعَ فِي يَدَىَّ أُسْوَارَيْنِ مِنْ ذَهَبٍ فَكَبُرَا عَلَىَّ وَأَهَمَّانِي فَأُوحِيَ إِلَىَّ أَنِ انْفُخْهُمَا فَنَفَخْتُهُمَا فَذَهَبَا فَأَوَّلْتُهُمَا الْكَذَّابَيْنِ اللَّذَيْنِ أَنَا بَيْنَهُمَا صَاحِبَ صَنْعَاءَ وَصَاحِبَ الْيَمَامَةِ ‏"‏ ‏.‏\hadithno{5936}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:While I was sleeping, the treasures of the earth were presented to me and I was made to wear in my hands two gold bangles. I felt a sort of burden upon me and I was disturbed and it was suggested to me that I should blow over them, so I blew and both of them disappeared. I interpreted them as two great liars who would appear at any time, one is the inhabitant of San`a' and the other is that of Yamama}}
\hadithdefcmd{muslim}{5937}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي، عَنْ أَبِي رَجَاءٍ الْعُطَارِدِيِّ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا صَلَّى الصُّبْحَ أَقْبَلَ عَلَيْهِمْ بِوَجْهِهِ فَقَالَ ‏ "‏ هَلْ رَأَى أَحَدٌ مِنْكُمُ الْبَارِحَةَ رُؤْيَا ‏"‏ ‏.‏\hadithno{5937}\hadithtrans{Samura b. Jundab reported that when Allah's Messenger (ﷺ) had performed his dawn prayer he turned his face towards them (that is towards his Companions) and said:Did any one of you see any vision last night?}}
