% Auto-generated chapter 9 for malik
% Hadiths in this chapter: 102

\hadithdefcmd{malik}{326}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَجْمَعُ بَيْنَ الظُّهْرِ وَالْعَصْرِ فِي سَفَرِهِ إِلَى تَبُوكَ ‏.‏\hadithno{326}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Da'ud ibn al-Husayn from al- Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, joined dhuhr and asr on his journey to Tabuk}}
\hadithdefcmd{malik}{327}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، عَنْ أَبِي الطُّفَيْلِ، عَامِرِ بْنِ وَاثِلَةَ أَنَّ مُعَاذَ بْنَ جَبَلٍ، أَخْبَرَهُ أَنَّهُمْ، خَرَجُوا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ تَبُوكَ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَجْمَعُ بَيْنَ الظُّهْرِ وَالْعَصْرِ وَالْمَغْرِبِ وَالْعِشَاءِ - قَالَ - فَأَخَّرَ الصَّلاَةَ يَوْمًا ثُمَّ خَرَجَ فَصَلَّى الظُّهْرَ وَالْعَصْرَ جَمِيعًا ثُمَّ دَخَلَ ثُمَّ خَرَجَ فَصَلَّى الْمَغْرِبَ وَالْعِشَاءَ جَمِيعًا ثُمَّ قَالَ ‏"‏ إِنَّكُمْ سَتَأْتُونَ غَدًا إِنْ شَاءَ اللَّهُ عَيْنَ تَبُوكَ وَإِنَّكُمْ لَنْ تَأْتُوهَا حَتَّى يَضْحَى النَّهَارُ فَمَنْ جَاءَهَا فَلاَ يَمَسَّ مِنْ مَائِهَا شَيْئًا حَتَّى آتِيَ ‏"‏ ‏.‏ فَجِئْنَاهَا وَقَدْ سَبَقَنَا إِلَيْهَا رَجُلاَنِ وَالْعَيْنُ تَبِضُّ بِشَىْءٍ مِنْ مَاءٍ فَسَأَلَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ مَسِسْتُمَا مِنْ مَائِهَا شَيْئًا ‏"‏ ‏.‏ فَقَالاَ نَعَمْ ‏.‏ فَسَبَّهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ لَهُمَا مَا شَاءَ اللَّهُ أَنْ يَقُولَ ثُمَّ غَرَفُوا بِأَيْدِيهِمْ مِنَ الْعَيْنِ قَلِيلاً قَلِيلاً حَتَّى اجْتَمَعَ فِي شَىْءٍ ثُمَّ غَسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِيهِ وَجْهَهُ وَيَدَيْهِ ثُمَّ أَعَادَهُ فِيهَا فَجَرَتِ الْعَيْنُ بِمَاءٍ كَثِيرٍ فَاسْتَقَى النَّاسُ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُوشِكُ يَا مُعَاذُ إِنْ طَالَتْ بِكَ حَيَاةٌ أَنْ تَرَى هَا هُنَا قَدْ مُلِئَ جِنَانًا ‏"‏ ‏.‏\hadithno{327}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zubayr al-Makki from Abu't-Tufayl Amir ibn Wathila that Muadh ibn Jabal told him that they went out with the Messenger of Allah, may Allah bless him and grant him peace, in the year of Tabuk, and the Messenger of Allah, may Allah bless him and grant him peace, joined dhuhr with asr and maghrib with isha. Muadh said, "One day he delayed the prayer, and then came out and prayed dhuhr and asr together. Then he said, 'Tomorrow you will come, insha' llah, to the spring of Tabuk. But you will not get there until well into the morning. No one who arrives should touch any of its water until I come.' We came to it and two men had got to it before us and the spring was dripping with a little water. The Messenger of Allah, may Allah bless him and grant him peace, asked them, 'Have you touched any of its water?' They said, 'Yes.' The Messenger of Allah, may Allah bless him and grant him peace, reviled them and said what Allah wished him to say. Then they took water with their hands from the spring little by little until it had been collected in something. Then the Messenger of Allah, may Allah bless him and grant him peace, washed his face and hands in it. Then he put it back into the spring and the spring flowed with an abundance of water and the people drew water from it. The Messenger of Allah, may Allah bless him and grant him peace, said, 'If you live long enough, Muadh, you will soon see this place filled with gardens}}
\hadithdefcmd{malik}{328}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا عَجِلَ بِهِ السَّيْرُ يَجْمَعُ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ ‏.‏\hadithno{328}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar said, "The Messenger of Allah, may Allah bless him and grant him peace, used to join maghrib and isha together when it was urgent to travel}}
\hadithdefcmd{malik}{329}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الظُّهْرَ وَالْعَصْرَ جَمِيعًا وَالْمَغْرِبَ وَالْعِشَاءَ جَمِيعًا فِي غَيْرِ خَوْفٍ وَلاَ سَفَرٍ ‏.‏\hadithno{329}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zubayr al-Makki from Said ibn Jubayr that Abdullah ibn Abbas said, "The Messenger of Allah, may Allah bless him and grant him peace, prayed dhuhr and asr together and maghrib and isha together, and not out of fear nor because of travelling}}
\hadithdefcmd{malik}{330}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا جَمَعَ الأُمَرَاءُ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ فِي الْمَطَرِ جَمَعَ مَعَهُمْ ‏.‏\hadithno{330}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{(with regards to above) Malik said, "I believe that was during rain." Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to join the prayer along with the amirs if they joined maghrib and isha in the rain}}
\hadithdefcmd{malik}{331}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ سَأَلَ سَالِمَ بْنَ عَبْدِ اللَّهِ هَلْ يُجْمَعُ بَيْنَ الظُّهْرِ وَالْعَصْرِ فِي السَّفَرِ فَقَالَ نَعَمْ لاَ بَأْسَ بِذَلِكَ أَلَمْ تَرَ إِلَى صَلاَةِ النَّاسِ بِعَرَفَةَ\hadithno{331}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that he had asked Salim ibn Abdullah, "Can you join dhuhr and asr when travelling?" He said, "Yes, there is no harm in that. Haven't you seen the people pray on Arafa?}}
\hadithdefcmd{malik}{332}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ عَلِيِّ بْنِ حُسَيْنٍ، أَنَّهُ كَانَ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَسِيرَ يَوْمَهُ جَمَعَ بَيْنَ الظُّهْرِ وَالْعَصْرِ وَإِذَا أَرَادَ أَنْ يَسِيرَ لَيْلَهُ جَمَعَ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ ‏.‏\hadithno{332}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that he had heard that AIi ibn Husain used to say, "The Messenger of Allah, may Allah bless him and grant him peace, would join dhuhr and asr if he wished to travel the same day, and he would join maghrib and isha if he wished to travel the same night}}
\hadithdefcmd{malik}{333}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ رَجُلٍ، مِنْ آلِ خَالِدِ بْنِ أَسِيدٍ أَنَّهُ سَأَلَ عَبْدَ اللَّهِ بْنَ عُمَرَ فَقَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ إِنَّا نَجِدُ صَلاَةَ الْخَوْفِ وَصَلاَةَ الْحَضَرِ فِي الْقُرْآنِ وَلاَ نَجِدُ صَلاَةَ السَّفَرِ فَقَالَ ابْنُ عُمَرَ يَا ابْنَ أَخِي إِنَّ اللَّهَ عَزَّ وَجَلَّ بَعَثَ إِلَيْنَا مُحَمَّدًا صلى الله عليه وسلم وَلاَ نَعْلَمُ شَيْئًا فَإِنَّمَا نَفْعَلُ كَمَا رَأَيْنَاهُ يَفْعَلُ ‏.‏\hadithno{333}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from a man of the family of Khalid ibn Asid that he said to Abdullah ibn Umar, "Abu Abd ar-Rahman, we find the fear prayer and the prayer when settled mentioned in the Qur'an, but we do not find any mention of the travelling prayer in it." Ibn Umar said, "Son of my brother! Allah the Mighty and Majestic sent us Muhammad, may Allah bless him and grant him peace, and we know nothing. We only do as we saw him doing}}
\hadithdefcmd{malik}{334}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ فُرِضَتِ الصَّلاَةُ رَكْعَتَيْنِ رَكْعَتَيْنِ فِي الْحَضَرِ وَالسَّفَرِ فَأُقِرَّتْ صَلاَةُ السَّفَرِ وَزِيدَ فِي صَلاَةِ الْحَضَرِ ‏.‏\hadithno{334}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Salih ibn Kaysan from Urwa ibn az-Zubayr that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "The prayer was prescribed as two rakas, both when settled and when travelling. Then the travelling prayer was kept as it was, and an increase was made in the prayer when settled}}
\hadithdefcmd{malik}{335}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ لِسَالِمِ بْنِ عَبْدِ اللَّهِ مَا أَشَدَّ مَا رَأَيْتَ أَبَاكَ أَخَّرَ الْمَغْرِبَ فِي السَّفَرِ فَقَالَ سَالِمٌ غَرَبَتِ الشَّمْسُ وَنَحْنُ بِذَاتِ الْجَيْشِ فَصَلَّى الْمَغْرِبَ بِالْعَقِيقِ ‏.‏\hadithno{335}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that he said to Salim ibn Abdullah, "What is the latest you have seen your father delay maghrib while on a journey?" and Salim replied, "One time the sun set when we were at Dhat al-Jaysh and he prayed maghrib at al- Aqiq}}
\hadithdefcmd{malik}{336}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا خَرَجَ حَاجًّا أَوْ مُعْتَمِرًا قَصَرَ الصَّلاَةَ بِذِي الْحُلَيْفَةِ ‏.‏\hadithno{336}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar, shortened the prayer when he left for hajj or umra at Dhu'l Hulayfa}}
\hadithdefcmd{malik}{337}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّهُ رَكِبَ إِلَى رِيمٍ فَقَصَرَ الصَّلاَةَ فِي مَسِيرِهِ ذَلِكَ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ نَحْوٌ مِنْ أَرْبَعَةِ بُرُدٍ ‏.‏\hadithno{337}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah that his father rode to Rim and shortened the prayer on the journey. Malik said, "That was about four mail-stages." (approximately forty-eight miles)}}
\hadithdefcmd{malik}{338}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، رَكِبَ إِلَى ذَاتِ النُّصُبِ فَقَصَرَ الصَّلاَةَ فِي مَسِيرِهِ ذَلِكَ ‏.‏ قَالَ مَالِكٌ وَبَيْنَ ذَاتِ النُّصُبِ وَالْمَدِينَةِ أَرْبَعَةُ بُرُدٍ ‏.‏\hadithno{338}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Salim ibn Abdullah that Abdullah ibn Umar rode to Dhat an-Nusub and shortened the prayer on the journey. Malik said, "There are four mail-stages between Dhat an-Nusub and Madina}}
\hadithdefcmd{malik}{339}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَانَ يُسَافِرُ إِلَى خَيْبَرَ فَيَقْصُرُ الصَّلاَةَ ‏.‏\hadithno{339}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Ibn Umar that he used to travel to Khaybar and he would shorten the prayer}}
\hadithdefcmd{malik}{340}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقْصُرُ الصَّلاَةَ فِي مَسِيرِهِ الْيَوْمَ التَّامَّ ‏.‏\hadithno{340}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah that Abdullah ibn Umar used to shorten the prayer when he travelled for a whole day}}
\hadithdefcmd{malik}{341}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّهُ كَانَ يُسَافِرُ مَعَ ابْنِ عُمَرَ الْبَرِيدَ فَلاَ يَقْصُرُ الصَّلاَةَ ‏.‏\hadithno{341}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that he used to travel one mail-stage with Ibn Umar, and he would not shorten the prayer}}
\hadithdefcmd{malik}{342}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، كَانَ يَقْصُرُ الصَّلاَةَ فِي مِثْلِ مَا بَيْنَ مَكَّةَ وَالطَّائِفِ وَفِي مِثْلِ مَا بَيْنَ مَكَّةَ وَعُسْفَانَ وَفِي مِثْلِ مَا بَيْنَ مَكَّةَ وَجُدَّةَ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ أَرْبَعَةُ بُرُدٍ وَذَلِكَ أَحَبُّ مَا تُقْصَرُ إِلَىَّ فِيهِ الصَّلاَةُ ‏.‏ قَالَ مَالِكٌ لاَ يَقْصُرُ الَّذِي يُرِيدُ السَّفَرَ الصَّلاَةَ حَتَّى يَخْرُجَ مِنْ بُيُوتِ الْقَرْيَةِ وَلاَ يُتِمُّ حَتَّى يَدْخُلَ أَوَّلَ بُيُوتِ الْقَرْيَةِ أَوْ يُقَارِبُ ذَلِكَ ‏.‏\hadithno{342}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Abbas used to shorten the prayer when he travelled a distance equivalent to that between Makka and Ta'if, and that between Makka and Usfan and that between Makka and Jedda. Malik said, "That is four mail-stages, and to me that is the most preferable distance for shortening the prayer." Malik said, "Someone who intends to travel does not shorten the prayer until he has left the houses of the village. And he does not do it in full until he comes to the first houses of the village, or is nearby}}
\hadithdefcmd{malik}{343}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ أُصَلِّي صَلاَةَ الْمُسَافِرِ مَا لَمْ أُجْمِعْ مُكْثًا وَإِنْ حَبَسَنِي ذَلِكَ اثْنَتَىْ عَشْرَةَ لَيْلَةً ‏.‏\hadithno{343}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah that Abdullah ibn Umar used to say, "I pray the prayerof a traveller as long as I am undecided whether to remain somewhere or not, even if I am detained for twelve nights}}
\hadithdefcmd{malik}{344}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، أَقَامَ بِمَكَّةَ عَشْرَ لَيَالٍ يَقْصُرُ الصَّلاَةَ إِلاَّ أَنْ يُصَلِّيَهَا مَعَ الإِمَامِ فَيُصَلِّيهَا بِصَلاَتِهِ ‏.‏\hadithno{344}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Ibn Umar stayed in Makka for ten nights, shortening the prayer, except when he prayed it behind an imam, in which case he followed the imam's prayer}}
\hadithdefcmd{malik}{345}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَطَاءٍ الْخُرَاسَانِيِّ، أَنَّهُ سَمِعَ سَعِيدَ بْنَ الْمُسَيَّبِ، قَالَ مَنْ أَجْمَعَ إِقَامَةً أَرْبَعَ لَيَالٍ وَهُوَ مُسَافِرٌ أَتَمَّ الصَّلاَةَ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ أَحَبُّ مَا سَمِعْتُ إِلَىَّ ‏.‏ وَسُئِلَ مَالِكٌ عَنْ صَلاَةِ الأَسِيرِ فَقَالَ مِثْلُ صَلاَةِ الْمُقِيمِ إِلاَّ أَنْ يَكُونَ مُسَافِرًا ‏.‏\hadithno{345}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Ata al-Khurasani that he heard Said ibn al Musayyab say, "A traveller who has decided to remain somewhere for four nights does the prayer in full." Malik said, "That is what I prefer most out of what I have heard." Malik when asked about the prayer of a prisoner, said, "It is the same as the prayer of a person who remains in one place, except if he is travelling}}
\hadithdefcmd{malik}{346}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ إِذَا قَدِمَ مَكَّةَ صَلَّى بِهِمْ رَكْعَتَيْنِ ثُمَّ يَقُولُ يَا أَهْلَ مَكَّةَ أَتِمُّوا صَلاَتَكُمْ فَإِنَّا قَوْمٌ سَفْرٌ ‏.‏\hadithno{346}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah from his father that Umar ibn al-Khattab, when he went to Makka, used to lead them in prayer and do two rakas and then say, "People of Makka,complete the prayer, we are a group travelling}}
\hadithdefcmd{malik}{347}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، مِثْلَ ذَلِكَ ‏.‏\hadithno{347}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related the same as that to me from Malik from Zayd ibn Aslam from his father from Umar ibn al-Khattab}}
\hadithdefcmd{malik}{348}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يُصَلِّي وَرَاءَ الإِمَامِ بِمِنًى أَرْبَعًا فَإِذَا صَلَّى لِنَفْسِهِ صَلَّى رَكْعَتَيْنِ ‏.‏\hadithno{348}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to pray four rakas behind the imam at Mina, and when he prayed by himself he would pray two rakas}}
\hadithdefcmd{malik}{349}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ صَفْوَانَ، أَنَّهُ قَالَ جَاءَ عَبْدُ اللَّهِ بْنُ عُمَرَ يَعُودُ عَبْدَ اللَّهِ بْنَ صَفْوَانَ فَصَلَّى لَنَا رَكْعَتَيْنِ ثُمَّ انْصَرَفَ فَقُمْنَا فَأَتْمَمْنَا ‏.‏\hadithno{349}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Safwan said, "Abdullah ibn Umar used to come and visit Abdullah ibn Safwan and he would pray two rakas with us, and when he went away we would stand and complete the prayer}}
\hadithdefcmd{malik}{350}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ لَمْ يَكُنْ يُصَلِّي مَعَ صَلاَةِ الْفَرِيضَةِ فِي السَّفَرِ شَيْئًا قَبْلَهَا وَلاَ بَعْدَهَا إِلاَّ مِنْ جَوْفِ اللَّيْلِ فَإِنَّهُ كَانَ يُصَلِّي عَلَى الأَرْضِ وَعَلَى رَاحِلَتِهِ حَيْثُ تَوَجَّهَتْ ‏.‏\hadithno{350}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar never used to pray anything with the fard prayer, either before it or after it, while travelling, except in the depths of the night. He would pray on the ground or on his mount, whichever way it was facing}}
\hadithdefcmd{malik}{351}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ، وَعُرْوَةَ بْنَ الزُّبَيْرِ، وَأَبَا، بَكْرِ بْنَ عَبْدِ الرَّحْمَنِ كَانُوا يَتَنَفَّلُونَ فِي السَّفَرِ ‏.‏ قَالَ يَحْيَى وَسُئِلَ مَالِكٌ عَنِ النَّافِلَةِ فِي السَّفَرِ فَقَالَ لاَ بَأْسَ بِذَلِكَ بِاللَّيْلِ وَالنَّهَارِ وَقَدْ بَلَغَنِي أَنَّ بَعْضَ أَهْلِ الْعِلْمِ كَانَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{351}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that al-Qasim ibn Muhammad and Urwa ibn az-Zubayr and Abu Bakr ibn Abd ar Rahman used to pray nawafil when travelling. Yahya said that Malik was asked about voluntary prayers when travelling and he said, "There is no harm in them, either at night or during the day. I have heard that some of the people of knowledge used to do that}}
\hadithdefcmd{malik}{352}{وَحَدَّثَنِي عَنْ مَالِكٍ، قَالَ بَلَغَنِي عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَرَى ابْنَهُ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ يَتَنَفَّلُ فِي السَّفَرِ فَلاَ يُنْكِرُ عَلَيْهِ ‏.‏\hadithno{352}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me that Malik said, "I have heard from Nafi that Abdullah ibn Umar used to see his son, Ubaydullah ibn Abdullah, doing voluntary prayers on a journey,and he would not disapprove of it}}
\hadithdefcmd{malik}{353}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ أَبِي الْحُبَابِ، سَعِيدِ بْنِ يَسَارٍ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي وَهُوَ عَلَى حِمَارٍ وَهُوَ مُتَوَجِّهٌ إِلَى خَيْبَرَ ‏.‏\hadithno{353}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Amr ibn Yahya al-Mazini from Abu'l-Hubab Said ibn Yasar that Abdullah ibn Umar said, "I saw the Messenger of Allah, may Allah bless him and grant him peace, praying on a donkey while heading towards Khaybar}}
\hadithdefcmd{malik}{354}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي عَلَى رَاحِلَتِهِ فِي السَّفَرِ حَيْثُ تَوَجَّهَتْ بِهِ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ دِينَارٍ وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{354}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, used to pray on his mount while travelling, whichever way it was facing. Abdullah ibn Dinar said, "Abdullah ibn Umar would also do that}}
\hadithdefcmd{malik}{355}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ رَأَيْتُ أَنَسَ بْنَ مَالِكٍ فِي السَّفَرِ وَهُوَ يُصَلِّي عَلَى حِمَارٍ وَهُوَ مُتَوَجِّهٌ إِلَى غَيْرِ الْقِبْلَةِ يَرْكَعُ وَيَسْجُدُ إِيمَاءً مِنْ غَيْرِ أَنْ يَضَعَ وَجْهَهُ عَلَى شَىْءٍ ‏.‏\hadithno{355}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said, "I saw Anas ibn Malik on a journey praying on a donkey facing away from the qibla. He did the raka and the sajda by motioning with his head, without putting his face on anything}}
\hadithdefcmd{malik}{356}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ مُوسَى بْنِ مَيْسَرَةَ، عَنْ أَبِي مُرَّةَ، مَوْلَى عَقِيلِ بْنِ أَبِي طَالِبٍ أَنَّ أُمَّ هَانِئٍ بِنْتَ أَبِي طَالِبٍ، أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى عَامَ الْفَتْحِ ثَمَانِيَ رَكَعَاتٍ مُلْتَحِفًا فِي ثَوْبٍ وَاحِدٍ ‏.‏\hadithno{356}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Musa ibn Maysara from Abu Murra, the mawla of Aqil ibn Abi Talib, that Umm Hani bint Abi Talib told him that in the year of the conquest the Messenger of Allah, may Allah bless him and grant him peace, prayed eight rakas, covering himself with one garment}}
\hadithdefcmd{malik}{357}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ أَنَّ أَبَا مُرَّةَ، مَوْلَى عَقِيلِ بْنِ أَبِي طَالِبٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ أُمَّ هَانِئٍ بِنْتَ أَبِي طَالِبٍ، تَقُولُ ذَهَبْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ فَوَجَدْتُهُ يَغْتَسِلُ وَفَاطِمَةُ ابْنَتُهُ تَسْتُرُهُ بِثَوْبٍ - قَالَتْ - فَسَلَّمْتُ عَلَيْهِ فَقَالَ ‏"‏ مَنْ هَذِهِ ‏"‏ ‏.‏ فَقُلْتُ أُمُّ هَانِئٍ بِنْتُ أَبِي طَالِبٍ ‏.‏ فَقَالَ ‏"‏ مَرْحَبًا بِأُمِّ هَانِئٍ ‏"‏ ‏.‏ فَلَمَّا فَرَغَ مِنْ غُسْلِهِ قَامَ فَصَلَّى ثَمَانِيَ رَكَعَاتٍ مُلْتَحِفًا فِي ثَوْبٍ وَاحِدٍ ثُمَّ انْصَرَفَ فَقُلْتُ يَا رَسُولَ اللَّهِ زَعَمَ ابْنُ أُمِّي عَلِيٌّ أَنَّهُ قَاتِلٌ رَجُلاً أَجَرْتُهُ فُلاَنُ بْنُ هُبَيْرَةَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ أَجَرْنَا مَنْ أَجَرْتِ يَا أُمَّ هَانِئٍ ‏"‏ ‏.‏ قَالَتْ أُمُّ هَانِئٍ وَذَلِكَ ضُحًى ‏.‏\hadithno{357}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'n Nadr, the mawla of Umar ibn Ubaydullah, that Abu Murra, the mawla of Aqil ibn Abi Talib, told him that he had heard Umm Hani bint Abi Talib say, "I went to the Messenger of Allah, may Allah bless him and grant him peace, in the year of the conquest and found him doing ghusl while his daughter Fatima, was screening him with a garment. I said to him, 'Peace be upon you' and he said, 'Who is that?' I replied, 'Umm Hani bint Abi Talib,' and he said, 'Welcome, Umm Hani!' When he had finished his ghusl, he stood and prayed eight rakas, covering himself with one garment, and then came away. I said, 'Messenger of Allah, the son of my mother, AIi, says that he is determined to kill so-and-so, son of Hubayra, a man I have placed under my protection.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'We give protection to whoever you have given protection to, Umm Hani.' " Umm Hani related that this incident happened in the morning}}
\hadithdefcmd{malik}{358}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي سُبْحَةَ الضُّحَى قَطُّ وَإِنِّي لأُسَبِّحُهَا وَإِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيَدَعُ الْعَمَلَ وَهُوَ يُحِبُّ أَنْ يَعْمَلَهُ خَشْيَةَ أَنْ يَعْمَلَ بِهِ النَّاسُ فَيُفْرَضَ عَلَيْهِمْ ‏.‏\hadithno{358}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Urwa ibn az- Zubayr that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "I never once saw the Messenger of Allah, may Allah bless him and grant him peace, doing the voluntary prayer of duha, but I myself do it. Sometimes the Messenger of Allah, may Allah bless him and grant him peace, would refrain from a practice that he loved to do, fearing that people would do the same and it would become fard for them}}
\hadithdefcmd{malik}{359}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَائِشَةَ، أَنَّهَا كَانَتْ تُصَلِّي الضُّحَى ثَمَانِيَ رَكَعَاتٍ ثُمَّ تَقُولُ لَوْ نُشِرَ لِي أَبَوَاىَ مَا تَرَكْتُهُنَّ ‏.‏\hadithno{359}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from A'isha that she used to pray duha with eight rakas, and she would say, "I would never stop doing them even if my parents were to be brought back to life}}
\hadithdefcmd{malik}{360}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ جَدَّتَهُ، مُلَيْكَةَ دَعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم لِطَعَامٍ فَأَكَلَ مِنْهُ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قُومُوا فَلأُصَلِّيَ لَكُمْ ‏"‏ ‏.‏ قَالَ أَنَسٌ فَقُمْتُ إِلَى حَصِيرٍ لَنَا قَدِ اسْوَدَّ مِنْ طُولِ مَا لُبِسَ فَنَضَحْتُهُ بِمَاءٍ فَقَامَ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَصَفَفْتُ أَنَا وَالْيَتِيمُ وَرَاءَهُ وَالْعَجُوزُ مِنْ وَرَائِنَا فَصَلَّى لَنَا رَكْعَتَيْنِ ثُمَّ انْصَرَفَ ‏.‏\hadithno{360}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ishaq ibn Abdullah ibn Abi Talha from Anas ibn Malik that his grandmother, Mulayka, invited the Messenger of Allah, may Allah bless him and grant him peace, for food and he ate some of it. Then the Messenger of Allah, may Allah bless him and grant him peace, said, "Get up and I will lead you in prayer." Anas said, "I stood up and took a woven mat belonging to us that had become black through long use and sprinkled it with water, and the Messengerof Allah, may Allah bless him and grant him peace, stood on it. The orphan and I formed a row behind him, and the old woman stood behind us. He prayed two rakas with us and then left}}
\hadithdefcmd{malik}{361}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّهُ قَالَ دَخَلْتُ عَلَى عُمَرَ بْنِ الْخَطَّابِ بِالْهَاجِرَةِ فَوَجَدْتُهُ يُسَبِّحُ فَقُمْتُ وَرَاءَهُ فَقَرَّبَنِي حَتَّى جَعَلَنِي حِذَاءَهُ عَنْ يَمِينِهِ فَلَمَّا جَاءَ يَرْفَأُ تَأَخَّرْتُ فَصَفَفْنَا وَرَاءَهُ ‏.‏\hadithno{361}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Ubaydullah ibn Abdullah ibn Utba said, "I visited Umar ibn al-Khattab just before noon and found him praying a voluntary prayer. So I stood behind him, but he pulled me nearer and put me next to him, on his right hand side, and then Yarfa came and I moved back and we formed a row behind him}}
\hadithdefcmd{malik}{362}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانَ أَحَدُكُمْ يُصَلِّي فَلاَ يَدَعْ أَحَدًا يَمُرُّ بَيْنَ يَدَيْهِ وَلْيَدْرَأْهُ مَا اسْتَطَاعَ فَإِنْ أَبَى فَلْيُقَاتِلْهُ فَإِنَّمَا هُوَ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{362}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Abd ar- Rahman ibn Abi Said al-Khudri from his father that the Messenger of Allah, may Allah bless him and grant him peace, said, "Do not let anyone pass in front of you when you are praying. Repel him as much as you can, and, if he refuses, fight him, for he is only a shaytan}}
\hadithdefcmd{malik}{363}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ بُسْرِ بْنِ سَعِيدٍ، أَنَّ زَيْدَ بْنَ خَالِدٍ الْجُهَنِيَّ، أَرْسَلَهُ إِلَى أَبِي جُهَيْمٍ يَسْأَلُهُ مَاذَا سَمِعَ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْمَارِّ بَيْنَ يَدَىِ الْمُصَلِّي فَقَالَ أَبُو جُهَيْمٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ يَعْلَمُ الْمَارُّ بَيْنَ يَدَىِ الْمُصَلِّي مَاذَا عَلَيْهِ لَكَانَ أَنْ يَقِفَ أَرْبَعِينَ خَيْرًا لَهُ مِنْ أَنْ يَمُرَّ بَيْنَ يَدَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو النَّضْرِ لاَ أَدْرِي أَقَالَ أَرْبَعِينَ يَوْمًا أَوْ شَهْرًا أَوْ سَنَةً ‏.‏\hadithno{363}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'n Nadr, the mawla of Umar ibn Ubaydullah from Busr ibn Said that Zayd ibn Khalid al-Juhani sent him to Abu Juhaym to ask him what he had heard from the Messenger of Allah, may Allah bless him and grant him peace, about passing in front of someone praying. Abu Juhaym said, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'If the one who passes in front of a man praying knew what he was bringing upon himself it would be better for him to stop for forty than to pass in front of him.' " Abu'n-Nadr said, "I do not know whether he said forty days or months or years}}
\hadithdefcmd{malik}{364}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ كَعْبَ الأَحْبَارِ، قَالَ لَوْ يَعْلَمُ الْمَارُّ بَيْنَ يَدَىِ الْمُصَلِّي مَاذَا عَلَيْهِ لَكَانَ أَنْ يُخْسَفَ بِهِ خَيْرًا لَهُ مِنْ أَنْ يَمُرَّ بَيْنَ يَدَيْهِ ‏.‏\hadithno{364}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar that Kab al-Ahbar said, "If the person who passed in front of a man praying knew what he was bringing on himself, it would be better for him to sink into the ground than to pass in front of him}}
\hadithdefcmd{malik}{365}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَكْرَهُ أَنْ يَمُرَّ، بَيْنَ أَيْدِي النِّسَاءِ وَهُنَّ يُصَلِّينَ ‏.‏\hadithno{365}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Umar used to disapprove of passing in front of women while they were praying}}
\hadithdefcmd{malik}{366}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ لاَ يَمُرُّ بَيْنَ يَدَىْ أَحَدٍ وَلاَ يَدَعُ أَحَدًا يَمُرُّ بَيْنَ يَدَيْهِ ‏.‏\hadithno{366}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar would neither pass in front of anyone, nor let anyone pass in front of him}}
\hadithdefcmd{malik}{367}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ قَالَ أَقْبَلْتُ رَاكِبًا عَلَى أَتَانٍ - وَأَنَا يَوْمَئِذٍ قَدْ نَاهَزْتُ الاِحْتِلاَمَ - وَرَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي لِلنَّاسِ بِمِنًى فَمَرَرْتُ بَيْنَ يَدَىْ بَعْضِ الصَّفِّ فَنَزَلْتُ فَأَرْسَلْتُ الأَتَانَ تَرْتَعُ وَدَخَلْتُ فِي الصَّفِّ فَلَمْ يُنْكِرْ ذَلِكَ عَلَىَّ أَحَدٌ ‏.‏\hadithno{367}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Ubaydullah ibn Abdullah ibn Utba ibn Masud that Abdullah ibn Abbas said, "I approached, riding on a donkey, while the Messenger of Allah, may Allah bless him and grant him peace, was leading the people in prayer at Mina, and I was, at that time, nearing puberty. I passed in front of part of the row, dismounted, sent the donkey off to graze, and then joined the row, and no one rebuked me for doing so}}
\hadithdefcmd{malik}{368}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَعْدَ بْنَ أَبِي وَقَّاصٍ، كَانَ يَمُرُّ بَيْنَ يَدَىْ بَعْضِ الصُّفُوفِ وَالصَّلاَةُ قَائِمَةٌ ‏.‏ قَالَ مَالِكٌ وَأَنَا أَرَى ذَلِكَ وَاسِعًا إِذَا أُقِيمَتِ الصَّلاَةُ وَبَعْدَ أَنْ يُحْرِمَ الإِمَامُ وَلَمْ يَجِدِ الْمَرْءُ مَدْخَلاً إِلَى الْمَسْجِدِ إِلاَّ بَيْنَ الصُّفُوفِ ‏.‏\hadithno{368}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn Abi Waqqas used to pass in front of some of the rows while the prayer was in progress. Malik said, "I consider that it is permissible to do that if the iqama for the prayer has been said and the imam has said the initial takbir and a man cannot find any way into the mosque except by going between the rows}}
\hadithdefcmd{malik}{369}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ، قَالَ لاَ يَقْطَعُ الصَّلاَةَ شَىْءٌ مِمَّا يَمُرُّ بَيْنَ يَدَىِ الْمُصَلِّي ‏.‏\hadithno{369}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Ali ibn Abi Talib said, "Things that pass in front of a man praying do not break his prayer}}
\hadithdefcmd{malik}{370}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ لاَ يَقْطَعُ الصَّلاَةَ شَىْءٌ مِمَّا يَمُرُّ بَيْنَ يَدَىِ الْمُصَلِّي ‏.‏\hadithno{370}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah that Abdullah ibn Umar used to say, "Things that pass in front of a man praying do not break his prayer}}
\hadithdefcmd{malik}{371}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَسْتَتِرُ بِرَاحِلَتِهِ إِذَا صَلَّى ‏.‏\hadithno{371}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Umar would use the animal he was riding as a sutra when he prayed}}
\hadithdefcmd{malik}{372}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّ أَبَاهُ، كَانَ يُصَلِّي فِي الصَّحْرَاءِ إِلَى غَيْرِ سُتْرَةٍ ‏.‏\hadithno{372}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa that his father used to pray in the desert without a sutra}}
\hadithdefcmd{malik}{373}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي جَعْفَرٍ الْقَارِئِ، أَنَّهُ قَالَ رَأَيْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ إِذَا أَهْوَى لِيَسْجُدَ مَسَحَ الْحَصْبَاءَ لِمَوْضِعِ جَبْهَتِهِ مَسْحًا خَفِيفًا ‏.‏\hadithno{373}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Abu Jafar al-Qari said, "I saw Abdullah ibn Umar quickly brush away the small stones from the place where he was going to put his forehead as he was going down into sajda}}
\hadithdefcmd{malik}{374}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ بَلَغَهُ أَنَّ أَبَا ذَرٍّ، كَانَ يَقُولُ مَسْحُ الْحَصْبَاءِ مَسْحَةً وَاحِدَةً وَتَرْكُهَا خَيْرٌ مِنْ حُمْرِ النَّعَمِ ‏.‏\hadithno{374}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that he had heard that Abu Dharr used to say, "Brush away the small stones with one sweep, but if you leave them it is better than a red camel}}
\hadithdefcmd{malik}{375}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ يَأْمُرُ بِتَسْوِيَةِ الصُّفُوفِ فَإِذَا جَاءُوهُ فَأَخْبَرُوهُ أَنْ قَدِ اسْتَوَتْ كَبَّرَ ‏.‏\hadithno{375}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Umar ibn al-Khattab used to order the rows to be straightened, and when they had come to him and told him that the rows were straight he would say the takbir}}
\hadithdefcmd{malik}{376}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَمِّهِ أَبِي سُهَيْلِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّهُ قَالَ كُنْتُ مَعَ عُثْمَانَ بْنِ عَفَّانَ فَقَامَتِ الصَّلاَةُ وَأَنَا أُكَلِّمُهُ، فِي أَنْ يَفْرِضَ، لِي فَلَمْ أَزَلْ أُكَلِّمُهُ وَهُوَ يُسَوِّي الْحَصْبَاءَ بِنَعْلَيْهِ حَتَّى جَاءَهُ رِجَالٌ قَدْ كَانَ وَكَلَهُمْ بِتَسْوِيَةِ الصُّفُوفِ ‏.‏ فَأَخْبَرُوهُ أَنَّ الصُّفُوفَ قَدِ اسْتَوَتْ فَقَالَ لِي اسْتَوِ فِي الصَّفِّ ‏.‏ ثُمَّ كَبَّرَ ‏.‏\hadithno{376}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from his paternal uncle, Abu Suhayl ibn Malik, that his father said, "I was with Uthman ibn Affan when the iqama was said for the prayer and I was talking to him about being assigned a definite allowance by him. I continued talking to him while he was levelling some small stones with his sandals, and then some men that he had entrusted to straighten the rows came and told him that the rows were straight. He said to me, 'Line up in the row,' and then he said the takbir}}
\hadithdefcmd{malik}{377}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الْكَرِيمِ بْنِ أَبِي الْمُخَارِقِ الْبَصْرِيِّ، أَنَّهُ قَالَ مِنْ كَلاَمِ النُّبُوَّةِ إِذَا لَمْ تَسْتَحِي فَافْعَلْ مَا شِئْتَ وَوَضْعُ الْيَدَيْنِ إِحْدَاهُمَا عَلَى الأُخْرَى فِي الصَّلاَةِ يَضَعُ الْيُمْنَى عَلَى الْيُسْرَى وَتَعْجِيلُ الْفِطْرِ وَالاِسْتِينَاءُ بِالسَّحُورِ ‏.‏\hadithno{377}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Abd al-Karim ibn Abi'l-Mukhariq al-Basri said, "Among things the Prophet, may Allah bless him and grant him peace, said and did are:'As long as you do not feel ashamed, do whatever you wish', the placing of one hand on the other in prayer (one places the right hand on the left), being quick to break the fast, and delaying the meal before dawn}}
\hadithdefcmd{malik}{378}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي حَازِمِ بْنِ دِينَارٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّهُ قَالَ كَانَ النَّاسُ يُؤْمَرُونَ أَنْ يَضَعَ الرَّجُلُ الْيَدَ الْيُمْنَى عَلَى ذِرَاعِهِ الْيُسْرَى فِي الصَّلاَةِ ‏.‏ قَالَ أَبُو حَازِمٍ لاَ أَعْلَمُ إِلاَّ أَنَّهُ يَنْمِي ذَلِكَ ‏.‏\hadithno{378}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu Hazim ibn Dinar that Sahl ibn Sad said, "People used to be ordered to place their right hands on their left forearms in the prayer." Abu Hazim added, "I know for sure that Sahl traces that back to the Prophet, may Allah bless him and grant him peace}}
\hadithdefcmd{malik}{379}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ لاَ يَقْنُتُ فِي شَىْءٍ مِنَ الصَّلاَةِ ‏.‏\hadithno{379}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar did not say qunut in any of the prayers}}
\hadithdefcmd{malik}{380}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ عَبْدَ اللَّهِ بْنَ الأَرْقَمِ، كَانَ يَؤُمُّ أَصْحَابَهُ فَحَضَرَتِ الصَّلاَةُ يَوْمًا فَذَهَبَ لِحَاجَتِهِ ثُمَّ رَجَعَ فَقَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا أَرَادَ أَحَدُكُمُ الْغَائِطَ فَلْيَبْدَأْ بِهِ قَبْلَ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{380}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that Abdullah ibn al-Arqam used to lead his companions in prayer. The time for prayer came one day and he went to relieve himself. When he returned, he said, "I heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'If you wish to defecate, you should do so before the prayer}}
\hadithdefcmd{malik}{381}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ لاَ يُصَلِّيَنَّ أَحَدُكُمْ وَهُوَ ضَامٌّ بَيْنَ وَرِكَيْهِ ‏.‏\hadithno{381}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that Umar ibn al-Khattab said, "You should not pray while you are holding your bowels}}
\hadithdefcmd{malik}{382}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَلاَئِكَةُ تُصَلِّي عَلَى أَحَدِكُمْ مَا دَامَ فِي مُصَلاَّهُ الَّذِي صَلَّى فِيهِ مَا لَمْ يُحْدِثِ اللَّهُمَّ اغْفِرْ لَهُ اللَّهُمَّ ارْحَمْهُ ‏"‏ ‏.‏\hadithno{382}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "The angels ask for blessings on each one of you as long as he is in the place where he has prayed and has not discharged anything. They say, 'Allah, forgive him. Allah have mercy on him}}
\hadithdefcmd{malik}{383}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَزَالُ أَحَدُكُمْ فِي صَلاَةٍ مَا كَانَتِ الصَّلاَةُ تَحْبِسُهُ لاَ يَمْنَعُهُ أَنْ يَنْقَلِبَ إِلَى أَهْلِهِ إِلاَّ الصَّلاَةُ ‏"‏ ‏.‏\hadithno{383}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik said, "I do not consider that his words, 'has not discharged anything' refer to anything other than the discharges that break wudu." Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "You are in prayer as long as the prayer detains you and there is nothing that prevents you from returning to your family except the prayer}}
\hadithdefcmd{malik}{384}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ أَنَّ أَبَا بَكْرِ بْنَ عَبْدِ الرَّحْمَنِ، كَانَ يَقُولُ مَنْ غَدَا أَوْ رَاحَ إِلَى الْمَسْجِدِ لاَ يُرِيدُ غَيْرَهُ لِيَتَعَلَّمَ خَيْرًا أَوْ لِيُعَلِّمَهُ ثُمَّ رَجَعَ إِلَى بَيْتِهِ كَانَ كَالْمُجَاهِدِ فِي سَبِيلِ اللَّهِ رَجَعَ غَانِمًا ‏.‏\hadithno{384}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Sumayy, the mawla of Abu Bakr, that Abu Bakr ibn Abd ar-Rahman used to say, "Someone who goes to the mosque in the morning or the afternoon with no intention of going anywhere else, either to learn good or teach it, is like someone who does jihad in the way of Allah and returns with booty}}
\hadithdefcmd{malik}{385}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نُعَيْمِ بْنِ عَبْدِ اللَّهِ الْمُجْمِرِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ إِذَا صَلَّى أَحَدُكُمْ ثُمَّ جَلَسَ فِي مُصَلاَّهُ لَمْ تَزَلِ الْمَلاَئِكَةُ تُصَلِّي عَلَيْهِ اللَّهُمَّ اغْفِرْ لَهُ اللَّهُمَّ ارْحَمْهُ فَإِنْ قَامَ مِنْ مُصَلاَّهُ فَجَلَسَ فِي الْمَسْجِدِ يَنْتَظِرُ الصَّلاَةَ لَمْ يَزَلْ فِي صَلاَةٍ حَتَّى يُصَلِّيَ ‏.‏\hadithno{385}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nuaym ibn Abdullah al-Mujmir that he heard Abu Hurayra say, "If any one of you prays and then sits down in the spot where he has prayed, the angels ask blessings on him saying, 'Allah, forgive him. Allah, have mercy on him.' And if he moves from the spot where he has prayed and sits elsewhere in the mosque waiting for the prayer, he remains in prayer until he prays}}
\hadithdefcmd{malik}{386}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَعْقُوبَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ أُخْبِرُكُمْ بِمَا يَمْحُو اللَّهُ بِهِ الْخَطَايَا وَيَرْفَعُ بِهِ الدَّرَجَاتِ إِسْبَاغُ الْوُضُوءِ عِنْدَ الْمَكَارِهِ وَكَثْرَةُ الْخُطَا إِلَى الْمَسَاجِدِ وَانْتِظَارُ الصَّلاَةِ بَعْدَ الصَّلاَةِ فَذَلِكُمُ الرِّبَاطُ فَذَلِكُمُ الرِّبَاطُ فَذَلِكُمُ الرِّبَاطُ ‏"‏ ‏.‏\hadithno{386}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from al Ala ibn Abd ar-Rahman ibn Yaqub from his father from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Shall I tell you the things by which Allah erases wrong actions and by which he raises ranks:the complete and correct performance of wudu in adverse conditions, a great number of steps towards the mosque,and waiting after one prayer for the next prayer. That is the firm hold, that is the firm hold, that is the firm hold}}
\hadithdefcmd{malik}{387}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، قَالَ يُقَالُ لاَ يَخْرُجُ أَحَدٌ مِنَ الْمَسْجِدِ بَعْدَ النِّدَاءِ - إِلاَّ أَحَدٌ يُرِيدُ الرُّجُوعَ إِلَيْهِ - إِلاَّ مُنَافِقٌ ‏.‏\hadithno{387}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn al-Musayyab said, "It is said that no-one except a hypocrite leaves the mosque after the call to prayer, except for someone who intends to return}}
\hadithdefcmd{malik}{388}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، عَنْ أَبِي قَتَادَةَ الأَنْصَارِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دَخَلَ أَحَدُكُمُ الْمَسْجِدَ فَلْيَرْكَعْ رَكْعَتَيْنِ قَبْلَ أَنْ يَجْلِسَ ‏"‏ ‏.‏\hadithno{388}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Amir ibn Abdullah ibn az- Zubayr from Amr ibn Sulaymaz-Zuraqi from Abu Qatadaal-Ansari that the Messenger of Allah, may Allah bless him and grant him peace, said, "When you enter the mosque, you should pray two rakas before you sit down}}
\hadithdefcmd{malik}{389}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ قَالَ لَهُ أَلَمْ أَرَ صَاحِبَكَ إِذَا دَخَلَ الْمَسْجِدَ يَجْلِسُ قَبْلَ أَنْ يَرْكَعَ قَالَ أَبُو النَّضْرِ يَعْنِي بِذَلِكَ عُمَرَ بْنَ عُبَيْدِ اللَّهِ وَيَعِيبُ ذَلِكَ عَلَيْهِ أَنْ يَجْلِسَ إِذَا دَخَلَ الْمَسْجِدَ قَبْلَ أَنْ يَرْكَعَ ‏.‏ قَالَ يَحْيَى قَالَ مَالِكٌ وَذَلِكَ حَسَنٌ وَلَيْسَ بِوَاجِبٍ ‏.‏\hadithno{389}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Abu'nNadr, the mawla of Umar ibn Ubaydullah, that Abu Salama ibn Abd ar-Rahman asked him, "Didn't I see your master sit down before praying after he had entered the mosque?" Abu'n-Nadr said, "By that he meant Umar ibn Ubaydullah, and he was finding fault with him for sitting down before praying after he had come into the mosque." Yahya said that Malik said, "It is good to do that but not obligatory}}
\hadithdefcmd{malik}{390}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا سَجَدَ وَضَعَ كَفَّيْهِ عَلَى الَّذِي يَضَعُ عَلَيْهِ جَبْهَتَهُ ‏.‏ قَالَ نَافِعٌ وَلَقَدْ رَأَيْتُهُ فِي يَوْمٍ شَدِيدِ الْبَرْدِ وَإِنَّهُ لَيُخْرِجُ كَفَّيْهِ مِنْ تَحْتِ بُرْنُسٍ لَهُ حَتَّى يَضَعَهُمَا عَلَى الْحَصْبَاءِ ‏.‏\hadithno{390}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to place his palms flat on the surface where he put his forehead. Nafi said, "I have seen him take his hands out from under his burnus on a very cold day and place them on the ground}}
\hadithdefcmd{malik}{391}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ مَنْ وَضَعَ جَبْهَتَهُ بِالأَرْضِ فَلْيَضَعْ كَفَّيْهِ عَلَى الَّذِي يَضَعُ عَلَيْهِ جَبْهَتَهُ ثُمَّ إِذَا رَفَعَ فَلْيَرْفَعْهُمَا فَإِنَّ الْيَدَيْنِ تَسْجُدَانِ كَمَا يَسْجُدُ الْوَجْهُ ‏.‏\hadithno{391}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "When one of you puts his forehead on the ground he should put his palms on the place where he puts his forehead. Then, when he rises, he should raise them, for the hands prostrate just as the face prostrates}}
\hadithdefcmd{malik}{392}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي حَازِمٍ، سَلَمَةَ بْنِ دِينَارٍ عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَهَبَ إِلَى بَنِي عَمْرِو بْنِ عَوْفٍ لِيُصْلِحَ بَيْنَهُمْ وَحَانَتِ الصَّلاَةُ فَجَاءَ الْمُؤَذِّنُ إِلَى أَبِي بَكْرٍ الصِّدِّيقِ فَقَالَ أَتُصَلِّي لِلنَّاسِ فَأُقِيمَ قَالَ نَعَمْ ‏.‏ فَصَلَّى أَبُو بَكْرٍ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ فِي الصَّلاَةِ فَتَخَلَّصَ حَتَّى وَقَفَ فِي الصَّفِّ فَصَفَّقَ النَّاسُ وَكَانَ أَبُو بَكْرٍ لاَ يَلْتَفِتُ فِي صَلاَتِهِ فَلَمَّا أَكْثَرَ النَّاسُ مِنَ التَّصْفِيقِ الْتَفَتَ أَبُو بَكْرٍ فَرَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَشَارَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنِ امْكُثْ مَكَانَكَ فَرَفَعَ أَبُو بَكْرٍ يَدَيْهِ فَحَمِدَ اللَّهَ عَلَى مَا أَمَرَهُ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ ذَلِكَ ثُمَّ اسْتَأْخَرَ حَتَّى اسْتَوَى فِي الصَّفِّ وَتَقَدَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى ثُمَّ انْصَرَفَ فَقَالَ ‏"‏ يَا أَبَا بَكْرٍ مَا مَنَعَكَ أَنْ تَثْبُتَ إِذْ أَمَرْتُكَ ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ مَا كَانَ لاِبْنِ أَبِي قُحَافَةَ أَنْ يُصَلِّيَ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا لِي رَأَيْتُكُمْ أَكْثَرْتُمْ مِنَ التَّصْفِيحِ مَنْ نَابَهُ شَىْءٌ فِي صَلاَتِهِ فَلْيُسَبِّحْ فَإِنَّهُ إِذَا سَبَّحَ الْتُفِتَ إِلَيْهِ وَإِنَّمَا التَّصْفِيحُ لِلنِّسَاءِ ‏"‏ ‏.‏\hadithno{392}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu Hazim Salama ibn Dinar from Sahl ibn Said as-Saidi that the Messenger of Allah, may Allah bless him and grant him peace, went to the tribe of Bani Amr ibn Awf to settle their disputes .The time for the prayer came and the muadhdhin came to Abu Bakr as-Siddiq and said, "Could you lead the people in prayer and I will say the iqama?" He said, "Yes," and Abu Bakr prayed. The Messenger of Allah, may Allah bless him and grant him peace, came back while the people were praying, and approached and joined the row. People clapped, but Abu Bakr did not turn round. The people increased their clapping, and Abu Bakr turned round and saw the Messenger of Allah, may Allah bless him and grant him peace, and the Messenger of Allah, may Allah bless him and grant him peace, indicated to him to stay in his place. Abu Bakr raised his hands and praised Allah that the Messenger of Allah, may Allah bless him and grant him peace, had told him to do that. Then he drew back until he was in the row, and the Messenger of Allah, may Allah bless him and grant him peace, stepped forward and led the prayer. When he had finished he said, "Abu Bakr, what stopped you from staying put like I told you?" Abu Bakr said, "It is not for Ibn Abi Quhafa to pray in front of the Messenger of Allah, may Allah bless him and grant him peace." The Messenger of Allah, may Allah bless him and grant him peace, said, "Why did I see you all clapping so much? If something happens to you in the prayer you should say 'Subhana-llah' (Glory be to Allah), and when you say 'Subhana-llah' you will be heard. Clapping is only for women}}
\hadithdefcmd{malik}{393}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، لَمْ يَكُنْ يَلْتَفِتُ فِي صَلاَتِهِ ‏.‏\hadithno{393}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Ibn Umar would never turn around when praying}}
\hadithdefcmd{malik}{394}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي جَعْفَرٍ الْقَارِئِ، أَنَّهُ قَالَ كُنْتُ أُصَلِّي وَعَبْدُ اللَّهِ بْنُ عُمَرَ وَرَائِي وَلاَ أَشْعُرُ فَالْتَفَتُّ فَغَمَزَنِي ‏.‏\hadithno{394}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Abu Jafar al-Qari said, "I was praying, and Abdullah ibn Umar was behind me and I was not aware of it. Then I turned round and he prodded me (in disapproval)}}
\hadithdefcmd{malik}{395}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، أَنَّهُ قَالَ دَخَلَ زَيْدُ بْنُ ثَابِتٍ الْمَسْجِدَ فَوَجَدَ النَّاسَ رُكُوعًا فَرَكَعَ ثُمَّ دَبَّ حَتَّى وَصَلَ الصَّفَّ ‏.‏\hadithno{395}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Abu Umama ibn Sahl ibn Hunayf said, "Zayd ibn Thabit entered the mosque and found the people in ruku, so he went into ruku and then moved slowly forward until he reached the row}}
\hadithdefcmd{malik}{396}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، كَانَ يَدِبُّ رَاكِعًا ‏.‏\hadithno{396}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Masud used to move forward while in ruku}}
\hadithdefcmd{malik}{397}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ حَزْمٍ، عَنْ أَبِيهِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، أَنَّهُ قَالَ أَخْبَرَنِي أَبُو حُمَيْدٍ السَّاعِدِيُّ، أَنَّهُمْ قَالُوا يَا رَسُولَ اللَّهِ كَيْفَ نُصَلِّي عَلَيْكَ فَقَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَأَزْوَاجِهِ وَذُرِّيَّتِهِ كَمَا صَلَّيْتَ عَلَى آلِ إِبْرَاهِيمَ وَبَارِكْ عَلَى مُحَمَّدٍ وَأَزْوَاجِهِ وَذُرِّيَّتِهِ كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏ ‏.‏\hadithno{397}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr ibn Hazim from his father that Amr ibn Sulaym az-Zuraqi said, "Abu Humayd as-Saidi told me that they asked the Messenger of Allah, may Allah bless him and grant him peace, how they were to ask for blessings upon him and he replied that they should say, 'O Allah, bless Muhammad and his wives and his descendants asYou blessed the family of Ibrahim, and give baraka to Muhammad and his wives and his descendants as You gave baraka to the family of Ibrahim. You are worthy of Praise and Glorious.'" Allahumma salli ala Muhammad wa azwajihi wa alihi kama sallaita ala ali Ibrahim, wa barakaala Muhammad wa azwajihi wa alihi kama baraktaalaali Ibrahim, innaka Hamidu'm - Majid}}
\hadithdefcmd{malik}{398}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نُعَيْمِ بْنِ عَبْدِ اللَّهِ الْمُجْمِرِ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ زَيْدٍ، أَنَّهُ أَخْبَرَهُ عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، أَنَّهُ قَالَ أَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مَجْلِسِ سَعْدِ بْنِ عُبَادَةَ فَقَالَ لَهُ بَشِيرُ بْنُ سَعْدٍ أَمَرَنَا اللَّهُ أَنْ نُصَلِّيَ عَلَيْكَ يَا رَسُولَ اللَّهِ فَكَيْفَ نُصَلِّي عَلَيْكَ قَالَ فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى تَمَنَّيْنَا أَنَّهُ لَمْ يَسْأَلْهُ ثُمَّ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا صَلَّيْتَ عَلَى إِبْرَاهِيمَ وَبَارِكْ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ فِي الْعَالَمِينَ إِنَّكَ حَمِيدٌ مَجِيدٌ وَالسَّلاَمُ كَمَا قَدْ عَلِمْتُمْ ‏"‏ ‏.‏\hadithno{398}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nuaym ibn Abdullah al- Mujmirthat Muhammad ibn Abdullah ibn Zayd told him that Abu Masud al Ansari said, "The Messenger of Allah, may Allah bless him and grant him peace, came to us at the gathering of Sad ibn Ubada. Bashir ibn Sad said to him, 'Allah has ordered us to ask for blessings on you, Messenger of Allah. How should we do it?' The Messenger of Allah, may Allah bless him and grant him peace, remained silent until we wished we had not asked him. Then he told us to say, 'O Allah, bless Muhammad and the family of Muhammad as You blessed Ibrahim, and give baraka to Muhammad and the family of Muhammad as You gave baraka to the family of Ibrahim. In all the worlds You are worthy of Praise and Glorious,' and then give the taslim as you have learnt." Allahumma salli ala Muhammad wa ali Muhammad kama sallaita Ibrahim, wa baraka ala Muhammad wa ali Muhammad kama baraktaala ali Ibrahim. Fi'l alamin, innaka Hamidu'm - Majid}}
\hadithdefcmd{malik}{399}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، قَالَ رَأَيْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ يَقِفُ عَلَى قَبْرِ النَّبِيِّ صلى الله عليه وسلم فَيُصَلِّي عَلَى النَّبِيِّ صلى الله عليه وسلم وَعَلَى أَبِي بَكْرٍ وَعُمَرَ ‏.‏\hadithno{399}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Abdullah ibn Dinar said, "I saw Abdullah ibn Umar stop by the grave of the Prophet, may Allah bless him and grant him peace, and ask for blessings on the Prophet, may Allah bless him and grant him peace, and on Abu Bakr and Umar}}
\hadithdefcmd{malik}{400}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي قَبْلَ الظُّهْرِ رَكْعَتَيْنِ وَبَعْدَهَا رَكْعَتَيْنِ وَبَعْدَ الْمَغْرِبِ رَكْعَتَيْنِ فِي بَيْتِهِ وَبَعْدَ صَلاَةِ الْعِشَاءِ رَكْعَتَيْنِ وَكَانَ لاَ يُصَلِّي بَعْدَ الْجُمُعَةِ حَتَّى يَنْصَرِفَ فَيَرْكَعَ رَكْعَتَيْنِ ‏.‏\hadithno{400}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, used to pray two rakas before dhuhr and two rakas after it, two rakas after maghrib, in his house, and two rakas after isha. He did not pray after jumua until he had left, and then he prayed two rakas}}
\hadithdefcmd{malik}{401}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَتَرَوْنَ قِبْلَتِي هَاهُنَا فَوَاللَّهِ مَا يَخْفَى عَلَىَّ خُشُوعُكُمْ وَلاَ رُكُوعُكُمْ إِنِّي لأَرَاكُمْ مِنْ وَرَاءِ ظَهْرِي ‏"‏ ‏.‏\hadithno{401}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Do you see the direction I am facing here? By Allah, neither your concentration nor your ruku is hidden from me. I can see you behind my back}}
\hadithdefcmd{malik}{402}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْتِي قُبَاءً رَاكِبًا وَمَاشِيًا ‏.‏\hadithno{402}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that when the Messenger of Allah, may Allah bless him and grant him peace, used to go to Quba (to pray), he would walk as well as ride}}
\hadithdefcmd{malik}{403}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ النُّعْمَانِ بْنِ مُرَّةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا تَرَوْنَ فِي الشَّارِبِ وَالسَّارِقِ وَالزَّانِي ‏"‏ ‏.‏ وَذَلِكَ قَبْلَ أَنْ يُنْزَلَ فِيهِمْ ‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ هُنَّ فَوَاحِشُ وَفِيهِنَّ عُقُوبَةٌ وَأَسْوَأُ السَّرِقَةِ الَّذِي يَسْرِقُ صَلاَتَهُ ‏"‏ ‏.‏ قَالُوا وَكَيْفَ يَسْرِقُ صَلاَتَهُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لاَ يُتِمُّ رُكُوعَهَا وَلاَ سُجُودَهَا ‏"‏ ‏.‏\hadithno{403}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from an-Numan ibn Murra that the Messenger of Allah, may Allah bless him and grant him peace, said,"What about drunkenness, stealing and adultery? "That was before anything had been revealed about them. They said, "Allah and His Messenger know best." He said, "They are excesses and in them is a punishment. And the worst of thieves is the one who steals his prayer." They said, "How does he steal his prayer, Messenger of Allah?" He replied, "He does not do ruku or sajda properly}}
\hadithdefcmd{malik}{404}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اجْعَلُوا مِنْ صَلاَتِكُمْ فِي بُيُوتِكُمْ ‏"‏ ‏.‏\hadithno{404}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that the Messenger of Allah, may Allah bless him and grant him peace, said, "Do some of the prayers in your houses}}
\hadithdefcmd{malik}{405}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ إِذَا لَمْ يَسْتَطِعِ الْمَرِيضُ السُّجُودَ أَوْمَأَ بِرَأْسِهِ إِيمَاءً وَلَمْ يَرْفَعْ إِلَى جَبْهَتِهِ شَيْئًا ‏.‏\hadithno{405}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "When a sick man is unable to prostrate he should motion with his head, and not raise anything to his forehead}}
\hadithdefcmd{malik}{406}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا جَاءَ الْمَسْجِدَ - وَقَدْ صَلَّى النَّاسُ - بَدَأَ بِصَلاَةِ الْمَكْتُوبَةِ وَلَمْ يُصَلِّ قَبْلَهَا شَيْئًا ‏.‏\hadithno{406}\hadithgrade{Salim al-Hilali: Mauquf Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Rabia ibn Abi Abd ar-Rahman that if Abdullah ibn Umar arrived at the mosque and the people had already prayed, he would begin with the obligatory prayer and not pray anything before it}}
\hadithdefcmd{malik}{407}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، مَرَّ عَلَى رَجُلٍ وَهُوَ يُصَلِّي فَسَلَّمَ عَلَيْهِ فَرَدَّ الرَّجُلُ كَلاَمًا فَرَجَعَ إِلَيْهِ عَبْدُ اللَّهِ بْنُ عُمَرَ فَقَالَ لَهُ إِذَا سُلِّمَ عَلَى أَحَدِكُمْ وَهُوَ يُصَلِّي فَلاَ يَتَكَلَّمْ وَلْيُشِرْ بِيَدِهِ ‏.‏\hadithno{407}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar passed by a man who was praying and said, "Peace be upon you," and the man replied to him. Abdullah ibn Umar returned to him and said, "When someone says, 'Peace be upon you' to you while you are praying do not reply, but give a signal with your hand}}
\hadithdefcmd{malik}{408}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ مَنْ نَسِيَ صَلاَةً فَلَمْ يَذْكُرْهَا إِلاَّ وَهُوَ مَعَ الإِمَامِ فَإِذَا سَلَّمَ الإِمَامُ فَلْيُصَلِّ الصَّلاَةَ الَّتِي نَسِيَ ثُمَّ لِيُصَلِّ بَعْدَهَا الأُخْرَى ‏.‏\hadithno{408}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say, "Someone who only remembers that he has forgotten a prayer when he is praying the next prayer behind an imam, should pray the prayer he has forgotten after the imam has said the taslim, and then pray the other one again}}
\hadithdefcmd{malik}{409}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمِّهِ، وَاسِعِ بْنِ حَبَّانَ، أَنَّهُ قَالَ كُنْتُ أُصَلِّي وَعَبْدُ اللَّهِ بْنُ عُمَرَ مُسْنِدٌ ظَهْرَهُ إِلَى جِدَارِ الْقِبْلَةِ فَلَمَّا قَضَيْتُ صَلاَتِي انْصَرَفْتُ إِلَيْهِ مِنْ قِبَلِ شِقِّي الأَيْسَرِ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ مَا مَنَعَكَ أَنْ تَنْصَرِفَ عَنْ يَمِينِكَ قَالَ فَقُلْتُ رَأَيْتُكَ فَانْصَرَفْتُ إِلَيْكَ ‏.‏ قَالَ عَبْدُ اللَّهِ فَإِنَّكَ قَدْ أَصَبْتَ إِنَّ قَائِلاً يَقُولُ انْصَرِفْ عَنْ يَمِينِكَ فَإِذَا كُنْتَ تُصَلِّي فَانْصَرِفْ حَيْثُ شِئْتَ إِنْ شِئْتَ عَنْ يَمِينِكَ وَإِنْ شِئْتَ عَنْ يَسَارِكَ ‏.‏\hadithno{409}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Muhammad ibn Yahya ibn Habban that his paternal uncle Wasi ibn Habban said, "I was praying, and Abdullah ibn Umar was resting his back on the wall of the qibla. When I had finished the prayer I turned towards him on my left hand side. Abdullah ibn Umar said, 'What stopped you from turning away to your right?' I replied, 'I saw you and turned towards you.' Abdullah said, 'You have spoken correctly. People say that you should turn away to your right, but when you pray, you can turn whichever way you wish. If you like, to your right, and if you like, to your left}}
\hadithdefcmd{malik}{410}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ رَجُلٍ، مِنَ الْمُهَاجِرِينَ لَمْ يَرَ بِهِ بَأْسًا أَنَّهُ سَأَلَ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ أَأُصَلِّي فِي عَطَنِ الإِبِلِ فَقَالَ عَبْدُ اللَّهِ لاَ وَلَكِنْ صَلِّ فِي مُرَاحِ الْغَنَمِ ‏.‏\hadithno{410}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that one of the muhajirun in whom he saw no harm asked Abdullah ibn Amr ibn al-As, "Can I pray in a place where camels are watered?" Abdullah replied, "No, but you can pray in a sheep-pen}}
\hadithdefcmd{malik}{411}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ مَا صَلاَةٌ يُجْلَسُ فِي كُلِّ رَكْعَةٍ مِنْهَا ثُمَّ قَالَ سَعِيدٌ هِيَ الْمَغْرِبُ إِذَا فَاتَتْكَ مِنْهَا رَكْعَةٌ وَكَذَلِكَ سُنَّةُ الصَّلاَةِ كُلُّهَا ‏.‏\hadithno{411}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Said ibn al- Musayyab said, "Which prayer is it when you remain in the sitting position in every raka?'' Said said, "It is maghrib when you miss one raka, and that is the sunna in all the prayers}}
\hadithdefcmd{malik}{412}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، عَنْ أَبِي قَتَادَةَ الأَنْصَارِيِّ، ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي وَهُوَ حَامِلٌ أُمَامَةَ بِنْتَ زَيْنَبَ بِنْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلأَبِي الْعَاصِ بْنِ رَبِيعَةَ بْنِ عَبْدِ شَمْسٍ فَإِذَا سَجَدَ وَضَعَهَا وَإِذَا قَامَ حَمَلَهَا ‏.‏\hadithno{412}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Amir ibn Abdullah ibn az- Zubayr from Amr ibn Sulaym az-Zuraqi from Abu Qutada al-Ansari that the Messenger of Allah, may Allah bless him and grant him peace, used to pray carrying Umama, who was the daughter of his daughter Zaynab by Abu'l As ibn Rabia ibn Abd Shams. When he prostrated, he put her down, and when he got up he carried her}}
\hadithdefcmd{malik}{413}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَتَعَاقَبُونَ فِيكُمْ مَلاَئِكَةٌ بِاللَّيْلِ وَمَلاَئِكَةٌ بِالنَّهَارِ وَيَجْتَمِعُونَ فِي صَلاَةِ الْعَصْرِ وَصَلاَةِ الْفَجْرِ ثُمَّ يَعْرُجُ الَّذِينَ بَاتُوا فِيكُمْ فَيَسْأَلُهُمْ وَهُوَ أَعْلَمُ بِهِمْ كَيْفَ تَرَكْتُمْ عِبَادِي فَيَقُولُونَ تَرَكْنَاهُمْ وَهُمْ يُصَلُّونَ وَأَتَيْنَاهُمْ وَهُمْ يُصَلُّونَ ‏"‏ ‏.‏\hadithno{413}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "A group of angels in the night and a group of angels in the day alternate with each other among you, and gather together at the time of the asr and fajr prayers. Then those that have spent the night among you ascend, and He asks them, and He knows best, 'How did you leave my slaves?' and they say, 'When we left them they were praying, and when we came to them they were praying}}
\hadithdefcmd{malik}{414}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ لِلنَّاسِ ‏"‏ ‏.‏ فَقَالَتْ عَائِشَةُ إِنَّ أَبَا بَكْرٍ يَا رَسُولَ اللَّهِ إِذَا قَامَ فِي مَقَامِكَ لَمْ يُسْمِعِ النَّاسَ مِنَ الْبُكَاءِ فَمُرْ عُمَرَ فَلِيُصَلِّيَ لِلنَّاسِ ‏.‏ قَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ لِلنَّاسِ ‏"‏ ‏.‏ قَالَتْ عَائِشَةُ فَقُلْتُ لِحَفْصَةَ قُولِي لَهُ إِنَّ أَبَا بَكْرٍ إِذَا قَامَ فِي مَقَامِكَ لَمْ يُسْمِعِ النَّاسَ مِنَ الْبُكَاءِ فَمُرْ عُمَرَ فَلْيُصَلِّ لِلنَّاسِ فَفَعَلَتْ حَفْصَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّكُنَّ لأَنْتُنَّ صَوَاحِبُ يُوسُفَ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ لِلنَّاسِ ‏"‏ ‏.‏ فَقَالَتْ حَفْصَةُ لِعَائِشَةَ مَا كُنْتُ لأُصِيبَ مِنْكِ خَيْرًا ‏.‏\hadithno{414}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father from A'isha, the wife of the Prophet, may Allah bless him and grant him peace, that the Messenger of Allah, may Allah bless him and grant him peace, said, "Tell Abu Bakr to lead the people in prayer." A'isha said, "Messenger of Allah, when Abu Bakr stands in your place his voice does not reach the ears of the people because of his weeping, so tell Umar to lead the people in prayer." He said, "Tell Abu Bakr to lead the people in prayer." A'isha continued, "I told Hafsa to tell him that when Abu Bakr stood in his place his voice did not reach the ears of the people because of his weeping, and that he should tell Umar to lead the people in prayer. Hafsa did so, and the Messenger of Allah, may Allah bless him and grant him peace, said, 'You are the companions of Yusuf! (referring to the women who cut their hands when they saw the beauty of Yusuf). Tell Abu Bakr to lead the people in prayer!' " A'isha added that Hafsa said to her, "I have never had anything good from you}}
\hadithdefcmd{malik}{415}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَدِيِّ بْنِ الْخِيَارِ، أَنَّهُ قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ بَيْنَ ظَهْرَانَىِ النَّاسِ إِذْ جَاءَهُ رَجُلٌ فَسَارَّهُ فَلَمْ يُدْرَ مَا سَارَّهُ بِهِ حَتَّى جَهَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَإِذَا هُوَ يَسْتَأْذِنُهُ فِي قَتْلِ رَجُلٍ مِنَ الْمُنَافِقِينَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ جَهَرَ ‏"‏ أَلَيْسَ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ بَلَى وَلاَ شَهَادَةَ لَهُ ‏.‏ فَقَالَ ‏"‏ أَلَيْسَ يُصَلِّي ‏"‏ ‏.‏ قَالَ بَلَى وَلاَ صَلاَةَ لَهُ ‏.‏ فَقَالَ صلى الله عليه وسلم ‏"‏ أُولَئِكَ الَّذِينَ نَهَانِي اللَّهُ عَنْهُمْ ‏"‏ ‏.‏\hadithno{415}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Ata ibn Yazid al-Laythi that Ubaydullah ibn Adi ibnal-Khiyar said, "Once when the Messenger of Allah, may Allah bless him and grant him peace, was sitting with some people, a man came to him and spoke secretly to him. Nobody knew what he had said until the Messenger of Allah, may Allah bless him and grant him peace, disclosed that he had asked for permission to kill one of the hypocrites. When he disclosed this, the Messenger of Allah, may Allah bless him and grant him peace, said, 'Doesn't he testify that there is no god but Allah and that Muhammad is the Messenger of Allah?' The man replied, 'Of course, but he hasn't really done so.' He said, 'Doesn't he do the prayer?' and the man replied, 'Of course, but he doesn't really do the prayer.' He said, may Allah bless him and grant him peace, 'Those are the ones whom Allah has forbidden me (to kill)}}
\hadithdefcmd{malik}{416}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ لاَ تَجْعَلْ قَبْرِي وَثَنًا يُعْبَدُ اشْتَدَّ غَضَبُ اللَّهِ عَلَى قَوْمٍ اتَّخَذُوا قُبُورَ أَنْبِيَائِهِمْ مَسَاجِدَ ‏"‏ ‏.‏\hadithno{416}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar that the Messenger of Allah, may Allah bless him and grant him peace, said, "O Allah! Do not make my grave an idol that is worshipped. The anger on those who took the graves of their Prophets as places of prostration was terrible}}
\hadithdefcmd{malik}{417}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ مَحْمُودِ بْنِ الرَّبِيعِ الأَنْصَارِيِّ، أَنَّ عِتْبَانَ بْنَ مَالِكٍ، كَانَ يَؤُمُّ قَوْمَهُ وَهُوَ أَعْمَى وَأَنَّهُ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّهَا تَكُونُ الظُّلْمَةُ وَالْمَطَرُ وَالسَّيْلُ وَأَنَا رَجُلٌ ضَرِيرُ الْبَصَرِ فَصَلِّ يَا رَسُولَ اللَّهِ فِي بَيْتِي مَكَانًا أَتَّخِذْهُ مُصَلًّى ‏.‏ فَجَاءَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَيْنَ تُحِبُّ أَنْ أُصَلِّيَ ‏"‏ ‏.‏ فَأَشَارَ لَهُ إِلَى مَكَانٍ مِنَ الْبَيْتِ فَصَلَّى فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{417}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Mahmud ibn Rabi al-Ansari that Utban ibn Malik, who was a blind man, used to lead his people in prayer, and he said to the Messenger of Allah, may Allah bless him and grant him peace, "Sometimes it is dark and rainy and there is a lot of water around outside, and I am a man who has lost his sight. Messenger of Allah, pray in a certain place in my house so that I can take it as a place to pray." The Messenger of Allah, may Allah bless him and grant him peace, came to him and said, "Where would you like me to pray?" He indicated a place to him and the Messengerof Allah, may Allah bless him and grant him peace, prayed there}}
\hadithdefcmd{malik}{418}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم مُسْتَلْقِيًا فِي الْمَسْجِدِ وَاضِعًا إِحْدَى رِجْلَيْهِ عَلَى الأُخْرَى ‏.‏\hadithno{418}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Abbad ibn Tamim from his paternal uncle that he saw the Messenger of Allah, may Allah bless him and grant him peace, lying down in the mosque with one foot on top of the other}}
\hadithdefcmd{malik}{419}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، وَعُثْمَانَ بْنَ عَفَّانَ، - رضى الله عنهما - كَانَا يَفْعَلاَنِ ذَلِكَ ‏.‏\hadithno{419}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Said ihn al-Musayyab that Umar ibn al Khattab and Uthman ibn Affan, may Allah be pleased with them, used to do the same}}
\hadithdefcmd{malik}{420}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، قَالَ لإِنْسَانٍ إِنَّكَ فِي زَمَانٍ كَثِيرٌ فُقَهَاؤُهُ قَلِيلٌ قُرَّاؤُهُ تُحْفَظُ فِيهِ حُدُودُ الْقُرْآنِ وَتُضَيَّعُ حُرُوفُهُ قَلِيلٌ مَنْ يَسْأَلُ كَثِيرٌ مَنْ يُعْطِي يُطِيلُونَ فِيهِ الصَّلاَةَ وَيَقْصُرُونَ الْخُطْبَةَ يُبَدُّونَ أَعْمَالَهُمْ قَبْلَ أَهْوَائِهِمْ وَسَيَأْتِي عَلَى النَّاسِ زَمَانٌ قَلِيلٌ فُقَهَاؤُهُ كَثِيرٌ قُرَّاؤُهُ يُحْفَظُ فِيهِ حُرُوفُ الْقُرْآنِ وَتُضَيَّعُ حُدُودُهُ كَثِيرٌ مَنْ يَسْأَلُ قَلِيلٌ مَنْ يُعْطِي يُطِيلُونَ فِيهِ الْخُطْبَةَ وَيَقْصُرُونَ الصَّلاَةَ يُبَدُّونَ فِيهِ أَهْوَاءَهُمْ قَبْلَ أَعْمَالِهِمْ ‏.‏\hadithno{420}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Abdullah ibn Masud said to a certain man, "You are in a time when men of understanding (fuqaha) are many and Qur'an reciters are few, when the limits of behaviour defined in the Qur'an are guarded and its letters are lost, when few people ask and many give, when they make the prayer long and the khutba short, and put their actions before their desires. A time will come upon men when their fuqaha are few but their Qur'an reciters are many, when the letters of the Qur'an are guarded carefully but its limits are lost, when many ask but few give, when they make the khutba long but the prayer short, and put their desires before their actions}}
\hadithdefcmd{malik}{421}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ بَلَغَنِي أَنَّ أَوَّلَ، مَا يُنْظَرُ فِيهِ مِنْ عَمَلِ الْعَبْدِ الصَّلاَةُ فَإِنْ قُبِلَتْ مِنْهُ نُظِرَ فِيمَا بَقِيَ مِنْ عَمَلِهِ وَإِنْ لَمْ تُقْبَلْ مِنْهُ لَمْ يُنْظَرْ فِي شَىْءٍ مِنْ عَمَلِهِ ‏.‏\hadithno{421}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said, "I have heard that the first of the actions of a slave to be considered on the day of rising is the prayer. If it is accepted from him, the rest of his actions will be considered, and if it is not accepted from him, none of his actions will be considered}}
\hadithdefcmd{malik}{422}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كَانَ أَحَبُّ الْعَمَلِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الَّذِي يَدُومُ عَلَيْهِ صَاحِبُهُ ‏.‏\hadithno{422}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "The actions which the Messenger of Allah, may Allah bless him and grant him peace, loved most were those which were done most constantly}}
\hadithdefcmd{malik}{423}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، أَنَّهُ قَالَ كَانَ رَجُلاَنِ أَخَوَانِ فَهَلَكَ أَحَدُهُمَا قَبْلَ صَاحِبِهِ بِأَرْبَعِينَ لَيْلَةً فَذُكِرَتْ فَضِيلَةُ الأَوَّلِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَلَمْ يَكُنِ الآخَرُ مُسْلِمًا ‏"‏ ‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ وَكَانَ لاَ بَأْسَ بِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَمَا يُدْرِيكُمْ مَا بَلَغَتْ بِهِ صَلاَتُهُ إِنَّمَا مَثَلُ الصَّلاَةِ كَمَثَلِ نَهْرٍ غَمْرٍ عَذْبٍ بِبَابِ أَحَدِكُمْ يَقْتَحِمُ فِيهِ كُلَّ يَوْمٍ خَمْسَ مَرَّاتٍ فَمَا تَرَوْنَ ذَلِكَ يُبْقِي مِنْ دَرَنِهِ فَإِنَّكُمْ لاَ تَدْرُونَ مَا بَلَغَتْ بِهِ صَلاَتُهُ ‏"‏ ‏.‏\hadithno{423}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he had heard from Amir ibn Sad ibn Abi Waqqas that his father said, "There were two brothers, one of whom died forty nights before the other. The merit of the first was being mentioned in the presence of the Messenger of Allah, may Allah bless him and grant him peace, and he said, 'Wasn't the other one a muslim?' They said, 'Of course, Messenger of Allah, and there was no harm in him.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'What will make you realise what his prayer has brought him. The prayer is like a deep river of sweet water running by your door into which you plunge five times a day. How much of your dirtiness do you think that will leave? You do not realise what his prayer has brought him}}
\hadithdefcmd{malik}{424}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَطَاءَ بْنَ يَسَارٍ، كَانَ إِذَا مَرَّ عَلَيْهِ بَعْضُ مَنْ يَبِيعُ فِي الْمَسْجِدِ دَعَاهُ فَسَأَلَهُ مَا مَعَكَ وَمَا تُرِيدُ فَإِنْ أَخْبَرَهُ أَنَّهُ يُرِيدُ أَنْ يَبِيعَهُ قَالَ عَلَيْكَ بِسُوقِ الدُّنْيَا وَإِنَّمَا هَذَا سُوقُ الآخِرَةِ ‏.‏\hadithno{424}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that if some one passed by Ata ibn Yasar in the mosque with something to trade, he would call him and ask, "What is the matter with you? What do you want?" If the man said that he wished to trade with him, he would say, "You need the market of this world. This is the market of the next world}}
\hadithdefcmd{malik}{425}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، بَنَى رَحْبَةً فِي نَاحِيَةِ الْمَسْجِدِ تُسَمَّى الْبُطَيْحَاءَ وَقَالَ مَنْ كَانَ يُرِيدُ أَنْ يَلْغَطَ أَوْ يُنْشِدَ شِعْرًا أَوْ يَرْفَعَ صَوْتَهُ فَلْيَخْرُجْ إِلَى هَذِهِ الرَّحْبَةِ ‏.‏\hadithno{425}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Umar ibn al-Khattab set aside an area near the mosque called al-Butayha and said, "Whoever wishes to talk nonsense or recite poetry or raise his voice should go to that area}}
\hadithdefcmd{malik}{426}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَمِّهِ أَبِي سُهَيْلِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ طَلْحَةَ بْنَ عُبَيْدِ اللَّهِ، يَقُولُ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ أَهْلِ نَجْدٍ ثَائِرُ الرَّأْسِ يُسْمَعُ دَوِيُّ صَوْتِهِ وَلاَ نَفْقَهُ مَا يَقُولُ حَتَّى دَنَا فَإِذَا هُوَ يَسْأَلُ عَنِ الإِسْلاَمِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَمْسُ صَلَوَاتٍ فِي الْيَوْمِ وَاللَّيْلَةِ ‏"‏ ‏.‏ قَالَ هَلْ عَلَىَّ غَيْرُهُنَّ قَالَ ‏"‏ لاَ إِلاَّ أَنْ تَطَّوَّعَ ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَصِيَامُ شَهْرِ رَمَضَانَ ‏"‏ ‏.‏ قَالَ هَلْ عَلَىَّ غَيْرُهُ قَالَ ‏"‏ لاَ إِلاَّ أَنْ تَطَّوَّعَ ‏"‏ ‏.‏ قَالَ وَذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم الزَّكَاةَ ‏.‏ فَقَالَ هَلْ عَلَىَّ غَيْرُهَا قَالَ ‏"‏ لاَ إِلاَّ أَنْ تَطَّوَّعَ ‏"‏ ‏.‏ قَالَ فَأَدْبَرَ الرَّجُلُ وَهُوَ يَقُولُ وَاللَّهِ لاَ أَزِيدُ عَلَى هَذَا وَلاَ أَنْقُصُ مِنْهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَفْلَحَ الرَّجُلُ إِنْ صَدَقَ ‏"‏ ‏.‏\hadithno{426}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from his paternal uncle Abu Suhayl ibn Malik that his father heard Talha ibn Ubaydullah say, "Once one of the people of Najd came to the Messenger of Allah, may Allah bless him and grant him peace. He had dishevelled hair and although his voice could be heard we could not make out what he was saying until he drew nearer and then we found he was asking about Islam. The Messenger of Allah, may Allah bless him and grant him peace, said to him, 'There are five prayers during the day and the night.' He said, 'Do I have to do anything else besides that?' The Messenger of Allah, may Allah bless him and grant him peace, added, 'And fasting the month of Ramadan.' He said, 'Is there anything else I have to do?' He said, 'No, except what you do of your own accord.' The Messenger of Allah, may Allah bless him and grant him peace, mentioned zakat. The man said, 'Is there anything else that I have to do?' He said, 'No, except what you do of your own accord.' He continued, "The man went away saying, 'By Allah, I won't do any more than this, nor will I do any less.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'That man will be successful, if he is telling the truth}}
\hadithdefcmd{malik}{427}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَعْقِدُ الشَّيْطَانُ عَلَى قَافِيَةِ رَأْسِ أَحَدِكُمْ إِذَا هُوَ نَامَ ثَلاَثَ عُقَدٍ يَضْرِبُ مَكَانَ كُلِّ عُقْدَةٍ عَلَيْكَ لَيْلٌ طَوِيلٌ فَارْقُدْ فَإِنِ اسْتَيْقَظَ فَذَكَرَ اللَّهَ انْحَلَّتْ عُقْدَةٌ فَإِنْ تَوَضَّأَ انْحَلَّتْ عُقْدَةٌ فَإِنْ صَلَّى انْحَلَّتْ عُقَدُهُ فَأَصْبَحَ نَشِيطًا طَيِّبَ النَّفْسِ وَإِلاَّ أَصْبَحَ خَبِيثَ النَّفْسِ كَسْلاَنَ ‏"‏ ‏.‏\hadithno{427}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Shaytan ties three knots at the back of your head when you sleep, and he seals the place of each knot with 'You have a long night ahead, so sleep.' If you wake up and remember Allah, a knot is untied. If you do wudu, a knot is untied. If you pray, a knot is untied, and morning finds you lively and in good spirits, and if not, morning finds you in bad spirits and lazy}}
