% Auto-generated chapter 25 for malik
% Hadiths in this chapter: 15

\hadithdefcmd{malik}{1052}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّهُ قَالَ رَمَيْتُ طَائِرَيْنِ بِحَجَرٍ وَأَنَا بِالْجُرْفِ، فَأَصَبْتُهُمَا فَأَمَّا أَحَدُهُمَا فَمَاتَ فَطَرَحَهُ عَبْدُ اللَّهِ بْنُ عُمَرَ وَأَمَّا الآخَرُ فَذَهَبَ عَبْدُ اللَّهِ بْنُ عُمَرَ يُذَكِّيهِ بِقَدُومٍ فَمَاتَ قَبْلَ أَنْ يُذَكِّيَهُ فَطَرَحَهُ عَبْدُ اللَّهِ أَيْضًا ‏.‏\hadithno{1052}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{ahya related to me from Malik that Nafi said, "I was at al-Juruf (near Madina) and threw a stone at two birds, and hit them. One of them died, and Abdullah ibn Umar threw it away, and then went to slaughter the other one with an adze. It died before he could slaughter it, so Abdullah threw that one away as well}}
\hadithdefcmd{malik}{1053}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ، كَانَ يَكْرَهُ مَا قَتَلَ الْمِعْرَاضُ وَالْبُنْدُقَةُ ‏.‏\hadithno{1053}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that al-Qasim ibn Muhammad disapproved of eating game that had been killed with throwing sticks and by clay pellets}}
\hadithdefcmd{malik}{1054}{\hadithno{1054}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{}}
\hadithdefcmd{malik}{1055}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ فِي الْكَلْبِ الْمُعَلَّمِ كُلْ مَا أَمْسَكَ عَلَيْكَ إِنْ قَتَلَ وَإِنْ لَمْ يَقْتُلْ ‏.‏\hadithno{1055}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{}}
\hadithdefcmd{malik}{1056}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَمَّنْ سَمِعَ نَافِعًا، يَقُولُ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ وَإِنْ أَكَلَ وَإِنْ لَمْ يَأْكُلْ ‏.‏\hadithno{1056}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he heard Nafi say that Abdullah ibn Umar said, "Whether it eats from it or not}}
\hadithdefcmd{malik}{1057}{\hadithno{1057}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{}}
\hadithdefcmd{malik}{1058}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ أَبِي هُرَيْرَةَ، سَأَلَ عَبْدَ اللَّهِ بْنَ عُمَرَ عَمَّا لَفَظَ الْبَحْرُ فَنَهَاهُ عَنْ أَكْلِهِ، ‏.‏ قَالَ نَافِعٌ ثُمَّ انْقَلَبَ عَبْدُ اللَّهِ فَدَعَا بِالْمُصْحَفِ فَقَرَأَ ‏\{‏أُحِلَّ لَكُمْ صَيْدُ الْبَحْرِ وَطَعَامُهُ‏\}‏ قَالَ نَافِعٌ فَأَرْسَلَنِي عَبْدُ اللَّهِ بْنُ عُمَرَ إِلَى عَبْدِ الرَّحْمَنِ بْنِ أَبِي هُرَيْرَةَ إِنَّهُ لاَ بَأْسَ بِأَكْلِهِ ‏.‏\hadithno{1058}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{}}
\hadithdefcmd{malik}{1059}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ سَعْدٍ الْجَارِيِّ، مَوْلَى عُمَرَ بْنِ الْخَطَّابِ أَنَّهُ قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ عَنِ الْحِيتَانِ، يَقْتُلُ بَعْضُهَا بَعْضًا أَوْ تَمُوتُ صَرَدًا فَقَالَ لَيْسَ بِهَا بَأْسٌ ‏.‏ قَالَ سَعْدٌ ثُمَّ سَأَلْتُ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ فَقَالَ مِثْلَ ذَلِكَ ‏.‏\hadithno{1059}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that Sad al- Jari, the mawla of Umar ibn al-Khattab asked Abdullah ibn Umar about fish which had killed each other or which had died from severe cold . He said, "There is no harm in eating them.'' Sad said,' 'I then asked Abdullah ibn Amr ibn al As and he said the same}}
\hadithdefcmd{malik}{1060}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ ثَابِتٍ، أَنَّهُمَا كَانَا لاَ يَرَيَانِ بِمَا لَفَظَ الْبَحْرُ بَأْسًا ‏.‏\hadithno{1060}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from Abu Salama ibn Abd ar-Rahman from Abu Hurayra and Zayd ibn Thabit that they saw no harm in eating what was cast up by the sea}}
\hadithdefcmd{malik}{1061}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ نَاسًا، مِنْ أَهْلِ الْجَارِ قَدِمُوا فَسَأَلُوا مَرْوَانَ بْنَ الْحَكَمِ عَمَّا لَفَظَ الْبَحْرُ فَقَالَ لَيْسَ بِهِ بَأْسٌ وَقَالَ اذْهَبُوا إِلَى زَيْدِ بْنِ ثَابِتٍ وَأَبِي هُرَيْرَةَ فَاسْأَلُوهُمَا عَنْ ذَلِكَ ثُمَّ ائْتُونِي فَأَخْبِرُونِي مَاذَا يَقُولاَنِ فَأَتَوْهُمَا فَسَأَلُوهُمَا فَقَالاَ لاَ بَأْسَ بِهِ ‏.‏ فَأَتَوْا مَرْوَانَ فَأَخْبَرُوهُ ‏.‏ فَقَالَ مَرْوَانُ قَدْ قُلْتُ لَكُمْ ‏.‏ قَالَ مَالِكٌ لاَ بَأْسَ بِأَكْلِ الْحِيتَانِ يَصِيدُهَا الْمَجُوسِيُّ لأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي الْبَحْرِ ‏ "‏ هُوَ الطَّهُورُ مَاؤُهُ الْحِلُّ مَيْتَتُهُ ‏"‏ ‏.‏ قَالَ مَالِكٌ وَإِذَا أُكِلَ ذَلِكَ مَيْتًا فَلاَ يَضُرُّهُ مَنْ صَادَهُ ‏.‏\hadithno{1061}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from Abu Salama ibn Abd ar-Rahman that some people from al-Jar came to Marwan ibn al- Hakam and asked him about eating what was cast up by the sea. He said, "There is no harm in eating it." Marwan said, "Go to Zayd ibn Thabit and Abu Hurayra and ask them about it, then come to me and tell me what they say." They went to them and asked them, and they both said, "There is no harm in eating it " They returned to Marwan and told him. Marwan said, "I told you." Malik said that there was no harm in eating fish caught by magians, because the Messenger of Allah, may Allah bless him and grant him peace, said, "In the sea's water is purity, and that which is dead in it is halal. " Malik said, "If it is eaten when it is dead, there is no harm in who catches it}}
\hadithdefcmd{malik}{1062}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنِ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَكْلُ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ حَرَامٌ ‏"‏ ‏.‏\hadithno{1062}\hadithgrade{Salim al-Hilali: Shadh}\hadithtrans{Yahya related to me from Malik from Ibn Shibab from Abu Idris al- Khawlani from Abu Tha\textasciitilde{}laba al-Khushani that the Messenger of Allah, may Allah bless him and grant him peace, said, "It is haram to eat animals with fangs}}
\hadithdefcmd{malik}{1063}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي حَكِيمٍ، عَنْ عَبِيدَةَ بْنِ سُفْيَانَ الْحَضْرَمِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَكْلُ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ حَرَامٌ ‏"‏ ‏.‏\hadithno{1063}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ismail ibn Abi Hakim from Abiyda ibn Sufyan al-Hadrami from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Eating animals with fangs is haram. " Malik said, "This is the custom among us}}
\hadithdefcmd{malik}{1064}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ قَالَ مَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَاةٍ مَيِّتَةٍ كَانَ أَعْطَاهَا مَوْلاَةً لِمَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَفَلاَ انْتَفَعْتُمْ بِجِلْدِهَا ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّهَا مَيْتَةٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا حُرِّمَ أَكْلُهَا ‏"‏ ‏.‏\hadithno{1064}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that the best of what he had heard about horses, mules, and donkeys was that they were not eaten because Allah, the Blessed, the Exalted,said, "And horses, and mules and asses, for you to ride, and as an adornment. " (Sura 16 ayat 8) . He said, may He be Blessed and Exalted, "In cattle, some of them you ride, and some of them you eat." (Sura 6 ayat 79). He said, the Blessed, the Exalted, "Mention Allah's name over what He has provided you of cattle, and eat of them and feed the beggar (al-qani) and the suppliant (al-mutarr). (Sura 22 ayat 34). Malik said "Allah mentioned horses, mules, and donkeys for riding and adornment, and He mentioned cattle for riding and eating." Malik said, "Al-qani also means the poor." Yahya related to me from Malik from Ibn Shihab from Ubaydullah ibn Abdullah ibn Utba ibn Masud that Abdullah ibn Abbas said, "The Messenger of Allah, may Allah bless him and grant him peace, passed by a dead sheep which had been given to a mawla of his wife, Maimuna. He said, ' Aren't you going to use its skin?' They said, 'Messenger of Allah, but it is carrion. 'The Messenger of Allah, may Allah bless him and grant him peace, said, 'Only eating it is haram}}
\hadithdefcmd{malik}{1065}{وَحَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنِ ابْنِ وَعْلَةَ الْمِصْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دُبِغَ الإِهَابُ فَقَدْ طَهُرَ ‏"‏ ‏.‏\hadithno{1065}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Zayd ibn Aslam from Ibn Wala al-Misri from Abdullah ibn Abbas that the Messenger of Allah, may Allah bless him and grant him peace, said, "A skin when it is tanned is pure}}
\hadithdefcmd{malik}{1066}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ قُسَيْطٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ أَنْ يُسْتَمْتَعَ بِجُلُودِ الْمَيْتَةِ إِذَا دُبِغَتْ ‏.‏\hadithno{1066}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Yazid ibn Abdullah ibn Qusayt from Muhammad ibn Abd ar-Rahman ibn Thawban from his mother that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said that the Messenger of Allah, may Allah bless him and grant him peace, ordered that the skins of carrion be used after they had been tanned}}
