% Auto-generated chapter 41 for muslim
% Hadiths in this chapter: 10

\hadithdefcmd{muslim}{5887}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، كِلاَهُمَا عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ الطَّائِفِيِّ، عَنْ عَمْرِو، بْنِ الشَّرِيدِ عَنْ أَبِيهِ، قَالَ اسْتَنْشَدَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ وَزَادَ قَالَ ‏"‏ إِنْ كَادَ لَيُسْلِمُ ‏"‏ ‏.‏ وَفِي حَدِيثِ ابْنِ مَهْدِيٍّ قَالَ ‏"‏ فَلَقَدْ كَادَ يُسْلِمُ فِي شِعْرِهِ ‏"‏ ‏.‏\hadithno{5887}\hadithtrans{Amr b. Sharid reported on the authority of his father that Allah's Messenger (ﷺ) asked him to recite poetry, the rest of the hadith is the same, but with this addition:"He (that is Umayya b. Abu Salt) was about to become a Muslim", and in the hadith transmitted on the authority of Ibn Mahdi (the words are) "He was almost a Muslim in his poetry}}
\hadithdefcmd{muslim}{5888}{حَدَّثَنِي أَبُو جَعْفَرٍ، مُحَمَّدُ بْنُ الصَّبَّاحِ وَعَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ جَمِيعًا عَنْ شَرِيكٍ، قَالَ ابْنُ حُجْرٍ أَخْبَرَنَا شَرِيكٌ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَشْعَرُ كَلِمَةٍ تَكَلَّمَتْ بِهَا الْعَرَبُ كَلِمَةُ لَبِيدٍ أَلاَ كُلُّ شَىْءٍ مَا خَلاَ اللَّهَ بَاطِلٌ ‏"‏ ‏.‏\hadithno{5888}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The truest word spoken by an Arab (pre-Islamic) in poetry is this verse of Labid: "Behold! apart from Allah everything is vain}}
\hadithdefcmd{muslim}{5889}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الْمَلِكِ، بْنِ عُمَيْرٍ حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَصْدَقُ كَلِمَةٍ قَالَهَا شَاعِرٌ كَلِمَةُ لَبِيدٍ أَلاَ كُلُّ شَىْءٍ مَا خَلاَ اللَّهَ بَاطِلٌ وَكَادَ أُمَيَّةُ بْنُ أَبِي الصَّلْتِ أَنْ يُسْلِمَ ‏"‏ ‏.‏\hadithno{5889}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The truest word uttered by a poet is this verse of Labid: "Behold! apart from Allah everything is vain," and Umayya b. Abu Salt was almost a Muslim}}
\hadithdefcmd{muslim}{5890}{وَحَدَّثَنِي ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ زَائِدَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَصْدَقُ بَيْتٍ قَالَهُ الشَّاعِرُ أَلاَ كُلُّ شَىْءٍ مَا خَلاَ اللَّهَ بَاطِلٌ وَكَادَ ابْنُ أَبِي الصَّلْتِ أَنْ يُسْلِمَ ‏"‏ ‏.‏\hadithno{5890}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The truest verse recited by a poet is: "Behold! apart from Allah everything is vain," and Ibn Abu Salt was almost a Muslim}}
\hadithdefcmd{muslim}{5891}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ، عُمَيْرٍ عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَصْدَقُ بَيْتٍ قَالَتْهُ الشُّعَرَاءُ أَلاَ كُلُّ شَىْءٍ مَا خَلاَ اللَّهَ بَاطِلٌ ‏"‏ ‏.‏\hadithno{5891}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:The truest couplet recited by a poet is: "Behold! apart from Allah everything is vain," and he made no addition to it}}
\hadithdefcmd{muslim}{5892}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَحْيَى بْنُ زَكَرِيَّاءَ، عَنْ إِسْرَائِيلَ، عَنْ عَبْدِ الْمَلِكِ، بْنِ عُمَيْرٍ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ أَصْدَقَ كَلِمَةٍ قَالَهَا شَاعِرٌ كَلِمَةُ لَبِيدٍ أَلاَ كُلُّ شَىْءٍ مَا خَلاَ اللَّهَ بَاطِلٌ ‏"‏ ‏.‏ مَا زَادَ عَلَى ذَلِكَ ‏.‏\hadithno{5892}\hadithtrans{Abu Huraira reported:I heard Allah's Messenger (ﷺ) as saying: The truest word which the poet stated is the word of Labid: "Behold! apart from Allah everything is vain}}
\hadithdefcmd{muslim}{5893}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصٌ، وَأَبُو مُعَاوِيَةَ ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، كِلاَهُمَا عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لأَنْ يَمْتَلِئَ جَوْفُ الرَّجُلِ قَيْحًا يَرِيهِ خَيْرٌ مِنْ أَنْ يَمْتَلِئَ شِعْرًا ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ إِلاَّ أَنَّ حَفْصًا لَمْ يَقُلْ ‏"‏ يَرِيهِ ‏"‏ ‏.‏\hadithno{5893}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:It is better for a man's belly to be stuffed with pus which corrodes it than to stuff (one's mind) with frivolous poetry. Abu Bakr has reported it with a slight variation of wording}}
\hadithdefcmd{muslim}{5894}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ يُونُسَ بْنِ جُبَيْرٍ، عَنْ مُحَمَّدِ بْنِ سَعْدٍ، عَنْ سَعْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لأَنْ يَمْتَلِئَ جَوْفُ أَحَدِكُمْ قَيْحًا يَرِيهِ خَيْرٌ مِنْ أَنْ يَمْتَلِئَ شِعْرًا ‏"‏ ‏.‏\hadithno{5894}\hadithtrans{Sa`d reported Allah's Apostle (ﷺ) as saying:It is better for the belly of any one of you to be stuffed with pus rather than to stuff (one's mind) with poetry}}
\hadithdefcmd{muslim}{5895}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ الثَّقَفِيُّ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ الْهَادِ، عَنْ يُحَنِّسَ، مَوْلَى مُصْعَبِ بْنِ الزُّبَيْرِ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ بَيْنَا نَحْنُ نَسِيرُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْعَرْجِ إِذْ عَرَضَ شَاعِرٌ يُنْشِدُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خُذُوا الشَّيْطَانَ أَوْ أَمْسِكُوا الشَّيْطَانَ لأَنْ يَمْتَلِئَ جَوْفُ رَجُلٍ قَيْحًا خَيْرٌ لَهُ مِنْ أَنْ يَمْتَلِئَ شِعْرًا ‏"‏ ‏.‏\hadithno{5895}\hadithtrans{Abu Sa`id Al-Khudri reported:We were going with Allah's Messenger (ﷺ). As we reached the place (known as) `Arj there met (us) a poet who had been reciting poetry. Thereupon Allah's Messenger (ﷺ) said: Catch the satan or detain the satan, for filling the belly of a man with pus is better than stuffing his brain with poetry}}
\hadithdefcmd{muslim}{5896}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ بْنِ، مَرْثَدٍ عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَعِبَ بِالنَّرْدَشِيرِ فَكَأَنَّمَا صَبَغَ يَدَهُ فِي لَحْمِ خِنْزِيرٍ وَدَمِهِ ‏"‏ ‏.‏\hadithno{5896}\hadithtrans{Buraida reported on the authority of his father that Allah's Apostle (ﷺ) said:He who played Nardashir (a game similar to backgammon) is like one who dyed his hand with the flesh and blood of swine}}
