% Auto-generated chapter 28 for malik
% Hadiths in this chapter: 59

\hadithdefcmd{malik}{1091}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَخْطُبُ أَحَدُكُمْ عَلَى خِطْبَةِ أَخِيهِ ‏"‏ ‏.‏\hadithno{1091}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Muhammad ibn Yahya ibn Habban from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Do not ask for a woman in marriage when another muslim has already done so}}
\hadithdefcmd{malik}{1092}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَخْطُبُ أَحَدُكُمْ عَلَى خِطْبَةِ أَخِيهِ ‏"‏ ‏.‏\hadithno{1092}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "Do not ask for a woman in marriage when another muslim has already done so." Malik said, "The explanation of the statement of the Messenger of Allah, may Allah bless him and grant him peace, according to what we think - and Allah knows best - is that 'Do not ask for a woman in marriage when another muslim has already done so' means that when a man has asked for a woman in marriage, and she has inclined to him and they have agreed on a bride-price, which she has suggested and with which they are mutually satisfied, it is forbidden for another man to ask for that woman in marriage. It does not mean that when a man has asked for a woman in marriage, and his suit does not agree with her and she does not incline to him that no one else can ask for her in marriage. That is a door to misery for people}}
\hadithdefcmd{malik}{1093}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَقُولُ فِي قَوْلِ اللَّهِ تَبَارَكَ وَتَعَالَى ‏\{‏وَلاَ جُنَاحَ عَلَيْكُمْ فِيمَا عَرَّضْتُمْ بِهِ مِنْ خِطْبَةِ النِّسَاءِ أَوْ أَكْنَنْتُمْ فِي أَنْفُسِكُمْ عَلِمَ اللَّهُ أَنَّكُمْ سَتَذْكُرُونَهُنَّ وَلَكِنْ لاَ تُوَاعِدُوهُنَّ سِرًّا إِلاَّ أَنْ تَقُولُوا قَوْلاً مَعْرُوفًا‏\}‏ أَنْ يَقُولَ الرَّجُلُ لِلْمَرْأَةِ وَهِيَ فِي عِدَّتِهَا مِنْ وَفَاةِ زَوْجِهَا إِنَّكِ عَلَىَّ لَكَرِيمَةٌ وَإِنِّي فِيكِ لَرَاغِبٌ وَإِنَّ اللَّهَ لَسَائِقٌ إِلَيْكِ خَيْرًا وَرِزْقًا وَنَحْوَ هَذَا مِنَ الْقَوْلِ ‏.‏\hadithno{1093}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim that his father said about the word of Allah, the Blessed, the Exalted, "There is no fault in you about the proposal you offer to women, or hide in yourselves. Allah knows that you will be mindful of them; but do not make troth with them secretly without honourable words," (Sura 2 ayat 235) that it referred to a man saying to a woman while she was still in her idda after the death of her husband, "You are dear to me, and I desire you, and Allah brings provision and blessing to you," and words such as these}}
\hadithdefcmd{malik}{1094}{حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، عَنْ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الأَيِّمُ أَحَقُّ بِنَفْسِهَا مِنْ وَلِيِّهَا وَالْبِكْرُ تُسْتَأْذَنُ فِي نَفْسِهَا وَإِذْنُهَا صُمَاتُهَا ‏"‏ ‏.‏\hadithno{1094}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abdullah ibn al-Fadl from Nafi ibn Jubayr ibn Mutim from Abdullah ibn Abbas that the Messenger of Allah, may Allah bless him and grant him peace, said, "A woman who has been previously married is more entitled to her person than her guardian, and a virgin must be asked for her consent for herself, and her consent is her silence}}
\hadithdefcmd{malik}{1095}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ لاَ تُنْكَحُ الْمَرْأَةُ إِلاَّ بِإِذْنِ وَلِيِّهَا أَوْ ذِي الرَّأْىِ مِنْ أَهْلِهَا أَوِ السُّلْطَانِ ‏.‏\hadithno{1095}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn al-Musayyab had said that Umar ibn al-Khattab said, "A woman is only married with the consent of her guardian, someone of her family with sound judgement or the Sultan}}
\hadithdefcmd{malik}{1096}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ، وَسَالِمَ بْنَ عَبْدِ اللَّهِ، كَانَا يُنْكِحَانِ بَنَاتِهِمَا الأَبْكَارَ وَلاَ يَسْتَأْمِرَانِهِنَّ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ الأَمْرُ عِنْدَنَا فِي نِكَاحِ الأَبْكَارِ ‏.‏ قَالَ مَالِكٌ وَلَيْسَ لِلْبِكْرِ جَوَازٌ فِي مَالِهَا حَتَّى تَدْخُلَ بَيْتَهَا وَيُعْرَفَ مِنْ حَالِهَا ‏.‏\hadithno{1096}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that al-Qasim ibn Muhammad and Salim ibn Abdullah were marrying off their daughters and they did not consult them. Malik said, "That is what is done among us about the marriage of virgins." Malik said, "A virgin has no right to her property until she enters her house and her state (competence, maturity etc.) is known for sure}}
\hadithdefcmd{malik}{1097}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ، وَسَالِمَ بْنَ عَبْدِ اللَّهِ، وَسُلَيْمَانَ بْنَ يَسَارٍ، كَانُوا يَقُولُونَ فِي الْبِكْرِ يُزَوِّجُهَا أَبُوهَا بِغَيْرِ إِذْنِهَا إِنَّ ذَلِكَ لاَزِمٌ لَهَا ‏.‏\hadithno{1097}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that al-Qasim ibn Muhammad and Salim ibn Abdullah and Sulayman ibn Yasar said about the virgin given by her father in marriage without her permission, "That is binding on her}}
\hadithdefcmd{malik}{1098}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي حَازِمِ بْنِ دِينَارٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَاءَتْهُ امْرَأَةٌ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي قَدْ وَهَبْتُ نَفْسِي لَكَ فَقَامَتْ قِيَامًا طَوِيلاً فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ زَوِّجْنِيهَا إِنْ لَمْ تَكُنْ لَكَ بِهَا حَاجَةٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ عِنْدَكَ مِنْ شَىْءٍ تُصْدِقُهَا إِيَّاهُ ‏"‏ ‏.‏ فَقَالَ مَا عِنْدِي إِلاَّ إِزَارِي هَذَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ أَعْطَيْتَهَا إِيَّاهُ جَلَسْتَ لاَ إِزَارَ لَكَ فَالْتَمِسْ شَيْئًا ‏"‏ ‏.‏ فَقَالَ مَا أَجِدُ شَيْئًا ‏.‏ قَالَ ‏"‏ الْتَمِسْ وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏ ‏.‏ فَالْتَمَسَ فَلَمْ يَجِدْ شَيْئًا ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ مَعَكَ مِنَ الْقُرْآنِ شَىْءٌ ‏"‏ ‏.‏ فَقَالَ نَعَمْ مَعِي سُورَةُ كَذَا وَسُورَةُ كَذَا ‏.‏ لِسُوَرٍ سَمَّاهَا ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ أَنْكَحْتُكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{1098}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Malik from Abu Hazim ibn Dinar from Sahl ibn Sad as-Saidi that a woman came to the Messenger of Allah, may Allah bless him and grant him peace, and said, "Messenger of Allah! I have given myself to you." She stood for a long time, and then a man got up and said, "Messenger of Allah, marry her to me if you have no need of her." The Messenger of Allah, may Allah bless him and grant him peace, said, "Do you have anything to give her as a bride-price?" He said, "I possess only this lower garment of mine." The Messenger of Allah, may Allah bless him and grant him peace, said, "If you give it to her you will not have a garment to wear so look for something else." He said, "I have nothing else." He said, "Look for something else, even if it is only an iron ring." He looked, and found that he had nothing. The Messenger of Allah, may Allah bless him and grant him peace, said, "Do you know any of the Qur'an?" He said, "Yes. I know such-and-such a sura and such-and-such a sura," which he named. The Messengerof Allah, may Allah bless him and grant him peace, said to him, "I have married her to you for what you know of the Qur'an}}
\hadithdefcmd{malik}{1099}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ أَيُّمَا رَجُلٍ تَزَوَّجَ امْرَأَةً وَبِهَا جُنُونٌ أَوْ جُذَامٌ أَوْ بَرَصٌ فَمَسَّهَا فَلَهَا صَدَاقُهَا كَامِلاً وَذَلِكَ لِزَوْجِهَا غُرْمٌ عَلَى وَلِيِّهَا ‏.‏ قَالَ مَالِكٌ وَإِنَّمَا يَكُونُ ذَلِكَ غُرْمًا عَلَى وَلِيِّهَا لِزَوْجِهَا إِذَا كَانَ وَلِيُّهَا الَّذِي أَنْكَحَهَا هُوَ أَبُوهَا أَوْ أَخُوهَا أَوْ مَنْ يُرَى أَنَّهُ يَعْلَمُ ذَلِكَ مِنْهَا فَأَمَّا إِذَا كَانَ وَلِيُّهَا الَّذِي أَنْكَحَهَا ابْنَ عَمٍّ أَوْ مَوْلًى أَوْ مِنَ الْعَشِيرَةِ مِمَّنْ يُرَى أَنَّهُ لاَ يَعْلَمُ ذَلِكَ مِنْهَا فَلَيْسَ عَلَيْهِ غُرْمٌ وَتَرُدُّ تِلْكَ الْمَرْأَةُ مَا أَخَذَتْهُ مِنْ صَدَاقِهَا وَيَتْرُكُ لَهَا قَدْرَ مَا تُسْتَحَلُّ بِهِ ‏.‏\hadithno{1099}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab had said that Umar ibn al-Khattab said, "If a man marries a woman who is insane, or has leprosy or white leprosy, without being told of her condition by her guardian, and he has sexual relations with her, she keeps her bride-price in its entirety. Her husband has damages against her guardian." Malik said, "The husband has damages against her guardian when the guardian is her father, brother, or one who is deemed to have knowledge of her condition. If the guardian who gives her in marriage is a nephew, a mawla or a member of her tribe who is not deemed to have knowledge of her condition, there are no damages against him, and the woman returns what she has taken of her bride-price, and the husband leaves her whatever amount is thought to be fair}}
\hadithdefcmd{malik}{1100}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ ابْنَةَ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، - وَأُمُّهَا بِنْتُ زَيْدِ بْنِ الْخَطَّابِ - كَانَتْ تَحْتَ ابْنٍ لِعَبْدِ اللَّهِ بْنِ عُمَرَ فَمَاتَ وَلَمْ يَدْخُلْ بِهَا وَلَمْ يُسَمِّ لَهَا صَدَاقًا فَابْتَغَتْ أُمُّهَا صَدَاقَهَا فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ لَيْسَ لَهَا صَدَاقٌ وَلَوْ كَانَ لَهَا صَدَاقٌ لَمْ نُمْسِكْهُ وَلَمْ نَظْلِمْهَا ‏.‏ فَأَبَتْ أُمُّهَا أَنْ تَقْبَلَ ذَلِكَ فَجَعَلُوا بَيْنَهُمْ زَيْدَ بْنَ ثَابِتٍ فَقَضَى أَنْ لاَ صَدَاقَ لَهَا وَلَهَا الْمِيرَاثُ ‏.‏\hadithno{1100}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that the daughter of Ubaydullah ibn Umar whose mother was the daughter of Zayd ibn al- Khattab, married the son of Abdullah ibn Umar. He died and had not yet consummated the marriage or specified her bride-price. Her mother wanted the bride-price, and Abdullah ibn Umar said, "She is not entitled to a bride-price. Had she been entitled to a bride-price, we would not have kept it and we would not do her an injustice. "The mother refused to accept that. Zayd ibn Thabit was brought to adjudicate between them and he decided that she had no bride-price, but that she did inherit}}
\hadithdefcmd{malik}{1101}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، كَتَبَ فِي خِلاَفَتِهِ إِلَى بَعْضِ عُمَّالِهِ أَنَّ كُلَّ مَا اشْتَرَطَ الْمُنْكِحُ - مَنْ كَانَ أَبًا أَوْ غَيْرَهُ - مِنْ حِبَاءٍ أَوْ كَرَامَةٍ فَهُوَ لِلْمَرْأَةِ إِنِ ابْتَغَتْهُ ‏.‏ قَالَ مَالِكٌ فِي الْمَرْأَةِ يُنْكِحُهَا أَبُوهَا وَيَشْتَرِطُ فِي صَدَاقِهَا الْحِبَاءَ يُحْبَى بِهِ إِنَّ مَا كَانَ مِنْ شَرْطٍ يَقَعُ بِهِ النِّكَاحُ فَهُوَ لاِبْنَتِهِ إِنِ ابْتَغَتْهُ وَإِنْ فَارَقَهَا زَوْجُهَا قَبْلَ أَنْ يَدْخُلَ بِهَا فَلِزَوْجِهَا شَطْرُ الْحِبَاءِ الَّذِي وَقَعَ بِهِ النِّكَاحُ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ يُزَوِّجُ ابْنَهُ صَغِيرًا لاَ مَالَ لَهُ إِنَّ الصَّدَاقَ عَلَى أَبِيهِ إِذَا كَانَ الْغُلاَمُ يَوْمَ تَزَوَّجَ لاَ مَالَ لَهُ وَإِنْ كَانَ لِلْغُلاَمِ مَالٌ فَالصَّدَاقُ فِي مَالِ الْغُلاَمِ إِلاَّ أَنْ يُسَمِّيَ الأَبُ أَنَّ الصَّدَاقَ عَلَيْهِ وَذَلِكَ النِّكَاحُ ثَابِتٌ عَلَى الاِبْنِ إِذَا كَانَ صَغِيرًا وَكَانَ فِي وِلاَيَةِ أَبِيهِ ‏.‏ قَالَ مَالِكٌ فِي طَلاَقِ الرَّجُلِ امْرَأَتَهُ قَبْلَ أَنْ يَدْخُلَ بِهَا وَهِيَ بِكْرٌ فَيَعْفُوَ أَبُوهَا عَنْ نِصْفِ الصَّدَاقِ إِنَّ ذَلِكَ جَائِزٌ لِزَوْجِهَا مِنْ أَبِيهَا فِيمَا وَضَعَ عَنْهُ ‏.‏ قَالَ مَالِكٌ وَذَلِكَ أَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى قَالَ فِي كِتَابِهِ ‏\{‏إِلاَّ أَنْ يَعْفُونَ‏\}‏ فَهُنَّ النِّسَاءُ اللاَّتِي قَدْ دُخِلَ بِهِنَّ ‏\{‏أَوْ يَعْفُوَ الَّذِي بِيَدِهِ عُقْدَةُ النِّكَاحِ‏\}‏ فَهُوَ الأَبُ فِي ابْنَتِهِ الْبِكْرِ وَالسَّيِّدُ فِي أَمَتِهِ ‏.‏ قَالَ مَالِكٌ وَهَذَا الَّذِي سَمِعْتُ فِي ذَلِكَ وَالَّذِي عَلَيْهِ الأَمْرُ عِنْدَنَا ‏.‏ قَالَ مَالِكٌ فِي الْيَهُودِيَّةِ أَوِ النَّصْرَانِيَّةِ تَحْتَ الْيَهُودِيِّ أَوِ النَّصْرَانِيِّ فَتُسْلِمُ قَبْلَ أَنْ يَدْخُلَ بِهَا أَنَّهُ لاَ صَدَاقَ لَهَا ‏.‏ قَالَ مَالِكٌ لاَ أَرَى أَنْ تُنْكَحَ الْمَرْأَةُ بِأَقَلَّ مِنْ رُبْعِ دِينَارٍ وَذَلِكَ أَدْنَى مَا يَجِبُ فِيهِ الْقَطْعُ ‏.‏\hadithno{1101}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Umar ibn Abd al-Aziz during his khalifate, wrote to one of his governors, "Whatever a father, or guardian, who gives someone in marriage, makes a condition in the way of unreturnable gift or of favour, belongs to the woman if she wants it." Malik spoke about a woman whose father gave her in marriage and made an unreturnable gift a condition of the bride-price which was to be given. He said, "Whatever is given as a condition by which marriage occurs belongs to the woman if she wants it. If the husband parts from her before the marriage is consummated, the husband has half of the unreturnable gift by which the marriage occurred." Malik said about a man who married off his young son and the son had no wealth at all, that the bride- price was obliged of the father if the young man had no property on the day of marriage. If the young man did have property the bride- price was taken from his property unless the father stipulated that he would pay the bride-price. The marriage was affirmed for the son if he was a minor only if he was under the guardianship of his father. Malik said that if a man divorced his wife before he had consummated the marriage and she was a virgin, her father returned half of the bride-price to him. That half was permitted to the husband from the father to compensate him for his expenses. Malik said that that was because Allah, the Blessed, the Exalted, said in His Book, "Unless they (women with whom he had not consummated marriage) make remission or he makes remission to him in whose hand is the knot of marriage." (Sura 2 ayat 237). (He being the father of a virgin daughter or the master of a female slave.) Malik said, "That is what I have heard about the matter, and that is how things are done among us." Malik said that a jewish or christian woman who was married to a jew or christian and then became muslim before the marriage had been consummated, did not keep anything from the bride-price. Malik said, "I do not think that women should be married for less than a quarter of a dinar. That is the lowest amount for which cutting off the hand is obliged}}
\hadithdefcmd{malik}{1102}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَضَى فِي الْمَرْأَةِ إِذَا تَزَوَّجَهَا الرَّجُلُ أَنَّهُ إِذَا أُرْخِيَتِ السُّتُورُ فَقَدْ وَجَبَ الصَّدَاقُ ‏.‏\hadithno{1102}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Said ibn al-Musayyab that 'Umar ibn al-Khattab decided about the woman who was married by a man and the marriage had been consummated, that the bride-price was obligatory}}
\hadithdefcmd{malik}{1103}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ زَيْدَ بْنَ ثَابِتٍ، كَانَ يَقُولُ إِذَا دَخَلَ الرَّجُلُ بِامْرَأَتِهِ فَأُرْخِيَتْ عَلَيْهِمَا السُّتُورُ فَقَدْ وَجَبَ الصَّدَاقُ ‏.‏\hadithno{1103}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Zayd ibn Thabit said, "When a man takes his wife to his house and co-habits with her then the bride-price is obliged}}
\hadithdefcmd{malik}{1104}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، كَانَ يَقُولُ إِذَا دَخَلَ الرَّجُلُ بِالْمَرْأَةِ فِي بَيْتِهَا صُدِّقَ الرَّجُلُ عَلَيْهَا وَإِذَا دَخَلَتْ عَلَيْهِ فِي بَيْتِهِ صُدِّقَتْ عَلَيْهِ ‏.‏ قَالَ مَالِكٌ أَرَى ذَلِكَ فِي الْمَسِيسِ إِذَا دَخَلَ عَلَيْهَا فِي بَيْتِهَا فَقَالَتْ قَدْ مَسَّنِي وَقَالَ لَمْ أَمَسَّهَا صُدِّقَ عَلَيْهَا فَإِنْ دَخَلَتْ عَلَيْهِ فِي بَيْتِهِ فَقَالَ لَمْ أَمَسَّهَا وَقَالَتْ قَدْ مَسَّنِي صُدِّقَتْ عَلَيْهِ ‏.‏\hadithno{1104}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn al-Musayyab said, "When a man comes to his wife in her room, he is believed. When she comes to him in his room, she is believed." Malik commented, "I think that this refers to sexual intercourse. When he comes in to her in her room and she says, 'He has had intercourse with me' and he says, 'I have not touched her', he is believed. When she comes in to him in his room and he says, 'I have not had intercourse with her' and she says, 'He had intercourse with me', she is believed}}
\hadithdefcmd{malik}{1105}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ الْمَخْزُومِيِّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ تَزَوَّجَ أُمَّ سَلَمَةَ وَأَصْبَحَتْ عِنْدَهُ قَالَ لَهَا ‏ "‏ لَيْسَ بِكِ عَلَى أَهْلِكِ هَوَانٌ إِنْ شِئْتِ سَبَّعْتُ عِنْدَكِ وَسَبَّعْتُ عِنْدَهُنَّ وَإِنْ شِئْتِ ثَلَّثْتُ عِنْدَكِ وَدُرْتُ ‏"‏ ‏.‏ فَقَالَتْ ثَلِّثْ ‏.‏\hadithno{1105}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr ibn Muhammad ibn Amr ibn Hazm from Abd al-Malik ibn Abi Bakr ibn Abd ar- Rahman ibn al-Harith ibn Hisham al-Makhzumi from his father that when the Messenger of Allah, may Allah bless him and grant him peace, married Umm Salama and then spent the night with her, he said to her, "You are not being humbled in your right. If you wish, I will stay with you for seven nights as I stayed seven nights with the others. If you wish, I will stay with you for three nights, and then visit the others in turn." She said, "Stay three nights}}
\hadithdefcmd{malik}{1106}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ كَانَ يَقُولُ لِلْبِكْرِ سَبْعٌ وَلِلثَّيِّبِ ثَلاَثٌ ‏.‏\hadithno{1106}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Humayd at-Tawil that Anas ibn Malik said, "A virgin has seven nights, and a woman who has been previously married has three nights." Malik affirmed, "That is what is done among us." Malik added, "If the man has another wife, he divides his time equally between them after the wedding nights. He does not count the wedding nights against the one he has just married}}
\hadithdefcmd{malik}{1107}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، سُئِلَ عَنِ الْمَرْأَةِ، تَشْتَرِطُ عَلَى زَوْجِهَا أَنَّهُ لاَ يَخْرُجُ بِهَا مِنْ بَلَدِهَا فَقَالَ سَعِيدُ بْنُ الْمُسَيَّبِ يَخْرُجُ بِهَا إِنْ شَاءَ ‏.‏ قَالَ مَالِكٌ فَالأَمْرُ عِنْدَنَا ذَلِكَ أَنَّهُ إِذَا شَرَطَ الرَّجُلُ لِلْمَرْأَةِ وَإِنْ كَانَ ذَلِكَ عِنْدَ عُقْدَةِ النِّكَاحِ أَنْ لاَ أَنْكِحَ عَلَيْكِ وَلاَ أَتَسَرَّرَ إِنَّ ذَلِكَ لَيْسَ بِشَىْءٍ إِلاَّ أَنْ يَكُونَ فِي ذَلِكَ يَمِينٌ بِطَلاَقٍ أَوْ عِتَاقَةٍ فَيَجِبُ ذَلِكَ عَلَيْهِ وَيَلْزَمُهُ ‏.‏\hadithno{1107}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn al-Musayyab was asked about a woman who made a stipulation on her husband not to take her away from her town. Said ibn al-Musayyab said, "He takes her away if he wishes." Malik said, "The custom among us is that when a man marries a woman, and he makes a condition in the marriage contract that he will not marry after her or take a concubine, it means nothing unless there is an oath of divorce or setting-free attached to it. Then it is obliged and required of him}}
\hadithdefcmd{malik}{1108}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ الْمِسْوَرِ بْنِ رِفَاعَةَ الْقُرَظِيِّ، عَنِ الزُّبَيْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الزَّبِيرِ، أَنَّ رِفَاعَةَ بْنَ سِمْوَالٍ، طَلَّقَ امْرَأَتَهُ تَمِيمَةَ بِنْتَ وَهْبٍ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثَلاَثًا فَنَكَحَتْ عَبْدَ الرَّحْمَنِ بْنَ الزَّبِيرِ فَاعْتَرَضَ عَنْهَا فَلَمْ يَسْتَطِعْ أَنْ يَمَسَّهَا فَفَارَقَهَا فَأَرَادَ رِفَاعَةُ أَنْ يَنْكِحَهَا - وَهُوَ زَوْجُهَا الأَوَّلُ الَّذِي كَانَ طَلَّقَهَا - فَذَكَرَ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَنَهَاهُ عَنْ تَزْوِيجِهَا وَقَالَ ‏ "‏ لاَ تَحِلُّ لَكَ حَتَّى تَذُوقَ الْعُسَيْلَةَ ‏"‏ ‏.‏\hadithno{1108}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from al-Miswar ibn Rifaa al- Quradhi from az-Zubayr ibn Abd ar-Rahman ibn az-Zubayr that Rifaa ibn Simwal divorced his wife, Tamima bint Wahb, in the time of the Messenger of Allah, may Allah bless him and grant him peace, three times. Then she married Abd ar-Rahman ibn az-Zubayr and he turned from her and could not consummate the marriage and so he parted from her. Rifaa wanted to marry her again and it was mentioned to the Messenger of Allah, may Allah bless him and grant him peace, and he forbade him to marry her. He said, "She is not halal for you until she has tasted the sweetness of intercourse}}
\hadithdefcmd{malik}{1109}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا سُئِلَتْ عَنْ رَجُلٍ طَلَّقَ امْرَأَتَهُ الْبَتَّةَ فَتَزَوَّجَهَا بَعْدَهُ رَجُلٌ آخَرُ فَطَلَّقَهَا قَبْلَ أَنْ يَمَسَّهَا هَلْ يَصْلُحُ لِزَوْجِهَا الأَوَّلِ أَنْ يَتَزَوَّجَهَا فَقَالَتْ عَائِشَةُ لاَ حَتَّى يَذُوقَ عُسَيْلَتَهَا ‏.‏\hadithno{1109}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from al-Qasim ibn Muhammad that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said when asked whether it was permissible for a man to marry again a wife he had divorced irrevocably if she had married another man who divorced her before consummating the marriage, "Not until she has tasted the sweetness of intercourse}}
\hadithdefcmd{malik}{1110}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ، سُئِلَ عَنْ رَجُلٍ، طَلَّقَ امْرَأَتَهُ الْبَتَّةَ ثُمَّ تَزَوَّجَهَا بَعْدَهُ رَجُلٌ آخَرُ فَمَاتَ عَنْهَا قَبْلَ أَنْ يَمَسَّهَا هَلْ يَحِلُّ لِزَوْجِهَا الأَوَّلِ أَنْ يُرَاجِعَهَا فَقَالَ الْقَاسِمُ بْنُ مُحَمَّدٍ لاَ يَحِلُّ لِزَوْجِهَا الأَوَّلِ أَنْ يُرَاجِعَهَا ‏.‏ قَالَ مَالِكٌ فِي الْمُحَلِّلِ إِنَّهُ لاَ يُقِيمُ عَلَى نِكَاحِهِ ذَلِكَ حَتَّى يَسْتَقْبِلَ نِكَاحًا جَدِيدًا فَإِنْ أَصَابَهَا فِي ذَلِكَ فَلَهَا مَهْرُهَا ‏.‏\hadithno{1110}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that when asked whether it was permissible for a man to return to his wife if he had divorced her irrevocably and then another man had married her after him and died before consummating the marriage, al-Qasim ibn Muhammad said, "It is not halal for the first husband to return to her." Malik said, about the muhallil, that he could not remain in the marriage until he undertook a new marriage. If he had intercourse with her in that marriage, she had her dowry}}
\hadithdefcmd{malik}{1111}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُجْمَعُ بَيْنَ الْمَرْأَةِ وَعَمَّتِهَا وَلاَ بَيْنَ الْمَرْأَةِ وَخَالَتِهَا ‏"‏ ‏.‏\hadithno{1111}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said "One cannot be married to a woman and her paternal aunt, or a woman and her maternal aunt at the same time}}
\hadithdefcmd{malik}{1112}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ كَانَ يَقُولُ يُنْهَى أَنْ تُنْكَحَ الْمَرْأَةُ عَلَى عَمَّتِهَا أَوْ عَلَى خَالَتِهَا وَأَنْ يَطَأَ الرَّجُلُ وَلِيدَةً وَفِي بَطْنِهَا جَنِينٌ لِغَيْرِهِ ‏.‏\hadithno{1112}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab said, "It is forbidden to be married to a woman and her paternal or maternal aunt at the same time, and for a man to have intercourse with a female slave who is carrying another man's child}}
\hadithdefcmd{malik}{1113}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ سُئِلَ زَيْدُ بْنُ ثَابِتٍ عَنْ رَجُلٍ، تَزَوَّجَ امْرَأَةً ثُمَّ فَارَقَهَا قَبْلَ أَنْ يُصِيبَهَا هَلْ تَحِلُّ لَهُ أُمُّهَا فَقَالَ زَيْدُ بْنُ ثَابِتٍ لاَ الأُمُّ مُبْهَمَةٌ لَيْسَ فِيهَا شَرْطٌ وَإِنَّمَا الشَّرْطُ فِي الرَّبَائِبِ ‏.‏\hadithno{1113}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Zayd ibn Thabit asked whether it was halal for a man who married a woman and then separated from her before he had cohabited with her, to marry her mother. Zayd ibn Thabit said, "No. The mother is prohibited unconditionally. There are conditions, however about foster-mothers}}
\hadithdefcmd{malik}{1114}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ غَيْرِ، وَاحِدٍ، أَنَّ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، اسْتُفْتِيَ وَهُوَ بِالْكُوفَةِ عَنْ نِكَاحِ الأُمِّ، بَعْدَ الاِبْنَةِ إِذَا لَمْ تَكُنْ الاِبْنَةُ مُسَّتْ فَأَرْخَصَ فِي ذَلِكَ ثُمَّ إِنَّ ابْنَ مَسْعُودٍ قَدِمَ الْمَدِينَةَ فَسَأَلَ عَنْ ذَلِكَ فَأُخْبِرَ أَنَّهُ لَيْسَ كَمَا قَالَ وَإِنَّمَا الشَّرْطُ فِي الرَّبَائِبِ فَرَجَعَ ابْنُ مَسْعُودٍ إِلَى الْكُوفَةِ فَلَمْ يَصِلْ إِلَى مَنْزِلِهِ حَتَّى أَتَى الرَّجُلَ الَّذِي أَفْتَاهُ بِذَلِكَ فَأَمَرَهُ أَنْ يُفَارِقَ امْرَأَتَهُ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ تَكُونُ تَحْتَهُ الْمَرْأَةُ ثُمَّ يَنْكِحُ أُمَّهَا فَيُصِيبُهَا إِنَّهَا تَحْرُمُ عَلَيْهِ امْرَأَتُهُ وَيُفَارِقُهُمَا جَمِيعًا وَيَحْرُمَانِ عَلَيْهِ أَبَدًا إِذَا كَانَ قَدْ أَصَابَ الأُمَّ فَإِنْ لَمْ يُصِبِ الأُمَّ لَمْ تَحْرُمْ عَلَيْهِ امْرَأَتُهُ وَفَارَقَ الأُمَّ ‏.‏ وَقَالَ مَالِكٌ فِي الرَّجُلِ يَتَزَوَّجُ الْمَرْأَةَ ثُمَّ يَنْكِحُ أُمَّهَا فَيُصِيبُهَا إِنَّهُ لاَ تَحِلُّ لَهُ أُمُّهَا أَبَدًا وَلاَ تَحِلُّ لأَبِيهِ وَلاَ لاِبْنِهِ وَلاَ تَحِلُّ لَهُ ابْنَتُهَا وَتَحْرُمُ عَلَيْهِ امْرَأَتُهُ ‏.‏ قَالَ مَالِكٌ فَأَمَّا الزِّنَا فَإِنَّهُ لاَ يُحَرِّمُ شَيْئًا مِنْ ذَلِكَ لأَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى قَالَ ‏\{‏وَأُمَّهَاتُ نِسَائِكُمْ‏\}‏ فَإِنَّمَا حَرَّمَ مَا كَانَ تَزْوِيجًا وَلَمْ يَذْكُرْ تَحْرِيمَ الزِّنَا فَكُلُّ تَزْوِيجٍ كَانَ عَلَى وَجْهِ الْحَلاَلِ يُصِيبُ صَاحِبُهُ امْرَأَتَهُ فَهُوَ بِمَنْزِلَةِ التَّزْوِيجِ الْحَلاَلِ فَهَذَا الَّذِي سَمِعْتُ وَالَّذِي عَلَيْهِ أَمْرُ النَّاسِ عِنْدَنَا ‏.‏\hadithno{1114}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from more than one source that when Abdullah ibn Masud was in Kufa, he was asked for an opinion about marrying the mother after marrying the daughter when the marriage with the daughter had not been consummated. He permitted it. When Ibn Masud came to Madina, he asked about it and was told that it was not as he had said, and that this condition referred to foster-mothers. Ibn Masud returnedto Kufa,and he had just reached his dwelling when the man who had asked him for the opinion came to visit and he ordered him to separate from his wife. Malik said that if a man married the mother of a woman who was his wife and he had sexual relations with the mother then his wife was haram for him, and he had to separate from both of them. They were both haram to him forever, if he had had sexual relations with the mother. If he had not had relations with the mcther, his wife was not haram for him, and he separated from the mother. Malik explained further about the man who married a woman, and then married her mother and cohabited with her, "The mother will never be halal for him, and she is not halal for his father or his son, and any daughters of hers are not halal for him and so his wife is haram for him." Malik said, "Fornication however, does not make any of that haram because Allah, the Blessed, the Exalted, mentioned 'the mothers of your wives,' as one whom marriage made haram, and he didn't mention the making haram by fornication. Every marriage in a halal manner in which a man cohabits with his wife, is a halal marriage. This is what I have heard, and this is how things are done among us}}
\hadithdefcmd{malik}{1115}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الشِّغَارِ وَالشِّغَارُ أَنْ يُزَوِّجَ الرَّجُلُ ابْنَتَهُ عَلَى أَنْ يُزَوِّجَهُ الآخَرُ ابْنَتَهُ لَيْسَ بَيْنَهُمَا صَدَاقٌ ‏.‏\hadithno{1115}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik said that a man who had committed fornication with a woman and the hadd-punishment had been applied to him for it, could marry that woman's daughter and his son could marry the woman herself if he wished. That was because he had haram relations with her, and the relations Allah had made haram were from the relations made in a halal manner or in a manner resembling marriage. Allah, the Blessed, the Exalted, said, "Do not marry the women your fathers have married. " (Sura 4 ayat 21) Malik said, "If a man were to marry a woman in her idda-period in a halal marriage and have relations with her, it would be haram for his son to marry the woman. That is because the father married her in a halal manner, and the hadd-punishment would not have been applied to him. Any child who was born to him would be attached to him as the father. Just as it would be haram for the son to marry a woman whom his father had married in her idda-period and had relations with, so the woman's daughter would be haram for the father if he had had sexual relations with her." Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, forbade shighar, which meant one man giving his daughter in marriage to another man on the condition that the other gave his daughter to him in marriage without either of them paying the bride-price}}
\hadithdefcmd{malik}{1116}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَبْدِ الرَّحْمَنِ، وَمُجَمِّعٍ، ابْنَىْ يَزِيدَ بْنِ جَارِيَةَ الأَنْصَارِيِّ عَنْ خَنْسَاءَ بِنْتِ خِدَامٍ الأَنْصَارِيَّةِ، أَنَّ أَبَاهَا، زَوَّجَهَا وَهِيَ ثَيِّبٌ فَكَرِهَتْ ذَلِكَ فَأَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَرَدَّ نِكَاحَهُ ‏.‏\hadithno{1116}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim from his father from Abd ar-Rahman and Mujamma the sons of Yazid ibn Jariya al-Ansari from Khansa bint Khidam al-Ansariya that her father gave her in marriage and she had been previously married. She disapproved of that, and went to the Messenger of Allah, may Allah bless him and grant him peace, and he revoked the marriage}}
\hadithdefcmd{malik}{1117}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، أُتِيَ بِنِكَاحٍ لَمْ يَشْهَدْ عَلَيْهِ إِلاَّ رَجُلٌ وَامْرَأَةٌ فَقَالَ هَذَا نِكَاحُ السِّرِّ وَلاَ أُجِيزُهُ وَلَوْ كُنْتُ تَقَدَّمْتُ فِيهِ لَرَجَمْتُ ‏.‏\hadithno{1117}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Abu'z-Zubayr al-Makki that a case was brought to Umar about a marriage which had only been witnessed by one man and one woman . He said, "This is a secret marriage and I do not permit it. Had I been the first to come upon it, I would have ordered them to be stoned}}
\hadithdefcmd{malik}{1118}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَعَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّ طُلَيْحَةَ الأَسَدِيَّةَ، كَانَتْ تَحْتَ رُشَيْدٍ الثَّقَفِيِّ فَطَلَّقَهَا فَنَكَحَتْ فِي عِدَّتِهَا فَضَرَبَهَا عُمَرُ بْنُ الْخَطَّابِ وَضَرَبَ زَوْجَهَا بِالْمِخْفَقَةِ ضَرَبَاتٍ وَفَرَّقَ بَيْنَهُمَا ثُمَّ قَالَ عُمَرُ بْنُ الْخَطَّابِ أَيُّمَا امْرَأَةٍ نَكَحَتْ فِي عِدَّتِهَا فَإِنْ كَانَ زَوْجُهَا الَّذِي تَزَوَّجَهَا لَمْ يَدْخُلْ بِهَا فُرِّقَ بَيْنَهُمَا ثُمَّ اعْتَدَّتْ بَقِيَّةَ عِدَّتِهَا مِنْ زَوْجِهَا الأَوَّلِ ثُمَّ كَانَ الآخَرُ خَاطِبًا مِنَ الْخُطَّابِ وَإِنْ كَانَ دَخَلَ بِهَا فُرِّقَ بَيْنَهُمَا ثُمَّ اعْتَدَّتْ بَقِيَّةَ عِدَّتِهَا مِنَ الأَوَّلِ ثُمَّ اعْتَدَّتْ مِنَ الآخَرِ ثُمَّ لاَ يَجْتَمِعَانِ أَبَدًا ‏.‏ قَالَ\hadithno{1118}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Said ibn al- Musayyab and from Sulayman ibn Yasar that Tulayha al-Asadiya was the wife of Rushayd ath-Thaqafi. He divorced her, and she got married in her idda-period. Umar ibn al-Khattab beat her and her husband with a stick several times, and separated them. Then Umar ibn al-Khattab said, "If a woman marries in her idda-period, and the new husband has not consummated the marriage, then separate them, and when she has completed the idda of her first husband, the other becomes a suitor. If he has consummated the marriage then separate them. Then she must complete her idda from her first husband, and then the idda from the other one, and they are never to be reunited." Malik added, ''Said ibn al-Musayyab said that she had her dowry because he had consummated the marriage." Malik said,"The practice with us concerning a free woman whose husband dies, is that she does an idda of four months and ten days and she does not marry if she doubts her period until she is free of any doubt or if she fears that she is pregnant}}
\hadithdefcmd{malik}{1119}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، وَعَبْدَ اللَّهِ بْنَ عُمَرُ، سُئِلاَ عَنْ رَجُلٍ، كَانَتْ تَحْتَهُ امْرَأَةٌ حُرَّةٌ فَأَرَادَ أَنْ يَنْكِحَ عَلَيْهَا أَمَةً فَكَرِهَا أَنْ يَجْمَعَ بَيْنَهُمَا ‏.‏\hadithno{1119}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Abbas and Abdullah ibn Umar were asked about a man who had a free woman as a wife and then wanted to marry a slave-girl. They disapproved that he should combine the two of them}}
\hadithdefcmd{malik}{1120}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ كَانَ يَقُولُ لاَ تُنْكَحُ الأَمَةُ عَلَى الْحُرَّةِ إِلاَّ أَنْ تَشَاءَ الْحُرَّةُ فَإِنْ طَاعَتِ الْحُرَّةُ فَلَهَا الثُّلُثَانِ مِنَ الْقَسْمِ ‏.‏ قَالَ مَالِكٌ وَلاَ يَنْبَغِي لِحُرٍّ أَنْ يَتَزَوَّجَ أَمَةً وَهُوَ يَجِدُ طَوْلاً لِحُرَّةٍ وَلاَ يَتَزَوَّجَ أَمَةً إِذَا لَمْ يَجِدْ طَوْلاً لِحُرَّةٍ إِلاَّ أَنْ يَخْشَى الْعَنَتَ وَذَلِكَ أَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى قَالَ فِي كِتَابِهِ ‏\{‏وَمَنْ لَمْ يَسْتَطِعْ مِنْكُمْ طَوْلاً أَنْ يَنْكِحَ الْمُحْصَنَاتِ الْمُؤْمِنَاتِ فَمِمَّا مَلَكَتْ أَيْمَانُكُمْ مِنْ فَتَيَاتِكُمُ الْمُؤْمِنَاتِ‏\}‏ وَقَالَ ‏\{‏ذَلِكَ لِمَنْ خَشِيَ الْعَنَتَ مِنْكُمْ‏\}‏ قَالَ مَالِكٌ وَالْعَنَتُ هُوَ الزِّنَا ‏.‏\hadithno{1120}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab said, "The slave girl is not married when there is a free woman who is a wife unless the free woman wishes it. If the free woman complies, she has two-thirds of the division of time." Malik said, "A free man must not marry a slave-girl when he can afford to marry a free-woman, and he should not marry a slave-girl when he cannot afford a free woman unless he fears fornication. That is because Allah, may he be Blessed and Exalted, says in His Book, 'If you are not affluent enough to marry believing women, who are muhsanat, take slave-girls who are believing women that your right hands own.' (Sura 4 ayat 24) He says, 'That is for those of you who fear al-anat.' " Malik said, "Al-anat is fornication}}
\hadithdefcmd{malik}{1121}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّهُ كَانَ يَقُولُ فِي الرَّجُلِ يُطَلِّقُ الأَمَةَ ثَلاَثًا ثُمَّ يَشْتَرِيهَا إِنَّهَا لاَ تَحِلُّ لَهُ حَتَّى تَنْكِحَ زَوْجًا غَيْرَهُ ‏.‏\hadithno{1121}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Abu Abd ar- Rahman that Zayd ibn Thabit said that if a man divorced his slave-girl three times and then bought her, she was not halal for him until she had married another husband}}
\hadithdefcmd{malik}{1122}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، وَسُلَيْمَانَ بْنَ يَسَارٍ، سُئِلاَ عَنْ رَجُلٍ، زَوَّجَ عَبْدًا لَهُ جَارِيَةً فَطَلَّقَهَا الْعَبْدُ الْبَتَّةَ ثُمَّ وَهَبَهَا سَيِّدُهَا لَهُ هَلْ تَحِلُّ لَهُ بِمِلْكِ الْيَمِينِ فَقَالاَ لاَ تَحِلُّ لَهُ حَتَّى تَنْكِحَ زَوْجًا غَيْرَهُ ‏.‏\hadithno{1122}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn al-Musayyab and Sulayman ibn Yasar were asked whether, when a man married a slave of his to a slave-girl and the slave divorced her irrevocably, and then her master gave her to the slave, she was then halal for the slave by the possession of the right hand. They said, "No. She is not halal until she has married another husband}}
\hadithdefcmd{malik}{1123}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ سَأَلَ ابْنَ شِهَابٍ عَنْ رَجُلٍ، كَانَتْ تَحْتَهُ أَمَةٌ مَمْلُوكَةٌ فَاشْتَرَاهَا وَقَدْ كَانَ طَلَّقَهَا وَاحِدَةً فَقَالَ تَحِلُّ لَهُ بِمِلْكِ يَمِينِهِ مَا لَمْ يَبُتَّ طَلاَقَهَا فَإِنْ بَتَّ طَلاَقَهَا فَلاَ تَحِلُّ لَهُ بِمِلْكِ يَمِينِهِ حَتَّى تَنْكِحَ زَوْجًا غَيْرَهُ ‏.‏ قَالَ مَالِكٌ فِي الرَّجُلِ يَنْكِحُ الأَمَةَ فَتَلِدُ مِنْهُ ثُمَّ يَبْتَاعُهَا إِنَّهَا لاَ تَكُونُ أُمَّ وَلَدٍ لَهُ بِذَلِكَ الْوَلَدِ الَّذِي وَلَدَتْ مِنْهُ وَهِيَ لِغَيْرِهِ حَتَّى تَلِدَ مِنْهُ وَهِيَ فِي مِلْكِهِ بَعْدَ ابْتِيَاعِهِ إِيَّاهَا ‏.‏ قَالَ مَالِكٌ وَإِنِ اشْتَرَاهَا وَهِيَ حَامِلٌ مِنْهُ ثُمَّ وَضَعَتْ عِنْدَهُ كَانَتْ أُمَّ وَلَدِهِ بِذَلِكَ الْحَمْلِ فِيمَا نُرَى وَاللَّهُ أَعْلَمُ ‏.‏\hadithno{1123}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he had asked Ibn Shihab about a man who had a slave-girl as a wife, and then he bought her, and divorced her once. He said, "She is halal for him by the possession of the right hand as long as he does not make his divorce irrevocable. If he irrevocably divorces her, she is not halal for him by the possession of the right hand until she has married another husband." Malik said that if a man rnarried a female slave and then she had a child by him, and then he bought her, she was not an umm walad for him because of the child born to him while she belonged to another, until she had had a child by him while she was in his possession after he had purchased her. Malik said, "If he buys her and she is pregnant by him and she then gives birth while she belongs to him, she is his umm walad by that pregnancy, according to what we think, and Allah knows best}}
\hadithdefcmd{malik}{1124}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، سُئِلَ عَنِ الْمَرْأَةِ، وَابْنَتِهَا، مِنْ مِلْكِ الْيَمِينِ تُوطَأُ إِحْدَاهُمَا بَعْدَ الأُخْرَى فَقَالَ عُمَرُ مَا أُحِبُّ أَنْ أَخْبُرَهُمَا جَمِيعًا ‏.‏ وَنَهَى عَنْ ذَلِكَ ‏.‏\hadithno{1124}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Ubaydullah ibn Abdullah ibn Utba ibn Masud from his father that Umar ibn al- Khattab was asked about a woman and her daughter who were in the possession of the right hand, and whether one could have intercourse with one of them after the other Umar said, "I dislike both being permitted together." He then forbade that}}
\hadithdefcmd{malik}{1125}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ قَبِيصَةَ بْنِ ذُؤَيْبٍ، أَنَّ رَجُلاً، سَأَلَ عُثْمَانَ بْنَ عَفَّانَ عَنِ الأُخْتَيْنِ، مِنْ مِلْكِ الْيَمِينِ هَلْ يُجْمَعُ بَيْنَهُمَا فَقَالَ عُثْمَانُ أَحَلَّتْهُمَا آيَةٌ وَحَرَّمَتْهُمَا آيَةٌ فَأَمَّا أَنَا فَلاَ أُحِبُّ أَنْ أَصْنَعَ ذَلِكَ ‏.‏ قَالَ فَخَرَجَ مِنْ عِنْدِهِ فَلَقِيَ رَجُلاً مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ عَنْ ذَلِكَ فَقَالَ لَوْ كَانَ لِي مِنَ الأَمْرِ شَىْءٌ ثُمَّ وَجَدْتُ أَحَدًا فَعَلَ ذَلِكَ لَجَعَلْتُهُ نَكَالاً ‏.‏ قَالَ ابْنُ شِهَابٍ أُرَاهُ عَلِيَّ بْنَ أَبِي طَالِبٍ ‏.‏\hadithno{1125}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Qabisa ibn Dhu'ayb that a man asked Uthman ibn Affan whether one could have intercourse with two sisters who one owned. Uthman said, "One ayat makes them halal, and one ayat makes them haram. As for me, I wouldn't like to do it." The man left him and met one of the companions of the Messenger of Allah, may Allah bless him and grant him peace, and asked him about it, and he said, "Had I any authority and I found someone who had done it, I would punish him as an example." Ibn Shihab added, "I think that it was Ali ibn Abi Talib}}
\hadithdefcmd{malik}{1126}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنِ الزُّبَيْرِ بْنِ الْعَوَّامِ، مِثْلُ ذَلِكَ ‏.‏ قَالَ مَالِكٌ فِي الأَمَةِ تَكُونُ عِنْدَ الرَّجُلِ فَيُصِيبُهَا ثُمَّ يُرِيدُ أَنْ يُصِيبَ أُخْتَهَا إِنَّهَا لاَ تَحِلُّ لَهُ حَتَّى يُحَرِّمَ عَلَيْهِ فَرْجَ أُخْتِهَا بِنِكَاحٍ أَوْ عِتَاقَةٍ أَوْ كِتَابَةٍ أَوْ مَا أَشْبَهَ ذَلِكَ يُزَوِّجُهَا عَبْدَهُ أَوْ غَيْرَ عَبْدِهِ ‏.‏\hadithno{1126}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that az-Zubayr ibn al-Awwam said the like of that. Malik said that if a man had sexual relations with a female slave that he owned, and then he wanted to also have relations with her sister, the sister was not halal for a man until intercourse with the slave-girl had been made haram for him by marriage, setting free, kitaba, or the like of that - for instance, if he had married her to his slave or someone other than his slave}}
\hadithdefcmd{malik}{1127}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، وَهَبَ لاِبْنِهِ جَارِيَةً فَقَالَ لاَ تَمَسَّهَا فَإِنِّي قَدْ كَشَفْتُهَا ‏.‏\hadithno{1127}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Umar ibn al-Khattab gave his son a slave-girl and said, "Do not touch her, for I have uncovered her}}
\hadithdefcmd{malik}{1128}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْمُجَبَّرِ، أَنَّهُ قَالَ وَهَبَ سَالِمُ بْنُ عَبْدِ اللَّهِ لاِبْنِهِ جَارِيَةً قَالَ لاَ تَقْرَبْهَا فَإِنِّي قَدْ أَرَدْتُهَا فَلَمْ أَنْشَطْ إِلَيْهَا ‏.‏\hadithno{1128}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Abd arRahman ibn al-Mujabbir said that Salim ibn Abdullah gave his son a slave-girl and said, "Do not go near her, for I wanted her, and did not act towards her}}
\hadithdefcmd{malik}{1129}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ أَبَا نَهْشَلِ بْنَ الأَسْوَدِ، قَالَ لِلْقَاسِمِ بْنِ مُحَمَّدٍ إِنِّي رَأَيْتُ جَارِيَةً لِي مُنْكَشِفًا عَنْهَا وَهِيَ فِي الْقَمَرِ فَجَلَسْتُ مِنْهَا مَجْلِسَ الرَّجُلِ مِنِ امْرَأَتِهِ فَقَالَتْ إِنِّي حَائِضٌ فَقُمْتُ فَلَمْ أَقْرَبْهَا بَعْدُ أَفَأَهَبُهَا لاِبْنِي يَطَؤُهَا فَنَهَاهُ الْقَاسِمُ عَنْ ذَلِكَ ‏.‏\hadithno{1129}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Abu Nahshal ibn al-Aswad said to al-Qasim ibn Muhammad,"I saw a slave-girl of mine uncovered in the moonlight, and so I sat on her as a man sits on a woman. She said that she was menstruating, so I stood up and have not gone near her after that. Can I give her to my son to have intercourse with?" Al-Qasim forbade that}}
\hadithdefcmd{malik}{1130}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِبْرَاهِيمَ بْنِ أَبِي عَبْلَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ مَرْوَانَ، أَنَّهُ وَهَبَ لِصَاحِبٍ لَهُ جَارِيَةً ثُمَّ سَأَلَهُ عَنْهَا فَقَالَ قَدْ هَمَمْتُ أَنْ أَهَبَهَا لاِبْنِي فَيَفْعَلَ بِهَا كَذَا وَكَذَا ‏.‏ فَقَالَ عَبْدُ الْمَلِكِ لَمَرْوَانُ كَانَ أَوْرَعَ مِنْكَ وَهَبَ لاِبْنِهِ جَارِيَةً ثُمَّ قَالَ لاَ تَقْرَبْهَا فَإِنِّي قَدْ رَأَيْتُ سَاقَهَا مُنْكَشِفَةً ‏.‏\hadithno{1130}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Ibrahim ibn Abi Abla from Abd al-Malik ibn Marwan that he gave a slave-girl to a friend of his, and later asked him about her. He said, "I intended to give her to my son to do such-and-such with her." Abd al-Malik said, "Marwan was more scrupulous than you. He gave a slave-girl to his son, and then he said, 'Do not go near her, for I have seen her leg uncovered}}
\hadithdefcmd{malik}{1131}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ الْمُحْصَنَاتُ مِنَ النِّسَاءِ هُنَّ أُولاَتُ الأَزْوَاجِ وَيَرْجِعُ ذَلِكَ إِلَى أَنَّ اللَّهَ حَرَّمَ الزِّنَا ‏.‏\hadithno{1131}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik said, "It is not halal to marry a christian or jewish slave-girl because Allah the Blessed, the Exalted, said in His Book, 'Believing women who are muhsanat and women of those who were given the Book before you who are muhsanat', (sura 5 ayat 6) and they are free women from the Christians and Jews. Allah, the Blessed, the Exalted, said in His Book, 'If you are not affluent enough to marry believing women who are muhsanat, take believing slave-girls whom your right hands own.' " (Sura 4 ayat 24) Malik said, "In our opinion, Allah made marriage to believing slave-girls halal, and He did not make halal marriage to christian and jewish slave-girls from the People of the Book." Malik said, "The christian and jewish slave-girl are halal for their master by right of possession, but intercourse with a magian slave-girl is not halal by the right of possession." Yahya related to me from Malik from Ibn Shihab that Said ibn al- Musayyab said, "The muhsanat among women are those who have husbands." That referred to the fact that Allah has made fornication haram}}
\hadithdefcmd{malik}{1132}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، وَبَلَغَهُ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، أَنَّهُمَا كَانَا يَقُولاَنِ إِذَا نَكَحَ الْحُرُّ الأَمَةَ فَمَسَّهَا فَقَدْ أَحْصَنَتْهُ ‏.‏ قَالَ مَالِكٌ وَكُلُّ مَنْ أَدْرَكْتُ كَانَ يَقُولُ ذَلِكَ تُحْصِنُ الأَمَةُ الْحُرَّ إِذَا نَكَحَهَا فَمَسَّهَا فَقَدْ أَحْصَنَتْهُ ‏.‏ قَالَ مَالِكٌ يُحْصِنُ الْعَبْدُ الْحُرَّةَ إِذَا مَسَّهَا بِنِكَاحٍ وَلاَ تُحْصِنُ الْحُرَّةُ الْعَبْدَ إِلاَّ أَنْ يَعْتِقَ وَهُوَ زَوْجُهَا فَيَمَسَّهَا بَعْدَ عِتْقِهِ فَإِنْ فَارَقَهَا قَبْلَ أَنْ يَعْتِقَ فَلَيْسَ بِمُحْصَنٍ حَتَّى يَتَزَوَّجَ بَعْدَ عِتْقِهِ وَيَمَسَّ امْرَأَتَهُ ‏.‏ قَالَ مَالِكٌ وَالأَمَةُ إِذَا كَانَتْ تَحْتَ الْحُرِّ ثُمَّ فَارَقَهَا قَبْلَ أَنْ تَعْتِقَ فَإِنَّهُ لاَ يُحْصِنُهَا نِكَاحُهُ إِيَّاهَا وَهِيَ أَمَةٌ حَتَّى تُنْكَحَ بَعْدَ عِتْقِهَا وَيُصِيبَهَا زَوْجُهَا فَذَلِكَ إِحْصَانُهَا وَالأَمَةُ إِذَا كَانَتْ تَحْتَ الْحُرِّ فَتَعْتِقُ وَهِيَ تَحْتَهُ قَبْلَ أَنْ يُفَارِقَهَا فَإِنَّهُ يُحْصِنُهَا إِذَا عَتَقَتْ وَهِيَ عِنْدَهُ إِذَا هُوَ أَصَابَهَا بَعْدَ أَنْ تَعْتِقَ ‏.‏ وَقَالَ مَالِكٌ وَالْحُرَّةُ النَّصْرَانِيَّةُ وَالْيَهُودِيَّةُ وَالأَمَةُ الْمُسْلِمَةُ يُحْصِنَّ الْحُرَّ الْمُسْلِمَ إِذَا نَكَحَ إِحْدَاهُنَّ فَأَصَابَهَا ‏.‏\hadithno{1132}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab, and he had heard from al-Qasim ibn Muhammad that they said, "When a free man marries a slave-girl and consummates the marriage, she makes him muhsan." Malik said, "All (of the people of knowledge) I have seen said that a slave-girl makes a free man muhsan when he marries her and consummates the marriage." Malik said, "A slave makes a free woman muhsana when he consummates a marriage with her and a free woman only makes a slave muhsan when he is freed and he is her husband and has had sexual relations with her after he has been set free. If he parts from her before he is free, he is not a muhsan unless he marries her after having been set free and he consummates the marriage." Malik said, "When a slave-girl is married to a free man and then he separates from her before she is set free, his marriage to her does not make her muhsana. She is not muhsana until she has married after she has been set free and she has had intercourse with her husband. That gives her ihsan. If she is the wife of a freeman and then she is set free while she is his wife before he separates from her, the man makes her muhsana if he has intercourse with her after she has been set free." Malik said, "The christian and jewish free women and the muslim slave-girl all make a muslim free man muhsan when he marries one of them and has intercourse with her}}
\hadithdefcmd{malik}{1133}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ، وَالْحَسَنِ، ابْنَىْ مُحَمَّدِ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ عَنْ أَبِيهِمَا، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ مُتْعَةِ النِّسَاءِ يَوْمَ خَيْبَرَ وَعَنْ أَكْلِ لُحُومِ الْحُمُرِ الإِنْسِيَّةِ ‏.‏\hadithno{1133}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Abdullah and Hasan, the sons of Muhammad ibn Ali ibn Abi Talib from their ather, mayAllah be pleased with him, that the Messenger of Allah, may Allah bless him and grant him peace, forbade temporary marriage with women and the flesh of domestic donkeys on the Day of Khaybar}}
\hadithdefcmd{malik}{1134}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ خَوْلَةَ بِنْتَ حَكِيمٍ، دَخَلَتْ عَلَى عُمَرَ بْنِ الْخَطَّابِ فَقَالَتْ إِنَّ رَبِيعَةَ بْنَ أُمَيَّةَ اسْتَمْتَعَ بِامْرَأَةٍ فَحَمَلَتْ مِنْهُ ‏.‏ فَخَرَجَ عُمَرُ بْنُ الْخَطَّابِ فَزِعًا يَجُرُّ رِدَاءَهُ فَقَالَ هَذِهِ الْمُتْعَةُ وَلَوْ كُنْتُ تَقَدَّمْتُ فِيهَا لَرَجَمْتُ ‏.‏\hadithno{1134}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Urwa ibn az- Zubayr that Khawla ibn Hakim came to Umar ibn al-Khattab and said, ''Rabia ibn Umayya made a temporary marriage with a woman and she is pregnant by him.'' Umar ibn al-Khattab went out in dismay dragging his cloak, saying, "This temporary marriage, had I come across it, I would have ordered stoning and done away with it}}
\hadithdefcmd{malik}{1135}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ سَمِعَ رَبِيعَةَ بْنَ أَبِي عَبْدِ الرَّحْمَنِ، يَقُولُ يَنْكِحُ الْعَبْدُ أَرْبَعَ نِسْوَةٍ ‏.‏ قَالَ مَالِكٌ وَهَذَا أَحْسَنُ مَا سَمِعْتُ فِي ذَلِكَ ‏.‏ قَالَ مَالِكٌ وَالْعَبْدُ مُخَالِفٌ لِلْمُحَلِّلِ إِنْ أَذِنَ لَهُ سَيِّدُهُ ثَبَتَ نِكَاحُهُ وَإِنْ لَمْ يَأْذَنْ لَهُ سَيِّدُهُ فُرِّقَ بَيْنَهُمَا وَالْمُحَلِّلُ يُفَرَّقُ بَيْنَهُمَا عَلَى كُلِّ حَالٍ إِذَا أُرِيدَ بِالنِّكَاحِ التَّحْلِيلُ ‏.‏ قَالَ مَالِكٌ فِي الْعَبْدِ إِذَا مَلَكَتْهُ امْرَأَتُهُ أَوِ الزَّوْجُ يَمْلِكُ امْرَأَتَهُ إِنَّ مِلْكَ كُلِّ وَاحِدٍ مِنْهُمَا صَاحِبَهُ يَكُونُ فَسْخًا بِغَيْرِ طَلاَقٍ وَإِنْ تَرَاجَعَا بِنِكَاحٍ بَعْدُ لَمْ تَكُنْ تِلْكَ الْفُرْقَةُ طَلاَقًا ‏.‏ قَالَ مَالِكٌ وَالْعَبْدُ إِذَا أَعْتَقَتْهُ امْرَأَتُهُ إِذَا مَلَكَتْهُ وَهِيَ فِي عِدَّةٍ مِنْهُ لَمْ يَتَرَاجَعَا إِلاَّ بِنِكَاحٍ جَدِيدٍ ‏.‏\hadithno{1135}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that he heard Rabia ibn Abd ar- Rahman say that a slave could marry four women. Malik said, "This is the best of what I have heard about the matter." Malik said, "The slave differs with the muhallil if the slave is given permission by his master for his ex-wife. If his master does not give him permission, he separates them. The muhallil is separated in any case if he intends to make the woman halal by marriage." Malik said, "When a slave is owned by his wife or a husband owns his wife, the possession of each of them is rendered void without divorce. If a man, for instance, is married to a slave-girl, and then he buys her, he must divorce her as a matter of course. They can then re- marry. If they re-marry afterwards, that separation was not divorce." Malik said, "When a slave is freed by his wife who owns him and she is in the idda-period from him, they can only return to each other after she has made another marriage}}
\hadithdefcmd{malik}{1136}{حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ بَلَغَهُ أَنَّ نِسَاءً، كُنَّ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم يُسْلِمْنَ بِأَرْضِهِنَّ وَهُنَّ غَيْرُ مُهَاجِرَاتٍ وَأَزْوَاجُهُنَّ حِينَ أَسْلَمْنَ كُفَّارٌ مِنْهُنَّ بِنْتُ الْوَلِيدِ بْنِ الْمُغِيرَةِ ‏.‏ وَكَانَتْ تَحْتَ صَفْوَانَ بْنِ أُمَيَّةَ فَأَسْلَمَتْ يَوْمَ الْفَتْحِ وَهَرَبَ زَوْجُهَا صَفْوَانُ بْنُ أُمَيَّةَ مِنَ الإِسْلاَمِ فَبَعَثَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ابْنَ عَمِّهِ وَهْبَ بْنَ عُمَيْرٍ بِرِدَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَمَانًا لِصَفْوَانَ بْنِ أُمَيَّةَ وَدَعَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الإِسْلاَمِ وَأَنْ يَقْدَمَ عَلَيْهِ فَإِنْ رَضِيَ أَمْرًا قَبِلَهُ وَإِلاَّ سَيَّرَهُ شَهْرَيْنِ فَلَمَّا قَدِمَ صَفْوَانُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِرِدَائِهِ نَادَاهُ عَلَى رُءُوسِ النَّاسِ فَقَالَ يَا مُحَمَّدُ إِنَّ هَذَا وَهْبَ بْنَ عُمَيْرٍ جَاءَنِي بِرِدَائِكَ وَزَعَمَ أَنَّكَ دَعَوْتَنِي إِلَى الْقُدُومِ عَلَيْكَ فَإِنْ رَضِيتُ أَمْرًا قَبِلْتُهُ وَإِلاَّ سَيَّرْتَنِي شَهْرَيْنِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ انْزِلْ أَبَا وَهْبٍ ‏"‏ ‏.‏ فَقَالَ لاَ وَاللَّهِ لاَ أَنْزِلُ حَتَّى تُبَيِّنَ لِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَلْ لَكَ تَسِيرُ أَرْبَعَةَ أَشْهُرٍ ‏"‏ ‏.‏ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم قِبَلَ هَوَازِنَ بِحُنَيْنٍ ‏.‏ فَأَرْسَلَ إِلَى صَفْوَانَ بْنِ أُمَيَّةَ يَسْتَعِيرُهُ أَدَاةً وَسِلاَحًا عِنْدَهُ فَقَالَ صَفْوَانُ أَطَوْعًا أَمْ كَرْهًا فَقَالَ ‏"‏ بَلْ طَوْعًا ‏"‏ ‏.‏ فَأَعَارَهُ الأَدَاةَ وَالسِّلاَحَ الَّتِي عِنْدَهُ ثُمَّ خَرَجَ صَفْوَانُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ كَافِرٌ فَشَهِدَ حُنَيْنًا وَالطَّائِفَ وَهُوَ كَافِرٌ وَامْرَأَتُهُ مُسْلِمَةٌ وَلَمْ يُفَرِّقْ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَهُ وَبَيْنَ امْرَأَتِهِ حَتَّى أَسْلَمَ صَفْوَانُ وَاسْتَقَرَّتْ عِنْدَهُ امْرَأَتُهُ بِذَلِكَ النِّكَاحِ ‏.‏\hadithno{1136}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Malik related to me from Ibn Shihab that he had heard that in the time of the Messenger of Allah, may Allah bless him and grant him peace, women were becoming muslim in their own lands and they did not do hijra while their husbands were still kafirun although they themselves had become muslim. Among them was the daughter of al-Walid ibn al-Mughira and she was the wife of Safwan ibn Umayya. She became muslim on the day of the conquest (of Makka), and her husband, Safwan ibn Umayya fled from Islam. The Messenger of Allah, may Allah bless him and grant him peace, sent Safwan's paternal cousin, Wahb ibn Umayr with the cloak of the Messenger of Allah, may Allah bless him and grant him peace, as a safe-conduct for Safwan ibn Umayya, and the Messenger of Allah, may Allah bless him and grant him peace, called him to Islam and asked for him to come to him and if he was pleased with the matter to accept it. If not he would have a respite for two months. When Safwan came to the Messenger of Allah, may Allah bless him and grant him peace, with his cloak, he called out to him over the heads of the people, "Muhammad! Wahb ibn Umayr brought me your cloak and claimed that you had summoned me to come to you and if I was pleased with the matter, I should accept it and if not, you would give me a respite for two months. "The Messenger of Allah, may Allah bless him and grant him peace, said, "Come down, Abu Wahb." He said, "No, by Allah! I will not come down until you make it clear to me." The Messenger of Allah, may Allah bless him and grant him peace, said, "You have a respite of four months." The Messenger of Allah, may Allah bless him and grant him peace, went out toward Hawazin at Hunayn. He sent to Safwan ibn Umayya to borrow some equipment and arms that he had. Safwan said, "Willingly or unwillingly?" He said, "Willingly." Therefore he lent him the equipment and arms which he had. Then Safwan went out with the Messenger of Allah, may Allah bless him and grant him peace, while he was still a kafir. He was present at the battles of Hunayn and at-Ta'if while he was still a kafir and his wife was a muslim. The Messenger of Allah, may Allah bless him and grant him peace, did not separate Safwan and his wife until he had become muslim, and his wife was settled with him by that marriage}}
\hadithdefcmd{malik}{1137}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ كَانَ بَيْنَ إِسْلاَمِ صَفْوَانَ وَبَيْنَ إِسْلاَمِ امْرَأَتِهِ نَحْوٌ مِنْ شَهْرٍ ‏.‏ قَالَ ابْنُ شِهَابٍ وَلَمْ يَبْلُغْنَا أَنَّ امْرَأَةً هَاجَرَتْ إِلَى اللَّهِ وَرَسُولِهِ وَزَوْجُهَا كَافِرٌ مُقِيمٌ بِدَارِ الْكُفْرِ إِلاَّ فَرَّقَتْ هِجْرَتُهَا بَيْنَهَا وَبَيْنَ زَوْجِهَا إِلاَّ أَنْ يَقْدَمَ زَوْجُهَا مُهَاجِرًا قَبْلَ أَنْ تَنْقَضِيَ عِدَّتُهَا ‏.‏\hadithno{1137}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik that Ibn Shihab said, "Between the Islam of Safwan and the Islam of his wife there was about one month." Ibn Shihab said, "We have not heard about any woman doing hijra for Allah and His Messenger while her husband was a kafir abiding in the land of kufr, but that her hijra separated her and her husband unless her husband came in hijra before her period of idda had been completed}}
\hadithdefcmd{malik}{1138}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ أُمَّ حَكِيمٍ بِنْتَ الْحَارِثِ بْنِ هِشَامٍ، وَكَانَتْ، تَحْتَ عِكْرِمَةَ بْنِ أَبِي جَهْلٍ فَأَسْلَمَتْ يَوْمَ الْفَتْحِ وَهَرَبَ زَوْجُهَا عِكْرِمَةُ بْنُ أَبِي جَهْلٍ مِنَ الإِسْلاَمِ حَتَّى قَدِمَ الْيَمَنَ فَارْتَحَلَتْ أُمُّ حَكِيمٍ حَتَّى قَدِمَتْ عَلَيْهِ بِالْيَمَنِ فَدَعَتْهُ إِلَى الإِسْلاَمِ فَأَسْلَمَ وَقَدِمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ فَلَمَّا رَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَثَبَ إِلَيْهِ فَرِحًا وَمَا عَلَيْهِ رِدَاءٌ حَتَّى بَايَعَهُ فَثَبَتَا عَلَى نِكَاحِهِمَا ذَلِكَ ‏.‏ قَالَ مَالِكٌ وَإِذَا أَسْلَمَ الرَّجُلُ قَبْلَ امْرَأَتِهِ وَقَعَتِ الْفُرْقَةُ بَيْنَهُمَا إِذَا عُرِضَ عَلَيْهَا الإِسْلاَمُ فَلَمْ تُسْلِمْ لأَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى يَقُولُ فِي كِتَابِهِ ‏\{‏وَلاَ تُمْسِكُوا بِعِصَمِ الْكَوَافِرِ‏\}‏‏.‏\hadithno{1138}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Umm Hakim bint al-Harith ibn Hisham who was the wife of Ikrima ibn Abi Jahl became muslim on the day of the conquest of Makka, and her husband Ikrima fled from Islam as far as the Yemen. Umm Hakim set out after him until she came to him in the Yemen and she called him to Islam, and he became muslim. He went to the Messenger of Allah, may Allah bless him and grant him peace, in the year of the conquest. When the Messenger of Allah, may Allah bless him and grant him peace, saw him, he rushed to him in joy and did not bother to put on his cloak until he had made the pledge with him. They were confirmed in their marriage. Malik said, "If a man becomes muslim before his wife, a separation occurs between them when he presents Islam to her and she does not become muslim, because Allah, the Blessed, the Exalted, said in His Book, 'Do not hold fast to the ties of women who are kafirun}}
\hadithdefcmd{malik}{1139}{وَحَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ، جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَبِهِ أَثَرُ صُفْرَةٍ فَسَأَلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ أَنَّهُ تَزَوَّجَ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَمْ سُقْتَ إِلَيْهَا ‏"‏ ‏.‏ فَقَالَ زِنَةَ نَوَاةٍ مِنْ ذَهَبٍ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏ ‏.‏\hadithno{1139}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Humayd at-Tawil from Anas ibn Malik that Abd ar-Rahman ibn Awf came to the Messenger of Allah, may Allah bless him and grant him peace, and he had a traceof yellow on him. The Messenger of Allah, may Allah bless him and grant him peace, asked about it. He told him that he had just been married. The Messenger of Allah, may Allah bless him and grant him peace, said, "How much did you hand over to her?" He said, "The weight of a date pit in gold." The Messenger of Allah, may Allah bless him and grant him peace, said to him, "Hold a feast, even if it is only with a sheep}}
\hadithdefcmd{malik}{1140}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ لَقَدْ بَلَغَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُولِمُ بِالْوَلِيمَةِ مَا فِيهَا خُبْزٌ وَلاَ لَحْمٌ ‏.‏\hadithno{1140}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said, "I have heard that the Messenger of Allah, may Allah bless him and grant him peace, held a wedding feast in which there was neither meat nor bread}}
\hadithdefcmd{malik}{1141}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دُعِيَ أَحَدُكُمْ إِلَى وَلِيمَةٍ فَلْيَأْتِهَا ‏"‏ ‏.‏\hadithno{1141}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "When you are invited to a wedding feast, you must go to it}}
\hadithdefcmd{malik}{1142}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ كَانَ يَقُولُ شَرُّ الطَّعَامِ طَعَامُ الْوَلِيمَةِ يُدْعَى لَهَا الأَغْنِيَاءُ وَيُتْرَكُ الْمَسَاكِينُ وَمَنْ لَمْ يَأْتِ الدَّعْوَةَ فَقَدْ عَصَى اللَّهَ وَرَسُولَهُ ‏.‏\hadithno{1142}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibr. Shihab from al-Araj that Abu Hurayra said, "The worst food is the food of a wedding feast to which the rich are invited and the poor are left out. If anyone rejects an invitation, he has rebelled against Allah and His Messenger}}
\hadithdefcmd{malik}{1143}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ إِنَّ خَيَّاطًا دَعَا رَسُولَ اللَّهِ صلى الله عليه وسلم لِطَعَامٍ صَنَعَهُ ‏.‏ قَالَ أَنَسٌ فَذَهَبْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى ذَلِكَ الطَّعَامِ فَقَرَّبَ إِلَيْهِ خُبْزًا مِنْ شَعِيرٍ وَمَرَقًا فِيهِ دُبَّاءُ ‏.‏ قَالَ أَنَسٌ فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَتَبَّعُ الدُّبَّاءَ مِنْ حَوْلِ الْقَصْعَةِ فَلَمْ أَزَلْ أُحِبُّ الدُّبَّاءَ بَعْدَ ذَلِكَ الْيَوْمِ ‏.‏\hadithno{1143}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Ishaq ibn Abdullah ibn Abi Talha heard Anas ibn Malik say that a certain tailor invited the Messenger of Allah, may Allah bless him and grant him peace, to eat some food which he had prepared. Anas said, "I went with the Messenger of Allah, may Allah bless him and grant him peace, to eat the food. He served barley bread and a soup with pumpkin in it. I saw the Messenger of Allah, may Allah bless him and grant him peace, going after the pumpkin around the dish, so I have always liked pumpkin since that day}}
\hadithdefcmd{malik}{1144}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَزَوَّجَ أَحَدُكُمُ الْمَرْأَةَ أَوِ اشْتَرَى الْجَارِيَةَ فَلْيَأْخُذْ بِنَاصِيَتِهَا وَلْيَدْعُ بِالْبَرَكَةِ وَإِذَا اشْتَرَى الْبَعِيرَ فَلْيَأْخُذْ بِذِرْوَةِ سَنَامِهِ وَلْيَسْتَعِذْ بِاللَّهِ مِنَ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{1144}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that the Messenger of Allah, may Allah bless him and grant him peace, said, "When you marry a woman or buy a slave-girl, take her by the forelock and ask for baraka. When you buy a camel, take the top of its hump, and seek refuge with Allah from Shaytan}}
\hadithdefcmd{malik}{1145}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، أَنَّ رَجُلاً، خَطَبَ إِلَى رَجُلٍ أُخْتَهُ فَذَكَرَ أَنَّهَا قَدْ كَانَتْ أَحْدَثَتْ فَبَلَغَ ذَلِكَ عُمَرَ بْنَ الْخَطَّابِ فَضَرَبَهُ - أَوْ كَادَ يَضْرِبُهُ - ثُمَّ قَالَ مَا لَكَ وَلِلْخَبَرِ\hadithno{1145}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Abu'z-Zubayr al-Makki that somebody asked a man for his sister in marriage and the man mentioned that she had committed fornication. Umar ibn al-Khattab heard about it and he beat the man or almost beat him, and said, "What did you mean by giving him such information?}}
\hadithdefcmd{malik}{1146}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ، وَعُرْوَةَ بْنَ الزُّبَيْرِ، كَانَا يَقُولاَنِ فِي الرَّجُلِ يَكُونُ عِنْدَهُ أَرْبَعُ نِسْوَةٍ فَيُطَلِّقُ إِحْدَاهُنَّ الْبَتَّةَ أَنَّهُ يَتَزَوَّجُ إِنْ شَاءَ وَلاَ يَنْتَظِرُ أَنْ تَنْقَضِيَ عِدَّتُهَا ‏.‏\hadithno{1146}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Rabia ibn Abi Abd ar-Rahman that al-Qasim ibn Muhammad and Urwa ibn az-Zubayr said that a man who had four wives and then divorced one of them irrevocably, could marry straightaway if he wished, and he did not have to wait for the completion of her idda}}
\hadithdefcmd{malik}{1147}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ، وَعُرْوَةَ بْنَ الزُّبَيْرِ، أَفْتَيَا الْوَلِيدَ بْنَ عَبْدِ الْمَلِكِ عَامَ قَدِمَ الْمَدِينَةَ بِذَلِكَ غَيْرَ أَنَّ الْقَاسِمَ بْنَ مُحَمَّدٍ قَالَ طَلَّقَهَا فِي مَجَالِسَ شَتَّى ‏.‏\hadithno{1147}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Rabia ibn Abd ar-Rahman that al-Qasim ibn Muhammad and Urwa ibn az-Zubayr gave the same judgement to al-Walid ibn Abd al-Malik in the year of his arrival in Madina except that al-Qasim ibn Muhammad said that he divorced his wife on various occasions. (i.e. not at one time)}}
\hadithdefcmd{malik}{1148}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ ثَلاَثٌ لَيْسَ فِيهِنَّ لَعِبٌ النِّكَاحُ وَالطَّلاَقُ وَالْعِتْقُ ‏.‏\hadithno{1148}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab said, "There are three things in which there is no jest:marriage, divorce, and setting free}}
\hadithdefcmd{malik}{1149}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، أَنَّهُ تَزَوَّجَ بِنْتَ مُحَمَّدِ بْنِ مَسْلَمَةَ الأَنْصَارِيِّ فَكَانَتْ عِنْدَهُ حَتَّى كَبِرَتْ فَتَزَوَّجَ عَلَيْهَا فَتَاةً شَابَّةً فَآثَرَ الشَّابَّةَ عَلَيْهَا فَنَاشَدَتْهُ الطَّلاَقَ فَطَلَّقَهَا وَاحِدَةً ثُمَّ أَمْهَلَهَا حَتَّى إِذَا كَادَتْ تَحِلُّ رَاجَعَهَا ثُمَّ عَادَ فَآثَرَ الشَّابَّةَ فَنَاشَدَتْهُ الطَّلاَقَ فَطَلَّقَهَا وَاحِدَةً ثُمَّ رَاجَعَهَا ثُمَّ عَادَ فَآثَرَ الشَّابَّةَ فَنَاشَدَتْهُ الطَّلاَقَ فَقَالَ مَا شِئْتِ إِنَّمَا بَقِيَتْ وَاحِدَةٌ فَإِنْ شِئْتِ اسْتَقْرَرْتِ عَلَى مَا تَرَيْنَ مِنَ الأُثْرَةِ وَإِنْ شِئْتِ فَارَقْتُكِ ‏.‏ قَالَتْ بَلْ أَسْتَقِرُّ عَلَى الأُثْرَةِ ‏.‏ فَأَمْسَكَهَا عَلَى ذَلِكَ وَلَمْ يَرَ رَافِعٌ عَلَيْهِ إِثْمًا حِينَ قَرَّتْ عِنْدَهُ عَلَى الأُثْرَةِ ‏.‏\hadithno{1149}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Rafi ibn Khadij married the daughter of Muhammad ibn Maslama al-Ansari. She was with him until she grew older, and then he married a young girl and preferred the young girl to her. She begged him to divorce her, so he divorced her and then he gave her time until she had almost finished her idda period and then he returned and still preferred the young girl. She therefore asked him to divorce her. He divorced her once, and then returned to her, and still preferred the young girl, and she asked him to divorce her. He said, "What do you want? There is only one divorce left. If you like, continue and put up with what you see of preference, and if you like, I will separate from you." She said, "I will continue in spite of the preference." He kept her in spite of that. Rafi did not see that he had done any wrong action when she remained with him in spite of preference}}
