% Auto-generated chapter 72 for bukhari
% Hadiths in this chapter: 69

\hadithdefcmd{bukhari}{5475}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا زَكَرِيَّاءُ، عَنْ عَامِرٍ، عَنْ عَدِيِّ بْنِ حَاتِمٍ ـ رضى الله عنه ـ قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم عَنْ صَيْدِ الْمِعْرَاضِ قَالَ ‏"‏ مَا أَصَابَ بِحَدِّهِ فَكُلْهُ، وَمَا أَصَابَ بِعَرْضِهِ فَهْوَ وَقِيذٌ ‏"‏‏.‏ وَسَأَلْتُهُ عَنْ صَيْدِ الْكَلْبِ فَقَالَ ‏"‏ مَا أَمْسَكَ عَلَيْكَ فَكُلْ، فَإِنَّ أَخْذَ الْكَلْبِ ذَكَاةٌ، وَإِنْ وَجَدْتَ مَعَ كَلْبِكَ أَوْ كِلاَبِكَ كَلْبًا غَيْرَهُ فَخَشِيتَ أَنْ يَكُونَ أَخَذَهُ مَعَهُ، وَقَدْ قَتَلَهُ، فَلاَ تَأْكُلْ، فَإِنَّمَا ذَكَرْتَ اسْمَ اللَّهِ عَلَى كَلْبِكَ وَلَمْ تَذْكُرْهُ عَلَى غَيْرِهِ ‏"‏‏.‏\hadithno{5475}\hadithtrans{Narrated Adi bin Hatim:I asked the Prophet (ﷺ) about the game killed by a Mi'rad (i.e. a sharp-edged piece of wood or a piece of wood provided with a sharp piece of iron used for hunting). He said, "If the game is killed with its sharp edge, eat of it, but if it is killed with its shaft, with a hit by its broad side then the game is (unlawful to eat) for it has been beaten to death." I asked him about the game killed by a trained hound. He said, "If the hound catches the game for you, eat of it, for killing the game by the hound, is like its slaughtering. But if you see with your hound or hounds another dog, and you are afraid that it might have shared in hunting the game with your hound and killed it, then you should not eat of it, because you have mentioned Allah's name on (sending) your hound only, but you have not mentioned it on some other hound}}
\hadithdefcmd{bukhari}{5476}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي السَّفَرِ، عَنِ الشَّعْبِيِّ، قَالَ سَمِعْتُ عَدِيَّ بْنَ حَاتِمٍ ـ رضى الله عنه ـ قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْمِعْرَاضِ فَقَالَ ‏"‏ إِذَا أَصَبْتَ بِحَدِّهِ فَكُلْ، فَإِذَا أَصَابَ بِعَرْضِهِ فَقَتَلَ فَإِنَّهُ وَقِيذٌ، فَلاَ تَأْكُلْ ‏"‏‏.‏ فَقُلْتُ أُرْسِلُ كَلْبِي‏.‏ قَالَ ‏"‏ إِذَا أَرْسَلْتَ كَلْبَكَ وَسَمَّيْتَ، فَكُلْ ‏"‏‏.‏ قُلْتُ فَإِنْ أَكَلَ قَالَ ‏"‏ فَلاَ تَأْكُلْ، فَإِنَّهُ لَمْ يُمْسِكْ عَلَيْكَ، إِنَّمَا أَمْسَكَ عَلَى نَفْسِهِ ‏"‏‏.‏ قُلْتُ أُرْسِلُ كَلْبِي فَأَجِدُ مَعَهُ كَلْبًا آخَرَ‏.‏ قَالَ ‏"‏ لاَ تَأْكُلْ، فَإِنَّكَ إِنَّمَا سَمَّيْتَ عَلَى كَلْبِكَ، وَلَمْ تُسَمِّ عَلَى آخَرَ ‏"‏‏.‏\hadithno{5476}\hadithtrans{Narrated `Adi bin Hatim:I asked Allah's Messenger (ﷺ) about the Mi'rad. He said, "If you hit the game with its sharp edge, eat it, but if the Mi'rad hits the game with its shaft with a hit by its broad side do not eat it, for it has been beaten to death with a piece of wood. (i.e. unlawful)." I asked, "If I let loose my trained hound after a game?" He said, "If you let loose your trained hound after game, and mention the name of Allah, then you can eat." I said, "If the hound eats of the game?" He said "Then you should not eat of it, for the hound has hunted the game for itself and not for you." I said, "Some times I send my hound and then I find some other hound with it?" He said "Don't eat the game, as you have mentioned the Name of Allah on your dog only and not on the other}}
\hadithdefcmd{bukhari}{5477}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ هَمَّامِ بْنِ الْحَارِثِ، عَنْ عَدِيِّ بْنِ حَاتِمٍ ـ رضى الله عنه ـ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا نُرْسِلُ الْكِلاَبَ الْمُعَلَّمَةَ‏.‏ قَالَ ‏"‏ كُلْ مَا أَمْسَكْنَ عَلَيْكَ ‏"‏‏.‏ قُلْتُ وَإِنْ قَتَلْنَ قَالَ ‏"‏ وَإِنْ قَتَلْنَ ‏"‏‏.‏ قُلْتُ وَإِنَّا نَرْمِي بِالْمِعْرَاضِ‏.‏ قَالَ ‏"‏ كُلْ مَا خَزَقَ، وَمَا أَصَابَ بِعَرْضِهِ فَلاَ تَأْكُلْ ‏"‏‏.‏\hadithno{5477}\hadithtrans{Narrated Adi bin Hatim:I said, "O Allah's Messenger (ﷺ)! We let loose our trained hounds after a game?" He said, "Eat what they hunt for you." I said, "Even if they killed (the game)?" He replied, 'Even if they killed (the game)." I said, 'We also hit (the game) with the Mi'rad?" He said, "Eat of the animal which the Mi'rad kills by piercing its body, but do not eat of the animal which is killed by the broad side of the Mi'rad}}
\hadithdefcmd{bukhari}{5478}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا حَيْوَةُ، قَالَ أَخْبَرَنِي رَبِيعَةُ بْنُ يَزِيدَ الدِّمَشْقِيُّ، عَنْ أَبِي إِدْرِيسَ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، قَالَ قُلْتُ يَا نَبِيَّ اللَّهِ إِنَّا بِأَرْضِ قَوْمٍ أَهْلِ الْكِتَابِ، أَفَنَأْكُلُ فِي آنِيَتِهِمْ وَبِأَرْضِ صَيْدٍ، أَصِيدُ بِقَوْسِي وَبِكَلْبِي الَّذِي لَيْسَ بِمُعَلَّمٍ، وَبِكَلْبِي الْمُعَلَّمِ، فَمَا يَصْلُحُ لِي قَالَ ‏ "‏ أَمَّا مَا ذَكَرْتَ مِنْ أَهْلِ الْكِتَابِ فَإِنْ وَجَدْتُمْ غَيْرَهَا فَلاَ تَأْكُلُوا فِيهَا، وَإِنْ لَمْ تَجِدُوا فَاغْسِلُوهَا وَكُلُوا فِيهَا، وَمَا صِدْتَ بِقَوْسِكَ فَذَكَرْتَ اسْمَ اللَّهِ فَكُلْ، وَمَا صِدْتَ بِكَلْبِكَ الْمُعَلَّمِ فَذَكَرْتَ اسْمَ اللَّهِ فَكُلْ، وَمَا صِدْتَ بِكَلْبِكَ غَيْرَ مُعَلَّمٍ فَأَدْرَكْتَ ذَكَاتَهُ فَكُلْ ‏"‏‏.‏\hadithno{5478}\hadithtrans{Narrated Abu Tha`laba Al-Khushani:I said, "O Allah's Prophet! We are living in a land ruled by the people of the Scripture; Can we take our meals in their utensils? In that land there is plenty of game and I hunt the game with my bow and with my hound that is not trained and with my trained hound. Then what is lawful for me to eat?" He said, "As for what you have mentioned about the people of the Scripture, if you can get utensils other than theirs, do not eat out of theirs, but if you cannot get other than theirs, wash their utensils and eat out of it. If you hunt an animal with your bow after mentioning Allah's Name, eat of it. and if you hunt something with your trained hound after mentioning Allah's Name, eat of it, and if you hunt something with your untrained hound (and get it before it dies) and slaughter it, eat of it}}
\hadithdefcmd{bukhari}{5479}{حَدَّثَنَا يُوسُفُ بْنُ رَاشِدٍ، حَدَّثَنَا وَكِيعٌ، وَيَزِيدُ بْنُ هَارُونَ ـ وَاللَّفْظُ لِيَزِيدَ ـ عَنْ كَهْمَسِ بْنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، أَنَّهُ رَأَى رَجُلاً يَخْذِفُ فَقَالَ لَهُ لاَ تَخْذِفْ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْخَذْفِ ـ أَوْ كَانَ يَكْرَهُ الْخَذْفَ ـ وَقَالَ ‏ "‏ إِنَّهُ لاَ يُصَادُ بِهِ صَيْدٌ وَلاَ يُنْكَى بِهِ عَدُوٌّ، وَلَكِنَّهَا قَدْ تَكْسِرُ السِّنَّ وَتَفْقَأُ الْعَيْنَ ‏"‏‏.‏ ثُمَّ رَآهُ بَعْدَ ذَلِكَ يَخْذِفُ فَقَالَ لَهُ أُحَدِّثُكَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ نَهَى عَنِ الْخَذْفِ‏.‏ أَوْ كَرِهَ الْخَذْفَ، وَأَنْتَ تَخْذِفُ لاَ أُكَلِّمُكَ كَذَا وَكَذَا‏.‏\hadithno{5479}\hadithtrans{Narrated `Abdullah bin Maghaffal:that he saw a man throwing stones with two fingers (at something) and said to him, "Do not throw stones, for Allah's Messenger (ﷺ) has forbidden throwing stones, or he used to dislike it." `Abdullah added: Throwing stones will neither hunt the game, nor kill (or hurt) an enemy, but it may break a tooth or gouge out an eye." Afterwards `Abdullah once again saw the man throwing stones. He said to him, "I tell you that Allah's Messenger (ﷺ) has forbidden or disliked the throwing the stones (in such a way), yet you are throwing stones! I shall not talk to you for such-and-such a period}}
\hadithdefcmd{bukhari}{5480}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اقْتَنَى كَلْبًا لَيْسَ بِكَلْبِ مَاشِيَةٍ أَوْ ضَارِيَةٍ، نَقَصَ كُلَّ يَوْمٍ مِنْ عَمَلِهِ قِيرَاطَانِ ‏"‏‏.‏\hadithno{5480}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "Whoever keeps a (pet) dog which is neither a watch dog nor a hunting dog, will get a daily deduction of two Qirat from his good deeds}}
\hadithdefcmd{bukhari}{5481}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا حَنْظَلَةُ بْنُ أَبِي سُفْيَانَ، قَالَ سَمِعْتُ سَالِمًا، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ اقْتَنَى كَلْبًا إِلاَّ كَلْبٌ ضَارٍ لِصَيْدٍ أَوْ كَلْبَ مَاشِيَةٍ، فَإِنَّهُ يَنْقُصُ مِنْ أَجْرِهِ كُلَّ يَوْمٍ قِيرَاطَانِ ‏"‏‏.‏\hadithno{5481}\hadithtrans{Narrated `Abdullah bin `Umar:I heard the Prophet (ﷺ) saying, "If someone keeps a dog neither for hunting, nor for guarding livestock, the reward (for his good deeds) will be reduced by two Qirats per day}}
\hadithdefcmd{bukhari}{5482}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اقْتَنَى كَلْبًا إِلاَّ كَلْبَ مَاشِيَةٍ أَوْ ضَارٍ، نَقَصَ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطَانِ ‏"‏‏.‏\hadithno{5482}\hadithtrans{Narrated `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "If someone keeps a dog neither for guarding livestock, nor for hunting, his good deeds will decrease (in reward) by two Qirats a day}}
\hadithdefcmd{bukhari}{5483}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ بَيَانٍ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قُلْتُ إِنَّا قَوْمٌ نَصِيدُ بِهَذِهِ الْكِلاَبِ‏.‏ فَقَالَ ‏ "‏ إِذَا أَرْسَلْتَ كِلاَبَكَ الْمُعَلَّمَةَ وَذَكَرْتَ اسْمَ اللَّهِ، فَكُلْ مِمَّا أَمْسَكْنَ عَلَيْكُمْ، وَإِنْ قَتَلْنَ إِلاَّ أَنْ يَأْكُلَ الْكَلْبُ، فَإِنِّي أَخَافُ أَنْ يَكُونَ إِنَّمَا أَمْسَكَهُ عَلَى نَفْسِهِ، وَإِنْ خَالَطَهَا كِلاَبٌ مِنْ غَيْرِهَا فَلاَ تَأْكُلْ ‏"‏‏.‏\hadithno{5483}\hadithtrans{Narrated Adi bin Hatim:I asked Allah's Messenger (ﷺ). "We hunt with the help of these hounds." He said, "If you let loose your trained hounds after a game, and mention the name of Allah, then you can eat what the hounds catch for you, even if they killed the game. But you should not eat of it if the hound has eaten of it, for then it is likely that the hound has caught the game for itself. And if other hounds join your hound in hunting the game, then do not eat of it}}
\hadithdefcmd{bukhari}{5484}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا ثَابِتُ بْنُ يَزِيدَ، حَدَّثَنَا عَاصِمٌ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَرْسَلْتَ كَلْبَكَ وَسَمَّيْتَ فَأَمْسَكَ وَقَتَلَ، فَكُلْ، وَإِنْ أَكَلَ فَلاَ تَأْكُلْ، فَإِنَّمَا أَمْسَكَ عَلَى نَفْسِهِ، وَإِذَا خَالَطَ كِلاَبًا لَمْ يُذْكَرِ اسْمُ اللَّهِ عَلَيْهَا فَأَمْسَكْنَ وَقَتَلْنَ فَلاَ تَأْكُلْ، فَإِنَّكَ لاَ تَدْرِي أَيُّهَا قَتَلَ، وَإِنْ رَمَيْتَ الصَّيْدَ فَوَجَدْتَهُ بَعْدَ يَوْمٍ أَوْ يَوْمَيْنِ، لَيْسَ بِهِ إِلاَّ أَثَرُ سَهْمِكَ، فَكُلْ، وَإِنْ وَقَعَ فِي الْمَاءِ فَلاَ تَأْكُلْ ‏"‏‏.‏\hadithno{5484}\hadithtrans{Narrated Adi bin Hatim:The Prophet (ﷺ) said, "If you let loose your hound after a game and mention Allah's Name on sending it, and the hound catches the game and kills it, then you can eat of it. But if the hound eats of it, then you should not eat thereof, for the hound has caught it for itself. And if along with your hound, joined other hounds, and Allah's Name was not mentioned at the time of their sending, and they catch an animal and kill it, you should not eat of it, for you will not know which of them has killed it. And if you have thrown an arrow at the game and then find it (dead) two or three days later and, it bears no mark other than the wound inflicted by your arrow, then you can eat of it. But if the game is found (dead) in water, then do not eat of it}}
\hadithdefcmd{bukhari}{5485}{وَقَالَ عَبْدُ الأَعْلَى عَنْ دَاوُدَ، عَنْ عَامِرٍ، عَنْ عَدِيٍّ، أَنَّهُ قَالَ لِلنَّبِيِّ صلى الله عليه وسلم، يَرْمِي الصَّيْدَ فَيَقْتَفِرُ أَثَرَهُ الْيَوْمَيْنِ وَالثَّلاَثَةَ، ثُمَّ يَجِدُهُ مَيِّتًا وَفِيهِ سَهْمُهُ قَالَ ‏ "‏ يَأْكُلُ إِنْ شَاءَ ‏"‏‏.‏\hadithno{5485}\hadithtrans{And it has also been narrated by `Adi bin Hatim that he asked the Prophet (ﷺ) "If a hunter throws an arrow at the game and after tracing it for two or three days he finds it dead but still bearing his arrow, (can he eat of it)?" The Prophet (ﷺ) replied, "He can eat if he wishes}}
\hadithdefcmd{bukhari}{5486}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي السَّفَرِ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أُرْسِلُ كَلْبِي وَأُسَمِّي فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِذَا أَرْسَلْتَ كَلْبَكَ وَسَمَّيْتَ، فَأَخَذَ فَقَتَلَ فَأَكَلَ فَلاَ تَأْكُلْ، فَإِنَّمَا أَمْسَكَ عَلَى نَفْسِهِ ‏"‏‏.‏ قُلْتُ إِنِّي أُرْسِلُ كَلْبِي أَجِدُ مَعَهُ كَلْبًا آخَرَ، لاَ أَدْرِي أَيُّهُمَا أَخَذَهُ‏.‏ فَقَالَ ‏"‏ لاَ تَأْكُلْ فَإِنَّمَا سَمَّيْتَ عَلَى كَلْبِكَ وَلَمْ تُسَمِّ عَلَى غَيْرِهِ ‏"‏‏.‏ وَسَأَلْتُهُ عَنْ صَيْدِ الْمِعْرَاضِ فَقَالَ ‏"‏ إِذَا أَصَبْتَ بِحَدِّهِ، فَكُلْ، وَإِذَا أَصَبْتَ بِعَرْضِهِ فَقَتَلَ، فَإِنَّهُ وَقِيذٌ، فَلاَ تَأْكُلْ ‏"‏‏.‏\hadithno{5486}\hadithtrans{Narrated `Adi bin Hatim:I said, "O Allah's Messenger (ﷺ)! I let loose my hound after a game and mention Allah's Name on sending it." The Prophet (ﷺ) said, "If you let loose your hound after a game and you mention Allah's Name on sending it and the hound catches and kills the game and eats of it, then you should not eat of it, for it has killed it for itself." I said, "Sometimes when I send my hound after a game, I find another hound along with it and I do not know which of them has caught the game." He said, "You must not eat of it because you have not mentioned, the Name of Allah except on sending your own hound, and you did not mention it on the other hound." Then I asked him about the game hunted with a Mi'rad (i.e. a sharp edged piece of wood or a piece of wood provided with a sharp piece of iron used for hunting). He said, "If the game is killed with its sharp edge, you can eat of it, but if it is killed by its broad side (shaft), you cannot eat of it, for then it is like an animal beaten to death with a piece of wood}}
\hadithdefcmd{bukhari}{5487}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنِي ابْنُ فُضَيْلٍ، عَنْ بَيَانٍ، عَنْ عَامِرٍ، عَنْ عَدِيِّ بْنِ حَاتِمٍ ـ رضى الله عنه ـ قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ إِنَّا قَوْمٌ نَتَصَيَّدُ بِهَذِهِ الْكِلاَبِ‏.‏ فَقَالَ ‏ "‏ إِذَا أَرْسَلْتَ كِلاَبَكَ الْمُعَلَّمَةَ وَذَكَرْتَ اسْمَ اللَّهِ، فَكُلْ مِمَّا أَمْسَكْنَ عَلَيْكَ، إِلاَّ أَنْ يَأْكُلَ الْكَلْبُ، فَلاَ تَأْكُلْ فَإِنِّي أَخَافُ أَنْ يَكُونَ إِنَّمَا أَمْسَكَ عَلَى نَفْسِهِ، وَإِنْ خَالَطَهَا كَلْبٌ مِنْ غَيْرِهَا، فَلاَ تَأْكُلْ ‏"‏‏.‏\hadithno{5487}\hadithtrans{Narrated Adi Bin Hatim:I asked Allah's Messenger (ﷺ), "We hunt with these hounds." He said, "If you send your trained hounds after a game and mention Allah's Name on sending, you can eat of what they catch for you. But if the hound eats of the game, then you must not eat of it, for I am afraid that the hound caught it for itself, and if another hound joins your hounds (during the hunt), you should not eat of the game}}
\hadithdefcmd{bukhari}{5488}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ حَيْوَةَ،‏.‏ وَحَدَّثَنِي أَحْمَدُ بْنُ أَبِي رَجَاءٍ، حَدَّثَنَا سَلَمَةُ بْنُ سُلَيْمَانَ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، قَالَ سَمِعْتُ رَبِيعَةَ بْنَ يَزِيدَ الدِّمَشْقِيَّ، قَالَ أَخْبَرَنِي أَبُو إِدْرِيسَ، عَائِذُ اللَّهِ قَالَ سَمِعْتُ أَبَا ثَعْلَبَةَ الْخُشَنِيَّ ـ رضى الله عنه ـ يَقُولُ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّا بِأَرْضِ قَوْمٍ أَهْلِ الْكِتَابِ، نَأْكُلُ فِي آنِيَتِهِمْ، وَأَرْضِ صَيْدٍ أَصِيدُ بِقَوْسِي، وَأَصِيدُ بِكَلْبِي الْمُعَلَّمِ، وَالَّذِي لَيْسَ مُعَلَّمًا، فَأَخْبِرْنِي مَا الَّذِي يَحِلُّ لَنَا مِنْ ذَلِكَ فَقَالَ ‏ "‏ أَمَّا مَا ذَكَرْتَ أَنَّكَ بِأَرْضِ قَوْمٍ أَهْلِ الْكِتَابِ، تَأْكُلُ فِي آنِيَتِهِمْ، فَإِنْ وَجَدْتُمْ غَيْرَ آنِيَتِهِمْ، فَلاَ تَأْكُلُوا فِيهَا، وَإِنْ لَمْ تَجِدُوا فَاغْسِلُوهَا ثُمَّ كُلُوا فِيهَا، وَأَمَّا مَا ذَكَرْتَ أَنَّكَ بِأَرْضِ صَيْدٍ، فَمَا صِدْتَ بِقَوْسِكَ، فَاذْكُرِ اسْمَ اللَّهِ، ثُمَّ كُلْ، وَمَا صِدْتَ بِكَلْبِكَ الْمُعَلَّمِ، فَاذْكُرِ اسْمَ اللَّهِ، ثُمَّ كُلْ، وَمَا صِدْتَ بِكَلْبِكَ الَّذِي لَيْسَ مُعَلَّمًا فَأَدْرَكْتَ ذَكَاتَهُ، فَكُلْ ‏"‏‏.‏\hadithno{5488}\hadithtrans{Narrated Abu Tha`laba Al-Khushani:I came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! We are living in the land of the people of the Scripture and we take our meals in their utensils, and in the land there is game and I hunt with my bow and trained or untrained hounds; please tell me what is lawful for us of that." He said, "As for your saying that you are living in the land of the people of the Scripture and that you eat in their utensils, if you can get utensils other than theirs, do not eat in their utensils, but if you do not find (other than theirs), then wash their utensils and eat in them. As for your saying that you are in the land of game, if you hung something with your bow, and have mentioned Allah's Name while hunting, then you can eat (the game). And if you hunt something with your trained hound, and have mentioned Allah's Name on sending it for hunting then you can eat (the game). But if you hunt something with your untrained hound and you were able to slaughter it before its death, you can eat of it}}
\hadithdefcmd{bukhari}{5489}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، قَالَ حَدَّثَنِي هِشَامُ بْنُ زَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ أَنْفَجْنَا أَرْنَبًا بِمَرِّ الظَّهْرَانِ، فَسَعَوْا عَلَيْهَا حَتَّى لَغِبُوا، فَسَعَيْتُ عَلَيْهَا حَتَّى أَخَذْتُهَا، فَجِئْتُ بِهَا إِلَى أَبِي طَلْحَةَ، فَبَعَثَ إِلَى النَّبِيِّ صلى الله عليه وسلم بِوَرِكِهَا وَفَخِذَيْهَا فَقَبِلَهُ‏.‏\hadithno{5489}\hadithtrans{Narrated Anas bin Malik:We provoked a rabbit at Marr Az-Zahran till it started jumping. My companions chased it till they got tired. But I alone ran after it and caught it and brought it to Abu Talha. He sent both its legs to the Prophet who accepted them}}
\hadithdefcmd{bukhari}{5490}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ نَافِعٍ، مَوْلَى أَبِي قَتَادَةَ عَنْ أَبِي قَتَادَةَ، أَنَّهُ كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا كَانَ بِبَعْضِ طَرِيقِ مَكَّةَ تَخَلَّفَ مَعَ أَصْحَابٍ لَهُ مُحْرِمِينَ، وَهْوَ غَيْرُ مُحْرِمٍ، فَرَأَى حِمَارًا وَحْشِيًّا، فَاسْتَوَى عَلَى فَرَسِهِ، ثُمَّ سَأَلَ أَصْحَابَهُ أَنْ يُنَاوِلُوهُ سَوْطًا، فَأَبَوْا فَسَأَلَهُمْ رُمْحَهُ فَأَبَوْا فَأَخَذَهُ ثُمَّ شَدَّ عَلَى الْحِمَارِ، فَقَتَلَهُ فَأَكَلَ مِنْهُ بَعْضُ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبَى بَعْضُهُمْ، فَلَمَّا أَدْرَكُوا رَسُولَ اللَّهِ صلى الله عليه وسلم سَأَلُوهُ عَنْ ذَلِكَ فَقَالَ ‏ "‏ إِنَّمَا هِيَ طُعْمَةٌ أَطْعَمَكُمُوهَا اللَّهُ ‏"‏‏.‏\hadithno{5490}\hadithtrans{Narrated Abu Qatada:that once he was with Allah's Messenger (ﷺ) (on the way to Mecca). When he had covered some of the way to Mecca, he and some companions of his, who were in the state of Ihram. remained behind the Prophet while Abu Qatada himself was not in the state of Ihram. Abu Qatada, seeing an onager rode his horse and asked his companions to hand him a whip, but they refused. He then asked them to hand him his spear, but they refused. Then he took it himself and attacked the onager and killed it. Some of the Companions of Allah's Messenger (ﷺ) ate of it, but some others refused to eat. When they met Allah's Apostle they asked him about that. He said, "It was meal given to you by Allah}}
\hadithdefcmd{bukhari}{5491}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي قَتَادَةَ، مِثْلَهُ إِلاَّ أَنَّهُ قَالَ ‏ "‏ هَلْ مَعَكُمْ مِنْ لَحْمِهِ شَىْءٌ ‏"‏‏.‏\hadithno{5491}\hadithtrans{Narrated Abu Qatada:(the same Hadith above, but he added); The Prophet (ﷺ) asked, "Is there any of its meat left with you?}}
\hadithdefcmd{bukhari}{5492}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، أَخْبَرَنَا عَمْرٌو، أَنَّ أَبَا النَّضْرِ، حَدَّثَهُ عَنْ نَافِعٍ، مَوْلَى أَبِي قَتَادَةَ وَأَبِي صَالِحٍ مَوْلَى التَّوْأَمَةِ سَمِعْتُ أَبَا قَتَادَةَ، قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِيمَا بَيْنَ مَكَّةَ وَالْمَدِينَةِ وَهُمْ مُحْرِمُونَ وَأَنَا رَجُلٌ حِلٌّ عَلَى فَرَسٍ، وَكُنْتُ رَقَّاءً عَلَى الْجِبَالِ، فَبَيْنَا أَنَا عَلَى ذَلِكَ إِذْ رَأَيْتُ النَّاسَ مُتَشَوِّفِينَ لِشَىْءٍ، فَذَهَبْتُ أَنْظُرُ، فَإِذَا هُوَ حِمَارُ وَحْشٍ فَقُلْتُ لَهُمْ مَا هَذَا قَالُوا لاَ نَدْرِي‏.‏ قُلْتُ هُوَ حِمَارٌ وَحْشِيٌّ‏.‏ فَقَالُوا هُوَ مَا رَأَيْتَ‏.‏ وَكُنْتُ نَسِيتُ سَوْطِي فَقُلْتُ لَهُمْ نَاوِلُونِي سَوْطِي‏.‏ فَقَالُوا لاَ نُعِينُكَ عَلَيْهِ‏.‏ فَنَزَلْتُ فَأَخَذْتُهُ، ثُمَّ ضَرَبْتُ فِي أَثَرِهِ، فَلَمْ يَكُنْ إِلاَّ ذَاكَ، حَتَّى عَقَرْتُهُ، فَأَتَيْتُ إِلَيْهِمْ فَقُلْتُ لَهُمْ قُومُوا فَاحْتَمِلُوا‏.‏ قَالُوا لاَ نَمَسُّهُ‏.‏ فَحَمَلْتُهُ حَتَّى جِئْتُهُمْ بِهِ، فَأَبَى بَعْضُهُمْ، وَأَكَلَ بَعْضُهُمْ، فَقُلْتُ أَنَا أَسْتَوْقِفُ لَكُمُ النَّبِيَّ صلى الله عليه وسلم فَأَدْرَكْتُهُ فَحَدَّثْتُهُ الْحَدِيثَ فَقَالَ لِي ‏"‏ أَبَقِيَ مَعَكُمْ شَىْءٌ مِنْهُ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ فَقَالَ ‏"‏ كُلُوا فَهْوَ طُعْمٌ أَطْعَمَكُمُوهَا اللَّهُ ‏"‏‏.‏\hadithno{5492}\hadithtrans{Narrated Abu Qatada:I was with the Prophet (on a journey) between Mecca and Medina, and all of them, (i.e. the Prophet (ﷺ) and his companions) were in the state of Ihram, while I was not in that state. I was riding my horse and I used to be fond of ascending mountains. So while I was doing so I noticed that the people were looking at something. I went to see what it was, and behold it was an onager. I asked my companions, "What is that?" They said, "We do not know." I said, "It is an onager.' They said, "It is what you have seen." I had left my whip, so I said to them, "Hand to me my whip." They said, "We will not help you in that (in hunting the onager)." I got down, took my whip and chased the animal (on my horse) and did not stop till I killed it. I went to them and said, "Come on, carry it!" But they said, "We will not even touch it." At last I alone carried it and brought it to them. Some of them ate of it and some refused to eat of it. I said (to them), "I will ask the Prophet (ﷺ) about it (on your behalf)." When I met the Prophet, I told him the whole story. He said to me, "Has anything of it been left with you?" I said, "Yes." He said, "Eat, for it is a meal Allah has offered to you}}
\hadithdefcmd{bukhari}{5493}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرٌو، أَنَّهُ سَمِعَ جَابِرًا ـ رضى الله عنه ـ يَقُولُ غَزَوْنَا جَيْشَ الْخَبَطِ وَأُمِّرَ أَبُو عُبَيْدَةَ فَجُعْنَا جُوعًا شَدِيدًا فَأَلْقَى الْبَحْرُ حُوتًا مَيِّتًا لَمْ يُرَ مِثْلُهُ يُقَالُ لَهُ الْعَنْبَرُ فَأَكَلْنَا مِنْهُ نِصْفَ شَهْرٍ فَأَخَذَ أَبُو عُبَيْدَةَ عَظْمًا مِنْ عِظَامِهِ فَمَرَّ الرَّاكِبُ تَحْتَهُ‏.‏\hadithno{5493}\hadithtrans{Narrated Jabir:We went out in a campaign and the army was called The Army of the Khabat, and Abu 'Ubaida was our commander. We were struck with severe hunger. Then the sea threw a huge dead fish called Al- `Anbar, the like of which had never been seen. We ate of it for half a month, and then Abu 'Ubaida took one of its bones (and made an arch of it) so that a rider could easily pass under it}}
\hadithdefcmd{bukhari}{5494}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ سَمِعْتُ جَابِرًا، يَقُولُ بَعَثَنَا النَّبِيُّ صلى الله عليه وسلم ثَلاَثَمِائَةِ رَاكِبٍ وَأَمِيرُنَا أَبُو عُبَيْدَةَ نَرْصُدُ عِيرًا لِقُرَيْشٍ فَأَصَابَنَا جُوعٌ شَدِيدٌ حَتَّى أَكَلْنَا الْخَبَطَ، فَسُمِّيَ جَيْشَ الْخَبَطِ وَأَلْقَى الْبَحْرُ حُوتًا يُقَالُ لَهُ الْعَنْبَرُ فَأَكَلْنَا نِصْفَ شَهْرٍ وَادَّهَنَّا بِوَدَكِهِ حَتَّى صَلَحَتْ أَجْسَامُنَا قَالَ فَأَخَذَ أَبُو عُبَيْدَةَ ضِلَعًا مِنْ أَضْلاَعِهِ فَنَصَبَهُ فَمَرَّ الرَّاكِبُ تَحْتَهُ، وَكَانَ فِينَا رَجُلٌ فَلَمَّا اشْتَدَّ الْجُوعُ نَحَرَ ثَلاَثَ جَزَائِرَ، ثُمَّ ثَلاَثَ جَزَائِرَ، ثُمَّ نَهَاهُ أَبُو عُبَيْدَةَ‏.‏\hadithno{5494}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) sent us as an army unit of three hundred warriors under the command of Abu 'Ubaida to ambush a caravan of the Quraish. But we were struck with such severe hunger that we ate the Khabat (desert bushes), so our army was called the Army of the Khabat. Then the sea threw a huge fish called Al-`Anbar and we ate of it for half a month and rubbed our bodies with its fat till our bodies became healthy. Then Abu Ubaida took one of its ribs and fixed it over the ground and a rider passed underneath it. There was a man amongst us who slaughtered three camels when hunger became severe, and he slaughtered three more, but after that Abu 'Ubaida forbade him to do so}}
\hadithdefcmd{bukhari}{5495}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي يَعْفُورٍ، قَالَ سَمِعْتُ ابْنَ أَبِي أَوْفَى ـ رضى الله عنهما ـ قَالَ غَزَوْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم سَبْعَ غَزَوَاتٍ أَوْ سِتًّا، كُنَّا نَأْكُلُ مَعَهُ الْجَرَادَ‏.‏ قَالَ سُفْيَانُ وَأَبُو عَوَانَةَ وَإِسْرَائِيلُ عَنْ أَبِي يَعْفُورٍ عَنِ ابْنِ أَبِي أَوْفَى سَبْعَ غَزَوَاتٍ‏.‏\hadithno{5495}\hadithtrans{Narrated Ibn Abi `Aufa:We participated with the Prophet (ﷺ) in six or seven Ghazawat, and we used to eat locusts with him}}
\hadithdefcmd{bukhari}{5496}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ حَيْوَةَ بْنِ شُرَيْحٍ، قَالَ حَدَّثَنِي رَبِيعَةُ بْنُ يَزِيدَ الدِّمَشْقِيُّ، قَالَ حَدَّثَنِي أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ، قَالَ حَدَّثَنِي أَبُو ثَعْلَبَةَ الْخُشَنِيُّ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّا بِأَرْضِ أَهْلِ الْكِتَابِ، فَنَأْكُلُ فِي آنِيَتِهِمْ، وَبِأَرْضِ صَيْدٍ، أَصِيدُ بِقَوْسِي، وَأَصِيدُ بِكَلْبِي الْمُعَلَّمِ، وَبِكَلْبِي الَّذِي لَيْسَ بِمُعَلَّمٍ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَمَّا مَا ذَكَرْتَ أَنَّكَ بِأَرْضِ أَهْلِ كِتَابٍ فَلاَ تَأْكُلُوا فِي آنِيَتِهِمْ، إِلاَّ أَنْ لاَ تَجِدُوا بُدًّا، فَإِنْ لَمْ تَجِدُوا بُدًّا فَاغْسِلُوهَا وَكُلُوا، وَأَمَّا مَا ذَكَرْتَ أَنَّكُمْ بِأَرْضِ صَيْدٍ، فَمَا صِدْتَ بِقَوْسِكَ، فَاذْكُرِ اسْمَ اللَّهِ وَكُلْ، وَمَا صِدْتَ بِكَلْبِكَ الْمُعَلَّمِ، فَاذْكُرِ اسْمَ اللَّهِ وَكُلْ، وَمَا صِدْتَ بِكَلْبِكَ الَّذِي لَيْسَ بِمُعَلَّمٍ، فَأَدْرَكْتَ ذَكَاتَهُ، فَكُلْهُ ‏"‏‏.‏\hadithno{5496}\hadithtrans{Narrated Abu Tha`laba Al-Khushani:I came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! We are living in the land of the people of the Scripture, and we take our meals in their utensils, and there is game in that land and I hunt with my bow and with my trained hound and with my untrained hound." The Prophet (ﷺ) said, "As for your saying that you are in the land of people of the Scripture, you should not eat in their utensils unless you find no alternative, in which case you must wash the utensils and then eat in them As for your saying that you are in the land of game, if you hunt something with your bow, mention Allah's Name (while hunting the game) and eat; and if you hunt something with your trained hound, mention Allah's Name on sending and eat; and if you hunt something with your untrained hound and get it alive, slaughter it and you can eat of it}}
\hadithdefcmd{bukhari}{5497}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، قَالَ لَمَّا أَمْسَوْا يَوْمَ فَتَحُوا خَيْبَرَ أَوْقَدُوا النِّيرَانَ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَلَى مَا أَوْقَدْتُمْ هَذِهِ النِّيرَانَ ‏"‏‏.‏ قَالُوا لُحُومِ الْحُمُرِ الإِنْسِيَّةِ‏.‏ قَالَ ‏"‏ أَهْرِيقُوا مَا فِيهَا، وَاكْسِرُوا قُدُورَهَا ‏"‏‏.‏ فَقَامَ رَجُلٌ مِنَ الْقَوْمِ فَقَالَ نُهَرِيقُ مَا فِيهَا وَنَغْسِلُهَا‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَوْ ذَاكَ ‏"‏‏.‏\hadithno{5497}\hadithtrans{Narrated Salama bin Al-Aqwa':In the evening of the day of the conquest of Khaibar, the army made fires (for cooking). The Prophet (ﷺ) said, "For what have you made these fires?" They said, "For cooking the meat of domestic donkeys." He said, "Throw away what is in the cooking pots and break the pots." A man from the people got up and said, "Shall we throw the contents of the cooking pots and then wash the pots (instead of breaking them)?" The Prophet (ﷺ) said, "Yes, you can do either}}
\hadithdefcmd{bukhari}{5498}{حَدَّثَنِي مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ بْنِ رَافِعٍ، عَنْ جَدِّهِ، رَافِعِ بْنِ خَدِيجٍ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم بِذِي الْحُلَيْفَةِ، فَأَصَابَ النَّاسَ جُوعٌ، فَأَصَبْنَا إِبِلاً وَغَنَمًا، وَكَانَ النَّبِيُّ صلى الله عليه وسلم فِي أُخْرَيَاتِ النَّاسِ، فَعَجِلُوا فَنَصَبُوا الْقُدُورَ، فَدُفِعَ إِلَيْهِمُ النَّبِيُّ صلى الله عليه وسلم فَأَمَرَ بِالْقُدُورِ فَأُكْفِئَتْ، ثُمَّ قَسَمَ فَعَدَلَ عَشَرَةً مِنَ الْغَنَمِ بِبَعِيرٍ، فَنَدَّ مِنْهَا بَعِيرٌ، وَكَانَ فِي الْقَوْمِ خَيْلٌ يَسِيرَةٌ فَطَلَبُوهُ فَأَعْيَاهُمْ، فَأَهْوَى إِلَيْهِ رَجُلٌ بِسَهْمٍ فَحَبَسَهُ اللَّهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ لِهَذِهِ الْبَهَائِمِ أَوَابِدَ كَأَوَابِدِ الْوَحْشِ، فَمَا نَدَّ عَلَيْكُمْ فَاصْنَعُوا بِهِ هَكَذَا ‏"‏‏.‏ قَالَ وَقَالَ جَدِّي إِنَّا لَنَرْجُو ـ أَوْ نَخَافُ ـ أَنْ نَلْقَى الْعَدُوَّ غَدًا، وَلَيْسَ مَعَنَا مُدًى، أَفَنَذْبَحُ بِالْقَصَبِ فَقَالَ ‏"‏ مَا أَنْهَرَ الدَّمَ وَذُكِرَ اسْمُ اللَّهِ عَلَيْهِ فَكُلْ، لَيْسَ السِّنَّ وَالظُّفُرَ، وَسَأُخْبِرُكُمْ عَنْهُ، أَمَّا السِّنُّ عَظْمٌ وَأَمَّا الظُّفُرُ فَمُدَى الْحَبَشَةِ ‏"‏‏.‏\hadithno{5498}\hadithtrans{Narrated Rafi` bin Khadij:We were with the Prophet (ﷺ) in Dhul-Hulaifa and there the people were struck with severe hunger. Then we got camels and sheep as war booty (and slaughtered them). The Prophet (ﷺ) was behind all the people. The people hurried and fixed the cooking pots (for cooking) but the Prophet (ﷺ) came there and ordered that the cooking pots be turned upside down. Then he distributed the animals, regarding ten sheep as equal to one camel. One of the camels ran away and there were a few horses with the people. They chased the camel but they got tired, whereupon a man shot it with an arrow whereby Allah stopped it. The Prophet (ﷺ) said, "Among these animals some are as wild as wild beasts, so if one of them runs away from you, treat it in this way." I said. "We hope, or we are afraid that tomorrow we will meet the enemy and we have no knives, shall we slaughter (our animals) with canes?" The Prophet (ﷺ) said, "If the killing tool causes blood to gush out and if Allah's Name is mentioned, eat (of the slaughterer animal). But do not slaughter with a tooth or a nail. I am telling you why: A tooth is a bone, and the nail is the knife of Ethiopians}}
\hadithdefcmd{bukhari}{5499}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ ـ يَعْنِي ابْنَ الْمُخْتَارِ ـ أَخْبَرَنَا مُوسَى بْنُ عُقْبَةَ، قَالَ أَخْبَرَنِي سَالِمٌ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ، يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ لَقِيَ زَيْدَ بْنَ عَمْرِو بْنِ نُفَيْلٍ بِأَسْفَلِ بَلْدَحٍ، وَذَاكَ قَبْلَ أَنْ يُنْزَلَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الْوَحْىُ، فَقَدَّمَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم سُفْرَةً فِيهَا لَحْمٌ، فَأَبَى أَنْ يَأْكُلَ مِنْهَا، ثُمَّ قَالَ إِنِّي لاَ آكُلُ مِمَّا تَذْبَحُونَ عَلَى أَنْصَابِكُمْ، وَلاَ آكُلُ إِلاَّ مِمَّا ذُكِرَ اسْمُ اللَّهِ عَلَيْهِ‏.‏\hadithno{5499}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said that he met Zaid bin `Amr Nufail at a place near Baldah and this had happened before Allah's Messenger (ﷺ) received the Divine Inspiration. Allah's Messenger (ﷺ) presented a dish of meat (that had been offered to him by the pagans) to Zaid bin `Amr, but Zaid refused to eat of it and then said (to the pagans), "I do not eat of what you slaughter on your stonealtars (Ansabs) nor do I eat except that on which Allah's Name has been mentioned on slaughtering}}
\hadithdefcmd{bukhari}{5500}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ جُنْدَبِ بْنِ سُفْيَانَ الْبَجَلِيِّ، قَالَ ضَحَّيْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم أُضْحِيَّةً ذَاتَ يَوْمٍ فَإِذَا أُنَاسٌ قَدْ ذَبَحُوا ضَحَايَاهُمْ قَبْلَ الصَّلاَةِ فَلَمَّا انْصَرَفَ رَآهُمُ النَّبِيُّ صلى الله عليه وسلم أَنَّهُمْ قَدْ ذَبَحُوا قَبْلَ الصَّلاَةِ فَقَالَ ‏ "‏ مَنْ ذَبَحَ قَبْلَ الصَّلاَةِ فَلْيَذْبَحْ مَكَانَهَا أُخْرَى، وَمَنْ كَانَ لَمْ يَذْبَحْ حَتَّى صَلَّيْنَا فَلْيَذْبَحْ عَلَى اسْمِ اللَّهِ ‏"‏‏.‏\hadithno{5500}\hadithtrans{Narrated Jundub bin Sufyan Al-Bajali:Once during the lifetime of Allah's Messenger (ﷺ) we offered some animals as sacrifices. Some people slaughtered their sacrifices before the (Id) prayer, so when the Prophet (ﷺ) finished his prayer, he saw that they had slaughtered their sacrifices before the prayer. He said, "Whoever has slaughtered (his sacrifice) before the prayer, should slaughter (another sacrifice) in lieu of it; and whoever has not yet slaughtered it till we have prayed; should slaughter (it) by mentioning Allah's Name}}
\hadithdefcmd{bukhari}{5501}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، سَمِعَ ابْنَ كَعْبِ بْنِ مَالِكٍ، يُخْبِرُ ابْنَ عُمَرَ أَنَّ أَبَاهُ، أَخْبَرَهُ أَنَّ جَارِيَةً لَهُمْ كَانَتْ تَرْعَى غَنَمًا بِسَلْعٍ، فَأَبْصَرَتْ بِشَاةٍ مِنْ غَنَمِهَا مَوْتًا، فَكَسَرَتْ حَجَرًا فَذَبَحَتْهَا، فَقَالَ لأَهْلِهِ لاَ تَأْكُلُوا حَتَّى آتِيَ النَّبِيَّ صلى الله عليه وسلم فَأَسْأَلَهُ، أَوْ حَتَّى أُرْسِلَ إِلَيْهِ مَنْ يَسْأَلُهُ‏.‏ فَأَتَى النَّبِيَّ صلى الله عليه وسلم أَوْ بَعَثَ إِلَيْهِ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم بِأَكْلِهَا‏.‏\hadithno{5501}\hadithtrans{Narrated Ka`b:that a slave girl of theirs used to shepherd some sheep at Si'a (a mountain near Medina). On seeing one of her sheep dying, she broke a stone and slaughtered it. Ka`b said to his family, "Do not eat (of it) till I go to the Prophet (ﷺ) and ask him, or, till I send someone to ask him." So he went to the Prophet (ﷺ) or sent someone to him The Prophet (ﷺ) permitted (them) to eat it}}
\hadithdefcmd{bukhari}{5502}{حَدَّثَنَا مُوسَى، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنْ رَجُلٍ، مِنْ بَنِي سَلِمَةَ أَخْبَرَ عَبْدَ اللَّهِ، أَنَّ جَارِيَةً، لِكَعْبِ بْنِ مَالِكٍ تَرْعَى غَنَمًا لَهُ بِالْجُبَيْلِ الَّذِي بِالسُّوقِ وَهْوَ بِسَلْعٍ، فَأُصِيبَتْ شَاةٌ، فَكَسَرَتْ حَجَرًا فَذَبَحَتْهَا، فَذَكَرُوا لِلنَّبِيِّ صلى الله عليه وسلم فَأَمَرَهُمْ بِأَكْلِهَا‏.‏\hadithno{5502}\hadithtrans{Narrated `Abdullah:that Ka`b had a slave girl who used to graze his sheep on a small mountain, called "Sl'a", situated near the market. Once a sheep was dying, so she broke a stone and slaughtered it with it. When they mentioned that to the Prophet, he, permitted them to eat it}}
\hadithdefcmd{bukhari}{5503}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رَافِعٍ، عَنْ جَدِّهِ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ لَيْسَ لَنَا مُدًى‏.‏ فَقَالَ ‏"‏ مَا أَنْهَرَ الدَّمَ وَذُكِرَ اسْمُ اللَّهِ فَكُلْ، لَيْسَ الظُّفُرَ وَالسِّنَّ، أَمَّا الظُّفُرُ فَمُدَى الْحَبَشَةِ، وَأَمَّا السِّنُّ فَعَظْمٌ ‏"‏‏.‏ وَنَدَّ بَعِيرٌ فَحَبَسَهُ فَقَالَ ‏"‏ إِنَّ لِهَذِهِ الإِبِلِ أَوَابِدَ كَأَوَابِدِ الْوَحْشِ فَمَا غَلَبَكُمْ مِنْهَا فَاصْنَعُوا هَكَذَا ‏"‏‏.‏\hadithno{5503}\hadithtrans{Narrated Rafi` bin Khadij:that he said, "O Allah's Messenger (ﷺ)! We have no knife." The Prophet (ﷺ) said, "if the killing tool causes blood to gush out, and if Allah's Name is mentioned, eat (of the slaughtered animal). But do not slaughter with a nail or a tooth, for the nail is the knife of Ethiopians and a tooth is a bone." Suddenly a camel ran away and it was stopped (with an arrow). The Prophet (ﷺ) then said, "Of these camels there are some which are as wild as wild beasts; so if one of them runs away from you and you cannot catch it, treat it in this manner (i.e. shoot it with an arrow)}}
\hadithdefcmd{bukhari}{5504}{حَدَّثَنَا صَدَقَةُ، أَخْبَرَنَا عَبْدَةُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنٍ لِكَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّ امْرَأَةً، ذَبَحَتْ شَاةً بِحَجَرٍ، فَسُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنْ ذَلِكَ، فَأَمَرَ بِأَكْلِهَا‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنَا نَافِعٌ أَنَّهُ سَمِعَ رَجُلاً مِنَ الأَنْصَارِ يُخْبِرُ عَبْدَ اللَّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّ جَارِيَةً لِكَعْبٍ بِهَذَا‏.‏\hadithno{5504}\hadithtrans{Narrated Ka`b bin Malik:A lady slaughtered a sheep with a stone and then the Prophet (ﷺ) was asked about it and he permitted it to be eaten}}
\hadithdefcmd{bukhari}{5505}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ رَجُلٍ، مِنَ الأَنْصَارِ عَنْ مُعَاذِ بْنِ سَعْدٍ ـ أَوْ سَعْدِ بْنِ مُعَاذٍ ـ أَخْبَرَهُ أَنَّ جَارِيَةً لِكَعْبِ بْنِ مَالِكٍ كَانَتْ تَرْعَى غَنَمًا بِسَلْعٍ، فَأُصِيبَتْ شَاةٌ مِنْهَا، فَأَدْرَكَتْهَا فَذَبَحَتْهَا بِحَجَرٍ، فَسُئِلَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ كُلُوهَا ‏"‏‏.‏\hadithno{5505}\hadithtrans{Narrated Mu`adh bin Sa`d or Sa`d bin Mu`adh:A slave girl belonging to Ka`b used to graze some sheep at Sl'a (mountain). Once one of her sheep was dying. She reached it (before it died) and slaughtered it with a stone. The Prophet (ﷺ) was asked, and he said, "Eat it}}
\hadithdefcmd{bukhari}{5506}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِيهِ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ كُلْ ـ يَعْنِي ـ مَا أَنْهَرَ الدَّمَ إِلاَّ السِّنَّ وَالظُّفُرَ ‏"‏‏.‏\hadithno{5506}\hadithtrans{Narrated Rafi` bin Khadij:The Prophet (ﷺ) said, "Eat what is slaughtered (with any instrument) that makes blood flow out, except what is slaughtered with a tooth or a nail}}
\hadithdefcmd{bukhari}{5507}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ، حَدَّثَنَا أُسَامَةُ بْنُ حَفْصٍ الْمَدَنِيُّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ قَوْمًا، قَالُوا لِلنَّبِيِّ صلى الله عليه وسلم إِنَّ قَوْمًا يَأْتُونَا بِاللَّحْمِ لاَ نَدْرِي أَذُكِرَ اسْمُ اللَّهِ عَلَيْهِ أَمْ لاَ فَقَالَ ‏ "‏ سَمُّوا عَلَيْهِ أَنْتُمْ وَكُلُوهُ ‏"‏‏.‏ قَالَتْ وَكَانُوا حَدِيثِي عَهْدٍ بِالْكُفْرِ‏.‏ تَابَعَهُ عَلِيٌّ عَنِ الدَّرَاوَرْدِيِّ‏.‏ وَتَابَعَهُ أَبُو خَالِدٍ وَالطُّفَاوِيُّ‏.‏\hadithno{5507}\hadithtrans{Narrated `Aisha:A group of people said to the Prophet, "Some people bring us meat and we do not know whether they have mentioned Allah's Name or not on slaughtering the animal." He said, "Mention Allah's Name on it and eat." Those people had embraced Islam recently}}
\hadithdefcmd{bukhari}{5508}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ ـ رضى الله عنه ـ قَالَ كُنَّا مُحَاصِرِينَ قَصْرَ خَيْبَرَ، فَرَمَى إِنْسَانٌ بِجِرَابٍ فِيهِ شَحْمٌ، فَنَزَوْتُ لآخُذَهُ، فَالْتَفَتُّ فَإِذَا النَّبِيُّ صلى الله عليه وسلم فَاسْتَحْيَيْتُ مِنْهُ‏\hadithno{5508}\hadithtrans{Narrates `Abdullah bin Mughaffal:While we were besieging the castle of Khaibar, Somebody threw a skin full of fat and I went ahead to take it, but on looking behind, I saw the Prophet (ﷺ) and I felt shy in his presence (and did not take it)}}
\hadithdefcmd{bukhari}{5509}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَبِي، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ بْنِ رَافِعِ بْنِ خَدِيجٍ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا لاَقُو الْعَدُوِّ غَدًا، وَلَيْسَتْ مَعَنَا مُدًى فَقَالَ ‏"‏ اعْجَلْ أَوْ أَرِنْ مَا أَنْهَرَ الدَّمَ وَذُكِرَ اسْمُ اللَّهِ فَكُلْ، لَيْسَ السِّنَّ وَالظُّفُرَ، وَسَأُحَدِّثُكَ، أَمَّا السِّنُّ فَعَظْمٌ، وَأَمَّا الظُّفُرُ فَمُدَى الْحَبَشَةِ ‏"‏‏.‏ وَأَصَبْنَا نَهْبَ إِبِلٍ وَغَنَمٍ فَنَدَّ مِنْهَا بَعِيرٌ، فَرَمَاهُ رَجُلٌ بِسَهْمٍ فَحَبَسَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ لِهَذِهِ الإِبِلِ أَوَابِدَ كَأَوَابِدِ الْوَحْشِ، فَإِذَا غَلَبَكُمْ مِنْهَا شَىْءٌ، فَافْعَلُوا بِهِ هَكَذَا ‏"‏‏.‏\hadithno{5509}\hadithtrans{Narrated Rafi` bin Khadij:I said, "O Allah's Messenger (ﷺ)! We are going to face the enemy tomorrow and we do not have knives." He said, "Hurry up (in killing the animal). If the killing tool causes blood to flow out, and if Allah's Name is mentioned, eat (of the slaughtered animal). But do not slaughter with a tooth or a nail. I will tell you why: As for the tooth, it is a bone; and as for the nail, it is the knife of Ethiopians." Then we got some camels and sheep as war booty, and one of those camels ran away, whereupon a man shot it with an arrow and stopped it. Allah's Messenger (ﷺ) said, "Of these camels there are some which are as wild as wild beasts, so if one of them (runs away and) makes you tired, treat it in this manner}}
\hadithdefcmd{bukhari}{5510}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، قَالَ أَخْبَرَتْنِي فَاطِمَةُ بِنْتُ الْمُنْذِرِ، امْرَأَتِي عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ قَالَتْ نَحَرْنَا عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَرَسًا فَأَكَلْنَاهُ‏.‏\hadithno{5510}\hadithtrans{Narrated Asma bint Abu Bakr:We slaughtered a horse (by Nahr) during the lifetime of the Prophet (ﷺ) and ate it}}
\hadithdefcmd{bukhari}{5511}{حَدَّثَنَا إِسْحَاقُ، سَمِعَ عَبْدَةَ، عَنْ هِشَامٍ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، قَالَتْ ذَبَحْنَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَسًا وَنَحْنُ بِالْمَدِينَةِ فَأَكَلْنَاهُ‏.‏\hadithno{5511}\hadithtrans{Narrated Asma':We slaughtered a horse (by Dhabh) during the lifetime of Allah's Messenger (ﷺ) while we were at Medina, and we ate it}}
\hadithdefcmd{bukhari}{5512}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنْ هِشَامٍ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، أَنَّ أَسْمَاءَ بِنْتَ أَبِي بَكْرٍ، قَالَتْ نَحَرْنَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَسًا فَأَكَلْنَاهُ‏.‏ تَابَعَهُ وَكِيعٌ وَابْنُ عُيَيْنَةَ عَنْ هِشَامٍ فِي النَّحْرِ‏.‏\hadithno{5512}\hadithtrans{Narrated Asma' bint Abu Bakr:We slaughtered a horse (by Nahr) during the lifetime of Allah's Messenger (ﷺ) and ate it}}
\hadithdefcmd{bukhari}{5513}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، قَالَ دَخَلْتُ مَعَ أَنَسٍ عَلَى الْحَكَمِ بْنِ أَيُّوبَ، فَرَأَى غِلْمَانًا ـ أَوْ فِتْيَانًا ـ نَصَبُوا دَجَاجَةً يَرْمُونَهَا‏.‏ فَقَالَ أَنَسٌ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ تُصْبَرَ الْبَهَائِمُ‏.‏\hadithno{5513}\hadithtrans{Narrated Hisham bin Zaid:Anas and I went to Al-Hakam bin Aiyub. Anas saw some boys shooting at a tied hen. Anas said, "The Prophet has forbidden the shooting of tied or confined animals}}
\hadithdefcmd{bukhari}{5514}{حَدَّثَنَا أَحْمَدُ بْنُ يَعْقُوبَ، أَخْبَرَنَا إِسْحَاقُ بْنُ سَعِيدِ بْنِ عَمْرٍو، عَنْ أَبِيهِ، أَنَّهُ سَمِعَهُ يُحَدِّثُ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّهُ دَخَلَ عَلَى يَحْيَى بْنِ سَعِيدٍ وَغُلاَمٌ مِنْ بَنِي يَحْيَى رَابِطٌ دَجَاجَةً يَرْمِيهَا، فَمَشَى إِلَيْهَا ابْنُ عُمَرَ حَتَّى حَلَّهَا، ثُمَّ أَقْبَلَ بِهَا وَبِالْغُلاَمِ مَعَهُ فَقَالَ ازْجُرُوا غُلاَمَكُمْ عَنْ أَنْ يَصْبِرَ هَذَا الطَّيْرَ لِلْقَتْلِ، فَإِنِّي سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ تُصْبَرَ بَهِيمَةٌ أَوْ غَيْرُهَا لِلْقَتْلِ‏.‏\hadithno{5514}\hadithtrans{Narrated Ibn `Umar:that he entered upon Yahya bin Sa`id while one of Yahya's sons was aiming at a hen after tying it. Ibn `Umar walked to it and untied it. Then he brought it and the boy and said. "Prevent your boys from tying the birds for the sake of killing them, as I have heard the Prophet (ﷺ) forbidding the killing of an animal or other living thing after tying them}}
\hadithdefcmd{bukhari}{5515}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ كُنْتُ عِنْدَ ابْنِ عُمَرَ فَمَرُّوا بِفِتْيَةٍ أَوْ بِنَفَرٍ نَصَبُوا دَجَاجَةً يَرْمُونَهَا، فَلَمَّا رَأَوُا ابْنَ عُمَرَ تَفَرَّقُوا عَنْهَا، وَقَالَ ابْنُ عُمَرَ مَنْ فَعَلَ هَذَا إِنَّ النَّبِيَّ صلى الله عليه وسلم لَعَنَ مَنْ فَعَلَ هَذَا‏.‏ تَابَعَهُ سُلَيْمَانُ عَنْ شُعْبَةَ، حَدَّثَنَا الْمِنْهَالُ، عَنْ سَعِيدٍ، عَنِ ابْنِ عُمَرَ، لَعَنَ النَّبِيُّ صلى الله عليه وسلم مَنْ مَثَّلَ بِالْحَيَوَانِ‏.‏ وَقَالَ عَدِيٌّ عَنْ سَعِيدٍ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{5515}\hadithtrans{Narrated Sa`id bin Jubair:While I was with Ibn `Umar, we passed by a group of young men who had tied a hen and started shooting at it. When they saw Ibn `Umar, they dispersed, leaving it. On that Ibn `Umar said, "Who has done this? The Prophet (ﷺ) cursed the one who did so." Narrated Ibn `Umar: The Prophet (ﷺ) cursed the one who did Muthla to an animal (i e., cut its limbs or some other part of its body while it is still alive)}}
\hadithdefcmd{bukhari}{5516}{حَدَّثَنَا حَجَّاجُ بْنُ مِنْهَالٍ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي عَدِيُّ بْنُ ثَابِتٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ يَزِيدَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنِ النُّهْبَةِ وَالْمُثْلَةِ‏.‏\hadithno{5516}\hadithtrans{Narrated `Abdullah bin Yazid:The Prophet (ﷺ) forbade An-Nuhba and Al-Muthla}}
\hadithdefcmd{bukhari}{5517}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ زَهْدَمٍ الْجَرْمِيِّ، عَنْ أَبِي مُوسَى ـ يَعْنِي الأَشْعَرِيَّ ـ رضى الله عنه ـ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَأْكُلُ دَجَاجًا‏.‏\hadithno{5517}\hadithtrans{Narrated Abu Musa Al-Ash`ari:I saw the Prophet (ﷺ) eating chicken}}
\hadithdefcmd{bukhari}{5518}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ بْنُ أَبِي تَمِيمَةَ، عَنِ الْقَاسِمِ، عَنْ زَهْدَمٍ، قَالَ كُنَّا عِنْدَ أَبِي مُوسَى الأَشْعَرِيِّ، وَكَانَ بَيْنَنَا وَبَيْنَ هَذَا الْحَىِّ مِنْ جَرْمٍ إِخَاءٌ، فَأُتِيَ بِطَعَامٍ فِيهِ لَحْمُ دَجَاجٍ، وَفِي الْقَوْمِ رَجُلٌ جَالِسٌ أَحْمَرُ فَلَمْ يَدْنُ مِنْ طَعَامِهِ قَالَ ادْنُ فَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْكُلُ مِنْهُ‏.‏ قَالَ إِنِّي رَأَيْتُهُ أَكَلَ شَيْئًا فَقَذِرْتُهُ، فَحَلَفْتُ أَنْ لاَ آكُلَهُ‏.‏ فَقَالَ ادْنُ أُخْبِرْكَ ـ أَوْ أُحَدِّثْكَ ـ إِنِّي أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فِي نَفَرٍ مِنَ الأَشْعَرِيِّينَ، فَوَافَقْتُهُ وَهْوَ غَضْبَانُ، وَهْوَ يَقْسِمُ نَعَمًا مِنْ نَعَمِ الصَّدَقَةِ فَاسْتَحْمَلْنَاهُ فَحَلَفَ أَنْ لاَ يَحْمِلَنَا، قَالَ ‏"‏ مَا عِنْدِي مَا أَحْمِلُكُمْ عَلَيْهِ ‏"‏‏.‏ ثُمَّ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِنَهْبٍ مِنْ إِبِلٍ فَقَالَ ‏"‏ أَيْنَ الأَشْعَرِيُّونَ أَيْنَ الأَشْعَرِيُّونَ ‏"‏‏.‏ قَالَ فَأَعْطَانَا خَمْسَ ذَوْدٍ غُرِّ الذُّرَى، فَلَبِثْنَا غَيْرَ بَعِيدٍ، فَقُلْتُ لأَصْحَابِي نَسِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمِينَهُ، فَوَاللَّهِ لَئِنْ تَغَفَّلْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم يَمِينَهُ لاَ نُفْلِحُ أَبَدًا‏.‏ فَرَجَعْنَا إِلَى النَّبِيِّ صلى الله عليه وسلم فَقُلْنَا يَا رَسُولَ اللَّهِ إِنَّا اسْتَحْمَلْنَاكَ، فَحَلَفْتَ أَنْ لاَ تَحْمِلَنَا فَظَنَنَّا أَنَّكَ نَسِيتَ يَمِينَكَ‏.‏ فَقَالَ ‏"‏ إِنَّ اللَّهَ هُوَ حَمَلَكُمْ، إِنِّي وَاللَّهِ إِنْ شَاءَ اللَّهُ لاَ أَحْلِفُ عَلَى يَمِينٍ فَأَرَى غَيْرَهَا خَيْرًا مِنْهَا إِلاَّ أَتَيْتُ الَّذِي هُوَ خَيْرٌ، وَتَحَلَّلْتُهَا ‏"‏‏.‏\hadithno{5518}\hadithtrans{Narrated Zahdam:We were in the company of Abu Musa Al-Ash`ari and there were friendly relations between us and this tribe of Jarm. Abu Musa was presented with a dish containing chicken. Among the people there was sitting a red-faced man who did not come near the food. Abu Musa said (to him), "Come on (and eat), for I have seen Allah's Messenger (ﷺ) eating of it (i.e. chicken)." He said, "I have seen it eating something (dirty) and since then I have disliked it, and have taken an oath that I shall not eat it ' Abu Musa said, "Come on, I will tell you (or narrate to you). Once I went to Allah's Apostle with a group of Al-Ash`ariyin, and met him while he was angry, distributing some camels of rak`at. We asked for mounts but he took an oath that he would not give us any mounts, and added, 'I have nothing to mount you on' In the meantime some camels of booty were brought to Allah's Messenger (ﷺ) and he asked twice, 'Where are Al-Ash`ariyin?" So he gave us five white camels with big humps. We stayed for a short while (after we had covered a little distance), and then I said to my companions, "Allah's Messenger (ﷺ) has forgotten his oath. By Allah, if we do not remind Allah's Messenger (ﷺ) of his oath, we will never be successful." So we returned to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! We asked you for mounts, but you took an oath that you would not give us any mounts; we think that you have forgotten your oath.' He said, 'It is Allah Who has given you mounts. By Allah, and Allah willing, if I take an oath and later find something else better than that. then I do what is better and expiate my oath}}
\hadithdefcmd{bukhari}{5519}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا هِشَامٌ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، قَالَتْ نَحَرْنَا فَرَسًا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَكَلْنَاهُ‏.‏\hadithno{5519}\hadithtrans{Narrated Asma':We slaughtered a horse during the lifetime of Allah's Messenger (ﷺ) and ate it}}
\hadithdefcmd{bukhari}{5520}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ مُحَمَّدِ بْنِ عَلِيٍّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهم ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم يَوْمَ خَيْبَرَ عَنْ لُحُومِ الْحُمُرِ، وَرَخَّصَ فِي لُحُومِ الْخَيْلِ‏.‏\hadithno{5520}\hadithtrans{Narrated Jabir bin `Abdullah:On the Day of the battle of Khaibar, Allah's Messenger (ﷺ) made donkey's meat unlawful and allowed the eating of horse flesh}}
\hadithdefcmd{bukhari}{5521}{حَدَّثَنَا صَدَقَةُ، أَخْبَرَنَا عَبْدَةُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ سَالِمٍ، وَنَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ يَوْمَ خَيْبَرَ‏.‏\hadithno{5521}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) made the meat of donkeys unlawful on the day of the battle of Khaibar}}
\hadithdefcmd{bukhari}{5522}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ، قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ‏.‏ تَابَعَهُ ابْنُ الْمُبَارَكِ عَنْ عُبَيْدِ اللَّهِ عَنْ نَافِعٍ‏.‏ وَقَالَ أَبُو أُسَامَةَ عَنْ عُبَيْدِ اللَّهِ عَنْ سَالِمٍ‏.‏\hadithno{5522}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) prohibited the eating of donkey's meat}}
\hadithdefcmd{bukhari}{5523}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ، وَالْحَسَنِ، ابْنَىْ مُحَمَّدِ بْنِ عَلِيٍّ عَنْ أَبِيهِمَا، عَنْ عَلِيٍّ ـ رضى الله عنهم ـ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُتْعَةِ عَامَ خَيْبَرَ وَلُحُومِ حُمُرِ الإِنْسِيَّةِ‏.‏\hadithno{5523}\hadithtrans{Narrated `Ali:Allah's Messenger (ﷺ) prohibited Al-Mut'a marriage and the eating of donkey's meat in the year of the Khaibar battle}}
\hadithdefcmd{bukhari}{5524}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرٍو، عَنْ مُحَمَّدِ بْنِ عَلِيٍّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم يَوْمَ خَيْبَرَ عَنْ لُحُومِ الْحُمُرِ، وَرَخَّصَ فِي لُحُومِ الْخَيْلِ‏.‏\hadithno{5524}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) prohibited the eating of donkey's meat on the day of the battle of Khaibar, and allowed the eating of horse flesh}}
\hadithdefcmd{bukhari}{5526}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، قَالَ حَدَّثَنِي عَدِيٌّ، عَنِ الْبَرَاءِ، وَابْنِ أَبِي أَوْفَى، رضى الله عنهم قَالاَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ لُحُومِ الْحُمُرِ‏.‏\hadithno{5526}\hadithtrans{Narrated Al-Bara' and Ibn Abi `Aufa:The Prophet (ﷺ) prohibited the eating of donkey's meat}}
\hadithdefcmd{bukhari}{5527}{حَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ أَبَا إِدْرِيسَ، أَخْبَرَهُ أَنَّ أَبَا ثَعْلَبَةَ قَالَ حَرَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لُحُومَ الْحُمُرِ الأَهْلِيَّةِ‏.‏ تَابَعَهُ الزُّبَيْدِيُّ وَعُقَيْلٌ عَنِ ابْنِ شِهَابٍ‏.‏ وَقَالَ مَالِكٌ وَمَعْمَرٌ وَالْمَاجِشُونُ وَيُونُسُ وَابْنُ إِسْحَاقَ عَنِ الزُّهْرِيِّ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ‏.‏\hadithno{5527}\hadithtrans{Narrated Abu Tha'alba: Allah's Messenger (ﷺ) prohibited the eating of donkey's meat. Narrated Az-Zuhri: The Prophet (ﷺ) prohibited the eating of beasts having fangs}}
\hadithdefcmd{bukhari}{5528}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَاءَهُ جَاءٍ فَقَالَ أُكِلَتِ الْحُمُرُ، ثُمَّ جَاءَهُ جَاءٍ فَقَالَ أُكِلَتِ الْحُمُرُ‏.‏ ثُمَّ جَاءَهُ جَاءٍ فَقَالَ أُفْنِيَتِ الْحُمُرُ‏.‏ فَأَمَرَ مُنَادِيًا فَنَادَى فِي النَّاسِ إِنَّ اللَّهَ وَرَسُولَهُ يَنْهَيَانِكُمْ عَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ، فَإِنَّهَا رِجْسٌ‏.‏ فَأُكْفِئَتِ الْقُدُورُ وَإِنَّهَا لَتَفُورُ بِاللَّحْمِ‏.‏\hadithno{5528}\hadithtrans{Narrated Anas bin Malik:Someone came to Allah's Messenger (ﷺ) and said, "The donkeys have been (slaughtered and) eaten. Another man came and said, "The donkeys have been destroyed." On that the Prophet (ﷺ) ordered a caller to announce to the people: Allah and His Apostle forbid you to eat the meat of donkeys, for it is impure.' Thus the pots were turned upside down while the (donkeys') meat was boiling in them}}
\hadithdefcmd{bukhari}{5529}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو قُلْتُ لِجَابِرِ بْنِ زَيْدٍ يَزْعُمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ حُمُرِ الأَهْلِيَّةِ فَقَالَ قَدْ كَانَ يَقُولُ ذَاكَ الْحَكَمُ بْنُ عَمْرٍو الْغِفَارِيُّ عِنْدَنَا بِالْبَصْرَةِ، وَلَكِنْ أَبَى ذَاكَ الْبَحْرُ ابْنُ عَبَّاسٍ وَقَرَأَ ‏\{‏قُلْ لاَ أَجِدُ فِيمَا أُوحِيَ إِلَىَّ مُحَرَّمًا‏\}‏\hadithno{5529}\hadithtrans{Narrated `Amr:I said to Jabir bin Zaid, "The people claim that Allah's Messenger (ﷺ) forbade the eating of donkey's meat." He said, "Al-Hakam bin `Amr Al-Ghifari used to say so when he was with us, but Ibn `Abbas, the great religious learned man, refused to give a final verdict and recited:-- 'Say: I find not in that which has been inspired to me anything forbidden to be eaten by one who wishes to eat it, unless it be carrion, blood poured forth or the flesh of swine}}
\hadithdefcmd{bukhari}{5530}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي ثَعْلَبَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ أَكْلِ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ‏.‏ تَابَعَهُ يُونُسُ وَمَعْمَرٌ وَابْنُ عُيَيْنَةَ وَالْمَاجِشُونُ عَنِ الزُّهْرِيِّ‏.‏\hadithno{5530}\hadithtrans{Narrated Abu Tha`laba:Allah's Messenger (ﷺ) forbade the eating of the meat of beasts having fangs}}
\hadithdefcmd{bukhari}{5531}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، قَالَ حَدَّثَنِي ابْنُ شِهَابٍ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ ـ رضى الله عنهما ـ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِشَاةٍ مَيِّتَةٍ فَقَالَ ‏"‏ هَلاَّ اسْتَمْتَعْتُمْ بِإِهَابِهَا ‏"‏‏.‏ قَالُوا إِنَّهَا مَيِّتَةٌ‏.‏ قَالَ ‏"‏ إِنَّمَا حَرُمَ أَكْلُهَا ‏"‏‏.‏\hadithno{5531}\hadithtrans{Narrated `Abdullah bin `Abbas:Once Allah's Messenger (ﷺ) passed by a dead sheep and said (to the people), "Why don't you use its hide?" They said, "But it is dead," He said, "Only eating it, is prohibited}}
\hadithdefcmd{bukhari}{5532}{حَدَّثَنَا خَطَّابُ بْنُ عُثْمَانَ، حَدَّثَنَا مُحَمَّدُ بْنُ حِمْيَرَ، عَنْ ثَابِتِ بْنِ عَجْلاَنَ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ مَرَّ النَّبِيُّ صلى الله عليه وسلم بِعَنْزٍ مَيْتَةٍ فَقَالَ ‏ "‏ مَا عَلَى أَهْلِهَا لَوِ انْتَفَعُوا بِإِهَابِهَا ‏"‏‏.‏\hadithno{5532}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) passed by a dead goat and said, "There is no harm if its owners benefit from its skin}}
\hadithdefcmd{bukhari}{5533}{حَدَّثَنَا مُسَدَّدٌ، عَنْ عَبْدِ الْوَاحِدِ، حَدَّثَنَا عُمَارَةُ بْنُ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ مَكْلُومٍ يُكْلَمُ فِي اللَّهِ إِلاَّ جَاءَ يَوْمَ الْقِيَامَةِ وَكَلْمُهُ يَدْمَى، اللَّوْنُ لَوْنُ دَمٍ وَالرِّيحُ رِيحُ مِسْكٍ ‏"‏‏.‏\hadithno{5533}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "None is wounded in Allah's Cause but will come on the Day of Resurrection with his wound bleeding. The thing that will come out of his wound will be the color of blood, but its smell will be the smell of musk}}
\hadithdefcmd{bukhari}{5534}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الْجَلِيسِ الصَّالِحِ وَالسَّوْءِ كَحَامِلِ الْمِسْكِ وَنَافِخِ الْكِيرِ، فَحَامِلُ الْمِسْكِ إِمَّا أَنْ يُحْذِيَكَ، وَإِمَّا أَنْ تَبْتَاعَ مِنْهُ، وَإِمَّا أَنْ تَجِدَ مِنْهُ رِيحًا طَيِّبَةً، وَنَافِخُ الْكِيرِ إِمَّا أَنْ يُحْرِقَ ثِيَابَكَ، وَإِمَّا أَنْ تَجِدَ رِيحًا خَبِيثَةً ‏"‏‏.‏\hadithno{5534}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, 'The example of a good pious companion and an evil one is that of a person carrying musk and another blowing a pair of bellows. The one who is carrying musk will either give you some perfume as a present, or you will buy some from him, or you will get a good smell from him, but the one who is blowing a pair of bellows will either burn your clothes or you will get a bad smell from him}}
\hadithdefcmd{bukhari}{5535}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ أَنْفَجْنَا أَرْنَبًا وَنَحْنُ بِمَرِّ الظَّهْرَانِ، فَسَعَى الْقَوْمُ فَلَغَبُوا، فَأَخَذْتُهَا فَجِئْتُ بِهَا إِلَى أَبِي طَلْحَةَ فَذَبَحَهَا، فَبَعَثَ بِوَرِكَيْهَا ـ أَوْ قَالَ بِفَخِذَيْهَا ـ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَبِلَهَا‏.‏\hadithno{5535}\hadithtrans{Narrated Anas bin Malik:Once we provoked a rabbit at Marr-az-Zahran. The people chased it till they got tired. Then I caught It and brought it to Abu Talha, who slaughtered it and then sent both its pelvic pieces (or legs) to the Prophet, and the Prophet (ﷺ) accepted the present}}
\hadithdefcmd{bukhari}{5536}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الضَّبُّ لَسْتُ آكُلُهُ وَلاَ أُحَرِّمُهُ ‏"‏‏.‏\hadithno{5536}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "I do not eat mastigure, but I do not prohibit its eating}}
\hadithdefcmd{bukhari}{5537}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنْ خَالِدِ بْنِ الْوَلِيدِ، أَنَّهُ دَخَلَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بَيْتَ مَيْمُونَةَ فَأُتِيَ بِضَبٍّ مَحْنُوذٍ، فَأَهْوَى إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ فَقَالَ بَعْضُ النِّسْوَةِ أَخْبِرُوا رَسُولَ اللَّهِ صلى الله عليه وسلم بِمَا يُرِيدُ أَنْ يَأْكُلَ‏.‏ فَقَالُوا هُوَ ضَبٌّ يَا رَسُولَ اللَّهِ‏.‏ فَرَفَعَ يَدَهُ، فَقُلْتُ أَحَرَامٌ هُوَ يَا رَسُولَ اللَّهِ فَقَالَ ‏ "‏ لاَ، وَلَكِنْ لَمْ يَكُنْ بِأَرْضِ قَوْمِي فَأَجِدُنِي أَعَافُهُ ‏"‏‏.‏ قَالَ خَالِدٌ فَاجْتَرَرْتُهُ فَأَكَلْتُهُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَنْظُرُ‏.‏\hadithno{5537}\hadithtrans{Narrated Khalid bin Al-Walid:Allah's Messenger (ﷺ) and I entered the house of Maimuna. A roasted mastigure was served. Allah's Messenger (ﷺ) stretched his hand out (to eat of it) but some woman said, "Inform Allah's Messenger (ﷺ) of what he is about to eat." So they said, "It is mastigure, O Allah's Messenger (ﷺ)!" He withdrew his hand, whereupon I said, "O Allah's Messenger (ﷺ)! Is it unlawful?" He said, "No, but this is not found in the land of my people, so I dislike it." So I pulled the mastigure towards me and ate it while Allah's Messenger (ﷺ) was looking at me}}
\hadithdefcmd{bukhari}{5538}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الزُّهْرِيُّ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، يُحَدِّثُهُ عَنْ مَيْمُونَةَ، أَنَّ فَأْرَةً، وَقَعَتْ، فِي سَمْنٍ فَمَاتَتْ، فَسُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنْهَا فَقَالَ ‏ "‏ أَلْقُوهَا وَمَا حَوْلَهَا وَكُلُوهُ ‏"‏‏.‏ قِيلَ لِسُفْيَانَ فَإِنَّ مَعْمَرًا يُحَدِّثُهُ عَنِ الزُّهْرِيِّ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ عَنْ أَبِي هُرَيْرَةَ‏.‏ قَالَ مَا سَمِعْتُ الزُّهْرِيَّ يَقُولُ إِلاَّ عَنْ عُبَيْدِ اللَّهِ عَنِ ابْنِ عَبَّاسٍ عَنْ مَيْمُونَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَقَدْ سَمِعْتُهُ مِنْهُ مِرَارًا‏.‏\hadithno{5538}\hadithtrans{Narrated Maimuna:A mouse fell into the butter-fat and died. The Prophet (ﷺ) was asked about that. He said, "Throw away the mouse and the butter-fat that surrounded it, and eat the rest of the butter-fat (As-Samn)}}
\hadithdefcmd{bukhari}{5539}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنِ الدَّابَّةِ، تَمُوتُ فِي الزَّيْتِ وَالسَّمْنِ وَهْوَ جَامِدٌ أَوْ غَيْرُ جَامِدٍ، الْفَأْرَةِ أَوْ غَيْرِهَا قَالَ بَلَغَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِفَأْرَةٍ مَاتَتْ فِي سَمْنٍ، فَأَمَرَ بِمَا قَرُبَ مِنْهَا فَطُرِحَ ثُمَّ أُكِلَ، عَنْ حَدِيثِ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ‏.‏\hadithno{5539}\hadithtrans{Narrated Az-Zhuri:regarding an animal, e.g., a mouse or some other animal that had fallen into solid or liquid oil or butter-fat: I had been informed that a mouse had died in butter-fat whereupon Allah's Messenger (ﷺ) ordered that the butter-fat near it be thrown away and the rest of the butter-fat can be eaten}}
\hadithdefcmd{bukhari}{5540}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ ـ رضى الله عنهم ـ قَالَتْ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنْ فَأْرَةٍ سَقَطَتْ فِي سَمْنٍ فَقَالَ ‏ "‏ أَلْقُوهَا وَمَا حَوْلَهَا وَكُلُوهُ ‏"‏‏.‏\hadithno{5540}\hadithtrans{Narrated Maimuna:The Prophet (ﷺ) was asked about a mouse that had fallen into butter-fat (and died). He said, "Throw away the mouse and the portion of butter-fat around it, and eat the rest}}
\hadithdefcmd{bukhari}{5541}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ حَنْظَلَةَ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَرِهَ أَنْ تُعْلَمَ الصُّورَةُ،‏.‏ وَقَالَ ابْنُ عُمَرَ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ تُضْرَبَ‏.‏ تَابَعَهُ قُتَيْبَةُ حَدَّثَنَا الْعَنْقَزِيُّ عَنْ حَنْظَلَةَ وَقَالَ تُضْرَبُ الصُّورَةُ‏.‏\hadithno{5541}\hadithtrans{Narrated Salim:that Ibn `Umar disliked the branding of animals on the face. Ibn `Umar said, "The Prophet (ﷺ) forbade beating (animals) on the face}}
\hadithdefcmd{bukhari}{5542}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ هِشَامِ بْنِ زَيْدٍ، عَنْ أَنَسٍ، قَالَ دَخَلْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم بِأَخٍ لِي يُحَنِّكُهُ، وَهْوَ فِي مِرْبَدٍ لَهُ، فَرَأَيْتُهُ يَسِمُ شَاةً ـ حَسِبْتُهُ قَالَ ـ فِي آذَانِهَا‏.‏\hadithno{5542}\hadithtrans{Narrated Anas:I brought a brother of mine to the Prophet (ﷺ) to do Tahnik for him while the Prophet (ﷺ) was in a sheep fold of his, and I saw him branding a sheep. (The sub-narrator said: I think Anas said, branding it on the ear)}}
\hadithdefcmd{bukhari}{5543}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا سَعِيدُ بْنُ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، رَافِعِ بْنِ خَدِيجٍ قَالَ قُلْتُ لِلنَّبِيِّ صلى الله عليه وسلم إِنَّنَا نَلْقَى الْعَدُوَّ غَدًا، وَلَيْسَ مَعَنَا مُدًى‏.‏ فَقَالَ ‏"‏ مَا أَنْهَرَ الدَّمَ وَذُكِرَ اسْمُ اللَّهِ فَكُلُوا، مَا لَمْ يَكُنْ سِنٌّ وَلاَ ظُفُرٌ، وَسَأُحَدِّثُكُمْ عَنْ ذَلِكَ، أَمَّا السِّنُّ فَعَظْمٌ، وَأَمَّا الظُّفْرُ فَمُدَى الْحَبَشَةِ ‏"‏‏.‏ وَتَقَدَّمَ سَرَعَانُ النَّاسِ فَأَصَابُوا مِنَ الْغَنَائِمِ وَالنَّبِيُّ صلى الله عليه وسلم فِي آخِرِ النَّاسِ فَنَصَبُوا قُدُورًا فَأَمَرَ بِهَا فَأُكْفِئَتْ وَقَسَمَ بَيْنَهُمْ وَعَدَلَ بَعِيرًا بِعَشْرِ شِيَاهٍ، ثُمَّ نَدَّ بَعِيرٌ مِنْ أَوَائِلِ الْقَوْمِ وَلَمْ يَكُنْ مَعَهُمْ خَيْلٌ فَرَمَاهُ رَجُلٌ بِسَهْمٍ فَحَبَسَهُ اللَّهُ‏.‏ فَقَالَ ‏"‏ إِنَّ لِهَذِهِ الْبَهَائِمِ أَوَابِدَ كَأَوَابِدِ الْوَحْشِ فَمَا فَعَلَ مِنْهَا هَذَا فَافْعَلُوا مِثْلَ هَذَا ‏"‏‏.‏\hadithno{5543}\hadithtrans{Narrated Rait' bin Khadij:I said to the Prophet, "We will be facing the enemy tomorrow and we have no knives (for slaughtering)' He said, "If you slaughter the animal with anything that causes its blood to flow out, and if Allah's Name is mentioned on slaughtering it, eat of it, unless the killing instrument is a tooth or nail. I will tell you why: As for the tooth, it is a bone; and as for the nail, it is the knife of Ethiopians." The quick ones among the people got the war booty while the Prophet (ﷺ) was behind the people. So they placed the cooking pots on the fire, but the Prophet (ﷺ) ordered the cooking pots to be turned upside down. Then he distributed (the war booty) among them, considering one camel as equal to ten sheep. Then a camel belonging to the first party of people ran away and they had no horses with them, so a man shot it with an arrow whereby Allah stopped it. The Prophet (ﷺ) said, "Of these animals there are some which are as wild as wild beasts. So, if anyone of them runs away like this, do like this (shoot it with an arrow)}}
\hadithdefcmd{bukhari}{5544}{حَدَّثَنَا ابْنُ سَلاَمٍ، أَخْبَرَنَا عُمَرُ بْنُ عُبَيْدٍ الطَّنَافِسِيُّ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ جَدِّهِ، رَافِعِ بْنِ خَدِيجٍ ـ رضى الله عنه ـ قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَنَدَّ بَعِيرٌ مِنَ الإِبِلِ ـ قَالَ ـ فَرَمَاهُ رَجُلٌ بِسَهْمٍ فَحَبَسَهُ، قَالَ ثُمَّ قَالَ ‏"‏ إِنَّ لَهَا أَوَابِدَ كَأَوَابِدِ الْوَحْشِ فَمَا غَلَبَكُمْ مِنْهَا فَاصْنَعُوا بِهِ هَكَذَا ‏"‏‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا نَكُونُ فِي الْمَغَازِي وَالأَسْفَارِ فَنُرِيدُ أَنْ نَذْبَحَ فَلاَ تَكُونُ مُدًى قَالَ ‏"‏ أَرِنْ مَا نَهَرَ ـ أَوْ أَنْهَرَ ـ الدَّمَ وَذُكِرَ اسْمُ اللَّهِ فَكُلْ، غَيْرَ السِّنِّ وَالظُّفُرِ، فَإِنَّ السِّنَّ عَظْمٌ، وَالظُّفُرَ مُدَى الْحَبَشَةِ ‏"‏‏.‏\hadithno{5544}\hadithtrans{Narrated Rafi` bin Khadij:While we were with the Prophet. on a journey, one of the camels ran away. A man shot it with an arrow and stopped it. The Prophet (ﷺ) said, "Of these camels some are as wild as wild beasts, so if one of them runs away and you cannot catch it, then do like this (shoot it with an arrow)." I said, "O Allah's Apostle! Sometimes when we are in battles or on a journey we want to slaughter (animals) but we have no knives." He said, "Listen! If you slaughter the animal with anything that causes its blood to flow out, and if Allah's Name is mentioned on slaughtering it, eat of it, provided that the slaughtering instrument is not a tooth or a nail, as the tooth is a bone and the nail is the knife of Ethiopians}}
