% Auto-generated chapter 14 for bukhari
% Hadiths in this chapter: 15

\hadithdefcmd{bukhari}{990}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، وَعَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ صَلاَةِ اللَّيْلِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صَلاَةُ اللَّيْلِ مَثْنَى مَثْنَى، فَإِذَا خَشِيَ أَحَدُكُمُ الصُّبْحَ صَلَّى رَكْعَةً وَاحِدَةً، تُوتِرُ لَهُ مَا قَدْ صَلَّى ‏"‏‏.‏\hadithno{990}\hadithtrans{Narrated Ibn `Umar: Once a person asked Allah's Messenger (ﷺ) about the night prayer. Allah's Apostle (ﷺ) replied, "The night prayer is offered as two Rak`at followed by two Rak`at and so on and if anyone is afraid of the approaching dawn (Fajr prayer) he should pray one Rak`ah and this will be a Witr for all the Rak`at which he has prayed before}}
\hadithdefcmd{bukhari}{991}{وَعَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يُسَلِّمُ بَيْنَ الرَّكْعَةِ وَالرَّكْعَتَيْنِ فِي الْوِتْرِ، حَتَّى يَأْمُرَ بِبَعْضِ حَاجَتِهِ‏.‏\hadithno{991}\hadithtrans{Nafi` told that `Abdullah bin `Umar used to say Taslim between (the first) two Rak`at and (the third) odd one in the Witr prayer, when he wanted to attend to a certain matter (during that interval between the Rak`at)}}
\hadithdefcmd{bukhari}{992}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، أَنَّ ابْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّهُ، بَاتَ عِنْدَ مَيْمُونَةَ، وَهْىَ خَالَتُهُ، فَاضْطَجَعْتُ فِي عَرْضِ وِسَادَةٍ، وَاضْطَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَهْلُهُ فِي طُولِهَا، فَنَامَ حَتَّى انْتَصَفَ اللَّيْلُ أَوْ قَرِيبًا مِنْهُ، فَاسْتَيْقَظَ يَمْسَحُ النَّوْمَ عَنْ وَجْهِهِ، ثُمَّ قَرَأَ عَشْرَ آيَاتٍ مِنْ آلِ عِمْرَانَ، ثُمَّ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى شَنٍّ مُعَلَّقَةٍ، فَتَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ، ثُمَّ قَامَ يُصَلِّي فَصَنَعْتُ مِثْلَهُ فَقُمْتُ إِلَى جَنْبِهِ، فَوَضَعَ يَدَهُ الْيُمْنَى عَلَى رَأْسِي، وَأَخَذَ بِأُذُنِي يَفْتِلُهَا، ثُمَّ صَلَّى رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ رَكْعَتَيْنِ، ثُمَّ أَوْتَرَ، ثُمَّ اضْطَجَعَ حَتَّى جَاءَهُ الْمُؤَذِّنُ فَقَامَ فَصَلَّى رَكْعَتَيْنِ ثُمَّ، خَرَجَ فَصَلَّى الصُّبْحَ‏.‏\hadithno{992}\hadithtrans{Narrated Ibn `Abbas:Once I passed the night in the house of Maimuna (his aunt). I slept across the bed while Allah's Apostle and his wife slept length-wise. The Prophet (ﷺ) slept till midnight or nearly so and woke up rubbing his face and recited ten verses from Surat "Al-`Imran." Allah's Messenger (ﷺ) went towards a leather skin and performed ablution in the most perfect way and then stood for the prayer. I did the same and stood beside him. The Prophet (ﷺ) put his right hand on my head, twisted my ear and then prayed two rak`at five times and then ended his prayer with witr. He laid down till the Mu'adh-dhin came then he stood up and offered two rak`at (Sunnah of Fajr prayer) and then went out and offered the Fajr prayer. (See Hadith)}}
\hadithdefcmd{bukhari}{993}{حَدَّثَنَا يَحْيَى بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرٌو، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ، حَدَّثَهُ عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ صَلاَةُ اللَّيْلِ مَثْنَى مَثْنَى، فَإِذَا أَرَدْتَ أَنْ تَنْصَرِفَ فَارْكَعْ رَكْعَةً تُوتِرُ لَكَ مَا صَلَّيْتَ ‏"‏‏.‏ قَالَ الْقَاسِمُ وَرَأَيْنَا أُنَاسًا مُنْذُ أَدْرَكْنَا يُوتِرُونَ بِثَلاَثٍ، وَإِنَّ كُلاًّ لَوَاسِعٌ أَرْجُو أَنْ لاَ يَكُونَ بِشَىْءٍ مِنْهُ بَأْسٌ‏.‏\hadithno{993}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "Night prayer is offered as two rak`at followed by two rak`at and so on, and if you want to finish it, pray only one rak`a which will be witr for all the previous rak`at." Al-Qasim said, "Since we attained the age of puberty we have seen some people offering a three-rak`at prayer as witr and all that is permissible. I hope there will be no harm in it}}
\hadithdefcmd{bukhari}{994}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي إِحْدَى عَشْرَةَ رَكْعَةً، كَانَتْ تِلْكَ صَلاَتَهُ ـ تَعْنِي بِاللَّيْلِ ـ فَيَسْجُدُ السَّجْدَةَ مِنْ ذَلِكَ قَدْرَ مَا يَقْرَأُ أَحَدُكُمْ خَمْسِينَ آيَةً قَبْلَ أَنْ يَرْفَعَ رَأْسَهُ، وَيَرْكَعُ رَكْعَتَيْنِ قَبْلَ صَلاَةِ الْفَجْرِ، ثُمَّ يَضْطَجِعُ عَلَى شِقِّهِ الأَيْمَنِ حَتَّى يَأْتِيَهُ الْمُؤَذِّنُ لِلصَّلاَةِ‏.‏\hadithno{994}\hadithtrans{Narrated `A'isha:Allah's Messenger (ﷺ) used to pray eleven rak`at at night and that was his night prayer and each of his prostrations lasted for a period enough for one of you to recite fifty verses before Allah's Messenger (ﷺ) raised his head. He also used to pray two rak`at (Sunnah) before the (compulsory) Fajr prayer and then lie down on his right side till the Mu'adh-dhin came to him for the prayer}}
\hadithdefcmd{bukhari}{995}{حَدَّثَنَا أَبُو النُّعْمَانِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، قَالَ حَدَّثَنَا أَنَسُ بْنُ سِيرِينَ، قَالَ قُلْتُ لاِبْنِ عُمَرَ أَرَأَيْتَ الرَّكْعَتَيْنِ قَبْلَ صَلاَةِ الْغَدَاةِ أُطِيلُ فِيهِمَا الْقِرَاءَةَ فَقَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ مَثْنَى مَثْنَى، وَيُوتِرُ بِرَكْعَةٍ وَيُصَلِّي الرَّكْعَتَيْنِ قَبْلَ صَلاَةِ الْغَدَاةِ وَكَأَنَّ الأَذَانَ بِأُذُنَيْهِ‏.‏ قَالَ حَمَّادٌ أَىْ سُرْعَةً‏.‏\hadithno{995}\hadithtrans{Narrated Anas bin Seereen:I asked Ibn `Umar, "What is your opinion about the two rak`at before the Fajr (compulsory) prayer, as to prolonging the recitation in them?" He said, "The Prophet (ﷺ) used to pray at night two rak`at followed by two and so on, and end the prayer by one rak`ah witr. He used to offer two rak`at before the Fajr prayer immediately after the Adhan." (Hammad, the sub-narrator said, "That meant (that he prayed) quickly}}
\hadithdefcmd{bukhari}{996}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي مُسْلِمٌ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كُلَّ اللَّيْلِ أَوْتَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَانْتَهَى وِتْرُهُ إِلَى السَّحَرِ‏.‏\hadithno{996}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) offered witr prayer at different nights at various hours extending (from the `Isha' prayer) up to the last hour of the night}}
\hadithdefcmd{bukhari}{997}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ حَدَّثَنِي أَبِي، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي، وَأَنَا رَاقِدَةٌ مُعْتَرِضَةً عَلَى فِرَاشِهِ، فَإِذَا أَرَادَ أَنْ يُوتِرَ أَيْقَظَنِي فَأَوْتَرْتُ‏.‏\hadithno{997}\hadithtrans{Narrated `A'isha:The Prophet (ﷺ) used to offer his night prayer while I was sleeping across in his bed. Whenever he intended to offer the witr prayer, he used to wake me up and I would offer the witr prayer too}}
\hadithdefcmd{bukhari}{998}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اجْعَلُوا آخِرَ صَلاَتِكُمْ بِاللَّيْلِ وِتْرًا ‏"‏‏.‏\hadithno{998}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) said, "Make witr as your last prayer at night}}
\hadithdefcmd{bukhari}{999}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي بَكْرِ بْنِ عُمَرَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ، عَنْ سَعِيدِ بْنِ يَسَارٍ، أَنَّهُ قَالَ كُنْتُ أَسِيرُ مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ بِطَرِيقِ مَكَّةَ فَقَالَ سَعِيدٌ فَلَمَّا خَشِيتُ الصُّبْحَ نَزَلْتُ فَأَوْتَرْتُ، ثُمَّ لَحِقْتُهُ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ أَيْنَ كُنْتَ فَقُلْتُ خَشِيتُ الصُّبْحَ، فَنَزَلْتُ فَأَوْتَرْتُ‏.‏ فَقَالَ عَبْدُ اللَّهِ أَلَيْسَ لَكَ فِي رَسُولِ اللَّهِ صلى الله عليه وسلم أُسْوَةٌ حَسَنَةٌ فَقُلْتُ بَلَى وَاللَّهِ‏.‏ قَالَ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُوتِرُ عَلَى الْبَعِيرِ‏.‏\hadithno{999}\hadithtrans{Narrated Sa`id bin Yasar:I was going to Mecca in the company of `Abdullah bin `Umar and when I apprehended the approaching dawn, I dismounted and offered the witr prayer and then joined him. `Abdullah bin `Umar said, "Where have you been?" I replied, "I apprehended the approaching dawn so I dismounted and prayed the witr prayer." `Abdullah said, "Isn't it sufficient for you to follow the good example of Allah's Messenger (ﷺ)?" I replied, "Yes, by Allah." He said, "Allah's Messenger (ﷺ) used to pray witr on the back of the camel (while on a journey)}}
\hadithdefcmd{bukhari}{1000}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا جُوَيْرِيَةُ بْنُ أَسْمَاءَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي فِي السَّفَرِ عَلَى رَاحِلَتِهِ، حَيْثُ تَوَجَّهَتْ بِهِ، يُومِئُ إِيمَاءً، صَلاَةَ اللَّيْلِ إِلاَّ الْفَرَائِضَ، وَيُوتِرُ عَلَى رَاحِلَتِهِ‏.‏\hadithno{1000}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) used to offer (Nawafil) prayers on his Rahila (mount) facing its direction by signals, but not the compulsory prayer. He also used to pray witr on his (mount) Rahila}}
\hadithdefcmd{bukhari}{1001}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، قَالَ سُئِلَ أَنَسٌ أَقَنَتَ النَّبِيُّ صلى الله عليه وسلم فِي الصُّبْحِ قَالَ نَعَمْ‏.‏ فَقِيلَ لَهُ أَوَقَنَتَ قَبْلَ الرُّكُوعِ قَالَ بَعْدَ الرُّكُوعِ يَسِيرًا‏.‏\hadithno{1001}\hadithtrans{Narrated Muhammad bin Seereen:Anas was asked, "Did the Prophet (ﷺ) recite Qunut in the Fajr prayer?" Anas replied in the affirmative. He was further asked, "Did he recite Qunut before bowing?" Anas replied, "He recited Qunut after bowing for some time (for one month)}}
\hadithdefcmd{bukhari}{1002}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ، قَالَ حَدَّثَنَا عَاصِمٌ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ عَنِ الْقُنُوتِ،‏.‏ فَقَالَ قَدْ كَانَ الْقُنُوتُ‏.‏ قُلْتُ قَبْلَ الرُّكُوعِ أَوْ بَعْدَهُ قَالَ قَبْلَهُ‏.‏ قَالَ فَإِنَّ فُلاَنًا أَخْبَرَنِي عَنْكَ أَنَّكَ قُلْتَ بَعْدَ الرُّكُوعِ‏.‏ فَقَالَ كَذَبَ، إِنَّمَا قَنَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْدَ الرُّكُوعِ شَهْرًا ـ أُرَاهُ ـ كَانَ بَعَثَ قَوْمًا يُقَالُ لَهُمُ الْقُرَّاءُ زُهَاءَ سَبْعِينَ رَجُلاً إِلَى قَوْمٍ مِنَ الْمُشْرِكِينَ دُونَ أُولَئِكَ، وَكَانَ بَيْنَهُمْ وَبَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَهْدٌ فَقَنَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَهْرًا يَدْعُو عَلَيْهِمْ‏.‏\hadithno{1002}\hadithtrans{Narrated `Asim:I asked Anas bin Malik about the Qunut. Anas replied, "Definitely it was (recited)". I asked, "Before bowing or after it?" Anas replied, "Before bowing." I added, "So and so has told me that you had informed him that it had been after bowing." Anas said, "He told an untruth (i.e. "was mistaken," according to the Hijazi dialect). Allah's Messenger (ﷺ) recited Qunut after bowing for a period of one month." Anas added, "The Prophet (ﷺ) sent about seventy men (who knew the Qur'an by heart) towards the pagans (of Najd) who were less than they in number and there was a peace treaty between them and Allah's Messenger (ﷺ) (but the Pagans broke the treaty and killed the seventy men). So Allah's Messenger (ﷺ) recited Qunut for a period of one month asking Allah to punish them}}
\hadithdefcmd{bukhari}{1003}{أَخْبَرَنَا أَحْمَدُ بْنُ يُونُسَ، قَالَ حَدَّثَنَا زَائِدَةُ، عَنِ التَّيْمِيِّ، عَنْ أَبِي مِجْلَزٍ، عَنْ أَنَسٍ، قَالَ قَنَتَ النَّبِيُّ صلى الله عليه وسلم شَهْرًا يَدْعُو عَلَى رِعْلٍ وَذَكْوَانَ‏.‏\hadithno{1003}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) recited Qunut for one month (in the Fajr prayer) asking Allah to punish the tribes of Ral and Dhakwan}}
\hadithdefcmd{bukhari}{1004}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، قَالَ كَانَ الْقُنُوتُ فِي الْمَغْرِبِ وَالْفَجْرِ‏.‏\hadithno{1004}\hadithtrans{Narrated Anas:The Qunut used to be recited in the Maghrib and the Fajr prayers}}
