% Auto-generated chapter 15 for ibnmajah
% Hadiths in this chapter: 46

\hadithdefcmd{ibnmajah}{2390}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَعُدْ فِي صَدَقَتِكَ ‏"‏ ‏.‏\hadithno{2390}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Umar bin Khattab that:the Messenger of Allah (ﷺ) said: “Do not take back your charity.”}}
\hadithdefcmd{ibnmajah}{2391}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي أَبُو جَعْفَرٍ، مُحَمَّدُ بْنُ عَلِيٍّ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ الْعَبَّاسِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلُ الَّذِي يَتَصَدَّقُ ثُمَّ يَرْجِعُ فِي صَدَقَتِهِ مَثَلُ الْكَلْبِ يَقِيءُ ثُمَّ يَرْجِعُ فَيَأْكُلُ قَيْئَهُ ‏"‏ ‏.‏\hadithno{2391}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin 'Abbas narrated that the Messenger of Allah (ﷺ) said:“The likeness of the one who gives charity then takes it back is that of a dog who vomits then goes back and eats its vomit.”}}
\hadithdefcmd{ibnmajah}{2392}{حَدَّثَنَا تَمِيمُ بْنُ الْمُنْتَصِرِ الْوَاسِطِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ، عَنْ شَرِيكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُمَرَ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ يَعْنِي، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عُمَرَ أَنَّهُ تَصَدَّقَ بِفَرَسٍ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَبْصَرَ صَاحِبَهَا يَبِيعُهَا بِكَسْرٍ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَسَأَلَهُ عَنْ ذَلِكَ فَقَالَ ‏ "‏ لاَ تَبْتَعْ صَدَقَتَكَ ‏"‏ ‏.‏\hadithno{2392}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Umar, meaning, from his father, his grandfather 'Umar, that :he gave a horse in charity at the time of the Messenger of Allah (ﷺ), then he saw its owner selling it for a low price. He went to the Prophet (ﷺ) and asked him about that, and he said: “Do not buy what you gave in charity.”}}
\hadithdefcmd{ibnmajah}{2393}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرٍ، عَنِ الزُّبَيْرِ بْنِ الْعَوَّامِ، أَنَّهُ حَمَلَ عَلَى فَرَسٍ يُقَالُ لَهُ غَمْرٌ أَوْ غَمْرَةٌ فَرَأَى مُهْرًا أَوْ مُهْرَةً مِنْ أَفْلاَئِهَا يُبَاعُ يُنْسَبُ إِلَى فَرَسِهِ فَنَهَى عَنْهَا ‏.‏\hadithno{2393}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Zubair bin 'Awwam that :he gave a horse called Ghamr or Ghamrah to someone, then he saw one of its colts or fillies attributed to his horse being sold, but he refrained from (buging) it}}
\hadithdefcmd{ibnmajah}{2394}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ عَطَاءٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي تَصَدَّقْتُ عَلَى أُمِّي بِجَارِيَةٍ وَإِنَّهَا مَاتَتْ ‏.‏ فَقَالَ ‏ "‏ آجَرَكِ اللَّهُ وَرَدَّ عَلَيْكِ الْمِيرَاثَ ‏"‏ ‏.‏\hadithno{2394}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah bin Buraidah that his father said:“A woman came to-the Prophet (ﷺ) and said: 'O Messenger of Allah (ﷺ), I gave my mother a slave girl of mine, and she has died.' The Messenger of Allah (ﷺ) said: 'Allah (SWT) has rewarded you, and returned to you your inheritance (without your seeking that.' ”)}}
\hadithdefcmd{ibnmajah}{2395}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الرَّقِّيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنِّي أَعْطَيْتُ أُمِّي حَدِيقَةً لِي وَإِنَّهَا مَاتَتْ وَلَمْ تَتْرُكْ وَارِثًا غَيْرِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَجَبَتْ صَدَقَتُكَ وَرَجَعَتْ إِلَيْكَ حَدِيقَتُكَ ‏"‏ ‏.‏\hadithno{2395}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said:“A man came to the Prophet (ﷺ) and said: 'I gave my mother a garden of mine, and she has died and has no other heir but me.' The Messenger of Allah(ﷺ) said: 'Your charity is valid and your garden has been returned to you.' ”}}
\hadithdefcmd{ibnmajah}{2396}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنِ ابْنِ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ أَصَابَ عُمَرُ بْنُ الْخَطَّابِ أَرْضًا بِخَيْبَرَ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَاسْتَأْمَرَهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَصَبْتُ مَالاً بِخَيْبَرَ لَمْ أُصِبْ مَالاً قَطُّ هُوَ أَنْفَسُ عِنْدِي مِنْهُ فَمَا تَأْمُرُنِي بِهِ فَقَالَ ‏ "‏ إِنْ شِئْتَ حَبَسْتَ أَصْلَهَا وَتَصَدَّقْتَ بِهَا ‏"‏ ‏.‏ قَالَ فَعَمِلَ بِهَا عُمَرُ عَلَى أَنْ لاَ يُبَاعَ أَصْلُهَا وَلاَ يُوهَبَ وَلاَ يُورَثَ تَصَدَّقَ بِهَا لِلْفُقَرَاءِ وَفِي الْقُرْبَى وَفِي الرِّقَابِ وَفِي سَبِيلِ اللَّهِ وَابْنِ السَّبِيلِ وَالضَّيْفِ لاَ جُنَاحَ عَلَى مَنْ وَلِيَهَا أَنْ يَأْكُلَ مِنْهَا بِالْمَعْرُوفِ أَوْ يُطْعِمَ صَدِيقًا غَيْرَ مُتَمَوِّلٍ ‏.‏\hadithno{2396}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:“Umar bin Khattab acquired some land at Khaibar, and he came to the Prophet (ﷺ) and consulted him. He said: 'O Messenger of Allah(ﷺ), I have been given some wealth at Khaibar and I have never been given any wealth that is more precious to me than it. What do you command me to do with it? He said: 'If you wish, you can make it an endowment and give (its produce) in charity.' So 'Umar gave it on the basis that it would not be sold, given away or inherited, and (its produce) was to be given to the poor, to relatives, for freeing slaves, in the cause of Allah, to way fares and to guests; and there was nothing wrong if a person appointed to be in charge of it consumed from it on a reasonable basis or feeding a fried, without accumulating it for himself.”}}
\hadithdefcmd{ibnmajah}{2397}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ يَا رَسُولَ اللَّهِ إِنَّ الْمِائَةَ سَهْمٍ الَّتِي بِخَيْبَرَ لَمْ أُصِبْ مَالاً قَطُّ هُوَ أَحَبُّ إِلَىَّ مِنْهَا وَقَدْ أَرَدْتُ أَنْ أَتَصَدَّقَ بِهَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ احْبِسْ أَصْلَهَا وَسَبِّلْ ثَمَرَتَهَا ‏"‏ ‏.‏ قَالَ ابْنُ أَبِي عُمَرَ فَوَجَدْتُ هَذَا الْحَدِيثَ فِي مَوْضِعٍ آخَرَ فِي كِتَابِي عَنْ سُفْيَانَ عَنْ عَبْدِ اللَّهِ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ قَالَ قَالَ عُمَرُ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{2397}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:“Umar bin Khattab said: 'O Messenger of Allah (ﷺ), the one hundred shares of the Khaibar I have never been given any wealth that is more beloved to me than them, and I wanted to give them in charity.' The Prophet (ﷺ) said: 'Make it an endowment and give its produce in the cause of Allah (SWT).”}}
\hadithdefcmd{ibnmajah}{2398}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا شُرَحْبِيلُ بْنُ مُسْلِمٍ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْعَارِيَةُ مُؤَدَّاةٌ وَالْمِنْحَةُ مَرْدُودَةٌ ‏"‏ ‏.‏\hadithno{2398}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Shurahbil Muslim said:I heard Abu Umamah say: “I heard the Messenger of Allah (ﷺ) say: 'Borrowed items are to be returned and an animal borrowed for milking is to be returned.”}}
\hadithdefcmd{ibnmajah}{2399}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَعَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيَّانِ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْعَارِيَةُ مُؤَدَّاةٌ وَالْمِنْحَةُ مَرْدُودَةٌ ‏"‏ ‏.‏\hadithno{2399}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:“I heard the Messenger of Allah (ﷺ) say: 'Borrowed items are to be returned and an animal borrowed for milking is to be returned.' ”}}
\hadithdefcmd{ibnmajah}{2400}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُسْتَمِرِّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ، ح وَحَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، جَمِيعًا عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عَلَى الْيَدِ مَا أَخَذَتْ حَتَّى تُؤَدِّيَهُ ‏"‏ ‏.‏\hadithno{2400}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Samurah that the Messenger of Allah (ﷺ) said:“The hand that takes is responsible for what it has taken until it returns it.”}}
\hadithdefcmd{ibnmajah}{2401}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ الْجَهْمِ الأَنْمَاطِيُّ، حَدَّثَنَا أَيُّوبُ بْنُ سُوَيْدٍ، عَنِ الْمُثَنَّى، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أُودِعَ وَدِيعَةً فَلاَ ضَمَانَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{2401}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said:“The Messenger of Allah (ﷺ) said: 'Whoever is entrusted with an item for safekeeping, is not responsible for it (so long as he is not negligent).' ”}}
\hadithdefcmd{ibnmajah}{2402}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ شَبِيبِ بْنِ غَرْقَدَةَ، عَنْ عُرْوَةَ الْبَارِقِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَعْطَاهُ دِينَارًا يَشْتَرِي لَهُ شَاةً فَاشْتَرَى لَهُ شَاتَيْنِ فَبَاعَ إِحْدَاهُمَا بِدِينَارٍ فَأَتَى النَّبِيَّ صلى الله عليه وسلم بِدِينَارٍ وَشَاةٍ فَدَعَا لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْبَرَكَةِ ‏.‏ قَالَ فَكَانَ لَوِ اشْتَرَى التُّرَابَ لَرَبِحَ فِيهِ ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا سَعِيدُ بْنُ زَيْدٍ، عَنِ الزُّبَيْرِ بْنِ الْخِرِّيتِ، عَنْ أَبِي لَبِيدٍ، لِمَازَةَ بْنِ زَبَّارٍ عَنْ عُرْوَةَ بْنِ أَبِي الْجَعْدِ الْبَارِقِيِّ، قَالَ قَدِمَ جَلَبٌ فَأَعْطَانِي النَّبِيُّ صلى الله عليه وسلم دِينَارًا فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{2402}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Urwah Al-Bariqi that :the Prophet (ﷺ) gave him a Dinar to buy him a sheep, and he bought two sheep for him, then he sold one of them for a Dinar, and bought a Dinar and a sheep to the Prophet (ﷺ). The Messenger of Allah (ﷺ) prayed for blessing for him}}
\hadithdefcmd{ibnmajah}{2403}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الظُّلْمُ مَطْلُ الْغَنِيِّ وَإِذَا أُتْبِعَ أَحَدُكُمْ عَلَى مَلِيءٍ فَلْيَتْبَعْ ‏"‏ ‏.‏\hadithno{2403}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“(Wrongdoing) is when a rich man takes a long time to repay a debt, and if one of you is referred to a rich man (to collect a debt), he should accept that referral.”}}
\hadithdefcmd{ibnmajah}{2404}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ تَوْبَةَ، حَدَّثَنَا هُشَيْمٌ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَطْلُ الْغَنِيِّ ظُلْمٌ وَإِذَا أُحِلْتَ عَلَى مَلِيءٍ فَاتْبَعْهُ ‏"‏ ‏.‏\hadithno{2404}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:“When a rich man takes too long to repay a debt, this is wrongdoing, and if the debt is transferred to a rich man, you should accept if.”}}
\hadithdefcmd{ibnmajah}{2405}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَالْحَسَنُ بْنُ عَرَفَةَ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنِي شُرَحْبِيلُ بْنُ مُسْلِمٍ الْخَوْلاَنِيُّ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ الْبَاهِلِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الزَّعِيمُ غَارِمٌ وَالدَّيْنُ مَقْضِيٌّ ‏"‏ ‏.‏\hadithno{2405}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Shurahbil bin Muslim Al-Khawlani said:I heard Abu Umamah Al-Bahil say: “I heard the Messenger of Allah(ﷺ) say: “The guarantor is responsible and the debt must be repaid.' ”}}
\hadithdefcmd{ibnmajah}{2406}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، لَزِمَ غَرِيمًا لَهُ بِعَشَرَةِ دَنَانِيرَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ مَا عِنْدِي شَىْءٌ أُعْطِيكَهُ فَقَالَ لاَ وَاللَّهِ لاَ أُفَارِقُكَ حَتَّى تَقْضِيَنِي أَوْ تَأْتِيَنِي بِحَمِيلٍ فَجَرَّهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ كَمْ تَسْتَنْظِرُهُ ‏"‏ ‏.‏ فَقَالَ شَهْرًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَأَنَا أَحْمِلُ لَهُ ‏"‏ ‏.‏ فَجَاءَهُ فِي الْوَقْتِ الَّذِي قَالَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مِنْ أَيْنَ أَصَبْتَ هَذَا ‏"‏ ‏.‏ قَالَ مِنْ مَعْدِنٍ قَالَ ‏"‏ لاَ خَيْرَ فِيهَا ‏"‏ ‏.‏ وَقَضَاهَا عَنْهُ ‏.‏\hadithno{2406}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Abbas:That during the time of the Messenger of Allah (ﷺ), a man pursued a debtor who owed him ten Dinar, and he said: “I do not have anything to give you.” He (the creditor) said: “No, by Allah, I will not leave you until you pay the debt or you bring me a guarantor.” Then he dragged him to the Prophet (ﷺ) and the Prophet (ﷺ) said to him: “How long will you wait?” He said: “One month.” The Messenger of Allah (ﷺ) said: “I will be a guarantor for him.” Then he came to him at the time the Prophet (ﷺ) had said, and the Prophet (ﷺ) said to him: “Where did you get this from?” He said: “From a mine.” He said: “There is nothing good in it,” and he paid the debt for him}}
\hadithdefcmd{ibnmajah}{2407}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِجِنَازَةٍ لِيُصَلِّيَ عَلَيْهَا فَقَالَ ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ فَإِنَّ عَلَيْهِ دَيْنًا ‏"‏ ‏.‏ فَقَالَ أَبُو قَتَادَةَ أَنَا أَتَكَفَّلُ بِهِ ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بِالْوَفَاءِ ‏"‏ ‏.‏ قَالَ بِالْوَفَاءِ ‏.‏ وَكَانَ الَّذِي عَلَيْهِ ثَمَانِيَةَ عَشَرَ أَوْ تِسْعَةَ عَشَرَ دِرْهَمًا ‏.‏\hadithno{2407}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Uthman bin 'Abdullah bin Mawhab said:“I heard 'Abdullah bin Abu Qatadah narrate from his father that a corpse was brought to the Prophet (ﷺ) for him to offer the funeral prayer, and he said: 'Pray for your companion, for he owes a debt.' Abu Qatadah said: 'I will stand surely for him?' The Prophet (ﷺ) said: 'In full?' He said: 'In full.” And the debt he owed was eighteen or nineteen Dirham.”}}
\hadithdefcmd{ibnmajah}{2408}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنْ مَنْصُورٍ، عَنْ زِيَادِ بْنِ عَمْرِو بْنِ هِنْدٍ، عَنِ ابْنِ حُذَيْفَةَ، - هُوَ عِمْرَانُ - عَنْ أُمِّ الْمُؤْمِنِينَ، مَيْمُونَةَ قَالَ كَانَتْ تَدَّانُ دَيْنًا فَقَالَ لَهَا بَعْضُ أَهْلِهَا لاَ تَفْعَلِي وَأَنْكَرَ ذَلِكَ عَلَيْهَا قَالَتْ بَلَى إِنِّي سَمِعْتُ نَبِيِّي وَخَلِيلِي صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ مُسْلِمٍ يَدَّانُ دَيْنًا يَعْلَمُ اللَّهُ مِنْهُ أَنَّهُ يُرِيدُ أَدَاءَهُ إِلاَّ أَدَّاهُ اللَّهُ عَنْهُ فِي الدُّنْيَا ‏"‏ ‏.‏\hadithno{2408}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that :the Mother of the Believers Maimunah used to take out loans frequently, and some of her family said: “Do not that,” and they denounced her for that. She said: “No. I heard my Prophet (ﷺ) and my close friend say: ‘There is no Muslim who takes out a loan and Allah(SWT) knows that he intends to pay it back, but Allah(SWT) will pay it back for him in this world.'”}}
\hadithdefcmd{ibnmajah}{2409}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنَا سَعِيدُ بْنُ سُفْيَانَ، - مَوْلَى الأَسْلَمِيِّينَ - عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ مَعَ الدَّائِنِ حَتَّى يَقْضِيَ دَيْنَهُ مَا لَمْ يَكُنْ فِيمَا يَكْرَهُ اللَّهُ ‏"‏ ‏.‏ قَالَ فَكَانَ عَبْدُ اللَّهِ بْنُ جَعْفَرٍ يَقُولُ لِخَازِنِهِ اذْهَبْ فَخُذْ لِي بِدَيْنٍ فَإِنِّي أَكْرَهُ أَنْ أَبِيتَ لَيْلَةً إِلاَّ وَاللَّهُ مَعِي بَعْدَ الَّذِي سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2409}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin Ja'far that the Messenger of Allah (ﷺ) said:“Allah will be the borrower until he pays off his debt, so long as it (the loan) is not for something that Allah dislikes.”}}
\hadithdefcmd{ibnmajah}{2410}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يُوسُفُ بْنُ مُحَمَّدِ بْنِ صَيْفِيِّ بْنِ صُهَيْبِ الْخَيْرِ، حَدَّثَنِي عَبْدُ الْحَمِيدِ بْنُ زِيَادِ بْنِ صَيْفِيِّ بْنِ صُهَيْبٍ، عَنْ شُعَيْبِ بْنِ عَمْرٍو، حَدَّثَنَا صُهَيْبُ الْخَيْرِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا رَجُلٍ يَدَيَّنُ دَيْنًا وَهُوَ مُجْمِعٌ أَنْ لاَ يُوَفِّيَهُ إِيَّاهُ لَقِيَ اللَّهَ سَارِقًا ‏"‏ ‏.‏ حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا يُوسُفُ بْنُ مُحَمَّدِ بْنِ صَيْفِيٍّ، عَنْ عَبْدِ الْحَمِيدِ بْنِ زِيَادٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، صُهَيْبٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2410}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Suhaib Al-Khair narrated that the Messenger of Allah (ﷺ) said:“ Any Man who takes out a loan, having resolved not to pay it back, will meet Allah (SWT) as a thief.”}}
\hadithdefcmd{ibnmajah}{2411}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ الدِّيلِيِّ، عَنْ أَبِي الْغَيْثِ، - مَوْلَى ابْنِ مُطِيعٍ - عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَخَذَ أَمْوَالَ النَّاسِ يُرِيدُ إِتْلاَفَهَا أَتْلَفَهُ اللَّهُ ‏"‏ ‏.‏\hadithno{2411}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Whoever takes people's wealth with the intention of destroying it, Allah (SWT) will destroy him.”}}
\hadithdefcmd{ibnmajah}{2412}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ، عَنْ ثَوْبَانَ، - مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم - عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ فَارَقَ الرُّوحُ الْجَسَدَ وَهُوَ بَرِيءٌ مِنْ ثَلاَثٍ دَخَلَ الْجَنَّةَ مِنَ الْكِبْرِ وَالْغُلُولِ وَالدَّيْنِ ‏"‏ ‏.‏\hadithno{2412}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Thawban, the freed slave of the Messenger of Allah (ﷺ), that the Messenger of Allah (ﷺ) said:“Anyone whose soul leaves his body and he is free of three things, will enter Paradise: Arrogance, stealing from the spoils of war, and debt.”}}
\hadithdefcmd{ibnmajah}{2413}{حَدَّثَنَا أَبُو مَرْوَانَ الْعُثْمَانِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَفْسُ الْمُؤْمِنِ مُعَلَّقَةٌ بِدَيْنِهِ حَتَّى يُقْضَى عَنْهُ ‏"‏ ‏.‏\hadithno{2413}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) that the Messenger of Allah (ﷺ) said:“The soul of the believer is attached to his debt until it is paid off.”}}
\hadithdefcmd{ibnmajah}{2414}{حَدَّثَنَا مُحَمَّدُ بْنُ ثَعْلَبَةَ بْنِ سَوَاءٍ، حَدَّثَنَا عَمِّي، مُحَمَّدُ بْنُ سَوَاءٍ عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ مَطَرٍ الْوَرَّاقِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ مَاتَ وَعَلَيْهِ دِينَارٌ أَوْ دِرْهَمٌ قُضِيَ مِنْ حَسَنَاتِهِ لَيْسَ ثَمَّ دِينَارٌ وَلاَ دِرْهَمٌ ‏"‏ ‏.‏\hadithno{2414}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:“Whoever dies owing a Dinar or a Dirham, it will be paid back from his good deeds, because then there will be no Dinar or Dirham.”}}
\hadithdefcmd{ibnmajah}{2415}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ إِذَا تُوُفِّيَ الْمُؤْمِنُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ الدَّيْنُ فَيَسْأَلُ ‏"‏ هَلْ تَرَكَ لِدَيْنِهِ مِنْ قَضَاءٍ ‏"‏ ‏.‏ فَإِنْ قَالُوا نَعَمْ ‏.‏ صَلَّى عَلَيْهِ وَإِنْ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ ‏"‏ ‏.‏ فَلَمَّا فَتَحَ اللَّهُ عَلَى رَسُولِهِ الْفُتُوحَ قَالَ ‏"‏ أَنَا أَوْلَى بِالْمُؤْمِنِينَ مِنْ أَنْفُسِهِمْ فَمَنْ تُوُفِّيَ وَعَلَيْهِ دَيْنٌ فَعَلَىَّ قَضَاؤُهُ وَمَنْ تَرَكَ مَالاً فَهُوَ لِوَرَثَتِهِ ‏"‏ ‏.‏\hadithno{2415}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that:if a believer died at the time of the Messenger of Allah (ﷺ) and he had debts, the Messenger of Allah (ﷺ) would ask: “Did he leave anything with which to off his debt?” If they said yes, then he would offer the funeral prayer for him, but if they said no, then he would say: “Pray for your companion.” When Allah granted his Prophet (ﷺ) the conquests, he said: “I am nearer to the believers than their own selves. Whoever dies owing a debt, I will pay it off for him, and whoever leaves behind wealth, it will be for his heirs.”}}
\hadithdefcmd{ibnmajah}{2416}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَرَكَ مَالاً فَلِوَرَثَتِهِ وَمَنْ تَرَكَ دَيْنًا أَوْ ضَيَاعًا فَعَلَىَّ وَإِلَىَّ وَأَنَا أَوْلَى بِالْمُؤْمِنِينَ ‏"‏ ‏.‏\hadithno{2416}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“Whoever leaves behind money, it is for his heirs, and whoever leaves behind a debt for children, I am nearer to the believers.”}}
\hadithdefcmd{ibnmajah}{2417}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يَسَّرَ عَلَى مُعْسِرٍ يَسَّرَ اللَّهُ عَلَيْهِ فِي الدُّنْيَا وَالآخِرَةِ ‏"‏ ‏.‏\hadithno{2417}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:Whoever is easy with (a debtor) who is in difficulty, Allah will be easy with him in this world and in the Hereafter.”}}
\hadithdefcmd{ibnmajah}{2418}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ نُفَيْعٍ أَبِي دَاوُدَ، عَنْ بُرَيْدَةَ الأَسْلَمِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَنْظَرَ مُعْسِرًا كَانَ لَهُ بِكُلِّ يَوْمٍ صَدَقَةٌ وَمَنْ أَنْظَرَهُ بَعْدَ حِلِّهِ كَانَ لَهُ مِثْلُهُ فِي كُلِّ يَوْمٍ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2418}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Buraidah Al-Aslami that the Prophet (ﷺ) said:“Whoever gives respite to one in difficulty, he will have (the reward of) an act of charity for each day. Whoever gives him respite after payment becomes due, will have (the reward of) an act of charity equal to (the amount of the loan) for each day.”}}
\hadithdefcmd{ibnmajah}{2419}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مُعَاوِيَةَ، عَنْ حَنْظَلَةَ بْنِ قَيْسٍ، عَنْ أَبِي الْيَسَرِ، صَاحِبِ النَّبِيِّ صلى الله عليه وسلم قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَحَبَّ أَنْ يُظِلَّهُ اللَّهُ فِي ظِلِّهِ - فَلْيُنْظِرْ مُعْسِرًا أَوْ لِيَضَعْ لَهُ ‏"‏ ‏.‏\hadithno{2419}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Yasar, the Companion of the Prophet (ﷺ) that :the Messenger of Allah (ﷺ) said: “Whoever would like Allah to shade him with His shade, let him give respite to one in difficulty, or waive repayment of the loan.”}}
\hadithdefcmd{ibnmajah}{2420}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، قَالَ سَمِعْتُ رِبْعِيَّ بْنَ حِرَاشٍ، يُحَدِّثُ عَنْ حُذَيْفَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ أَنَّ رَجُلاً مَاتَ فَقِيلَ لَهُ مَا عَمِلْتَ - فَإِمَّا ذَكَرَ أَوْ ذُكِّرَ - قَالَ إِنِّي كُنْتُ أَتَجَوَّزُ فِي السِّكَّةِ وَالنَّقْدِ وَأُنْظِرُ الْمُعْسِرَ ‏.‏ فَغَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏ قَالَ أَبُو مُسْعُودٍ أَنَا قَدْ، سَمِعْتُ هَذَا، مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2420}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Hudhaifah that the Prophet (ﷺ) said:“A man died and it was said to him: 'What did you do?' Either he remembered or was reminded and said: 'I used to be easy going in coins and cash collecting debts due, and I used to give respite to (the debtor) who was in difficulty. So, Allah (SWT) forgave him.' ” Abu Masud said: “I heard that from the Messenger of Allah (ﷺ).”}}
\hadithdefcmd{ibnmajah}{2421}{حَدَّثَنَا مُحَمَّدُ بْنُ خَلَفٍ الْعَسْقَلاَنِيُّ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، وَعَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ طَلَبَ حَقًّا فَلْيَطْلُبْهُ فِي عَفَافٍ وَافٍ أَوْ غَيْرِ وَافٍ ‏"‏ ‏.‏\hadithno{2421}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Umar and 'Aishah that the Messenger of Allah (ﷺ) said:“Whoever demands his rights let him do so in a decent manner as much as he can.”}}
\hadithdefcmd{ibnmajah}{2422}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُؤَمَّلِ بْنِ الصَّبَّاحِ الْقَيْسِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ مُحَبَّبٍ الْقُرَشِيُّ، حَدَّثَنَا سَعِيدُ بْنُ السَّائِبِ الطَّائِفِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ يَامِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِصَاحِبِ الْحَقِّ ‏ "‏ خُذْ حَقَّكَ فِي عَفَافٍ وَافٍ أَوْ غَيْرِ وَافٍ ‏"‏ ‏.‏\hadithno{2422}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said to the one who was entitled to something:“Take your rights in a decent manner as much as he can.”}}
\hadithdefcmd{ibnmajah}{2423}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، سَمِعْتُ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ خَيْرَكُمْ - أَوْ مِنْ خَيْرِكُمْ - أَحَاسِنُكُمْ قَضَاءً ‏"‏ ‏.‏\hadithno{2423}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The best of you - or among the best of you - are those who pay off their debts in the best manner.”}}
\hadithdefcmd{ibnmajah}{2424}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي رَبِيعَةَ الْمَخْزُومِيُّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اسْتَسْلَفَ مِنْهُ حِينَ غَزَا حُنَيْنًا ثَلاَثِينَ أَوْ أَرْبَعِينَ أَلْفًا فَلَمَّا قَدِمَ قَضَاهَا إِيَّاهُ ثُمَّ قَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ بَارَكَ اللَّهُ لَكَ فِي أَهْلِكَ وَمَالِكَ إِنَّمَا جَزَاءُ السَّلَفِ الْوَفَاءُ وَالْحَمْدُ ‏"‏ ‏.‏\hadithno{2424}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Isma'il bin Abi Rabi'ah Al-Makhzumi narrated from his father, from his grandfather, that :the Prophet (ﷺ) borrowed thirty or forty thousand from him, when he fought at Hunain. When he came back he paid the loan, then the Prophet (ﷺ) said to him: 'May Allah (SWT) bless your family and your wealth for you. The reward for lending is repayment and words of paradise.”}}
\hadithdefcmd{ibnmajah}{2425}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، عَنْ حَنَشٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ رَجُلٌ يَطْلُبُ نَبِيَّ اللَّهِ صلى الله عليه وسلم بِدَيْنٍ أَوْ بِحَقٍّ فَتَكَلَّمَ بِبَعْضِ الْكَلاَمِ فَهَمَّ صَحَابَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم بِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَهْ إِنَّ صَاحِبَ الدَّيْنِ لَهُ سُلْطَانٌ عَلَى صَاحِبِهِ حَتَّى يَقْضِيَهُ ‏"‏ ‏.‏\hadithno{2425}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:“A man came to ask the Prophet of Allah (ﷺ) for some debt or some right, and he spoke harshly to him, and the Companions of the Messenger of Allah (ﷺ) wanted to rebuke him. But the Messenger of Allah (ﷺ) said: 'Let him be, for the one who is owed something has authority over the debtor, until it is paid off.' ”}}
\hadithdefcmd{ibnmajah}{2426}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عُثْمَانَ أَبُو شَيْبَةَ، حَدَّثَنَا ابْنُ أَبِي عُبَيْدَةَ، - أَظُنُّهُ قَالَ - حَدَّثَنَا أَبِي، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم يَتَقَاضَاهُ دَيْنًا كَانَ عَلَيْهِ فَاشْتَدَّ عَلَيْهِ حَتَّى قَالَ لَهُ أُحَرِّجُ عَلَيْكَ إِلاَّ قَضَيْتَنِي ‏.‏ فَانْتَهَرَهُ أَصْحَابُهُ وَقَالُوا وَيْحَكَ تَدْرِي مَنْ تُكَلِّمُ قَالَ إِنِّي أَطْلُبُ حَقِّي ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلاَّ مَعَ صَاحِبِ الْحَقِّ كُنْتُمْ ‏"‏ ‏.‏ ثُمَّ أَرْسَلَ إِلَى خَوْلَةَ بِنْتِ قَيْسٍ فَقَالَ لَهَا ‏"‏ إِنْ كَانَ عِنْدَكِ تَمْرٌ فَأَقْرِضِينَا حَتَّى يَأْتِيَنَا تَمْرٌ فَنَقْضِيَكِ ‏"‏ ‏.‏ فَقَالَتْ نَعَمْ بِأَبِي أَنْتَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ فَأَقْرَضَتْهُ فَقَضَى الأَعْرَابِيَّ وَأَطْعَمَهُ فَقَالَ أَوْفَيْتَ أَوْفَى اللَّهُ لَكَ ‏.‏ فَقَالَ ‏"‏ أُولَئِكَ خِيَارُ النَّاسِ إِنَّهُ لاَ قُدِّسَتْ أُمَّةٌ لاَ يَأْخُذُ الضَّعِيفُ فِيهَا حَقَّهُ غَيْرَ مُتَعْتَعٍ ‏"‏ ‏.‏\hadithno{2426}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:“A Bedouin came to the Prophet (ﷺ) to ask him to pay back a debt that he owed him, and he spoke harshly, saying: 'I will make things difficult for you unless you repay me.' His Companions rebuked him and said: 'Woe to you, do you know who you are speaking to?' He said: 'I am only asking for my rights.' The Prophet (ﷺ) said: 'Why do you not support the one who has a right?' Then he sent word to Khawlah bint Qais, saying to her: 'If you have dates, lend them to us until our dates come, then we will pay you back.' She said: 'Yes, may my father be ransomed for you, O Messenger of Allah (ﷺ)!' So she gave him a loan, and he paid back the Bedouin and fed him. He (the Bedouin) said: 'You have paid me in full, may Allah (SWT) pay you in full.' He (the Prophet (ﷺ) ) said: 'Those are the best of people. May that nation not be cleansed (of sin) among whom the weak cannot get their rights without trouble.' ”}}
\hadithdefcmd{ibnmajah}{2427}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا وَبْرُ بْنُ أَبِي دُلَيْلَةَ الطَّائِفِيُّ، حَدَّثَنِي مُحَمَّدُ بْنُ مَيْمُونِ بْنِ مُسَيْكَةَ، - قَالَ وَكِيعٌ وَأَثْنَى عَلَيْهِ خَيْرًا - عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَىُّ الْوَاجِدِ يُحِلُّ عِرْضَهُ وَعُقُوبَتَهُ ‏"‏ ‏.‏ قَالَ عَلِيٌّ الطَّنَافِسِيُّ يَعْنِي عِرْضَهُ شِكَايَتَهُ وَعُقُوبَتَهُ سِجْنَهُ ‏.‏\hadithno{2427}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Sharid that his father said that the Messenger of Allah (ﷺ) said:“If one who can afford it delays repayment, his honor and punishment become permissible.”}}
\hadithdefcmd{ibnmajah}{2428}{حَدَّثَنَا هَدِيَّةُ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، حَدَّثَنَا الْهِرْمَاسُ بْنُ حَبِيبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم بِغَرِيمٍ لِي فَقَالَ لِي ‏"‏ الْزَمْهُ ‏"‏ ‏.‏ ثُمَّ مَرَّ بِي آخِرَ النَّهَارِ فَقَالَ ‏"‏ مَا فَعَلَ أَسِيرُكَ يَا أَخَا بَنِي تَمِيمٍ ‏"‏ ‏.‏\hadithno{2428}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Hirmas bin Habib narrated from his father that his grandfather said:“I came to the Prophet (ﷺ) with a man who owed me money, and he said to me: 'Keep him.' Then he passed by me at the end of the day and said: 'What did your prisoner do, O brother of Banu Tamim?' ”}}
\hadithdefcmd{ibnmajah}{2429}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَيَحْيَى بْنُ حَكِيمٍ، قَالاَ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَنْبَأَنَا يُونُسُ بْنُ يَزِيدَ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّهُ تَقَاضَى ابْنَ أَبِي حَدْرَدٍ دَيْنًا لَهُ عَلَيْهِ فِي الْمَسْجِدِ حَتَّى ارْتَفَعَتْ أَصْوَاتُهُمَا حَتَّى سَمِعَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ فِي بَيْتِهِ فَخَرَجَ إِلَيْهِمَا فَنَادَى كَعْبًا فَقَالَ لَبَّيْكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ دَعْ مِنْ دَيْنِكَ هَذَا ‏"‏ ‏.‏ وَأَوْمَأَ بِيَدِهِ إِلَى الشَّطْرِ فَقَالَ قَدْ فَعَلْتُ ‏.‏ قَالَ ‏"‏ قُمْ فَاقْضِهِ ‏"‏ ‏.‏\hadithno{2429}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah bin Ka'b bin Malik from his father that :he demanded payment owed by Ibn Abi Hadrad in the mosque. Their voices became so loud that the Messenger of Allah (ﷺ) heard them when he was in his house. He came out and called Ka'b who said: “Here I am, O Messenger of Allah (ﷺ)!” He said: “Waive this much of your loan,” and gestured with his hand to indicate half. He said: “I will do that,” and he said: “Get up and repay it.”}}
\hadithdefcmd{ibnmajah}{2430}{حَدَّثَنَا مُحَمَّدُ بْنُ خَلَفٍ الْعَسْقَلاَنِيُّ، حَدَّثَنَا يَعْلَى، حَدَّثَنَا سُلَيْمَانُ بْنُ يُسَيْرٍ، عَنْ قَيْسِ بْنِ رُومِيٍّ، قَالَ كَانَ سُلَيْمَانُ بْنُ أُذُنَانٍ يُقْرِضُ عَلْقَمَةَ أَلْفَ دِرْهَمٍ إِلَى عَطَائِهِ فَلَمَّا خَرَجَ عَطَاؤُهُ تَقَاضَاهَا مِنْهُ وَاشْتَدَّ عَلَيْهِ فَقَضَاهُ فَكَأَنَّ عَلْقَمَةَ غَضِبَ فَمَكَثَ أَشْهُرًا ثُمَّ أَتَاهُ فَقَالَ أَقْرِضْنِي أَلْفَ دِرْهَمٍ إِلَى عَطَائِي قَالَ نَعَمْ وَكَرَامَةً يَا أُمَّ عُتْبَةَ هَلُمِّي تِلْكَ الْخَرِيطَةَ الْمَخْتُومَةَ الَّتِي عِنْدَكِ ‏.‏ فَجَاءَتْ بِهَا فَقَالَ أَمَا وَاللَّهِ إِنَّهَا لَدَرَاهِمُكَ الَّتِي قَضَيْتَنِي مَا حَرَّكْتُ مِنْهَا دِرْهَمًا وَاحِدًا ‏.‏ قَالَ فَلِلَّهِ أَبُوكَ مَا حَمَلَكَ عَلَى مَا فَعَلْتَ بِي ‏.‏ قَالَ مَا سَمِعْتُ مِنْكَ ‏.‏ قَالَ مَا سَمِعْتَ مِنِّي قَالَ سَمِعْتُكَ تَذْكُرُ عَنِ ابْنِ مَسْعُودٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ مُسْلِمٍ يُقْرِضُ مُسْلِمًا قَرْضًا مَرَّتَيْنِ إِلاَّ كَانَ كَصَدَقَتِهَا مَرَّةً ‏"‏ ‏.‏ قَالَ كَذَلِكَ أَنْبَأَنِي ابْنُ مَسْعُودٍ ‏.‏\hadithno{2430}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Qais bin Rumi said:“Sulaiman bin Udhunan lent 'Alqamah one thousand Dirham until he got his salary, When he got his salary, he demanded that he pay him back and treated him harshly. He paid him back, and it was as if 'Alqamah was angry. Several months passed then he came to him and said: 'Lend me one thousand Dirham until my salary comes.' He said 'Yes, it would be an honor. O Umm 'Utbah! Bring me that sealed leather bag that you have.' He said: 'By Allah(SWT), these are your Dirham that you paid back to me; I did not touch a single Dirham., ' What made you do what you did to me (i.e., treat me so harshly)?' He said: 'What I heard from you.' He said: 'What did you hear from me?' He said: 'I heard you narrated from Ibn Mas'ud that the Prophet (ﷺ) said: “There is no Muslim who lends something to another Muslim twice, but it will be like giving charity once.”He said: 'That is what Ibn Mas'ud told me.' ”}}
\hadithdefcmd{ibnmajah}{2431}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْكَرِيمِ، حَدَّثَنَا هِشَامُ بْنُ خَالِدٍ، حَدَّثَنَا خَالِدُ بْنُ يَزِيدَ بْنِ أَبِي مَالِكٍ، وَحَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا هِشَامُ بْنُ خَالِدٍ، حَدَّثَنَا خَالِدُ بْنُ يَزِيدَ بْنِ أَبِي مَالِكٍ، عَنْ أَبِيهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَأَيْتُ لَيْلَةَ أُسْرِيَ بِي عَلَى بَابِ الْجَنَّةِ مَكْتُوبًا الصَّدَقَةُ بِعَشْرِ أَمْثَالِهَا وَالْقَرْضُ بِثَمَانِيَةَ عَشَرَ ‏.‏ فَقُلْتُ يَا جِبْرِيلُ مَا بَالُ الْقَرْضِ أَفْضَلُ مِنَ الصَّدَقَةِ ‏.‏ قَالَ لأَنَّ السَّائِلَ يَسْأَلُ وَعِنْدَهُ وَالْمُسْتَقْرِضُ لاَ يَسْتَقْرِضُ إِلاَّ مِنْ حَاجَةٍ ‏"‏ ‏.‏\hadithno{2431}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“On the night on which I was taken on the Night Journey (Isra), I saw written at the gate of Paradise: 'Charity brings a tenfold reward and a loan brings an eighteen fold reward.' I said: 'O Jibril! Why is a loan better than charity?' He said: 'Because the beggar asks when he has something, but the one who asks for loan does so only because he is in need.' ”}}
\hadithdefcmd{ibnmajah}{2432}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنِي عُتْبَةُ بْنُ حُمَيْدٍ الضَّبِّيُّ، عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ الْهُنَائِيِّ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ الرَّجُلُ مِنَّا يُقْرِضُ أَخَاهُ الْمَالَ فَيُهْدِي لَهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَقْرَضَ أَحَدُكُمْ قَرْضًا فَأَهْدَى لَهُ أَوْ حَمَلَهُ عَلَى الدَّابَّةِ فَلاَ يَرْكَبْهَا وَلاَ يَقْبَلْهُ إِلاَّ أَنْ يَكُونَ جَرَى بَيْنَهُ وَبَيْنَهُ قَبْلَ ذَلِكَ ‏"‏ ‏.‏\hadithno{2432}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Yahya bin Abu Ishaq Al-Huna'i said:“I asked Anas bin Malik: 'What if a man gives his brother a loan, then (the borrower) give him a gift?’ The Messenger of Allah (ﷺ) said: ‘If anyone of you borrow something then he gives (the lender) a gift or gives him a ride on his riding-beast, he should not accept the gift or the ride, unless they used to treat each other in that manner beforehand.'”}}
\hadithdefcmd{ibnmajah}{2433}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَخْبَرَنِي عَبْدُ الْمَلِكِ أَبُو جَعْفَرٍ، عَنْ أَبِي نَضْرَةَ، عَنْ سَعْدِ بْنِ الأَطْوَلِ، أَنَّ أَخَاهُ، مَاتَ وَتَرَكَ ثَلاَثَمِائَةِ دِرْهَمٍ وَتَرَكَ عِيَالاً فَأَرَدْتُ أَنْ أُنْفِقَهَا عَلَى عِيَالِهِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ أَخَاكَ مُحْتَبَسٌ بِدَيْنِهِ فَاقْضِ عَنْهُ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ قَدْ أَدَّيْتُ عَنْهُ إِلاَّ دِينَارَيْنِ ادَّعَتْهُمَا امْرَأَةٌ وَلَيْسَ لَهَا بَيِّنَةٌ ‏.‏ قَالَ ‏"‏ فَأَعْطِهَا فَإِنَّهَا مُحِقَّةٌ ‏"‏ ‏.‏\hadithno{2433}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sa'd bin Atwal that :his brother died, leaving behind three hundred Dirham and dependents. “I wanted to spend (his money) on his dependents, but the Prophet (ﷺ) said: 'Your brother is being detained by his debt, so pay it off for him.'” He said “O Messenger of Allah (ﷺ), I have paid it off apart from two Dinar, which a woman is claiming but she has no proof.” He said: “Give them to her for she is telling the truth.”}}
\hadithdefcmd{ibnmajah}{2434}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا شُعَيْبُ بْنُ إِسْحَاقَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ أَبَاهُ، تُوُفِّيَ وَتَرَكَ عَلَيْهِ ثَلاَثِينَ وَسْقًا لِرَجُلٍ مِنَ الْيَهُودِ فَاسْتَنْظَرَهُ جَابِرُ بْنُ عَبْدِ اللَّهِ فَأَبَى أَنْ يُنْظِرَهُ فَكَلَّمَ جَابِرٌ رَسُولَ اللَّهِ صلى الله عليه وسلم لِيَشْفَعَ لَهُ إِلَيْهِ فَجَاءَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَكَلَّمَ الْيَهُودِيَّ لِيَأْخُذَ ثَمَرَ نَخْلِهِ بِالَّذِي لَهُ عَلَيْهِ فَأَبَى عَلَيْهِ فَكَلَّمَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَبَى أَنْ يُنْظِرَهُ فَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّخْلَ فَمَشَى فِيهَا ثُمَّ قَالَ لِجَابِرٍ ‏"‏ جُدَّ لَهُ فَأَوْفِهِ الَّذِي لَهُ ‏"‏ ‏.‏ فَجَدَّ لَهُ بَعْدَ مَا رَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثَلاَثِينَ وَسْقًا وَفَضَلَ لَهُ اثْنَا عَشَرَ وَسْقًا فَجَاءَ جَابِرٌ رَسُولَ اللَّهِ صلى الله عليه وسلم لِيُخْبِرَهُ بِالَّذِي كَانَ فَوَجَدَ رَسُولَ اللَّهِ صلى الله عليه وسلم غَائِبًا فَلَمَّا انْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم جَاءَهُ فَأَخْبَرَهُ أَنَّهُ قَدْ أَوْفَاهُ وَأَخْبَرَهُ بِالْفَضْلِ الَّذِي فَضَلَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَخْبِرْ بِذَلِكَ عُمَرَ بْنَ الْخَطَّابِ ‏"‏ ‏.‏ فَذَهَبَ جَابِرٌ إِلَى عُمَرَ فَأَخْبَرَهُ فَقَالَ لَهُ عُمَرُ لَقَدْ عَلِمْتُ حِينَ مَشَى فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُبَارِكَنَّ اللَّهُ فِيهَا ‏.‏\hadithno{2434}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Jabir bin 'Abdullah that :his father died owing thirty Wasq to a Jewish man. Jabir bin Abdullah asked him for respite but he refused. Jabir asked the Messenger of Allah (ﷺ) to intercede for him with him, so the Messenger of Allah (ﷺ) went and spoke to the Jew, asking him to accept dates in lieu of what was owed, but he refused. The Messenger of Allah (ﷺ) spoke to him but he refused to give respite. Then the Messenger of Allah (ﷺ) went in among the date-palm trees and walked among them. Then he said to Jabir: “Pick (dates) for him and pay off what is owed to him in full.” So he picked thirty Wasq of dates after the Messenger of Allah (ﷺ) came back, and there were twelve Wasq more (than what was owed). Jabir came to the Messenger of Allah (ﷺ) to tell him what had happened, and he found that the Messenger of Allah (ﷺ) was absent. When the Messenger of Allah (ﷺ) came back he came to him and told him that he had paid off the debt in full, and he told him about the extra dates. The Messenger of Allah (ﷺ) said: “Tell 'Umar bin Khattab about that.” So Jabir went to 'Umar said to him: “I knew when the Messenger of Allah (ﷺ) walked amongst them that Allah (SWT) would bless them for us.”}}
\hadithdefcmd{ibnmajah}{2528}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ شِرْكًا لَهُ فِي عَبْدٍ أُقِيمَ عَلَيْهِ بِقِيمَةِ عَدْلٍ فَأَعْطَى شُرَكَاءَهُ حِصَصَهُمْ إِنْ كَانَ لَهُ مِنَ الْمَالِ مَا يَبْلُغُ ثَمَنَهُ وَعَتَقَ عَلَيْهِ الْعَبْدُ وَإِلاَّ فَقَدْ عَتَقَ مِنْهُ مَا عَتَقَ ‏"‏ ‏.‏\hadithno{2528}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn`Umar that the Messenger of Allah (ﷺ) said:“Whoever frees his share of a slave, the price of the slave should be fairly evaluated, and he (the partner who initiated this process) should free him (in full, by giving the rest of his price to the other co-owners), if he has enough wealth to do so. Otherwise, he will have freed whatever he freed.”}}
