% Auto-generated chapter index for nasai
% Source: ara-nasai.json
% Total hadiths: 5765
% Chapters: 52

\hadithcollectionname{nasai}{Sunan an Nasai}

\hadithsectionname{nasai}{1}{The Book of Purification}
\hadithsectionname{nasai}{2}{The Book of Water}
\hadithsectionname{nasai}{3}{The Book of Menstruation and Istihadah}
\hadithsectionname{nasai}{4}{The Book of Ghusl and Tayammum}
\hadithsectionname{nasai}{5}{The Book of Salah}
\hadithsectionname{nasai}{6}{The Book of the Times (of Prayer)}
\hadithsectionname{nasai}{7}{The Book of the Adhan (The Call to Prayer)}
\hadithsectionname{nasai}{8}{The Book of the Masjids}
\hadithsectionname{nasai}{9}{The Book of the Qiblah}
\hadithsectionname{nasai}{10}{The Book of Leading the Prayer (Al-Imamah)}
\hadithsectionname{nasai}{11}{The Book of the Commencement of the Prayer}
\hadithsectionname{nasai}{12}{The Book of The At-Tatbiq (Clasping One's Hands Together)}
\hadithsectionname{nasai}{13}{The Book of Forgetfulness (In Prayer)}
\hadithsectionname{nasai}{14}{The Book of Jumu'ah (Friday Prayer)}
\hadithsectionname{nasai}{15}{The Book of Shortening the Prayer When Traveling}
\hadithsectionname{nasai}{16}{The Book of Eclipses}
\hadithsectionname{nasai}{17}{The Book of Praying for Rain (Al-Istisqa')}
\hadithsectionname{nasai}{18}{The Book of the Fear Prayer}
\hadithsectionname{nasai}{19}{The Book of the Prayer for the Two 'Eids}
\hadithsectionname{nasai}{20}{The Book of Qiyam Al-Lail (The Night Prayer) and Voluntary Prayers During the Day}
\hadithsectionname{nasai}{21}{The Book of Funerals}
\hadithsectionname{nasai}{22}{The Book of Fasting}
\hadithsectionname{nasai}{23}{The Book of Zakah}
\hadithsectionname{nasai}{24}{The Book of Hajj}
\hadithsectionname{nasai}{25}{The Book of Jihad}
\hadithsectionname{nasai}{26}{The Book of Marriage}
\hadithsectionname{nasai}{27}{The Book of Divorce}
\hadithsectionname{nasai}{28}{The Book of Horses, Races and Shooting}
\hadithsectionname{nasai}{29}{The Book of Endowments}
\hadithsectionname{nasai}{30}{The Book of Wills}
\hadithsectionname{nasai}{31}{The Book of Presents}
\hadithsectionname{nasai}{32}{The Book of Gifts}
\hadithsectionname{nasai}{33}{The Book of ar-Ruqba}
\hadithsectionname{nasai}{34}{The Book of 'Umra}
\hadithsectionname{nasai}{35}{The Book of Agriculture}
\hadithsectionname{nasai}{36}{The Book of the Kind Treatment of Women}
\hadithsectionname{nasai}{37}{The Book of Fighting [The Prohibition of Bloodshed]}
\hadithsectionname{nasai}{38}{The Book of Distribution of Al-Fay'}
\hadithsectionname{nasai}{39}{The Book of al-Bay'ah}
\hadithsectionname{nasai}{40}{The Book of al-'Aqiqah}
\hadithsectionname{nasai}{41}{The Book of al-Fara' and al-'Atirah}
\hadithsectionname{nasai}{42}{The Book of Hunting and Slaughtering}
\hadithsectionname{nasai}{43}{The Book of ad-Dahaya (Sacrifices)}
\hadithsectionname{nasai}{44}{The Book of Financial Transactions}
\hadithsectionname{nasai}{45}{The Book of Oaths (qasamah), Retaliation and Blood Money}
\hadithsectionname{nasai}{46}{The Book of Cutting off the Hand of the Thief}
\hadithsectionname{nasai}{47}{The Book Of Faith and its Signs}
\hadithsectionname{nasai}{48}{The Book of Adornment}
\hadithsectionname{nasai}{49}{The Book of the Etiquette of Judges}
\hadithsectionname{nasai}{50}{The Book of Seeking Refuge with Allah}
\hadithsectionname{nasai}{51}{The Book of Drinks}

\hadithsectionrange{nasai}{1}{1}{324}
\hadithsectionrange{nasai}{2}{325}{347}
\hadithsectionrange{nasai}{3}{348}{395}
\hadithsectionrange{nasai}{4}{396}{447}
\hadithsectionrange{nasai}{5}{448}{493}
\hadithsectionrange{nasai}{6}{494}{625}
\hadithsectionrange{nasai}{7}{626}{687}
\hadithsectionrange{nasai}{8}{688}{741}
\hadithsectionrange{nasai}{9}{742}{776}
\hadithsectionrange{nasai}{10}{777}{875}
\hadithsectionrange{nasai}{11}{876}{1028}
\hadithsectionrange{nasai}{12}{1029}{1178}
\hadithsectionrange{nasai}{13}{1179}{1366}
\hadithsectionrange{nasai}{14}{1367}{1432}
\hadithsectionrange{nasai}{15}{1433}{1458}
\hadithsectionrange{nasai}{16}{1459}{1503}
\hadithsectionrange{nasai}{17}{1504}{1528}
\hadithsectionrange{nasai}{18}{1529}{1555}
\hadithsectionrange{nasai}{19}{1556}{1597}
\hadithsectionrange{nasai}{20}{1598}{1817}
\hadithsectionrange{nasai}{21}{1818}{2089}
\hadithsectionrange{nasai}{22}{2090}{2434}
\hadithsectionrange{nasai}{23}{2435}{2618}
\hadithsectionrange{nasai}{24}{2619}{3084}
\hadithsectionrange{nasai}{25}{3085}{3195}
\hadithsectionrange{nasai}{26}{3196}{3388}
\hadithsectionrange{nasai}{27}{3389}{3560}
\hadithsectionrange{nasai}{28}{3561}{3593}
\hadithsectionrange{nasai}{29}{3594}{3610}
\hadithsectionrange{nasai}{30}{3611}{3671}
\hadithsectionrange{nasai}{31}{3672}{3687}
\hadithsectionrange{nasai}{32}{3688}{3705}
\hadithsectionrange{nasai}{33}{3706}{3719}
\hadithsectionrange{nasai}{34}{3720}{3760}
\hadithsectionrange{nasai}{35}{3761}{3856}
\hadithsectionrange{nasai}{36}{3939}{3965}
\hadithsectionrange{nasai}{37}{3966}{4132}
\hadithsectionrange{nasai}{38}{4133}{4148}
\hadithsectionrange{nasai}{39}{4149}{4211}
\hadithsectionrange{nasai}{40}{4212}{4221}
\hadithsectionrange{nasai}{41}{4222}{4262}
\hadithsectionrange{nasai}{42}{4263}{4360}
\hadithsectionrange{nasai}{43}{4361}{4448}
\hadithsectionrange{nasai}{44}{4449}{4705}
\hadithsectionrange{nasai}{45}{4706}{4869}
\hadithsectionrange{nasai}{46}{4870}{4984}
\hadithsectionrange{nasai}{47}{4985}{5039}
\hadithsectionrange{nasai}{48}{5040}{5378}
\hadithsectionrange{nasai}{49}{5379}{5427}
\hadithsectionrange{nasai}{50}{5428}{5539}
\hadithsectionrange{nasai}{51}{5540}{5758}

% Chapter index — which .def file to load for each chapter

\hadithchapterfile{nasai}{0}{hadithtext-nasai-ch00.def}{3857}{3938}
\hadithchapterfile{nasai}{1}{hadithtext-nasai-ch01.def}{1}{324}
\hadithchapterfile{nasai}{2}{hadithtext-nasai-ch02.def}{325}{347}
\hadithchapterfile{nasai}{3}{hadithtext-nasai-ch03.def}{348}{395}
\hadithchapterfile{nasai}{4}{hadithtext-nasai-ch04.def}{396}{447}
\hadithchapterfile{nasai}{5}{hadithtext-nasai-ch05.def}{448}{493}
\hadithchapterfile{nasai}{6}{hadithtext-nasai-ch06.def}{494}{625}
\hadithchapterfile{nasai}{7}{hadithtext-nasai-ch07.def}{626}{687}
\hadithchapterfile{nasai}{8}{hadithtext-nasai-ch08.def}{688}{741}
\hadithchapterfile{nasai}{9}{hadithtext-nasai-ch09.def}{742}{776}
\hadithchapterfile{nasai}{10}{hadithtext-nasai-ch10.def}{777}{875}
\hadithchapterfile{nasai}{11}{hadithtext-nasai-ch11.def}{876}{1028}
\hadithchapterfile{nasai}{12}{hadithtext-nasai-ch12.def}{1029}{1178}
\hadithchapterfile{nasai}{13}{hadithtext-nasai-ch13.def}{1179}{1366}
\hadithchapterfile{nasai}{14}{hadithtext-nasai-ch14.def}{1367}{1432}
\hadithchapterfile{nasai}{15}{hadithtext-nasai-ch15.def}{1433}{1458}
\hadithchapterfile{nasai}{16}{hadithtext-nasai-ch16.def}{1459}{1503}
\hadithchapterfile{nasai}{17}{hadithtext-nasai-ch17.def}{1504}{1528}
\hadithchapterfile{nasai}{18}{hadithtext-nasai-ch18.def}{1529}{1555}
\hadithchapterfile{nasai}{19}{hadithtext-nasai-ch19.def}{1556}{1597}
\hadithchapterfile{nasai}{20}{hadithtext-nasai-ch20.def}{1598}{1817}
\hadithchapterfile{nasai}{21}{hadithtext-nasai-ch21.def}{1818}{2089}
\hadithchapterfile{nasai}{22}{hadithtext-nasai-ch22.def}{2090}{2434}
\hadithchapterfile{nasai}{23}{hadithtext-nasai-ch23.def}{2435}{2618}
\hadithchapterfile{nasai}{24}{hadithtext-nasai-ch24.def}{2619}{3084}
\hadithchapterfile{nasai}{25}{hadithtext-nasai-ch25.def}{3085}{3195}
\hadithchapterfile{nasai}{26}{hadithtext-nasai-ch26.def}{3196}{3388}
\hadithchapterfile{nasai}{27}{hadithtext-nasai-ch27.def}{3389}{3560}
\hadithchapterfile{nasai}{28}{hadithtext-nasai-ch28.def}{3561}{3593}
\hadithchapterfile{nasai}{29}{hadithtext-nasai-ch29.def}{3594}{3610}
\hadithchapterfile{nasai}{30}{hadithtext-nasai-ch30.def}{3611}{3671}
\hadithchapterfile{nasai}{31}{hadithtext-nasai-ch31.def}{3672}{3687}
\hadithchapterfile{nasai}{32}{hadithtext-nasai-ch32.def}{3688}{3705}
\hadithchapterfile{nasai}{33}{hadithtext-nasai-ch33.def}{3706}{3719}
\hadithchapterfile{nasai}{34}{hadithtext-nasai-ch34.def}{3720}{3760}
\hadithchapterfile{nasai}{35}{hadithtext-nasai-ch35.def}{3761}{3856}
\hadithchapterfile{nasai}{36}{hadithtext-nasai-ch36.def}{3939}{3965}
\hadithchapterfile{nasai}{37}{hadithtext-nasai-ch37.def}{3966}{4132}
\hadithchapterfile{nasai}{38}{hadithtext-nasai-ch38.def}{4133}{4148}
\hadithchapterfile{nasai}{39}{hadithtext-nasai-ch39.def}{4149}{4211}
\hadithchapterfile{nasai}{40}{hadithtext-nasai-ch40.def}{4212}{4221}
\hadithchapterfile{nasai}{41}{hadithtext-nasai-ch41.def}{4222}{4262}
\hadithchapterfile{nasai}{42}{hadithtext-nasai-ch42.def}{4263}{4360}
\hadithchapterfile{nasai}{43}{hadithtext-nasai-ch43.def}{4361}{4448}
\hadithchapterfile{nasai}{44}{hadithtext-nasai-ch44.def}{4449}{4705}
\hadithchapterfile{nasai}{45}{hadithtext-nasai-ch45.def}{4706}{4869}
\hadithchapterfile{nasai}{46}{hadithtext-nasai-ch46.def}{4870}{4984}
\hadithchapterfile{nasai}{47}{hadithtext-nasai-ch47.def}{4985}{5039}
\hadithchapterfile{nasai}{48}{hadithtext-nasai-ch48.def}{5040}{5378}
\hadithchapterfile{nasai}{49}{hadithtext-nasai-ch49.def}{5379}{5427}
\hadithchapterfile{nasai}{50}{hadithtext-nasai-ch50.def}{5428}{5539}
\hadithchapterfile{nasai}{51}{hadithtext-nasai-ch51.def}{5540}{5758}
