% Auto-generated chapter 23 for ibnmajah
% Hadiths in this chapter: 34

\hadithdefcmd{ibnmajah}{2719}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا حَفْصُ بْنُ عُمَرَ بْنِ أَبِي الْعَطَّافِ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا أَبَا هُرَيْرَةَ تَعَلَّمُوا الْفَرَائِضَ وَعَلِّمُوهَا فَإِنَّهُ نِصْفُ الْعِلْمِ وَهُوَ يُنْسَى وَهُوَ أَوَّلُ شَىْءٍ يُنْتَزَعُ مِنْ أُمَّتِي ‏"‏ ‏.‏\hadithno{2719}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“O Abu Hurairah. Learn about the inheritance and teach it, for it is half of knowledge, but it will be forgotten. This is the first thing that will be taken away from my nation.’”}}
\hadithdefcmd{ibnmajah}{2720}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ جَاءَتِ امْرَأَةُ سَعْدِ بْنِ الرَّبِيعِ بِابْنَتَىْ سَعْدٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ هَاتَانِ ابْنَتَا سَعْدٍ قُتِلَ مَعَكَ يَوْمَ أُحُدٍ وَإِنَّ عَمَّهُمَا أَخَذَ جَمِيعَ مَا تَرَكَ أَبُوهُمَا وَإِنَّ الْمَرْأَةَ لاَ تُنْكَحُ إِلاَّ عَلَى مَالِهَا ‏.‏ فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أُنْزِلَتْ آيَةُ الْمِيرَاثِ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَخَا سَعْدِ بْنِ الرَّبِيعِ فَقَالَ ‏ "‏ أَعْطِ ابْنَتَىْ سَعْدٍ ثُلُثَىْ مَالِهِ وَأَعْطِ امْرَأَتَهُ الثُّمُنَ وَخُذْ أَنْتَ مَا بَقِيَ ‏"‏ ‏.‏\hadithno{2720}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir bin ‘Abdullah said:“The wife of Sa’d bin Rabi’ came with the two daughters of Sa’d to the Prophet (ﷺ) and said: ‘O Messenger of Allah, these are the two daughters of Sa’d. He was killed with you on the day of Uhud, and their paternal uncle has taken all that their father left behind, and a woman is only married for her wealth.’ The Prophet (ﷺ) remained silent until the Verse of inheritance was revealed to him. Then the Messenger of Allah (ﷺ) called the brother of Sa’d bin Rabi’ and said: ‘Give the two daughters of Sa’d two thirds of his wealth, and give his wife on eighth, and take what is left.’”}}
\hadithdefcmd{ibnmajah}{2721}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي قَيْسٍ الأَوْدِيِّ، عَنِ الْهُزَيْلِ بْنِ شُرَحْبِيلَ، قَالَ جَاءَ رَجُلٌ إِلَى أَبِي مُوسَى الأَشْعَرِيِّ وَسَلْمَانَ بْنِ رَبِيعَةَ الْبَاهِلِيِّ فَسَأَلَهُمَا عَنِ ابْنَةٍ وَابْنَةِ ابْنٍ وَأُخْتٍ، لأَبٍ وَأُمٍّ فَقَالاَ لِلاِبْنَةِ النِّصْفُ وَمَا بَقِيَ فَلِلأُخْتِ وَائْتِ ابْنَ مَسْعُودٍ فَسَيُتَابِعُنَا ‏.‏ فَأَتَى الرَّجُلُ ابْنَ مَسْعُودٍ فَسَأَلَهُ وَأَخْبَرَهُ بِمَا قَالاَ فَقَالَ عَبْدُ اللَّهِ قَدْ ضَلَلْتُ إِذًا وَمَا أَنَا مِنَ الْمُهْتَدِينَ وَلَكِنِّي سَأَقْضِي بِمَا قَضَى بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلاِبْنَةِ النِّصْفُ وَلاِبْنَةِ الاِبْنِ السُّدُسُ تَكْمِلَةَ الثُّلُثَيْنِ وَمَا بَقِيَ فَلِلأُخْتِ ‏.‏\hadithno{2721}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Huzail bin Shurahbil said:“A man came to Abu Musa Al-Ash’ari and Salman bin Rabi’ah Al-Bahili and asked them about (the shares of) a daughter, a son’s daughter, a sister through one’s father and mother. They said: ‘The daughter gets one half, and what is left goes to the sister. Go to Ibn Mas’ud, for he will concur with what we say.’ So the man went to Ibn Mas’ud, and told him what they had said. ‘Abdullah said: ‘I will go astray and will not be guided (if I say that I agree); but I will judge as the Messenger of Allah (ﷺ) judged. The daughter gets one half, and the son’s daughter gets one- sixth. That makes two thirds. And what is left goes to the sister.’”}}
\hadithdefcmd{ibnmajah}{2722}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ مَعْقِلِ بْنِ يَسَارٍ الْمُزَنِيِّ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِفَرِيضَةٍ فِيهَا جَدٌّ فَأَعْطَاهُ ثُلُثًا أَوْ سُدُسًا ‏.‏\hadithno{2722}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ma’qil bin Yasar Al-Muzani said:“I heard the Prophet (ﷺ) when a case was brought to him which involved the share of a grandfather. He gave him one third, or one sixth.”}}
\hadithdefcmd{ibnmajah}{2723}{قَالَ أَبُو الْحَسَنِ الْقَطَّانُ حَدَّثَنَا أَبُو حَاتِمٍ، حَدَّثَنَا ابْنُ الطَّبَّاعِ، حَدَّثَنَا هُشَيْمٌ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ مَعْقِلِ بْنِ يَسَارٍ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي جَدٍّ كَانَ فِينَا بِالسُّدُسِ ‏.‏\hadithno{2723}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ma’qil bin Yasar said:“The Messenger of Allah (ﷺ) ruled concerning a grandfather who was among us, that he should receive one sixth.”}}
\hadithdefcmd{ibnmajah}{2724}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَهُ عَنْ قَبِيصَةَ بْنِ ذُؤَيْبٍ، ح وَحَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُثْمَانَ بْنِ إِسْحَاقَ بْنِ خَرَشَةَ، عَنِ ابْنِ ذُؤَيْبٍ، قَالَ جَاءَتِ الْجَدَّةُ إِلَى أَبِي بَكْرٍ الصِّدِّيقِ تَسْأَلُهُ مِيرَاثَهَا فَقَالَ لَهَا أَبُو بَكْرٍ مَا لَكِ فِي كِتَابِ اللَّهِ شَىْءٌ وَمَا عَلِمْتُ لَكِ فِي سُنَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم شَيْئًا فَارْجِعِي حَتَّى أَسْأَلَ النَّاسَ ‏.‏ فَسَأَلَ النَّاسَ فَقَالَ الْمُغِيرَةُ بْنُ شُعْبَةَ حَضَرْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَعْطَاهَا السُّدُسَ فَقَالَ أَبُو بَكْرٍ هَلْ مَعَكَ غَيْرُكَ فَقَامَ مُحَمَّدُ بْنُ مَسْلَمَةَ الأَنْصَارِيُّ فَقَالَ مِثْلَ مَا قَالَ الْمُغِيرَةُ بْنُ شُعْبَةَ فَأَنْفَذَهُ لَهَا أَبُو بَكْرٍ ‏.‏ ثُمَّ جَاءَتِ الْجَدَّةُ الأُخْرَى مِنْ قِبَلِ الأَبِ إِلَى عُمَرَ تَسْأَلُهُ مِيرَاثَهَا فَقَالَ مَا لَكِ فِي كِتَابِ اللَّهِ شَىْءٌ وَمَا كَانَ الْقَضَاءُ الَّذِي قُضِيَ بِهِ إِلاَّ لِغَيْرِكِ وَمَا أَنَا بِزَائِدٍ فِي الْفَرَائِضِ شَيْئًا وَلَكِنْ هُوَ ذَاكِ السُّدُسُ فَإِنِ اجْتَمَعْتُمَا فِيهِ فَهُوَ بَيْنَكُمَا وَأَيَّتُكُمَا خَلَتْ بِهِ فَهُوَ لَهَا ‏.‏\hadithno{2724}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn Dhu’aib said:“A grandmother came to Abu Bakr Siddiq and asked him for her inheritance. Abu Bakr said to her: ‘You have nothing according to the Book of Allah, and I don’t know of anything for you according to the Book of Allah, and I don’t know of anything for you according to the Sunnah of the Messenger of Allah (ﷺ). Go back until I ask the people.’ So he asked the people and Al-Mughirah bin Shu’bah said: ‘I was present with the Messenger of Allah (ﷺ) and he gave her (the grandmother) one sixth.’ Abu Bakr said: ‘Is there anyone else with you (who will corroborate what you say)?’ Muhammad bin Maslamah Al-Ansari stood up and said something like what Mughirah bin Shu’bah had said. So Abu Bakr applied it in her case.”}}
\hadithdefcmd{ibnmajah}{2725}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا سَلْمُ بْنُ قُتَيْبَةَ، عَنْ شَرِيكٍ، عَنْ لَيْثٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَرَّثَ جَدَّةً سُدُسًا ‏.‏\hadithno{2725}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) gave a grandmother one sixth of the inheritance}}
\hadithdefcmd{ibnmajah}{2726}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ الْيَعْمُرِيِّ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَامَ خَطِيبًا يَوْمَ الْجُمُعَةِ أَوْ خَطَبَهُمْ يَوْمَ الْجُمُعَةِ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَقَالَ إِنِّي وَاللَّهِ مَا أَدَعُ بَعْدِي شَيْئًا هُوَ أَهَمُّ إِلَىَّ مِنْ أَمْرِ الْكَلاَلَةِ وَقَدْ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَمَا أَغْلَظَ لِي فِي شَىْءٍ مَا أَغْلَظَ لِي فِيهَا حَتَّى طَعَنَ بِإِصْبَعِهِ فِي جَنْبِي أَوْ فِي صَدْرِي ثُمَّ قَالَ ‏ "‏ يَا عُمَرُ تَكْفِيكَ آيَةُ الصَّيْفِ الَّتِي نَزَلَتْ فِي آخِرِ سُورَةِ النِّسَاءِ ‏"‏ ‏.‏\hadithno{2726}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ma’dan bin Abu Talhah Al-Ya’muri that ‘Umar bin Khattab stood up to deliver a sermon one Friday, or he addressed them one Friday. He praised and glorified Allah, and said:“By Allah, I am not leaving behind any problem more difficult than the one who leaves behind an heir. I asked the Messenger of Allah (ﷺ), and he never spoke so harshly to me about anything as he spoke to me about this. He jabbed his finger into my side or my chest and said: ‘O ‘Umar, sufficient for you is the Verse that was revealed in summer, at the end of Surat An-Nisa’.”}}
\hadithdefcmd{ibnmajah}{2727}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرُو بْنُ مُرَّةَ، عَنْ مُرَّةَ بْنِ شَرَاحِيلَ، قَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ ثَلاَثٌ لأَنْ يَكُونَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيَّنَهُنَّ أَحَبُّ إِلَىَّ مِنَ الدُّنْيَا وَمَا فِيهَا الْكَلاَلَةُ وَالرِّبَا وَالْخِلاَفَةُ ‏.‏\hadithno{2727}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Umar bin Khattab said:“There are three things, if the Messenger of Allah (ﷺ) had clarified them, that would have been dearer to me than the world and everything in it: a person who leaves behind no heir, usury, and the caliphate.”}}
\hadithdefcmd{ibnmajah}{2728}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ مَرِضْتُ فَأَتَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُنِي هُوَ وَأَبُو بَكْرٍ مَعَهُ وَهُمَا مَاشِيَانِ وَقَدْ أُغْمِيَ عَلَىَّ فَتَوَضَّأَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَبَّ عَلَىَّ مِنْ وَضُوئِهِ فَقُلْتُ يَا رَسُولَ اللَّهِ كَيْفَ أَصْنَعُ كَيْفَ أَقْضِي فِي مَالِي حَتَّى نَزَلَتْ آيَةُ الْمِيرَاثِ فِي آخِرِ النِّسَاءِ ‏\{وَإِنْ كَانَ رَجُلٌ يُورَثُ كَلاَلَةً‏\}‏ الآيَةَ وَ ‏\{يَسْتَفْتُونَكَ قُلِ اللَّهُ يُفْتِيكُمْ فِي الْكَلاَلَةِ\}‏ الآيَةَ ‏.‏\hadithno{2728}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Muhammad bin Munkadir that he heard Jabir bin ‘Abdullah say:“I fell sick and the Messenger of Allah (ﷺ) came to visit me, he and Abu Bakr with him, and they came walking. I had lost consciousness, so the Messenger of Allah (ﷺ) performed ablution and poured some of the water of his ablution over me. I said: ‘O Messenger of Allah, what should I do? How should I decide about my wealth?’ Until the Verse of inheritance was revealed at the end of An-Nisa’: “If the man or woman whose inheritance is in question has left neither ascendants or descendents.” [4:12] And: “They ask you for a legal verdict. Say: ‘Allah directs (thus) about those who leave neither descendants nor ascendants as heirs.’” [4:]}}
\hadithdefcmd{ibnmajah}{2729}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ الْحُسَيْنِ، عَنْ عَمْرِو بْنِ عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، رَفَعَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَرِثُ الْمُسْلِمُ الْكَافِرَ وَلاَ الْكَافِرُ الْمُسْلِمَ ‏"‏ ‏.‏\hadithno{2729}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Usamah bin Zaid, who attributed it to the Prophet (ﷺ):“The Muslim does not inherit from a disbeliever and the disbeliever does not inherit from a Muslim.”}}
\hadithdefcmd{ibnmajah}{2730}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عَلِيِّ بْنِ الْحُسَيْنِ، أَنَّهُ حَدَّثَهُ أَنَّ عَمْرَو بْنَ عُثْمَانَ أَخْبَرَهُ عَنْ أُسَامَةَ بْنِ زَيْدٍ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ أَتَنْزِلُ فِي دَارِكَ بِمَكَّةَ قَالَ ‏"‏ وَهَلْ تَرَكَ لَنَا عَقِيلٌ مِنْ رِبَاعٍ أَوْ دُورٍ ‏"‏ ‏.‏ وَكَانَ عَقِيلٌ وَرِثَ أَبَا طَالِبٍ هُوَ وَطَالِبٌ وَلَمْ يَرِثْ جَعْفَرٌ وَلاَ عَلِيٌّ شَيْئًا لأَنَّهُمَا كَانَا مُسْلِمَيْنِ وَكَانَ عَقِيلٌ وَطَالِبٌ كَافِرَيْنِ ‏.‏ فَكَانَ عُمَرُ مِنْ أَجْلِ ذَلِكَ يَقُولُ لاَ يَرِثُ الْمُؤْمِنُ الْكَافِرَ ‏.‏ وَقَالَ أُسَامَةُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَرِثُ الْمُسْلِمُ الْكَافِرَ وَلاَ الْكَافِرُ الْمُسْلِمَ ‏"‏ ‏.‏\hadithno{2730}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Usamah bin Zaid that he said:“O Messenger of Allah, will you stay in your house in Makkah?” He said: “Has ‘Aqeel left us any houses?” 'Aqeel had inherited Abu Talib along with Talib. Neither Ja'far nor 'Ali inherited anything because they had been Muslims, and 'Aqeel and Talib had been disbelievers. So on account of that, Omar would say the believer does not inherit from the disbeliever. And Usamah said: the Messenger of Allah (ﷺ) said "The Muslim does not inherit from the disbeliever nor the disbeliever from the Muslim}}
\hadithdefcmd{ibnmajah}{2731}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا ابْنُ لَهِيعَةَ، عَنْ خَالِدِ بْنِ يَزِيدَ، أَنَّ الْمُثَنَّى بْنَ الصَّبَّاحِ، أَخْبَرَهُ عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَتَوَارَثُ أَهْلُ مِلَّتَيْنِ ‏"‏ ‏.‏\hadithno{2731}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Amr bin Shu’aib, from his father, from his grandfather, that the Messenger of Allah (ﷺ) said:“People of two different religions do not inherit from one another.”}}
\hadithdefcmd{ibnmajah}{2732}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ تَزَوَّجَ رِئَابُ بْنُ حُذَيْفَةَ بْنِ سُعَيْدِ بْنِ سَهْمٍ أُمَّ وَائِلٍ بِنْتَ مَعْمَرٍ الْجُمَحِيَّةَ فَوَلَدَتْ لَهُ ثَلاَثَةً فَتُوُفِّيَتْ أُمُّهُمْ فَوَرِثَهَا بَنُوهَا رِبَاعًا وَوَلاَءَ مَوَالِيهَا فَخَرَجَ بِهِمْ عَمْرُو بْنُ الْعَاصِ مَعَهُ إِلَى الشَّامِ فَمَاتُوا فِي طَاعُونِ عَمْوَاسَ فَوَرِثَهُمْ عَمْرٌو وَكَانَ عَصَبَتَهُمْ فَلَمَّا رَجَعَ عَمْرُو بْنُ الْعَاصِ جَاءَ بَنُو مَعْمَرٍ يُخَاصِمُونَهُ فِي وَلاَءِ أُخْتِهِمْ إِلَى عُمَرَ فَقَالَ عُمَرُ أَقْضِي بَيْنَكُمْ بِمَا سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم سَمِعْتُهُ يَقُولُ ‏ "‏ مَا أَحْرَزَ الْوَلَدُ أَوِ الْوَالِدُ فَهُوَ لِعَصَبَتِهِ مَنْ كَانَ ‏"‏ ‏.‏ قَالَ فَقَضَى لَنَا بِهِ وَكَتَبَ لَنَا بِهِ كِتَابًا فِيهِ شَهَادَةُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَزَيْدِ بْنِ ثَابِتٍ وَآخَرَ حَتَّى إِذَا اسْتُخْلِفَ عَبْدُ الْمَلِكِ بْنُ مَرْوَانَ تُوُفِّيَ مَوْلًى لَهَا وَتَرَكَ أَلْفَىْ دِينَارٍ فَبَلَغَنِي أَنَّ ذَلِكَ الْقَضَاءَ قَدْ غُيِّرَ فَخَاصَمُوهُ إِلَى هِشَامِ بْنِ إِسْمَاعِيلَ فَرَفَعَنَا إِلَى عَبْدِ الْمَلِكِ فَأَتَيْنَاهُ بِكِتَابِ عُمَرَ فَقَالَ إِنْ كُنْتُ لأَرَى أَنَّ هَذَا مِنَ الْقَضَاءِ الَّذِي لاَ يُشَكُّ فِيهِ وَمَا كُنْتُ أَرَى أَنَّ أَمْرَ أَهْلِ الْمَدِينَةِ بَلَغَ هَذَا أَنْ يَشُكُّوا فِي هَذَا الْقَضَاءِ ‏.‏ فَقَضَى لَنَا بِهِ فَلَمْ نَزَلْ فِيهِ بَعْدُ ‏.‏\hadithno{2732}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Amr bin Shu’aib, from his father, that his grandfather said:“Rabab bin Hudhaifah (bin Sa’eed) bin Sahm married Umm Wa’il bint Ma’mar Al-Jumahiyyah, and she bore him three sons. Their mother died and her sons inherited her houses and the Wala’ of her freed slaves. ‘Amr bin ‘As took them out to Sham, and they died of the plague of ‘Amwas. ‘Amr inherited from them, and he was their ‘Asabah.* When ‘Amr came back, Banu Ma’mar came to him and they referred their dispute with him concerning the Wala’ of their sister to ‘Umar. ‘Umar said: ‘I will judge between you according to what I heard from the Messenger of Allah (ﷺ). I heard him say: “What the son or father acquires goes to his. ‘Asabah, no matter who they are.’” So he ruled in our favour and wrote a document to that effect, in which was the testimony of ‘Abdur-Rahman bin ‘Awf, Zaid bin Thabit and someone else. Then when ‘Abdul-Malik bin Marwan was appointed caliph, a freed slave of hers (Umm Wa’il’s) died, leaving behind two thousand Dinar. I heard that that ruling had been changed, so they referred the dispute to Hisham bin Isma’il. We referred the matter to ‘Abdul-Malik, and brought him the document of ‘Umar. He said: ‘I thought that this was a ruling concerning which there was no doubt. I never thought that the people of Al-Madinah would reach such a state that they would doubt this ruling. So he ruled in our favour, and it remained like that afterwards.”}}
\hadithdefcmd{ibnmajah}{2733}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَصْبَهَانِيِّ، عَنْ مُجَاهِدِ بْنِ وَرْدَانَ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ مَوْلًى، لِلنَّبِيِّ صلى الله عليه وسلم وَقَعَ مِنْ نَخْلَةٍ فَمَاتَ وَتَرَكَ مَالاً وَلَمْ يَتْرُكْ وَلَدًا وَلاَ حَمِيمًا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَعْطُوا مِيرَاثَهُ رَجُلاً مِنْ أَهْلِ قَرْيَتِهِ ‏"‏ ‏.‏\hadithno{2733}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Aishah that the freed slave of the Prophet (ﷺ) fell from a palm tree and died. He left behind wealth but he had no child or close relative. The Prophet (ﷺ) said:“Give his legacy to a man from his village.”}}
\hadithdefcmd{ibnmajah}{2734}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ الْحَكَمِ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنْ بِنْتِ حَمْزَةَ، - قَالَ مُحَمَّدٌ يَعْنِي ابْنَ أَبِي لَيْلَى وَهِيَ أُخْتُ ابْنِ شَدَّادٍ لأُمِّهِ - قَالَتْ مَاتَ مَوْلاَىَ وَتَرَكَ ابْنَةً فَقَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَالَهُ بَيْنِي وَبَيْنَ ابْنَتِهِ فَجَعَلَ لِيَ النِّصْفَ وَلَهَا النِّصْفَ ‏.‏\hadithno{2734}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that the daughter of Hamzah said:“My freed slave died, leaving behind a daughter. The Messenger of Allah (ﷺ) divided his wealth between myself and his daughter, giving me half and her half.”}}
\hadithdefcmd{ibnmajah}{2735}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ إِسْحَاقَ بْنِ أَبِي فَرْوَةَ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الْقَاتِلُ لاَ يَرِثُ ‏"‏ ‏.‏\hadithno{2735}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The killer does not inherit.”}}
\hadithdefcmd{ibnmajah}{2736}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنِ الْحَسَنِ بْنِ صَالِحٍ، عَنْ مُحَمَّدِ بْنِ سَعِيدٍ، - وَقَالَ مُحَمَّدُ بْنُ يَحْيَى عَنْ عُمَرَ بْنِ سَعِيدٍ، - عَنْ عَمْرِو بْنِ شُعَيْبٍ، حَدَّثَنِي أَبِي، عَنْ جَدِّي عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ يَوْمَ فَتْحِ مَكَّةَ فَقَالَ ‏ "‏ الْمَرْأَةُ تَرِثُ مِنْ دِيَةِ زَوْجِهَا وَمَالِهِ وَهُوَ يَرِثُ مِنْ دِيَتِهَا وَمَالِهَا مَا لَمْ يَقْتُلْ أَحَدُهُمَا صَاحِبَهُ فَإِذَا قَتَلَ أَحَدُهُمَا صَاحِبَهُ عَمْدًا لَمْ يَرِثْ مِنْ دِيَتِهِ وَمَالِهِ شَيْئًا وَإِنْ قَتَلَ أَحَدُهُمَا صَاحِبَهُ خَطَأً وَرِثَ مِنْ مَالِهِ وَلَمْ يَرِثْ مِنْ دِيَتِهِ ‏"‏ ‏.‏\hadithno{2736}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr that the Messenger of Allah (ﷺ) stood up, on the day of the conquest of Makkah, and said:“A woman inherits from the blood money and wealth of her husband, and he inherits from her blood money and wealth, so long as one of them did not kill the other. If one of them killed the other deliberately, then he or she inherits nothing from the blood money or wealth. If one of them killed the other by mistake, he or she inherits from the other’s wealth, but not from the blood money.”}}
\hadithdefcmd{ibnmajah}{2737}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ عَيَّاشِ بْنِ أَبِي رَبِيعَةَ الزُّرَقِيِّ، عَنْ حَكِيمِ بْنِ حَكِيمِ بْنِ عَبَّادِ بْنِ حُنَيْفٍ الأَنْصَارِيِّ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، أَنَّ رَجُلاً، رَمَى رَجُلاً بِسَهْمٍ فَقَتَلَهُ وَلَيْسَ لَهُ وَارِثٌ إِلاَّ خَالٌ فَكَتَبَ فِي ذَلِكَ أَبُو عُبَيْدَةَ بْنُ الْجَرَّاحِ إِلَى عُمَرَ فَكَتَبَ إِلَيْهِ عُمَرُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُ وَرَسُولُهُ مَوْلَى مَنْ لاَ مَوْلَى لَهُ وَالْخَالُ وَارِثُ مَنْ لاَ وَارِثَ لَهُ ‏"‏ ‏.‏\hadithno{2737}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Umamah bin Sahl bin Hunaif that a man shot an arrow at another man and killed him, and he had no heir except a maternal uncle. Abu ‘Ubaidah bin Jarrah wrote to ‘Umar about that, and ‘Umar wrote back to him saying that the Prophet (ﷺ) said:“Allah and His Messenger are the guardians of the one who has no guardian, and the maternal uncle is the heir of one who has no other heir.”}}
\hadithdefcmd{ibnmajah}{2738}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي بُدَيْلُ بْنُ مَيْسَرَةَ الْعُقَيْلِيُّ، عَنْ عَلِيِّ بْنِ أَبِي طَلْحَةَ، عَنْ رَاشِدِ بْنِ سَعْدٍ، عَنْ أَبِي عَامِرٍ الْهَوْزَنِيِّ، عَنِ الْمِقْدَامِ أَبِي كَرِيمَةَ، - رَجُلٌ مِنْ أَهْلِ الشَّامِ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ - قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَرَكَ مَالاً فَلِوَرَثَتِهِ وَمَنْ تَرَكَ كَلاًّ فَإِلَيْنَا - وَرُبَّمَا قَالَ فَإِلَى اللَّهِ وَإِلَى رَسُولِهِ - وَأَنَا وَارِثُ مَنْ لاَ وَارِثَ لَهُ أَعْقِلُ عَنْهُ وَأَرِثُهُ وَالْخَالُ وَارِثُ مَنْ لاَ وَارِثَ لَهُ يَعْقِلُ عَنْهُ وَيَرِثُهُ ‏"‏ ‏.‏\hadithno{2738}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Miqdam Abu Karimah, a man from Sham who was one of the Companions of the Messenger of Allah (ﷺ), that the Messenger of Allah (ﷺ) said:“Whoever leaves behind wealth, it is for his heirs. Whoever leaves behind poor dependents and a debt, it is for us to take care of – or he said: ‘It is for Allah and His Messenger (to take care of) – I am the heir of the one who has no heir, I will pay the blood money on his behalf and inherit from him. And the maternal uncle is the heir of the one who has no heir, he pays blood money on his behalf and inherits from him.”}}
\hadithdefcmd{ibnmajah}{2739}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا أَبُو بَحْرٍ الْبَكْرَاوِيُّ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّ أَعْيَانَ بَنِي الأُمِّ يَتَوَارَثُونَ دُونَ بَنِي الْعَلاَّتِ يَرِثُ الرَّجُلُ أَخَاهُ لأَبِيهِ وَأُمِّهِ دُونَ إِخْوَتِهِ لأَبِيهِ ‏.‏\hadithno{2739}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali bin Abu Talib said:“The Messenger of Allah (ﷺ) ruled that the sons from the same mother inherit from one another, but not sons from different mothers. A man inherits from his full brother from the same father and mother, but not his brothers from his father.”}}
\hadithdefcmd{ibnmajah}{2740}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْسِمُوا الْمَالَ بَيْنَ أَهْلِ الْفَرَائِضِ عَلَى كِتَابِ اللَّهِ فَمَا تَرَكَتِ الْفَرَائِضُ فَلأَوْلَى رَجُلٍ ذَكَرٍ ‏"‏ ‏.‏\hadithno{2740}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) said: ‘Distribute wealth among those who are entitled to shares of inheritance, according to the Book of Allah, then whatever is left over goes to the nearest male relative.’”}}
\hadithdefcmd{ibnmajah}{2741}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَوْسَجَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَاتَ رَجُلٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَمْ يَدَعْ لَهُ وَارِثًا إِلاَّ عَبْدًا هُوَ أَعْتَقَهُ فَدَفَعَ النَّبِيُّ صلى الله عليه وسلم مِيرَاثَهُ إِلَيْهِ ‏.‏\hadithno{2741}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn ‘Abbas said:“A man died at the time of the Messenger of Allah (ﷺ), and he left no heir except for a slave whom he had set free. The Messenger of Allah (ﷺ) gave the legacy to him.”}}
\hadithdefcmd{ibnmajah}{2742}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَنَا عُمَرُ بْنُ رُؤْبَةَ التَّغْلِبِيُّ، عَنْ عَبْدِ الْوَاحِدِ بْنِ عَبْدِ اللَّهِ النَّصْرِيِّ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَرْأَةُ تَحُوزُ ثَلاَثَ مَوَارِيثَ عَتِيقِهَا وَلَقِيطِهَا وَوَلَدِهَا الَّذِي لاَعَنَتْ عَلَيْهِ ‏"‏ ‏.‏ قَالَ مُحَمَّدُ بْنُ يَزِيدَ مَا رَوَى هَذَا الْحَدِيثَ غَيْرُ هِشَامٍ ‏.‏\hadithno{2742}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Wathilah bin Asqa’ that the Prophet (ﷺ) said:“A woman may get three types of inheritance: From her freed slave woman, a foundling whom she raised, and her child concerning whom she swore in Li’an that he was legitimate.”}}
\hadithdefcmd{ibnmajah}{2743}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ مُوسَى بْنِ عُبَيْدَةَ، حَدَّثَنِي يَحْيَى بْنُ حَرْبٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَمَّا نَزَلَتْ آيَةُ اللِّعَانِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا امْرَأَةٍ أَلْحَقَتْ بِقَوْمٍ مَنْ لَيْسَ مِنْهُمْ فَلَيْسَتْ مِنَ اللَّهِ فِي شَىْءٍ وَلَنْ يُدْخِلَهَا جَنَّتَهُ وَأَيُّمَا رَجُلٍ أَنْكَرَ وَلَدَهُ وَقَدْ عَرَفَهُ احْتَجَبَ اللَّهُ مِنْهُ يَوْمَ الْقِيَامَةِ وَفَضَحَهُ عَلَى رُءُوسِ الأَشْهَادِ ‏"‏ ‏.‏\hadithno{2743}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“Then the Verse of Li’an was revealed, the Messenger of Allah (ﷺ) said: ‘Any woman who attributed her child to people to whom he does not belong, then she has no relation to (the religion of) Allah, and she will never enter Paradise, and any man who rejects his child, while he recognizes him, Allah will screen Himself from him on the Day of Resurrection and disgrace him before the witnesses.’”}}
\hadithdefcmd{ibnmajah}{2744}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ كُفْرٌ بِامْرِئٍ ادِّعَاءُ نَسَبٍ لاَ يَعْرِفُهُ أَوْ جَحْدُهُ وَإِنْ دَقَّ ‏"‏ ‏.‏\hadithno{2744}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Amr bin Shu’aib, from his father, from his grandfather, that the Prophet (ﷺ) said:“It is disbelief for a man to attribute himself to someone other than his father knowingly, or to deny his connection to his father, even subtly.”}}
\hadithdefcmd{ibnmajah}{2745}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا يَحْيَى بْنُ الْيَمَانِ، عَنِ الْمُثَنَّى بْنِ الصَّبَّاحِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ عَاهَرَ أَمَةً أَوْ حُرَّةً فَوَلَدُهُ وَلَدُ زِنًا لاَ يَرِثُ وَلاَ يُورَثُ ‏"‏ ‏.‏\hadithno{2745}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Amr bin Shu’aib, from his father, from his grandfather that the Messenger of Allah (ﷺ) said:“Whoever commits adultery with a slave woman or a free woman, his child is illegitimate, and he cannot inherit from him or be inherited from (i.e., this child cannot inherit from him).”}}
\hadithdefcmd{ibnmajah}{2746}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ بَكَّارِ بْنِ بِلاَلٍ الدِّمَشْقِيُّ، أَنْبَأَنَا مُحَمَّدُ بْنُ رَاشِدٍ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ مُسْتَلْحَقٍ اسْتُلْحِقَ بَعْدَ أَبِيهِ الَّذِي يُدْعَى لَهُ ادَّعَاهُ وَرَثَتُهُ مِنْ بَعْدِهِ فَقَضَى أَنَّ مَنْ كَانَ مِنْ أَمَةٍ يَمْلِكُهَا يَوْمَ أَصَابَهَا فَقَدْ لَحِقَ بِمَنِ اسْتَلْحَقَهُ وَلَيْسَ لَهُ فِيمَا قُسِمَ قَبْلَهُ مِنَ الْمِيرَاثِ شَىْءٌ وَمَا أَدْرَكَ مِنْ مِيرَاثٍ لَمْ يُقْسَمْ فَلَهُ نَصِيبُهُ وَلاَ يَلْحَقُ إِذَا كَانَ أَبُوهُ الَّذِي يُدْعَى لَهُ أَنْكَرَهُ وَإِنْ كَانَ مِنْ أَمَةٍ لاَ يَمْلِكُهَا أَوْ مِنْ حُرَّةٍ عَاهَرَ بِهَا فَإِنَّهُ لاَ يَلْحَقُ وَلاَ يُورَثُ وَإِنْ كَانَ الَّذِي يُدْعَى لَهُ هُوَ ادَّعَاهُ فَهُوَ وَلَدُ زِنًا لأَهْلِ أُمِّهِ مَنْ كَانُوا حُرَّةً أَوْ أَمَةً ‏"‏ ‏.‏ قَالَ مُحَمَّدُ بْنُ رَاشِدٍ يَعْنِي بِذَلِكَ مَا قُسِمَ فِي الْجَاهِلِيَّةِ قَبْلَ الإِسْلاَمِ ‏.‏\hadithno{2746}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Amr bin Shu’aib, from his father, from his grandfather, that the Messenger of Allah (ﷺ) said:“Every child who is attributed to his father after his father to whom he is attributed has died, and his heirs attributed him to him after he died, he ruled that* whoever was born to a slave woman whom he owned at the time when he had intercourse with her, he should be named after the one to whom he was attributed, but he has no share of any inheritance that was distributed previously. Whatever inheritance he finds has not yet been distributed, he will have a share of it. But he cannot be named after his father if the man whom he claimed as his father did not acknowledge him. If he as born to a slave woman whom his father did not own, or to a free woman with whom he committed adultery, then he cannot be named after him and he does not inherit from him, even if the one whom he claims as his father acknowledges him. So he is an illegitimate child who belongs to his mother’s people, whoever they are, whether she is a free woman or a slave.”}}
\hadithdefcmd{ibnmajah}{2747}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا شُعْبَةُ، وَسُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الْوَلاَءِ وَعَنْ هِبَتِهِ ‏.‏\hadithno{2747}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) forbade selling the right of inheritance or giving it away.”}}
\hadithdefcmd{ibnmajah}{2748}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ الطَّائِفِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الْوَلاَءِ وَعَنْ هِبَتِهِ ‏.‏\hadithno{2748}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:The Messenger of Allah (ﷺ) forbade selling the right of inheritance, or giving it as a gift}}
\hadithdefcmd{ibnmajah}{2749}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ لَهِيعَةَ، عَنْ عُقَيْلٍ، أَنَّهُ سَمِعَ نَافِعًا، يُخْبِرُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا كَانَ مِنْ مِيرَاثٍ قُسِمَ فِي الْجَاهِلِيَّةِ فَهُوَ عَلَى قِسْمَةِ الْجَاهِلِيَّةِ وَمَا كَانَ مِنْ مِيرَاثٍ أَدْرَكَهُ الإِسْلاَمُ فَهُوَ عَلَى قِسْمَةِ الإِسْلاَمِ ‏"‏ ‏.‏\hadithno{2749}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Abdullah bin ‘Umar that the Messenger of Allah (ﷺ) said:“Whatever division of inheritance was made during the Ignorance period, stands according to the division of the Ignorance period, and whatever division of inheritance was made during Islam, it stands according to the division of Islam.”}}
\hadithdefcmd{ibnmajah}{2750}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الرَّبِيعُ بْنُ بَدْرٍ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا اسْتَهَلَّ الصَّبِيُّ صُلِّيَ عَلَيْهِ وَوَرِثَ ‏"‏ ‏.‏\hadithno{2750}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“If the child has cired, the (funeral) prayer should be offered for him (if he dies) and he is an heir.”}}
\hadithdefcmd{ibnmajah}{2751}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا مَرْوَانُ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، وَالْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالاَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَرِثُ الصَّبِيُّ حَتَّى يَسْتَهِلَّ صَارِخًا ‏"‏ ‏.‏ قَالَ وَاسْتِهْلاَلُهُ أَنْ يَبْكِيَ وَيَصِيحَ أَوْ يَعْطِسَ ‏.‏\hadithno{2751}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Jabir bin ‘Abdullah and Miswar bin Makhrumah that the Messenger of Allah (ﷺ) said:“No child inherits until he raises his voice or cries.”}}
\hadithdefcmd{ibnmajah}{2752}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ عَبْدِ الْعَزِيزِ بْنِ عُمَرَ، عَنْ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، قَالَ سَمِعْتُ تَمِيمًا الدَّارِيَّ، يَقُولُ قُلْتُ يَا رَسُولَ اللَّهِ مَا السُّنَّةُ فِي الرَّجُلِ مِنْ أَهْلِ الْكِتَابِ يُسْلِمُ عَلَى يَدَىِ الرَّجُلِ قَالَ ‏ "‏ هُوَ أَوْلَى النَّاسِ بِمَحْيَاهُ وَمَمَاتِهِ ‏"‏ ‏.‏\hadithno{2752}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Abdullah bin Mawhab said:“I heard Tamim Ad- Dari say: ‘I said: O Messenger of Allah, what is the Sunnah concerning a man from among the People of the Book who becomes a Muslim at the hands of another man?’ He said: ‘He is the closest of all people to him in life and in death.’”}}
