% Auto-generated chapter 51 for malik
% Hadiths in this chapter: 17

\hadithdefcmd{malik}{1730}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي بَكْرِ بْنِ نَافِعٍ، عَنْ أَبِيهِ، نَافِعٍ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِإِحْفَاءِ الشَّوَارِبِ وَإِعْفَاءِ اللِّحَى ‏.‏\hadithno{1730}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu Bakr ibn Nafi from his father Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, ordered the moustache to be trimmed and the beard to be left}}
\hadithdefcmd{malik}{1731}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّهُ سَمِعَ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ، عَامَ حَجَّ وَهُوَ عَلَى الْمِنْبَرِ وَتَنَاوَلَ قُصَّةً مِنْ شَعَرٍ كَانَتْ فِي يَدِ حَرَسِيٍّ يَقُولُ يَا أَهْلَ الْمَدِينَةِ أَيْنَ عُلَمَاؤُكُمْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ مِثْلِ هَذِهِ وَيَقُولُ ‏ "‏ إِنَّمَا هَلَكَتْ بَنُو إِسْرَائِيلَ حِينَ اتَّخَذَ هَذِهِ نِسَاؤُهُمْ ‏"‏ ‏.‏\hadithno{1731}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Humay ibn Abd ar-Rahman ibn Awf heard Muawiya ibn Abi Sufyan say from the mimbar in the year that he performed the hajj, holding a lock of hair (i.e. a hairpiece) which he took from one of his guards, "People of Madina! Where are your learned men? I heard the Messenger of Allah, may Allah bless him and grant him peace, forbid the like of this, saying, 'The Banu Israil were destroyed when their women started to use this}}
\hadithdefcmd{malik}{1732}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زِيَادِ بْنِ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ سَمِعَهُ يَقُولُ سَدَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَاصِيَتَهُ مَا شَاءَ اللَّهُ ثُمَّ فَرَقَ بَعْدَ ذَلِكَ ‏.‏ قَالَ مَالِكٌ لَيْسَ عَلَى الرَّجُلِ يَنْظُرُ إِلَى شَعَرِ امْرَأَةِ ابْنِهِ أَوْ شَعَرِ أُمِّ امْرَأَتِهِ بَأْسٌ ‏.‏\hadithno{1732}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Ziyad ibn Sad heard Ibn Shihab say, "The Messenger of Allah, may Allah bless him and grant him peace, let his hair hang down his forehead as Allah willed, and afterwards he parted it." Malik said, "There is no harm in a man's looking at the hair of his son's wife or the hair of his wife's mother}}
\hadithdefcmd{malik}{1733}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَكْرَهُ الإِخْصَاءَ وَيَقُولُ فِيهِ تَمَامُ الْخَلْقِ ‏.‏\hadithno{1733}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar disapproved of castration and said, "The completeness of the created form is in the testicles}}
\hadithdefcmd{malik}{1734}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، أَنَّهُ بَلَغَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَنَا وَكَافِلُ الْيَتِيمِ لَهُ أَوْ لِغَيْرِهِ فِي الْجَنَّةِ كَهَاتَيْنِ إِذَا اتَّقَى ‏"‏ ‏.‏ وَأَشَارَ بِإِصْبُعَيْهِ الْوُسْطَى وَالَّتِي تَلِي الإِبْهَامَ ‏.‏\hadithno{1734}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that Safwan ibn Sulaym heard that the Prophet, may Allah bless him and grant him peace, said, "I and the one who guards the orphan, whether for himself or for someone else, will be like these two in the Garden, when he has taqwa," indicating his middle and index fingers}}
\hadithdefcmd{malik}{1735}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ أَبَا قَتَادَةَ الأَنْصَارِيَّ، قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّ لِي جُمَّةً أَفَأُرَجِّلُهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ وَأَكْرِمْهَا ‏"‏ فَكَانَ أَبُو قَتَادَةَ رُبَّمَا دَهَنَهَا فِي الْيَوْمِ مَرَّتَيْنِ لِمَا قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَأَكْرِمْهَا ‏"‏ ‏.‏\hadithno{1735}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Abu Qatada al-Ansari said to the Messenger of Allah, may Allah bless him and grant him peace, "I have a lot of hair which comes down to my shoulders, shall I comb it?'' The Messenger of Allah. may Allah bless him and grant him peace, said, "Yes, and honour it." Sometimes Abu Qatada oiled it twice in one day because the Messenger of Allah, may Allah bless him and grant him peace, said to him. "Honour it}}
\hadithdefcmd{malik}{1736}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ عَطَاءَ بْنَ يَسَارٍ، أَخْبَرَهُ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ فَدَخَلَ رَجُلٌ ثَائِرَ الرَّأْسِ وَاللِّحْيَةِ فَأَشَارَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ أَنِ اخْرُجْ كَأَنَّهُ يَعْنِي إِصْلاَحَ شَعَرِ رَأْسِهِ وَلِحْيَتِهِ فَفَعَلَ الرَّجُلُ ثُمَّ رَجَعَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلَيْسَ هَذَا خَيْرًا مِنْ أَنْ يَأْتِيَ أَحَدُكُمْ ثَائِرَ الرَّأْسِ كَأَنَّهُ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{1736}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that Ata ibn Yasar told him that the Messenger of Allah, may Allah bless him and grant him peace, was in the mosque when a man came in with dishevelled hair and beard. The Messenger of Allah. may Allah bless him and grant him peace, motioned with his hand that he should be sent out to groom his hair and beard. The man did so and then returned. The Messenger of Allah, may Allah bless him and grant him peace, said, "Isn't this better than that one of you should come with his head dishevelled, as if he were a shaytan?}}
\hadithdefcmd{malik}{1737}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ التَّيْمِيُّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ الأَسْوَدِ بْنِ عَبْدِ يَغُوثَ، قَالَ وَكَانَ جَلِيسًا لَهُمْ وَكَانَ أَبْيَضَ اللِّحْيَةِ وَالرَّأْسِ - قَالَ - فَغَدَا عَلَيْهِمْ ذَاتَ يَوْمٍ وَقَدْ حَمَّرَهُمَا - قَالَ - فَقَالَ لَهُ الْقَوْمُ هَذَا أَحْسَنُ فَقَالَ إِنَّ أُمِّي عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَرْسَلَتْ إِلَىَّ الْبَارِحَةَ جَارِيَتَهَا نُخَيْلَةَ فَأَقْسَمَتْ عَلَىَّ لأَصْبُغَنَّ وَأَخْبَرَتْنِي أَنَّ أَبَا بَكْرٍ الصِّدِّيقَ كَانَ يَصْبُغُ ‏.‏ قَالَ يَحْيَى سَمِعْتُ مَالِكًا يَقُولُ فِي صَبْغِ الشَّعَرِ بِالسَّوَادِ لَمْ أَسْمَعْ فِي ذَلِكَ شَيْئًا مَعْلُومًا وَغَيْرُ ذَلِكَ مِنَ الصِّبْغِ أَحَبُّ إِلَىَّ ‏.‏ قَالَ وَتَرْكُ الصَّبْغِ كُلِّهِ وَاسِعٌ إِنْ شَاءَ اللَّهُ لَيْسَ عَلَى النَّاسِ فِيهِ ضِيقٌ ‏.‏ قَالَ وَسَمِعْتُ مَالِكًا يَقُولُ فِي هَذَا الْحَدِيثِ بَيَانُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَصْبُغْ وَلَوْ صَبَغَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَرْسَلَتْ بِذَلِكَ عَائِشَةُ إِلَى عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ ‏.‏\hadithno{1737}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said that Muhammad ibn Ibrahim at-Taymi had informed him that Abu Salama ibn Abd ar-Rahman said "Abd ar-Rahman ibn al-Aswad ibn Abdal-Yaghuth used to sit with us and he had a white beard and hair. One day he came to us and he had dyed them red, and the people said to him, 'This is better.' He said. 'A'isha the wife of the Prophet, may Allah bless him and grant him peace, sent her slave girl Nukhayla to me yesterday. She swore that my hair would be dyed and she informed me that Abu Bakr as- Siddiq used to dye his hair.' " Yahya said that he heard Malik say about dyeing the hair black, 'I have not heard anything certain on that, and other colours than that are preferable to me." Yahya said, "Not to dye at all is permitted, Allah willing, and there is no constraint on people concerning it." Yahya said that he had heard Malik say, "There is no clear indication in this hadith that the Messenger of Allah, may Allah bless him and grant him peace, did not dye his hair. Had the Messenger of Allah, may Allah bless him and grant him peace, dyed his hair, A'isha would have sent a message to that effect to Abd ar-Rahman ibn al-Aswad}}
\hadithdefcmd{malik}{1738}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ بَلَغَنِي أَنَّ خَالِدَ بْنَ الْوَلِيدِ، قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِنِّي أُرَوَّعُ فِي مَنَامِي ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قُلْ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّةِ مِنْ غَضَبِهِ وَعِقَابِهِ وَشَرِّ عِبَادِهِ وَمِنْ هَمَزَاتِ الشَّيَاطِينِ وَأَنْ يَحْضُرُونِ ‏"‏ ‏.‏\hadithno{1738}\hadithgrade{Salim al-Hilali: Hasan Lighairihi}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said that he had heard that Khalid ibn al-Walid said to the Messenger of Allah, may Allah bless him and grant him peace, "I have nightmares." The Messenger of Allah, may Allah bless him and grant him peace, said to him, "Say, 'I seek refuge with the complete words of Allah from His anger and His punishment and the evil of His slaves, and from the evil suggestions of the shayatin and from their being present (at death).' " Audhu bi kalimati' llahi't-tammati min ghadabihi wa iqabihi wa sharri ibadihi wa min hamazati' sh-shayatin wa an yahdurun}}
\hadithdefcmd{malik}{1739}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ أُسْرِيَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم فَرَأَى عِفْرِيتًا مِنَ الْجِنِّ يَطْلُبُهُ بِشُعْلَةٍ مِنْ نَارٍ كُلَّمَا الْتَفَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَآهُ فَقَالَ لَهُ جِبْرِيلُ أَفَلاَ أُعَلِّمُكَ كَلِمَاتٍ تَقُولُهُنَّ إِذَا قُلْتَهُنَّ طَفِئَتْ شُعْلَتُهُ وَخَرَّ لِفِيهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَلَى ‏"‏ فَقَالَ جِبْرِيلُ فَقُلْ أَعُوذُ بِوَجْهِ اللَّهِ الْكَرِيمِ وَبِكَلِمَاتِ اللَّهِ التَّامَّاتِ اللاَّتِي لاَ يُجَاوِزُهُنَّ بَرٌّ وَلاَ فَاجِرٌ مِنْ شَرِّ مَا يَنْزِلُ مِنَ السَّمَاءِ وَشَرِّ مَا يَعْرُجُ فِيهَا وَشَرِّ مَا ذَرَأَ فِي الأَرْضِ وَشَرِّ مَا يَخْرُجُ مِنْهَا وَمِنْ فِتَنِ اللَّيْلِ وَالنَّهَارِ وَمِنْ طَوَارِقِ اللَّيْلِ وَالنَّهَارِ إِلاَّ طَارِقًا يَطْرُقُ بِخَيْرٍ يَا رَحْمَنُ ‏.‏\hadithno{1739}\hadithgrade{Salim al-Hilali: Hasan Lighairihi}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said, "When the Messenger of Allah, may Allah bless him and grant him peace, was taken on the Night Journey, he saw an evil jinn seeking him with a torch of fire. Whenever the Messenger of Allah, may Allah bless him and grant him peace, turned, he saw him. Jibril said to him, 'Shall I teach you some words to say? When you say them, his torch will be put out and will fall from him.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'Yes, indeed.' Jibril said, 'Say, 'I seek refuge with the Noble Face of Allah and with the complete words of Allah which neither the good person nor the corrupt can exceed, from the evil of what descends from the sky and the evil of what ascends in it, and from the evil of what is created in the earth and the evil of what comes out of it, and from the trials of the night and day, and from the visitations of the night and day, except for one that knocks with good, O Merciful!" "' Audhu bi wajhi'llahi' l-karim wa bi kalimati'llahi't-tammati. Allati la yujawazu hunna barra wa la fajir, min sharri ma yanzil min as-sama, wa sharri ma yaruju fiha, wa sham ma dhara' fi'l-ard, wa sharri ma yakhruju minha, wa min fitani'l-layli wa'n-nahar, wa min tawariqi'l-layli wa'n-nahar illa tariqan yatruq bikhayr ya Rahman}}
\hadithdefcmd{malik}{1740}{وَحَدَّثَنِي مَالِكٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، مِنْ أَسْلَمَ قَالَ مَا نِمْتُ هَذِهِ اللَّيْلَةَ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مِنْ أَىِّ شَىْءٍ ‏"‏ ‏.‏ فَقَالَ لَدَغَتْنِي عَقْرَبٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا إِنَّكَ لَوْ قُلْتَ حِينَ أَمْسَيْتَ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّاتِ مِنْ شَرِّ مَا خَلَقَ ‏.‏ لَمْ تَضُرَّكَ ‏"‏ ‏.‏\hadithno{1740}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Suhayl ibn Abi Salih from his father from Abu Hurayra that a man of the Aslam tribe said, "I did not sleep last night." The Messenger of Allah, may Allah bless him and grant him peace, said to him, "For what reason?" He said, "A scorpion bit me." The Messenger of Allah, may Allah bless him and grant him peace, said, "Had you said in the evening, 'I seek refuge with the complete words of Allah from the evil of what He has created, 'it would not have happened." Audhu bi kalimati'llahi't-tammati min sharri ma khalaq}}
\hadithdefcmd{malik}{1741}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، أَنَّ كَعْبَ الأَحْبَارِ، قَالَ لَوْلاَ كَلِمَاتٌ أَقُولُهُنَّ لَجَعَلَتْنِي يَهُودُ حِمَارًا ‏.‏ فَقِيلَ لَهُ وَمَا هُنَّ فَقَالَ أَعُوذُ بِوَجْهِ اللَّهِ الْعَظِيمِ الَّذِي لَيْسَ شَىْءٌ أَعْظَمَ مِنْهُ وَبِكَلِمَاتِ اللَّهِ التَّامَّاتِ الَّتِي لاَ يُجَاوِزُهُنَّ بَرٌّ وَلاَ فَاجِرٌ وَبِأَسْمَاءِ اللَّهِ الْحُسْنَى كُلِّهَا مَا عَلِمْتُ مِنْهَا وَمَا لَمْ أَعْلَمْ مِنْ شَرِّ مَا خَلَقَ وَبَرَأَ وَذَرَأَ ‏.‏\hadithno{1741}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Summayy, the mawla of Abu Bakr from al-Qa'qa ibn Hakim that Kab al-Ahbar said, "Had it not been for some words which I said, the jews would have made me into a donkey." Someone asked him what they were. He said, "I seek refuge with the immense Face of Allah - there is nothing greater than it - and with the complete words of Allah which neither the good person nor the corrupt can exceed and with all the most beautiful names of Allah, what I know of them and what I do not know, from the evil of what He has created and originated and multiplied." Audhu bi wajhi'llahi l-adheem aladhee laysa shay'un adham minh, wa bi kalimati'llahi't-tammati, alatee la yujawizu hunna barra wa la fajir, wa bi asma'illahi'l-husna kulliha ma alamtu minha wa ma lam alam, min sharri ma khalaqa wa bara'a wa dhara'a}}
\hadithdefcmd{malik}{1742}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ مَعْمَرٍ، عَنْ أَبِي الْحُبَابِ، سَعِيدِ بْنِ يَسَارٍ عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى يَقُولُ يَوْمَ الْقِيَامَةِ أَيْنَ الْمُتَحَابُّونَ لِجَلاَلِي الْيَوْمَ أُظِلُّهُمْ فِي ظِلِّي يَوْمَ لاَ ظِلَّ إِلاَّ ظِلِّي ‏"‏ ‏.‏\hadithno{1742}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abd ar-Rahman ibn Mamar from Abu'l-Hubab Said ibn Yasar that Abu Hurayra said, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'Allah, the Blessed, the Exalted, will say on the Day of Rising, "Where are those who loved each other for My majesty? Today I will shade them in My shade on the day when there is no shade except My shade}}
\hadithdefcmd{malik}{1743}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ الأَنْصَارِيِّ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَوْ عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَبْعَةٌ يُظِلُّهُمُ اللَّهُ فِي ظِلِّهِ يَوْمَ لاَ ظِلَّ إِلاَّ ظِلُّهُ إِمَامٌ عَادِلٌ وَشَابٌّ نَشَأَ فِي عِبَادَةِ اللَّهِ\hadithno{1743}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Khubayb ibn Abd ar-Rahman al- Ansari from Hafs ibn Asim that either Abu Said al-Khudri or Abu Hurayra said, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'There are seven whom Allah will shade in His shade on the day on which there is no shade except His shade:a just imam, a youth who grows up worshipping Allah, a man whose heart is attached to the mosque when he leaves it until he returns to it, two men who love each other in Allah and meet for that and part for that, a man who remembers Allah when he is alone and his eyes overflow with tears, a man who refuses the approaches of a noble, beautiful woman, saying "I fear Allah," and a man who gives sadaqa and conceals it so that his left hand does not know what his right hand gives}}
\hadithdefcmd{malik}{1744}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَحَبَّ اللَّهُ الْعَبْدَ قَالَ لِجِبْرِيلَ قَدْ أَحْبَبْتُ فُلاَنًا فَأَحِبَّهُ ‏.‏ فَيُحِبُّهُ جِبْرِيلُ ثُمَّ يُنَادِي فِي أَهْلِ السَّمَاءِ إِنَّ اللَّهَ قَدْ أَحَبَّ فُلاَنًا فَأَحِبُّوهُ ‏.‏ فَيُحِبُّهُ أَهْلُ السَّمَاءِ ثُمَّ يُوضَعُ لَهُ الْقَبُولُ فِي الأَرْضِ ‏.‏ وَإِذَا أَبْغَضَ اللَّهُ الْعَبْدَ ‏"‏ ‏.‏ قَالَ مَالِكٌ لاَ أَحْسِبُهُ إِلاَّ أَنَّهُ قَالَ فِي الْبُغْضِ مِثْلَ ذَلِكَ ‏.‏\hadithno{1744}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Suhayl ibn Abi Salih from his father from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "If Allah loves a slave, he says to Jibril, 'I love so-and-so, so love him,' so Jibril loves him and then calls out to the people of heaven, 'Allah loves so-and-so, so love him,' and the people of heaven love him, and then acceptance is placed in the Earth for him." When Allah is angry with a slave, Malik said, "I consider that he says the like of that about His anger}}
\hadithdefcmd{malik}{1745}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي حَازِمِ بْنِ دِينَارٍ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، أَنَّهُ قَالَ دَخَلْتُ مَسْجِدَ دِمَشْقَ فَإِذَا فَتًى شَابٌّ بَرَّاقُ الثَّنَايَا وَإِذَا النَّاسُ مَعَهُ إِذَا اخْتَلَفُوا فِي شَىْءٍ أَسْنَدُوا إِلَيْهِ وَصَدَرُوا عَنْ قَوْلِهِ فَسَأَلْتُ عَنْهُ فَقِيلَ هَذَا مُعَاذُ بْنُ جَبَلٍ ‏.‏ فَلَمَّا كَانَ الْغَدُ هَجَّرْتُ فَوَجَدْتُهُ قَدْ سَبَقَنِي بِالتَّهْجِيرِ وَوَجَدْتُهُ يُصَلِّي - قَالَ - فَانْتَظَرْتُهُ حَتَّى قَضَى صَلاَتَهُ ثُمَّ جِئْتُهُ مِنْ قِبَلِ وَجْهِهِ فَسَلَّمْتُ عَلَيْهِ ثُمَّ قُلْتُ وَاللَّهِ إِنِّي لأُحِبُّكَ لِلَّهِ ‏.‏ فَقَالَ آللَّهِ فَقُلْتُ آللَّهِ ‏.‏ فَقَالَ آللَّهِ فَقُلْتُ آللَّهِ ‏.‏ فَقَالَ آللَّهِ فَقُلْتُ آللَّهِ ‏.‏ قَالَ فَأَخَذَ بِحُبْوَةِ رِدَائِي فَجَبَذَنِي إِلَيْهِ وَقَالَ أَبْشِرْ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ قَالَ اللَّهُ تَبَارَكَ وَتَعَالَى وَجَبَتْ مَحَبَّتِي لِلْمُتَحَابِّينَ فِيَّ وَالْمُتَجَالِسِينَ فِيَّ وَالْمُتَزَاوِرِينَ فِيَّ وَالْمُتَبَاذِلِينَ فِيَّ ‏"‏ ‏.‏\hadithno{1745}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu Hazim ibn Dinar that Abu Idris al-Khawlani said, "I entered the Damascus mosque and there was a young man with a beautiful mouth and white teeth sitting with some people. When they disagreed about something, they referred it to him and proceeded from his statement. I inquired about him, and it was said, 'This is Muadh ibn Jabal.' The next day I went to the noon-prayer, and I found that he had preceded me to the noon prayer and I found him praying." Abu Idris continued, "I waited for him until he had finished the prayer. Then I came to him from in front of him and greeted him and said, 'By Allah! I love you for Allah!' He said, 'By Allah?' I said, 'By Allah.' He said, 'By Allah?' I said, 'By Allah.' He said, 'By Allah?' I said, 'By Allah.' " He continued, "He took me by the upper part of my cloak and pulled me to him and said, 'Rejoice! I heard the Messenger of Allah, may Allah bless him and grant him peace, say, "Allah, the Blessed and Exalted, said, 'My love is obliged for those who love each other in Me, and those who sit with each other in Me, and those who visit each other in Me, and those who give to each other generously in Me}}
\hadithdefcmd{malik}{1746}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ كَانَ يَقُولُ الْقَصْدُ وَالْتُّؤَدَةُ وَحُسْنُ السَّمْتِ جُزْءٌ مِنْ خَمْسَةٍ وَعِشْرِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏.‏\hadithno{1746}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Abbas said, "Equanimity, gentleness, and good behaviour are one twenty-fifth of prophecy}}
