% Auto-generated chapter 32 for bukhari
% Hadiths in this chapter: 11

\hadithdefcmd{bukhari}{2014}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ حَفِظْنَاهُ وَإِنَّمَا حَفِظَ مِنَ الزُّهْرِيِّ عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ، وَمَنْ قَامَ لَيْلَةَ الْقَدْرِ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏‏.‏ تَابَعَهُ سُلَيْمَانُ بْنُ كَثِيرٍ عَنِ الزُّهْرِيِّ‏.‏\hadithno{2014}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Whoever fasted the month of Ramadan out of sincere Faith (i.e. belief) and hoping for a reward from Allah, then all his past sins will be forgiven, and whoever stood for the prayers in the night of Qadr out of sincere Faith and hoping for a reward from Allah, then all his previous sins will be forgiven}}
\hadithdefcmd{bukhari}{2015}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رِجَالاً، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أُرُوا لَيْلَةَ الْقَدْرِ فِي الْمَنَامِ فِي السَّبْعِ الأَوَاخِرِ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَرَى رُؤْيَاكُمْ قَدْ تَوَاطَأَتْ فِي السَّبْعِ الأَوَاخِرِ، فَمَنْ كَانَ مُتَحَرِّيَهَا فَلْيَتَحَرَّهَا فِي السَّبْعِ الأَوَاخِرِ ‏"‏‏.‏\hadithno{2015}\hadithtrans{Narrated Ibn `Umar:Some men amongst the companions of the Prophet (ﷺ) were shown in their dreams that the night of Qadr was in the last seven nights of Ramadan. Allah's Messenger (ﷺ) said, "It seems that all your dreams agree that (the Night of Qadr) is in the last seven nights, and whoever wants to search for it (i.e. the Night of Qadr) should search in the last seven (nights of Ramadan)}}
\hadithdefcmd{bukhari}{2016}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، قَالَ سَأَلْتُ أَبَا سَعِيدٍ وَكَانَ لِي صَدِيقًا فَقَالَ اعْتَكَفْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم الْعَشْرَ الأَوْسَطَ مِنْ رَمَضَانَ، فَخَرَجَ صَبِيحَةَ عِشْرِينَ، فَخَطَبَنَا وَقَالَ ‏ "‏ إِنِّي أُرِيتُ لَيْلَةَ الْقَدْرِ، ثُمَّ أُنْسِيتُهَا أَوْ نُسِّيتُهَا، فَالْتَمِسُوهَا فِي الْعَشْرِ الأَوَاخِرِ فِي الْوَتْرِ، وَإِنِّي رَأَيْتُ أَنِّي أَسْجُدُ فِي مَاءٍ وَطِينٍ، فَمَنْ كَانَ اعْتَكَفَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلْيَرْجِعْ ‏"‏‏.‏ فَرَجَعْنَا وَمَا نَرَى فِي السَّمَاءِ قَزَعَةً، فَجَاءَتْ سَحَابَةٌ فَمَطَرَتْ حَتَّى سَالَ سَقْفُ الْمَسْجِدِ وَكَانَ مِنْ جَرِيدِ النَّخْلِ، وَأُقِيمَتِ الصَّلاَةُ، فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْجُدُ فِي الْمَاءِ وَالطِّينِ، حَتَّى رَأَيْتُ أَثَرَ الطِّينِ فِي جَبْهَتِهِ‏.‏\hadithno{2016}\hadithtrans{Narrated Abu Salama:I asked Abu Sa`id, and he was a friend of mine, (about the Night of Qadr) and he said, "We practiced I`tikaf (seclusion in the mosque) in the middle third of the month of Ramadan with the Prophet (ﷺ) . In the morning of the 20th of Ramadan, the Prophet (ﷺ) came and addressed us and said, 'I was informed of (the date of the Night of Qadr) but I was caused to forget it; so search for it in the odd nights of the last ten nights of the month of Ramadan. (In the dream) I saw myself prostrating in mud and water (as a sign). So, whoever was in I`tikaf with me should return to it with me (for another 10-day's period)', and we returned. At that time there was no sign of clouds in the sky but suddenly a cloud came and it rained till rainwater started leaking through the roof of the mosque which was made of date-palm leaf stalks. Then the prayer was established and I saw Allah's Messenger (ﷺ) prostrating in mud and water and I saw the traces of mud on his forehead}}
\hadithdefcmd{bukhari}{2017}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، حَدَّثَنَا أَبُو سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَحَرَّوْا لَيْلَةَ الْقَدْرِ فِي الْوِتْرِ مِنَ الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ ‏"‏‏.‏\hadithno{2017}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said, "Search for the Night of Qadr in the odd nights of the last ten days of Ramadan}}
\hadithdefcmd{bukhari}{2018}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ، قَالَ حَدَّثَنِي ابْنُ أَبِي حَازِمٍ، وَالدَّرَاوَرْدِيُّ، عَنْ يَزِيدَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ‏.‏ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُجَاوِرُ فِي رَمَضَانَ الْعَشْرَ الَّتِي فِي وَسَطِ الشَّهْرِ، فَإِذَا كَانَ حِينَ يُمْسِي مِنْ عِشْرِينَ لَيْلَةً تَمْضِي، وَيَسْتَقْبِلُ إِحْدَى وَعِشْرِينَ، رَجَعَ إِلَى مَسْكَنِهِ وَرَجَعَ مَنْ كَانَ يُجَاوِرُ مَعَهُ‏.‏ وَأَنَّهُ أَقَامَ فِي شَهْرٍ جَاوَرَ فِيهِ اللَّيْلَةَ الَّتِي كَانَ يَرْجِعُ فِيهَا، فَخَطَبَ النَّاسَ، فَأَمَرَهُمْ مَا شَاءَ اللَّهُ، ثُمَّ قَالَ ‏ "‏ كُنْتُ أُجَاوِرُ هَذِهِ الْعَشْرَ، ثُمَّ قَدْ بَدَا لِي أَنْ أُجَاوِرَ هَذِهِ الْعَشْرَ الأَوَاخِرَ، فَمَنْ كَانَ اعْتَكَفَ مَعِي فَلْيَثْبُتْ فِي مُعْتَكَفِهِ، وَقَدْ أُرِيتُ هَذِهِ اللَّيْلَةَ ثُمَّ أُنْسِيتُهَا فَابْتَغُوهَا فِي الْعَشْرِ الأَوَاخِرِ وَابْتَغُوهَا فِي كُلِّ وِتْرٍ، وَقَدْ رَأَيْتُنِي أَسْجُدُ فِي مَاءٍ وَطِينٍ ‏"‏‏.‏ فَاسْتَهَلَّتِ السَّمَاءُ فِي تِلْكَ اللَّيْلَةِ، فَأَمْطَرَتْ، فَوَكَفَ الْمَسْجِدُ فِي مُصَلَّى النَّبِيِّ صلى الله عليه وسلم لَيْلَةَ إِحْدَى وَعِشْرِينَ، فَبَصُرَتْ عَيْنِي رَسُولَ اللَّهِ صلى الله عليه وسلم وَنَظَرْتُ إِلَيْهِ انْصَرَفَ مِنَ الصُّبْحِ، وَوَجْهُهُ مُمْتَلِئٌ طِينًا وَمَاءً‏.‏\hadithno{2018}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) used to practice I`tikaf (in the mosque) in the middle third of Ramadan and after passing the twenty nights he used to go back to his house on the 21st, and the people who were in I`tikaf with him also used to go back to their houses. Once in Ramadan, in which he practiced I`tikaf, he established the night prayers at the night in which he used to return home, and then he addressed the people and ordered them whatever Allah wished him to order and said, "I used to practice I`tikaf for these ten days (i.e. the middle third but now I intend to stay in I`tikaf for the last ten days (of the month); so whoever was in I`tikaf with me should stay at his place of seclusion. I have verily been shown (the date of) this Night (of Qadr) but I have forgotten it. So search for it in the odd nights of the last ten days (of this month). I also saw myself (in the dream) prostrating in mud and water." On the night of the 21st, the sky was covered with clouds and it rained, and the rainwater started leaking through the roof of the mosque at the praying place of the Prophet (ﷺ) . I saw with my own eyes the Prophet at the completion of the morning prayer leaving with his face covered with mud and water}}
\hadithdefcmd{bukhari}{2019}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ ـ رضى الله عنها ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْتَمِسُوا ‏"‏‏.‏\hadithno{2019}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "Look for (the Night of Qadr)}}
\hadithdefcmd{bukhari}{2020}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُجَاوِرُ فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ، وَيَقُولُ ‏ "‏ تَحَرَّوْا لَيْلَةَ الْقَدْرِ فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ ‏"‏‏.‏\hadithno{2020}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to practice I`tikaf in the last ten nights of Ramadan and used to say, "Look for the Night of Qadr in the last ten nights of the month of Ramadan}}
\hadithdefcmd{bukhari}{2021}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الْتَمِسُوهَا فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ لَيْلَةَ الْقَدْرِ فِي تَاسِعَةٍ تَبْقَى، فِي سَابِعَةٍ تَبْقَى، فِي خَامِسَةٍ تَبْقَى ‏"‏‏.‏\hadithno{2021}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "Look for the Night of Qadr in the last ten nights of Ramadan ,' on the night when nine or seven or five nights remain out of the last ten nights of Ramadan (i.e. 21, 23, 25, respectively)}}
\hadithdefcmd{bukhari}{2022}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي الأَسْوَدِ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا عَاصِمٌ، عَنْ أَبِي مِجْلَزٍ، وَعِكْرِمَةَ، قَالَ ابْنُ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هِيَ فِي الْعَشْرِ، هِيَ فِي تِسْعٍ يَمْضِينَ أَوْ فِي سَبْعٍ يَبْقَيْنَ ‏"‏‏.‏ يَعْنِي لَيْلَةَ الْقَدْرِ‏.‏ قَالَ عَبْدُ الْوَهَّابِ عَنْ أَيُّوبَ‏.‏ وَعَنْ خَالِدٍ عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ الْتَمِسُوا فِي أَرْبَعٍ وَعِشْرِينَ‏.‏\hadithno{2022}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) said, "The Night of Qadr is in the last ten nights of the month (Ramadan), either on the first nine or in the last (remaining) seven nights (of Ramadan)." Ibn `Abbas added, "Search for it on the twenty-fourth (of Ramadan)}}
\hadithdefcmd{bukhari}{2023}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا حُمَيْدٌ، حَدَّثَنَا أَنَسٌ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم لِيُخْبِرَنَا بِلَيْلَةِ الْقَدْرِ، فَتَلاَحَى رَجُلاَنِ مِنَ الْمُسْلِمِينَ، فَقَالَ ‏ "‏ خَرَجْتُ لأُخْبِرَكُمْ بِلَيْلَةِ الْقَدْرِ، فَتَلاَحَى فُلاَنٌ وَفُلاَنٌ، فَرُفِعَتْ، وَعَسَى أَنْ يَكُونَ خَيْرًا لَكُمْ، فَالْتَمِسُوهَا فِي التَّاسِعَةِ وَالسَّابِعَةِ وَالْخَامِسَةِ ‏"‏‏.‏\hadithno{2023}\hadithtrans{Narrated 'Ubada bin As-Samit:The Prophet (ﷺ) came out to inform us about the Night of Qadr but two Muslims were quarreling with each other. So, the Prophet (ﷺ) said, "I came out to inform you about the Night of Qadr but such-and-such persons were quarreling, so the news about it had been taken away; yet that might be for your own good, so search for it on the 29th, 27th and 25th (of Ramadan)}}
\hadithdefcmd{bukhari}{2024}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي يَعْفُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا دَخَلَ الْعَشْرُ شَدَّ مِئْزَرَهُ، وَأَحْيَا لَيْلَهُ، وَأَيْقَظَ أَهْلَهُ‏.‏\hadithno{2024}\hadithtrans{Narrated Aisha:With the start of the last ten days of Ramadan, the Prophet (ﷺ) used to tighten his waist belt (i.e. work hard) and used to pray all the night, and used to keep his family awake for the prayers}}
