% Auto-generated chapter 41 for tirmidhi
% Hadiths in this chapter: 43

\hadithdefcmd{tirmidhi}{2645}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ يُرِدِ اللَّهُ بِهِ خَيْرًا يُفَقِّهْهُ فِي الدِّينِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عُمَرَ وَأَبِي هُرَيْرَةَ وَمُعَاوِيَةَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2645}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ibn 'Abbas:that the Messenger of Allah (ﷺ) said: "For whomever Allah wants good, he gives him understanding in the religion}}
\hadithdefcmd{tirmidhi}{2646}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَلَكَ طَرِيقًا يَلْتَمِسُ فِيهِ عِلْمًا سَهَّلَ اللَّهُ لَهُ طَرِيقًا إِلَى الْجَنَّةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2646}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Whoever takes a path upon which to obtain knowledge, Allah makes the path to Paradise easy for him}}
\hadithdefcmd{tirmidhi}{2647}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا خَالِدُ بْنُ يَزِيدَ الْعَتَكِيُّ، عَنْ أَبِي جَعْفَرٍ الرَّازِيِّ، عَنِ الرَّبِيعِ بْنِ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ خَرَجَ فِي طَلَبِ الْعِلْمِ فَهُوَ فِي سَبِيلِ اللَّهِ حَتَّى يَرْجِعَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَرَوَاهُ بَعْضُهُمْ فَلَمْ يَرْفَعْهُ ‏.‏\hadithno{2647}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) said: "Whoever goes out seeking knowledge, then he is in Allah's cause until he returns}}
\hadithdefcmd{tirmidhi}{2648}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُعَلَّى، حَدَّثَنَا زِيَادُ بْنُ خَيْثَمَةَ، عَنْ أَبِي دَاوُدَ، عَنْ عَبْدِ اللَّهِ بْنِ سَخْبَرَةَ، عَنْ سَخْبَرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ طَلَبَ الْعِلْمَ كَانَ كَفَّارَةً لِمَا مَضَى ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ ضَعِيفُ الإِسْنَادِ ‏.‏ أَبُو دَاوُدَ يُضَعَّفُ وَلاَ نَعْرِفُ لِعَبْدِ اللَّهِ بْنِ سَخْبَرَةَ كَبِيِرَ شَيْءٍ وَلاَ لأَبِيهِ وَاسْمُ أَبِي دَاوُدَ نُفَيْعٌ الأَعْمَى تَكَلَّمَ فِيهِ قَتَادَةُ وَغَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ ‏.‏\hadithno{2648}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abdullah bin Sakhbarah:narrated that the Prophet (ﷺ) said: "Whoever seeks knowledge, he is atoning for what has passed (of sins while doing so)}}
\hadithdefcmd{tirmidhi}{2649}{حَدَّثَنَا أَحْمَدُ بْنُ بُدَيْلِ بْنِ قُرَيْشٍ الْيَامِيُّ الْكُوفِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُمَارَةَ بْنِ زَاذَانَ، عَنْ عَلِيِّ بْنِ الْحَكَمِ، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سُئِلَ عَنْ عِلْمٍ عَلِمَهُ ثُمَّ كَتَمَهُ أُلْجِمَ يَوْمَ الْقِيَامَةِ بِلِجَامٍ مِنْ نَارٍ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ جَابِرٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2649}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Whoever is asked about some knowledge that he knows, then he conceals it, he will be bridled with bridle of fire}}
\hadithdefcmd{tirmidhi}{2650}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ، عَنْ أَبِي هَارُونَ الْعَبْدِيِّ، قَالَ كُنَّا نَأْتِي أَبَا سَعِيدٍ فَيَقُولُ مَرْحَبًا بِوَصِيَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ النَّاسَ لَكُمْ تَبَعٌ وَإِنَّ رِجَالاً يَأْتُونَكُمْ مِنْ أَقْطَارِ الأَرَضِينَ يَتَفَقَّهُونَ فِي الدِّينِ فَإِذَا أَتَوْكُمْ فَاسْتَوْصُوا بِهِمْ خَيْرًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى قَالَ عَلِيٌّ قَالَ يَحْيَى بْنُ سَعِيدٍ كَانَ شُعْبَةُ يُضَعِّفُ أَبَا هَارُونَ الْعَبْدِيَّ ‏.‏ قَالَ يَحْيَى بْنُ سَعِيدٍ مَا زَالَ ابْنُ عَوْنٍ يَرْوِي عَنْ أَبِي هَارُونَ الْعَبْدِيِّ حَتَّى مَاتَ ‏.‏ قَالَ أَبُو عِيسَى وَأَبُو هَارُونَ اسْمُهُ عُمَارَةُ بْنُ جُوَيْنٍ ‏.‏\hadithno{2650}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Harun [Al-'Abdi]:"We went to Abu Sa'eed and he said: 'Welcome with the exhortation of the Messenger of Allah (ﷺ). Indeed the Prophet (ﷺ) said: "Surely, the people are followers of you, and men will certainly come to you from the regions of the earth to gain understanding in the religion. So when they come to you exhort them with good}}
\hadithdefcmd{tirmidhi}{2651}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا نُوحُ بْنُ قَيْسٍ، عَنْ أَبِي هَارُونَ الْعَبْدِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَأْتِيكُمْ رِجَالٌ مِنْ قِبَلِ الْمَشْرِقِ يَتَعَلَّمُونَ فَإِذَا جَاءُوكُمْ فَاسْتَوْصُوا بِهِمْ خَيْرًا ‏"‏ ‏.‏ قَالَ فَكَانَ أَبُو سَعِيدٍ إِذَا رَآنَا قَالَ مَرْحَبًا بِوَصِيَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ أَبِي هَارُونَ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ‏.‏\hadithno{2651}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Harun [Al-'Abdi]:from Abu Sa'eed Al-Khudri that the Prophet (ﷺ) said: "Men will come to you from the direction of the east to learn. So when they come to you then exhort them to good." He said: "When Abu Sa'eed saw us he would say: 'Welcome with the exhortation of the Messenger of Allah, may the peace and blessings of Allah be upon him and his family}}
\hadithdefcmd{tirmidhi}{2652}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ لاَ يَقْبِضُ الْعِلْمَ انْتِزَاعًا يَنْتَزِعُهُ مِنَ النَّاسِ وَلَكِنْ يَقْبِضُ الْعِلْمَ بِقَبْضِ الْعُلَمَاءِ حَتَّى إِذَا لَمْ يَتْرُكْ عَالِمًا اتَّخَذَ النَّاسُ رُءُوسًا جُهَّالاً فَسُئِلُوا فَأَفْتَوْا بِغَيْرِ عِلْمٍ فَضَلُّوا وَأَضَلُّوا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ وَزِيَادِ بْنِ لَبِيدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى هَذَا الْحَدِيثَ الزُّهْرِيُّ عَنْ عُرْوَةَ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَنْ عُرْوَةَ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ هَذَا ‏.‏\hadithno{2652}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah bin 'Amr bin Al-'As:that the Messenger of Allah (ﷺ) said: "Indeed Allah does not take away knowledge by removing it from the people, but He takes away knowledge by taking the scholars, until there remains no scholar and the people begin to ask the ignorant leaders, so they give their verdict without knowledge. They will go astray and lead the people astray}}
\hadithdefcmd{tirmidhi}{2653}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ صَالِحٍ، حَدَّثَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، جُبَيْرِ بْنِ نُفَيْرٍ عَنْ أَبِي الدَّرْدَاءِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَشَخَصَ بِبَصَرِهِ إِلَى السَّمَاءِ ثُمَّ قَالَ ‏"‏ هَذَا أَوَانٌ يُخْتَلَسُ الْعِلْمُ مِنَ النَّاسِ حَتَّى لاَ يَقْدِرُوا مِنْهُ عَلَى شَيْءٍ ‏"‏ ‏.‏ فَقَالَ زِيَادُ بْنُ لَبِيدٍ الأَنْصَارِيُّ كَيْفَ يُخْتَلَسُ مِنَّا وَقَدْ قَرَأْنَا الْقُرْآنَ فَوَاللَّهِ لَنَقْرَأَنَّهُ وَلَنُقْرِئَنَّهُ نِسَاءَنَا وَأَبْنَاءَنَا ‏.‏ فَقَالَ ‏"‏ ثَكِلَتْكَ أُمُّكَ يَا زِيَادُ إِنْ كُنْتُ لأَعُدُّكَ مِنْ فُقَهَاءِ أَهْلِ الْمَدِينَةِ هَذِهِ التَّوْرَاةُ وَالإِنْجِيلُ عِنْدَ الْيَهُودِ وَالنَّصَارَى فَمَاذَا تُغْنِي عَنْهُمْ ‏"‏ ‏.‏ قَالَ جُبَيْرٌ فَلَقِيتُ عُبَادَةَ بْنَ الصَّامِتِ قُلْتُ أَلاَ تَسْمَعُ إِلَى مَا يَقُولُ أَخُوكَ أَبُو الدَّرْدَاءِ فَأَخْبَرْتُهُ بِالَّذِي قَالَ أَبُو الدَّرْدَاءِ قَالَ صَدَقَ أَبُو الدَّرْدَاءِ إِنْ شِئْتَ لأُحَدِّثَنَّكَ بِأَوَّلِ عِلْمٍ يُرْفَعُ مِنَ النَّاسِ الْخُشُوعُ يُوشِكُ أَنْ تَدْخُلَ مَسْجِدَ جَمَاعَةٍ فَلاَ تَرَى فِيهِ رَجُلاً خَاشِعًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَمُعَاوِيَةُ بْنُ صَالِحٍ ثِقَةٌ عِنْدَ أَهْلِ الْحَدِيثِ وَلاَ نَعْلَمُ أَحَدًا تَكَلَّمَ فِيهِ غَيْرَ يَحْيَى بْنِ سَعِيِدٍ الْقَطَّانِ وَقَدْ رُوِيَ عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ نَحْوُ هَذَا ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ عَنْ أَبِيهِ عَنْ عَوْفِ بْنِ مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2653}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jubair bin Nufair:from Abu Ad-Darda who said: "We were with the Prophet (ﷺ) when he raised his sight to the sky, then he said: 'This is the time when knowledge is to be taken from the people, until what remains of it shall not amount to anything." So Ziyad bin Labid Al-Ansari said: 'How will it be taken from us while we recite the Qur'an. By Allah we recite it, and our women and children recite it?' He (ﷺ) said: 'May you be bereaved of your mother O Ziyad! I used to consider you among the Fuqaha of the people of Al-Madinah. The Tawrah and Injil are with the Jews and Christians, but what do they avail of them?'" Jubair said: "So I met 'Ubadah bin As-Samit and said to him: 'Have you not heard what your brother Abu Ad-Darda said?' Then I informed him of what Abu Ad-Darda said. He said: 'Abu Ad-Darda spoke the truth. If you wish, we shall narrated to you about the first knowledge to be removed from the people: It is Khushu', soon you will enter the congregational Masjid, but not see any man in it with Khushu}}
\hadithdefcmd{tirmidhi}{2654}{حَدَّثَنَا أَبُو الأَشْعَثِ، أَحْمَدُ بْنُ الْمِقْدَامِ الْعِجْلِيُّ الْبَصْرِيُّ حَدَّثَنَا أُمَيَّةُ بْنُ خَالِدٍ، حَدَّثَنَا إِسْحَاقُ بْنُ يَحْيَى بْنِ طَلْحَةَ، حَدَّثَنِي ابْنُ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ طَلَبَ الْعِلْمَ لِيُجَارِيَ بِهِ الْعُلَمَاءَ أَوْ لِيُمَارِيَ بِهِ السُّفَهَاءَ أَوْ يَصْرِفَ بِهِ وُجُوهَ النَّاسِ إِلَيْهِ أَدْخَلَهُ اللَّهُ النَّارَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَإِسْحَاقُ بْنُ يَحْيَى بْنِ طَلْحَةَ لَيْسَ بِذَاكَ الْقَوِيِّ عِنْدَهُمْ تُكُلِّمَ فِيهِ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{2654}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Ka'b bin Malik:from his father that he heard the Messenger of Allah (ﷺ) saying: "Whoever seeks knowledge to contend with the scholars, or to use it to argue with the fools, and to have people's faces turn towards him, then he shall be admitted to the Fire}}
\hadithdefcmd{tirmidhi}{2655}{حَدَّثَنَا عَلِيُّ بْنُ نَصْرِ بْنِ عَلِيٍّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ الْهُنَائِيُّ، حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ أَيُّوبَ السِّخْتِيَانِيِّ، عَنْ خَالِدِ بْنِ دُرَيْكٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَعَلَّمَ عِلْمًا لِغَيْرِ اللَّهِ أَوْ أَرَادَ بِهِ غَيْرَ اللَّهِ فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ أَيُّوبَ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2655}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Umar:that the Prophet (ﷺ) said: "Whoever learns knowledge for other than (the sake of) Allah, or intends by it other than Allah, then let him take his seat in the Fire}}
\hadithdefcmd{tirmidhi}{2656}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، أَخْبَرَنَا عُمَرُ بْنُ سُلَيْمَانَ، مِنْ وَلَدِ عُمَرَ بْنِ الْخَطَّابِ قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ أَبَانَ بْنِ عُثْمَانَ، يُحَدِّثُ عَنْ أَبِيهِ، قَالَ خَرَجَ زَيْدُ بْنُ ثَابِتٍ مِنْ عِنْدِ مَرْوَانَ نِصْفَ النَّهَارِ قُلْنَا مَا بَعَثَ إِلَيْهِ فِي هَذِهِ السَّاعَةِ إِلاَّ لِشَيْءٍ سَأَلَهُ عَنْهُ فَقُمْنَا فَسَأَلْنَاهُ فَقَالَ نَعَمْ سَأَلَنَا عَنْ أَشْيَاءَ سَمِعْنَاهَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ نَضَّرَ اللَّهُ امْرَأً سَمِعَ مِنَّا حَدِيثًا فَحَفِظَهُ حَتَّى يُبَلِّغَهُ غَيْرَهُ فَرُبَّ حَامِلِ فِقْهٍ إِلَى مَنْ هُوَ أَفْقَهُ مِنْهُ وَرُبَّ حَامِلِ فِقْهٍ لَيْسَ بِفَقِيهٍ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَمُعَاذِ بْنِ جَبَلٍ وَجُبَيْرِ بْنِ مُطْعِمٍ وَأَبِي الدَّرْدَاءِ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ زَيْدِ بْنِ ثَابِتٍ حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2656}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Abdur-Rahman bin Aban bin 'Uthman:from his father who said: "Zaid bin Thabit left to go to Marwan during the middle of the day. We said: 'He did not send for him [during] this hour except to ask him about something.' So we got up to ask him, and he said: 'Yes, he asked us about something we heard from the Messenger of Allah (ﷺ). I heard the Messenger of Allah (ﷺ) saying: "May Allah gladden a man who hears a Hadith from us, so he memorizes it until he conveys it to someone else. Perhaps he carries Fiqh to one who is more understanding than him, and perhaps the one who carries the Fiqh is not a Faqih}}
\hadithdefcmd{tirmidhi}{2657}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَنْبَأَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، يُحَدِّثُ عَنْ أَبِيهِ، قَالَ قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ نَضَّرَ اللَّهُ امْرَأً سَمِعَ مِنَّا شَيْئًا فَبَلَّغَهُ كَمَا سَمِعَ فَرُبَّ مُبَلَّغٍ أَوْعَى مِنْ سَامِعٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رَوَاهُ عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ ‏.‏\hadithno{2657}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Simak bin Hard:"I heard 'Abdur-Rahman bin 'Abdullah bin Mas'ud narrating from his father who said: 'I heard the Messenger of Allah (ﷺ) saying: 'May Allah gladden a man who hears something from us, so he conveys it as he heard it. Perhaps the one it is conveyed to is more understanding than the one who heard it}}
\hadithdefcmd{tirmidhi}{2658}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، يُحَدِّثُ عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ نَضَّرَ اللَّهُ امْرَأً سَمِعَ مَقَالَتِي فَوَعَاهَا وَحَفِظَهَا وَبَلَّغَهَا فَرُبَّ حَامِلِ فِقْهٍ إِلَى مَنْ هُوَ أَفْقَهُ مِنْهُ ‏.‏ ثَلاَثٌ لاَ يُغَلُّ عَلَيْهِنَّ قَلْبُ مُسْلِمٍ إِخْلاَصُ الْعَمَلِ لِلَّهِ وَمُنَاصَحَةُ أَئِمَّةِ الْمُسْلِمِينَ وَلُزُومِ جَمَاعَتِهِمْ فَإِنَّ الدَّعْوَةَ تُحِيطُ مِنْ وَرَائِهِمْ ‏"‏ ‏.‏\hadithno{2658}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Abdul-Malik bin 'Umair:from 'Abdur-Rahman bin 'Abdullah bin Mas'ud that he narrated from his father, from the Prophet (ﷺ) who said: "May Allah beautify a man who hears a saying of mine, so he understands it, remembers it, and conveys it. Perhaps he carries the Fiqh to one who has more understanding than him. There are three with which the heart of a Muslim shall not be deceived. Sincerity in deeds for Allah, giving Nasihah to the A'immah of Muslims, and sticking to the Jama'ah. For indeed the call is protected from behind them}}
\hadithdefcmd{tirmidhi}{2659}{حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، حَدَّثَنَا عَاصِمٌ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَذَبَ عَلَىَّ مُتَعَمِّدًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{2659}\hadithgrade{Ahmad Muhammad Shakir: Sahih Mutawatir; Al-Albani: Sahih Mutawatir; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Abdullah [bin Mas'ud]:that the Messenger of Allah (ﷺ) said: "Whoever lies upon me, then let him take his seat in the Fire}}
\hadithdefcmd{tirmidhi}{2660}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى الْفَزَارِيُّ ابْنُ بِنْتِ السُّدِّيِّ، حَدَّثَنَا شَرِيكُ بْنُ عَبْدِ اللَّهِ، عَنْ مَنْصُورِ بْنِ الْمُعْتَمِرِ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَكْذِبُوا عَلَىَّ فَإِنَّهُ مَنْ كَذَبَ عَلَىَّ يَلِجُ فِي النَّارِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ وَالزُّبَيْرِ وَسَعِيدِ بْنِ زَيْدٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَنَسٍ وَجَابِرٍ وَابْنِ عَبَّاسٍ وَأَبِي سَعِيدٍ وَعَمْرِو بْنِ عَبَسَةَ وَعُقْبَةَ بْنِ عَامِرٍ وَمُعَاوِيَةَ وَبُرَيْدَةَ وَأَبِي مُوسَى الْغَافِقِيِّ وَأَبِي أُمَامَةَ وَعَبْدِ اللَّهِ بْنِ عُمَرَ وَالْمُنْقَعِ وَأَوْسٍ الثَّقَفِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ مَنْصُورُ بْنُ الْمُعْتَمِرِ أَثْبَتُ أَهْلِ الْكُوفَةِ ‏.‏ وَقَالَ وَكِيعٌ لَمْ يَكْذِبْ رِبْعِيُّ بْنُ حِرَاشٍ فِي الإِسْلاَمِ كِذْبَةً\hadithno{2660}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated 'Ali bin Abi Talib:that the Messenger of Allah (ﷺ) said: "Do not lie upon me, for indeed whoever lies upon me, he will be admitted into the Fire}}
\hadithdefcmd{tirmidhi}{2661}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَذَبَ عَلَىَّ - حَسِبْتُ أَنَّهُ قَالَ مُتَعَمِّدًا فَلْيَتَبَوَّأْ بَيْتَهُ مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ الزُّهْرِيِّ عَنْ أَنَسٍ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2661}\hadithgrade{Ahmad Muhammad Shakir: Sahih Mutawatir; Al-Albani: Sahih Mutawatir; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas bin Malik:that the Messenger of Allah (ﷺ) said: "Whoever lies upon me" - I think he said - "purposely, then let him take his seat in the Fire}}
\hadithdefcmd{tirmidhi}{2662}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ مَيْمُونِ بْنِ أَبِي شَبِيبٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ حَدَّثَ عَنِّي حَدِيثًا وَهُوَ يَرَى أَنَّهُ كَذِبٌ فَهُوَ أَحَدُ الْكَاذِبِينَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ وَسَمُرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى شُعْبَةُ عَنِ الْحَكَمِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى عَنْ سَمُرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم هَذَا الْحَدِيثَ وَرَوَى الأَعْمَشُ وَابْنُ أَبِي لَيْلَى عَنِ الْحَكَمِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى عَنْ عَلِيٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم وَكَأَنَّ حَدِيثَ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى عَنْ سَمُرَةَ عِنْدَ أَهْلِ الْحَدِيثِ أَصَحُّ ‏.‏ قَالَ سَأَلْتُ أَبَا مُحَمَّدٍ عَبْدَ اللَّهِ بْنَ عَبْدِ الرَّحْمَنِ عَنْ حَدِيثِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ مَنْ حَدَّثَ عَنِّي حَدِيثًا وَهُوَ يَرَى أَنَّهُ كَذِبٌ فَهُوَ أَحَدُ الْكَاذِبِينَ ‏"‏ ‏.‏ قُلْتُ لَهُ مَنْ رَوَى حَدِيثًا وَهُوَ يَعْلَمُ أَنَّ إِسْنَادَهُ خَطَأٌ أَيَخَافُ أَنْ يَكُونَ قَدْ دَخَلَ فِي حَدِيثِ النَّبِيِّ صلى الله عليه وسلم أَوْ إِذَا رَوَى النَّاسُ حَدِيثًا مُرْسَلاً فَأَسْنَدَهُ بَعْضُهُمْ أَوْ قَلَبَ إِسْنَادَهُ يَكُونُ قَدْ دَخَلَ فِي هَذَا الْحَدِيثِ ‏.‏ فَقَالَ لاَ إِنَّمَا مَعْنَى هَذَا الْحَدِيثِ إِذَا رَوَى الرَّجُلُ حَدِيثًا وَلاَ يُعْرَفُ لِذَلِكَ الْحَدِيثِ عَنِ النَّبِيِّ صلى الله عليه وسلم أَصْلٌ فَحَدَّثَ بِهِ فَأَخَافُ أَنْ يَكُونَ قَدْ دَخَلَ فِي هَذَا الْحَدِيثِ ‏.‏\hadithno{2662}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Al-Mughirah bin Shu'bah:that the Prophet (ﷺ) said: "Whoever narrates a Hadith from me which he knows is a lie, then he is one of the liars}}
\hadithdefcmd{tirmidhi}{2663}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، وَسَالِمٍ أَبِي النَّضْرِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ أَبِي رَافِعٍ، وَغَيْرُهُ، رَفَعَهُ قَالَ ‏ "‏ لاَ أُلْفِيَنَّ أَحَدَكُمْ مُتَّكِئًا عَلَى أَرِيكَتِهِ يَأْتِيهِ أَمْرٌ مِمَّا أَمَرْتُ بِهِ أَوْ نَهَيْتُ عَنْهُ فَيَقُولُ لاَ أَدْرِي مَا وَجَدْنَا فِي كِتَابِ اللَّهِ اتَّبَعْنَاهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَرَوَى بَعْضُهُمْ عَنْ سُفْيَانَ عَنِ ابْنِ الْمُنْكَدِرِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً وَسَالِمٍ أَبِي النَّضْرِ عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَكَانَ ابْنُ عُيَيْنَةَ إِذَا رَوَى هَذَا الْحَدِيثَ عَلَى الاِنْفِرَادِ بَيَّنَ حَدِيثَ مُحَمَّدِ بْنِ الْمُنْكَدِرِ مِنْ حَدِيثِ سَالِمٍ أَبِي النَّضْرِ وَإِذَا جَمَعَهُمَا رَوَى هَكَذَا ‏.‏ وَأَبُو رَافِعٍ مَوْلَى النَّبِيِّ صلى الله عليه وسلم اسْمُهُ أَسْلَمُ ‏.‏\hadithno{2663}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated 'Ubaidullah bin Abu Rafi:from Abu Rafi' and others, from the Prophet (ﷺ) who said: "Let me not find one of you reclining on his couch when a command I ordered, or a prohibition from me comes to him, and he says: 'I do not know. What we find in the Book of Allah, we follow it}}
\hadithdefcmd{tirmidhi}{2664}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنِ الْحَسَنِ بْنِ جَابِرٍ اللَّخْمِيِّ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ هَلْ عَسَى رَجُلٌ يَبْلُغُهُ الْحَدِيثُ عَنِّي وَهُوَ مُتَّكِئٌ عَلَى أَرِيكَتِهِ فَيَقُولُ بَيْنَنَا وَبَيْنَكُمْ كِتَابُ اللَّهِ فَمَا وَجَدْنَا فِيهِ حَلاَلاً اسْتَحْلَلْنَاهُ وَمَا وَجَدْنَا فِيهِ حَرَامًا حَرَّمْنَاهُ وَإِنَّ مَا حَرَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم كَمَا حَرَّمَ اللَّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{2664}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Al-Miqdam bin Ma'dikarib:that the Messenger of Allah (ﷺ) said: "Lo! Soon a Hadith from me will be conveyed to a man, while he is reclining on his couch, and he says: 'Between us and you is Allah's Book. So whatever we find in it that is lawful, we consider lawful, and whatever we find in it that is unlawful, we consider it unlawful.' Indeed whatever the Messenger of Allah (ﷺ) made unlawful, it is the same as what Allah made unlawful}}
\hadithdefcmd{tirmidhi}{2665}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ اسْتَأْذَنَّا النَّبِيَّ صلى الله عليه وسلم فِي الْكِتَابَةِ فَلَمْ يَأْذَنْ لَنَا ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ أَيْضًا عَنْ زَيْدِ بْنِ أَسْلَمَ رَوَاهُ هَمَّامٌ عَنْ زَيْدِ بْنِ أَسْلَمَ ‏.‏\hadithno{2665}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Sa'eed Al-Khudri:"We sought permission from the Messenger of Allah (ﷺ) for writing but he did not permit us}}
\hadithdefcmd{tirmidhi}{2666}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ الْخَلِيلِ بْنِ مُرَّةَ، عَنْ يَحْيَى بْنِ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَجُلٌ مِنَ الأَنْصَارِ يَجْلِسُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَيَسْمَعُ مِنَ النَّبِيِّ صلى الله عليه وسلم الْحَدِيثَ فَيُعْجِبُهُ وَلاَ يَحْفَظُهُ فَشَكَا ذَلِكَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَسْمَعُ مِنْكَ الْحَدِيثَ فَيُعْجِبُنِي وَلاَ أَحْفَظُهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اسْتَعِنْ بِيَمِينِكَ ‏"‏ ‏.‏ وَأَوْمَأَ بِيَدِهِ لِلْخَطِّ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ إِسْنَادُهُ لَيْسَ بِذَلِكَ الْقَائِمِ ‏.‏ وَسَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ الْخَلِيلُ بْنُ مُرَّةَ مُنْكَرُ الْحَدِيثِ ‏.‏\hadithno{2666}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:"There was a man among the Ansar who would sit with the Messenger of Allah (ﷺ), and he would listen to the Ahadith of the Prophet (ﷺ) and he was amazed with them but he could not remember them. So he complained about that to the Messenger of Allah (ﷺ). He said: 'O Messenger of Allah! I listen to your Ahadith and I am amazed but I can not remember them.' So the Messenger of Allah (ﷺ) said: 'Help yourself with your right hand' and he motioned with his hand as if writing}}
\hadithdefcmd{tirmidhi}{2667}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالاَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَطَبَ فَذَكَرَ الْقِصَّةَ فِي الْحَدِيثِ ‏.‏ قَالَ أَبُو شَاهٍ اكْتُبُوا لِي يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اكْتُبُوا لأَبِي شَاهٍ ‏"‏ ‏.‏ وَفِي الْحَدِيثِ قِصَّةٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى شَيْبَانُ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ مِثْلَ هَذَا ‏.‏\hadithno{2667}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah:That the Messenger of Allah (ﷺ) gave an address. So he mentioned a story in the Hadith, and Abu Shah said: 'Have it written for me O Messenger of Allah! So the Messenger of Allah (ﷺ) said: 'Write it for Abu Shah}}
\hadithdefcmd{tirmidhi}{2668}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ وَهْبِ بْنِ مُنَبِّهٍ، عَنْ أَخِيهِ، وَهُوَ هَمَّامُ بْنُ مُنَبِّهٍ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ لَيْسَ أَحَدٌ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَكْثَرَ حَدِيثًا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنِّي إِلاَّ عَبْدُ اللَّهِ بْنُ عَمْرٍو فَإِنَّهُ كَانَ يَكْتُبُ وَكُنْتُ لاَ أَكْتُبُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَوَهْبُ بْنُ مُنَبِّهٍ عَنْ أَخِيهِ هُوَ هَمَّامُ بْنُ مُنَبِّهٍ ‏.‏\hadithno{2668}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Hammam bin Munabbih:that the heard Abu Hurairah say: "None of the Companions of the Messenger of Allah (ﷺ) narrated more Ahadith from him than me, except 'Abdullah bin 'Amr. For he used to write them down and I did not write}}
\hadithdefcmd{tirmidhi}{2669}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنِ ابْنِ ثَوْبَانَ، هُوَ عَبْدُ الرَّحْمَنِ بْنُ ثَابِتِ بْنِ ثَوْبَانَ عَنْ حَسَّانَ بْنِ عَطِيَّةَ، عَنْ أَبِي كَبْشَةَ السَّلُولِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَلِّغُوا عَنِّي وَلَوْ آيَةً وَحَدِّثُوا عَنْ بَنِي إِسْرَائِيلَ وَلاَ حَرَجَ وَمَنْ كَذَبَ عَلَىَّ مُتَعَمِّدًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ الأَوْزَاعِيِّ، عَنْ حَسَّانَ بْنِ عَطِيَّةَ، عَنْ أَبِي كَبْشَةَ السَّلُولِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ وَهَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2669}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated 'Abdullah bin 'Amr:that the Messenger of Allah (ﷺ) said: "Convey from me, even if it be an Ayah, and narrate from the Children of Isra'il, and there is no harm, And whoever lies upon me purposely, then let him take his seat in the Fire}}
\hadithdefcmd{tirmidhi}{2670}{حَدَّثَنَا نَصْرُ بْنُ عَبْدِ الرَّحْمَنِ الْكُوفِيُّ، حَدَّثَنَا أَحْمَدُ بْنُ بَشِيرٍ، عَنْ شَبِيبِ بْنِ بِشْرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَتَى النَّبِيَّ صلى الله عليه وسلم رَجُلٌ يَسْتَحْمِلُهُ فَلَمْ يَجِدْ عِنْدَهُ مَا يَتَحَمَّلُهُ فَدَلَّهُ عَلَى آخَرَ فَحَمَلَهُ ‏.‏ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرَهُ فَقَالَ ‏ "‏ إِنَّ الدَّالَّ عَلَى الْخَيْرِ كَفَاعِلِهِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي مَسْعُودٍ الْبَدْرِيِّ وَبُرَيْدَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2670}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas bin Malik:"A man came to the Prophet (ﷺ) to get a mount, but he (ﷺ) did not have anything to mount him on with him. So he was lead to another person to give him a mount. He came to the Prophet (ﷺ) to inform him about that and he said: 'Whoever leads to good, he is like the one who does it}}
\hadithdefcmd{tirmidhi}{2671}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَنْبَأَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ أَبَا عَمْرٍو الشَّيْبَانِيَّ، يُحَدِّثُ عَنْ أَبِي مَسْعُودٍ الْبَدْرِيِّ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم يَسْتَحْمِلُهُ فَقَالَ إِنَّهُ قَدْ أُبْدِعَ بِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ائْتِ فُلاَنًا ‏"‏ ‏.‏ فَأَتَاهُ فَحَمَلَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ دَلَّ عَلَى خَيْرٍ فَلَهُ مِثْلُ أَجْرِ فَاعِلِهِ أَوْ قَالَ عَامِلِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَأَبُو عَمْرٍو الشَّيْبَانِيُّ اسْمُهُ سَعْدُ بْنُ إِيَاسٍ وَأَبُو مَسْعُودٍ الْبَدْرِيُّ اسْمُهُ عُقْبَةُ بْنُ عَمْرٍو ‏.‏ حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي عَمْرٍو الشَّيْبَانِيِّ، عَنْ أَبِي مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَقَالَ ‏"‏ مِثْلُ أَجْرِ فَاعِلِهِ ‏"‏ ‏.‏ وَلَمْ يَشُكَّ فِيهِ ‏.‏\hadithno{2671}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Mas'ud Al-Badri:that a man came to the Prophet (ﷺ) looking for a mount, he said: 'Mine has been ruined.' So the Messenger of Allah (ﷺ) said: 'Go to so-and-so.' So he went to him and he gave him a mount. The Messenger of Allah (ﷺ) said: 'Whoever leads to good, then for him is the same reward as the one who does it - or - who acts upon it}}
\hadithdefcmd{tirmidhi}{2672}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، وَالْحَسَنُ بْنُ عَلِيٍّ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ، عَنْ جَدِّهِ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اشْفَعُوا وَلْتُؤْجَرُوا وَلْيَقْضِ اللَّهُ عَلَى لِسَانِ نَبِيِّهِ مَا شَاءَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَبُرَيْدٌ يُكْنَى أَبَا بُرْدَةَ أَيْضًا وَهُوَ كُوفِيٌّ ثِقَةٌ فِي الْحَدِيثِ رَوَى عَنْهُ شُعْبَةُ وَالثَّوْرِيُّ وَابْنُ عُيَيْنَةَ ‏.‏\hadithno{2672}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Musa Al-Ash'ari:that the Prophet (ﷺ) said: "Intercede, and you will be rewarded, and Allah will fulfill what He wills upon the tongue of His Prophet}}
\hadithdefcmd{tirmidhi}{2673}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، وَعَبْدُ الرَّزَّاقِ، عَنْ سُفْيَانَ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ نَفْسٍ تُقْتَلُ ظُلْمًا إِلاَّ كَانَ عَلَى ابْنِ آدَمَ كِفْلٌ مِنْ دَمِهَا وَذَلِكَ لأَنَّهُ أَوَّلُ مَنْ أَسَنَّ الْقَتْلَ ‏"‏ ‏.‏ وَقَالَ عَبْدُ الرَّزَّاقِ ‏"‏ سَنَّ الْقَتْلَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ نَحْوَهُ بِمَعْنَاهُ قَالَ ‏"‏ سَنَّ الْقَتْلَ ‏"‏ ‏.‏\hadithno{2673}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Abdullah bin Mas'ud:that the Messenger of Allah (ﷺ) said: "No soul is wrongfully taken except that some of the burden of its blood is upon the son of Adam, because he was the first to institute murder}}
\hadithdefcmd{tirmidhi}{2674}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ دَعَا إِلَى هُدًى كَانَ لَهُ مِنَ الأَجْرِ مِثْلُ أُجُورِ مَنْ يَتَّبِعُهُ لاَ يَنْقُصُ ذَلِكَ مِنْ أُجُورِهِمْ شَيْئًا وَمَنْ دَعَا إِلَى ضَلاَلَةٍ كَانَ عَلَيْهِ مِنَ الإِثْمِ مِثْلُ آثَامِ مَنْ يَتَّبِعُهُ لاَ يَنْقُصُ ذَلِكَ مِنْ آثَامِهِمْ شَيْئًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2674}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Whoever calls to guidance, then he receives the reward similar to the reward of whoever follows him, without that diminishing anything from their rewards. And whoever calls to misguidance, then he receives of sin similar to the sins of those who followed him, without that diminishing anything from their sins}}
\hadithdefcmd{tirmidhi}{2675}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا الْمَسْعُودِيُّ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنِ ابْنِ جَرِيرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَنَّ سُنَّةَ خَيْرٍ فَاتُّبِعَ عَلَيْهَا فَلَهُ أَجْرُهُ وَمِثْلُ أُجُورِ مَنِ اتَّبَعَهُ غَيْرَ مَنْقُوصٍ مِنْ أُجُورِهِمْ شَيْئًا وَمَنْ سَنَّ سُنَّةَ شَرٍّ فَاتُّبِعَ عَلَيْهَا كَانَ عَلَيْهِ وِزْرُهُ وَمِثْلُ أَوْزَارِ مَنِ اتَّبَعَهُ غَيْرَ مَنْقُوصٍ مِنْ أَوْزَارِهِمْ شَيْئًا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ حُذَيْفَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوُ هَذَا ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنِ الْمُنْذِرِ بْنِ جَرِيرِ بْنِ عَبْدِ اللَّهِ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَقَدْ رُوِيَ عَنْ عُبَيْدِ اللَّهِ بْنِ جَرِيرٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم أَيْضًا ‏.‏\hadithno{2675}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ibn Jarir bin 'Abdullah:from his father that the Messenger of Allah (ﷺ) said: "Whoever starts a good tradition which is followed, then for him is a reward, and the likes of their rewards of whoever follows him, there being nothing diminished from their rewards. And whoever starts a bad tradition which is followed, then for him is the sin, and the likes of the sins of whoever follows him, there being nothing diminished from their sins}}
\hadithdefcmd{tirmidhi}{2676}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَمْرٍو السُّلَمِيِّ، عَنِ الْعِرْبَاضِ بْنِ سَارِيَةَ، قَالَ وَعَظَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا بَعْدَ صَلاَةِ الْغَدَاةِ مَوْعِظَةً بَلِيغَةً ذَرَفَتْ مِنْهَا الْعُيُونُ وَوَجِلَتْ مِنْهَا الْقُلُوبُ فَقَالَ رَجُلٌ إِنَّ هَذِهِ مَوْعِظَةُ مُوَدِّعٍ فَمَاذَا تَعْهَدُ إِلَيْنَا يَا رَسُولَ اللَّهِ قَالَ ‏ "‏ أُوصِيكُمْ بِتَقْوَى اللَّهِ وَالسَّمْعِ وَالطَّاعَةِ وَإِنْ عَبْدٌ حَبَشِيٌّ فَإِنَّهُ مَنْ يَعِشْ مِنْكُمْ يَرَى اخْتِلاَفًا كَثِيرًا وَإِيَّاكُمْ وَمُحْدَثَاتِ الأُمُورِ فَإِنَّهَا ضَلاَلَةٌ فَمَنْ أَدْرَكَ ذَلِكَ مِنْكُمْ فَعَلَيْهِ بِسُنَّتِي وَسُنَّةِ الْخُلَفَاءِ الرَّاشِدِينَ الْمَهْدِيِّينَ عَضُّوا عَلَيْهَا بِالنَّوَاجِذِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى ثَوْرُ بْنُ يَزِيدَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَمْرٍو السُّلَمِيِّ، عَنِ الْعِرْبَاضِ بْنِ سَارِيَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا ‏.‏ حَدَّثَنَا بِذَلِكَ الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ وَغَيْرُ وَاحِدٍ قَالُوا حَدَّثَنَا أَبُو عَاصِمٍ عَنْ ثَوْرِ بْنِ يَزِيدَ عَنْ خَالِدِ بْنِ مَعْدَانَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَمْرٍو السُّلَمِيِّ عَنِ الْعِرْبَاضِ بْنِ سَارِيَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَالْعِرْبَاضُ بْنُ سَارِيَةَ يُكْنَى أَبَا نَجِيحٍ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ حُجْرِ بْنِ حُجْرٍ عَنْ عِرْبَاضِ بْنِ سَارِيَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2676}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Al-'Irbad bin Sariyah:"One day after the morning Salat, the Messenger of Allah (ﷺ) exhorted us to the extent that the eyes wept and the hearts shuddered with fear. A man said: 'Indeed this is a farewell exhortation. [So what] do you order us O Messenger of Allah?' He said: 'I order you to have Taqwa of Allah, and to listen and obey, even in the case of an Ethiopian slave. Indeed, whomever among you lives, he will see much difference. Beware of the newly invented matters, for indeed they are astray. Whoever among you sees that, then he must stick to my Sunnah and the Sunnah of the rightly guided Khulafa', cling to it with the molars}}
\hadithdefcmd{tirmidhi}{2677}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا مُحَمَّدُ بْنُ عُيَيْنَةَ، عَنْ مَرْوَانَ بْنِ مُعَاوِيَةَ الْفَزَارِيِّ، عَنْ كَثِيرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِبِلاَلِ بْنِ الْحَارِثِ ‏"‏ اعْلَمْ ‏"‏ ‏.‏ قَالَ مَا أَعْلَمُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ اعْلَمْ يَا بِلاَلُ ‏"‏ ‏.‏ قَالَ مَا أَعْلَمُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أَنَّهُ مَنْ أَحْيَا سُنَّةً مِنْ سُنَّتِي قَدْ أُمِيتَتْ بَعْدِي فَإِنَّ لَهُ مِنَ الأَجْرِ مِثْلَ مَنْ عَمِلَ بِهَا مِنْ غَيْرِ أَنْ يَنْقُصَ مِنْ أُجُورِهِمْ شَيْئًا وَمَنِ ابْتَدَعَ بِدْعَةَ ضَلاَلَةٍ لاَ يَرْضَاهَا اللَّهُ وَرَسُولُهُ كَانَ عَلَيْهِ مِثْلُ آثَامِ مَنْ عَمِلَ بِهَا لاَ يَنْقُصُ ذَلِكَ مِنْ أَوْزَارِ النَّاسِ شَيْئًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَمُحَمَّدُ بْنُ عُيَيْنَةَ هُوَ مِصِّيصِيٌّ شَامِيٌّ وَكَثِيرُ بْنُ عَبْدِ اللَّهِ هُوَ ابْنُ عَمْرِو بْنِ عَوْفٍ الْمُزَنِيُّ ‏.‏\hadithno{2677}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Narrated Kathir bin 'Abdullah [and he is Ibn 'Amr bin 'Awf Al-Musani]:narrated from his father, from his grandfather that the Prophet (ﷺ) said to Bilal bin Al-Harith: "Know." He said: "I am ready to know O Messenger of Allah!" He (ﷺ) said: "That indeed whoever revives a Sunnah from my Sunnah which has died after me, then for him is a reward similar to whoever acts upon it without diminishing anything from their rewards. And whoever introduces an erroneous innovation which Allah is not pleased with, nor His Messenger, then he shall receive sins similar to whoever acts upon it, without that diminishing anything from the sins of the people}}
\hadithdefcmd{tirmidhi}{2678}{حَدَّثَنَا مُسْلِمُ بْنُ حَاتِمٍ الأَنْصَارِيُّ الْبَصْرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ قَالَ أَنَسُ بْنُ مَالِكٍ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا بُنَىَّ إِنْ قَدَرْتَ أَنْ تُصْبِحَ وَتُمْسِيَ لَيْسَ فِي قَلْبِكَ غِشٌّ لأَحَدٍ فَافْعَلْ ‏"‏ ‏.‏ ثُمَّ قَالَ لِي ‏"‏ يَا بُنَىَّ وَذَلِكَ مِنْ سُنَّتِي وَمَنْ أَحْيَا سُنَّتِي فَقَدْ أَحَبَّنِي ‏.‏ وَمَنْ أَحَبَّنِي كَانَ مَعِي فِي الْجَنَّةِ ‏"‏ ‏.‏ وَفِي الْحَدِيثِ قِصَّةٌ طَوِيلَةٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ ثِقَةٌ وَأَبُوهُ ثِقَةٌ وَعَلِيُّ بْنُ زَيْدٍ صَدُوقٌ إِلاَّ أَنَّهُ رُبَّمَا يَرْفَعُ الشَّىْءَ الَّذِي يُوقِفُهُ غَيْرُهُ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدَ بْنَ بَشَّارٍ يَقُولُ قَالَ أَبُو الْوَلِيدِ قَالَ شُعْبَةُ حَدَّثَنَا عَلِيُّ بْنُ زَيْدٍ وَكَانَ رَفَّاعًا وَلاَ نَعْرِفُ لِسَعِيدِ بْنِ الْمُسَيَّبِ عَنْ أَنَسٍ رِوَايَةً إِلاَّ هَذَا الْحَدِيثَ بِطُولِهِ ‏.‏ وَقَدْ رَوَى عَبَّادُ بْنُ مَيْسَرَةَ الْمِنْقَرِيُّ هَذَا الْحَدِيثَ عَنْ عَلِيِّ بْنِ زَيْدٍ عَنْ أَنَسٍ وَلَمْ يَذْكُرْ فِيهِ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ ‏.‏ قَالَ أَبُو عِيسَى وَذَاكَرْتُ بِهِ مُحَمَّدَ بْنَ إِسْمَاعِيلَ فَلَمْ يَعْرِفْهُ وَلَمْ يُعْرَفْ لِسَعِيدِ بْنِ الْمُسَيَّبِ عَنْ أَنَسٍ هَذَا الْحَدِيثُ وَلاَ غَيْرُهُ وَمَاتَ أَنَسُ بْنُ مَالِكٍ سَنَةَ ثَلاَثٍ وَتِسْعِينَ وَمَاتَ سَعِيدُ بْنُ الْمُسَيَّبِ بَعْدَهُ بِسَنَتَيْنِ مَاتَ سَنَةَ خَمْسٍ وَتِسْعِينَ ‏.‏\hadithno{2678}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas bin Malik:"The Messenger of Allah (ﷺ) said to me: 'O my son! If you are capable of (waking up in) the morning and (ending) the evening, while there is nothing of deception in your heart for anything, then do so.' Then he said to me: 'O my son! That is from my Sunnah. Whoever revives my Sunnah then he has loved me. And whoever loved me, he shall be with me in Paradise}}
\hadithdefcmd{tirmidhi}{2679}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اتْرُكُونِي مَا تَرَكْتُكُمْ فَإِذَا حَدَّثْتُكُمْ فَخُذُوا عَنِّي فَإِنَّمَا هَلَكَ مَنْ كَانَ قَبْلَكُمْ بِكَثْرَةِ سُؤَالِهِمْ وَاخْتِلاَفِهِمْ عَلَى أَنْبِيَائِهِمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2679}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Leave me with what I left you. When I narrated a Hadith to you, then take it from me. The people before you were only destroyed by their excessive questioning and disagreeing with their Prophets}}
\hadithdefcmd{tirmidhi}{2680}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ الْبَزَّارُ، وَإِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، رِوَايَةً ‏ "‏ يُوشِكُ أَنْ يَضْرِبَ النَّاسُ، أَكْبَادَ الإِبِلِ يَطْلُبُونَ الْعِلْمَ فَلاَ يَجِدُونَ أَحَدًا أَعْلَمَ مِنْ عَالِمِ الْمَدِينَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَهُوَ حَدِيثُ ابْنِ عُيَيْنَةَ ‏.‏ وَقَدْ رُوِيَ عَنِ ابْنِ عُيَيْنَةَ أَنَّهُ قَالَ فِي هَذَا سُئِلَ مَنْ عَالِمُ الْمَدِينَةِ فَقَالَ إِنَّهُ مَالِكُ بْنُ أَنَسٍ ‏.‏ وَقَالَ إِسْحَاقُ بْنُ مُوسَى سَمِعْتُ ابْنَ عُيَيْنَةَ يَقُولُ هُوَ الْعُمَرِيُّ عَبْدُ اللَّهِ بْنُ عَبْدِ الْعَزِيزَ الزَّاهِدُ ‏.‏ وَسَمِعْتُ يَحْيَى بْنَ مُوسَى يَقُولُ قَالَ عَبْدُ الرَّزَّاقِ هُوَ مَالِكُ بْنُ أَنَسٍ ‏.‏ وَالْعُمَرِيُّ هُوَ عَبْدُ اللَّهِ بْنُ عَبْدِ الْعَزِيزِ مِنْ وَلَدِ عُمَرَ بْنِ الْخَطَّابِ ‏.‏\hadithno{2680}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Salih reported a narration from Abu Hurairah:"It shall soon be that people are beating the livers of camels (meaning that they are hastening and traveling upon them) seeking knowledge. But they will not find anyone more knowledgeable than a scholar of Al-Madinah}}
\hadithdefcmd{tirmidhi}{2681}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا رَوْحُ بْنُ جَنَاحٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَقِيهٌ أَشَدُّ عَلَى الشَّيْطَانِ مِنْ أَلْفِ عَابِدٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ الْوَلِيدِ بْنِ مُسْلِمٍ ‏.‏\hadithno{2681}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:that the Messenger of Allah (ﷺ) said: "The Faqih is harder on Ash-Shaitan than a thousand worshipers}}
\hadithdefcmd{tirmidhi}{2682}{حَدَّثَنَا مَحْمُودُ بْنُ خِدَاشٍ الْبَغْدَادِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ يَزِيدَ الْوَاسِطِيُّ، حَدَّثَنَا عَاصِمُ بْنُ رَجَاءِ بْنِ حَيْوَةَ، عَنْ قَيْسِ بْنِ كَثِيرٍ، قَالَ قَدِمَ رَجُلٌ مِنَ الْمَدِينَةِ عَلَى أَبِي الدَّرْدَاءِ وَهُوَ بِدِمَشْقَ فَقَالَ مَا أَقْدَمَكَ يَا أَخِي فَقَالَ حَدِيثٌ بَلَغَنِي أَنَّكَ تُحَدِّثُهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ أَمَا جِئْتَ لِحَاجَةٍ قَالَ لاَ ‏.‏ قَالَ أَمَا قَدِمْتَ لِتِجَارَةٍ قَالَ لاَ ‏.‏ قَالَ مَا جِئْتَ إِلاَّ فِي طَلَبِ هَذَا الْحَدِيثِ قَالَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ سَلَكَ طَرِيقًا يَبْتَغِي فِيهِ عِلْمًا سَلَكَ اللَّهُ بِهِ طَرِيقًا إِلَى الْجَنَّةِ وَإِنَّ الْمَلاَئِكَةَ لَتَضَعُ أَجْنِحَتَهَا رِضًا لِطَالِبِ الْعِلْمِ وَإِنَّ الْعَالِمَ لَيَسْتَغْفِرُ لَهُ مَنْ فِي السَّمَوَاتِ وَمَنْ فِي الأَرْضِ حَتَّى الْحِيتَانُ فِي الْمَاءِ وَفَضْلُ الْعَالِمِ عَلَى الْعَابِدِ كَفَضْلِ الْقَمَرِ عَلَى سَائِرِ الْكَوَاكِبِ إِنَّ الْعُلَمَاءَ وَرَثَةُ الأَنْبِيَاءِ إِنَّ الأَنْبِيَاءَ لَمْ يُوَرِّثُوا دِينَارًا وَلاَ دِرْهَمًا إِنَّمَا وَرَّثُوا الْعِلْمَ فَمَنْ أَخَذَ بِهِ أَخَذَ بِحَظٍّ وَافِرٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَلاَ نَعْرِفُ هَذَا الْحَدِيثَ إِلاَّ مِنْ حَدِيثِ عَاصِمِ بْنِ رَجَاءِ بْنِ حَيْوَةَ وَلَيْسَ هُوَ عِنْدِي بِمُتَّصِلٍ هَكَذَا حَدَّثَنَا مَحْمُودُ بْنُ خِدَاشٍ بِهَذَا الإِسْنَادِ ‏.‏ وَإِنَّمَا يُرْوَى هَذَا الْحَدِيثُ عَنْ عَاصِمِ بْنِ رَجَاءِ بْنِ حَيْوَةَ عَنِ الْوَلِيدِ بْنِ جَمِيلٍ عَنْ كَثِيرِ بْنِ قَيْسٍ عَنْ أَبِي الدَّرْدَاءِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَهَذَا أَصَحُّ مِنْ حَدِيثِ مَحْمُودِ بْنِ خِدَاشٍ وَرَأَى مُحَمَّدُ بْنُ إِسْمَاعِيلَ هَذَا أَصَحَّ ‏.‏\hadithno{2682}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qais bin Kathir:"A man from Al-Madinah came to Abu Ad-Darda when he was in Dimashq. So he said: 'What brings you O my nephew?' He replied: 'A Hadith reached me which you have narrated from the Messenger of Allah (ﷺ).' He said: 'You did not come for some need?' He said: 'No.' He said: 'Did you come for trade?' He said: 'No, I did not come except seeking this Hadith.' So he said: 'Indeed, I heard the Messenger of Allah (ﷺ) saying: "Whoever takes a path upon which he seeks knowledge, then Allah makes a path to Paradise easy for him. And indeed the angels lower their wings in approval to the one seeking knowledge. Indeed forgiveness is sought for the knowledgeable one by whomever is in the heavens and whomever is in the earth, even the fish in the waters. And superiority of the scholar over the worshiper is like the superiority of the moon over the rest of the celestial bodies. Indeed the scholars are the heirs of the Prophets, and the Prophets do not leave behind Dinar or Dirham. The only legacy of the scholars is knowledge, so whoever takes from it, then he has indeed taken the most able share}}
\hadithdefcmd{tirmidhi}{2683}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنِ ابْنِ أَشْوَعَ، عَنْ يَزِيدَ بْنِ سَلَمَةَ الْجُعْفِيِّ، قَالَ قَالَ يَزِيدُ بْنُ سَلَمَةَ يَا رَسُولَ اللَّهِ إِنِّي قَدْ سَمِعْتُ مِنْكَ، حَدِيثًا كَثِيرًا أَخَافُ أَنْ يُنْسِيَنِي، أَوَّلَهُ آخِرُهُ فَحَدِّثْنِي بِكَلِمَةٍ تَكُونُ جِمَاعًا ‏.‏ قَالَ ‏ "‏ اتَّقِ اللَّهَ فِيمَا تَعْلَمُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لَيْسَ إِسْنَادُهُ بِمُتَّصِلٍ وَهُوَ عِنْدِي مُرْسَلٌ ‏.‏ وَلَمْ يُدْرِكْ عِنْدِي ابْنُ أَشْوَعَ يَزِيدَ بْنَ سَلَمَةَ وَابْنُ أَشْوَعَ اسْمُهُ سَعِيدُ بْنُ أَشْوَعَ ‏.‏\hadithno{2683}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Ashwa:from Yazid bin Salamah Al-Ju'fi, he said: "Yazid bin Salamah 'O Messenger of Allah! I heard so many narrations from you that I am afraid the last of them will cause me to forget the first of them. So narrate a statement to me that will encompass them.' So he said: 'Have Taqwa of Allah with what you learn}}
\hadithdefcmd{tirmidhi}{2684}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا خَلَفُ بْنُ أَيُّوبَ الْعَامِرِيُّ، عَنْ عَوْفٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَصْلَتَانِ لاَ تَجْتَمِعَانِ فِي مُنَافِقٍ حُسْنُ سَمْتٍ وَلاَ فِقْهٌ فِي الدِّينِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَلاَ نَعْرِفُ هَذَا الْحَدِيثَ مِنْ حَدِيثِ عَوْفٍ إِلاَّ مِنْ حَدِيثِ هَذَا الشَّيْخِ خَلَفِ بْنِ أَيُّوبَ الْعَامِرِيِّ وَلَمْ أَرَ أَحَدًا يَرْوِي عَنْهُ غَيْرَ أَبِي كُرَيْبٍ مُحَمَّدِ بْنِ الْعَلاَءِ وَلاَ أَدْرِي كَيْفَ هُوَ\hadithno{2684}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "Two things will not be together in a hypocrite: Good manners, and Fiqh in the religion}}
\hadithdefcmd{tirmidhi}{2685}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا سَلَمَةُ بْنُ رَجَاءٍ، حَدَّثَنَا الْوَلِيدُ بْنُ جَمِيلٍ، حَدَّثَنَا الْقَاسِمُ أَبُو عَبْدِ الرَّحْمَنِ، عَنْ أَبِي أُمَامَةَ الْبَاهِلِيِّ، قَالَ ذُكِرَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم رَجُلاَنِ أَحَدُهُمَا عَابِدٌ وَالآخَرُ عَالِمٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَضْلُ الْعَالِمِ عَلَى الْعَابِدِ كَفَضْلِي عَلَى أَدْنَاكُمْ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ وَمَلاَئِكَتَهُ وَأَهْلَ السَّمَوَاتِ وَالأَرْضِ حَتَّى النَّمْلَةَ فِي جُحْرِهَا وَحَتَّى الْحُوتَ لَيُصَلُّونَ عَلَى مُعَلِّمِ النَّاسِ الْخَيْرَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ قَالَ سَمِعْتُ أَبَا عَمَّارٍ الْحُسَيْنَ بْنَ حُرَيْثٍ الْخُزَاعِيَّ يَقُولُ سَمِعْتُ الْفُضَيْلَ بْنَ عِيَاضٍ يَقُولُ عَالِمٌ عَامِلٌ مُعَلِّمٌ يُدْعَى كَبِيرًا فِي مَلَكُوتِ السَّمَوَاتِ ‏.‏\hadithno{2685}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Umamah Al-Bahili:"Two men were mentioned before the Messenger of Allah (ﷺ). One of them a worshiper, and the other a scholar. So the Messenger of Allah (ﷺ) said: 'The superiority of the scholar over the worshiper is like my superiority over the least of you.' Then the Messenger of Allah (ﷺ) said: 'Indeed Allah, His Angels, the inhabitants of the heavens and the earths - even the ant in his hole, even the fish - say Salat upon the one who teaches the people to do good}}
\hadithdefcmd{tirmidhi}{2686}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ الشَّيْبَانِيُّ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ دَرَّاجٍ، عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَنْ يَشْبَعَ الْمُؤْمِنُ مِنْ خَيْرٍ يَسْمَعُهُ حَتَّى يَكُونَ مُنْتَهَاهُ الْجَنَّةُ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2686}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Sa'eed Al-Khudri:that the Messenger of Allah (ﷺ) said: "The believer will never be satisfied with the good he hears, until he ends up in Paradise}}
\hadithdefcmd{tirmidhi}{2687}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ الْوَلِيدِ الْكِنْدِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ إِبْرَاهِيمَ بْنِ الْفَضْلِ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْكَلِمَةُ الْحِكْمَةُ ضَالَّةُ الْمُؤْمِنِ فَحَيْثُ وَجَدَهَا فَهُوَ أَحَقُّ بِهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَإِبْرَاهِيمُ بْنُ الْفَضْلِ الْمَدَنِيُّ الْمَخْزُومِيُّ يُضَعَّفُ فِي الْحَدِيثِ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{2687}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah:that the Messenger of Allah (ﷺ) said: "The wise statement is the lost property of the believer, so wherever he finds it, then he is more worthy of it}}
