% Auto-generated chapter 7 for malik
% Hadiths in this chapter: 33

\hadithdefcmd{malik}{254}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ رَجُلٍ، عِنْدَهُ رِضًا أَنَّهُ أَخْبَرَهُ أَنَّ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنِ امْرِئٍ تَكُونُ لَهُ صَلاَةٌ بِلَيْلٍ يَغْلِبُهُ عَلَيْهَا نَوْمٌ إِلاَّ كَتَبَ اللَّهُ لَهُ أَجْرَ صَلاَتِهِ وَكَانَ نَوْمُهُ عَلَيْهِ صَدَقَةً ‏"‏ ‏.‏\hadithno{254}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Muhammad ibn al-Munkadir from Said ibn al-Jubayr that a man who has approval (as a relater of hadith), told him that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "If a man prays in the night and sleep overcomes him during it, Allah writes for him the reward of his prayer, and his sleep is sadaqa for him}}
\hadithdefcmd{malik}{255}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كُنْتُ أَنَامُ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَرِجْلاَىَ فِي قِبْلَتِهِ فَإِذَا سَجَدَ غَمَزَنِي فَقَبَضْتُ رِجْلَىَّ فَإِذَا قَامَ بَسَطْتُهُمَا ‏.‏ قَالَتْ وَالْبُيُوتُ يَوْمَئِذٍ لَيْسَ فِيهَا مَصَابِيحُ ‏.‏\hadithno{255}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'nNadr, the mawla of Umar ibn 'Ubaydullah, from Abu Salama ibn Abd ar-Rahman that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "I was sleeping in front of the Messenger of Allah, may Allah bless him and grant him peace, and my feet were in his qibla. When he prostrated, he nudged me and I pulled up my feet,and when he stood up I spread them out." She added, "There were no lamps in the house at that time}}
\hadithdefcmd{malik}{256}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نَعَسَ أَحَدُكُمْ فِي صَلاَتِهِ فَلْيَرْقُدْ حَتَّى يَذْهَبَ عَنْهُ النَّوْمُ فَإِنَّ أَحَدَكُمْ إِذَا صَلَّى وَهُوَ نَاعِسٌ لاَ يَدْرِي لَعَلَّهُ يَذْهَبُ يَسْتَغْفِرُ فَيَسُبُّ نَفْسَهُ ‏"‏ ‏.‏\hadithno{256}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father from A'isha, the wife of the Prophet, may Allah bless him and grant him peace, that the Messenger of Allah, may Allah bless him and grant him peace, said, "If you are drowsy in prayer, sleep until sleep leaves you, because if you pray while you are drowsy, you do not know whether you may intend to ask for forgiveness but (in fact) ask for harm}}
\hadithdefcmd{malik}{257}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي حَكِيمٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَمِعَ امْرَأَةً مِنَ اللَّيْلِ تُصَلِّي فَقَالَ ‏"‏ مَنْ هَذِهِ ‏"‏ ‏.‏ فَقِيلَ لَهُ هَذِهِ الْحَوْلاَءُ بِنْتُ تُوَيْتٍ لاَ تَنَامُ اللَّيْلَ ‏.‏ فَكَرِهَ ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى عُرِفَتِ الْكَرَاهِيَةُ فِي وَجْهِهِ ثُمَّ قَالَ ‏"‏ إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى لاَ يَمَلُّ حَتَّى تَمَلُّوا اكْلَفُوا مِنَ الْعَمَلِ مَا لَكُمْ بِهِ طَاقَةٌ ‏"‏ ‏.‏\hadithno{257}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Ismail from Ibn Abi Hakim that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, heard a woman praying at night. He said, "Who is that?" and someone said to him,"It is al-Hawla bint Tuwayt, she does not sleep in the night." The Messenger of Allah, may Allah bless him and grant him peace, disapproved of that and his disapproval showed in his face. Then he said, "Allah, the Blessed and Exalted, does not become weary, but you become weary. Take on whatever is within your capability}}
\hadithdefcmd{malik}{258}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ يُصَلِّي مِنَ اللَّيْلِ مَا شَاءَ اللَّهُ حَتَّى إِذَا كَانَ مِنْ آخِرِ اللَّيْلِ أَيْقَظَ أَهْلَهُ لِلصَّلاَةِ يَقُولُ لَهُمُ الصَّلاَةَ الصَّلاَةَ ثُمَّ يَتْلُو هَذِهِ الآيَةَ ‏\{‏وَأْمُرْ أَهْلَكَ بِالصَّلاَةِ وَاصْطَبِرْ عَلَيْهَا لاَ نَسْأَلُكَ رِزْقًا نَحْنُ نَرْزُقُكَ وَالْعَاقِبَةُ لِلتَّقْوَى‏\}‏\hadithno{258}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from his father that Umar ibn al-Khattab used to pray as much as Allah willed in the night until at the end of the night he would wake his family for the prayer. He used to say to them, "The prayer, the prayer." Then he would recite the ayat, "Enjoin prayer on your family and be constant in it. We do not ask you for your provision. We provide for you. And the end result is for taqwa." (Sura 20 ayat)}}
\hadithdefcmd{malik}{259}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، كَانَ يَقُولُ يُكْرَهُ النَّوْمُ قَبْلَ الْعِشَاءِ وَالْحَدِيثُ بَعْدَهَا ‏.‏\hadithno{259}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Said ibn al-Musayyab used to say, "Sleep is disapproved of before isha and conversation after it}}
\hadithdefcmd{malik}{260}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ صَلاَةُ اللَّيْلِ وَالنَّهَارِ مَثْنَى مَثْنَى يُسَلِّمُ مِنْ كُلِّ رَكْعَتَيْنِ ‏.‏\hadithno{260}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Umar used to say, "(Voluntary) prayer in both the day and night is two at a time with a taslim after every 2 raka'ahs." Malik said, "That is the custom among us}}
\hadithdefcmd{malik}{261}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي مِنَ اللَّيْلِ إِحْدَى عَشْرَةَ رَكْعَةً يُوتِرُ مِنْهَا بِوَاحِدَةٍ فَإِذَا فَرَغَ اضْطَجَعَ عَلَى شِقِّهِ الأَيْمَنِ ‏.‏\hadithno{261}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Urwa ibn az- Zubayr from A'isha, the wife of the Prophet, may Allah bless him and grant him peace, that the Messenger of Allah, may Allah bless him and grant him peace, used to pray eleven rakas in the night, making them odd by a single one, and when he had finished he lay down on his right side}}
\hadithdefcmd{malik}{262}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّهُ سَأَلَ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَيْفَ كَانَتْ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَمَضَانَ فَقَالَتْ مَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَزِيدُ فِي رَمَضَانَ وَلاَ فِي غَيْرِهِ عَلَى إِحْدَى عَشْرَةَ رَكْعَةً يُصَلِّي أَرْبَعًا فَلاَ تَسْأَلْ عَنْ حُسْنِهِنَّ وَطُولِهِنَّ ثُمَّ يُصَلِّي أَرْبَعًا فَلاَ تَسْأَلْ عَنْ حُسْنِهِنَّ وَطُولِهِنَّ ثُمَّ يُصَلِّي ثَلاَثًا فَقَالَتْ عَائِشَةُ فَقُلْتُ يَا رَسُولَ اللَّهِ أَتَنَامُ قَبْلَ أَنْ تُوتِرَ فَقَالَ ‏ "‏ يَا عَائِشَةُ إِنَّ عَيْنَىَّ تَنَامَانِ وَلاَ يَنَامُ قَلْبِي ‏"‏ ‏.‏\hadithno{262}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Said ibn Abi Said al-Maqburi from Abu Salama ibn Abd ar-Rahman ibn Awf that he asked A'isha, the wife of the Prophet, may Allah bless him and grant him peace, what the prayer of the Messenger of Allah, may Allah bless him and grant him peace, was like during Ramadan. She said, "The Messenger of Allah, may Allah bless him and grant him peace, did not go above eleven rakas in Ramadan or at any other time. He prayed four - do not ask me about their beauty or length. Then he prayed another four - do not ask me about their beauty and length. Then he prayed three." A'isha continued, "I said, 'Messenger of Allah, are you sleeping before you do the witr?' He said, A'isha, my eyes sleep but my heart does not sleep}}
\hadithdefcmd{malik}{263}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِاللَّيْلِ ثَلاَثَ عَشْرَةَ رَكْعَةً ثُمَّ يُصَلِّي إِذَا سَمِعَ النِّدَاءَ بِالصُّبْحِ رَكْعَتَيْنِ خَفِيفَتَيْنِ ‏.‏\hadithno{263}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that A'isha, umm al-muminin said, "The Messenger of Allah, may Allah bless him and grant him peace, used to pray thirteen rakas in the night and then would pray two rakas when he heard the adhan for the subh prayer}}
\hadithdefcmd{malik}{264}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّهُ، بَاتَ لَيْلَةً عِنْدَ مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم - وَهِيَ خَالَتُهُ - قَالَ فَاضْطَجَعْتُ فِي عَرْضِ الْوِسَادَةِ وَاضْطَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَهْلُهُ فِي طُولِهَا فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا انْتَصَفَ اللَّيْلُ - أَوْ قَبْلَهُ بِقَلِيلٍ أَوْ بَعْدَهُ بِقَلِيلٍ - اسْتَيْقَظَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَلَسَ يَمْسَحُ النَّوْمَ عَنْ وَجْهِهِ بِيَدِهِ ثُمَّ قَرَأَ الْعَشْرَ الآيَاتِ الْخَوَاتِمَ مِنْ سُورَةِ آلِ عِمْرَانَ ثُمَّ قَامَ إِلَى شَنٍّ مُعَلَّقٍ فَتَوَضَّأَ مِنْهُ فَأَحْسَنَ وُضُوءَهُ ثُمَّ قَامَ يُصَلِّي - قَالَ ابْنُ عَبَّاسٍ - فَقُمْتُ فَصَنَعْتُ مِثْلَ مَا صَنَعَ ثُمَّ ذَهَبْتُ فَقُمْتُ إِلَى جَنْبِهِ فَوَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ الْيُمْنَى عَلَى رَأْسِي وَأَخَذَ بِأُذُنِي الْيُمْنَى يَفْتِلُهَا فَصَلَّى رَكْعَتَيْنِ ثُمَّ رَكْعَتَيْنِ ثُمَّ رَكْعَتَيْنِ ثُمَّ رَكْعَتَيْنِ ثُمَّ رَكْعَتَيْنِ ثُمَّ رَكْعَتَيْنِ ثُمَّ أَوْتَرَ ثُمَّ اضْطَجَعَ حَتَّى أَتَاهُ الْمُؤَذِّنُ فَصَلَّى رَكْعَتَيْنِ خَفِيفَتَيْنِ ثُمَّ خَرَجَ فَصَلَّى الصُّبْحَ ‏.‏\hadithno{264}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Makhrama ibn Sulayman from Kurayb, the mawla of Ibn Abbas, that Abdullah ibn Abbas told him that he had spent a night at the house of Maimuna, the wife of the Prophet, may Allah bless him and grant him peace, who was also Ibn Abbas' mother's sister. Ibn Abbas said, "I lay down with my head on the breadth of the cushion, and the Messenger of Allah, may Allah bless him and grant him peace, and his wife lay down with their heads on its length. The Messenger of Allah, may Allah bless him and grant him peace, slept, until, halfway through the night or a little before or after it, he awoke and sat up and wiped the sleep away from his face with his hand. Then he recited the last ten ayats of sura Ali Imran (Sura3). Then he got up and went over to a water-skin which was hanging up and did wudu from it, doing his wudu thoroughly, and then he stood in prayer." Ibn Abbas continued, "I stood up and did the same and then went and stood by his side. The Messenger of Allah, may Allah bless him and grant him peace, put his right hand on my head and took my right ear and tweaked it. He prayed two rakas, then two rakas, then two rakas, then two rakas, then two rakas, then two rakas, and then prayed an odd raka. Then he lay down until the muadhdhin came to him, and then prayed two quick rakas, and went out and prayed subh}}
\hadithdefcmd{malik}{265}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، أَنَّ عَبْدَ اللَّهِ بْنَ قَيْسِ بْنِ مَخْرَمَةَ، أَخْبَرَهُ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّهُ قَالَ لأَرْمُقَنَّ اللَّيْلَةَ صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ - فَتَوَسَّدْتُ عَتَبَتَهُ - أَوْ فُسْطَاطَهُ - فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّى رَكْعَتَيْنِ طَوِيلَتَيْنِ طَوِيلَتَيْنِ طَوِيلَتَيْنِ ثُمَّ صَلَّى رَكْعَتَيْنِ وَهُمَا دُونَ اللَّتَيْنِ قَبْلَهُمَا ثُمَّ صَلَّى رَكْعَتَيْنِ وَهُمَا دُونَ اللَّتَيْنِ قَبْلَهُمَا ثُمَّ صَلَّى رَكْعَتَيْنِ وَهُمَا دُونَ اللَّتَيْنِ قَبْلَهُمَا ثُمَّ صَلَّى رَكْعَتَيْنِ وَهُمَا دُونَ اللَّتَيْنِ قَبْلَهُمَا ثُمَّ صَلَّى رَكْعَتَيْنِ وَهُمَا دُونَ اللَّتَيْنِ قَبْلَهُمَا ثُمَّ أَوْتَرَ فَتِلْكَ ثَلاَثَ عَشْرَةَ رَكْعَةً ‏.‏\hadithno{265}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr from his father that Abdullah ibn Qays ibn Makhrama told him that Zayd ibn Khalid al-Juhani said one night that he was going to observe the prayer of the Messenger of Allah, may Allah bless him and grant him peace. He said, "I rested my head on his threshold. The Messenger of Allah, may Allah bless him and grant him peace, got up and prayed two long, long, long rakas. Then he prayed two rakas which were slightly less long than the two before them. Then he prayed two rakas which were slightly less long than the two before them. Then he prayed two rakas which were slightly less long than the two before them. Then he prayed two rakas which were slightly less long than the two before them. Then he prayed two rakas which were slightly less long than the two before them. Then he prayed an odd raka, making thirteen rakas in all}}
\hadithdefcmd{malik}{266}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، وَعَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ صَلاَةِ اللَّيْلِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صَلاَةُ اللَّيْلِ مَثْنَى مَثْنَى فَإِذَا خَشِيَ أَحَدُكُمُ الصُّبْحَ صَلَّى رَكْعَةً وَاحِدَةً تُوتِرُ لَهُ مَا قَدْ صَلَّى ‏"‏ ‏.‏\hadithno{266}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi and Abdullah ibn Umar that a man asked the Messenger of Allah, may Allah bless him and grant him peace, about night prayers. The Messenger of Allah, may Allah bless him and grant him peace, said, "Night prayers are two by two, and when you are afraid that dawn is approaching, pray one raka to make what you have prayed odd}}
\hadithdefcmd{malik}{267}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ ابْنِ مُحَيْرِيزٍ، أَنَّ رَجُلاً، مِنْ بَنِي كِنَانَةَ يُدْعَى الْمُخْدَجِيَّ سَمِعَ رَجُلاً، بِالشَّامِ يُكَنَّى أَبَا مُحَمَّدٍ يَقُولُ إِنَّ الْوِتْرَ وَاجِبٌ ‏.‏ فَقَالَ الْمُخْدَجِيُّ فَرُحْتُ إِلَى عُبَادَةَ بْنِ الصَّامِتِ فَاعْتَرَضْتُ لَهُ وَهُوَ رَائِحٌ إِلَى الْمَسْجِدِ فَأَخْبَرْتُهُ بِالَّذِي قَالَ أَبُو مُحَمَّدٍ فَقَالَ عُبَادَةُ كَذَبَ أَبُو مُحَمَّدٍ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ خَمْسُ صَلَوَاتٍ كَتَبَهُنَّ اللَّهُ عَزَّ وَجَلَّ عَلَى الْعِبَادِ فَمَنْ جَاءَ بِهِنَّ لَمْ يُضَيِّعْ مِنْهُنَّ شَيْئًا اسْتِخْفَافًا بِحَقِّهِنَّ كَانَ لَهُ عِنْدَ اللَّهِ عَهْدٌ أَنْ يُدْخِلَهُ الْجَنَّةَ وَمَنْ لَمْ يَأْتِ بِهِنَّ فَلَيْسَ لَهُ عِنْدَ اللَّهِ عَهْدٌ إِنْ شَاءَ عَذَّبَهُ وَإِنْ شَاءَ أَدْخَلَهُ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{267}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Muhammad ibn Yahya ibn Habban from Ibn Muhayriz that a man from the Kinana tribe called al-Mukhdaji heard a man in Syria known as Abu Muhammad saying, "The witr is obligatory (fard)." Al-Mukhdaji said, "I went to Ubada ibn as-Samit and presented myself to him as he was going to the mosque, and told him what Abu Muhammad had said. Ubada said that Abu Muhammad had lied and that he had heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'Allah the Majestic and Mighty has written five prayers for mankind, and whoever does them and does not waste anything of them by making light of what is due to them, there is a pact for him with Allah that He will admit him into the Garden.Whoever does not do them, there is no pact for him with Allah. If He wishes, He punishes him, and if He wishes, He admits him into the Garden}}
\hadithdefcmd{malik}{268}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي بَكْرِ بْنِ عُمَرَ، عَنْ سَعِيدِ بْنِ يَسَارٍ، قَالَ كُنْتُ أَسِيرُ مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ بِطَرِيقِ مَكَّةَ - قَالَ سَعِيدٌ - فَلَمَّا خَشِيتُ الصُّبْحَ نَزَلْتُ فَأَوْتَرْتُ ثُمَّ أَدْرَكْتُهُ فَقَالَ لِي عَبْدُ اللَّهِ بْنُ عُمَرَ أَيْنَ كُنْتَ فَقُلْتُ لَهُ خَشِيتُ الصُّبْحَ فَنَزَلْتُ فَأَوْتَرْتُ ‏.‏ فَقَالَ عَبْدُ اللَّهِ أَلَيْسَ لَكَ فِي رَسُولِ اللَّهِ أُسْوَةٌ ‏.‏ فَقُلْتُ بَلَى وَاللَّهِ ‏.‏ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُوتِرُ عَلَى الْبَعِيرِ ‏.‏\hadithno{268}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu Bakr ibn Umar that Said ibn Yasar said, ''I was travelling with Abdullah ibn Umar on the road to Makka, and fearing that it was nearly dawn. I dismounted and prayed witr. Abdullah said, 'Is there not a model for you in the Messenger of Allah, may Allah bless him and grant him peace?' I said, 'Of course, by Allah!' He said, 'The Messenger of Allah, may Allah bless him and grant him peace, used to pray witr on his camel}}
\hadithdefcmd{malik}{269}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ كَانَ أَبُو بَكْرٍ الصِّدِّيقُ إِذَا أَرَادَ أَنْ يَأْتِيَ، فِرَاشَهُ أَوْتَرَ وَكَانَ عُمَرُ بْنُ الْخَطَّابِ يُوتِرُ آخِرَ اللَّيْلِ قَالَ سَعِيدُ بْنُ الْمُسَيَّبِ فَأَمَّا أَنَا فَإِذَا جِئْتُ فِرَاشِي أَوْتَرْتُ ‏.‏\hadithno{269}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab said, "Abu Bakr as-Siddiq used to pray witr when he wished to go to bed, and Umar ibn al-Khattab used to pray witr at the end of the night. As for me, I pray witr when I go to bed}}
\hadithdefcmd{malik}{270}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَجُلاً، سَأَلَ عَبْدَ اللَّهِ بْنَ عُمَرَ عَنِ الْوِتْرِ أَوَاجِبٌ هُوَ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ قَدْ أَوْتَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَوْتَرَ الْمُسْلِمُونَ ‏.‏ فَجَعَلَ الرَّجُلُ يُرَدِّدُ عَلَيْهِ وَعَبْدُ اللَّهِ بْنُ عُمَرَ يَقُولُ أَوْتَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَوْتَرَ الْمُسْلِمُونَ ‏.‏\hadithno{270}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that a man asked Abdullah ibn Umar whether the witr was obligatory and Abdullah ibn Umar said, "The Messenger of Allah, may Allah bless him and grant him peace, prayed witr, and the muslims prayed witr." The man began repeating his question, and Abdullah ibn Umar kept saying, "The Messenger of Allah, may Allah bless him and grant him peace, prayed witr, and the muslims prayed witr}}
\hadithdefcmd{malik}{271}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَانَتْ تَقُولُ مَنْ خَشِيَ أَنْ يَنَامَ حَتَّى يُصْبِحَ فَلْيُوتِرْ قَبْلَ أَنْ يَنَامَ وَمَنْ رَجَا أَنْ يَسْتَيْقِظَ آخِرَ اللَّيْلِ فَلْيُؤَخِّرْ وِتْرَهُ ‏.‏\hadithno{271}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, used to say, "If someone fears that he will sleep through till the morning, let him pray the witr before he sleeps, and if some one hopes to wake for the last part of the night, let him delay his witr}}
\hadithdefcmd{malik}{272}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّهُ قَالَ كُنْتُ مَعَ عَبْدِ اللَّهِ بْنِ عُمَرَ بِمَكَّةَ وَالسَّمَاءُ مُغِيمَةٌ فَخَشِيَ عَبْدُ اللَّهِ الصُّبْحَ فَأَوْتَرَ بِوَاحِدَةٍ ثُمَّ انْكَشَفَ الْغَيْمُ فَرَأَى أَنَّ عَلَيْهِ لَيْلاً فَشَفَعَ بِوَاحِدَةٍ ثُمَّ صَلَّى بَعْدَ ذَلِكَ رَكْعَتَيْنِ رَكْعَتَيْنِ فَلَمَّا خَشِيَ الصُّبْحَ أَوْتَرَ بِوَاحِدَةٍ ‏.‏\hadithno{272}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that Nafi said, "I was with Abdullah ibn Umar in Makka. The sky was clouded over and Abdullah feared that dawn was approaching so he prayed one raka for witr. Then the clouds cleared and he saw that it was still night, so he made his prayers even with one raka. Then he continued to pray two rakas at a time, until when he feared the approach of dawn, he prayed one raka for witr}}
\hadithdefcmd{malik}{273}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يُسَلِّمُ بَيْنَ الرَّكْعَتَيْنِ وَالرَّكْعَةِ فِي الْوِتْرِ حَتَّى يَأْمُرَ بِبَعْضِ حَاجَتِهِ ‏.‏\hadithno{273}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Abdullah ibn Umar used to say the taslim between the two rakas and the one raka of witr so that he could order something he needed}}
\hadithdefcmd{malik}{274}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَعْدَ بْنَ أَبِي وَقَّاصٍ، كَانَ يُوتِرُ بَعْدَ الْعَتَمَةِ بِوَاحِدَةٍ ‏.‏ قَالَ مَالِكٌ وَلَيْسَ عَلَى هَذَا الْعَمَلُ عِنْدَنَا وَلَكِنْ أَدْنَى الْوِتْرِ ثَلاَثٌ ‏.‏\hadithno{274}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab that Sad ibn Abi Waqqas used to pray witr after isha with one raka. Malik said, "This is not the situation with us. Rather three is the minimum for witr}}
\hadithdefcmd{malik}{275}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ يَقُولُ صَلاَةُالمغرب وتر صلاة النهار ‏.‏ قال مالك من أوتر أول الليل ثم نام ثم قام فبدا له أن يصلي فليصل مثنى مثنى فهو أحب ما سمعت إلى ‏\hadithno{275}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar that Abdullah ibn Umar used to say, "The maghrib prayer is the witr of the daytime prayers." Malik said, "If someone prays witr at the beginning of the night, and goes to sleep, and then wakes up and it seems good to him to pray, let him pray, two rakas at a time. That is what I like most of what I have heard}}
\hadithdefcmd{malik}{276}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ الْكَرِيمِ بْنِ أَبِي الْمُخَارِقِ الْبَصْرِيِّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، رَقَدَ ثُمَّ اسْتَيْقَظَ فَقَالَ لِخَادِمِهِ انْظُرْ مَا صَنَعَ النَّاسُ ‏.‏ وَهُوَ يَوْمَئِذٍ قَدْ ذَهَبَ بَصَرُهُ ‏.‏ فَذَهَبَ الْخَادِمُ ثُمَّ رَجَعَ فَقَالَ قَدِ انْصَرَفَ النَّاسُ مِنَ الصُّبْحِ ‏.‏ فَقَامَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ فَأَوْتَرَ ثُمَّ صَلَّى الصُّبْحَ ‏.‏\hadithno{276}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Abd al Karim ibn Abi'l-Mukhariq al-Basri from Said ibn Jubayr that Abdullah ibn Abbas slept, and when he woke up, he said to his servant, "Go and see what the people have done," (by that time his sight had gone.) The servant went out and returned saying, "The people have left from subh," so Abdullah ibn Abbas got up and prayed witr and then prayed subh}}
\hadithdefcmd{malik}{277}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، وَعُبَادَةَ بْنَ الصَّامِتِ، وَالْقَاسِمَ بْنَ مُحَمَّدٍ، وَعَبْدَ اللَّهِ بْنَ عَامِرِ بْنِ رَبِيعَةَ، قَدْ أَوْتَرُوا بَعْدَ الْفَجْرِ ‏.‏\hadithno{277}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Abbas and Ubada ibn as-Samit and al-Qasim ibn Muhammad and Abdullah ibn Amir ibn Rabia had all prayed witr after the break of dawn}}
\hadithdefcmd{malik}{278}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، قَالَ مَا أُبَالِي لَوْ أُقِيمَتْ صَلاَةُ الصُّبْحِ وَأَنَا أُوتِرُ، ‏.‏\hadithno{278}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father that Abdullah ibn Masud said, "I do not mind if the iqama for the subh prayer is called while I am still praying witr}}
\hadithdefcmd{malik}{279}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ كَانَ عُبَادَةُ بْنُ الصَّامِتِ يَؤُمُّ قَوْمًا فَخَرَجَ يَوْمًا إِلَى الصُّبْحِ فَأَقَامَ الْمُؤَذِّنُ صَلاَةَ الصُّبْحِ فَأَسْكَتَهُ عُبَادَةُ حَتَّى أَوْتَرَ ثُمَّ صَلَّى بِهِمُ الصُّبْحَ ‏.‏\hadithno{279}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said, ''Ubada ibn as-Samit used to lead the people in prayer. One day he came out for subh and the muadhdhin began to give the iqama for the subh prayer Ubada silenced him, prayed witr and then led them in subh}}
\hadithdefcmd{malik}{280}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، أَنَّهُ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَامِرِ بْنِ رَبِيعَةَ، يَقُولُ إِنِّي لأُوتِرُ وَأَنَا أَسْمَعُ الإِقَامَةَ، أَوْ بَعْدَ الْفَجْرِ ‏.‏ يَشُكُّ عَبْدُ الرَّحْمَنِ أَىَّ ذَلِكَ قَالَ ‏.‏\hadithno{280}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Abd ar-Rahman ibn al-Qasim said, "I heard Abdullah ibn Amir ibn Rabia say, 'I sometimes pray witr while hearing the iqama, or after the break of dawn.' " Abd ar-Rahman was not certain which he said}}
\hadithdefcmd{malik}{281}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، أَنَّهُ سَمِعَ أَبَاهُ الْقَاسِمَ بْنَ مُحَمَّدٍ، يَقُولُ إِنِّي لأُوتِرُ بَعْدَ الْفَجْرِ ‏.‏ قَالَ مَالِكٌ وَإِنَّمَا يُوتِرُ بَعْدَ الْفَجْرِ مَنْ نَامَ عَنِ الْوِتْرِ وَلاَ يَنْبَغِي لأَحَدٍ أَنْ يَتَعَمَّدَ ذَلِكَ حَتَّى يَضَعَ وِتْرَهُ بَعْدَ الْفَجْرِ ‏.‏\hadithno{281}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Malik related to me that Abd ar-Rahman ibn al-Qasim heard his father al-Qasim ibn Muhammad say, "I have prayed witr after dawn." Malik said, "Only a person who oversleeps so that he does not do the witr prays it after dawn. No one should intentionally make his witr after dawn}}
\hadithdefcmd{malik}{282}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ حَفْصَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا سَكَتَ الْمُؤَذِّنُ عَنِ الأَذَانِ لِصَلاَةِ الصُّبْحِ صَلَّى رَكْعَتَيْنِ خَفِيفَتَيْنِ قَبْلَ أَنْ تُقَامَ الصَّلاَةُ ‏.‏\hadithno{282}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that Hafsa, the wife of the Prophet, may Allah bless him and grant him peace, told him that the Messenger of Allah, may Allah bless him and grant him peace, used to pray two quick rakas when the muadhdhin had finished the adhan for the subh prayer, before the iqama was said for the prayer}}
\hadithdefcmd{malik}{283}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُخَفِّفُ رَكْعَتَىِ الْفَجْرِ حَتَّى إِنِّي لأَقُولُ أَقَرَأَ بِأُمِّ الْقُرْآنِ أَمْ لاَ\hadithno{283}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Yahya ibn Said that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "The Messenger of Allah, may Allah bless him and grant him peace, used to pray the two rakas of the dawn (fajr) so quickly that I would say to myself 'Has he recited the umm al-Qur'an or not?}}
\hadithdefcmd{malik}{284}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ قَالَ سَمِعَ قَوْمٌ الإِقَامَةَ، فَقَامُوا يُصَلُّونَ فَخَرَجَ عَلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَصَلاَتَانِ مَعًا أَصَلاَتَانِ مَعًا ‏"‏ ‏.‏ وَذَلِكَ فِي صَلاَةِ الصُّبْحِ فِي الرَّكْعَتَيْنِ اللَّتَيْنِ قَبْلَ الصُّبْحِ ‏.‏\hadithno{284}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Sharik ibn Abdullah ibn Abi Namir that Abu Salama ibn Abd ar-Rahman said, "Some people heard the iqama and started to pray. The Messenger of Allah, may Allah bless him and grant him peace, came out and said, 'Are you doing two prayers at the same time? Are you doing two prayers at the same time?' That was about the subh prayer and the two rakas before subh}}
\hadithdefcmd{malik}{285}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، فَاتَتْهُ رَكْعَتَا الْفَجْرِ فَقَضَاهُمَا بَعْدَ أَنْ طَلَعَتِ الشَّمْسُ ‏.‏\hadithno{285}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Umar missed the two rakas of dawn, and then did them after the sun rose}}
\hadithdefcmd{malik}{286}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، أَنَّهُ صَنَعَ مِثْلَ الَّذِي صَنَعَ ابْنُ عُمَرَ ‏.‏\hadithno{286}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from Abd ar-Rahman ibn al-Qasim that al-Qasim ibn Muhammad had done the same as Ibn Umar}}
