% Auto-generated chapter 56 for muslim
% Hadiths in this chapter: 39

\hadithdefcmd{muslim}{7523}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قِيلَ لِبَنِي إِسْرَائِيلَ ‏\{‏ ادْخُلُوا الْبَابَ سُجَّدًا وَقُولُوا حِطَّةٌ يُغْفَرْ لَكُمْ خَطَايَاكُمْ‏\}‏ فَبَدَّلُوا فَدَخَلُوا الْبَابَ يَزْحَفُونَ عَلَى أَسْتَاهِهِمْ وَقَالُوا حَبَّةٌ فِي شَعَرَةٍ"‏ ‏.‏\hadithno{7523}\hadithtrans{Hammim b. Munabbih reported:This is what Abu Huraira reported to us from Allah's Messenger (ﷺ) and in this connection he narrated some of the ahadith and Allah's Messenger (ﷺ) said: It was said to people of Israel: Enter this land saying Hitta (Remove Thou from us the burden of our sins), whereupon We would forgive you your sins, but they twisted (this statement) and entered the gate dragging upon their breech and said: The" grain in the ear}}
\hadithdefcmd{muslim}{7524}{حَدَّثَنِي عَمْرُو بْنُ مُحَمَّدِ بْنِ بُكَيْرٍ النَّاقِدُ، وَالْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ، حُمَيْدٍ - قَالَ عَبْدٌ حَدَّثَنِي وَقَالَ الآخَرَانِ، حَدَّثَنَا يَعْقُوبُ، - يَعْنُونَ ابْنَ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، - وَهُوَ ابْنُ كَيْسَانَ - عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ، مَالِكٍ أَنَّ اللَّهَ، عَزَّ وَجَلَّ تَابَعَ الْوَحْىَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَبْلَ وَفَاتِهِ حَتَّى تُوُفِّيَ وَأَكْثَرُ مَا كَانَ الْوَحْىُ يَوْمَ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{7524}\hadithtrans{Anas b. Malik reported that Allah, the Exalted and Glorious, sent revelation to Allah's Messenger (ﷺ) just before his death in quick succession until he left for his heavenly home, and the day when he died, he received the revelation profusely}}
\hadithdefcmd{muslim}{7525}{حَدَّثَنِي أَبُو خَيْثَمَةَ، زُهَيْرُ بْنُ حَرْبٍ وَمُحَمَّدُ بْنُ الْمُثَنَّى - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - وَهُوَ ابْنُ مَهْدِيٍّ - حَدَّثَنَا سُفْيَانُ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ، بْنِ شِهَابٍ أَنَّ الْيَهُودَ، قَالُوا لِعُمَرَ إِنَّكُمْ تَقْرَءُونَ آيَةً لَوْ أُنْزِلَتْ فِينَا لاَتَّخَذْنَا ذَلِكَ الْيَوْمَ عِيدًا ‏.‏ فَقَالَ عُمَرُ إِنِّي لأَعْلَمُ حَيْثُ أُنْزِلَتْ وَأَىَّ يَوْمٍ أُنْزِلَتْ وَأَيْنَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَيْثُ أُنْزِلَتْ أُنْزِلَتْ بِعَرَفَةَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم وَاقِفٌ بِعَرَفَةَ ‏.‏ قَالَ سُفْيَانُ أَشُكُّ كَانَ يَوْمَ جُمُعَةٍ أَمْ لاَ ‏.‏ يَعْنِي ‏\{‏ الْيَوْمَ أَكْمَلْتُ لَكُمْ دِينَكُمْ وَأَتْمَمْتُ عَلَيْكُمْ نِعْمَتِي‏\}‏\hadithno{7525}\hadithtrans{Tariq b. Shihab reported that a Jew said to'Umar:You recite a verse which, if it had been revealed in relation to us, we would have taken that day as the day of rejoicing. Thereupon 'Umar said: I know where it was revealed and on the day when it was revealed and where Allah's Messenger (ﷺ) had been at that time when it was revealed. It was revealed on the day of 'Arafa (ninth of Dhu'l Hijjah) and Allah's Messenger (ﷺ) had been staying in 'Arafat. Sufyan said: I doubt, whether it was Friday or not (and the verse referred to) is this:" Today I have perfected your religion for you and completed My favours upon you" (v)}}
\hadithdefcmd{muslim}{7526}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالَ حَدَّثَنَا عَبْدُ، اللَّهِ بْنُ إِدْرِيسَ عَنْ أَبِيهِ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، قَالَ قَالَتِ الْيَهُودُ لِعُمَرَ لَوْ عَلَيْنَا مَعْشَرَ يَهُودَ نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ الْيَوْمَ أَكْمَلْتُ لَكُمْ دِينَكُمْ وَأَتْمَمْتُ عَلَيْكُمْ نِعْمَتِي وَرَضِيتُ لَكُمُ الإِسْلاَمَ دِينًا‏\}‏ نَعْلَمُ الْيَوْمَ الَّذِي أُنْزِلَتْ فِيهِ لاَتَّخَذْنَا ذَلِكَ الْيَوْمَ عِيدًا ‏.‏ قَالَ فَقَالَ عُمَرُ فَقَدْ عَلِمْتُ الْيَوْمَ الَّذِي أُنْزِلَتْ فِيهِ وَالسَّاعَةَ وَأَيْنَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ نَزَلَتْ نَزَلَتْ لَيْلَةَ جَمْعٍ وَنَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِعَرَفَاتٍ ‏.‏\hadithno{7526}\hadithtrans{Tariq b. Shihab reported that a Jew said to 'Umar:If this verse were revealed in relation to the Jews (i e. "This day I have perfected your religion for you and have completed My favours for you and have chosen for you al-Islam as religion") we would have taken the day of rejoicing on which this verse was revealed. Thereupon 'Umar said: I know the day on which it was revealed and the hour when it was revealed and where Allah's Messenger (ﷺ) had been when it was revealed. It was revealed on the night of Friday and we were in 'Arafat with Allah's Messenger (ﷺ) at that time}}
\hadithdefcmd{muslim}{7527}{وَحَدَّثَنِي عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا جَعْفَرُ بْنُ عَوْنٍ، أَخْبَرَنَا أَبُو عُمَيْسٍ، عَنْ قَيْسِ، بْنِ مُسْلِمٍ عَنْ طَارِقِ بْنِ شِهَابٍ، قَالَ جَاءَ رَجُلٌ مِنَ الْيَهُودِ إِلَى عُمَرَ فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ آيَةٌ فِي كِتَابِكُمْ تَقْرَءُونَهَا لَوْ عَلَيْنَا نَزَلَتْ مَعْشَرَ الْيَهُودِ لاَتَّخَذْنَا ذَلِكَ الْيَوْمَ عِيدًا ‏.‏ قَالَ وَأَىُّ آيَةٍ قَالَ ‏\{‏ الْيَوْمَ أَكْمَلْتُ لَكُمْ دِينَكُمْ وَأَتْمَمْتُ عَلَيْكُمْ نِعْمَتِي وَرَضِيتُ لَكُمُ الإِسْلاَمَ دِينًا‏\}‏ فَقَالَ عُمَرُ إِنِّي لأَعْلَمُ الْيَوْمَ الَّذِي نَزَلَتْ فِيهِ وَالْمَكَانَ الَّذِي نَزَلَتْ فِيهِ نَزَلَتْ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِعَرَفَاتٍ فِي يَوْمِ جُمُعَةٍ ‏.‏\hadithno{7527}\hadithtrans{Tariq b. Shihab reported that a Jew came to 'Umar and said:Commander of the Faithful, there is a verse in your Book, which you recite. Had it been revealed in connection with the Jews, we would have taken it as the day of rejoicing. Thereupon he said: Which verse do you mean? He replied:" This day I have perfected your religion for you and I have completed My favours upon you and I have chosen al-Islam as religion for you." Umar said, I know the day when it was revealed and the place where it was revealed. It was revealed to Allah's Messenger (ﷺ) at 'Arafat on Friday}}
\hadithdefcmd{muslim}{7528}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ وَحَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ - قَالَ أَبُو الطَّاهِرِ حَدَّثَنَا وَقَالَ، حَرْمَلَةُ أَخْبَرَنَا - ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّهُ سَأَلَ عَائِشَةَ عَنْ قَوْلِ اللَّهِ، ‏\{‏ وَإِنْ خِفْتُمْ أَنْ لاَ، تُقْسِطُوا فِي الْيَتَامَى فَانْكِحُوا مَا طَابَ لَكُمْ مِنَ النِّسَاءِ مَثْنَى وَثُلاَثَ وَرُبَاعَ‏\}‏ قَالَتْ يَا ابْنَ أُخْتِي هِيَ الْيَتِيمَةُ تَكُونُ فِي حَجْرِ وَلِيِّهَا تُشَارِكُهُ فِي مَالِهِ فَيُعْجِبُهُ مَالُهَا وَجَمَالُهَا فَيُرِيدُ وَلِيُّهَا أَنْ يَتَزَوَّجَهَا بِغَيْرِ أَنْ يُقْسِطَ فِي صَدَاقِهَا فَيُعْطِيَهَا مِثْلَ مَا يُعْطِيهَا غَيْرُهُ فَنُهُوا أَنْ يَنْكِحُوهُنَّ إِلاَّ أَنْ يُقْسِطُوا لَهُنَّ وَيَبْلُغُوا بِهِنَّ أَعْلَى سُنَّتِهِنَّ مِنَ الصَّدَاقِ وَأُمِرُوا أَنْ يَنْكِحُوا مَا طَابَ لَهُمْ مِنَ النِّسَاءِ سِوَاهُنَّ ‏.‏ قَالَ عُرْوَةُ قَالَتْ عَائِشَةُ ثُمَّ إِنَّ النَّاسَ اسْتَفْتَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدَ هَذِهِ الآيَةِ فِيهِنَّ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَيَسْتَفْتُونَكَ فِي النِّسَاءِ قُلِ اللَّهُ يُفْتِيكُمْ فِيهِنَّ وَمَا يُتْلَى عَلَيْكُمْ فِي الْكِتَابِ فِي يَتَامَى النِّسَاءِ اللاَّتِي لاَ تُؤْتُونَهُنَّ مَا كُتِبَ لَهُنَّ وَتَرْغَبُونَ أَنْ تَنْكِحُوهُنَّ‏\}‏ ‏.‏ قَالَتْ وَالَّذِي ذَكَرَ اللَّهُ تَعَالَى أَنَّهُ يُتْلَى عَلَيْكُمْ فِي الْكِتَابِ الآيَةُ الأُولَى الَّتِي قَالَ اللَّهُ فِيهَا ‏\{‏ وَإِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى فَانْكِحُوا مَا طَابَ لَكُمْ مِنَ النِّسَاءِ‏\}‏ ‏.‏ قَالَتْ عَائِشَةُ وَقَوْلُ اللَّهِ فِي الآيَةِ الأُخْرَى ‏\{‏ وَتَرْغَبُونَ أَنْ تَنْكِحُوهُنَّ‏\}‏ رَغْبَةَ أَحَدِكُمْ عَنِ الْيَتِيمَةِ الَّتِي تَكُونُ فِي حَجْرِهِ حِينَ تَكُونُ قَلِيلَةَ الْمَالِ وَالْجَمَالِ فَنُهُوا أَنْ يَنْكِحُوا مَا رَغِبُوا فِي مَالِهَا وَجَمَالِهَا مِنْ يَتَامَى النِّسَاءِ إِلاَّ بِالْقِسْطِ مِنْ أَجْلِ رَغْبَتِهِمْ عَنْهُنَّ ‏.‏\hadithno{7528}\hadithtrans{Urwa b. Zubair reported that he asked 'A'isha about the words of Allah:" If you fear that you will not be able to maintain equity amongst the orphan girls, then marry (those) you like from amongst the women two, three or four." She said: O, the son of my sister, the orphan girl is one who is under the patronage of her guardian and she shares with him in his property and her property and beauty fascinate him and her guardian makes up his mind to marry her without giving her due share of the wedding money and is not prepared (to pay so much amount) which anyone else is prepared to pay and so Allah has forbidden to marry these girls but in case when equity is observed as regards the wedding money and they are prepared to pay them the full amount of the wedding money and Allah commanded to marry other women besides them according to the liking of their heart. 'Urwa reported that 'A'isha said that people began to seek verdict from Allah's Messenger (ﷺ) after the revelation of this verse about them (orphan girls) and Allah, the Exalted and Glorious, revealed this verse:" They asked thee verdict about women; say: Allah gives verdict to you in regard to them and what is recited to you in the Book about orphan woman, whom you give not what is ordained for them while you like to marry them" (iv. 126). She said: The wording of Allah" what is recited to you" in the Book means the first verse, i. e." if you fear that you may not be able to observe equity in case of an orphan woman, marry what you like in case of woman" (iv. 3). 'A'isha said: (And as for this verse [iv. 126], i. e. and you intend" to marry one of them from amongst the orphan girls" it pertains to one who is in charge (of orphans) having small amount of wealth and less beauty and they have been forbidden that they should marry what they like of her wealth and beauty out of the orphan girls, but with equity, because of their disliking for them}}
\hadithdefcmd{muslim}{7529}{وَحَدَّثَنَا الْحَسَنُ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ يَعْقُوبَ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ، أَنَّهُ سَأَلَ عَائِشَةَ عَنْ قَوْلِ اللَّهِ، ‏\{‏وَإِنْ خِفْتُمْ أَنْ لاَ، تُقْسِطُوا فِي الْيَتَامَى‏\}‏ وَسَاقَ الْحَدِيثَ بِمِثْلِ حَدِيثِ يُونُسَ عَنِ الزُّهْرِيِّ وَزَادَ فِي آخِرِهِ مِنْ أَجْلِ رَغْبَتِهِمْ عَنْهُنَّ إِذَا كُنَّ قَلِيلاَتِ الْمَالِ وَالْجَمَالِ ‏.‏\hadithno{7529}\hadithtrans{Urwa reported that he asked 'A'isha about the words of Allah:" If you fear that you will not be able to observe equity in case of orphan girls" ; the rest of the hadith is the same but with a slight variation of wording}}
\hadithdefcmd{muslim}{7530}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، فِي قَوْلِهِ ‏\{‏ وَإِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى‏\}‏ قَالَتْ أُنْزِلَتْ فِي الرَّجُلِ تَكُونُ لَهُ الْيَتِيمَةُ وَهُوَ وَلِيُّهَا وَوَارِثُهَا وَلَهَا مَالٌ وَلَيْسَ لَهَا أَحَدٌ يُخَاصِمُ دُونَهَا فَلاَ يُنْكِحُهَا لِمَالِهَا فَيَضُرُّ بِهَا وَيُسِيءُ صُحْبَتَهَا فَقَالَ ‏\{‏ إِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى فَانْكِحُوا مَا طَابَ لَكُمْ مِنَ النِّسَاءِ‏\}‏ يَقُولُ مَا أَحْلَلْتُ لَكُمْ وَدَعْ هَذِهِ الَّتِي تَضُرُّ بِهَا ‏.‏\hadithno{7530}\hadithtrans{(A'isha said that as for the words of Allah:" If you fear that you would not be able to observe equity in case of orphan girls)," it was revealed in reference to a person who had an orphan girl (as his ward) and he was her guardian, and her heir, and she possessed property, but there was none to contend on her behalf except her ownself. And he (her guardian) did not give her in marriage because of her property and he tortured her and ill-treated her, it was in relation to her that (Allah said: )" If you fear that you would not be able to observe equity in case of orphan girls, then marry whom you like among women," i. e. whatever I have made lawful for you and leave her whom you are putting to torture}}
\hadithdefcmd{muslim}{7531}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، فِي قَوْلِهِ ‏\{‏ وَمَا يُتْلَى عَلَيْكُمْ فِي الْكِتَابِ فِي يَتَامَى النِّسَاءِ اللاَّتِي لاَ تُؤْتُونَهُنَّ مَا كُتِبَ لَهُنَّ وَتَرْغَبُونَ أَنْ تَنْكِحُوهُنَّ‏\}‏ قَالَتْ أُنْزِلَتْ فِي الْيَتِيمَةِ تَكُونُ عِنْدَ الرَّجُلِ فَتَشْرَكُهُ فِي مَالِهِ فَيَرْغَبُ عَنْهَا أَنْ يَتَزَوَّجَهَا وَيَكْرَهُ أَنْ يُزَوِّجَهَا غَيْرَهُ فَيَشْرَكُهُ فِي مَالِهِ فَيَعْضِلُهَا فَلاَ يَتَزَوَّجُهَا وَلاَ يُزَوِّجُهَا غَيْرَهُ ‏.‏\hadithno{7531}\hadithtrans{A'isha said in connection with His words (those of Allah):" What is recited to you in the Book about orphan women whom you give not what is ordained for them, while you like to marry them," these were revealed in connection with an orphan girl who was in the charge of the person and she shared with him in his property and he was reluctant to marry her himself and was also unwilling to marry her to someone else (fearing) that (that person) would share in his property (as the husband of that girl), preventing her to marry, neither marrying her himself nor marrying her to another person}}
\hadithdefcmd{muslim}{7532}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، أَخْبَرَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، فِي قَوْلِهِ ‏\{‏ ويَسْتَفْتُونَكَ فِي النِّسَاءِ قُلِ اللَّهُ يُفْتِيكُمْ فِيهِنَّ‏\}‏ الآيَةَ قَالَتْ هِيَ الْيَتِيمَةُ الَّتِي تَكُونُ عِنْدَ الرَّجُلِ لَعَلَّهَا أَنْ تَكُونَ قَدْ شَرِكَتْهُ فِي مَالِهِ حَتَّى فِي الْعَذْقِ فَيَرْغَبُ يَعْنِي أَنْ يَنْكِحَهَا وَيَكْرَهُ أَنْ يُنْكِحَهَا رَجُلاً فَيَشْرَكُهُ فِي مَالِهِ فَيَعْضِلُهَا ‏.‏\hadithno{7532}\hadithtrans{Hisham reported that 'A'isha said in connection with the words of Allah:" They ask thee the religious verdict about women, say: Allah gives you the verdict about them" (iv. 126), that these relate to an orphan girl who is in charge of the person and she shares with him in his property (as a heir) even in the date-palm trees and he is reluctant to give her hand in marriage to any other person lest he (her husband) should partake of his property, and thus keep her in a lingering state}}
\hadithdefcmd{muslim}{7533}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، فِي قَوْلِهِ ‏\{‏ وَمَنْ كَانَ فَقِيرًا فَلْيَأْكُلْ بِالْمَعْرُوفِ‏\}‏ قَالَتْ أُنْزِلَتْ فِي وَالِي مَالِ الْيَتِيمِ الَّذِي يَقُومُ عَلَيْهِ وَيُصْلِحُهُ إِذَا كَانَ مُحْتَاجًا أَنْ يَأْكُلَ مِنْهُ ‏.‏\hadithno{7533}\hadithtrans{Hisham reported on the authority of his father that 'A'isha said in connection with His (Allah's) words:" And whoever is poor let him take reasonably (out of it)" that it was revealed in connection with the custodian of the property of an orphan, who is in charge of her and looks after her; In case he is poor, he is allowed to eat out of that}}
\hadithdefcmd{muslim}{7534}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، فِي قَوْلِهِ تَعَالَى ‏\{‏ وَمَنْ كَانَ غَنِيًّا فَلْيَسْتَعْفِفْ وَمَنْ كَانَ فَقِيرًا فَلْيَأْكُلْ بِالْمَعْرُوفِ‏\}‏ قَالَتْ أُنْزِلَتْ فِي وَلِيِّ الْيَتِيمِ أَنْ يُصِيبَ مِنْ مَالِهِ إِذَا كَانَ مُحْتَاجًا بِقَدْرِ مَالِهِ بِالْمَعْرُوفِ ‏.‏\hadithno{7534}\hadithtrans{A'isha reported in connection with the words of Allah, the Exalted:" He who is rich should abstain, and he who is poor may reasonably eat (out of it)" that this was revealed in relation to the guardian of an orphan who is poor; he may get out of that what is reasonable keeping in view his own status of solvency}}
\hadithdefcmd{muslim}{7535}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامٌ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{7535}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{7536}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ إِذْ جَاءُوكُمْ مِنْ فَوْقِكُمْ وَمِنْ أَسْفَلَ مِنْكُمْ وَإِذْ زَاغَتِ الأَبْصَارُ وَبَلَغَتِ الْقُلُوبُ الْحَنَاجِرَ‏\}‏ قَالَتْ كَانَ ذَلِكَ يَوْمَ الْخَنْدَقِ ‏.‏\hadithno{7536}\hadithtrans{A'isha reported that these words of Allah:" When they came upon you from above you and from below you and when the eyes turned dull and the hearts rose up to the throats" (xxxiii. 10) pertain to the day of Ditch}}
\hadithdefcmd{muslim}{7537}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، ‏\{‏ وَإِنِ امْرَأَةٌ خَافَتْ مِنْ بَعْلِهَا نُشُوزًا أَوْ إِعْرَاضًا‏\}‏ الآيَةَ قَالَتْ أُنْزِلَتْ فِي الْمَرْأَةِ تَكُونُ عِنْدَ الرَّجُلِ فَتَطُولُ صُحْبَتُهَا فَيُرِيدُ طَلاَقَهَا فَتَقُولُ لاَ تُطَلِّقْنِي وَأَمْسِكْنِي وَأَنْتَ فِي حِلٍّ مِنِّي ‏.‏ فَنَزَلَتْ هَذِهِ الآيَةُ ‏.‏\hadithno{7537}\hadithtrans{A'isha said in connection with the verse:" And if a woman has reason to fear ill-treatment from her husband or that he might turn away from her" (iv. 128) that it was revealed in case of a woman who had long association with a person (as his wife) and now he intends to divorce her and she says: Do not divorce me, but retain me (as wife in your house) and you are permitted to live with another wife. It is in this context that this verse was revealed}}
\hadithdefcmd{muslim}{7538}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ وَإِنِ امْرَأَةٌ خَافَتْ مِنْ بَعْلِهَا نُشُوزًا أَوْ إِعْرَاضًا‏\}‏ قَالَتْ نَزَلَتْ فِي الْمَرْأَةِ تَكُونُ عِنْدَ الرَّجُلِ فَلَعَلَّهُ أَنْ لاَ يَسْتَكْثِرَ مِنْهَا وَتَكُونُ لَهَا صُحْبَةٌ وَوَلَدٌ فَتَكْرَهُ أَنْ يُفَارِقَهَا فَتَقُولُ لَهُ أَنْتَ فِي حِلٍّ مِنْ شَأْنِي ‏.‏\hadithno{7538}\hadithtrans{A'isha said in connection with these words of Allah, the Exalted and Glorious:" And if a woman has reason to fear ill-treatment from her husband or that he might turn away from her" that it was revealed in case of a woman who lived with a person and perhaps he does not want to prolong (his relationship with her) whereas she has had sexual relationship with him (and as a result thereof) she got a child from him and she does not like that she should be divorced, so she says to him: I permit you to live with the other wife}}
\hadithdefcmd{muslim}{7539}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، قَالَ قَالَتْ لِي عَائِشَةُ يَا ابْنَ أُخْتِي أُمِرُوا أَنْ يَسْتَغْفِرُوا، لأَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فَسَبُّوهُمْ ‏.‏\hadithno{7539}\hadithtrans{Urwa reported on the authority of his father that 'A'isha said to him:O, the son of my sister, the Muslims were commanded to seek forgiveness for the Companions of Allah's Apostle (ﷺ) but they reviled them}}
\hadithdefcmd{muslim}{7540}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامٌ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{7540}\hadithtrans{This hadith has been transmitted on the authority of Abu Usama with the same chain of narrators}}
\hadithdefcmd{muslim}{7541}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ الْمُغِيرَةِ بْنِ النُّعْمَانِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ اخْتَلَفَ أَهْلُ الْكُوفَةِ فِي هَذِهِ الآيَةِ ‏\{‏ وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا فَجَزَاؤُهُ جَهَنَّمُ‏\}‏ فَرَحَلْتُ إِلَى ابْنِ عَبَّاسٍ فَسَأَلْتُهُ عَنْهَا فَقَالَ لَقَدْ أُنْزِلَتْ آخِرَ مَا أُنْزِلَ ثُمَّ مَا نَسَخَهَا شَىْءٌ ‏.‏\hadithno{7541}\hadithtrans{Sa'id b. Jubair reported:The inhabitants of Kufa differed in regard to this verse:" But whoever slays another believer intentionally, his requital shall be Hell" (iv. 92), so I went to Ibn 'Abbas and asked him about it, whereupon he said: This has been revealed and nothing abrogated it}}
\hadithdefcmd{muslim}{7542}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ أَخْبَرَنَا النَّضْرُ، قَالاَ جَمِيعًا حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ ‏.‏ فِي حَدِيثِ ابْنِ جَعْفَرٍ نَزَلَتْ فِي آخِرِ مَا أُنْزِلَ ‏.‏ وَفِي حَدِيثِ النَّضْرِ إِنَّهَا لَمِنْ آخِرِ مَا أُنْزِلَتْ ‏.‏\hadithno{7542}\hadithtrans{This hadith has been transmitted on the authority of Shu'ba with the same chain of narrators but with a slight variation of wording}}
\hadithdefcmd{muslim}{7543}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ أَمَرَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبْزَى أَنْ أَسْأَلَ ابْنَ عَبَّاسٍ، عَنْ هَاتَيْنِ الآيَتَيْنِ، ‏\{‏ وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا فَجَزَاؤُهُ جَهَنَّمُ خَالِدًا فِيهَا‏\}‏ فَسَأَلْتُهُ فَقَالَ لَمْ يَنْسَخْهَا شَىْءٌ ‏.‏ وَعَنْ هَذِهِ الآيَةِ ‏\{‏ وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ وَلاَ يَقْتُلُونَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ‏\}‏ قَالَ نَزَلَتْ فِي أَهْلِ الشِّرْكِ ‏.‏\hadithno{7543}\hadithtrans{Sa'id b. Jubair reported:'Abd al Rahman b. Abzi commanded me that I should ask Ibn 'Abbas about these two verses:" He who slays a believer intentionally his requital shall be Hell where he would abide for ever" (iv. 92). So, I asked him and he said: Nothing has abrogated it. And as for this verse:" And they who call not upon another god with Allah and slay not the soul which Allah has forbidden, except in the cause of justice" (xxv. 68), he (Ibn Abbas) said: This has been revealed in regard to the polytheists}}
\hadithdefcmd{muslim}{7544}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو النَّضْرِ، هَاشِمُ بْنُ الْقَاسِمِ اللَّيْثِيُّ حَدَّثَنَا أَبُو مُعَاوِيَةَ، - يَعْنِي شَيْبَانَ - عَنْ مَنْصُورِ بْنِ الْمُعْتَمِرِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ،قَالَ نَزَلَتْ هَذِهِ الآيَةُ بِمَكَّةَ ‏\{‏ وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ مُهَانًا‏\}‏ فَقَالَ الْمُشْرِكُونَ وَمَا يُغْنِي عَنَّا الإِسْلاَمُ وَقَدْ عَدَلْنَا بِاللَّهِ وَقَدْ قَتَلْنَا النَّفْسَ الَّتِي حَرَّمَ اللَّهُ وَأَتَيْنَا الْفَوَاحِشَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ إِلاَّ مَنْ تَابَ وَآمَنَ وَعَمِلَ عَمَلاً صَالِحًا‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏ قَالَ فَأَمَّا مَنْ دَخَلَ فِي الإِسْلاَمِ وَعَقَلَهُ ثُمَّ قَتَلَ فَلاَ تَوْبَةَ لَهُ ‏.‏\hadithno{7544}\hadithtrans{Ibn 'Abbas said:This verse was revealed in Mecca:" And they who call not upon another god with Allah and slay not the soul which Allah has forbidden except in the cause of justice" up to the word Muhdana (abased). Thereupon the polytheists said: Islam is of no avail to us for we have made peer with Allah and we killed the soul which Allah had forbidden to do and we committed debauchery, and it was (on this occasion) that Allah, the Exalted and Glorious, revealed this verse:" Except him who repents and believes and does good deeds" up to the end Ibn 'Abbis says: He who enters the fold of Islam and understands its command and then kills the soul there is no repentance for him}}
\hadithdefcmd{muslim}{7545}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ هَاشِمٍ، وَعَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ الْعَبْدِيُّ، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ الْقَطَّانُ - عَنِ ابْنِ جُرَيْجٍ، حَدَّثَنِي الْقَاسِمُ بْنُ أَبِي بَزَّةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ أَلِمَنْ قَتَلَ مُؤْمِنًا مُتَعَمِّدًا مِنْ تَوْبَةٍ قَالَ لاَ ‏.‏ قَالَ فَتَلَوْتُ عَلَيْهِ هَذِهِ الآيَةَ الَّتِي فِي الْفُرْقَانِ ‏\{‏ وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ وَلاَ يَقْتُلُونَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏ قَالَ هَذِهِ آيَةٌ مَكِّيَّةٌ نَسَخَتْهَا آيَةٌ مَدَنِيَّةٌ ‏\{‏ وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا فَجَزَاؤُهُ جَهَنَّمُ خَالِدًا‏\}‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ هَاشِمٍ فَتَلَوْتُ هَذِهِ الآيَةَ الَّتِي فِي الْفُرْقَانِ‏\{‏ إِلاَّ مَنْ تَابَ‏\}‏\hadithno{7545}\hadithtrans{Sa'id b. Jubair reported:I said to Ibn Abbas: Will the repentance of that person be accepted who kills a believer intentionally? He said: No. I recited to him this verse of Sura al-Furqan (xix.):" And those who call not upon another god with Allah and slay not the soul which Allah has forbidden except in the cause of justice" to the end of the verse. He said: This is a Meccan verse which has been abrogated by a verse revealed at Medina:" He who slays a believer intentionally, for him is the requital of Hell-Fire where he would abide for ever," and in the narration of Ibn Hisham (the words are): I recited to him this verse of Sura al-Furqan:" Except one who made repentance}}
\hadithdefcmd{muslim}{7546}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، أَخْبَرَنَا أَبُو عُمَيْسٍ، عَنْ عَبْدِ الْمَجِيدِ بْنِ سُهَيْلٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، قَالَ قَالَ لِيَ ابْنُ عَبَّاسٍ تَعْلَمُ - وَقَالَ هَارُونُ تَدْرِي - آخِرَ سُورَةٍ نَزَلَتْ مِنَ الْقُرْآنِ نَزَلَتْ جَمِيعًا قُلْتُ نَعَمْ ‏.‏ ‏\{‏ إِذَا جَاءَ نَصْرُ اللَّهِ وَالْفَتْحُ‏\}‏ قَالَ صَدَقْتَ ‏.‏ وَفِي رِوَايَةِ ابْنِ أَبِي شَيْبَةَ تَعْلَمُ أَىُّ سُورَةٍ ‏.‏ وَلَمْ يَقُلْ آخِرَ ‏.‏\hadithno{7546}\hadithtrans{Ubaidullah b. 'Abdullah b. 'Utba reported:Ibn Abbas said to me: Do you know-and in the words of Harun (another narrator): Are you aware of-the last Sura which was revealed in the Qur'an as a whole? I said: Yes," When came the help from Allah and the victory" (cx.). Thereupon, he said: You have told the truth. And in the narration of Abu Shaiba (the words are): Do you know the Sura? And he did not mention the words" the last one}}
\hadithdefcmd{muslim}{7547}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا أَبُو عُمَيْسٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ وَقَالَ آخِرَ سُورَةٍ وَقَالَ عَبْدُ الْمَجِيدِ وَلَمْ يَقُلِ ابْنِ سُهَيْلٍ ‏.‏\hadithno{7547}\hadithtrans{This hadith has been reported on the authority of Abu 'Umais through the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{7548}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَأَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، - وَاللَّفْظُ لاِبْنِ أَبِي شَيْبَةَ - قَالَ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَقِيَ نَاسٌ مِنَ الْمُسْلِمِينَ رَجُلاً فِي غُنَيْمَةٍ لَهُ فَقَالَ السَّلاَمُ عَلَيْكُمْ ‏.‏ فَأَخَذُوهُ فَقَتَلُوهُ وَأَخَذُوا تِلْكَ الْغُنَيْمَةَ فَنَزَلَتْ ‏\{‏ وَلاَ تَقُولُوا لِمَنْ أَلْقَى إِلَيْكُمُ السَّلَمَ لَسْتَ مُؤْمِنًا‏\}‏ وَقَرَأَهَا ابْنُ عَبَّاسٍ السَّلاَمَ ‏.‏\hadithno{7548}\hadithtrans{Ibn Abbas reported that some Muslims met a person with a small flock of sheep. He said:As-Salam-o-'Alaikum. They caught hold of him and killed him and took possession of his flock. Then this verse was revealed:" He who meets you and extends you salutations, don't say: You are not a Muslim" (iv. 94). Ibn 'Abbas, however, recited the word as-Salam instead of" as-Salam}}
\hadithdefcmd{muslim}{7549}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ، يَقُولُ كَانَتِ الأَنْصَارُ إِذَا حَجُّوا فَرَجَعُوا لَمْ يَدْخُلُوا الْبُيُوتَ إِلاَّ مِنْ ظُهُورِهَا - قَالَ - فَجَاءَ رَجُلٌ مِنَ الأَنْصَارِ فَدَخَلَ مِنْ بَابِهِ فَقِيلَ لَهُ فِي ذَلِكَ فَنَزَلَتْ هَذِهِ الآيَةُ ‏\{‏وَلَيْسَ الْبِرُّ بِأَنْ تَأْتُوا الْبُيُوتَ مِنْ ظُهُورِهَا‏\}‏ ‏.‏\hadithno{7549}\hadithtrans{Bara' reported:When the Ansar performed the Pilgrimage, they did not enter their houses but from behind. A person from the Ansar came and he began to enter from his door but it was said to him (why he was doing something in contravention to the common practice of coming to the houses from behind). Then this verse was revealed." Piety is not that you come to the doors from behind" (ii)}}
\hadithdefcmd{muslim}{7550}{حَدَّثَنِي يُونُسُ بْنُ عَبْدِ الأَعْلَى الصَّدَفِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو، بْنُ الْحَارِثِ عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ عَوْنِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّ ابْنَ مَسْعُودٍ، قَالَ مَا كَانَ بَيْنَ إِسْلاَمِنَا وَبَيْنَ أَنْ عَاتَبَنَا اللَّهُ بِهَذِهِ الآيَةِ ‏\{‏ أَلَمْ يَأْنِ لِلَّذِينَ آمَنُوا أَنْ تَخْشَعَ قُلُوبُهُمْ لِذِكْرِ اللَّهِ‏\}‏ إِلاَّ أَرْبَعُ سِنِينَ ‏.‏\hadithno{7550}\hadithtrans{Ibn Mas'ud said:Since our acceptance of Islam and the revelation of this verse in which Allah has shown annoyance to us:" Has not the time yet come for the believers that their hearts should be humble for the remembrance of Allah?" (lvii. 16), there was a gap of four years}}
\hadithdefcmd{muslim}{7551}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ مُسْلِمٍ الْبَطِينِ، عَنْ سَعِيدِ بْنِ، جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَتِ الْمَرْأَةُ تَطُوفُ بِالْبَيْتِ وَهِيَ عُرْيَانَةٌ فَتَقُولُ مَنْ يُعِيرُنِي تِطْوَافًا تَجْعَلُهُ عَلَى فَرْجِهَا وَتَقُولُ الْيَوْمَ يَبْدُو بَعْضُهُ أَوْ كُلُّهُ فَمَا بَدَا مِنْهُ فَلاَ أُحِلُّهُ فَنَزَلَتْ هَذِهِ الآيَةَ ‏\{‏ خُذُوا زِينَتَكُمْ عِنْدَ كُلِّ مَسْجِدٍ‏\}‏\hadithno{7551}\hadithtrans{Ibn Abbas reported:During the pre-Islamic days women circumambulated the Ka'ba nakedly, and said: Who would provide cloth to cover the one who is circumambulating the Ka'ba so that she would cover her private parts? And then she would say: Today will be exposed the whole or the part and what is exposed I shall not make it lawful. It was in this connection that the verse was revealed:" Adorn yourself at every place of worship" (vii)}}
\hadithdefcmd{muslim}{7552}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ جَمِيعًا عَنْ أَبِي مُعَاوِيَةَ، - وَاللَّفْظُ لأَبِي كُرَيْبٍ - حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ كَانَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ ابْنُ سَلُولَ يَقُولُ لِجَارِيَةٍ لَهُ اذْهَبِي فَابْغِينَا شَيْئًا فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَلاَ تُكْرِهُوا فَتَيَاتِكُمْ عَلَى الْبِغَاءِ إِنْ أَرَدْنَ تَحَصُّنًا لِتَبْتَغُوا عَرَضَ الْحَيَاةِ الدُّنْيَا وَمَنْ يُكْرِهْهُنَّ فَإِنَّ اللَّهَ مِنْ بَعْدِ إِكْرَاهِهِنَّ‏\}‏ لَهُنَّ ‏\{‏ غَفُورٌ رَحِيمٌ‏\}‏\hadithno{7552}\hadithtrans{Jabir reported that 'Abdullah b. Ubayy b. Salul used to say to his slave-girl:Go and fetch something for us by committing prostitution. It was in this connection that Allah, the Exalted and Glorious, revealed this verse:" And compel not your slave-girls to prostitution when they desire to keep chaste in order to seek the frail goods of this world's life, and whoever compels them, then surely after their compulsion Allah is Forgiving, Merciful" (xxiv)}}
\hadithdefcmd{muslim}{7553}{وَحَدَّثَنِي أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، أَنَّ جَارِيَةً، لِعَبْدِ اللَّهِ بْنِ أُبَىٍّ ابْنِ سَلُولَ يُقَالُ لَهَا مُسَيْكَةُ وَأُخْرَى يُقَالُ لَهَا أُمَيْمَةُ فَكَانَ يُكْرِهُهُمَا عَلَى الزِّنَى فَشَكَتَا ذَلِكَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَنْزَلَ اللَّهُ ‏\{‏ وَلاَ تُكْرِهُوا فَتَيَاتِكُمْ عَلَى الْبِغَاءِ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ غَفُورٌ رَحِيمٌ‏\}‏\hadithno{7553}\hadithtrans{Jabir reported that 'Abdullah b. Ubayy b. Salul had two slave-girls; one was called Musaika and the other one was called Umaima and he compelled them to prostitution (for which'Abdullah b. Ubayy b. Salul compelled them). They made a complaint about this to Allah's Messenger (ﷺ) and it was upon this that this verse was revealed:" And compel not your slave-girls to prostitute" up to the words:" Allah is Forgiving, Merciful}}
\hadithdefcmd{muslim}{7554}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ، فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ أُولَئِكَ الَّذِينَ يَدْعُونَ يَبْتَغُونَ إِلَى رَبِّهِمُ الْوَسِيلَةَ أَيُّهُمْ أَقْرَبُ‏\}‏ قَالَ كَانَ نَفَرٌ مِنَ الْجِنِّ أَسْلَمُوا وَكَانُوا يُعْبَدُونَ فَبَقِيَ الَّذِينَ كَانُوا يَعْبُدُونَ عَلَى عِبَادَتِهِمْ وَقَدْ أَسْلَمَ النَّفَرُ مِنَ الْجِنِّ ‏.‏\hadithno{7554}\hadithtrans{Abdullah b. Mas'ud reported in connection with the words of Allah, the Exalted and Glorious:" Those to whom they call upon, themselves seek the means or access to their Lord as to whoever of them becomes nearest" (xvii. 57) that it related to a party of Jinn who were being worshipped and they embraced Islam but those who worshipped them kept on worshipping them (though the Jinn whom the misguided people worshipped had become Muslims). It was then that this verse was revealed}}
\hadithdefcmd{muslim}{7556}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنِي أَبِي، حَدَّثَنَا حُسَيْنٌ، عَنْ قَتَادَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْبَدٍ الزِّمَّانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ، مَسْعُودٍ ‏\{‏ أُولَئِكَ الَّذِينَ يَدْعُونَ يَبْتَغُونَ إِلَى رَبِّهِمُ الْوَسِيلَةَ‏\}‏ قَالَ نَزَلَتْ فِي نَفَرٍ مِنَ الْعَرَبِ كَانُوا يَعْبُدُونَ نَفَرًا مِنَ الْجِنِّ فَأَسْلَمَ الْجِنِّيُّونَ وَالإِنْسُ الَّذِينَ كَانُوا يَعْبُدُونَهُمْ لاَ يَشْعُرُونَ فَنَزَلَتْ ‏\{‏ أُولَئِكَ الَّذِينَ يَدْعُونَ يَبْتَغُونَ إِلَى رَبِّهِمُ الْوَسِيلَةَ‏\}‏\hadithno{7556}\hadithtrans{Abdullah b. Mas'ud said in connection with the verse:" Those whom they call upon, themselves seek the means of access to their Lord," that that verse was revealed in connection with a party of Arabs who used to worship a group amnogst the jinn; the jinn embraced Islam but the people kept worshipping them without being conscious of it. Then this verse was revealed:" Those whom they call upon, themselves seek the means of access to their Lord}}
\hadithdefcmd{muslim}{7558}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُطِيعٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ سُورَةُ التَّوْبَةِ قَالَ آلتَّوْبَةِ قَالَ بَلْ هِيَ الْفَاضِحَةُ مَا زَالَتْ تَنْزِلُ وَمِنْهُمْ وَمِنْهُمْ ‏.‏ حَتَّى ظَنُّوا أَنْ لاَ يَبْقَى مِنَّا أَحَدٌ إِلاَّ ذُكِرَ فِيهَا ‏.‏ قَالَ قُلْتُ سُورَةُ الأَنْفَالِ قَالَ تِلْكَ سُورَةُ بَدْرٍ ‏.‏ قَالَ قُلْتُ فَالْحَشْرُ قَالَ نَزَلَتْ فِي بَنِي النَّضِيرِ ‏.‏\hadithno{7558}\hadithtrans{Sa'id b. Jubair reported:I said to Ibn 'Abbas about Sura Tauba, whereupon he said: As for Sura Tauba, it is meant to humiliate (the non-believers and the hypocrites). There is constantly revealed in it (the pronoun) minhum (of them) and minhom (of them, i. e. such is the condition of some of them) till they (the Muslims) thought that none would be left unmentioned out of them who would not be blamed (for one fault or the other). I again said: What about Sura Anfal? He said: It pertains to the Battle of Badr. I again asked him about Sura al-Hashr. He said: It was revealed in connection with (the tribe) of Banu Nadir}}
\hadithdefcmd{muslim}{7559}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ أَبِي حَيَّانَ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عُمَرَ، قَالَ خَطَبَ عُمَرُ عَلَى مِنْبَرِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ أَمَّا بَعْدُ أَلاَ وَإِنَّ الْخَمْرَ نَزَلَ تَحْرِيمُهَا يَوْمَ نَزَلَ وَهْىَ مِنْ خَمْسَةِ أَشْيَاءَ مِنَ الْحِنْطَةِ وَالشَّعِيرِ وَالتَّمْرِ وَالزَّبِيبِ وَالْعَسَلِ ‏.‏ وَالْخَمْرُ مَا خَامَرَ الْعَقْلَ وَثَلاَثَةُ أَشْيَاءَ وَدِدْتُ أَيُّهَا النَّاسُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عَهِدَ إِلَيْنَا فِيهَا الْجَدُّ وَالْكَلاَلَةُ وَأَبْوَابٌ مِنْ أَبْوَابِ الرِّبَا ‏.‏\hadithno{7559}\hadithtrans{Ibn 'Umar reported that Umar delivered a sermon on the pulpit of Allah's Messenger (ﷺ) and he praised Allah and lauded Him and then said:Now coming to the point. Behold I when the command pertaining to the prohibition of wine was revealed, it was prepared from five things: from wheat, barley, date, grape, honey; and wine is that which clouds the intellect; and O people, I wish Allah's Messenger (ﷺ) could have explained to us in (more) detail the laws pertaining to the inheritance of the grandfather, about one who dies leaving no issue, and some of the problems pertaining to interest}}
\hadithdefcmd{muslim}{7560}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، أَخْبَرَنَا ابْنُ إِدْرِيسَ، حَدَّثَنَا أَبُو حَيَّانَ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ، عُمَرَ قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، عَلَى مِنْبَرِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ أَمَّا بَعْدُ أَيُّهَا النَّاسُ فَإِنَّهُ نَزَلَ تَحْرِيمُ الْخَمْرِ وَهْىَ مِنْ خَمْسَةٍ مِنَ الْعِنَبِ وَالتَّمْرِ وَالْعَسَلِ وَالْحِنْطَةِ وَالشَّعِيرِ وَالْخَمْرُ مَا خَامَرَ الْعَقْلَ وَثَلاَثٌ أَيُّهَا النَّاسُ وَدِدْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ عَهِدَ إِلَيْنَا فِيهِنَّ عَهْدًا نَنْتَهِي إِلَيْهِ الْجَدُّ وَالْكَلاَلَةُ وَأَبْوَابٌ مِنْ أَبْوَابِ الرِّبَا ‏.‏\hadithno{7560}\hadithtrans{Ibn 'Umar reported:I heard 'Umar b. Khattab delivering sermon on the pulpit ol Allah's messenger (ﷺ) and saying': Now, coming to the point, O people, there was revealed (the command pertaining to the prohibition of wine) and it was prepared (at that time) out of five things: grape, date, honey, wheat, barley, and wine is that which clouds the intellect, and, O people, I wish Allah's Messenger (ﷺ) had explained to us in greater detail three things: the inheritance of the grandfather, of one who dies without leaving any issue, and some of the problems of interest}}
\hadithdefcmd{muslim}{7561}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كِلاَهُمَا عَنْ أَبِي حَيَّانَ، بِهَذَا الإِسْنَادِ ‏.‏ بِمِثْلِ حَدِيثِهِمَا غَيْرَ أَنَّ ابْنَ عُلَيَّةَ فِي حَدِيثِهِ الْعِنَبِ ‏.‏ كَمَا قَالَ ابْنُ إِدْرِيسَ وَفِي حَدِيثِ عِيسَى الزَّبِيبِ ‏.‏ كَمَا قَالَ ابْنُ مُسْهِرٍ ‏.‏\hadithno{7561}\hadithtrans{This hadith has been transmitted on the same authority but with a slight variation of wording}}
\hadithdefcmd{muslim}{7562}{حَدَّثَنَا عَمْرُو بْنُ زُرَارَةَ، حَدَّثَنَا هُشَيْمٌ، عَنْ أَبِي هَاشِمٍ، عَنْ أَبِي مِجْلَزٍ، عَنْ قَيْسِ، بْنِ عُبَادٍ قَالَ سَمِعْتُ أَبَا ذَرٍّ، يُقْسِمُ قَسَمًا إِنَّ ‏\{‏ هَذَانِ خَصْمَانِ اخْتَصَمُوا فِي رَبِّهِمْ‏\}‏ إِنَّهَا نَزَلَتْ فِي الَّذِينَ بَرَزُوا يَوْمَ بَدْرٍ حَمْزَةُ وَعَلِيٌّ وَعُبَيْدَةُ بْنُ الْحَارِثِ وَعُتْبَةُ وَشَيْبَةُ ابْنَا رَبِيعَةَ وَالْوَلِيدُ بْنُ عُتْبَةَ ‏.‏\hadithno{7562}\hadithtrans{Abu Dharr took an oath that this verse:" These two adversaries who dispute about their Lord" (xxii. 19) was revealed in connection with those who on the Day of Badr came out (of rows to fight against the non-believers and they were) Hamza, 'Ali, 'Ubaida b. Harith (from the side of the Muslims) and 'Utba and Shaiba, both of them the sons of Rabi'a and Walid b. 'Utba (from the side of the non-believers of Mecca)}}
\hadithdefcmd{muslim}{7563}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، جَمِيعًا عَنْ سُفْيَانَ، عَنْ أَبِي هَاشِمٍ، عَنْ أَبِي مِجْلَزٍ، عَنْ قَيْسِ بْنِ عُبَادٍ، قَالَ سَمِعْتُ أَبَا ذَرٍّ، يُقْسِمُ لَنَزَلَتْ ‏\{‏ هَذَانِ خَصْمَانِ‏\}‏ بِمِثْلِ حَدِيثِ هُشَيْمٍ ‏.‏\hadithno{7563}\hadithtrans{This hadith has been narrated on the authority of Abu Dharr through another chain of transmitters}}
