% Auto-generated chapter 54 for malik
% Hadiths in this chapter: 45

\hadithdefcmd{malik}{1763}{حَدَّثَنِي مَالِكٌ، عَنْ صَفْوَانَ بْنَ سُلَيْمٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَأَلَهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ أَسْتَأْذِنُ عَلَى أُمِّي فَقَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ الرَّجُلُ إِنِّي مَعَهَا فِي الْبَيْتِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اسْتَأْذِنْ عَلَيْهَا ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ إِنِّي خَادِمُهَا ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اسْتَأْذِنْ عَلَيْهَا أَتُحِبُّ أَنْ تَرَاهَا عُرْيَانَةً ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَاسْتَأْذِنْ عَلَيْهَا ‏"‏ ‏.‏\hadithno{1763}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{}}
\hadithdefcmd{malik}{1764}{وَحَدَّثَنِي مَالِكٌ، عَنِ الثِّقَةِ، عِنْدَهُ عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الاِسْتِئْذَانُ ثَلاَثٌ فَإِنْ أُذِنَ لَكَ فَادْخُلْ وَإِلاَّ فَارْجِعْ ‏"‏ ‏.‏\hadithno{1764}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from a reliable source of his from Bukayr ibn Abdullah ibn al-Ashajj from Basr ibn Said from Abu Said al-Khudri that Abu Musa al-Ashari said, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'One asks permission three times. If you are given permission, then enter. If not, go away}}
\hadithdefcmd{malik}{1765}{وَحَدَّثَنِي مَالِكٌ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ غَيْرِ، وَاحِدٍ، مِنْ عُلَمَائِهِمْ أَنَّ أَبَا مُوسَى الأَشْعَرِيَّ، جَاءَ يَسْتَأْذِنُ عَلَى عُمَرَ بْنِ الْخَطَّابِ فَاسْتَأْذَنَ ثَلاَثًا ثُمَّ رَجَعَ فَأَرْسَلَ عُمَرُ بْنُ الْخَطَّابِ فِي أَثَرِهِ فَقَالَ مَا لَكَ لَمْ تَدْخُلْ فَقَالَ أَبُو مُوسَى سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ الاِسْتِئْذَانُ ثَلاَثٌ فَإِنْ أُذِنَ لَكَ فَادْخُلْ وَإِلاَّ فَارْجِعْ ‏"‏ ‏.‏ فَقَالَ عُمَرُ وَمَنْ يَعْلَمُ هَذَا لَئِنْ لَمْ تَأْتِنِي بِمَنْ يَعْلَمُ ذَلِكَ لأَفْعَلَنَّ بِكَ كَذَا وَكَذَا ‏.‏ فَخَرَجَ أَبُو مُوسَى حَتَّى جَاءَ مَجْلِسًا فِي الْمَسْجِدِ يُقَالُ لَهُ مَجْلِسُ الأَنْصَارِ فَقَالَ إِنِّي أَخْبَرْتُ عُمَرَ بْنَ الْخَطَّابِ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ الاِسْتِئْذَانُ ثَلاَثٌ فَإِنْ أُذِنَ لَكَ فَادْخُلْ وَإِلاَّ فَارْجِعْ ‏"‏ ‏.‏ فَقَالَ لَئِنْ لَمْ تَأْتِنِي بِمَنْ يَعْلَمُ هَذَا لأَفْعَلَنَّ بِكَ كَذَا وَكَذَا ‏.‏ فَإِنْ كَانَ سَمِعَ ذَلِكَ أَحَدٌ مِنْكُمْ فَلْيَقُمْ مَعِي ‏.‏ فَقَالُوا لأَبِي سَعِيدٍ الْخُدْرِيِّ قُمْ مَعَهُ ‏.‏ وَكَانَ أَبُو سَعِيدٍ أَصْغَرَهُمْ فَقَامَ مَعَهُ فَأَخْبَرَ بِذَلِكَ عُمَرَ بْنَ الْخَطَّابِ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ لأَبِي مُوسَى أَمَا إِنِّي لَمْ أَتَّهِمْكَ وَلَكِنْ خَشِيتُ أَنْ يَتَقَوَّلَ النَّاسُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1765}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Rabia ibn Abi Abd ar-Rahman from another of the ulama of that time that Abu Musa al-Ashari came and asked permission from Umar ibn al-Khattab to enter. He asked permission three times, and then went away Umar ibn al-Khattab sent after him and said, "What's wrong with you? Why didn't you come in?" Abu Musa said, "I heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'Ask permission to enter three times. If you are given permission, then enter. If not, go away.' ''Umar said, "Who can confirm this? If you do not bring me someone to confirm it, I will do such-and-such to you." Abu Musa went out until he came to an assembly in the mosque which was called the Majlis-al-Ansar. He said, "I told Umar ibn al-Khattab that I heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'Ask permission three times. If you are given permission, then enter. If not, go away.' Umar said, 'If you do not bring me someone who can confirm it, I will do such- and-such to you'. If any of you have heard that, let him come with me.' " They said to Abu Said al-Khudri, "Go with him". Abu Said was the youngest of them. He went with him and told Umar ibn al-Khattab about that." Umar ibn al-Khattab said to Abu Musa, "I did not suspect you, but I feared lest people forge sayings of the Messenger of Allah, may Allah bless him and grant him peace}}
\hadithdefcmd{malik}{1766}{حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنْ عَطَسَ فَشَمِّتْهُ ثُمَّ إِنْ عَطَسَ فَشَمِّتْهُ ثُمَّ إِنْ عَطَسَ فَشَمِّتْهُ ثُمَّ إِنْ عَطَسَ فَقُلْ إِنَّكَ مَضْنُوكٌ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ لاَ أَدْرِي أَبَعْدَ الثَّالِثَةِ أَوِ الرَّابِعَةِ\hadithno{1766}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Malik related to me from Abdullah ibn Abi Bakr from his father that the Messenger of Allah, may Allah bless him and grant him peace, said, "If a man sneezes, invoke a blessing on him. Then if he sneezes, invoke a blessing on him. Then if he sneezes, invoke a blessing on him. Then if he sneezes, say, 'You have a cold'." Abdullah ibn Abi Bakr said, "I don't know whether it was after the third or fourth}}
\hadithdefcmd{malik}{1767}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، كَانَ إِذَا عَطَسَ فَقِيلَ لَهُ يَرْحَمُكَ اللَّهُ ‏.‏ قَالَ يَرْحَمُنَا اللَّهُ وَإِيَّاكُمْ وَيَغْفِرُ لَنَا وَلَكُمْ ‏.‏\hadithno{1767}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Nafi that when Abdullah ibn Umar sneezed and someone said to him, "May Allah have mercy on you," (Yarhamuka'llah), he said, "May Allah have mercy on us and you, and forgive us and you." (Yarhamuna'llah wa yaghfirlana wa lakum)}}
\hadithdefcmd{malik}{1768}{حَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّ رَافِعَ بْنَ إِسْحَاقَ، مَوْلَى الشِّفَاءِ أَخْبَرَهُ قَالَ دَخَلْتُ أَنَا وَعَبْدُ اللَّهِ بْنُ أَبِي طَلْحَةَ، عَلَى أَبِي سَعِيدٍ الْخُدْرِيِّ نَعُودُهُ فَقَالَ لَنَا أَبُو سَعِيدٍ أَخْبَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَّ الْمَلاَئِكَةَ لاَ تَدْخُلُ بَيْتًا فِيهِ تَمَاثِيلُ أَوْ تَصَاوِيرُ ‏"‏ ‏.‏ شَكَّ إِسْحَاقُ لاَ يَدْرِي أَيَّتَهُمَا قَالَ أَبُو سَعِيدٍ ‏.‏\hadithno{1768}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Ishaq ibn Abdullah ibn Abi Talha that Rafi ibn Ishaq, the mawla of ash-Shifa informed him that he and Abdullah ibn Abi Talha had gone to visit Abu Said al-Khudri while he was ill. Abu Said said to them, "The Messenger of Allah, may Allah bless him and grant him peace, informed us, 'The angels do not enter a house which contains pictures or images.' " Ishaq was not sure which of them Abu Said said}}
\hadithdefcmd{malik}{1769}{وَحَدَّثَنِي مَالِكٌ، عَنْ أَبِي النَّضْرِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّهُ دَخَلَ عَلَى أَبِي طَلْحَةَ الأَنْصَارِيِّ يَعُودُهُ قَالَ فَوَجَدَ عِنْدَهُ سَهْلَ بْنَ حُنَيْفٍ فَدَعَا أَبُو طَلْحَةَ إِنْسَانًا فَنَزَعَ نَمَطًا مِنْ تَحْتِهِ فَقَالَ لَهُ سَهْلُ بْنُ حُنَيْفٍ لِمَ تَنْزِعُهُ قَالَ لأَنَّ فِيهِ تَصَاوِيرَ وَقَدْ قَالَ فِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مَا قَدْ عَلِمْتَ ‏.‏ فَقَالَ سَهْلٌ أَلَمْ يَقُلْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِلاَّ مَا كَانَ رَقْمًا فِي ثَوْبٍ ‏"‏ ‏.‏ قَالَ بَلَى وَلَكِنَّهُ أَطْيَبُ لِنَفْسِي ‏.‏\hadithno{1769}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abu'n-Nasr that Ubaydullah ibn Abdullah ibn Utba ibn Masud went to visit Abu Talha al-Ansari when he was ill. He said, "I found Sahl ibn Hunayf with him. Abu Talha summoned a man and removed a rug which was under him. Sahl ibn Hunayf said to him, 'Why did you remove it?' He said, 'Because there were pictures on it, and the Messenger of Allah, may Allah bless him and grant him peace, said what you know about them.' Sahl replied, 'Didn't the Messenger of Allah, may Allah bless him and grant him peace, say, "except for markings on a garment?"' (A rug was considered a garment). He said, 'Yes, but it is more pleasing to myself}}
\hadithdefcmd{malik}{1770}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا اشْتَرَتْ نُمْرُقَةً فِيهَا تَصَاوِيرُ فَلَمَّا رَآهَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَامَ عَلَى الْبَابِ فَلَمْ يَدْخُلْ فَعَرَفَتْ فِي وَجْهِهِ الْكَرَاهِيَةَ وَقَالَتْ يَا رَسُولَ اللَّهِ أَتُوبُ إِلَى اللَّهِ وَإِلَى رَسُولِهِ فَمَاذَا أَذْنَبْتُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَمَا بَالُ هَذِهِ النُّمْرُقَةِ ‏"‏ ‏.‏ قَالَتِ اشْتَرَيْتُهَا لَكَ تَقْعُدُ عَلَيْهَا وَتَوَسَّدُهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ أَصْحَابَ هَذِهِ الصُّوَرِ يُعَذَّبُونَ يَوْمَ الْقِيَامَةِ يُقَالُ لَهُمْ أَحْيُوا مَا خَلَقْتُمْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ الْبَيْتَ الَّذِي فِيهِ الصُّوَرُ لاَ تَدْخُلُهُ الْمَلاَئِكَةُ ‏"‏ ‏.‏\hadithno{1770}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Nafi from al-Qasim ibn Muhammad from A'isha, the wife of the Prophet, may Allah bless him and grant him peace, that she bought a cushion which had pictures on it. When the Messenger of Allah, may Allah bless him and grant him peace, saw it, he stopped at the door and did not enter. She recognised disapproval on his face and said, "Messenger of Allah, I turn in repentance to Allah and His Messenger. What have I done wrong?" The Messenger of Allah, may Allah bless him and grant him peace, said, "What is the meaning of this cushion?" She said, "I bought it for you to sit and recline on." The Messenger of Allah, may Allah bless him and grant him peace, said, "Those who make such pictures will be punished on the Day of Rising. It will be said to them, 'Bring to life what you have created'. Then he said, 'The angels do not enter a house in which there are pictures}}
\hadithdefcmd{malik}{1771}{حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّهُ قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْتَ مَيْمُونَةَ بِنْتِ الْحَارِثِ فَإِذَا ضِبَابٌ فِيهَا بَيْضٌ وَمَعَهُ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ وَخَالِدُ بْنُ الْوَلِيدِ فَقَالَ ‏"‏ مِنْ أَيْنَ لَكُمْ هَذَا ‏"‏ ‏.‏ فَقَالَتْ أَهْدَتْهُ لِي أُخْتِي هُزَيْلَةُ بِنْتُ الْحَارِثِ ‏.‏ فَقَالَ لِعَبْدِ اللَّهِ بْنِ عَبَّاسٍ وَخَالِدِ بْنِ الْوَلِيدِ ‏"‏ كُلاَ ‏"‏ ‏.‏ فَقَالاَ أَوَلاَ تَأْكُلُ أَنْتَ يَا رَسُولَ اللَّهِ فَقَالَ ‏"‏ إِنِّي تَحْضُرُنِي مِنَ اللَّهِ حَاضِرَةٌ ‏"‏ ‏.‏ قَالَتْ مَيْمُونَةُ أَنَسْقِيكَ يَا رَسُولَ اللَّهِ مِنْ لَبَنٍ عِنْدَنَا فَقَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَلَمَّا شَرِبَ قَالَ ‏"‏ مِنْ أَيْنَ لَكُمْ هَذَا ‏"‏ ‏.‏ فَقَالَتْ أَهْدَتْهُ لِي أُخْتِي هُزَيْلَةُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرَأَيْتِكِ جَارِيَتَكِ الَّتِي كُنْتِ اسْتَأْمَرْتِينِي فِي عِتْقِهَا أَعْطِيهَا أُخْتَكِ وَصِلِي بِهَا رَحِمَكِ تَرْعَى عَلَيْهَا فَإِنَّهُ خَيْرٌ لَكِ ‏"‏ ‏.‏\hadithno{1771}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Malik related to me from Abd ar-Rahman ibn Abdullah ibn Abd ar- Rahman ibn Abi Sasaca that Sulayman ibn Yasar said, "The Messenger of Allah, may Allah bless him and grant him peace, entered the house of Maimuna bint al-Harith and there was a lizard in which there were eggs to eat. Abdullah ibn Abbas and Khalid ibn al-Walid were with him. He said, 'From where did you get this?' She replied, 'My sister, Huzayla bint al-Harith, gave it to me.' He then told Abdullah ibn Abbas and Khalid to eat. They said, 'Won't you eat, Messenger of Allah?' He said, 'There are those who visit me from Allah.' Maimuna said, 'Messenger of Allah, shall we give you some milk to drink which we have?' He said, 'Yes.' When he drank, he said, 'From where did you get this?' She said, 'My sister, Huzayla gave it to me.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'Do you see your slave-girl whom you asked me for permission to free? Give her to your sister and bring her to your maternal relatives to take care of her. That is better for you}}
\hadithdefcmd{malik}{1772}{وَحَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ خَالِدِ بْنِ الْوَلِيدِ بْنِ الْمُغِيرَةِ، أَنَّهُ دَخَلَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بَيْتَ مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَأُتِيَ بِضَبٍّ مَحْنُوذٍ فَأَهْوَى إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ ‏.‏ فَقَالَ بَعْضُ النِّسْوَةِ اللاَّتِي فِي بَيْتِ مَيْمُونَةَ أَخْبِرُوا رَسُولَ اللَّهِ صلى الله عليه وسلم بِمَا يُرِيدُ أَنْ يَأْكُلَ مِنْهُ ‏.‏ فَقِيلَ هُوَ ضَبٌّ يَا رَسُولَ اللَّهِ ‏.‏ فَرَفَعَ يَدَهُ فَقُلْتُ أَحَرَامٌ هُوَ يَا رَسُولَ اللَّهِ فَقَالَ ‏ "‏ لاَ وَلَكِنَّهُ لَمْ يَكُنْ بِأَرْضِ قَوْمِي فَأَجِدُنِي أَعَافُهُ ‏"‏ ‏.‏ قَالَ خَالِدٌ فَاجْتَرَرْتُهُ فَأَكَلْتُهُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَنْظُرُ ‏.‏\hadithno{1772}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Ibn Shihab from Abu Umama ibn Sahl ibn Hunayf from Abdullah ibn Abbas that Khalid ibn al-Walid ibn al-Mughira entered the house of Maimuna, the wife of the Prophet, may Allah bless him and grant him peace, with the Messenger of Allah, may Allah bless him and grant him peace, and he was brought a roasted lizard. The Messenger of Allah, may Allah bless him and grant him peace, stretched his hand toward it. One of the women who was in Maimuna's house said, "Tell the Messenger of Allah, may Allah bless him and grant him peace, what he means to eat." Someone said, "It is a lizard, Messenger of Allah." He withdrew his hand. Khalid said, "Is it haram, Messenger of Allah?" He said, "No, but there were none in my people's land, and I find that I dislike them." Khalid added, "I chewed and ate it while the Messenger of Allah, may Allah bless him and grant him peace, was looking}}
\hadithdefcmd{malik}{1773}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَجُلاً، نَادَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ مَا تَرَى فِي الضَّبِّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَسْتُ بِآكِلِهِ وَلاَ بِمُحَرِّمِهِ ‏"‏ ‏.‏\hadithno{1773}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abdullah ibn Dinar from Abdullah ibn Umar that a man called the Messenger of Allah and said, "Messenger of Allah, what do you think about lizards?" The Messenger of Allah, may Allah bless him and grant him peace, said, "I do not eat them, and I do not forbid them}}
\hadithdefcmd{malik}{1774}{حَدَّثَنِي مَالِكٌ، عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، أَنَّ السَّائِبَ بْنَ يَزِيدَ، أَخْبَرَهُ أَنَّهُ، سَمِعَ سُفْيَانَ بْنَ أَبِي زُهَيْرٍ، وَهُوَ رَجُلٌ مِنْ أَزْدِ شَنُوءَةَ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يُحَدِّثُ نَاسًا مَعَهُ عِنْدَ بَابِ الْمَسْجِدِ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ اقْتَنَى كَلْبًا لاَ يُغْنِي عَنْهُ زَرْعًا وَلاَ ضَرْعًا نَقَصَ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطٌ ‏"‏ ‏.‏ قَالَ آنْتَ سَمِعْتَ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِي وَرَبِّ هَذَا الْمَسْجِدِ ‏.‏\hadithno{1774}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Yazid ibn Khusayfa that as-Sa'ib ibn Yazid informed him that he heard Sufyan ibn Abi Zuhayr who was from the Azd Shanua tribe and among the companions of the Messenger of Allah, may Allah bless him and grant him peace, speaking with some people who were with him at the door of the mosque. He said, "I heard the Messenger of Allah, may Allah bless him and grant him peace, say, 'If anyone acquires a dog which he does not use as a sheepdog or for hunting, a qirat will be deducted from the reward of his good deeds each day.' " He was asked, "Did you hear this from the Messenger of Allah, may Allah bless him and grant him peace?" He said, "Yes, by the Lord of this mosque}}
\hadithdefcmd{malik}{1775}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اقْتَنَى كَلْبًا إِلاَّ كَلْبًا ضَارِيًا أَوْ كَلْبَ مَاشِيَةٍ نَقَصَ مِنْ عَمَلِهِ كُلَّ يَوْمٍ قِيرَاطَانِ ‏"‏ ‏.‏\hadithno{1775}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "Whoever acquires a dog other than a sheepdog or hunting dog, will have two qirats deducted from the reward of his good actions every day}}
\hadithdefcmd{malik}{1776}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِقَتْلِ الْكِلاَبِ ‏.‏\hadithno{1776}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, ordered dogs to be killed}}
\hadithdefcmd{malik}{1777}{حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رَأْسُ الْكُفْرِ نَحْوَ الْمَشْرِقِ وَالْفَخْرُ وَالْخُيَلاَءُ فِي أَهْلِ الْخَيْلِ وَالإِبِلِ وَالْفَدَّادِينَ أَهْلِ الْوَبَرِ وَالسَّكِينَةُ فِي أَهْلِ الْغَنَمِ ‏"‏ ‏.‏\hadithno{1777}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "The head of kufr is towards the east. Boasting and price is among people who have horses and camels. The loud-voiced people are the people of tents (the Bedouins). Tranquillity is with the people who have sheep}}
\hadithdefcmd{malik}{1778}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُوشِكُ أَنْ يَكُونَ خَيْرُ مَالِ الْمُسْلِمِ غَنَمًا يَتْبَعُ بِهَا شَعَفَ الْجِبَالِ وَمَوَاقِعَ الْقَطْرِ يَفِرُّ بِدِينِهِ مِنَ الْفِتَنِ ‏"‏ ‏.‏\hadithno{1778}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abd ar-Rahman ibn Abd ar-Rahman ibn Sasaca from his father that Abu Said al-Khudri said that the Messenger of Allah, may Allah bless him and grant him peace, said, "It will soon happen that the best property of a muslim will be sheep which he takes to the peaks of the mountains and the valleys, fleeing with his deen from trials}}
\hadithdefcmd{malik}{1779}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحْتَلِبَنَّ أَحَدٌ مَاشِيَةَ أَحَدٍ بِغَيْرِ إِذْنِهِ أَيُحِبُّ أَحَدُكُمْ أَنْ تُؤْتَى مَشْرُبَتُهُ فَتُكْسَرَ خِزَانَتُهُ فَيُنْتَقَلَ طَعَامُهُ وَإِنَّمَا تَخْزُنُ لَهُمْ ضُرُوعُ مَوَاشِيهِمْ أَطْعِمَاتِهِمْ فَلاَ يَحْتَلِبَنَّ أَحَدٌ مَاشِيَةَ أَحَدٍ إِلاَّ بِإِذْنِهِ ‏"‏ ‏.‏\hadithno{1779}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Nafi from Ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "No one should milk someone else's cow without his permission. Would any of you like someone to come to his apartment, break into his larder, and take his food? The udders of cows guard their food for their owners, so no one should milk someone else's cow without his permission}}
\hadithdefcmd{malik}{1780}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا مِنْ نَبِيِّ إِلاَّ قَدْ رَعَى غَنَمًا ‏"‏ ‏.‏ قِيلَ وَأَنْتَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَأَنَا ‏"‏ ‏.‏\hadithno{1780}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, said, "There is no Prophet who has not herded sheep," and someone asked, "You as well, Messenger of Allah?" He said, "Myself as well}}
\hadithdefcmd{malik}{1781}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، كَانَ يُقَرَّبُ إِلَيْهِ عَشَاؤُهُ فَيَسْمَعُ قِرَاءَةَ الإِمَامِ وَهُوَ فِي بَيْتِهِ فَلاَ يَعْجَلُ عَنْ طَعَامِهِ حَتَّى يَقْضِيَ حَاجَتَهُ مِنْهُ ‏.‏\hadithno{1781}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Nafi that one time as Ibn Umar was served his evening meal, he heard the recitation of the Imam while he was in his house and he did not hurry from his food until he had finished what he needed}}
\hadithdefcmd{malik}{1782}{وَحَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الْفَأْرَةِ تَقَعُ فِي السَّمْنِ فَقَالَ ‏ "‏ انْزِعُوهَا وَمَا حَوْلَهَا فَاطْرَحُوهُ ‏"‏ ‏.‏\hadithno{1782}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Ibn Shihab from Ubaydullah ibn Abdullah ibn Utba ibn Masud from Abdullah ibn Abbas from Maimuna, the wife of the Prophet, may Allah bless him and grant him peace, that the Messenger of Allah, may Allah bless him and grant him peace, was asked about a mouse falling into clarified butter. He said, "Remove it and throw away what is around it}}
\hadithdefcmd{malik}{1783}{وَحَدَّثَنِي مَالِكٌ، عَنْ أَبِي حَازِمِ بْنِ دِينَارٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنْ كَانَ فَفِي الْفَرَسِ وَالْمَرْأَةِ وَالْمَسْكَنِ ‏"‏ ‏.‏ يَعْنِي الشُّؤْمَ ‏.‏\hadithno{1783}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abu Hazim ibn Dinar from Sahl ibn Sad as-Saidi that the Messenger of Allah, may Allah bless him and grant him peace, said, "If it exists, it is in a horse, a woman, and a house," meaning ill luck}}
\hadithdefcmd{malik}{1784}{وَحَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ حَمْزَةَ، وَسَالِمٍ، ابْنَىْ عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الشُّؤْمُ فِي الدَّارِ وَالْمَرْأَةِ وَالْفَرَسِ ‏"‏ ‏.‏\hadithno{1784}\hadithgrade{Salim al-Hilali: Shadh}\hadithtrans{Malik related to me from Malik from Ibn Shihab from Hamza and Salim the sons of Abdullah ibn Umar from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "Ill luck is in a house, a woman and a horse}}
\hadithdefcmd{malik}{1785}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ دَارٌ سَكَنَّاهَا وَالْعَدَدُ كَثِيرٌ وَالْمَالُ وَافِرٌ فَقَلَّ الْعَدَدُ وَذَهَبَ الْمَالُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دَعُوهَا ذَمِيمَةً ‏"‏ ‏.‏\hadithno{1785}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Malik related to me that Yahya ibn Said said, "A woman came to the Messenger of Allah, may Allah bless him and grant him peace, and said, 'Messenger of Allah, we moved into a house when our number was great and our wealth was abundant. Now our number has dwindled and the wealth has gone.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'Leave it as blameworthy}}
\hadithdefcmd{malik}{1786}{حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ قَالَ لِلَقْحَةٍ تُحْلَبُ ‏"‏ مَنْ يَحْلُبُ هَذِهِ ‏"‏ ‏.‏ فَقَامَ رَجُلٌ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا اسْمُكَ ‏"‏ ‏.‏ فَقَالَ لَهُ الرَّجُلُ مُرَّةُ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اجْلِسْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ مَنْ يَحْلُبُ هَذِهِ ‏"‏ ‏.‏ فَقَامَ رَجُلٌ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا اسْمُكَ ‏"‏ ‏.‏ فَقَالَ حَرْبٌ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اجْلِسْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ مَنْ يَحْلُبُ هَذِهِ ‏"‏ ‏.‏ فَقَامَ رَجُلٌ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا اسْمُكَ ‏"‏ ‏.‏ فَقَالَ يَعِيشُ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ احْلُبْ ‏"‏ ‏.‏\hadithno{1786}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Malik related to me from Yahya ibn Said that the Messenger of Allah, may Allah bless him and grant him peace, asked about a milk camel about to be milked, "Who milks this camel?" A man stood up. The Messenger of Allah, may Allah bless him and grant him peace, said, "What is your name?" The man said, "Murra (bitterness)." The Messenger of Allah, may Allah bless him and grant him peace, said to him, "Sit down." Then he said, "Who milks this one?" A man stood up and the Messenger of Allah, may Allah bless him and grant him peace, said, "What is your name?" He said, "Harb (war)." The Messenger of Allah, may Allah bless him and grant him peace, said, "Sit down." Then he said, "Who milks this camel?" A man stood up, and the Messenger of Allah, may Allah bless him and grant him peace, said to him, "What is your name?" The man said, ''Yaish (he lives)." The Messenger of Allah, may Allah bless him and grant him peace, said to him, "Milk}}
\hadithdefcmd{malik}{1787}{وَحَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ لِرَجُلٍ مَا اسْمُكَ فَقَالَ جَمْرَةُ ‏.‏ فَقَالَ ابْنُ مَنْ فَقَالَ ابْنُ شِهَابٍ ‏.‏ قَالَ مِمَّنْ قَالَ مِنَ الْحُرَقَةِ ‏.‏ قَالَ أَيْنَ مَسْكَنُكَ قَالَ بِحَرَّةِ النَّارِ ‏.‏ قَالَ بِأَيِّهَا قَالَ بِذَاتِ لَظًى ‏.‏ قَالَ عُمَرُ أَدْرِكْ أَهْلَكَ فَقَدِ احْتَرَقُوا ‏.‏ قَالَ فَكَانَ كَمَا قَالَ عُمَرُ بْنُ الْخَطَّابِ رضى الله عنه ‏.‏\hadithno{1787}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Yahya ibn Said that Umar ibn al-Khattab asked a man what his name was. He said, "Jamra (live coal)." "The son of who?" He said, "Ibn Shihab (meteor, flame)." "From whom?" He said, "From al-Huraqa (burning)." "Where do you live?" He said, "At Harrat an-Nar (lava field of the fire). "At which one of them?" He said, "At Dhati Ladha (one with flames)." Umar said, "Go and look at your family - they have been burned." Yahya added, "It was as Umar ibn al-Khattab, may Allah be pleased with him, said}}
\hadithdefcmd{malik}{1788}{حَدَّثَنِي مَالِكٌ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ احْتَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَجَمَهُ أَبُو طَيْبَةَ فَأَمَرَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِصَاعٍ مِنْ تَمْرٍ وَأَمَرَ أَهْلَهُ أَنْ يُخَفِّفُوا عَنْهُ مِنْ خَرَاجِهِ ‏.‏\hadithno{1788}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Humayd at-Tawil that Anas ibn Malik said, "The Messenger of Allah, may Allah bless him and grant him peace, was cupped. Abu Tayba cupped him, and the Messenger of Allah, may Allah bless him and grant him peace, ordered him to be given a sa of dates and ordered his family to lessen what he paid them for his kitaba or kharaj}}
\hadithdefcmd{malik}{1789}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنْ كَانَ دَوَاءٌ يَبْلُغُ الدَّاءَ فَإِنَّ الْحِجَامَةَ تَبْلُغُهُ ‏"‏ ‏.‏\hadithno{1789}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Malik related to me that he heard that the Messenger of Allah, may Allah bless him and grant him peace, said, "If there is a remedy that will reach the disease, then cupping will reach it}}
\hadithdefcmd{malik}{1790}{وَحَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ مُحَيِّصَةَ الأَنْصَارِيِّ، أَحَدِ بَنِي حَارِثَةَ أَنَّهُ اسْتَأْذَنَ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي إِجَارَةِ الْحَجَّامِ فَنَهَاهُ عَنْهَا فَلَمْ يَزَلْ يَسْأَلُهُ وَيَسْتَأْذِنُهُ حَتَّى قَالَ ‏ "‏ اعْلِفْهُ نُضَّاحَكَ ‏"‏ ‏.‏ يَعْنِي رَقِيقَكَ ‏.‏\hadithno{1790}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Malik related to me from Ibn Shihab from Ibn Muhayyisa al-Ansari, one of the Banu Haritha, that he asked permission from the Messenger of Allah, may Allah bless him and grant him peace, to give payment for cupping, and he forbade him to do it. He continued to ask and seek his permission until he said, "Feed the ones who drive your water-carrying camels," meaning "your slaves}}
\hadithdefcmd{malik}{1791}{حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُشِيرُ إِلَى الْمَشْرِقِ وَيَقُولُ ‏ "‏ هَا إِنَّ الْفِتْنَةَ هَا هُنَا إِنَّ الْفِتْنَةَ هَا هُنَا مِنْ حَيْثُ يَطْلُعُ قَرْنُ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{1791}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Abdullah ibn Dinar that Abdullah ibn Umar said, "I saw the Messenger of Allah, may Allah bless him and grant him peace, pointing at the east and saying, 'The cause of dissension is here. The cause of dissension is here, from where the helpers of shaytan arise}}
\hadithdefcmd{malik}{1792}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، أَرَادَ الْخُرُوجَ إِلَى الْعِرَاقِ فَقَالَ لَهُ كَعْبُ الأَحْبَارِ لاَ تَخْرُجْ إِلَيْهَا يَا أَمِيرَ الْمُؤْمِنِينَ فَإِنَّ بِهَا تِسْعَةَ أَعْشَارِ السِّحْرِ وَبِهَا فَسَقَةُ الْجِنِّ وَبِهَا الدَّاءُ الْعُضَالُ ‏.‏\hadithno{1792}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me that he heard that Umar ibn al-Khattab wanted to go to Iraq, and Kabal-Ahbar said to him, "Do not go there, amir al- muminin. There is nine-tenths of sorcery there and it is the place of the rebellious jinn and the disease which the doctors are unable to cure}}
\hadithdefcmd{malik}{1793}{حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ أَبِي لُبَابَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ قَتْلِ الْحَيَّاتِ الَّتِي فِي الْبُيُوتِ ‏.‏\hadithno{1793}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Nafi from Abu Lubaba that the Messenger of Allah, may Allah bless him and grant him peace, forbade killing snakes which were in the houses}}
\hadithdefcmd{malik}{1794}{وَحَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ سَائِبَةَ، مَوْلاَةٍ لِعَائِشَةَ ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ قَتْلِ الْجِنَّانِ الَّتِي فِي الْبُيُوتِ إِلاَّ ذَا الطُّفْيَتَيْنِ وَالأَبْتَرَ فَإِنَّهُمَا يَخْطِفَانِ الْبَصَرَ وَيَطْرَحَانِ مَا فِي بُطُونِ النِّسَاءِ ‏.‏\hadithno{1794}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Nafi from Sa'iba, the female mawla of A'isha, that the Messenger of Allah, may Allah bless him and grant him peace, forbade killing the snakes which were in the houses except those with two white stripes on their back and the short ones. They made one go blind and caused miscarriages in women}}
\hadithdefcmd{malik}{1795}{وَحَدَّثَنِي مَالِكٌ، عَنْ صَيْفِيٍّ، مَوْلَى ابْنِ أَفْلَحَ عَنْ أَبِي السَّائِبِ، مَوْلَى هِشَامِ بْنِ زُهْرَةَ أَنَّهُ قَالَ دَخَلْتُ عَلَى أَبِي سَعِيدٍ الْخُدْرِيِّ فَوَجَدْتُهُ يُصَلِّي فَجَلَسْتُ أَنْتَظِرُهُ حَتَّى قَضَى صَلاَتَهُ فَسَمِعْتُ تَحْرِيكًا تَحْتَ سَرِيرٍ فِي بَيْتِهِ فَإِذَا حَيَّةٌ فَقُمْتُ لأَقْتُلَهَا فَأَشَارَ أَبُو سَعِيدٍ أَنِ اجْلِسْ فَلَمَّا انْصَرَفَ أَشَارَ إِلَى بَيْتٍ فِي الدَّارِ فَقَالَ أَتَرَى هَذَا الْبَيْتَ فَقُلْتُ نَعَمْ ‏.‏ قَالَ إِنَّهُ قَدْ كَانَ فِيهِ فَتًى حَدِيثُ عَهْدٍ بِعُرْسٍ فَخَرَجَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى الْخَنْدَقِ فَبَيْنَا هُوَ بِهِ إِذْ أَتَاهُ الْفَتَى يَسْتَأْذِنُهُ فَقَالَ يَا رَسُولَ اللَّهِ ائْذَنْ لِي أُحْدِثُ بِأَهْلِي عَهْدًا فَأَذِنَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ خُذْ عَلَيْكَ سِلاَحَكَ فَإِنِّي أَخْشَى عَلَيْكَ بَنِي قُرَيْظَةَ ‏"‏ فَانْطَلَقَ الْفَتَى إِلَى أَهْلِهِ فَوَجَدَ امْرَأَتَهُ قَائِمَةً بَيْنَ الْبَابَيْنِ فَأَهْوَى إِلَيْهَا بِالرُّمْحِ لِيَطْعُنَهَا وَأَدْرَكَتْهُ غَيْرَةٌ فَقَالَتْ لاَ تَعْجَلْ حَتَّى تَدْخُلَ وَتَنْظُرَ مَا فِي بَيْتِكَ ‏.‏ فَدَخَلَ فَإِذَا هُوَ بِحَيَّةٍ مُنْطَوِيَةٍ عَلَى فِرَاشِهِ فَرَكَزَ فِيهَا رُمْحَهُ ثُمَّ خَرَجَ بِهَا فَنَصَبَهُ فِي الدَّارِ فَاضْطَرَبَتِ الْحَيَّةُ فِي رَأْسِ الرُّمْحِ وَخَرَّ الْفَتَى مَيِّتًا فَمَا يُدْرَى أَيُّهُمَا كَانَ أَسْرَعَ مَوْتًا الْفَتَى أَمِ الْحَيَّةُ فَذُكِرَ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنَّ بِالْمَدِينَةِ جِنًّا قَدْ أَسْلَمُوا فَإِذَا رَأَيْتُمْ مِنْهُمْ شَيْئًا فَآذِنُوهُ ثَلاَثَةَ أَيَّامٍ فَإِنْ بَدَا لَكُمْ بَعْدَ ذَلِكَ فَاقْتُلُوهُ فَإِنَّمَا هُوَ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{1795}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Safiyy, the mawla of Ibn Aflah that Abu's-Saib, the mawla of Hisham ibn Zuhra said, "I went to Abu Said al-Khudri and found him praying. I sat to wait for him until he finished the prayer. I heard a movement under a bed in his room, and it was a snake. I stood up to kill it, and Abu Said gestured to me to sit. When he was finished he pointed to a room in the house and said, 'Do you see this room?' I said, 'Yes.' He said, 'There was a young boy in it who had just got married. He went out with the Messenger of Allah, may Allah bless him and grant him peace, to al-Khandaq, (the ditch which the muslims dug in the 5th year of the Hijra to defend Madina against the Quraysh and their allies). When he was there, the youth came and asked his permission, saying, "Messenger of Allah. Give me permission to return to my family." The Messenger of Allah, may Allah bless him and grant him peace, gave him permission and said, "Take your weapons with you, for I fear the Banu Quraydha tribe. They may harm you." The youth went to his family and found his wife standing between the two doors. He lifted his spear to stab her as jealousy had been aroused in him. She said, "Don't be hasty until you go in and see what is in your house." He entered and found a snake coiled up on his bed. He transfixed it with his spear and then went out with it and pitched it into the house. The snake stirred on the end of the spear and the youth fell dead. No one knew which of them died first, the snake or the youth. That was mentioned to the Messenger of Allah, may Allah bless him and grant him peace, and he said, "There are jinn in Madina who have become muslim. When you see one of them, call out to it for three days. If it appears after that, then kill it, for it is a shaytan}}
\hadithdefcmd{malik}{1796}{حَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا وَضَعَ رِجْلَهُ فِي الْغَرْزِ وَهُوَ يُرِيدُ السَّفَرَ يَقُولُ ‏ "‏ بِاسْمِ اللَّهِ ‏.‏ اللَّهُمَّ أَنْتَ الصَّاحِبُ فِي السَّفَرِ وَالْخَلِيفَةُ فِي الأَهْلِ اللَّهُمَّ ازْوِ لَنَا الأَرْضَ وَهَوِّنْ عَلَيْنَا السَّفَرَ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ وَعْثَاءِ السَّفَرِ وَمِنْ كَآبَةِ الْمُنْقَلَبِ وَمِنْ سُوءِ الْمَنْظَرِ فِي الْمَالِ وَالأَهْلِ ‏"‏ ‏.‏\hadithno{1796}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Malik related to me that he heard that when the Messenger of Allah, may Allah bless him and grant him peace, set foot in the stirrup intending to travel, he would say, "In the name of Allah. O Allah! You are my companion in the journey and the Khalifa of my family. O Allah! Spread out the earth for us and make the journey easy for us. O Allah! I seek refuge with You from the hardship of the journey and from returning to sorrow and a distressing sight regarding property and family}}
\hadithdefcmd{malik}{1797}{وَحَدَّثَنِي مَالِكٌ، عَنِ الثِّقَةِ، عِنْدَهُ عَنْ يَعْقُوبَ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ خَوْلَةَ بِنْتِ حَكِيمٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ نَزَلَ مَنْزِلاً فَلْيَقُلْ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّاتِ مِنْ شَرِّ مَا خَلَقَ ‏.‏ فَإِنَّهُ لَنْ يَضُرَّهُ شَىْءٌ حَتَّى يَرْتَحِلَ ‏"‏ ‏.‏\hadithno{1797}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from a reliable source of his from Yaqub ibn Abdullah al-Ashajj from Bushr ibn Said from Sad ibn Abi Waqqas from Khawla bint Hakim that the Messenger of Allah, may Allah bless him and grant him peace, said, "Whoever dismounts to rest in a place should say, 'I seek refuge with the complete words of Allah from the evil of what he created,' (audhu bi kalimati-llahi at-tammati min sharri ma khalaqa), and nothing will harm him until he remounts}}
\hadithdefcmd{malik}{1798}{حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حَرْمَلَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الرَّاكِبُ شَيْطَانٌ وَالرَّاكِبَانِ شَيْطَانَانِ وَالثَّلاَثَةُ رَكْبٌ ‏"‏ ‏.‏\hadithno{1798}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Malik related to me from Abd ar-Rahman ibn Harmala from Amr ibn Shuayb from his father from his father that the Messenger of Allah, may Allah bless him and grant him peace, said, "One rider is a shaytan. Two riders are two shaytans, and three are a riding-party}}
\hadithdefcmd{malik}{1799}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حَرْمَلَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ كَانَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشَّيْطَانُ يَهُمُّ بِالْوَاحِدِ وَالاِثْنَيْنِ فَإِذَا كَانُوا ثَلاَثَةً لَمْ يَهُمَّ بِهِمْ ‏"‏ ‏.‏\hadithno{1799}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Malik related to me from Abd ar-Rahman ibn Harmala that Said ibn al-Musayyab heard the Messenger of Allah, may Allah bless him and grant him peace, say, "Shaytan concerns himself with one and two. When there are three, he does not concern himself with them}}
\hadithdefcmd{malik}{1800}{وَحَدَّثَنِي مَالِكٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخَرِ تُسَافِرُ مَسِيرَةَ يَوْمٍ وَلَيْلَةٍ إِلاَّ مَعَ ذِي مَحْرَمٍ مِنْهَا ‏"‏ ‏.‏\hadithno{1800}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Said ibn Abi Said al-Maqburi from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "It is not halal for a woman who believes in Allah and the Last Day to travel the distance of a day and night without a man who is her mahram}}
\hadithdefcmd{malik}{1801}{حَدَّثَنِي مَالِكٌ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى سُلَيْمَانَ بْنِ عَبْدِ الْمَلِكِ عَنْ خَالِدِ بْنِ مَعْدَانَ، يَرْفَعُهُ ‏ "‏ إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى رَفِيقٌ يُحِبُّ الرِّفْقَ وَيَرْضَى بِهِ وَيُعِينُ عَلَيْهِ مَا لاَ يُعِينُ عَلَى الْعُنْفِ فَإِذَا رَكِبْتُمْ هَذِهِ الدَّوَابَّ الْعُجْمَ فَأَنْزِلُوهَا مَنَازِلَهَا فَإِنْ كَانَتِ الأَرْضُ جَدْبَةً فَانْجُوا عَلَيْهَا بِنِقْيِهَا وَعَلَيْكُمْ بِسَيْرِ اللَّيْلِ فَإِنَّ الأَرْضَ تُطْوَى بِاللَّيْلِ مَا لاَ تُطْوَى بِالنَّهَارِ وَإِيَّاكُمْ وَالتَّعْرِيسَ عَلَى الطَّرِيقِ فَإِنَّهَا طُرُقُ الدَّوَابِّ وَمَأْوَى الْحَيَّاتِ ‏"‏ ‏.‏\hadithno{1801}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Malik related to me from Abu Ubayd, the mawla of Sulayman ibn Abd al-Malik from Khalid ibn Madan who attributed it to the Prophet, may Allah bless him and grant him peace, "Allah, the Blessed and Exalted is kind and loves kindness. He is pleased with it and helps you with it as long as it is not misplaced. When you ride dumb beasts, stop them in their stopping places, and quicken their pace when the land is barren. Travel by night, because the land is travelled faster at night than it is during the day. Beware of pitching tents on the road, for it is the path of animals and the abode of snakes}}
\hadithdefcmd{malik}{1802}{وَحَدَّثَنِي مَالِكٌ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ السَّفَرُ قِطْعَةٌ مِنَ الْعَذَابِ يَمْنَعُ أَحَدَكُمْ نَوْمَهُ وَطَعَامَهُ وَشَرَابَهُ فَإِذَا قَضَى أَحَدُكُمْ نَهْمَتَهُ مِنْ وَجْهِهِ فَلْيُعَجِّلْ إِلَى أَهْلِهِ ‏"‏ ‏.‏\hadithno{1802}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Sumayy, the mawla of Abu Bakr from Abu Salih from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Travelling is a portion of the torment. It denies you your sleep, food, and drink. When you have accomplished your purpose, you should hurry back to your family}}
\hadithdefcmd{malik}{1803}{حَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِلْمَمْلُوكِ طَعَامُهُ وَكِسْوَتُهُ بِالْمَعْرُوفِ وَلاَ يُكَلَّفُ مِنَ الْعَمَلِ إِلاَّ مَا يُطِيقُ ‏"‏ ‏.‏\hadithno{1803}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me that he heard that Abu Hurayra said that the Messenger of Allah, may Allah bless him and grant him peace, said, "A slave has his food and clothing in the normal manner, and he is only obliged to do such work as he is capable of doing}}
\hadithdefcmd{malik}{1804}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ يَذْهَبُ إِلَى الْعَوَالِي كُلَّ يَوْمِ سَبْتٍ فَإِذَا وَجَدَ عَبْدًا فِي عَمَلٍ لاَ يُطِيقُهُ وَضَعَ عَنْهُ مِنْهُ ‏.‏\hadithno{1804}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me that he heard that Umar ibn al-Khattab went to the villages every Saturday. If he found a slave doing work which he was not capable of doing, he lightened it for him}}
\hadithdefcmd{malik}{1805}{وَحَدَّثَنِي مَالِكٌ، عَنْ عَمِّهِ أَبِي سُهَيْلِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ عُثْمَانَ بْنَ عَفَّانَ، وَهُوَ يَخْطُبُ وَهُوَ يَقُولُ لاَ تُكَلِّفُوا الأَمَةَ غَيْرَ ذَاتِ الصَّنْعَةِ الْكَسْبَ فَإِنَّكُمْ مَتَى كَلَّفْتُمُوهَا ذَلِكَ كَسَبَتْ بِفَرْجِهَا وَلاَ تُكَلِّفُوا الصَّغِيرَ الْكَسْبَ فَإِنَّهُ إِذَا لَمْ يَجِدْ سَرَقَ وَعِفُّوا إِذْ أَعَفَّكُمُ اللَّهُ وَعَلَيْكُمْ مِنَ الْمَطَاعِمِ بِمَا طَابَ مِنْهَا ‏.‏\hadithno{1805}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from his paternal uncle, Abu Suhayl ibn Malik, that his father heard Uthman ibn Affan say in a khutba, "Do not oblige the slave-girl to earn money unless she has a skill. When you oblige her to do that, she will earn money by prostitution. Do not oblige the child to earn money. If he does not find it, he will steal. Have integrity since Allah has integrity with you, and you must feed them good food}}
\hadithdefcmd{malik}{1806}{حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَبْدُ إِذَا نَصَحَ لِسَيِّدِهِ وَأَحْسَنَ عِبَادَةَ اللَّهِ فَلَهُ أَجْرُهُ مَرَّتَيْنِ ‏"‏ ‏.‏\hadithno{1806}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said, "When a slave gives good counsel to his master and worships Allah correctly, he has his reward twice over}}
\hadithdefcmd{malik}{1807}{وَحَدَّثَنِي مَالِكٌ، أَنَّهُ بَلَغَهُ أَنَّ أَمَةً، كَانَتْ لِعَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ رَآهَا عُمَرُ بْنُ الْخَطَّابِ وَقَدْ تَهَيَّأَتْ بِهَيْئَةِ الْحَرَائِرِ فَدَخَلَ عَلَى ابْنَتِهِ حَفْصَةَ فَقَالَ أَلَمْ أَرَ جَارِيَةَ أَخِيكِ تَجُوسُ النَّاسَ وَقَدْ تَهَيَّأَتْ بِهَيْئَةِ الْحَرَائِرِ وَأَنْكَرَ ذَلِكَ عُمَرُ ‏.‏\hadithno{1807}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Malik related to me that he heard that Umar ibn al-Khattab saw a female slave belonging to Abdullah ibn Umar ibn al-Khattab. She was dressed like free (non-slave) women. He went to his daughter Hafsa and said, "Didn't I see your brother's slave-girl dressed like a free (non-slave) woman walking among the people and causing trouble?" Umar disapproved of that}}
