% Auto-generated chapter 53 for malik
% Hadiths in this chapter: 7

\hadithdefcmd{malik}{1756}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يُسَلِّمُ الرَّاكِبُ عَلَى الْمَاشِي وَإِذَا سَلَّمَ مِنَ الْقَوْمِ وَاحِدٌ أَجْزَأَ عَنْهُمْ ‏"‏ ‏.‏\hadithno{1756}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that the Messenger of Allah, may Allah bless him and grant him peace, said, "The one riding greets the one walking, and when one of a group of people gives a greeting, it is enough for all of them}}
\hadithdefcmd{malik}{1757}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، أَنَّهُ قَالَ كُنْتُ جَالِسًا عِنْدَ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ فَدَخَلَ عَلَيْهِ رَجُلٌ مِنْ أَهْلِ الْيَمَنِ فَقَالَ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ ‏.‏ ثُمَّ زَادَ شَيْئًا مَعَ ذَلِكَ أَيْضًا ‏.‏ قَالَ ابْنُ عَبَّاسٍ وَهُوَ يَوْمَئِذٍ قَدْ ذَهَبَ بَصَرُهُ مَنْ هَذَا قَالُوا هَذَا الْيَمَانِيُّ الَّذِي يَغْشَاكَ ‏.‏ فَعَرَّفُوهُ إِيَّاهُ ‏.‏ قَالَ فَقَالَ ابْنُ عَبَّاسٍ إِنَّ السَّلاَمَ انْتَهَى إِلَى الْبَرَكَةِ ‏.‏ قَالَ يَحْيَى سُئِلَ مَالِكٌ هَلْ يُسَلَّمُ عَلَى الْمَرْأَةِ فَقَالَ أَمَّا الْمُتَجَالَّةُ فَلاَ أَكْرَهُ ذَلِكَ وَأَمَّا الشَّابَّةُ فَلاَ أُحِبُّ ذَلِكَ ‏.‏\hadithno{1757}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Wahb ibn Kaysan that Muhammad ibn Amr ibn Ata said, "I was sitting with Abdullah ibn Abbas when a Yemeni man came in. He said, 'Peace be upon you, and the mercy of Allah and His blessing' (as-salamu alaykum wa rahmatullahi wa barakatuhu), and then he added something more to that. Ibn Abbas said (and at that time his eyesight had gone), 'Who is this?' People said, 'This is a Yemeni who has come to see you,' and they introduced him. Ibn Abbas said, 'The greeting ends with the word blessing.' " Yahya said that Malik was asked, "Does one greet a woman?" He said, "As for an old woman, I do not disapprove of it. As for a young woman, I do not like it}}
\hadithdefcmd{malik}{1758}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْيَهُودَ إِذَا سَلَّمَ عَلَيْكُمْ أَحَدُهُمْ فَإِنَّمَا يَقُولُ السَّامُ عَلَيْكُمْ ‏.‏ فَقُلْ عَلَيْكَ ‏"‏ ‏.‏\hadithno{1758}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar that Abdullah ibn Umar said that the Messenger of Allah, may Allah bless him and grant him peace, said, "When a jew greets you, and says 'Death to you' (as-samu alaykum) say, 'And to you.' " Yahya said, "Malik was asked whether a person who greeted a jew or christian, should apologise for it. He said, 'No}}
\hadithdefcmd{malik}{1759}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَبِي مُرَّةَ، مَوْلَى عَقِيلِ بْنِ أَبِي طَالِبٍ عَنْ أَبِي وَاقِدٍ اللَّيْثِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَيْنَمَا هُوَ جَالِسٌ فِي الْمَسْجِدِ وَالنَّاسُ مَعَهُ إِذْ أَقْبَلَ نَفَرٌ ثَلاَثَةٌ فَأَقْبَلَ اثْنَانِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَذَهَبَ وَاحِدٌ فَلَمَّا وَقَفَا عَلَى مَجْلِسِ رَسُولِ اللَّهِ صلى الله عليه وسلم سَلَّمَا فَأَمَّا أَحَدُهُمَا فَرَأَى فُرْجَةً فِي الْحَلْقَةِ فَجَلَسَ فِيهَا وَأَمَّا الآخَرُ فَجَلَسَ خَلْفَهُمْ وَأَمَّا الثَّالِثُ فَأَدْبَرَ ذَاهِبًا فَلَمَّا فَرَغَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ أُخْبِرُكُمْ عَنِ النَّفَرِ الثَّلاَثَةِ أَمَّا أَحَدُهُمْ فَأَوَى إِلَى اللَّهِ فَآوَاهُ اللَّهُ وَأَمَّا الآخَرُ فَاسْتَحْيَا فَاسْتَحْيَا اللَّهُ مِنْهُ وَأَمَّا الآخَرُ فَأَعْرَضَ فَأَعْرَضَ اللَّهُ عَنْهُ ‏"‏ ‏.‏\hadithno{1759}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ishaq ibn Abdullah ibn Abi Talha from Abu Murra, the mawla of Aqil ibn Abi Talib from Abu Waqid al-Laythi that the Messenger of Allah, may Allah bless him and grant him peace, was sitting in the mosque with some people when three people came in. Two came toward the Messenger of Allah, may Allah bless him and grant him peace, and one went away. When the two stopped at the assembly of the Messenger of Allah, may Allah bless him and grant him peace, they gave the greeting. One of them saw a gap in the circle and sat in it. The other sat down behind the circle. The third turned away and left. When the Messenger of Allah, may Allah bless him and grant him peace, finished, he said, "Shall I tell you about three people? One of them sought shelter with Allah, so Allah gave him shelter. The other was shy, so Allah was shy to him. The other turned away, so Allah turned away from him}}
\hadithdefcmd{malik}{1760}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ سَمِعَ عُمَرَ بْنَ الْخَطَّابِ، وَسَلَّمَ، عَلَيْهِ رَجُلٌ فَرَدَّ عَلَيْهِ السَّلاَمَ ثُمَّ سَأَلَ عُمَرُ الرَّجُلَ كَيْفَ أَنْتَ فَقَالَ أَحْمَدُ إِلَيْكَ اللَّهَ ‏.‏ فَقَالَ عُمَرُ ذَلِكَ الَّذِي أَرَدْتُ مِنْكَ ‏.‏\hadithno{1760}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ishaq ibn Abdullah ibn Abi Talha that Anas ibn Malik heard Umar ibn al-Khattab return the greeting of a man who greeted him. Then Umar asked the man, "How are you?" He said, "I praise Allah to you." (Ahmadu ilayka Allah) Umar said, "That is what I wanted from you}}
\hadithdefcmd{malik}{1761}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّ الطُّفَيْلَ بْنَ أُبَىِّ بْنِ كَعْبٍ، أَخْبَرَهُ أَنَّهُ، كَانَ يَأْتِي عَبْدَ اللَّهِ بْنَ عُمَرَ فَيَغْدُو مَعَهُ إِلَى السُّوقِ قَالَ فَإِذَا غَدَوْنَا إِلَى السُّوقِ لَمْ يَمُرَّ عَبْدُ اللَّهِ بْنُ عُمَرَ عَلَى سَقَاطٍ وَلاَ صَاحِبِ بَيْعَةٍ وَلاَ مِسْكِينٍ وَلاَ أَحَدٍ إِلاَّ سَلَّمَ عَلَيْهِ - قَالَ الطُّفَيْلُ - فَجِئْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ يَوْمًا فَاسْتَتْبَعَنِي إِلَى السُّوقِ فَقُلْتُ لَهُ وَمَا تَصْنَعُ فِي السُّوقِ وَأَنْتَ لاَ تَقِفُ عَلَى الْبَيِّعِ وَلاَ تَسْأَلُ عَنِ السِّلَعِ وَلاَ تَسُومُ بِهَا وَلاَ تَجْلِسُ فِي مَجَالِسِ السُّوقِ قَالَ وَأَقُولُ اجْلِسْ بِنَا هَا هُنَا نَتَحَدَّثْ ‏.‏ قَالَ فَقَالَ لِي عَبْدُ اللَّهِ بْنُ عُمَرَ يَا أَبَا بَطْنٍ - وَكَانَ الطُّفَيْلُ ذَا بَطْنٍ - إِنَّمَا نَغْدُو مِنْ أَجْلِ السَّلاَمِ نُسَلِّمُ\hadithno{1761}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Ishaq ibn Abdullah ibn Abi Talha that at-Tufayl ibn Ubayy ibn Kab told him that he visited Abdullah ibn Umar one morning and went out with him to the market, and when they were out, Abdullah ibn Umar did not pass by anyone selling poor merchandise or selling commodities or a needy person or anyone but that he greeted them. At-Tufayl said, "I came to Abdullah ibn Umar one day and he asked me to follow him to the market. I said to him, 'What will you do in the market if you will not stop to sell nor seek any goods or barter with them or sit in any of the assemblies or market?' Abdullah ibn Umar said that we should sit down and talk, and then he explained, 'Abu Batni, (lit. father of the belly, at- Tufayl had a prominent stomach), we go out in the morning only for the sake of the greeting. We greet whomever we meet}}
\hadithdefcmd{malik}{1762}{\hadithno{1762}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{}}
