% Auto-generated chapter 6 for abudawud
% Hadiths in this chapter: 30

\hadithdefcmd{abudawud}{1371}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ الْمُتَوَكِّلِ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، - قَالَ الْحَسَنُ فِي حَدِيثِهِ وَمَالِكُ بْنُ أَنَسٍ - عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُرَغِّبُ فِي قِيَامِ رَمَضَانَ مِنْ غَيْرِ أَنْ يَأْمُرَهُمْ بِعَزِيمَةٍ ثُمَّ يَقُولُ ‏"‏ مَنْ قَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏ فَتُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالأَمْرُ عَلَى ذَلِكَ ثُمَّ كَانَ الأَمْرُ عَلَى ذَلِكَ فِي خِلاَفَةِ أَبِي بَكْرٍ - رضى الله عنه - وَصَدْرًا مِنْ خِلاَفَةِ عُمَرَ رضى الله عنه ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَا رَوَاهُ عُقَيْلٌ وَيُونُسُ وَأَبُو أُوَيْسٍ ‏"‏ مَنْ قَامَ رَمَضَانَ ‏"‏ ‏.‏ وَرَوَى عُقَيْلٌ ‏"‏ مَنْ صَامَ رَمَضَانَ وَقَامَهُ ‏"‏ ‏.‏\hadithno{1371}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (759)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) used to commend prayer at night during Ramadan, but did not command it as duty. He would say: If anyone prays during the night in Ramadan because of faith and seeking his reward from Allah, his previous sins will be forgiven for him. When the Messenger of Allah (ﷺ) died, this was the practice, and it continued thus during Abu Bakr's caliphate and early part of 'Umar's. Abu Dawud said: This tradition has been transmitted by 'Uqail, Yunus, and Abu Uwais in like manner. The version of 'Uqail goes: He who fasts during Ramadan and prays during the night}}
\hadithdefcmd{abudawud}{1372}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، وَابْنُ أَبِي خَلَفٍ، - الْمَعْنَى - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم ‏ "‏ مَنْ صَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَنْ قَامَ لَيْلَةَ الْقَدْرِ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَا رَوَاهُ يَحْيَى بْنُ أَبِي كَثِيرٍ عَنْ أَبِي سَلَمَةَ وَمُحَمَّدُ بْنُ عَمْرٍو عَنْ أَبِي سَلَمَةَ ‏.‏\hadithno{1372}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2014)}\hadithtrans{Narrated Abu Hurairah: The Prophet (ﷺ) as saying: If anyone fasts during Ramadan because of faith and in order to seek his reward from Allah, his previous sins will be forgiven to him. If anyone prays in the night of the power (lailat al-qadr) because of faith and in order to seek his reward from Allah his previous sins will be forgiven for him. Abu Dawud said: This tradition has been transmitted in a similar manner by Yahya b. Abi Kathir and Muhammad b. 'Amr from Abu Salamah}}
\hadithdefcmd{abudawud}{1373}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى فِي الْمَسْجِدِ فَصَلَّى بِصَلاَتِهِ نَاسٌ ثُمَّ صَلَّى مِنَ الْقَابِلَةِ فَكَثُرَ النَّاسُ ثُمَّ اجْتَمَعُوا مِنَ اللَّيْلَةِ الثَّالِثَةِ فَلَمْ يَخْرُجْ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا أَصْبَحَ قَالَ ‏ "‏ قَدْ رَأَيْتُ الَّذِي صَنَعْتُمْ فَلَمْ يَمْنَعْنِي مِنَ الْخُرُوجِ إِلَيْكُمْ إِلاَّ أَنِّي خَشِيتُ أَنْ يُفْرَضَ عَلَيْكُمْ ‏"‏ ‏.‏ وَذَلِكَ فِي رَمَضَانَ ‏.‏\hadithno{1373}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2012) Sahih Muslim (761)}\hadithtrans{Narrated 'Aishah, wife of Prophet (ﷺ):That the Prophet (ﷺ) once offered (tarawih) prayer in the mosque and the people also prayed along with him. He then prayed on the following night, and the people gathered in large numbers. They gathered on the third night too, but the Messenger of Allah (ﷺ) did not come out to them. When the morning came, he said: I witnessed what you did, and nothing prevented me from coming out to you except that I feared that this (prayer) might be prescribed to you. That was in Ramadan}}
\hadithdefcmd{abudawud}{1374}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا عَبْدَةُ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّاسُ يُصَلُّونَ فِي الْمَسْجِدِ فِي رَمَضَانَ أَوْزَاعًا فَأَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَضَرَبْتُ لَهُ حَصِيرًا فَصَلَّى عَلَيْهِ بِهَذِهِ الْقِصَّةِ قَالَتْ فِيهِ قَالَ - تَعْنِي النَّبِيَّ صلى الله عليه وسلم - ‏ "‏ أَيُّهَا النَّاسُ أَمَا وَاللَّهِ مَا بِتُّ لَيْلَتِي هَذِهِ بِحَمْدِ اللَّهِ غَافِلاً وَلاَ خَفِيَ عَلَىَّ مَكَانُكُمْ ‏"‏ ‏.‏\hadithno{1374}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Aishah:The people used to pray (tarawih prayer) in the mosque during Ramadan severally. The Messenger of Allah (ﷺ) commanded me (to spread a mat). I spread a mat for him and he prayed upon it. The narrator then transmitted the same story. The Prophet (ﷺ) said: O People, praise be to Allah, I did not pass my night carelessly, nor did your position remain hidden from me}}
\hadithdefcmd{abudawud}{1375}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، أَخْبَرَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، عَنِ الْوَلِيدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِي ذَرٍّ، قَالَ صُمْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم رَمَضَانَ فَلَمْ يَقُمْ بِنَا شَيْئًا مِنَ الشَّهْرِ حَتَّى بَقِيَ سَبْعٌ فَقَامَ بِنَا حَتَّى ذَهَبَ ثُلُثُ اللَّيْلِ فَلَمَّا كَانَتِ السَّادِسَةُ لَمْ يَقُمْ بِنَا فَلَمَّا كَانَتِ الْخَامِسَةُ قَامَ بِنَا حَتَّى ذَهَبَ شَطْرُ اللَّيْلِ فَقُلْتُ يَا رَسُولَ اللَّهِ لَوْ نَفَّلْتَنَا قِيَامَ هَذِهِ اللَّيْلَةِ ‏.‏ قَالَ فَقَالَ ‏ "‏ إِنَّ الرَّجُلَ إِذَا صَلَّى مَعَ الإِمَامِ حَتَّى يَنْصَرِفَ حُسِبَ لَهُ قِيَامُ لَيْلَةٍ ‏"‏ ‏.‏ قَالَ فَلَمَّا كَانَتِ الرَّابِعَةُ لَمْ يَقُمْ فَلَمَّا كَانَتِ الثَّالِثَةُ جَمَعَ أَهْلَهُ وَنِسَاءَهُ وَالنَّاسَ فَقَامَ بِنَا حَتَّى خَشِينَا أَنْ يَفُوتَنَا الْفَلاَحُ ‏.‏ قَالَ قُلْتُ مَا الْفَلاَحُ قَالَ السُّحُورُ ثُمَّ لَمْ يَقُمْ بِنَا بَقِيَّةَ الشَّهْرِ ‏.‏\hadithno{1375}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuDharr: We fasted with the Messenger of Allah (ﷺ) during Ramadan, but he did not make us get up at night for prayer at any time during the month till seven nights remained; then he made us get up for prayer till a third of the night had passed. When the sixth remaining night came, he did not make us get up for prayer. When the fifth remaining night came, he made us stand in prayer till a half of the night had gone. So I said: Messenger of Allah, I wish you had led us in supererogatory prayers during the whole of tonight. He said: When a man prays with an imam till he goes he is reckoned as having spent a whole night in prayer. On the fourth remaining night he did not make us get up. When the third remaining night came, he gathered his family, his wives, and the people and prayed with us till we were afraid we should miss the falah (success). I said: What is falah? He said: The meal before daybreak. Then he did not make us get up for prayer during the remainder of the month}}
\hadithdefcmd{abudawud}{1376}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، وَدَاوُدُ بْنُ أُمَيَّةَ، أَنَّ سُفْيَانَ، أَخْبَرَهُمْ عَنْ أَبِي يَعْفُورٍ، - وَقَالَ دَاوُدُ عَنِ ابْنِ عُبَيْدِ بْنِ نِسْطَاسٍ، - عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا دَخَلَ الْعَشْرُ أَحْيَا اللَّيْلَ وَشَدَّ الْمِئْزَرَ وَأَيْقَظَ أَهْلَهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَأَبُو يَعْفُورٍ اسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ عُبَيْدِ بْنِ نِسْطَاسٍ ‏.‏\hadithno{1376}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2024) Sahih Muslim (1174)}\hadithtrans{Narrated 'Aishah: When the last ten days of Ramadan came, the Prophet (ﷺ) kept vigil and prayed during the whole night, and tied the wrapper tightly, and awakened his family (to pray during the night). Abu Dawud said: The name of Abu Ya'fur is 'Abd al-Rahman b. 'Ubaid b. Nistas}}
\hadithdefcmd{abudawud}{1377}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي مُسْلِمُ بْنُ خَالِدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَإِذَا أُنَاسٌ فِي رَمَضَانَ يُصَلُّونَ فِي نَاحِيَةِ الْمَسْجِدِ فَقَالَ ‏"‏ مَا هَؤُلاَءِ ‏"‏ ‏.‏ فَقِيلَ هَؤُلاَءِ نَاسٌ لَيْسَ مَعَهُمْ قُرْآنٌ وَأُبَىُّ بْنُ كَعْبٍ يُصَلِّي وَهُمْ يُصَلُّونَ بِصَلاَتِهِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَصَابُوا وَنِعْمَ مَا صَنَعُوا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ لَيْسَ هَذَا الْحَدِيثُ بِالْقَوِيِّ مُسْلِمُ بْنُ خَالِدٍ ضَعِيفٌ ‏.‏\hadithno{1377}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah: The Messenger of Allah (ﷺ) came out and saw that the people were praying during (the night of) Ramadan in the corner of the mosque. He asked: Who are these people ? It was said to him that those were people who had not learnt Quran. But Ubayy b. Ka'b is praying and they would pray behind him. The Prophet (ﷺ) said: They did right and it is good what they did. Abu Dawud said: This tradition is not strong, the narrator Muslim b. Khalid is weak}}
\hadithdefcmd{abudawud}{1378}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُسَدَّدٌ، - الْمَعْنَى - قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، قَالَ قُلْتُ لأُبَىِّ بْنِ كَعْبٍ أَخْبِرْنِي عَنْ لَيْلَةِ الْقَدْرِ، يَا أَبَا الْمُنْذِرِ فَإِنَّ صَاحِبَنَا سُئِلَ عَنْهَا ‏.‏ فَقَالَ مَنْ يَقُمِ الْحَوْلَ يُصِبْهَا ‏.‏ فَقَالَ رَحِمَ اللَّهُ أَبَا عَبْدِ الرَّحْمَنِ وَاللَّهِ لَقَدْ عَلِمَ أَنَّهَا فِي رَمَضَانَ - زَادَ مُسَدَّدٌ وَلَكِنْ كَرِهَ أَنْ يَتَّكِلُوا أَوْ أَحَبَّ أَنْ لاَ يَتَّكِلُوا ثُمَّ اتَّفَقَا - وَاللَّهِ إِنَّهَا لَفِي رَمَضَانَ لَيْلَةُ سَبْعٍ وَعِشْرِينَ لاَ يَسْتَثْنِي ‏.‏ قُلْتُ يَا أَبَا الْمُنْذِرِ أَنَّى عَلِمْتَ ذَلِكَ قَالَ بِالآيَةِ الَّتِي أَخْبَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قُلْتُ لِزِرٍّ مَا الآيَةُ قَالَ تُصْبِحُ الشَّمْسُ صَبِيحَةَ تِلْكَ اللَّيْلَةِ مِثْلَ الطَّسْتِ لَيْسَ لَهَا شُعَاعٌ حَتَّى تَرْتَفِعَ ‏.‏\hadithno{1378}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih Muslim (1169)}\hadithtrans{Zirr (b. Hubaish) said:I said to Ubayy b. Ka'b: Tell me about lailat al-qadr, O Abu al-Mundhir, for our companion (Ibn Mas'ud) was questioned about it, and he said: Anyone who gets up for prayer every night all the year round will hit upon it (i.e. lailat al-qadr). He replied: May Allah have mercy on Abu 'Abd al-Rahman. By Allah, he knew that it was in Ramadan, (Musaddad's version goes) but he disliked that the people should content themselves (with that night alone); or he liked that the people should not content themselves (with the night alone). According to the agreed version: By Allah, it is the twenty-seventh night of Ramadan, without any reservation. I said: How did you know that, Abu al-Mundhir? He replied: By the indication (or sign) of which the Messenger of Allah (ﷺ) informed us. I asked Zirr: What is the sign ? He replied: The sun rises like a vessel of water in the morning following that night; it has no rays until it rises high up}}
\hadithdefcmd{abudawud}{1379}{حَدَّثَنَا أَحْمَدُ بْنُ حَفْصِ بْنِ عَبْدِ اللَّهِ السُّلَمِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ عَبَّادِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ مُسْلِمٍ الزُّهْرِيِّ، عَنْ ضَمْرَةَ بْنِ عَبْدِ اللَّهِ بْنِ أُنَيْسٍ، عَنْ أَبِيهِ، قَالَ كُنْتُ فِي مَجْلِسِ بَنِي سَلِمَةَ وَأَنَا أَصْغَرُهُمْ، فَقَالُوا مَنْ يَسْأَلُ لَنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ لَيْلَةِ الْقَدْرِ وَذَلِكَ صَبِيحَةَ إِحْدَى وَعِشْرِينَ مِنْ رَمَضَانَ ‏.‏ فَخَرَجْتُ فَوَافَيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْمَغْرِبِ ثُمَّ قُمْتُ بِبَابِ بَيْتِهِ فَمَرَّ بِي فَقَالَ ‏"‏ ادْخُلْ ‏"‏ ‏.‏ فَدَخَلْتُ فَأُتِيَ بِعَشَائِهِ فَرَآنِي أَكُفُّ عَنْهُ مِنْ قِلَّتِهِ فَلَمَّا فَرَغَ قَالَ ‏"‏ نَاوِلْنِي نَعْلِي ‏"‏ ‏.‏ فَقَامَ وَقُمْتُ مَعَهُ فَقَالَ ‏"‏ كَأَنَّ لَكَ حَاجَةً ‏"‏ ‏.‏ قُلْتُ أَجَلْ أَرْسَلَنِي إِلَيْكَ رَهْطٌ مِنْ بَنِي سَلِمَةَ يَسْأَلُونَكَ عَنْ لَيْلَةِ الْقَدْرِ فَقَالَ ‏"‏ كَمِ اللَّيْلَةُ ‏"‏ ‏.‏ فَقُلْتُ اثْنَتَانِ وَعِشْرُونَ قَالَ ‏"‏ هِيَ اللَّيْلَةُ ‏"‏ ‏.‏ ثُمَّ رَجَعَ فَقَالَ ‏"‏ أَوِ الْقَابِلَةُ ‏"‏ ‏.‏ يُرِيدُ لَيْلَةَ ثَلاَثٍ وَعِشْرِينَ ‏.‏\hadithno{1379}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Unays: I was present at the gathering of Banu Salamah, and I was the youngest of them. They (the people) said: Who will ask the Messenger of Allah (ﷺ) for us about Laylat al-Qadr? That was the twenty-first of Ramadan. I went out and said the sunset prayer along with the Messenger of Allah (ﷺ). I then stood at the door of his house. He passed by me and said: Come in. I entered (the house) and dinner was brought for him. I was prevented from taking food as it was scanty. When he finished his dinner, he said to me: Give me my shoes. He then stood up and I also stood up with him. He said: Perhaps you have some business with me. I said: Yes. Some people of Banu Salamah have sent me to you to ask you about Laylat al-Qadr. He asked: Which night: Is it tonight? I said: Twenty-second. He said: This is the very night. He then withdrew and said: Or the following night, referring to the twenty-third night}}
\hadithdefcmd{abudawud}{1380}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، أَخْبَرَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، حَدَّثَنَا مُحَمَّدُ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ عَبْدِ اللَّهِ بْنِ أُنَيْسٍ الْجُهَنِيِّ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ لِي بَادِيَةً أَكُونُ فِيهَا وَأَنَا أُصَلِّي فِيهَا بِحَمْدِ اللَّهِ فَمُرْنِي بِلَيْلَةٍ أَنْزِلُهَا إِلَى هَذَا الْمَسْجِدِ ‏.‏ فَقَالَ ‏ "‏ انْزِلْ لَيْلَةَ ثَلاَثٍ وَعِشْرِينَ ‏"‏ ‏.‏ فَقُلْتُ لاِبْنِهِ كَيْفَ كَانَ أَبُوكَ يَصْنَعُ قَالَ كَانَ يَدْخُلُ الْمَسْجِدَ إِذَا صَلَّى الْعَصْرَ فَلاَ يَخْرُجُ مِنْهُ لِحَاجَةٍ حَتَّى يُصَلِّيَ الصُّبْحَ فَإِذَا صَلَّى الصُّبْحَ وَجَدَ دَابَّتَهُ عَلَى بَابِ الْمَسْجِدِ فَجَلَسَ عَلَيْهَا فَلَحِقَ بِبَادِيَتِهِ ‏.‏\hadithno{1380}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Unays al-Juhani: I said to the Messenger of Allah: I have a place in the desert where I live and in which I pray, with the praise of Allah; but give me command about a night when I come to this mosque. He replied: Come on the twenty third night. I (a sub-narrator, Muhammad ibn Ibrahim) said to his (Abdullah ibn Unays's) son: How would your father act? He replied: He used to enter the mosque when he had offered the afternoon prayer, and did not leave it for any purpose till he prayed the morning prayer. Then when he had prayed the morning prayer, he found his riding beast at the door of the mosque, mounted it and got back to his desert}}
\hadithdefcmd{abudawud}{1381}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، أَخْبَرَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْتَمِسُوهَا فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ فِي تَاسِعَةٍ تَبْقَى وَفِي سَابِعَةٍ تَبْقَى وَفِي خَامِسَةٍ تَبْقَى ‏"‏ ‏.‏\hadithno{1381}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2021)}\hadithtrans{Narrated Ibn 'Abbas:The Prophet (ﷺ) as saying: Seek laitat al-Qadr in the last ten night of Ramadan. When nine (nights) remain (i.e. on the twenty first) , when seven (night) remain (i.e. on the twenty third), and when five (nights) remain (i.e. on the twenty fifth)}}
\hadithdefcmd{abudawud}{1382}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْتَكِفُ الْعَشْرَ الأَوْسَطَ مِنْ رَمَضَانَ فَاعْتَكَفَ عَامًا حَتَّى إِذَا كَانَتْ لَيْلَةُ إِحْدَى وَعِشْرِينَ وَهِيَ اللَّيْلَةُ الَّتِي يَخْرُجُ فِيهَا مِنَ اعْتِكَافِهِ قَالَ ‏ "‏ مَنْ كَانَ اعْتَكَفَ مَعِي فَلْيَعْتَكِفِ الْعَشْرَ الأَوَاخِرَ وَقَدْ رَأَيْتُ هَذِهِ اللَّيْلَةَ ثُمَّ أُنْسِيتُهَا وَقَدْ رَأَيْتُنِي أَسْجُدُ مِنْ صَبِيحَتِهَا فِي مَاءٍ وَطِينٍ فَالْتَمِسُوهَا فِي الْعَشْرِ الأَوَاخِرِ وَالْتَمِسُوهَا فِي كُلِّ وِتْرٍ ‏"‏ ‏.‏ قَالَ أَبُو سَعِيدٍ فَمُطِرَتِ السَّمَاءُ مِنْ تِلْكَ اللَّيْلَةِ وَكَانَ الْمَسْجِدُ عَلَى عَرِيشٍ فَوَكَفَ الْمَسْجِدُ ‏.‏ فَقَالَ أَبُو سَعِيدٍ فَأَبْصَرَتْ عَيْنَاىَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَعَلَى جَبْهَتِهِ وَأَنْفِهِ أَثَرُ الْمَاءِ وَالطِّينِ مِنْ صَبِيحَةِ إِحْدَى وَعِشْرِينَ ‏.‏\hadithno{1382}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2027) Sahih Muslim (1167)}\hadithtrans{Narrated Abu Sa’id Al Khudri :The Messenger of Allah (ﷺ) used to spend the middle ten days of Ramadan in retirement and devotion (i'tikaf) in the mosque. One year he had retirement and devotion in the mosque (as usual); when the twenty-first night came, and this night when he used to come out his devotion in the mosque, he said: He who has engaged himself in devotion along with me should do so during the last ten days; I saw that night, that was caused to forget it, but I have seen myself prostrating in water and mud on the morning following (that night), so seek it in the last ten days and seek it every night with an odd number. Abu sa'id said: Rain fell that night, the mosque that was thatched building dripped, and my eyes saw the Messenger of Allah (ﷺ) with the traces of water and mud, on his forehead on the morning following the twenty-first night}}
\hadithdefcmd{abudawud}{1383}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، أَخْبَرَنَا سَعِيدٌ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْتَمِسُوهَا فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ وَالْتَمِسُوهَا فِي التَّاسِعَةِ وَالسَّابِعَةِ وَالْخَامِسَةِ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا أَبَا سَعِيدٍ إِنَّكُمْ أَعْلَمُ بِالْعَدَدِ مِنَّا ‏.‏ قَالَ أَجَلْ ‏.‏ قُلْتُ مَا التَّاسِعَةُ وَالسَّابِعَةُ وَالْخَامِسَةُ قَالَ إِذَا مَضَتْ وَاحِدَةٌ وَعِشْرُونَ فَالَّتِي تَلِيهَا التَّاسِعَةُ وَإِذَا مَضَى ثَلاَثٌ وَعِشْرُونَ فَالَّتِي تَلِيهَا السَّابِعَةُ وَإِذَا مَضَى خَمْسٌ وَعِشْرُونَ فَالَّتِي تَلِيهَا الْخَامِسَةُ ‏.‏ قَالَ أَبُو دَاوُدَ لاَ أَدْرِي أَخَفِيَ عَلَىَّ مِنْهُ شَىْءٌ أَمْ لاَ ‏.‏\hadithno{1383}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1167)}\hadithtrans{Narrated AbuSa'id al-Khudri: The Prophet (ﷺ) said: Seek it (laylat al-Qadr) in the last ten days of Ramadan. Seek it on the ninth, seventh and fifth night. I (AbuNadrah) said: You know counting better than us, AbuSa'id. He said: Yes. I asked: What do you mean by the ninth, seventh and fifth night? He said: When the twenty-first night passes, the night which follows it is the night; when the twenty-third night passes, the night which follows it is the seventh; when the twenty-fifth passes, the night which follows it is the fifth. Abu Dawud said: I do not know whether anything remained hidden from me or not}}
\hadithdefcmd{abudawud}{1384}{حَدَّثَنَا حَكِيمُ بْنُ سَيْفٍ الرَّقِّيُّ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ عَمْرٍو - عَنْ زَيْدٍ، - يَعْنِي ابْنَ أَبِي أُنَيْسَةَ - عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَسْوَدِ، عَنْ أَبِيهِ، عَنِ ابْنِ مَسْعُودٍ، قَالَ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اطْلُبُوهَا لَيْلَةَ سَبْعَ عَشْرَةَ مِنْ رَمَضَانَ وَلَيْلَةَ إِحْدَى وَعِشْرِينَ وَلَيْلَةَ ثَلاَثٍ وَعِشْرِينَ ‏"‏ ‏.‏ ثُمَّ سَكَتَ ‏.‏\hadithno{1384}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Messenger of Allah (ﷺ) said to us: Seek it (laylat al-Qadr) on the seventeenth night of Ramadan, and on the twenty first night, and on the twenty-third night. He then kept silence}}
\hadithdefcmd{abudawud}{1385}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَحَرَّوْا لَيْلَةَ الْقَدْرِ فِي السَّبْعِ الأَوَاخِرِ ‏"‏ ‏.‏\hadithno{1385}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1165)}\hadithtrans{Narrated Ibn 'Umar:The Messenger of Allah (ﷺ) as saying: Seek lailat al-qadr in the last seven days}}
\hadithdefcmd{abudawud}{1386}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، أَنَّهُ سَمِعَ مُطَرِّفًا، عَنْ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي لَيْلَةِ الْقَدْرِ قَالَ ‏ "‏ لَيْلَةُ الْقَدْرِ لَيْلَةُ سَبْعٍ وَعِشْرِينَ ‏"‏ ‏.‏\hadithno{1386}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Mu'awiyah b. Abi Sufyan :The Prophet (ﷺ) as saying: Lailat al-qadr is the twenty-seventh night (of Ramadan)}}
\hadithdefcmd{abudawud}{1387}{حَدَّثَنَا حُمَيْدُ بْنُ زَنْجُويَهْ النَّسَائِيُّ، أَخْبَرَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرِ بْنِ أَبِي كَثِيرٍ، أَخْبَرَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَسْمَعُ عَنْ لَيْلَةِ الْقَدْرِ فَقَالَ ‏ "‏ هِيَ فِي كُلِّ رَمَضَانَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ سُفْيَانُ وَشُعْبَةُ عَنْ أَبِي إِسْحَاقَ مَوْقُوفًا عَلَى ابْنِ عُمَرَ لَمْ يَرْفَعَاهُ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1387}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abd Allah bin 'Amr: The Messenger of Allah (ﷺ) was asked about lailat al-qadr and I was hearing: He said: It is during the whole of Ramadan. Abu Dawud said: Sufyan and Shu'bah narrated this tradition from Abu Ishaq as a statement of Ibn 'Umar himself, they did not transmit it as a saying of the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{1388}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، وَمُوسَى بْنُ إِسْمَاعِيلَ، قَالاَ أَخْبَرَنَا أَبَانُ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ ‏"‏ اقْرَإِ الْقُرْآنَ فِي شَهْرٍ ‏"‏ ‏.‏ قَالَ إِنِّي أَجِدُ قُوَّةً ‏.‏ قَالَ ‏"‏ اقْرَأْ فِي عِشْرِينَ ‏"‏ ‏.‏ قَالَ إِنِّي أَجِدُ قُوَّةً ‏.‏ قَالَ ‏"‏ اقْرَأْ فِي خَمْسَ عَشْرَةَ ‏"‏ ‏.‏ قَالَ إِنِّي أَجِدُ قُوَّةً ‏.‏ قَالَ ‏"‏ اقْرَأْ فِي عَشْرٍ ‏"‏ ‏.‏ قَالَ إِنِّي أَجِدُ قُوَّةً ‏.‏ قَالَ ‏"‏ اقْرَأْ فِي سَبْعٍ وَلاَ تَزِيدَنَّ عَلَى ذَلِكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدِيثُ مُسْلِمٍ أَتَمُّ ‏.‏\hadithno{1388}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5054) Sahih Muslim (1159)}\hadithtrans{Narrated 'Abd Allah b. 'Amr: The Prophet (ﷺ) as saying to him: Complete the recitation of the Qu'ran in one month. He said: I have more strength. He (the Prophet) said: Complete the recitation in twenty days. He again said: I have more energy. He said : Recite in fifteen days. He again said: I have more energy. He said: Recite in ten days. He again said: I have more energy. He said: Recite in seven days, do not add to it. Abu Dawud said: The tradition narrated by Muslim is more perfect}}
\hadithdefcmd{abudawud}{1389}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، أَخْبَرَنَا حَمَّادٌ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صُمْ مِنْ كُلِّ شَهْرٍ ثَلاَثَةَ أَيَّامٍ وَاقْرَإِ الْقُرْآنَ فِي شَهْرٍ ‏"‏ ‏.‏ فَنَاقَصَنِي وَنَاقَصْتُهُ فَقَالَ ‏"‏ صُمْ يَوْمًا وَأَفْطِرْ يَوْمًا ‏"‏ ‏.‏ قَالَ عَطَاءٌ وَاخْتَلَفْنَا عَنْ أَبِي فَقَالَ بَعْضُنَا سَبْعَةَ أَيَّامٍ وَقَالَ بَعْضُنَا خَمْسًا ‏.‏\hadithno{1389}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Abd Allah b. 'Amr:The Messenger of Allah (ﷺ) said to me: Keep fast for three days of month, and finish the recitation of the Qur'an in one month. I and he differed among ourselves on period of time. He said: Fast one day and give it up other day. The narrator 'Ata said: The people differed from my father (in narrating the period of time). Some narrated seven days and others five}}
\hadithdefcmd{abudawud}{1390}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الصَّمَدِ، أَخْبَرَنَا هَمَّامٌ، أَخْبَرَنَا قَتَادَةُ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ فِي كَمْ أَقْرَأُ الْقُرْآنَ قَالَ ‏"‏ فِي شَهْرٍ ‏"‏ ‏.‏ قَالَ إِنِّي أَقْوَى مِنْ ذَلِكَ - يُرَدِّدُ الْكَلاَمَ أَبُو مُوسَى - وَتَنَاقَصَهُ حَتَّى قَالَ ‏"‏ اقْرَأْهُ فِي سَبْعٍ ‏"‏ ‏.‏ قَالَ إِنِّي أَقْوَى مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ لاَ يَفْقَهُ مَنْ قَرَأَهُ فِي أَقَلَّ مِنْ ثَلاَثٍ ‏"‏ ‏.‏\hadithno{1390}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: Yazid ibn Abdullah said that Abdullah ibn Amr asked the Prophet (ﷺ): In how many days should I complete the recitation of the whole Qur'an, Messenger of Allah? He replied: In one month. He said: I am more energetic to complete it in a period less than this. He kept on repeating these words and lessening the period until he said: Complete its recitation in seven days. He again said: I am more energetic to complete it in a period less than this. The Prophet (ﷺ) said: He who finishes the recitation of the Qur'an in less than three days does not understand it}}
\hadithdefcmd{abudawud}{1391}{حَدَّثَنَا مُحَمَّدُ بْنُ حَفْصٍ أَبُو عَبْدِ الرَّحْمَنِ الْقَطَّانُ، خَالُ عِيسَى بْنِ شَاذَانَ أَخْبَرَنَا أَبُو دَاوُدَ، أَخْبَرَنَا الْحَرِيشُ بْنُ سُلَيْمٍ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، عَنْ خَيْثَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَإِ الْقُرْآنَ فِي شَهْرٍ ‏"‏ ‏.‏ قَالَ إِنَّ بِي قُوَّةً ‏.‏ قَالَ ‏"‏ اقْرَأْهُ فِي ثَلاَثٍ ‏"‏ ‏.‏ قَالَ أَبُو عَلِيٍّ سَمِعْتُ أَبَا دَاوُدَ يَقُولُ سَمِعْتُ أَحْمَدَ - يَعْنِي ابْنَ حَنْبَلٍ - يَقُولُ عِيسَى بْنُ شَاذَانَ كَيِّسٌ ‏.‏\hadithno{1391}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Khaithamah reported that 'Abd Allah b. 'Amr said:The Messenger of Allah (ﷺ) said to me: Recite the Qur'an in one month. I said: I have (more) energy. He said: Recite it in three days Abu 'Ali said: I heard Abu Dawud say: I heard Ahmad b. Hanbal say: The narrator 'Isa b. Shadhan is a sane person}}
\hadithdefcmd{abudawud}{1392}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، أَخْبَرَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ، عَنِ ابْنِ الْهَادِ، قَالَ سَأَلَنِي نَافِعُ بْنُ جُبَيْرِ بْنِ مُطْعِمٍ فَقَالَ لِي فِي كَمْ تَقْرَأُ الْقُرْآنَ فَقُلْتُ مَا أُحَزِّبُهُ ‏.‏ فَقَالَ لِي نَافِعٌ لاَ تَقُلْ مَا أُحَزِّبُهُ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَرَأْتُ جُزْءًا مِنَ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ حَسِبْتُ أَنَّهُ ذَكَرَهُ عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ ‏.‏\hadithno{1392}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn al-Had said:Nafi' b. Jubair asked me: In how many days do you recite the Qur'an ? I said: I have not fixed any part from it for daily round. Nafi' said to me: Do not say: I do not fix any part of it for daily round, for the Messenger of Allah (ﷺ) said: I recited a part of the Qur'an. The narrator Ibn al-Had said: I think I have transmitted this tradition from al-Mughirah b. Shu'bah}}
\hadithdefcmd{abudawud}{1393}{حَدَّثَنَا مُسَدَّدٌ، أَخْبَرَنَا قُرَّانُ بْنُ تَمَّامٍ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، أَخْبَرَنَا أَبُو خَالِدٍ، - وَهَذَا لَفْظُهُ - عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَعْلَى، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ أَوْسٍ، عَنْ جَدِّهِ، - قَالَ عَبْدُ اللَّهِ بْنُ سَعِيدٍ فِي حَدِيثِهِ أَوْسُ بْنُ حُذَيْفَةَ - قَالَ قَدِمْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي وَفْدِ ثَقِيفٍ - قَالَ - فَنَزَلَتِ الأَحْلاَفُ عَلَى الْمُغِيرَةِ بْنِ شُعْبَةَ وَأَنْزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَنِي مَالِكٍ فِي قُبَّةٍ لَهُ ‏.‏ قَالَ مُسَدَّدٌ وَكَانَ فِي الْوَفْدِ الَّذِينَ قَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ ثَقِيفٍ قَالَ كَانَ كُلَّ لَيْلَةٍ يَأْتِينَا بَعْدَ الْعِشَاءِ يُحَدِّثُنَا ‏.‏ قَالَ أَبُو سَعِيدٍ قَائِمًا عَلَى رِجْلَيْهِ حَتَّى يُرَاوِحَ بَيْنَ رِجْلَيْهِ مِنْ طُولِ الْقِيَامِ وَأَكْثَرُ مَا يُحَدِّثُنَا مَا لَقِيَ مِنْ قَوْمِهِ مِنْ قُرَيْشٍ ثُمَّ يَقُولُ لاَ سَوَاءً كُنَّا مُسْتَضْعَفِينَ مُسْتَذَلِّينَ - قَالَ مُسَدَّدٌ بِمَكَّةَ - فَلَمَّا خَرَجْنَا إِلَى الْمَدِينَةِ كَانَتْ سِجَالُ الْحَرْبِ بَيْنَنَا وَبَيْنَهُمْ نُدَالُ عَلَيْهِمْ وَيُدَالُونَ عَلَيْنَا فَلَمَّا كَانَتْ لَيْلَةً أَبْطَأَ عَنِ الْوَقْتِ الَّذِي كَانَ يَأْتِينَا فِيهِ فَقُلْنَا لَقَدْ أَبْطَأْتَ عَنَّا اللَّيْلَةَ ‏.‏ قَالَ إِنَّهُ طَرَأَ عَلَىَّ جُزْئِي مِنَ الْقُرْآنِ فَكَرِهْتُ أَنْ أَجِيءَ حَتَّى أُتِمَّهُ ‏.‏ قَالَ أَوْسٌ سَأَلْتُ أَصْحَابَ رَسُولِ اللَّهِ صلى الله عليه وسلم كَيْفَ يُحَزِّبُونَ الْقُرْآنَ قَالُوا ثَلاَثٌ وَخَمْسٌ وَسَبْعٌ وَتِسْعٌ وَإِحْدَى عَشْرَةَ وَثَلاَثَ عَشْرَةَ وَحِزْبُ الْمُفَصَّلِ وَحْدَهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدِيثُ أَبِي سَعِيدٍ أَتَمُّ ‏.‏\hadithno{1393}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aws ibn Hudhayfah: We came upon the Messenger of Allah (ﷺ) in a deputation of Thaqif. The signatories of the pact came to al-Mughirah ibn Shu'bah as his guests. The Messenger of Allah (ﷺ) made Banu-Malik stay in a tent of his. Musaddad's version says: He was in the deputation of Thaqif which came to the Messenger of Allah (ﷺ). He used to visit and have a talk with us every day after the night prayer. The version of AbuSa'id says: He remained standing for such a long time (talking to us) that he put his weight sometimes on one leg and sometimes on the other due to his long stay. He mostly told us how his people, the Quraysh, behaved with him. He would say: We were not equal; we were weak and degraded at Mecca (according to Musaddad's version). When we came over to Medina the fighting began between us; sometimes we overcome them and at other times they overcome us. One night he came late and did not come at the time he used to come. We asked him: You came late tonight? He said: I could not recite the fixed part of the Qur'an that I used to recite every day. I disliked to come till I had completed it. Aws said: I asked the companions of the Messenger of Allah (ﷺ): How do you divide the Qur'an for daily recitation? They said: Three surahs, five surahs, eleven surahs, thirteen surahs' mufassal surahs. Abu Dawud said: The version of Abu Sa'id is complete}}
\hadithdefcmd{abudawud}{1394}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمِنْهَالِ، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، أَخْبَرَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَلاَءِ، يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ عَنْ عَبْدِ اللَّهِ، - يَعْنِي ابْنَ عَمْرٍو - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَفْقَهُ مَنْ قَرَأَ الْقُرْآنَ فِي أَقَلَّ مِنْ ثَلاَثٍ ‏"‏ ‏.‏\hadithno{1394}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: He who recites the Qur'an in a period less than three days does not understand it}}
\hadithdefcmd{abudawud}{1395}{حَدَّثَنَا نُوحُ بْنُ حَبِيبٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ سِمَاكِ بْنِ الْفَضْلِ، عَنْ وَهْبِ بْنِ مُنَبِّهٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّهُ سَأَلَ النَّبِيَّ صلى الله عليه وسلم فِي كَمْ يَقْرَأُ الْقُرْآنَ قَالَ ‏"‏ فِي أَرْبَعِينَ يَوْمًا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ فِي شَهْرٍ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ فِي عِشْرِينَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ فِي خَمْسَ عَشْرَةَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ فِي عَشْرٍ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ فِي سَبْعٍ ‏"‏ ‏.‏ لَمْ يَنْزِلْ مِنْ سَبْعٍ ‏.‏\hadithno{1395}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: Wahb ibn Munabbih said: Abdullah ibn Amr asked the Prophet (ﷺ); In how many days should one complete the recitation of the Qur'an? He said: In forty days. He then said: In one month. He again said: In twenty days. He then said: In fifteen days. He then said: In ten days. Finally he said: In seven days}}
\hadithdefcmd{abudawud}{1396}{حَدَّثَنَا عَبَّادُ بْنُ مُوسَى، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، قَالاَ أَتَى ابْنَ مَسْعُودٍ رَجُلٌ فَقَالَ إِنِّي أَقْرَأُ الْمُفَصَّلَ فِي رَكْعَةٍ ‏.‏ فَقَالَ أَهَذًّا كَهَذِّ الشِّعْرِ وَنَثْرًا كَنَثْرِ الدَّقَلِ لَكِنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ النَّظَائِرَ السُّورَتَيْنِ فِي رَكْعَةٍ الرَّحْمَنَ وَالنَّجْمَ فِي رَكْعَةٍ وَاقْتَرَبَتْ وَالْحَاقَّةَ فِي رَكْعَةٍ وَالطُّورَ وَالذَّارِيَاتِ فِي رَكْعَةٍ وَإِذَا وَقَعَتْ وَن فِي رَكْعَةٍ وَسَأَلَ سَائِلٌ وَالنَّازِعَاتِ فِي رَكْعَةٍ وَوَيْلٌ لِلْمُطَفِّفِينَ وَعَبَسَ فِي رَكْعَةٍ وَالْمُدَّثِّرَ وَالْمُزَّمِّلَ فِي رَكْعَةٍ وَهَلْ أَتَى وَلاَ أُقْسِمُ بِيَوْمِ الْقِيَامَةِ فِي رَكْعَةٍ ‏.‏ وَعَمَّ يَتَسَاءَلُونَ وَالْمُرْسَلاَتِ فِي رَكْعَةٍ وَالدُّخَانَ وَإِذَا الشَّمْسُ كُوِّرَتْ فِي رَكْعَةٍ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا تَأْلِيفُ ابْنِ مَسْعُودٍ رَحِمَهُ اللَّهُ ‏.‏\hadithno{1396}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn Mas'ud: Alqamah and al-Aswad said: A man came to Ibn Mas'ud. He said: I recite the mufassal surahs in one rak'ah. You might recite it quickly as one recites verse (poetry) quickly, or as the dried dates fall down (from the tree). But the Prophet (ﷺ) used to recite two equal surahs in one rak'ah; he would recite (for instance) surahs an-Najm (53) and ar-Rahman (55) in one rak'ah, surahs Iqtarabat (54) and al-Haqqah (69) in one rak'ah, surahs at-Tur (52) and adh-Dhariyat (51) in one rak'ah, surahs al-Waqi'ah (56) and Nun (68) in one rak'ah, surahs al-Ma'arij (70) and an-Nazi'at (79) in one rak'ah, surahs al-Mutaffifin (83) and Abasa (80) in one rak'ah, surahs al-Muddaththir (74) and al-Muzzammil (73) in one rak'ah, surahs al-Insan (76) and al-Qiyamah (75) in one rak'ah, surahs an-Naba' (78) and al-Mursalat (77) in one rak'ah, and surahs ad-Dukhan (44) and at-Takwir (81) in one rak'ah. Abu Dawud said: This is the arrangement of Ibn Mas'ud himself}}
\hadithdefcmd{abudawud}{1397}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، أَخْبَرَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ سَأَلْتُ أَبَا مَسْعُودٍ وَهُوَ يَطُوفُ بِالْبَيْتِ فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَرَأَ الآيَتَيْنِ مِنْ آخِرِ سُورَةِ الْبَقَرَةِ فِي لَيْلَةٍ كَفَتَاهُ ‏"‏ ‏.‏\hadithno{1397}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5008) Sahih Muslim (807)}\hadithtrans{Abd al-Rahman b. Yazid said:I asked Abu Mas'ud while he was making circumambulation of the Ka'bah (about the recitation of some verses from the Qur'an). He said: The Messenger of Allah (ﷺ) said: If anyone recited two verses from the last of Surah al-Baqarah at night, they will be sufficient for him}}
\hadithdefcmd{abudawud}{1398}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا عَمْرٌو، أَنَّ أَبَا سَوِيَّةَ، حَدَّثَهُ أَنَّهُ، سَمِعَ ابْنَ حُجَيْرَةَ، يُخْبِرُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَامَ بِعَشْرِ آيَاتٍ لَمْ يُكْتَبْ مِنَ الْغَافِلِينَ وَمَنْ قَامَ بِمِائَةِ آيَةٍ كُتِبَ مِنَ الْقَانِتِينَ وَمَنْ قَامَ بِأَلْفِ آيَةٍ كُتِبَ مِنَ الْمُقَنْطَرِينَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ابْنُ حُجَيْرَةَ الأَصْغَرُ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ حُجَيْرَةَ ‏.‏\hadithno{1398}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: If anyone prays at night reciting regularly ten verses, he will not be recorded among the negligent; if anyone prays at night and recites a hundred verses, he will be recorded among those who are obedient to Allah; and if anyone prays at night reciting one thousand verses, he will be recorded among those who receive huge rewards. Abu Dawud said: The name of Ibn Hujairah al-Asghar is 'Abd Allah b. 'Abd al-Rahman b. Hujairah}}
\hadithdefcmd{abudawud}{1399}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى الْبَلْخِيُّ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، قَالاَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، أَخْبَرَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، حَدَّثَنِي عَيَّاشُ بْنُ عَبَّاسٍ الْقِتْبَانِيُّ، عَنْ عِيسَى بْنِ هِلاَلٍ الصَّدَفِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ أَتَى رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ أَقْرِئْنِي يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ اقْرَأْ ثَلاَثًا مِنْ ذَوَاتِ الرَّاءِ ‏"‏ ‏.‏ فَقَالَ كَبِرَتْ سِنِّي وَاشْتَدَّ قَلْبِي وَغَلُظَ لِسَانِي ‏.‏ قَالَ ‏"‏ فَاقْرَأْ ثَلاَثًا مِنْ ذَوَاتِ حم ‏"‏ ‏.‏ فَقَالَ مِثْلَ مَقَالَتِهِ ‏.‏ فَقَالَ ‏"‏ اقْرَأْ ثَلاَثًا مِنَ الْمُسَبِّحَاتِ ‏"‏ ‏.‏ فَقَالَ مِثْلَ مَقَالَتِهِ فَقَالَ الرَّجُلُ يَا رَسُولَ اللَّهِ أَقْرِئْنِي سُورَةً جَامِعَةً ‏.‏ فَأَقْرَأَهُ النَّبِيُّ صلى الله عليه وسلم ‏\{‏ إِذَا زُلْزِلَتِ الأَرْضُ ‏\}‏ حَتَّى فَرَغَ مِنْهَا ‏.‏ فَقَالَ الرَّجُلُ وَالَّذِي بَعَثَكَ بِالْحَقِّ لاَ أَزِيدُ عَلَيْهَا أَبَدًا ثُمَّ أَدْبَرَ الرَّجُلُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَفْلَحَ الرُّوَيْجِلُ ‏"‏ ‏.‏ مَرَّتَيْنِ ‏.‏\hadithno{1399}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr: A man came to the Messenger of Allah (ﷺ) and said: Teach me to read the Qur'an, Messenger of Allah. He said: Read three surahs which begin with A.L.R. He said: My age is advanced, my mind has become dull (i.e. memory has grown weak), and my tongue has grown heavy). So he said: Then read three surahs which begin with H.M. He repeated the same words. So he said: Read three surahs which begin with the "Glorification of Allah". But he repeated the same excuse. The man then said: Teach me a comprehensive surah, Messenger of Allah. The Prophet (ﷺ) taught him Surah (99). "When the Earth is shaken with her earthquake". When he finished it, the man said: By Him Who sent you with truth, I shall never add anything to it. Then man then went away. The Prophet (ﷺ) said twice: The man received salvation}}
\hadithdefcmd{abudawud}{1400}{حَدَّثَنَا عَمْرُو بْنُ مَرْزُوقٍ، أَخْبَرَنَا شُعْبَةُ، أَخْبَرَنَا قَتَادَةُ، عَنْ عَبَّاسٍ الْجُشَمِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ سُورَةٌ مِنَ الْقُرْآنِ ثَلاَثُونَ آيَةً تَشْفَعُ لِصَاحِبِهَا حَتَّى يُغْفَرَ لَهُ ‏\{‏ تَبَارَكَ الَّذِي بِيَدِهِ الْمُلْكُ ‏\}‏ ‏"‏ ‏.‏\hadithno{1400}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: A surah of the Qur'an containing thirty verses will intercede its reader till he will be forgiven. That is: "Blessed is He in Whose Hand is the sovereignty" (Surah)}}
