% Auto-generated chapter 12 for tirmidhi
% Hadiths in this chapter: 29

\hadithdefcmd{tirmidhi}{1146}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَلِيُّ بْنُ زَيْدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ حَرَّمَ مِنَ الرَّضَاعِ مَا حَرَّمَ مِنَ النَّسَبِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَابْنِ عَبَّاسٍ وَأُمِّ حَبِيبَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1146}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ali (bin Abi Talib) narrated that The Messenger of Allah said:“Indeed Allah has made unlawful through suckling whatever He made unlawful through lineage.”}}
\hadithdefcmd{tirmidhi}{1147}{حَدَّثَنَا بُنْدَارٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، قَالَ حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ حَرَّمَ مِنَ الرَّضَاعَةِ مَا حَرَّمَ مِنَ الْوِلاَدَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ لاَ نَعْلَمُ بَيْنَهُمْ فِي ذَلِكَ اخْتِلاَفًا ‏.‏\hadithno{1147}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated that the Messenger of Allah said:“Indeed Allah has made unlawful through suckling whatever He made unlawful through birth.”}}
\hadithdefcmd{tirmidhi}{1148}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَ عَمِّي مِنَ الرَّضَاعَةِ يَسْتَأْذِنُ عَلَىَّ فَأَبَيْتُ أَنْ آذَنَ لَهُ حَتَّى أَسْتَأْمِرَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَلْيَلِجْ عَلَيْكِ فَإِنَّهُ عَمُّكِ ‏"‏ ‏.‏ قَالَتْ إِنَّمَا أَرْضَعَتْنِي الْمَرْأَةُ وَلَمْ يُرْضِعْنِي الرَّجُلُ ‏.‏ قَالَ ‏"‏ فَإِنَّهُ عَمُّكِ فَلْيَلِجْ عَلَيْكِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ كَرِهُوا لَبَنَ الْفَحْلِ وَالأَصْلُ فِي هَذَا حَدِيثُ عَائِشَةَ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ فِي لَبَنِ الْفَحْلِ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏\hadithno{1148}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:“My uncle through suckling came and asked permission (to enter) but I refused to admit him until I asked the Messenger of Allah. So the Messenger of Allah said: “Let him in since he is your uncle.’” She said: “It is only the woman who suckled me; I was not suckled by the man.’ So he said: ‘Indeed he is your uncle, so let him in.’”}}
\hadithdefcmd{tirmidhi}{1149}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، قَالَ حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ سُئِلَ عَنْ رَجُلٍ، لَهُ جَارِيَتَانِ أَرْضَعَتْ إِحْدَاهُمَا جَارِيَةً وَالأُخْرَى غُلاَمًا أَيَحِلُّ لِلْغُلاَمِ أَنْ يَتَزَوَّجَ بِالْجَارِيَةِ فَقَالَ لاَ اللِّقَاحُ وَاحِدٌ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا تَفْسِيرُ لَبَنِ الْفَحْلِ وَهَذَا الأَصْلُ فِي هَذَا الْبَابِ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{1149}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Amr bin Ash-Shariq narrated that Ibn Abbas was asked about the case in which a man had two slave girls, one of them suckled a girl and the other suckled a boy, is it lawful for the boy to marry the girl? She said:“No, the semen is the same.”}}
\hadithdefcmd{tirmidhi}{1150}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، قَالَ حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ أَيُّوبَ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تُحَرِّمُ الْمَصَّةُ وَلاَ الْمَصَّتَانِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُمِّ الْفَضْلِ وَأَبِي هُرَيْرَةَ وَالزُّبَيْرِ بْنِ الْعَوَّامِ وَابْنِ الزُّبَيْرِ ‏.‏ وَرَوَى غَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تُحَرِّمُ الْمَصَّةُ وَلاَ الْمَصَّتَانِ ‏"‏ ‏.‏ وَرَوَى مُحَمَّدُ بْنُ دِينَارٍ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ عَنِ الزُّبَيْرِ عَنِ النَّبِيِّ عَلَيْهِ الصَّلاَةُ وَالسَّلاَمُ ‏.‏ وَزَادَ فِيهِ مُحَمَّدُ بْنُ دِينَارٍ الْبَصْرِيُّ عَنِ الزُّبَيْرِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَهُوَ غَيْرُ مَحْفُوظٍ ‏.‏ وَالصَّحِيحُ عِنْدَ أَهْلِ الْحَدِيثِ حَدِيثُ ابْنِ أَبِي مُلَيْكَةَ عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا فَقَالَ الصَّحِيحُ عَنِ ابْنِ الزُّبَيْرِ عَنْ عَائِشَةَ وَحَدِيثُ مُحَمَّدِ بْنِ دِينَارٍ خَطَأٌ أَخْطَأَ فِيهِ مُحَمَّدُ بْنُ دِينَارٍ وَزَادَ فِيهِ عَنِ الزُّبَيْرِ وَإِنَّمَا هُوَ هِشَامُ بْنُ عُرْوَةَ عَنْ أَبِيهِ عَنِ الزُّبَيْرِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ ‏.‏ وَقَالَتْ عَائِشَةُ أُنْزِلَ فِي الْقُرْآنِ عَشْرُ رَضَعَاتٍ مَعْلُومَاتٍ ‏.‏ فَنُسِخَ مِنْ ذَلِكَ خَمْسٌ وَصَارَ إِلَى خَمْسِ رَضَعَاتٍ مَعْلُومَاتٍ ‏.‏ فَتُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالأَمْرُ عَلَى ذَلِكَ ‏.‏ حَدَّثَنَا بِذَلِكَ إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ حَدَّثَنَا مَعْنٌ حَدَّثَنَا مَالِكٌ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ عَنْ عَمْرَةَ عَنْ عَائِشَةَ بِهَذَا ‏.‏ وَبِهَذَا كَانَتْ عَائِشَةُ تُفْتِي وَبَعْضُ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم وَهُوَ قَوْلُ الشَّافِعِيِّ وَإِسْحَاقَ ‏.‏ وَقَالَ أَحْمَدُ بِحَدِيثِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ تُحَرِّمُ الْمَصَّةُ وَلاَ الْمَصَّتَانِ ‏"‏ ‏.‏ وَقَالَ إِنْ ذَهَبَ ذَاهِبٌ إِلَى قَوْلِ عَائِشَةَ فِي خَمْسِ رَضَعَاتٍ فَهُوَ مَذْهَبٌ قَوِيٌّ ‏.‏ وَجَبُنَ عَنْهُ أَنْ يَقُولَ فِيهِ شَيْئًا ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ يُحَرِّمُ قَلِيلُ الرَّضَاعِ وَكَثِيرُهُ إِذَا وَصَلَ إِلَى الْجَوْفِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكِ بْنِ أَنَسٍ وَالأَوْزَاعِيِّ وَعَبْدِ اللَّهِ بْنِ الْمُبَارَكِ وَوَكِيعٍ وَأَهْلِ الْكُوفَةِ ‏.‏ عَبْدُ اللَّهِ بْنُ أَبِي مُلَيْكَةَ هُوَ عَبْدُ اللَّهِ بْنُ عُبَيْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ وَيُكْنَى أَبَا مُحَمَّدٍ وَكَانَ عَبْدُ اللَّهِ قَدِ اسْتَقْضَاهُ عَلَى الطَّائِفِ وَقَالَ ابْنُ جُرَيْجٍ عَنِ ابْنِ أَبِي مُلَيْكَةَ قَالَ أَدْرَكْتُ ثَلاَثِينَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1150}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin Az-Zubair narrated from Aishah from the Prophet who said:“One sip or two sips do not make a prohibition.”}}
\hadithdefcmd{tirmidhi}{1151}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، قَالَ حَدَّثَنِي عُبَيْدُ بْنُ أَبِي مَرْيَمَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ، قَالَ وَسَمِعْتُهُ مِنْ، عُقْبَةَ وَلَكِنِّي لِحَدِيثِ عُبَيْدٍ أَحْفَظُ قَالَ تَزَوَّجْتُ امْرَأَةً فَجَاءَتْنَا امْرَأَةٌ سَوْدَاءُ فَقَالَتْ إِنِّي قَدْ أَرْضَعْتُكُمَا ‏.‏ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ تَزَوَّجْتُ فُلاَنَةَ بِنْتَ فُلاَنٍ فَجَاءَتْنَا امْرَأَةٌ سَوْدَاءُ فَقَالَتْ إِنِّي قَدْ أَرْضَعْتُكُمَا وَهِيَ كَاذِبَةٌ ‏.‏ قَالَ فَأَعْرَضَ عَنِّي ‏.‏ قَالَ فَأَتَيْتُهُ مِنْ قِبَلِ وَجْهِهِ فَأَعْرَضَ عَنِّي بِوَجْهِهِ فَقُلْتُ إِنَّهَا كَاذِبَةٌ ‏.‏ قَالَ ‏"‏ وَكَيْفَ بِهَا وَقَدْ زَعَمَتْ أَنَّهَا قَدْ أَرْضَعَتْكُمَا دَعْهَا عَنْكَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُقْبَةَ بْنِ الْحَارِثِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى غَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنِ ابْنِ أَبِي مُلَيْكَةَ عَنْ عُقْبَةَ بْنِ الْحَارِثِ وَلَمْ يَذْكُرُوا فِيهِ عَنْ عُبَيْدِ بْنِ أَبِي مَرْيَمَ وَلَمْ يَذْكُرُوا فِيهِ ‏"‏ دَعْهَا عَنْكَ ‏"‏ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَجَازُوا شَهَادَةَ الْمَرْأَةِ الْوَاحِدَةِ فِي الرَّضَاعِ ‏.‏ وَقَالَ ابْنُ عَبَّاسٍ تَجُوزُ شَهَادَةُ امْرَأَةٍ وَاحِدَةٍ فِي الرَّضَاعِ وَيُؤْخَذُ يَمِينُهَا ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَدْ قَالَ بَعْضُ أَهْلِ الْعِلْمِ لاَ تَجُوزُ شَهَادَةُ الْمَرْأَةِ الْوَاحِدَةِ حَتَّى يَكُونَ أَكْثَرَ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏ سَمِعْتُ الْجَارُودَ يَقُولُ سَمِعْتُ وَكِيعًا يَقُولُ لاَ تَجُوزُ شَهَادَةُ امْرَأَةٍ وَاحِدَةٍ فِي الْحُكْمِ وَيُفَارِقُهَا فِي الْوَرَعِ ‏.‏\hadithno{1151}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abdullah bin Abi Mulaikah narrated:“Ubaid bin Abi Maryam narrated to me from Uqbah bin Al-Harith” and, he (Abdullah bin Abi Mulaikah) said: “And I heard it from Uqbah bin Al-Harith, but to me, the narration of Ubaid is better preserved; he said: (Uqbah bin Al-Harith narrated: ) “I married a woman, then a black woman came to us and she said: ‘I suckled both of you.’ So I went to the Prophet and said: ‘I married so-and-so the daughter of so-and-so, then a black women came to us, and said: “I suckled both of you” but she is a liar.’” He said: “Then he (pbuh) turned away from me.” He said: “So I went around to face him (and he (pbuh) turned his face away from me) so I said: ‘She is a liar.’ He said: ‘How can you stay with her while she claims that she suckled both of you? Leave her.’”}}
\hadithdefcmd{tirmidhi}{1152}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُحَرِّمُ مِنَ الرَّضَاعَةِ إِلاَّ مَا فَتَقَ الأَمْعَاءَ فِي الثَّدْىِ وَكَانَ قَبْلَ الْفِطَامِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ الرَّضَاعَةَ لاَ تُحَرِّمُ إِلاَّ مَا كَانَ دُونَ الْحَوْلَيْنِ وَمَا كَانَ بَعْدَ الْحَوْلَيْنِ الْكَامِلَيْنِ فَإِنَّهُ لاَ يُحَرِّمُ شَيْئًا ‏.‏ وَفَاطِمَةُ بِنْتُ الْمُنْذِرِ بْنِ الزُّبَيْرِ بْنِ الْعَوَّامِ هِيَ امْرَأَةُ هِشَامِ بْنِ عُرْوَةَ ‏.‏\hadithno{1152}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umm Salamah narrated that The Messenger of Allah said:“No prohibition results from suckling except for what penetrates the intestines while on the breast before weaning.”}}
\hadithdefcmd{tirmidhi}{1153}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ حَجَّاجِ بْنِ حَجَّاجٍ الأَسْلَمِيِّ، عَنْ أَبِيهِ، أَنَّهُ سَأَلَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ مَا يُذْهِبُ عَنِّي مَذَمَّةَ الرَّضَاعِ فَقَالَ ‏ "‏ غُرَّةٌ عَبْدٌ أَوْ أَمَةٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَمَعْنَى قَوْلِهِ مَا يُذْهِبُ عَنِّي مَذَمَّةَ الرَّضَاعِ ‏.‏ يَقُولُ إِنَّمَا يَعْنِي بِهِ ذِمَامَ الرَّضَاعَةِ وَحَقَّهَا يَقُولُ إِذَا أَعْطَيْتَ الْمُرْضِعَةَ عَبْدًا أَوْ أَمَةً فَقَدْ قَضَيْتَ ذِمَامَهَا ‏.‏ وَيُرْوَى عَنْ أَبِي الطُّفَيْلِ قَالَ كُنْتُ جَالِسًا مَعَ النَّبِيِّ صلى الله عليه وسلم إِذْ أَقْبَلَتِ امْرَأَةٌ فَبَسَطَ النَّبِيُّ صلى الله عليه وسلم رِدَاءَهُ حَتَّى قَعَدَتْ عَلَيْهِ فَلَمَّا ذَهَبَتْ قِيلَ هِيَ كَانَتْ أَرْضَعَتِ النَّبِيَّ صلى الله عليه وسلم ‏.‏ هَكَذَا رَوَاهُ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ وَحَاتِمُ بْنُ إِسْمَاعِيلَ وَغَيْرُ وَاحِدٍ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنْ حَجَّاجِ بْنِ حَجَّاجٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَوَى سُفْيَانُ بْنُ عُيَيْنَةَ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنْ حَجَّاجِ بْنِ أَبِي حَجَّاجٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَحَدِيثُ ابْنِ عُيَيْنَةَ غَيْرُ مَحْفُوظٍ وَالصَّحِيحُ مَا رَوَى هَؤُلاَءِ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ ‏.‏ وَهِشَامُ بْنُ عُرْوَةَ يُكْنَى أَبَا الْمُنْذِرِ وَقَدْ أَدْرَكَ جَابِرَ بْنَ عَبْدِ اللَّهِ وَابْنَ عُمَرَ ‏.‏\hadithno{1153}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Hajjaj bin Hajjaj Al-Aslami narrated that His father asked the Prophet:“O Messenger of Allah! What will remove the responsibility of the foster relationship from me?” So he said: “A Ghurrah: a male slave or a female slave.”}}
\hadithdefcmd{tirmidhi}{1154}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ زَوْجُ بَرِيرَةَ عَبْدًا فَخَيَّرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَاخْتَارَتْ نَفْسَهَا وَلَوْ كَانَ حُرًّا لَمْ يُخَيِّرْهَا ‏.‏\hadithno{1154}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated:“Barfah’s husband was a slave, so the Messenger of Allah let her chose, and she chose herself, and if he was a free man she would not have had a choice.”}}
\hadithdefcmd{tirmidhi}{1155}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ زَوْجُ بَرِيرَةَ حُرًّا فَخَيَّرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ هَكَذَا رَوَى هِشَامٌ عَنْ أَبِيهِ عَنْ عَائِشَةَ قَالَتْ كَانَ زَوْجُ بَرِيرَةَ عَبْدًا ‏.‏ وَرَوَى عِكْرِمَةُ عَنِ ابْنِ عَبَّاسٍ قَالَ رَأَيْتُ زَوْجَ بَرِيرَةَ وَكَانَ عَبْدًا يُقَالُ لَهُ مُغِيثٌ ‏.‏ وَهَكَذَا رُوِيَ عَنِ ابْنِ عُمَرَ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَقَالُوا إِذَا كَانَتِ الأَمَةُ تَحْتَ الْحُرِّ فَأُعْتِقَتْ فَلاَ خِيَارَ لَهَا وَإِنَّمَا يَكُونُ لَهَا الْخِيَارُ إِذَا أُعْتِقَتْ وَكَانَتْ تَحْتَ عَبْدٍ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَرَوَى الأَعْمَشُ عَنْ إِبْرَاهِيمَ عَنِ الأَسْوَدِ عَنْ عَائِشَةَ قَالَتْ كَانَ زَوْجُ بَرِيرَةَ حُرًّا فَخَيَّرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ وَرَوَى أَبُو عَوَانَةَ هَذَا الْحَدِيثَ عَنِ الأَعْمَشِ عَنْ إِبْرَاهِيمَ عَنِ الأَسْوَدِ عَنْ عَائِشَةَ فِي قِصَّةِ بَرِيرَةَ قَالَ الأَسْوَدُ وَكَانَ زَوْجُهَا حُرًّا ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنَ التَّابِعِينَ وَمَنْ بَعْدَهُمْ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏\hadithno{1155}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:“Barfah’s husband was a free man, so the Messenger of Allah let her choose.”}}
\hadithdefcmd{tirmidhi}{1156}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ أَيُّوبَ، وَقَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ زَوْجَ، بَرِيرَةَ كَانَ عَبْدًا أَسْوَدَ لِبَنِي الْمُغِيرَةِ يَوْمَ أُعْتِقَتْ بَرِيرَةُ وَاللَّهِ لَكَأَنِّي بِهِ فِي طُرُقِ الْمَدِينَةِ وَنَوَاحِيهَا وَإِنَّ دُمُوعَهُ لَتَسِيلُ عَلَى لِحْيَتِهِ يَتَرَضَّاهَا لِتَخْتَارَهُ فَلَمْ تَفْعَلْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَسَعِيدُ بْنُ أَبِي عَرُوبَةَ هُوَ سَعِيدُ بْنُ مِهْرَانَ وَيُكْنَى أَبَا النَّضْرِ ‏.‏\hadithno{1156}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ibn Abbas narrated:“Barfahs husband was a black slave belonging to Banu Al-Mughirah. On the day that Barirah was freed. By Allah! It is as if I can see him in the streets of Al-Madinah behind her. Indeed tears were flowing down his beard while he was trying to get her to chose to stay with him, but she did not do it.”}}
\hadithdefcmd{tirmidhi}{1157}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْوَلَدُ لِلْفِرَاشِ وَلِلْعَاهِرِ الْحَجَرُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَعُثْمَانَ وَعَائِشَةَ وَأَبِي أُمَامَةَ وَعَمْرِو بْنِ خَارِجَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَالْبَرَاءِ بْنِ عَازِبٍ وَزَيْدِ بْنِ أَرْقَمَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ وَقَدْ رَوَاهُ الزُّهْرِيُّ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ وَأَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{1157}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that The Messenger of Allah said:“The child is for the bed, and for the fornicator is the stone.”}}
\hadithdefcmd{tirmidhi}{1158}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا هِشَامُ بْنُ أَبِي عَبْدِ اللَّهِ، وَهُوَ الدَّسْتَوَائِيُّ عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى امْرَأَةً فَدَخَلَ عَلَى زَيْنَبَ فَقَضَى حَاجَتَهُ وَخَرَجَ وَقَالَ ‏ "‏ إِنَّ الْمَرْأَةَ إِذَا أَقْبَلَتْ أَقْبَلَتْ فِي صُورَةِ شَيْطَانٍ فَإِذَا رَأَى أَحَدُكُمُ امْرَأَةً فَأَعْجَبَتْهُ فَلْيَأْتِ أَهْلَهُ فَإِنَّ مَعَهَا مِثْلَ الَّذِي مَعَهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ صَحِيحٌ حَسَنٌ غَرِيبٌ ‏.‏ وَهِشَامٌ الدَّسْتَوَائِيُّ هُوَ هِشَامُ بْنُ سَنْبَرٍ ‏.‏\hadithno{1158}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir (bin Abdullah) narrated:“The Prophet saw a woman, then he went to Zainab to fulfill his need and he left. He said: ‘Indeed when the woman enters, she enters in the image of Shaitan. So when one of you sees a woman that he is fascinated with, then let him go to his wife, for indeed with her (his wife) is the same as that which is with her.”}}
\hadithdefcmd{tirmidhi}{1159}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ كُنْتُ آمِرًا أَحَدًا أَنْ يَسْجُدَ لأَحَدٍ لأَمَرْتُ الْمَرْأَةَ أَنْ تَسْجُدَ لِزَوْجِهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ مُعَاذِ بْنِ جَبَلٍ وَسُرَاقَةَ بْنِ مَالِكِ بْنِ جُعْشُمٍ وَعَائِشَةَ وَابْنِ عَبَّاسٍ وَعَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى وَطَلْقِ بْنِ عَلِيٍّ وَأُمِّ سَلَمَةَ وَأَنَسٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ مُحَمَّدِ بْنِ عَمْرٍو عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{1159}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that The Prophet said:“If I were to order anyone to prostrate to anyone, then I would order the wife to prostrate to her husband.”}}
\hadithdefcmd{tirmidhi}{1160}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا مُلاَزِمُ بْنُ عَمْرٍو، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بَدْرٍ، عَنْ قَيْسِ بْنِ طَلْقٍ، عَنْ أَبِيهِ، طَلْقِ بْنِ عَلِيٍّ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا الرَّجُلُ دَعَا زَوْجَتَهُ لِحَاجَتِهِ فَلْتَأْتِهِ وَإِنْ كَانَتْ عَلَى التَّنُّورِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{1160}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Talq bin Ali narrated that The Messenger of Allah said:“When a man calls his wife to fulfill his need, then let her come, even if she is at the oven.”}}
\hadithdefcmd{tirmidhi}{1161}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى الْكُوفِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ أَبِي نَصْرٍ، عَنْ مُسَاوِرٍ الْحِمْيَرِيِّ، عَنْ أُمِّهِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا امْرَأَةٍ مَاتَتْ وَزَوْجُهَا عَنْهَا رَاضٍ دَخَلَتِ الْجَنَّةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{1161}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Umm Salamah narrated that The Messenger of Allah said:“Whichever woman dies while her husband is pleased with her, then she enters Paradise.”}}
\hadithdefcmd{tirmidhi}{1162}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَكْمَلُ الْمُؤْمِنِينَ إِيمَانًا أَحْسَنُهُمْ خُلُقًا وَخِيَارُكُمْ خِيَارُكُمْ لِنِسَائِهِمْ خُلُقًا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1162}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that The Messenger of Allah said:“The most complete of the believers in faith, is the one with the best character among them. And the best of you are those who are best to your women.”}}
\hadithdefcmd{tirmidhi}{1163}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ شَبِيبِ بْنِ غَرْقَدَةَ، عَنْ سُلَيْمَانَ بْنِ عَمْرِو بْنِ الأَحْوَصِ، قَالَ حَدَّثَنِي أَبِي أَنَّهُ، شَهِدَ حَجَّةَ الْوَدَاعِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَذَكَّرَ وَوَعَظَ فَذَكَرَ فِي الْحَدِيثِ قِصَّةً فَقَالَ ‏"‏ أَلاَ وَاسْتَوْصُوا بِالنِّسَاءِ خَيْرًا فَإِنَّمَا هُنَّ عَوَانٌ عِنْدَكُمْ لَيْسَ تَمْلِكُونَ مِنْهُنَّ شَيْئًا غَيْرَ ذَلِكَ إِلاَّ أَنْ يَأْتِينَ بِفَاحِشَةٍ مُبَيِّنَةٍ فَإِنْ فَعَلْنَ فَاهْجُرُوهُنَّ فِي الْمَضَاجِعِ وَاضْرِبُوهُنَّ ضَرْبًا غَيْرَ مُبَرِّحٍ فَإِنْ أَطَعْنَكُمْ فَلاَ تَبْغُوا عَلَيْهِنَّ سَبِيلاً أَلاَ إِنَّ لَكُمْ عَلَى نِسَائِكُمْ حَقًّا وَلِنِسَائِكُمْ عَلَيْكُمْ حَقًّا فَأَمَّا حَقُّكُمْ عَلَى نِسَائِكُمْ أَلاَّ يُوطِئْنَ فُرُشَكُمْ مَنْ تَكْرَهُونَ وَلاَ يَأْذَنَّ فِي بُيُوتِكُمْ لِمَنْ تَكْرَهُونَ أَلاَ وَحَقُّهُنَّ عَلَيْكُمْ أَنْ تُحْسِنُوا إِلَيْهِنَّ فِي كِسْوَتِهِنَّ وَطَعَامِهِنَّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ عَوَانٌ عِنْدَكُمْ ‏"‏ ‏.‏ يَعْنِي أَسْرَى فِي أَيْدِيكُمْ ‏.‏\hadithno{1163}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Sulaiman bin Amr bin Al-Ahwas said:“My father narrated to me that he witnessed the farewell Hajj with the Messenger of Allah. So he thanked and praised Allah and he reminded and gave admonition. He mentioned a story in his narration and he (the Prophet) said: “And indeed I order you to be good to the women, for they are but captives with you over whom you have no power than that, except if they come with manifest Fahishah (evil behavior). If they do that, then abandon their beds and beat them with a beating that is not harmful. And if they obey you then you have no cause against them. Indeed you have rights over your women, and your women have rights over you. As for your rights over your women, then they must not allow anyone whom you dislike to treat on your bedding (furniture), nor to admit anyone in your home that you dislike. And their rights over you are that you treat them well in clothing them and feeding them.”}}
\hadithdefcmd{tirmidhi}{1164}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَهَنَّادٌ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ عِيسَى بْنِ حِطَّانَ، عَنْ مُسْلِمِ بْنِ سَلاَّمٍ، عَنْ عَلِيِّ بْنِ طَلْقٍ، قَالَ أَتَى أَعْرَابِيٌّ النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ الرَّجُلُ مِنَّا يَكُونُ فِي الْفَلاَةِ فَتَكُونُ مِنْهُ الرُّوَيْحَةُ وَيَكُونُ فِي الْمَاءِ قِلَّةٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا فَسَا أَحَدُكُمْ فَلْيَتَوَضَّأْ وَلاَ تَأْتُوا النِّسَاءَ فِي أَعْجَازِهِنَّ فَإِنَّ اللَّهَ لاَ يَسْتَحْيِي مِنَ الْحَقِّ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَخُزَيْمَةَ بْنِ ثَابِتٍ وَابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيِّ بْنِ طَلْقٍ حَدِيثٌ حَسَنٌ ‏.‏ وَسَمِعْتُ مُحَمَّدًا يَقُولُ لاَ أَعْرِفُ لِعَلِيِّ بْنِ طَلْقٍ عَنِ النَّبِيِّ صلى الله عليه وسلم غَيْرَ هَذَا الْحَدِيثِ الْوَاحِدِ وَلاَ أَعْرِفُ هَذَا الْحَدِيثَ مِنْ حَدِيثِ طَلْقِ بْنِ عَلِيٍّ السُّحَيْمِيِّ ‏.‏ وَكَأَنَّهُ رَأَى أَنَّ هَذَا رَجُلٌ آخَرُ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1164}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ali bin Talq narrated that A Bedouin came to the Prophet and said:“O Messenger of Allah! A man among us would be in the desert and a small smell would come from him, (what should he do) while the water is scarce? So the Messenger of Allah said: “When one of you breaks wind then let him perform Wudu, and do not go into your women in their behinds for indeed Allah is not shy of the truth.”}}
\hadithdefcmd{tirmidhi}{1165}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَنْظُرُ اللَّهُ إِلَى رَجُلٍ أَتَى رَجُلاً أَوِ امْرَأَةً فِي الدُّبُرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَرَوَى وَكِيعٌ هَذَا الْحَدِيثَ ‏.‏\hadithno{1165}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Abbas narrated that The Messenger of Allah said:“Allah will not look at a man who enters a man or a woman in the behind.”}}
\hadithdefcmd{tirmidhi}{1166}{حَدَّثَنَا قُتَيْبَةُ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا وَكِيعٌ، عَنْ عَبْدِ الْمَلِكِ بْنِ مُسْلِمٍ، وَهُوَ ابْنُ سَلاَّمٍ عَنْ أَبِيهِ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا فَسَا أَحَدُكُمْ فَلْيَتَوَضَّأْ وَلاَ تَأْتُوا النِّسَاءَ فِي أَعْجَازِهِنَّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَعَلِيٌّ هَذَا هُوَ عَلِيُّ بْنُ طَلْقٍ ‏.‏\hadithno{1166}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ali narrated that The Messenger of Allah said:“When one of you breaks wind then let him perform Wudu, and do not go into your women through their behinds.”}}
\hadithdefcmd{tirmidhi}{1167}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنْ مُوسَى بْنِ عُبَيْدَةَ، عَنْ أَيُّوبَ بْنِ خَالِدٍ، عَنْ مَيْمُونَةَ بِنْتِ سَعْدٍ، وَكَانَتْ، خَادِمًا لِلنَّبِيِّ صلى الله عليه وسلم قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلُ الرَّافِلَةِ فِي الزِّينَةِ فِي غَيْرِ أَهْلِهَا كَمَثَلِ ظُلْمَةِ يَوْمِ الْقِيَامَةِ لاَ نُورَ لَهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُوسَى بْنِ عُبَيْدَةَ ‏.‏ وَمُوسَى بْنُ عُبَيْدَةَ يُضَعَّفُ فِي الْحَدِيثِ مِنْ قِبَلِ حِفْظِهِ وَهُوَ صَدُوقٌ ‏.‏ وَقَدْ رَوَاهُ بَعْضُهُمْ عَنْ مُوسَى بْنِ عُبَيْدَةَ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{1167}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Maimunah bin Sa’d who was a servant for the Prophet, narrated that The Messenger of Allah said:“The parable of the woman who walks to impress others in adornments for other than her family, is that of darkness on the Day of Judgment: There is no light for her.”}}
\hadithdefcmd{tirmidhi}{1168}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا سُفْيَانُ بْنُ حَبِيبٍ، عَنِ الْحَجَّاجِ الصَّوَّافِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يَغَارُ وَالْمُؤْمِنُ يَغَارُ وَغَيْرَةُ اللَّهِ أَنْ يَأْتِيَ الْمُؤْمِنُ مَا حَرَّمَ عَلَيْهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَعَبْدِ اللَّهِ بْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رُوِيَ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ عَنْ أَبِي سَلَمَةَ عَنْ عُرْوَةَ عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم هَذَا الْحَدِيثُ وَكِلاَ الْحَدِيثَيْنِ صَحِيحٌ ‏.‏ وَالْحَجَّاجُ الصَّوَّافُ هُوَ الْحَجَّاجُ بْنُ أَبِي عُثْمَانَ وَأَبُو عُثْمَانَ اسْمُهُ مَيْسَرَةُ وَالْحَجَّاجُ يُكْنَى أَبَا الصَّلْتِ وَثَّقَهُ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ ‏.‏ حَدَّثَنَا أَبُو بَكْرٍ الْعَطَّارُ عَنْ عَلِيِّ بْنِ الْمَدِينِيِّ قَالَ سَأَلْتُ يَحْيَى بْنَ سَعِيدٍ الْقَطَّانَ عَنْ حَجَّاجٍ الصَّوَّافِ فَقَالَ ثِقَةٌ فَطِنٌ كَيِّسٌ ‏.‏\hadithno{1168}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that The Messenger of Allah said:“Allah becomes jealous and the believer becomes jealous. Allah’s jealousy occurs when a believer does what He has made unlawful for him.”}}
\hadithdefcmd{tirmidhi}{1169}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُسَافِرَ سَفَرًا يَكُونُ ثَلاَثَةَ أَيَّامٍ فَصَاعِدًا إِلاَّ وَمَعَهَا أَبُوهَا أَوْ أَخُوهَا أَوْ زَوْجُهَا أَوِ ابْنُهَا أَوْ ذُو مَحْرَمٍ مِنْهَا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لاَ تُسَافِرُ الْمَرْأَةُ مَسِيرَةَ يَوْمٍ وَلَيْلَةٍ إِلاَّ مَعَ ذِي مَحْرَمٍ ‏"‏ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ يَكْرَهُونَ لِلْمَرْأَةِ أَنْ تُسَافِرَ إِلاَّ مَعَ ذِي مَحْرَمٍ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي الْمَرْأَةِ إِذَا كَانَتْ مُوسِرَةً وَلَمْ يَكُنْ لَهَا مَحْرَمٌ هَلْ تَحُجُّ ‏.‏ فَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لاَ يَجِبُ عَلَيْهَا الْحَجُّ لأَنَّ الْمَحْرَمَ مِنَ السَّبِيلِ لِقَوْلِ اللَّهِ عَزَّ وَجَلَِّ ‏:‏ ‏(‏ لِمَنِ اسْتَطَاعَ إِلَيْهِ سَبِيلاً ‏)‏ فَقَالُوا إِذَا لَمْ يَكُنْ لَهَا مَحْرَمٌ فَلاَ تَسْتَطِيعُ إِلَيْهِ سَبِيلاً ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا كَانَ الطَّرِيقُ آمِنًا فَإِنَّهَا تَخْرُجُ مَعَ النَّاسِ فِي الْحَجِّ ‏.‏ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ وَالشَّافِعِيِّ ‏.‏\hadithno{1169}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Sa’eed Al-Khudri narrated that The Messenger of Allah said:“It is not lawful for a woman who believers in Allah and the Last Day to travel on a trip that is three days or more, unless she is accompanied by her father, her brother, her husband, her son, or someone who is a Mahram to her.”}}
\hadithdefcmd{tirmidhi}{1170}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُسَافِرُ امْرَأَةٌ مَسِيرَةَ يَوْمٍ وَلَيْلَةٍ إِلاَّ وَمَعَهَا ذُو مَحْرَمٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1170}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that The Messenger of Allah said:“A woman is not to travel the distance of a day and a night unless she is accompanied by someone who is a Mahram.”}}
\hadithdefcmd{tirmidhi}{1171}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِيَّاكُمْ وَالدُّخُولَ عَلَى النِّسَاءِ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ الأَنْصَارِ يَا رَسُولَ اللَّهِ أَفَرَأَيْتَ الْحَمْوَ قَالَ ‏"‏ الْحَمْوُ الْمَوْتُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَجَابِرٍ وَعَمْرِو بْنِ الْعَاصِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُقْبَةَ بْنِ عَامِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَإِنَّمَا مَعْنَى كَرَاهِيَةِ الدُّخُولِ عَلَى النِّسَاءِ عَلَى نَحْوِ مَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَخْلُوَنَّ رَجُلٌ بِامْرَأَةٍ إِلاَّ كَانَ ثَالِثَهُمَا الشَّيْطَانُ ‏"‏ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ الْحَمْوُ ‏"‏ ‏.‏ يُقَالُ هُوَ أَخُو الزَّوْجِ كَأَنَّهُ كَرِهَ لَهُ أَنْ يَخْلُوَ بِهَا ‏.‏\hadithno{1171}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Uqbah bin Amir narrated that The Messenger of Allah said:“Beware of entering upon women.” So a man from the Ansar said: ‘”O Messenger of Allah! What do you think about Hamu? So he said: “The Hamu is death.”}}
\hadithdefcmd{tirmidhi}{1172}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ مُجَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَلِجُوا عَلَى الْمُغِيبَاتِ فَإِنَّ الشَّيْطَانَ يَجْرِي مِنْ أَحَدِكُمْ مَجْرَى الدَّمِ ‏"‏ ‏.‏ قُلْنَا وَمِنْكَ قَالَ ‏"‏ وَمِنِّي وَلَكِنَّ اللَّهَ أَعَانَنِي عَلَيْهِ فَأَسْلَمُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُهُمْ فِي مُجَالِدِ بْنِ سَعِيدٍ مِنْ قِبَلِ حِفْظِهِ ‏.‏ وَسَمِعْتُ عَلِيَّ بْنَ خَشْرَمٍ يَقُولُ قَالَ سُفْيَانُ بْنُ عُيَيْنَةَ فِي تَفْسِيرِ قَوْلِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ وَلَكِنَّ اللَّهَ أَعَانَنِي عَلَيْهِ فَأَسْلَمُ ‏"‏ ‏.‏ يَعْنِي أَسْلَمُ أَنَا مِنْهُ ‏.‏ قَالَ سُفْيَانُ وَالشَّيْطَانُ لاَ يُسْلِمُ ‏.‏ وَ ‏"‏ لاَ تَلِجُوا عَلَى الْمُغِيبَاتِ ‏"‏ وَالْمُغِيبَةُ الْمَرْأَةُ الَّتِي يَكُونُ زَوْجُهَا غَائِبًا وَالْمُغِيبَاتُ جَمَاعَةُ الْمُغِيبَةِ ‏.‏\hadithno{1172}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Jabir narrated that The Prophet said:“Do not enter upon Al-Mughibar (the women whose husband are absent), for indeed the Shaitan flows through one of you as the blood flows.” We said: “And you?” He said: “And me, but Allah helped me over him, so I am safe.”}}
\hadithdefcmd{tirmidhi}{1173}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ مُوَرِّقٍ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمَرْأَةُ عَوْرَةٌ فَإِذَا خَرَجَتِ اسْتَشْرَفَهَا الشَّيْطَانُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{1173}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abdullah narrated that The Prophet said:“The woman is Awrah, so when she goes out, the Shaitan seeks to tempt her.”}}
\hadithdefcmd{tirmidhi}{1174}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ كَثِيرِ بْنِ مُرَّةَ الْحَضْرَمِيِّ، عَنْ مُعَاذِ بْنِ جَبَلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُؤْذِي امْرَأَةٌ زَوْجَهَا فِي الدُّنْيَا إِلاَّ قَالَتْ زَوْجَتُهُ مِنَ الْحُورِ الْعِينِ لاَ تُؤْذِيهِ قَاتَلَكِ اللَّهُ فَإِنَّمَا هُوَ عِنْدَكِ دَخِيلٌ يُوشِكُ أَنْ يُفَارِقَكِ إِلَيْنَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَرِوَايَةُ إِسْمَاعِيلَ بْنِ عَيَّاشٍ عَنِ الشَّامِيِّينَ أَصْلَحُ وَلَهُ عَنْ أَهْلِ الْحِجَازِ وَأَهْلِ الْعِرَاقِ مَنَاكِيرُ ‏.‏\hadithno{1174}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Mu’adh bin Jabal narrated that The Prophet said:“No woman annoys her husband in the world except that his wife among the Al-Huril-Ain said: ‘Do not annoy him, may Allah destroy you, he is only like a guest with, soon he will part from you for us.’”}}
