% Auto-generated chapter 5 for bukhari
% Hadiths in this chapter: 46

\hadithdefcmd{bukhari}{248}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ بَدَأَ فَغَسَلَ يَدَيْهِ، ثُمَّ يَتَوَضَّأُ كَمَا يَتَوَضَّأُ لِلصَّلاَةِ، ثُمَّ يُدْخِلُ أَصَابِعَهُ فِي الْمَاءِ، فَيُخَلِّلُ بِهَا أُصُولَ شَعَرِهِ ثُمَّ يَصُبُّ عَلَى رَأْسِهِ ثَلاَثَ غُرَفٍ بِيَدَيْهِ، ثُمَّ يُفِيضُ الْمَاءَ عَلَى جِلْدِهِ كُلِّهِ‏.‏\hadithno{248}\hadithtrans{Narrated `Aisha:Whenever the Prophet (ﷺ) took a bath after Janaba he started by washing his hands and then performed ablution like that for the prayer. After that he would put his fingers in water and move the roots of his hair with them, and then pour three handfuls of water over his head and then pour water all over his body}}
\hadithdefcmd{bukhari}{249}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ تَوَضَّأَ رَسُولُ اللَّهِ صلى الله عليه وسلم وُضُوءَهُ لِلصَّلاَةِ غَيْرَ رِجْلَيْهِ، وَغَسَلَ فَرْجَهُ، وَمَا أَصَابَهُ مِنَ الأَذَى، ثُمَّ أَفَاضَ عَلَيْهِ الْمَاءَ، ثُمَّ نَحَّى رِجْلَيْهِ فَغَسَلَهُمَا، هَذِهِ غُسْلُهُ مِنَ الْجَنَابَةِ‏.‏\hadithno{249}\hadithtrans{Narrated Maimuna:(the wife of the Prophet) Allah's Messenger (ﷺ) performed ablution like that for the prayer but did not wash his feet. He washed off the discharge from his private parts and then poured water over his body. He withdrew his feet from that place (the place where he took the bath) and then washed them. And that was his way of taking the bath of Janaba}}
\hadithdefcmd{bukhari}{250}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَالنَّبِيُّ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ مِنْ قَدَحٍ يُقَالُ لَهُ الْفَرَقُ‏.‏\hadithno{250}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) and I used to take a bath from a single pot called 'Faraq}}
\hadithdefcmd{bukhari}{251}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنِي عَبْدُ الصَّمَدِ، قَالَ حَدَّثَنِي شُعْبَةُ، قَالَ حَدَّثَنِي أَبُو بَكْرِ بْنُ حَفْصٍ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ، يَقُولُ دَخَلْتُ أَنَا وَأَخُو، عَائِشَةَ عَلَى عَائِشَةَ فَسَأَلَهَا أَخُوهَا عَنْ غُسْلِ النَّبِيِّ، صلى الله عليه وسلم فَدَعَتْ بِإِنَاءٍ نَحْوًا مِنْ صَاعٍ، فَاغْتَسَلَتْ وَأَفَاضَتْ عَلَى رَأْسِهَا، وَبَيْنَنَا وَبَيْنَهَا حِجَابٌ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ قَالَ يَزِيدُ بْنُ هَارُونَ وَبَهْزٌ وَالْجُدِّيُّ عَنْ شُعْبَةَ قَدْرِ صَاعٍ‏.‏\hadithno{251}\hadithtrans{Narrated Abu Salama:`Aisha's brother and I went to `Aisha and he asked her about the bath of the Prophet. She brought a pot containing about a Sa` of water and took a bath and poured it over her head and at that time there was a screen between her and us}}
\hadithdefcmd{bukhari}{252}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، قَالَ حَدَّثَنَا أَبُو جَعْفَرٍ، أَنَّهُ كَانَ عِنْدَ جَابِرِ بْنِ عَبْدِ اللَّهِ هُوَ وَأَبُوهُ، وَعِنْدَهُ قَوْمٌ فَسَأَلُوهُ عَنِ الْغُسْلِ،‏.‏ فَقَالَ يَكْفِيكَ صَاعٌ‏.‏ فَقَالَ رَجُلٌ مَا يَكْفِينِي‏.‏ فَقَالَ جَابِرٌ كَانَ يَكْفِي مَنْ هُوَ أَوْفَى مِنْكَ شَعَرًا، وَخَيْرٌ مِنْكَ، ثُمَّ أَمَّنَا فِي ثَوْبٍ‏.‏\hadithno{252}\hadithtrans{Narrated Abu Ja`far:While I and my father were with Jabir bin `Abdullah, some people asked him about taking a bath. He replied, "A Sa` of water is sufficient for you." A man said, "A Sa` is not sufficient for me." Jabir said, "A Sa` was sufficient for one who had more hair than you and was better than you (meaning the Prophet)." And then Jabir (put on) his garment and led the prayer}}
\hadithdefcmd{bukhari}{253}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَمَيْمُونَةَ كَانَا يَغْتَسِلاَنِ مِنْ إِنَاءٍ وَاحِدٍ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ كَانَ ابْنُ عُيَيْنَةَ يَقُولُ أَخِيرًا عَنِ ابْنِ عَبَّاسٍ عَنْ مَيْمُونَةَ، وَالصَّحِيحُ مَا رَوَى أَبُو نُعَيْمٍ‏.‏\hadithno{253}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) and Maimuna used to take a bath from a single pot}}
\hadithdefcmd{bukhari}{254}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، قَالَ حَدَّثَنِي سُلَيْمَانُ بْنُ صُرَدٍ، قَالَ حَدَّثَنِي جُبَيْرُ بْنُ مُطْعِمٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَمَّا أَنَا فَأُفِيضُ عَلَى رَأْسِي ثَلاَثًا ‏"‏‏.‏ وَأَشَارَ بِيَدَيْهِ كِلْتَيْهِمَا‏.‏\hadithno{254}\hadithtrans{Narrated Jubair bin Mut`im:Allah's Messenger (ﷺ) said, "As for me, I pour water three times on my head." And he pointed with both his hands}}
\hadithdefcmd{bukhari}{255}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا غُنْدَرٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مِخْوَلِ بْنِ رَاشِدٍ، عَنْ مُحَمَّدِ بْنِ عَلِيٍّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُفْرِغُ عَلَى رَأْسِهِ ثَلاَثًا‏.‏\hadithno{255}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) used to pour water three times on his head}}
\hadithdefcmd{bukhari}{256}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا مَعْمَرُ بْنُ يَحْيَى بْنِ سَامٍ، حَدَّثَنِي أَبُو جَعْفَرٍ، قَالَ قَالَ لِي جَابِرٌ أَتَانِي ابْنُ عَمِّكَ يُعَرِّضُ بِالْحَسَنِ بْنِ مُحَمَّدٍ ابْنِ الْحَنَفِيَّةِ قَالَ كَيْفَ الْغُسْلُ مِنَ الْجَنَابَةِ فَقُلْتُ كَانَ النَّبِيُّ صلى الله عليه وسلم يَأْخُذُ ثَلاَثَةَ أَكُفٍّ وَيُفِيضُهَا عَلَى رَأْسِهِ، ثُمَّ يُفِيضُ عَلَى سَائِرِ جَسَدِهِ‏.‏ فَقَالَ لِي الْحَسَنُ إِنِّي رَجُلٌ كَثِيرُ الشَّعَرِ‏.‏ فَقُلْتُ كَانَ النَّبِيُّ صلى الله عليه وسلم أَكْثَرَ مِنْكَ شَعَرًا‏.‏\hadithno{256}\hadithtrans{Narrated Abu Ja`far:Jabir bin `Abdullah said to me, "Your cousin (Hasan bin Muhammad bin Al-Hanafiya) came to me and asked about the bath of Janaba. I replied, 'The Prophet (ﷺ) used to take three handfuls of water, pour them on his head and then pour more water over his body.' Al-Hasan said to me, 'I am a hairy man.' I replied, 'The Prophet (ﷺ) had more hair than you}}
\hadithdefcmd{bukhari}{257}{حَدَّثَنَا مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ، عَنِ الأَعْمَشِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَتْ مَيْمُونَةُ وَضَعْتُ لِلنَّبِيِّ صلى الله عليه وسلم مَاءً لِلْغُسْلِ، فَغَسَلَ يَدَيْهِ مَرَّتَيْنِ أَوْ ثَلاَثًا، ثُمَّ أَفْرَغَ عَلَى شِمَالِهِ فَغَسَلَ مَذَاكِيرَهُ، ثُمَّ مَسَحَ يَدَهُ بِالأَرْضِ، ثُمَّ مَضْمَضَ وَاسْتَنْشَقَ وَغَسَلَ وَجْهَهُ وَيَدَيْهِ، ثُمَّ أَفَاضَ عَلَى جَسَدِهِ، ثُمَّ تَحَوَّلَ مِنْ مَكَانِهِ فَغَسَلَ قَدَمَيْهِ‏.‏\hadithno{257}\hadithtrans{Narrated Maimuna:I placed water for the bath of the Prophet. He washed his hands twice or thrice and then poured water on his left hand and washed his private parts. He rubbed his hands over the earth (and cleaned them), rinsed his mouth, washed his nose by putting water in it and blowing it out, washed his face and both forearms and then poured water over his body. Then he withdrew from that place and washed his feet}}
\hadithdefcmd{bukhari}{258}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ حَنْظَلَةَ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ دَعَا بِشَىْءٍ نَحْوَ الْحِلاَبِ، فَأَخَذَ بِكَفِّهِ، فَبَدَأَ بِشِقِّ رَأْسِهِ الأَيْمَنِ ثُمَّ الأَيْسَرِ، فَقَالَ بِهِمَا عَلَى رَأْسِهِ‏.‏\hadithno{258}\hadithtrans{Narrated `Aisha:Whenever the Prophet (ﷺ) took the bath of Janaba (sexual relation or wet dream) he asked for the Hilab or some other scent. He used to take it in his hand, rub it first over the right side of his head and then over the left and then rub the middle of his head with both hands}}
\hadithdefcmd{bukhari}{259}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، قَالَ حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي سَالِمٌ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ حَدَّثَتْنَا مَيْمُونَةُ، قَالَتْ صَبَبْتُ لِلنَّبِيِّ صلى الله عليه وسلم غُسْلاً، فَأَفْرَغَ بِيَمِينِهِ عَلَى يَسَارِهِ فَغَسَلَهُمَا، ثُمَّ غَسَلَ فَرْجَهُ، ثُمَّ قَالَ بِيَدِهِ الأَرْضَ فَمَسَحَهَا بِالتُّرَابِ، ثُمَّ غَسَلَهَا، ثُمَّ تَمَضْمَضَ وَاسْتَنْشَقَ، ثُمَّ غَسَلَ وَجْهَهُ، وَأَفَاضَ عَلَى رَأْسِهِ، ثُمَّ تَنَحَّى فَغَسَلَ قَدَمَيْهِ، ثُمَّ أُتِيَ بِمِنْدِيلٍ، فَلَمْ يَنْفُضْ بِهَا‏.‏\hadithno{259}\hadithtrans{Narrated Maimuna:I placed water for the bath of the Prophet (ﷺ) and he poured water with his right hand on his left and washed them. Then he washed his private parts and rubbed his hands on the ground, washed them with water, rinsed his mouth and washed his nose by putting water in it and blowing it out, washed his face and poured water on his head. He withdrew from that place and washed his feet. A piece of cloth (towel) was given to him but he did not use it}}
\hadithdefcmd{bukhari}{260}{حَدَّثَنَا الْحُمَيْدِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اغْتَسَلَ مِنَ الْجَنَابَةِ، فَغَسَلَ فَرْجَهُ بِيَدِهِ، ثُمَّ دَلَكَ بِهَا الْحَائِطَ ثُمَّ غَسَلَهَا، ثُمَّ تَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ، فَلَمَّا فَرَغَ مِنْ غُسْلِهِ غَسَلَ رِجْلَيْهِ‏.‏\hadithno{260}\hadithtrans{Narrated Maimuna:The Prophet (ﷺ) took the bath of Janaba. (sexual relation or wet dream). He first cleaned his private parts with his hand, and then rubbed it (that hand) on the wall (earth) and washed it. Then he performed ablution like that for the prayer, and after the bath he washed his feet}}
\hadithdefcmd{bukhari}{261}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، أَخْبَرَنَا أَفْلَحُ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَالنَّبِيُّ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ تَخْتَلِفُ أَيْدِينَا فِيهِ‏.‏\hadithno{261}\hadithtrans{Narrated Aisha:The Prophet (ﷺ) and I used to take a bath from a single pot of water and our hands used to go in the pot after each other in turn}}
\hadithdefcmd{bukhari}{262}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ غَسَلَ يَدَهُ‏.‏\hadithno{262}\hadithtrans{Narrated `Aisha:Whenever Allah's Messenger (ﷺ) took a bath of Janaba, he washed his hands first}}
\hadithdefcmd{bukhari}{263}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بَكْرِ بْنِ حَفْصٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَالنَّبِيُّ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ مِنْ جَنَابَةٍ‏.‏ وَعَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ عَنْ أَبِيهِ عَنْ عَائِشَةَ مِثْلَهُ‏.‏\hadithno{263}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) and I used to take a bath from a single pot of water after Janaba}}
\hadithdefcmd{bukhari}{264}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ جَبْرٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم وَالْمَرْأَةُ مِنْ نِسَائِهِ يَغْتَسِلاَنِ مِنْ إِنَاءٍ وَاحِدٍ‏.‏ زَادَ مُسْلِمٌ وَوَهْبٌ عَنْ شُعْبَةَ مِنَ الْجَنَابَةِ‏.‏\hadithno{264}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) and one of his wives used to take a bath from a single pot of water. (Shu`ba added to Anas' Statement "After the Janaba)}}
\hadithdefcmd{bukhari}{265}{حَدَّثَنَا مُحَمَّدُ بْنُ مَحْبُوبٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَتْ مَيْمُونَةُ وَضَعْتُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم مَاءً يَغْتَسِلُ بِهِ، فَأَفْرَغَ عَلَى يَدَيْهِ، فَغَسَلَهُمَا مَرَّتَيْنِ مَرَّتَيْنِ أَوْ ثَلاَثًا، ثُمَّ أَفْرَغَ بِيَمِينِهِ عَلَى شِمَالِهِ، فَغَسَلَ مَذَاكِيرَهُ، ثُمَّ دَلَكَ يَدَهُ بِالأَرْضِ، ثُمَّ مَضْمَضَ وَاسْتَنْشَقَ، ثُمَّ غَسَلَ وَجْهَهُ وَيَدَيْهِ ثُمَّ غَسَلَ رَأْسَهُ ثَلاَثًا، ثُمَّ أَفْرَغَ عَلَى جَسَدِهِ، ثُمَّ تَنَحَّى مِنْ مَقَامِهِ فَغَسَلَ قَدَمَيْهِ‏.‏\hadithno{265}\hadithtrans{Narrated Maimuna:I placed water for the bath of Allah's Messenger (ﷺ) and he poured water over his hands and washed them twice or thrice; then he poured water with his right hand over his left and washed his private parts (with his left hand). He rubbed his hand over the earth and rinsed his mouth and washed his nose by putting water in it and blowing it out. After that he washed his face, both fore arms and head thrice and then poured water over his body. He withdrew from that place and washed his feet}}
\hadithdefcmd{bukhari}{266}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ بِنْتِ الْحَارِثِ، قَالَتْ وَضَعْتُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم غُسْلاً وَسَتَرْتُهُ، فَصَبَّ عَلَى يَدِهِ، فَغَسَلَهَا مَرَّةً أَوْ مَرَّتَيْنِ ـ قَالَ سُلَيْمَانُ لاَ أَدْرِي أَذَكَرَ الثَّالِثَةَ أَمْ لاَ ـ ثُمَّ أَفْرَغَ بِيَمِينِهِ عَلَى شِمَالِهِ، فَغَسَلَ فَرْجَهُ، ثُمَّ دَلَكَ يَدَهُ بِالأَرْضِ أَوْ بِالْحَائِطِ، ثُمَّ تَمَضْمَضَ وَاسْتَنْشَقَ، وَغَسَلَ وَجْهَهُ وَيَدَيْهِ، وَغَسَلَ رَأْسَهُ، ثُمَّ صَبَّ عَلَى جَسَدِهِ، ثُمَّ تَنَحَّى فَغَسَلَ قَدَمَيْهِ، فَنَاوَلْتُهُ خِرْقَةً، فَقَالَ بِيَدِهِ هَكَذَا، وَلَمْ يُرِدْهَا‏.‏\hadithno{266}\hadithtrans{Narrated Maimuna bint Al-Harith:I placed water for the bath of Allah's Messenger (ﷺ) and put a screen. He poured water over his hands, and washed them once or twice. (The sub-narrator added that he did not remember if she had said thrice or not). Then he poured water with his right hand over his left one and washed his private parts. He rubbed his hand over the earth or the wall and washed it. He rinsed his mouth and washed his nose by putting water in it and blowing it out. He washed his face, forearms and head. He poured water over his body and then withdrew from that place and washed his feet. I presented him a piece of cloth (towel) and he pointed with his hand (that he does not want it) and did not take it}}
\hadithdefcmd{bukhari}{267}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، وَيَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، عَنْ أَبِيهِ، قَالَ ذَكَرْتُهُ لِعَائِشَةَ فَقَالَتْ يَرْحَمُ اللَّهُ أَبَا عَبْدِ الرَّحْمَنِ، كُنْتُ أُطَيِّبُ رَسُولَ اللَّهِ صلى الله عليه وسلم، فَيَطُوفُ عَلَى نِسَائِهِ، ثُمَّ يُصْبِحُ مُحْرِمًا يَنْضَخُ طِيبًا‏.‏\hadithno{267}\hadithtrans{Narrated Muhammad bin Al-Muntathir:on the authority of his father that he had asked `Aisha (about the Hadith of Ibn `Umar). She said, "May Allah be Merciful to Abu `Abdur-Rahman. I used to put scent on Allah's Messenger (ﷺ) and he used to go round his wives, and in the morning he assumed the Ihram, and the fragrance of scent was still coming out from his body}}
\hadithdefcmd{bukhari}{268}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، قَالَ حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَدُورُ عَلَى نِسَائِهِ فِي السَّاعَةِ الْوَاحِدَةِ مِنَ اللَّيْلِ وَالنَّهَارِ، وَهُنَّ إِحْدَى عَشْرَةَ‏.‏ قَالَ قُلْتُ لأَنَسٍ أَوَكَانَ يُطِيقُهُ قَالَ كُنَّا نَتَحَدَّثُ أَنَّهُ أُعْطِيَ قُوَّةَ ثَلاَثِينَ‏.‏ وَقَالَ سَعِيدٌ عَنْ قَتَادَةَ إِنَّ أَنَسًا حَدَّثَهُمْ تِسْعُ نِسْوَةٍ‏.‏\hadithno{268}\hadithtrans{Narrated Qatada:Anas bin Malik said, "The Prophet (ﷺ) used to visit all his wives in a round, during the day and night and they were eleven in number." I asked Anas, "Had the Prophet (ﷺ) the strength for it?" Anas replied, "We used to say that the Prophet (ﷺ) was given the strength of thirty (men)." And Sa`id said on the authority of Qatada that Anas had told him about nine wives only (not eleven)}}
\hadithdefcmd{bukhari}{269}{حَدَّثَنَا أَبُو الْوَلِيدِ، قَالَ حَدَّثَنَا زَائِدَةُ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَلِيٍّ، قَالَ كُنْتُ رَجُلاً مَذَّاءً فَأَمَرْتُ رَجُلاً أَنْ يَسْأَلَ النَّبِيَّ صلى الله عليه وسلم لِمَكَانِ ابْنَتِهِ فَسَأَلَ فَقَالَ ‏ "‏ تَوَضَّأْ وَاغْسِلْ ذَكَرَكَ ‏"‏‏.‏\hadithno{269}\hadithtrans{Narrated `Ali:I used to get emotional urethral discharge frequently. Being the son-in-law of the Prophet (ﷺ) I requested a man to ask him about it. So the man asked the Prophet (ﷺ) about it. The Prophet (ﷺ) replied, "Perform ablution after washing your organ (penis)}}
\hadithdefcmd{bukhari}{270}{حَدَّثَنَا أَبُو النُّعْمَانِ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ الْمُنْتَشِرِ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ عَائِشَةَ فَذَكَرْتُ لَهَا قَوْلَ ابْنِ عُمَرَ مَا أُحِبُّ أَنْ أُصْبِحَ، مُحْرِمًا أَنْضَخُ طِيبًا‏.‏ فَقَالَتْ عَائِشَةُ أَنَا طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ثُمَّ طَافَ فِي نِسَائِهِ ثُمَّ أَصْبَحَ مُحْرِمًا‏.‏\hadithno{270}\hadithtrans{Narrated Muhammad bin Al-Muntathir:on the authority of his father that he had asked `Aisha about the saying of Ibn `Umar (i.e. he did not like to be a Muhrim while the smell of scent was still coming from his body). `Aisha said, "I scented Allah's Messenger (ﷺ) and he went round (had sexual intercourse with) all his wives, and in the morning he was Muhrim (after taking a bath)}}
\hadithdefcmd{bukhari}{271}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا الْحَكَمُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ الطِّيبِ فِي مَفْرِقِ النَّبِيِّ صلى الله عليه وسلم وَهْوَ مُحْرِمٌ‏.‏\hadithno{271}\hadithtrans{Narrated `Aisha:It is as if I am just looking at the glitter of scent in the parting of the Prophet's head hair while he was a Muhrim}}
\hadithdefcmd{bukhari}{272}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ غَسَلَ يَدَيْهِ، وَتَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ اغْتَسَلَ، ثُمَّ يُخَلِّلُ بِيَدِهِ شَعَرَهُ، حَتَّى إِذَا ظَنَّ أَنْ قَدْ أَرْوَى بَشَرَتَهُ، أَفَاضَ عَلَيْهِ الْمَاءَ ثَلاَثَ مَرَّاتٍ، ثُمَّ غَسَلَ سَائِرَ جَسَدِهِ‏.‏ وَقَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ نَغْرِفُ مِنْهُ جَمِيعًا‏.‏\hadithno{272}\hadithtrans{Narrated Hisham bin `Urwa:(on the authority of his father) `Aisha said, "Whenever Allah's Messenger (ﷺ) took the bath of Janaba, he cleaned his hands and performed ablution like that for prayer and then took a bath and rubbed his hair, till he felt that the whole skin of the head had become wet, then he would pour water thrice and wash the rest of the body." `Aisha further said, "I and Allah's Messenger (ﷺ) used to take a bath from a single water container, from which we took water simultaneously}}
\hadithdefcmd{bukhari}{273}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اغْتَسَلَ مِنَ الْجَنَابَةِ غَسَلَ يَدَيْهِ، وَتَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ ثُمَّ اغْتَسَلَ، ثُمَّ يُخَلِّلُ بِيَدِهِ شَعَرَهُ، حَتَّى إِذَا ظَنَّ أَنْ قَدْ أَرْوَى بَشَرَتَهُ، أَفَاضَ عَلَيْهِ الْمَاءَ ثَلاَثَ مَرَّاتٍ، ثُمَّ غَسَلَ سَائِرَ جَسَدِهِ‏.‏ وَقَالَتْ كُنْتُ أَغْتَسِلُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم مِنْ إِنَاءٍ وَاحِدٍ نَغْرِفُ مِنْهُ جَمِيعًا‏.‏\hadithno{273}\hadithtrans{Narrated Hisham bin `Urwa:(on the authority of his father) `Aisha said, "Whenever Allah's Messenger (ﷺ) took the bath of Janaba, he cleaned his hands and performed ablution like that for prayer and then took a bath and rubbed his hair, till he felt that the whole skin of the head had become wet, then he would pour water thrice and wash the rest of the body." `Aisha further said, "I and Allah's Messenger (ﷺ) used to take a bath from a single water container, from which we took water simultaneously}}
\hadithdefcmd{bukhari}{274}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، قَالَ أَخْبَرَنَا الْفَضْلُ بْنُ مُوسَى، قَالَ أَخْبَرَنَا الأَعْمَشُ، عَنْ سَالِمٍ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، قَالَتْ وَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَضُوءًا لِجَنَابَةٍ فَأَكْفَأَ بِيَمِينِهِ عَلَى شِمَالِهِ مَرَّتَيْنِ، أَوْ ثَلاَثًا، ثُمَّ غَسَلَ فَرْجَهُ، ثُمَّ ضَرَبَ يَدَهُ بِالأَرْضِ ـ أَوِ الْحَائِطِ ـ مَرَّتَيْنِ أَوْ ثَلاَثًا، ثُمَّ مَضْمَضَ وَاسْتَنْشَقَ، وَغَسَلَ وَجْهَهُ وَذِرَاعَيْهِ، ثُمَّ أَفَاضَ عَلَى رَأْسِهِ الْمَاءَ، ثُمَّ غَسَلَ جَسَدَهُ، ثُمَّ تَنَحَّى فَغَسَلَ رِجْلَيْهِ‏.‏ قَالَتْ فَأَتَيْتُهُ بِخِرْقَةٍ، فَلَمْ يُرِدْهَا، فَجَعَلَ يَنْفُضُ بِيَدِهِ‏.‏\hadithno{274}\hadithtrans{Narrated Maimuna:Water was placed for the ablution of Allah's Messenger (ﷺ) after Janaba. He poured water with his right hand over his left twice or thrice and then washed his private parts and rubbed his hand on the earth or on a wall twice or thrice and then rinsed his mouth, washed his nose by putting water in it and then blowing it out and then washed his face and forearms and poured water over his head and washed his body. Then he shifted from that place and washed his feet. I brought a piece of cloth, but he did not take it and removed the traces of water from his body with his hand}}
\hadithdefcmd{bukhari}{275}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، قَالَ أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُقِيمَتِ الصَّلاَةُ، وَعُدِّلَتِ الصُّفُوفُ قِيَامًا، فَخَرَجَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا قَامَ فِي مُصَلاَّهُ ذَكَرَ أَنَّهُ جُنُبٌ فَقَالَ لَنَا ‏:‏ ‏ "‏ مَكَانَكُمْ ‏"‏‏.‏ ثُمَّ رَجَعَ فَاغْتَسَلَ، ثُمَّ خَرَجَ إِلَيْنَا وَرَأْسُهُ يَقْطُرُ، فَكَبَّرَ فَصَلَّيْنَا مَعَهُ‏.‏ تَابَعَهُ عَبْدُ الأَعْلَى عَنْ مَعْمَرٍ عَنِ الزُّهْرِيِّ‏.‏ وَرَوَاهُ الأَوْزَاعِيُّ عَنِ الزُّهْرِيِّ‏.‏\hadithno{275}\hadithtrans{Narrated Abu Huraira:Once the call (Iqama) for the prayer was announced and the rows were straightened. Allah's Messenger (ﷺ) came out; and when he stood up at his Musalla, he remembered that he was Junub. Then he ordered us to stay at our places and went to take a bath and then returned with water dropping from his head. He said, "Allahu-Akbar", and we all offered the prayer with him}}
\hadithdefcmd{bukhari}{276}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنَا أَبُو حَمْزَةَ، قَالَ سَمِعْتُ الأَعْمَشَ، عَنْ سَالِمٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَتْ مَيْمُونَةُ وَضَعْتُ لِلنَّبِيِّ صلى الله عليه وسلم غُسْلاً، فَسَتَرْتُهُ بِثَوْبٍ، وَصَبَّ عَلَى يَدَيْهِ فَغَسَلَهُمَا، ثُمَّ صَبَّ بِيَمِينِهِ عَلَى شِمَالِهِ، فَغَسَلَ فَرْجَهُ، فَضَرَبَ بِيَدِهِ الأَرْضَ فَمَسَحَهَا، ثُمَّ غَسَلَهَا فَمَضْمَضَ، وَاسْتَنْشَقَ، وَغَسَلَ وَجْهَهُ وَذِرَاعَيْهِ، ثُمَّ صَبَّ عَلَى رَأْسِهِ، وَأَفَاضَ عَلَى جَسَدِهِ، ثُمَّ تَنَحَّى فَغَسَلَ قَدَمَيْهِ، فَنَاوَلْتُهُ ثَوْبًا فَلَمْ يَأْخُذْهُ، فَانْطَلَقَ وَهْوَ يَنْفُضُ يَدَيْهِ‏.‏\hadithno{276}\hadithtrans{Narrated Maimuna:I placed water for the bath of the Prophet (ﷺ) and screened him with a garment. He poured water over his hands and washed them. After that he poured water with his right hand over his left and washed his private parts, rubbed his hands with earth and washed them, rinsed his mouth, washed his nose by putting water in it and then blowing it out and then washed his face and forearms. He poured water over his head and body. He then shifted from that place and washed his feet. I gave him a piece of cloth but he did not take it and came out removing the water (from his body) with both his hands}}
\hadithdefcmd{bukhari}{277}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَافِعٍ، عَنِ الْحَسَنِ بْنِ مُسْلِمٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنَّا إِذَا أَصَابَتْ إِحْدَانَا جَنَابَةٌ، أَخَذَتْ بِيَدَيْهَا ثَلاَثًا فَوْقَ رَأْسِهَا، ثُمَّ تَأْخُذُ بِيَدِهَا عَلَى شِقِّهَا الأَيْمَنِ، وَبِيَدِهَا الأُخْرَى عَلَى شِقِّهَا الأَيْسَرِ‏.‏\hadithno{277}\hadithtrans{Narrated Aisha:Whenever any one of us was Junub, she poured water over her head thrice with both her hands and then rubbed the right side of her head with one hand and rubbed the left side of the head with the other hand}}
\hadithdefcmd{bukhari}{278}{حَدَّثَنَا إِسْحَاقُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كَانَتْ بَنُو إِسْرَائِيلَ يَغْتَسِلُونَ عُرَاةً، يَنْظُرُ بَعْضُهُمْ إِلَى بَعْضٍ، وَكَانَ مُوسَى يَغْتَسِلُ وَحْدَهُ، فَقَالُوا وَاللَّهِ مَا يَمْنَعُ مُوسَى أَنْ يَغْتَسِلَ مَعَنَا إِلاَّ أَنَّهُ آدَرُ، فَذَهَبَ مَرَّةً يَغْتَسِلُ، فَوَضَعَ ثَوْبَهُ عَلَى حَجَرٍ، فَفَرَّ الْحَجَرُ بِثَوْبِهِ، فَخَرَجَ مُوسَى فِي إِثْرِهِ يَقُولُ ثَوْبِي يَا حَجَرُ‏.‏ حَتَّى نَظَرَتْ بَنُو إِسْرَائِيلَ إِلَى مُوسَى، فَقَالُوا وَاللَّهِ مَا بِمُوسَى مِنْ بَأْسٍ‏.‏ وَأَخَذَ ثَوْبَهُ، فَطَفِقَ بِالْحَجَرِ ضَرْبًا ‏"‏‏.‏ فَقَالَ أَبُو هُرَيْرَةَ وَاللَّهِ إِنَّهُ لَنَدَبٌ بِالْحَجَرِ سِتَّةٌ أَوْ سَبْعَةٌ ضَرْبًا بِالْحَجَرِ‏.‏\hadithno{278}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, 'The (people of) Bani Israel used to take bath naked (all together) looking at each other. The Prophet Moses (ﷺ) used to take a bath alone. They said, 'By Allah! Nothing prevents Moses from taking a bath with us except that he has a scrotal hernia.' So once Moses went out to take a bath and put his clothes over a stone and then that stone ran away with his clothes. Moses followed that stone saying, "My clothes, O stone! My clothes, O stone! till the people of Bani Israel saw him and said, 'By Allah, Moses has got no defect in his body. Moses took his clothes and began to beat the stone." Abu Huraira added, "By Allah! There are still six or seven marks present on the stone from that excessive beating}}
\hadithdefcmd{bukhari}{279}{وَعَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَا أَيُّوبُ يَغْتَسِلُ عُرْيَانًا فَخَرَّ عَلَيْهِ جَرَادٌ مِنْ ذَهَبٍ، فَجَعَلَ أَيُّوبُ يَحْتَثِي فِي ثَوْبِهِ، فَنَادَاهُ رَبُّهُ يَا أَيُّوبُ، أَلَمْ أَكُنْ أَغْنَيْتُكَ عَمَّا تَرَى قَالَ بَلَى وَعِزَّتِكَ وَلَكِنْ لاَ غِنَى بِي عَنْ بَرَكَتِكَ ‏"‏‏.‏ وَرَوَاهُ إِبْرَاهِيمُ عَنْ مُوسَى بْنِ عُقْبَةَ عَنْ صَفْوَانَ عَنْ عَطَاءِ بْنِ يَسَارٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَا أَيُّوبُ يَغْتَسِلُ عُرْيَانًا ‏"‏‏.‏\hadithno{279}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "When the Prophet Job (Aiyub) (ﷺ) was taking a bath naked, golden locusts began to fall on him. Job started collecting them in his clothes. His Lord addressed him, 'O Job! Haven't I given you enough so that you are not in need of them.' Job replied, 'Yes! By Your Honor (power)! But I cannot dispense with Your Blessings}}
\hadithdefcmd{bukhari}{280}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ أَنَّ أَبَا مُرَّةَ، مَوْلَى أُمِّ هَانِئٍ بِنْتِ أَبِي طَالِبٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ أُمَّ هَانِئٍ بِنْتَ أَبِي طَالِبٍ، تَقُولُ ذَهَبْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ، فَوَجَدْتُهُ يَغْتَسِلُ وَفَاطِمَةُ تَسْتُرُهُ فَقَالَ ‏ "‏ مَنْ هَذِهِ ‏"‏‏.‏ فَقُلْتُ أَنَا أُمُّ هَانِئٍ‏.‏\hadithno{280}\hadithtrans{Narrated Um Hani bint Abi Talib:I went to Allah's Messenger (ﷺ) in the year of the conquest of Mecca and found him taking a bath while Fatima was screening him. The Prophet (ﷺ) asked, "Who is it?" I replied, "I am Um-Hani}}
\hadithdefcmd{bukhari}{281}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ مَيْمُونَةَ، قَالَتْ سَتَرْتُ النَّبِيَّ صلى الله عليه وسلم وَهُوَ يَغْتَسِلُ مِنَ الْجَنَابَةِ، فَغَسَلَ يَدَيْهِ ثُمَّ صَبَّ بِيَمِينِهِ عَلَى شِمَالِهِ، فَغَسَلَ فَرْجَهُ، وَمَا أَصَابَهُ، ثُمَّ مَسَحَ بِيَدِهِ عَلَى الْحَائِطِ أَوِ الأَرْضِ، ثُمَّ تَوَضَّأَ وُضُوءَهُ لِلصَّلاَةِ، غَيْرَ رِجْلَيْهِ، ثُمَّ أَفَاضَ عَلَى جَسَدِهِ الْمَاءَ، ثُمَّ تَنَحَّى فَغَسَلَ قَدَمَيْهِ‏.‏ تَابَعَهُ أَبُو عَوَانَةَ وَابْنُ فُضَيْلٍ فِي السَّتْرِ‏.‏\hadithno{281}\hadithtrans{Narrated Maimuna:I screened the Prophet (ﷺ) while he was taking a bath of Janaba. He washed his hands, poured water from his right hand over his left and washed his private parts. Then he rubbed his hand over a wall or the earth, and performed ablution similar to that for the prayer but did not wash his feet. Then he poured water over his body, shifted from that place, and washed his feet}}
\hadithdefcmd{bukhari}{282}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ أُمِّ الْمُؤْمِنِينَ، أَنَّهَا قَالَتْ جَاءَتْ أُمُّ سُلَيْمٍ امْرَأَةُ أَبِي طَلْحَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ، إِنَّ اللَّهَ لاَ يَسْتَحْيِي مِنَ الْحَقِّ، هَلْ عَلَى الْمَرْأَةِ مِنْ غُسْلٍ إِذَا هِيَ احْتَلَمَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَعَمْ إِذَا رَأَتِ الْمَاءَ ‏"‏‏.‏\hadithno{282}\hadithtrans{Narrated Um-Salama:(the mother of the believers) Um Sulaim, the wife of Abu Talha, came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! Verily Allah is not shy of (telling you) the truth. Is it necessary for a woman to take a bath after she has a wet dream (nocturnal sexual discharge)?" Allah's Messenger (ﷺ) replied, "Yes, if she notices a discharge}}
\hadithdefcmd{bukhari}{283}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا حُمَيْدٌ، قَالَ حَدَّثَنَا بَكْرٌ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَقِيَهُ فِي بَعْضِ طَرِيقِ الْمَدِينَةِ وَهْوَ جُنُبٌ، فَانْخَنَسْتُ مِنْهُ، فَذَهَبَ فَاغْتَسَلَ، ثُمَّ جَاءَ فَقَالَ ‏"‏ أَيْنَ كُنْتَ يَا أَبَا هُرَيْرَةَ ‏"‏‏.‏ قَالَ كُنْتُ جُنُبًا، فَكَرِهْتُ أَنْ أُجَالِسَكَ وَأَنَا عَلَى غَيْرِ طَهَارَةٍ‏.‏ فَقَالَ ‏"‏ سُبْحَانَ اللَّهِ، إِنَّ الْمُؤْمِنَ لاَ يَنْجُسُ ‏"‏‏.‏\hadithno{283}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) came across me in one of the streets of Medina and at that time I was Junub. So I slipped away from him and went to take a bath. On my return the Prophet (ﷺ) said, "O Abu Huraira! Where have you been?" I replied, "I was Junub, so I disliked to sit in your company." The Prophet (ﷺ) said, "Subhan Allah! A believer never becomes impure}}
\hadithdefcmd{bukhari}{284}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، أَنَّ أَنَسَ بْنَ مَالِكٍ، حَدَّثَهُمْ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَطُوفُ عَلَى نِسَائِهِ فِي اللَّيْلَةِ الْوَاحِدَةِ، وَلَهُ يَوْمَئِذٍ تِسْعُ نِسْوَةٍ‏.‏\hadithno{284}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) used to visit all his wives in one night and he had nine wives at that time}}
\hadithdefcmd{bukhari}{285}{حَدَّثَنَا عَيَّاشٌ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا حُمَيْدٌ، عَنْ بَكْرٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَقِيَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا جُنُبٌ، فَأَخَذَ بِيَدِي، فَمَشَيْتُ مَعَهُ حَتَّى قَعَدَ فَانْسَلَلْتُ، فَأَتَيْتُ الرَّحْلَ، فَاغْتَسَلْتُ ثُمَّ جِئْتُ وَهْوَ قَاعِدٌ فَقَالَ ‏"‏ أَيْنَ كُنْتَ يَا أَبَا هِرٍّ ‏"‏ فَقُلْتُ لَهُ‏.‏ فَقَالَ ‏"‏ سُبْحَانَ اللَّهِ يَا أَبَا هِرٍّ إِنَّ الْمُؤْمِنَ لاَ يَنْجُسُ ‏"‏‏.‏\hadithno{285}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) came across me and I was Junub. He took my hand and I went along with him till he sat down I slipped away, went home and took a bath. When I came back, he was still sitting there. He then said to me, "O Abu Huraira! Where have you been?' I told him about it. The Prophet (ﷺ) said, "Subhan Allah! O Abu Huraira! A believer never becomes impure}}
\hadithdefcmd{bukhari}{286}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا هِشَامٌ، وَشَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، قَالَ سَأَلْتُ عَائِشَةَ أَكَانَ النَّبِيُّ صلى الله عليه وسلم يَرْقُدُ وَهْوَ جُنُبٌ قَالَتْ نَعَمْ وَيَتَوَضَّأُ‏.‏\hadithno{286}\hadithtrans{Narrated Abu Salama:I asked `Aisha "Did the Prophet (ﷺ) use to sleep while he was Junub?" She replied, "Yes, but he used to perform ablution (before going to bed)}}
\hadithdefcmd{bukhari}{287}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَيَرْقُدُ أَحَدُنَا وَهْوَ جُنُبٌ قَالَ ‏ "‏ نَعَمْ إِذَا تَوَضَّأَ أَحَدُكُمْ فَلْيَرْقُدْ وَهُوَ جُنُبٌ ‏"‏‏.‏\hadithno{287}\hadithtrans{Narrated `Umar bin Al-Khattab:I asked Allah's Messenger (ﷺ) "Can any one of us sleep while he is Junub?" He replied, "Yes, if he performs ablution, he can sleep while he is Junub}}
\hadithdefcmd{bukhari}{288}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَنَامَ وَهْوَ جُنُبٌ، غَسَلَ فَرْجَهُ، وَتَوَضَّأَ لِلصَّلاَةِ‏.‏\hadithno{288}\hadithtrans{Narrated `Aisha:Whenever the Prophet (ﷺ) intended to sleep while he was Junub, he used to wash his private parts and perform ablution like that for the prayer}}
\hadithdefcmd{bukhari}{289}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، قَالَ اسْتَفْتَى عُمَرُ النَّبِيَّ صلى الله عليه وسلم أَيَنَامُ أَحَدُنَا وَهْوَ جُنُبٌ قَالَ ‏ "‏ نَعَمْ، إِذَا تَوَضَّأَ ‏"‏‏.‏\hadithno{289}\hadithtrans{Narrated `Abdullah:`Umar asked the Prophet (ﷺ) "Can anyone of us sleep while he is Junub?" He replied, "Yes, if he performs ablution}}
\hadithdefcmd{bukhari}{290}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ ذَكَرَ عُمَرُ بْنُ الْخَطَّابِ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ تُصِيبُهُ الْجَنَابَةُ مِنَ اللَّيْلِ، فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَوَضَّأْ وَاغْسِلْ ذَكَرَكَ ثُمَّ نَمْ ‏"‏‏.‏\hadithno{290}\hadithtrans{Narrated `Abdullah bin `Umar:`Umar bin Al-Khattab told Allah's Messenger (ﷺ), "I became Junub at night." Allah's Messenger (ﷺ) replied, "Perform ablution after washing your private parts and then sleep}}
\hadithdefcmd{bukhari}{291}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، قَالَ حَدَّثَنَا هِشَامٌ، ح وَحَدَّثَنَا أَبُو نُعَيْمٍ، عَنْ هِشَامٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا جَلَسَ بَيْنَ شُعَبِهَا الأَرْبَعِ ثُمَّ جَهَدَهَا، فَقَدْ وَجَبَ الْغَسْلُ ‏"‏‏.‏ تَابَعَهُ عَمْرُو بْنُ مَرْزُوقٍ عَنْ شُعْبَةَ مِثْلَهُ‏.‏ وَقَالَ مُوسَى حَدَّثَنَا أَبَانُ قَالَ حَدَّثَنَا قَتَادَةُ أَخْبَرَنَا الْحَسَنُ مِثْلَهُ‏.‏\hadithno{291}\hadithtrans{Narrated Hisham:as the following Hadith 290. Narrated Abu Huraira: The Prophet (ﷺ) said, "When a man sits in between the four parts of a woman and did the sexual intercourse with her, bath becomes compulsory}}
\hadithdefcmd{bukhari}{292}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنِ الْحُسَيْنِ، قَالَ يَحْيَى وَأَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّ عَطَاءَ بْنَ يَسَارٍ، أَخْبَرَهُ أَنَّ زَيْدَ بْنَ خَالِدٍ الْجُهَنِيَّ أَخْبَرَهُ أَنَّهُ، سَأَلَ عُثْمَانَ بْنَ عَفَّانَ فَقَالَ أَرَأَيْتَ إِذَا جَامَعَ الرَّجُلُ امْرَأَتَهُ فَلَمْ يُمْنِ‏.‏ قَالَ عُثْمَانُ يَتَوَضَّأُ كَمَا يَتَوَضَّأُ لِلصَّلاَةِ، وَيَغْسِلُ ذَكَرَهُ‏.‏ قَالَ عُثْمَانُ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ فَسَأَلْتُ عَنْ ذَلِكَ عَلِيَّ بْنَ أَبِي طَالِبٍ وَالزُّبَيْرَ بْنَ الْعَوَّامِ وَطَلْحَةَ بْنَ عُبَيْدِ اللَّهِ وَأُبَىَّ بْنَ كَعْبٍ ـ رضى الله عنهم ـ فَأَمَرُوهُ بِذَلِكَ‏.‏ قَالَ يَحْيَى وَأَخْبَرَنِي أَبُو سَلَمَةَ أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ أَخْبَرَهُ أَنَّ أَبَا أَيُّوبَ أَخْبَرَهُ أَنَّهُ سَمِعَ ذَلِكَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{292}\hadithtrans{Narrated Zaid bin Khalid Al-Juhani:I asked `Uthman bin `Affan about a man who engaged in the sexual intercourse with his wife but did not discharge. `Uthman replied, "He should perform ablution like that for the prayer after washing his private parts." `Uthman added, "I heard that from Allah's Messenger (ﷺ)." I asked `Ali bin Abi Talib, Az-Zubair bin Al-`Awwam, Talha bin 'Ubaidullah and Ubai bin Ka`b and they gave the same reply. (Abu Aiyub said that he had heard that from Allah's Messenger (ﷺ) ) (This order was canceled later on so one has to take a bath. See, Hadith No)}}
\hadithdefcmd{bukhari}{293}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ هِشَامِ بْنِ عُرْوَةَ، قَالَ أَخْبَرَنِي أَبِي قَالَ، أَخْبَرَنِي أَبُو أَيُّوبَ، قَالَ أَخْبَرَنِي أُبَىُّ بْنُ كَعْبٍ، أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ إِذَا جَامَعَ الرَّجُلُ الْمَرْأَةَ فَلَمْ يُنْزِلْ قَالَ ‏ "‏ يَغْسِلُ مَا مَسَّ الْمَرْأَةَ مِنْهُ، ثُمَّ يَتَوَضَّأُ وَيُصَلِّي ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ الْغَسْلُ أَحْوَطُ، وَذَاكَ الآخِرُ، وَإِنَّمَا بَيَّنَّا لاِخْتِلاَفِهِمْ‏.‏\hadithno{293}\hadithtrans{Narrated Ubai bin Ka`b:I asked Allah's Messenger (ﷺ) about a man who engages in sexual intercourse with his wife but does not discharge. He replied, "He should wash the parts which comes in contact with the private parts of the woman, perform ablution and then pray." (Abu `Abdullah said, "Taking a bath is safer and is the last order)}}
