% Auto-generated chapter 58 for malik
% Hadiths in this chapter: 15

\hadithdefcmd{malik}{1841}{حَدَّثَنِي مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي الْحُبَابِ، سَعِيدِ بْنِ يَسَارٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَصَدَّقَ بِصَدَقَةٍ مِنْ كَسْبٍ طَيِّبٍ - وَلاَ يَقْبَلُ اللَّهُ إِلاَّ طَيِّبًا - كَانَ إِنَّمَا يَضَعُهَا فِي كَفِّ الرَّحْمَنِ يُرَبِّيهَا كَمَا يُرَبِّي أَحَدُكُمْ فَلُوَّهُ أَوْ فَصِيلَهُ حَتَّى تَكُونَ مِثْلَ الْجَبَلِ ‏"‏ ‏.‏\hadithno{1841}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Yahya ibn Said from Abu'l-Hubab Said ibn Yasar that the Messenger of Allah, may Allah bless him and grant him peace, said, "Whoever gives sadaqa from good earning - and Allah only accepts the good - it is as if he placed it in the palm of the Merciful to raise it, as one of you raises his foal or young camel until it is like the mountain}}
\hadithdefcmd{malik}{1842}{وَحَدَّثَنِي مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ أَبُو طَلْحَةَ أَكْثَرَ أَنْصَارِيٍّ بِالْمَدِينَةِ مَالاً مِنْ نَخْلٍ وَكَانَ أَحَبُّ أَمْوَالِهِ إِلَيْهِ بَيْرُحَاءَ وَكَانَتْ مُسْتَقْبِلَةَ الْمَسْجِدِ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْخُلُهَا وَيَشْرَبُ مِنْ مَاءٍ فِيهَا طَيِّبٍ قَالَ أَنَسٌ فَلَمَّا أُنْزِلَتْ هَذِهِ الآيَةُ ‏\{‏ لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ قَامَ أَبُو طَلْحَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى يَقُولُ ‏\{‏لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ وَإِنَّ أَحَبَّ أَمْوَالِي إِلَىَّ بَيْرُحَاءَ وَإِنَّهَا صَدَقَةٌ لِلَّهِ أَرْجُو بِرَّهَا وَذُخْرَهَا عِنْدَ اللَّهِ فَضَعْهَا يَا رَسُولَ اللَّهِ حَيْثُ شِئْتَ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَخْ ذَلِكَ مَالٌ رَابِحٌ ذَلِكَ مَالٌ رَابِحٌ وَقَدْ سَمِعْتُ مَا قُلْتَ فِيهِ وَإِنِّي أَرَى أَنْ تَجْعَلَهَا فِي الأَقْرَبِينَ ‏"‏ ‏.‏ فَقَالَ أَبُو طَلْحَةَ أَفْعَلُ يَا رَسُولَ اللَّهِ فَقَسَمَهَا أَبُو طَلْحَةَ فِي أَقَارِبِهِ وَبَنِي عَمِّهِ ‏.‏\hadithno{1842}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me that Ishaq ibn Abdullah ibn Abi Talha heard Anas ibn Malik say, "Abu Talha had the greatest amount of property in palm-trees among the Ansar in Madina. The dearest of his properties to him was Bayruha which was in front of the mosque. The Messenger of Allah, may Allah bless him and grant him peace, used to go into it and drink from the pleasant water which was in it." Anas continued, "When this ayat was sent down 'You will not obtain rightness of action until you expend of what you love,' (Sura 2 ayat l76), Abu Talha went to the Messenger of Allah, may Allah bless him and grant him peace, and said, 'Messenger of Allah! Allah, the Blessed, the Exalted, has said, "You will not obtain until you expend of what you love." The property which I love the best is Bayruha. It is sadaqa for Allah. I hope for its good and for it to be stored up with Allah. Place it wherever you wish, Messengerof Allah. ' " "The Messenger of Allah, may Allah bless him and grant him peace, said, 'Well done! That is property which profits! That is property which profits. I have heard what you have said about it and I think that you should give it to your relatives.' Abu Talha said, 'I will do it, Messenger of Allah!' Abu Talha therefore divided it among his relatives and the children of his paternal uncle}}
\hadithdefcmd{malik}{1843}{وَحَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَعْطُوا السَّائِلَ وَإِنْ جَاءَ عَلَى فَرَسٍ ‏"‏ ‏.‏\hadithno{1843}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Malik related to me from Zayd ibn Aslam that the Messenger of Allah, may Allah bless him and grant him peace, said, "Give to a beggar even if he comes on a horse}}
\hadithdefcmd{malik}{1844}{وَحَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَمْرِو بْنِ مُعَاذٍ الأَشْهَلِيِّ الأَنْصَارِيِّ، عَنْ جَدَّتِهِ، أَنَّهَا قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا نِسَاءَ الْمُؤْمِنَاتِ لاَ تَحْقِرَنَّ إِحْدَاكُنَّ أَنْ تُهْدِيَ لِجَارَتِهَا وَلَوْ كُرَاعَ شَاةٍ مُحْرَقًا ‏"‏ ‏.‏\hadithno{1844}\hadithgrade{Salim al-Hilali: Hasan Lighairihi}\hadithtrans{Malik related to me from Zayd ibn Aslam from Amr ibn Muadh al- Ashali al-Ansari that his grandmother said, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'O trusting women! Let none of you despise giving to her neighbour even if it is only a roasted sheep's trotter}}
\hadithdefcmd{malik}{1845}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ مِسْكِينًا سَأَلَهَا وَهِيَ صَائِمَةٌ وَلَيْسَ فِي بَيْتِهَا إِلاَّ رَغِيفٌ فَقَالَتْ لِمَوْلاَةٍ لَهَا أَعْطِيهِ إِيَّاهُ ‏.‏ فَقَالَتْ لَيْسَ لَكِ مَا تُفْطِرِينَ عَلَيْهِ ‏.‏ فَقَالَتْ أَعْطِيهِ إِيَّاهُ قَالَتْ فَفَعَلْتُ - قَالَتْ - فَلَمَّا أَمْسَيْنَا أَهْدَى لَنَا أَهْلُ بَيْتٍ - أَوْ إِنْسَانٌ - مَا كَانَ يُهْدِي لَنَا شَاةً وَكَفَنَهَا فَدَعَتْنِي عَائِشَةُ أُمُّ الْمُؤْمِنِينَ فَقَالَتْ كُلِي مِنْ هَذَا هَذَا خَيْرٌ مِنْ قُرْصِكِ ‏.‏\hadithno{1845}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he heard that a beggar asked A'isha, the wife of the Prophet, may Allah bless him and grant him peace, for something while she was fasting and there was only a loaf of bread in her house. She said to her female mawla, "Give it to him." The mawla protested, "You will not have anything to break your fast with." A'isha repeated, "Give it to him," so she did so. When evening came, the people of a house or a man who did not usually give to them, gave them a sheep and some food to go with it. A'isha, umm al-muminin, called her mawla and said, "Eat from this. This is better than your loaf of bread}}
\hadithdefcmd{malik}{1846}{وَحَدَّثَنِي عَنْ مَالِكٍ، قَالَ بَلَغَنِي أَنَّ مِسْكِينًا، اسْتَطْعَمَ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ وَبَيْنَ يَدَيْهَا عِنَبٌ فَقَالَتْ لإِنْسَانٍ خُذْ حَبَّةً فَأَعْطِهِ إِيَّاهَا فَجَعَلَ يَنْظُرُ إِلَيْهَا وَيَعْجَبُ فَقَالَتْ عَائِشَةُ أَتَعْجَبُ كَمْ تَرَى فِي هَذِهِ الْحَبَّةِ مِنْ مِثْقَالِ ذَرَّةٍ\hadithno{1846}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me that Malik said, "I heard that a beggar asked for food from A'isha, umm al-muminin, while she had some grapes. She told some one to take him one grape. He began to look in amazement. A'isha said, 'Are you amazed? How many atoms' weights do you see in this grape?' " (referring to Sura 99 ayat)}}
\hadithdefcmd{malik}{1847}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، ‏.‏ أَنَّ نَاسًا، مِنَ الأَنْصَارِ سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَعْطَاهُمْ ثُمَّ سَأَلُوهُ فَأَعْطَاهُمْ حَتَّى نَفِدَ مَا عِنْدَهُ ثُمَّ قَالَ ‏ "‏ مَا يَكُونُ عِنْدِي مِنْ خَيْرٍ فَلَنْ أَدَّخِرَهُ عَنْكُمْ وَمَنْ يَسْتَعْفِفْ يُعِفَّهُ اللَّهُ وَمَنْ يَسْتَغْنِ يُغْنِهِ اللَّهُ وَمَنْ يَتَصَبَّرْ يُصَبِّرْهُ اللَّهُ وَمَا أُعْطِيَ أَحَدٌ عَطَاءً هُوَ خَيْرٌ وَأَوْسَعُ مِنَ الصَّبْرِ ‏"‏ ‏.‏\hadithno{1847}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik related to me from Malik from Ibn Shihab from Ata ibn Yazid al-Laythi from Abu Said al-Khudri that some people of the Ansar asked the Messenger of Allah, may Allah bless him and grant him peace, and he gave to them. Then they asked him again, and he gave to them until he used up what he had. Then he said, "What wealth I have, I will not hoard from you. Whoever has forbearance, Allah will help him. Whoever tries to be independent, Allah will enrich him. Whoever tries to be patient, Allah will give him patience, and no one is given a better or vaster gift than patience}}
\hadithdefcmd{malik}{1848}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ - وَهُوَ عَلَى الْمِنْبَرِ وَهُوَ يَذْكُرُ الصَّدَقَةَ وَالتَّعَفُّفَ عَنِ الْمَسْأَلَةِ - ‏ "‏ الْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى وَالْيَدُ الْعُلْيَا هِيَ الْمُنْفِقَةُ وَالسُّفْلَى هِيَ السَّائِلَةُ ‏"‏ ‏.‏\hadithno{1848}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, said from the mimbar when mentioning sadaqa and refraining from asking, "The upper hand is better than the lower hand. The upper hand is the one which expends, and the lower one is the one which asks}}
\hadithdefcmd{malik}{1849}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَرْسَلَ إِلَى عُمَرَ بْنِ الْخَطَّابِ بِعَطَاءٍ فَرَدَّهُ عُمَرُ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لِمَ رَدَدْتَهُ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ أَلَيْسَ أَخْبَرْتَنَا أَنَّ خَيْرًا لأَحَدِنَا أَنْ لاَ يَأْخُذَ مِنْ أَحَدٍ شَيْئًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا ذَلِكَ عَنِ الْمَسْأَلَةِ فَأَمَّا مَا كَانَ مِنْ غَيْرِ مَسْأَلَةٍ فَإِنَّمَا هُوَ رِزْقٌ يَرْزُقُكَهُ اللَّهُ ‏"‏ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ أَمَا وَالَّذِي نَفْسِي بِيَدِهِ لاَ أَسْأَلُ أَحَدًا شَيْئًا وَلاَ يَأْتِينِي شَىْءٌ مِنْ غَيْرِ مَسْأَلَةٍ إِلاَّ أَخَذْتُهُ ‏.‏\hadithno{1849}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar that the Messenger of Allah, may Allah bless him and grant him peace, sent a gift to Umar ibn al-Khattab, and Umar returned it. The Messenger of Allah, may Allah bless him and grant him peace, said, "Why did you return it?" He said, "Messenger of Allah, didn't you tell us that it is better for us not to take anything from anyone?" The Messenger of Allah, may Allah bless him and grant him peace, said, "That is by asking. Provision which Allah gives you is different from asking." Umar ibn al-Khattab said, "By the One in whose hand my self is, I will not ask anything from anyone, and anything that comes to me without my asking for it, I will accept}}
\hadithdefcmd{malik}{1850}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لأَنْ يَأْخُذَ أَحَدُكُمْ حَبْلَهُ فَيَحْتَطِبَ عَلَى ظَهْرِهِ خَيْرٌ لَهُ مِنْ أَنْ يَأْتِيَ رَجُلاً أَعْطَاهُ اللَّهُ مِنْ فَضْلِهِ فَيَسْأَلَهُ أَعْطَاهُ أَوْ مَنَعَهُ ‏"‏ ‏.‏\hadithno{1850}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "By Him in whose hand myself is! To take your rope and gather firewood on your back is better for you than that you come to a man to whom Allah has given some of His favour and ask him, so he gives to you or refuses}}
\hadithdefcmd{malik}{1851}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ رَجُلٍ، مِنْ بَنِي أَسَدٍ أَنَّهُ قَالَ نَزَلْتُ أَنَا وَأَهْلِي، بِبَقِيعِ الْغَرْقَدِ فَقَالَ لِي أَهْلِي اذْهَبْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْأَلْهُ لَنَا شَيْئًا نَأْكُلُهُ ‏.‏ وَجَعَلُوا يَذْكُرُونَ مِنْ حَاجَتِهِمْ ‏.‏ فَذَهَبْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَوَجَدْتُ عِنْدَهُ رَجُلاً يَسْأَلُهُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ أَجِدُ مَا أُعْطِيكَ ‏"‏ ‏.‏ فَتَوَلَّى الرَّجُلُ عَنْهُ وَهُوَ مُغْضَبٌ وَهُوَ يَقُولُ لَعَمْرِي إِنَّكَ لَتُعْطِي مَنْ شِئْتَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهُ لَيَغْضَبُ عَلَىَّ أَنْ لاَ أَجِدَ مَا أُعْطِيهِ مَنْ سَأَلَ مِنْكُمْ وَلَهُ أُوقِيَّةٌ أَوْ عَدْلُهَا فَقَدْ سَأَلَ إِلْحَافًا ‏"‏ ‏.‏ قَالَ الأَسَدِيُّ فَقُلْتُ لَلَقْحَةٌ لَنَا خَيْرٌ مِنْ أُوقِيَّةٍ ‏.‏ قَالَ مَالِكٌ وَالأُوقِيَّةُ أَرْبَعُونَ دِرْهَمًا ‏.‏ قَالَ فَرَجَعْتُ وَلَمْ أَسْأَلْهُ فَقُدِمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بَعْدَ ذَلِكَ بِشَعِيرٍ وَزَبِيبٍ فَقَسَمَ لَنَا مِنْهُ حَتَّى أَغْنَانَا اللَّهُ عَزَّ وَجَلَّ ‏.‏\hadithno{1851}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from Ata ibn Yasar that a man of the Banu Asad said, "My family and I dismounted to rest at Baqi. My family said to me, 'Go to the Messenger of Allah, may Allah bless him and grant him peace, and ask him for something that we can eat,' and they began to mention their need. I went to the Messenger of Allah, may Allah bless him and grant him peace, and found that a man was asking for something, and the Messenger of Allah, may Allah bless him and grant him peace, was saying, 'I do not have anything to give you.' The man turned away from him in anger, saying, 'By my life! You give to whomever you wish.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'He is angry with me because I do not have anything to give him. Whoever asks of you while he has an uqiya or its like, has asked with importunity.' " The man continued, "I said to myself about a camel that we had, 'It is better than an uqiya.' (Malik explained that an uqiya was forty dirhams.) So I returned and did not ask him for anything, and the Messenger of Allah, may Allah bless him and grant him peace, sent me barley and raisins after that. He gave us from his share until Allah, the Mighty, the Majestic gave us relief}}
\hadithdefcmd{malik}{1852}{وَعَنْ مَالِكٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَهُ يَقُولُ مَا نَقَصَتْ صَدَقَةٌ مِنْ مَالٍ وَمَا زَادَ اللَّهُ عَبْدًا بِعَفْوٍ إِلاَّ عِزًّا وَمَا تَوَاضَعَ عَبْدٌ إِلاَّ رَفَعَهُ اللَّهُ ‏.‏ قَالَ مَالِكٌ لاَ أَدْرِي أَيُرْفَعُ هَذَا الْحَدِيثُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَمْ لاَ ‏.‏\hadithno{1852}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related that Malik heard al-Ala ibn Abd ar-Rahman say, "Sadaqa does not decrease property, and Allah only increases a slave in worth for his restraint, and no slave is humble but that Allah raises him." Malik said, "I do not know whether this hadith goes back to the Prophet, may Allah bless him and grant him peace, or not}}
\hadithdefcmd{malik}{1853}{حَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَحِلُّ الصَّدَقَةُ لآلِ مُحَمَّدٍ إِنَّمَا هِيَ أَوْسَاخُ النَّاسِ ‏"‏ ‏.‏\hadithno{1853}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he heard that the Messenger of Allah, may Allah bless him and grant him peace, said, "Sadaqa to the family of Muhammad is not halal. It is only people's impurities}}
\hadithdefcmd{malik}{1854}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَعْمَلَ رَجُلاً مِنْ بَنِي عَبْدِ الأَشْهَلِ عَلَى الصَّدَقَةِ فَلَمَّا قَدِمَ سَأَلَهُ إِبِلاً مِنَ الصَّدَقَةِ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى عُرِفَ الْغَضَبُ فِي وَجْهِهِ - وَكَانَ مِمَّا يُعْرَفُ بِهِ الْغَضَبُ فِي وَجْهِهِ أَنْ تَحْمَرَّ عَيْنَاهُ - ثُمَّ قَالَ ‏ "‏ إِنَّ الرَّجُلَ لَيَسْأَلُنِي مَا لاَ يَصْلُحُ لِي وَلاَ لَهُ فَإِنْ مَنَعْتُهُ كَرِهْتُ الْمَنْعَ وَإِنْ أَعْطَيْتُهُ أَعْطَيْتُهُ مَا لاَ يَصْلُحُ لِي وَلاَ لَهُ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ يَا رَسُولَ اللَّهِ لاَ أَسْأَلُكَ مِنْهَا شَيْئًا أَبَدًا ‏.‏\hadithno{1854}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr from his father that the Messenger of Allah, may Allah bless him and grant him peace, gave a man from the Banu Abd al-Ashal charge over some sadaqa. When he came to ask him for some camels from the sadaqa, the Messenger of Allah, may Allah bless him and grant him peace, was so angry that the anger showed in his face. One way in which anger could be recognised in his face was that his eyes became red. Then he said, "This man has asked me for what is not good for me or him. If I refuse it, I hate to refuse. If I give it to him, I will give him what is not good for me or him." The man said, "Messenger of Allah! I will never ask you for any of it}}
\hadithdefcmd{malik}{1855}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ قَالَ عَبْدُ اللَّهِ بْنُ الأَرْقَمِ ادْلُلْنِي عَلَى بَعِيرٍ مِنَ الْمَطَايَا أَسْتَحْمِلُ عَلَيْهِ أَمِيرَ الْمُؤْمِنِينَ فَقُلْتُ نَعَمْ جَمَلاً مِنَ الصَّدَقَةِ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ الأَرْقَمِ أَتُحِبُّ أَنَّ رَجُلاً بَادِنًا فِي يَوْمٍ حَارٍّ غَسَلَ لَكَ مَا تَحْتَ إِزَارِهِ وَرُفْغَيْهِ ثُمَّ أَعْطَاكَهُ فَشَرِبْتَهُ قَالَ فَغَضِبْتُ وَقُلْتُ يَغْفِرُ اللَّهُ لَكَ أَتَقُولُ لِي مِثْلَ هَذَا فَقَالَ عَبْدُ اللَّهِ بْنُ الأَرْقَمِ إِنَّمَا الصَّدَقَةُ أَوْسَاخُ النَّاسِ يَغْسِلُونَهَا عَنْهُمْ ‏.‏\hadithno{1855}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam that his father said, "Abdullah ibn al-Arqam said, 'Show me a riding-camel which the amir al-muminim can give me to use.' I said, 'Yes. One of the sadaqa camels.' Abdullah ibn al-Arqam said, 'Would you want a stout man on a hot day to wash for you what is under his lower garment and its folds, and then give it to you to drink?' I was angry and said, 'May Allah forgive you! Why do you say such things to me?' Abdullah ibn al-Arqam said, 'Sadaqa is the impurities of people which they wash off themselves}}
