% Auto-generated chapter 8 for muslim
% Hadiths in this chapter: 22

\hadithdefcmd{muslim}{2044}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ عَبْدِ الرَّزَّاقِ، - قَالَ ابْنُ رَافِعٍ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، - أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي الْحَسَنُ بْنُ مُسْلِمٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ، عَبَّاسٍ قَالَ شَهِدْتُ صَلاَةَ الْفِطْرِ مَعَ نَبِيِّ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ فَكُلُّهُمْ يُصَلِّيهَا قَبْلَ الْخُطْبَةِ ثُمَّ يَخْطُبُ قَالَ فَنَزَلَ نَبِيُّ اللَّهِ صلى الله عليه وسلم كَأَنِّي أَنْظُرُ إِلَيْهِ حِينَ يُجَلِّسُ الرِّجَالَ بِيَدِهِ ثُمَّ أَقْبَلَ يَشُقُّهُمْ حَتَّى جَاءَ النِّسَاءَ وَمَعَهُ بِلاَلٌ فَقَالَ ‏\{‏ يَا أَيُّهَا النَّبِيُّ إِذَا جَاءَكَ الْمُؤْمِنَاتُ يُبَايِعْنَكَ عَلَى أَنْ لاَ يُشْرِكْنَ بِاللَّهِ شَيْئًا‏\}‏ فَتَلاَ هَذِهِ الآيَةَ حَتَّى فَرَغَ مِنْهَا ثُمَّ قَالَ حِينَ فَرَغَ مِنْهَا ‏"‏ أَنْتُنَّ عَلَى ذَلِكِ ‏"‏ فَقَالَتِ امْرَأَةٌ وَاحِدَةٌ لَمْ يُجِبْهُ غَيْرُهَا مِنْهُنَّ نَعَمْ يَا نَبِيَّ اللَّهِ لاَ يُدْرَى حِينَئِذٍ مَنْ هِيَ قَالَ ‏"‏ فَتَصَدَّقْنَ ‏"‏ ‏.‏ فَبَسَطَ بِلاَلٌ ثَوْبَهُ ثُمَّ قَالَ هَلُمَّ فِدًى لَكُنَّ أَبِي وَأُمِّي ‏.‏ فَجَعَلْنَ يُلْقِينَ الْفَتَخَ وَالْخَوَاتِمَ فِي ثَوْبِ بِلاَلٍ ‏.‏\hadithno{2044}\hadithtrans{Ibn 'Abbas reported:I participated in the Fitr prayer with the Messenger of Allah (ﷺ) and Abu Bakr, 'Umar and 'Uthman, and all of them observed this prayer before the Khutba, and then he (the Holy Prophet) delivered the sermon. Then the Messenger of Allah (ﷺ) descended (from the pulpit) and I (perceive) as if I am seeing him as he is commanding people with his hand to sit down. He then made his way through their (assembly) till he came to the women. Bilal was with him. He then recited (this verse): O Prophet, when believing women come to thee giving thee a pledge that they will not associate aught with Allah" (lx. 12) till he finished (his address to) them and then said: Do you conform to it (what has been described in the verse)? Only one woman among them replied: Yes, Apostle of Allah, but none else replied. He (the narrator) said: It could not be ascertained who actually she was. He (the Holy Prophet) exhorted them to give alms. Bilal stretched his cloth and then said: Come forward with alms. Let my father and mother be taken as ransom for you. And they began to throw rings and ringlets in the cloth of Bilal}}
\hadithdefcmd{muslim}{2047}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالَ ابْنُ رَافِعٍ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُهُ يَقُولُ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَامَ يَوْمَ الْفِطْرِ فَصَلَّى فَبَدَأَ بِالصَّلاَةِ قَبْلَ الْخُطْبَةِ ثُمَّ خَطَبَ النَّاسَ فَلَمَّا فَرَغَ نَبِيُّ اللَّهِ صلى الله عليه وسلم نَزَلَ وَأَتَى النِّسَاءَ فَذَكَّرَهُنَّ وَهُوَ يَتَوَكَّأُ عَلَى يَدِ بِلاَلٍ وَبِلاَلٌ بَاسِطٌ ثَوْبَهُ يُلْقِينَ النِّسَاءُ صَدَقَةً ‏.‏ قُلْتُ لِعَطَاءٍ زَكَاةَ يَوْمِ الْفِطْرِ قَالَ لاَ وَلَكِنْ صَدَقَةً يَتَصَدَّقْنَ بِهَا حِينَئِذٍ تُلْقِي الْمَرْأَةُ فَتَخَهَا وَيُلْقِينَ وَيُلْقِينَ ‏.‏ قُلْتُ لِعَطَاءٍ أَحَقًّا عَلَى الإِمَامِ الآنَ أَنْ يَأْتِيَ النِّسَاءَ حِينَ يَفْرُغُ فَيُذَكِّرَهُنَّ قَالَ إِي لَعَمْرِي إِنَّ ذَلِكَ لَحَقٌّ عَلَيْهِمْ وَمَا لَهُمْ لاَ يَفْعَلُونَ ذَلِكَ\hadithno{2047}\hadithtrans{Jabir b. 'Abdullah reported:The Apostle of Allah (ﷺ) stood up on the day of 'Id al-Fitr and observed prayer. And he commenced the prayer before the sermon. He then delivered the sermon. When the Messenger of Allah (ﷺ) had finished (the sermon) he came down from (the pulpit), and made his way to the women and exhorted them (to do good acts), and he was leaning on the hand of Bilal. Bilal had stretched his cloth in which women were throwing alms. I (one of the narrators) said to 'Ata' (the other narrator): It must be Zakat on the day of Fitr. He ('Ata') said: No. It was alms (which) they were giving on that occasion, and a woman gave her ring, and then others gave, and then others gave. I said to 'Ata': Is It right now for the Imam to come to the women when he has finished (his address to the men) that he should exhort them (to good deeds)? He said: (Why not) by my life, it is right for them (to do so). What is the matter with them that they do not do it now?}}
\hadithdefcmd{muslim}{2048}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ شَهِدْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الصَّلاَةَ يَوْمَ الْعِيدِ فَبَدَأَ بِالصَّلاَةِ قَبْلَ الْخُطْبَةِ بِغَيْرِ أَذَانٍ وَلاَ إِقَامَةٍ ثُمَّ قَامَ مُتَوَكِّئًا عَلَى بِلاَلٍ فَأَمَرَ بِتَقْوَى اللَّهِ وَحَثَّ عَلَى طَاعَتِهِ وَوَعَظَ النَّاسَ وَذَكَّرَهُمْ ثُمَّ مَضَى حَتَّى أَتَى النِّسَاءَ فَوَعَظَهُنَّ وَذَكَّرَهُنَّ فَقَالَ تَصَدَّقْنَ فَإِنَّ أَكْثَرَكُنَّ حَطَبُ جَهَنَّمَ فَقَامَتْ امْرَأَةٌ مِنْ سِطَةِ النِّسَاءِ سَفْعَاءُ الْخَدَّيْنِ فَقَالَتْ لِمَ يَا رَسُولَ اللَّهِ قَالَ لِأَنَّكُنَّ تُكْثِرْنَ الشَّكَاةَ وَتَكْفُرْنَ الْعَشِيرَ قَالَ فَجَعَلْنَ يَتَصَدَّقْنَ مِنْ حُلِيِّهِنَّ يُلْقِينَ فِي ثَوْبِ بِلَالٍ مِنْ أَقْرِطَتِهِنَّ وَخَوَاتِمِهِنَّ\hadithno{2048}\hadithtrans{Jabir b. 'Abdullah reported:I observed prayer with the Messenger of Allah (ﷺ) on the 'Id day. He commenced with prayer before the sermon without Adhan and Iqama. He then stood up leaning on Bilal, and he commanded (them) to be on guard (against evil for the sake of) Allah, and he exhorted (them) on obedience to Him, and he preached to the people and admonished them. He then walked on till he came to the women and preached to them and admonished them, and asked them to give alms, for most of them are the fuel for Hell. A woman having a dark spot on the cheek stood up and said: Why is it so, Messenger of Allah? He said: For you grumble often and show ingratitude to your spouse. And then they began to give alms out of their ornaments such as their earrings and rings which they threw on to the cloth of Bilal}}
\hadithdefcmd{muslim}{2049}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، عَنِ ابْنِ عَبَّاسٍ، وَعَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ الأَنْصَارِيِّ، قَالاَ لَمْ يَكُنْ يُؤَذَّنُ يَوْمَ الْفِطْرِ وَلاَ يَوْمَ الأَضْحَى ‏.‏ ثُمَّ سَأَلْتُهُ بَعْدَ حِينٍ عَنْ ذَلِكَ فَأَخْبَرَنِي قَالَ أَخْبَرَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ\hadithno{2049}\hadithtrans{Ibn 'Abbas and Jaibir b. 'Abdullah al-Ansari reported:There was no Adhan on the (occasion) of Id-ul-Fitr and Id-ul-Adha. I (Ibn Juraij) said: I asked him after some time about it. He ('Ata', one of the narrators) said: Jabir b. 'Abdullah al-Ansari told me: There is neither any Adhan on Id-ul-Fitr when the Imam comes out, nor even after his coming out; their is neither lqama nor call nor anything of the sort of calling on that day and nor Iqama}}
\hadithdefcmd{muslim}{2050}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، أَنَّ ابْنَ عَبَّاسٍ، أَرْسَلَ إِلَى ابْنِ الزُّبَيْرِ أَوَّلَ مَا بُويِعَ لَهُ أَنَّهُ لَمْ يَكُنْ يُؤَذَّنُ لِلصَّلاَةِ يَوْمَ الْفِطْرِ فَلاَ تُؤَذِّنْ لَهَا - قَالَ - فَلَمْ يُؤَذِّنْ لَهَا ابْنُ الزُّبَيْرِ يَوْمَهُ وَأَرْسَلَ إِلَيْهِ مَعَ ذَلِكَ إِنَّمَا الْخُطْبَةُ بَعْدَ الصَّلاَةِ وَإِنَّ ذَلِكَ قَدْ كَانَ يُفْعَلُ - قَالَ - فَصَلَّى ابْنُ الزُّبَيْرِ قَبْلَ الْخُطْبَةِ ‏.‏\hadithno{2050}\hadithtrans{Ata' reported that Ibn 'Abbas sent (him) to Ibn Zubair at the commencement of the oath of allegiance to him (for Caliphate saying):As there is no Adhan on 'Id-ul-Fitr, so you should not pronounce it. Ibn Zubair did not pronounce Adhan on that day. He (Ibn 'Abbas) also sent him (with this message) that sermon (is to be delivered) after the prayer, and thus it was done. So lbn Zubair observed prayer before Khutba}}
\hadithdefcmd{muslim}{2051}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَحَسَنُ بْنُ الرَّبِيعِ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ، سَمُرَةَ قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْعِيدَيْنِ غَيْرَ مَرَّةٍ وَلاَ مَرَّتَيْنِ بِغَيْرِ أَذَانٍ وَلاَ إِقَامَةٍ ‏.‏\hadithno{2051}\hadithtrans{Jabir b. Samura said:I prayed with the Messenger of Allah (ﷺ) prayers on two I'ds wore than once or twice without there being Adhan and Iqama}}
\hadithdefcmd{muslim}{2052}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، وَأَبُو أُسَامَةَ عَنْ عُبَيْدِ، اللَّهِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَأَبَا بَكْرٍ وَعُمَرَ كَانُوا يُصَلُّونَ الْعِيدَيْنِ قَبْلَ الْخُطْبَةِ ‏.‏\hadithno{2052}\hadithtrans{Ibn 'Umar reported that the Messenger of Allah (ﷺ), Abu Bakr and 'Umar used to observe the two 'Id prayers before the sermon}}
\hadithdefcmd{muslim}{2053}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ دَاوُدَ بْنِ قَيْسٍ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ بْنِ سَعْدٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَخْرُجُ يَوْمَ الأَضْحَى وَيَوْمَ الْفِطْرِ فَيَبْدَأُ بِالصَّلاَةِ فَإِذَا صَلَّى صَلاَتَهُ وَسَلَّمَ قَامَ فَأَقْبَلَ عَلَى النَّاسِ وَهُمْ جُلُوسٌ فِي مُصَلاَّهُمْ فَإِنْ كَانَ لَهُ حَاجَةٌ بِبَعْثٍ ذَكَرَهُ لِلنَّاسِ أَوْ كَانَتْ لَهُ حَاجَةٌ بِغَيْرِ ذَلِكَ أَمَرَهُمْ بِهَا وَكَانَ يَقُولُ ‏ "‏ تَصَدَّقُوا تَصَدَّقُوا تَصَدَّقُوا ‏"‏ ‏.‏ وَكَانَ أَكْثَرَ مَنْ يَتَصَدَّقُ النِّسَاءُ ثُمَّ يَنْصَرِفُ فَلَمْ يَزَلْ كَذَلِكَ حَتَّى كَانَ مَرْوَانُ بْنُ الْحَكَمِ فَخَرَجْتُ مُخَاصِرًا مَرْوَانَ حَتَّى أَتَيْنَا الْمُصَلَّى فَإِذَا كَثِيرُ بْنُ الصَّلْتِ قَدْ بَنَى مِنْبَرًا مِنْ طِينٍ وَلَبِنٍ فَإِذَا مَرْوَانُ يُنَازِعُنِي يَدَهُ كَأَنَّهُ يَجُرُّنِي نَحْوَ الْمِنْبَرِ وَأَنَا أَجُرُّهُ نَحْوَ الصَّلاَةِ فَلَمَّا رَأَيْتُ ذَلِكَ مِنْهُ قُلْتُ أَيْنَ الاِبْتِدَاءُ بِالصَّلاَةِ فَقَالَ لاَ يَا أَبَا سَعِيدٍ قَدْ تُرِكَ مَا تَعْلَمُ ‏.‏ قُلْتُ كَلاَّ وَالَّذِي نَفْسِي بِيَدِهِ لاَ تَأْتُونَ بِخَيْرٍ مِمَّا أَعْلَمُ ‏.‏ ثَلاَثَ مِرَارٍ ثُمَّ انْصَرَفَ ‏.‏\hadithno{2053}\hadithtrans{Abu Sa'id al-Khudri reported that the Messenger of Allah (ﷺ) used to go out on the day of Adha and on the day of Fitr and commenced the prayer. And after having observed his prayer and pronounced the salutation, he stood up facing people as they were seated at their places of worship. And if he intended to send out an army he made mention of it to the people, and if he intended any other thing besides it, he commanded them (to do that). He used to say (to the people):Give alms, give alms, give alms, and the majority that gave alms was of women. He then returned and this (practice) remained (in vogue) till Marwan b. al- Hakam (came into power). I went out hand in hand with Marwan till we came to the place of worship and there Kathir b. Salt had built a pulpit of clay and brick. Marwan began to tug me with his hand as though he were pulling me towards the pulpit, while I was pulling him towards the prayer. When I saw him doing that I said: What has happened to the practice of beginning with prayer? He said: No, Abu Sa'id, what you are familiar with has been abandoned. I thereupon said (three times and went back): By no means, by Him in Whose hand my life is, you are not doing anything better than what I am familiar with}}
\hadithdefcmd{muslim}{2054}{حَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ أَمَرَنَا - تَعْنِي النَّبِيَّ صلى الله عليه وسلم - أَنْ نُخْرِجَ فِي الْعِيدَيْنِ الْعَوَاتِقَ وَذَوَاتِ الْخُدُورِ وَأَمَرَ الْحُيَّضَ أَنْ يَعْتَزِلْنَ مُصَلَّى الْمُسْلِمِينَ ‏.‏\hadithno{2054}\hadithtrans{Umm 'Atiyya said:He (the Messenger of Allah) commanded us that we should take out unmarried women and the screened away ladies for 'Id prayers, and he commanded the menstruating women to remain away from the place of worship of the Muslims}}
\hadithdefcmd{muslim}{2055}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ حَفْصَةَ بِنْتِ، سِيرِينَ عَنْ أُمِّ عَطِيَّةَ، قَالَتْ كُنَّا نُؤْمَرُ بِالْخُرُوجِ فِي الْعِيدَيْنِ وَالْمُخَبَّأَةُ وَالْبِكْرُ قَالَتِ الْحُيَّضُ يَخْرُجْنَ فَيَكُنَّ خَلْفَ النَّاسِ يُكَبِّرْنَ مَعَ النَّاسِ ‏.‏\hadithno{2055}\hadithtrans{Umm Atiyya reported:We were commanded to go out as well as the hidden away ladies and those unmarried. She said menstruating women were to come out amongst you, but remain behind people and pronounce takbir (Allah-o-Akbar) along with them}}
\hadithdefcmd{muslim}{2056}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا هِشَامٌ، عَنْ حَفْصَةَ بِنْتِ، سِيرِينَ عَنْ أُمِّ عَطِيَّةَ، قَالَتْ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نُخْرِجَهُنَّ فِي الْفِطْرِ وَالأَضْحَى الْعَوَاتِقَ وَالْحُيَّضَ وَذَوَاتِ الْخُدُورِ فَأَمَّا الْحُيَّضُ فَيَعْتَزِلْنَ الصَّلاَةَ وَيَشْهَدْنَ الْخَيْرَ وَدَعْوَةَ الْمُسْلِمِينَ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِحْدَانَا لاَ يَكُونُ لَهَا جِلْبَابٌ قَالَ ‏ "‏ لِتُلْبِسْهَا أُخْتُهَا مِنْ جِلْبَابِهَا ‏"‏ ‏.‏\hadithno{2056}\hadithtrans{Umm 'Atiyya reported:The Messenger of Allah (ﷺ) commanded us to bring out on'Id-ul-Fitr and 'Id-ul-Adha young women, menstruating women and screened away ladies, menstruating women kept back from prayer, but participated in goodness and supplication of the Muslims. I said: Messenger of Allah, one of us does not have an outer garment (to cover her face and body). He said: Let her sister cover her with her outer garment}}
\hadithdefcmd{muslim}{2059}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ ضَمْرَةَ بْنِ سَعِيدٍ الْمَازِنِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، سَأَلَ أَبَا وَاقِدٍ اللَّيْثِيَّ مَا كَانَ يَقْرَأُ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الأَضْحَى وَالْفِطْرِ فَقَالَ كَانَ يَقْرَأُ فِيهِمَا بِـ ‏\{‏ ق وَالْقُرْآنِ الْمَجِيدِ‏\}‏ وَ ‏\{‏ اقْتَرَبَتِ السَّاعَةُ وَانْشَقَّ الْقَمَرُ‏\}‏\hadithno{2059}\hadithtrans{Abdullah b. 'Umar reported that (his father) 'Umar b. Khattab asked Abu Waqid al-Laithi what the Messenger of Allah (ﷺ) used to recite on 'Id-ul-Adha and 'Id-ul-Fitr. He said:He used to recite in them:" Qaf. By the Glorious Qur'an" (Surah 1)," The Hour drew near, and the moon was rent asunder" (Surah liv)}}
\hadithdefcmd{muslim}{2060}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا فُلَيْحٌ، عَنْ ضَمْرَةَ، بْنِ سَعِيدٍ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي وَاقِدٍ اللَّيْثِيِّ، قَالَ سَأَلَنِي عُمَرُ بْنُ الْخَطَّابِ عَمَّا قَرَأَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي يَوْمِ الْعِيدِ فَقُلْتُ بِـ ‏\{‏ اقْتَرَبَتِ السَّاعَةُ‏\}‏ وَ ‏\{‏ ق وَالْقُرْآنِ الْمَجِيدِ‏\}‏\hadithno{2060}\hadithtrans{Utba reported that his father Waqid al-Laithi said:'Umar b. Khattab asked me what the Messenger of Allah (ﷺ) recited on 'Id day. I said:" The Hour drew near" and Qaf. By the Glorious Qur'an}}
\hadithdefcmd{muslim}{2061}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ عَلَىَّ أَبُو بَكْرٍ وَعِنْدِي جَارِيَتَانِ مِنْ جَوَارِي الأَنْصَارِ تُغَنِّيَانِ بِمَا تَقَاوَلَتْ بِهِ الأَنْصَارُ يَوْمَ بُعَاثٍ قَالَتْ وَلَيْسَتَا بِمُغَنِّيَتَيْنِ ‏.‏ فَقَالَ أَبُو بَكْرٍ أَبِمُزْمُورِ الشَّيْطَانِ فِي بَيْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَذَلِكَ فِي يَوْمِ عِيدٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا أَبَا بَكْرٍ إِنَّ لِكُلِّ قَوْمٍ عِيدًا وَهَذَا عِيدُنَا ‏"‏ ‏.‏\hadithno{2061}\hadithtrans{A'isha reported:Abu Bakr came to see me and I had two girls with me from among the girls of the Ansar and they were singing what the Ansar recited to one another at the Battle of Bu'ath. They were not, however, singing girls. Upon this Abu Bakr said: What I (the playing of) this wind instrument of Satan in the house of the Messenger of Allah (ﷺ) and this too on 'Id day? Upon this the Messenger of Allah (ﷺ) said: Abu Bakr, every people have a festival and it is our festival (so let them play on)}}
\hadithdefcmd{muslim}{2062}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، وَأَبُو كُرَيْبٍ جَمِيعًا عَنْ أَبِي مُعَاوِيَةَ، عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِيهِ جَارِيَتَانِ تَلْعَبَانِ بِدُفٍّ ‏.‏\hadithno{2062}\hadithtrans{This hadith has been narrated by Hisham with the same chain of transmitters, but there the words are:" Two girls were playing upon a tambourine}}
\hadithdefcmd{muslim}{2063}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، أَنَّ ابْنَ شِهَابٍ، حَدَّثَهُ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ أَبَا بَكْرٍ، دَخَلَ عَلَيْهَا وَعِنْدَهَا جَارِيَتَانِ فِي أَيَّامِ مِنًى تُغَنِّيَانِ وَتَضْرِبَانِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم مُسَجًّى بِثَوْبِهِ فَانْتَهَرَهُمَا أَبُو بَكْرٍ فَكَشَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْهُ وَقَالَ ‏ "‏ دَعْهُمَا يَا أَبَا بَكْرٍ فَإِنَّهَا أَيَّامُ عِيدٍ ‏"‏ ‏.‏ وَقَالَتْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتُرُنِي بِرِدَائِهِ وَأَنَا أَنْظُرُ إِلَى الْحَبَشَةِ وَهُمْ يَلْعَبُونَ وَأَنَا جَارِيَةٌ فَاقْدِرُوا قَدْرَ الْجَارِيَةِ الْعَرِبَةِ الْحَدِيثَةِ السِّنِّ ‏.‏\hadithno{2063}\hadithtrans{A'isha reported that Abu Bakr came to her and there were with her two girls on Adha days who were singing and beating the tambourine and the Messenger of Allah (ﷺ) had wrapped himself with his mantle. Abu Bakr scolded them. The Messenger of Allah (may peace he upon him) uncovered (his face) and said:Abu Bakr, leave them alone for these are the days of 'Id. And 'A'isha said: I recapitulate to my mind the fact that once the Messenger of Allah (ﷺ) screened me with his mantle and I saw the sports of the Abyssinians, and I was only a girl, and so you can well imagine how a girl of tender age is fond of watching the sport}}
\hadithdefcmd{muslim}{2064}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، بْنِ الزُّبَيْرِ قَالَ قَالَتْ عَائِشَةُ وَاللَّهِ لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُومُ عَلَى بَابِ حُجْرَتِي - وَالْحَبَشَةُ يَلْعَبُونَ بِحِرَابِهِمْ فِي مَسْجِدِ رَسُولِ اللَّهِ صلى الله عليه وسلم - يَسْتُرُنِي بِرِدَائِهِ لِكَىْ أَنْظُرَ إِلَى لَعِبِهِمْ ثُمَّ يَقُومُ مِنْ أَجْلِي حَتَّى أَكُونَ أَنَا الَّتِي أَنْصَرِفُ ‏.‏ فَاقْدُرُوا قَدْرَ الْجَارِيَةِ الْحَدِيثَةِ السِّنِّ حَرِيصَةً عَلَى اللَّهْوِ ‏.‏\hadithno{2064}\hadithtrans{A'isha reported:BY Allah, I remember the Messenger of Allah (ﷺ) standing on the door of my apartment screening me with his mantle enabling me to see the sport of the Abyssinians as they played with their daggers in the mosque of the Messenger of Allah (may peace be upom him). He (the Holy Prophet) kept standing for my sake till I was satiated and then I went back; and thus you can well imagine how long a girl tender of age who is fond of sports (could have watched it)}}
\hadithdefcmd{muslim}{2065}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَيُونُسُ بْنُ عَبْدِ الأَعْلَى، - وَاللَّفْظُ لِهَارُونَ - قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا عَمْرٌو، أَنَّ مُحَمَّدَ بْنَ عَبْدِ الرَّحْمَنِ، حَدَّثَهُ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعِنْدِي جَارِيَتَانِ تُغَنِّيَانِ بِغِنَاءِ بُعَاثٍ فَاضْطَجَعَ عَلَى الْفِرَاشِ وَحَوَّلَ وَجْهَهُ فَدَخَلَ أَبُو بَكْرٍ فَانْتَهَرَنِي وَقَالَ مِزْمَارُ الشَّيْطَانِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَقْبَلَ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ دَعْهُمَا ‏"‏ فَلَمَّا غَفَلَ غَمَزْتُهُمَا فَخَرَجَتَا وَكَانَ يَوْمَ عِيدٍ يَلْعَبُ السُّودَانُ بِالدَّرَقِ وَالْحِرَابِ فَإِمَّا سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَإِمَّا قَالَ ‏"‏ تَشْتَهِينَ تَنْظُرِينَ ‏"‏ ‏.‏ فَقُلْتُ نَعَمْ فَأَقَامَنِي وَرَاءَهُ خَدِّي عَلَى خَدِّهِ وَهُوَ يَقُولُ ‏"‏ دُونَكُمْ يَا بَنِي أَرْفَدَةَ ‏"‏ ‏.‏ حَتَّى إِذَا مَلِلْتُ قَالَ ‏"‏ حَسْبُكِ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ فَاذْهَبِي ‏"‏ ‏.‏\hadithno{2065}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) came (to my apartment) while there were two girls with me singing the song of the Battle of Bu`ath. He lay down on the bed and turned away his face. Then came Abu Bakr and he scolded me and said: Oh! this musical instrument of the devil in the house of the Messenger of Allah (ﷺ)! The Messenger of Allah (ﷺ) turned towards him and said: Leave them alone. And when he (the Holy Prophet) became unattentive, I hinted them and they went out, and it was the day of `Id and the black men were playing with shields and spears. (I do not remember) whether I asked the Messenger of Allah (ﷺ) or whether he said to me if I desired to see (that sport). I said: Yes. I stood behind him with his face parallel to my face, and he said: O Banu Arfada, be busy (in your sports) till I was satiated. He said (to me): Is that enough? I said: Yes. Upon this he asked me to go}}
\hadithdefcmd{muslim}{2066}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَ حَبَشٌ يَزْفِنُونَ فِي يَوْمِ عِيدٍ فِي الْمَسْجِدِ فَدَعَانِي النَّبِيُّ صلى الله عليه وسلم فَوَضَعْتُ رَأْسِي عَلَى مَنْكِبِهِ فَجَعَلْتُ أَنْظُرُ إِلَى لَعِبِهِمْ حَتَّى كُنْتُ أَنَا الَّتِي أَنْصَرِفُ عَنِ النَّظَرِ إِلَيْهِمْ\hadithno{2066}\hadithtrans{A'isha reported that some Abyssinians came and gave a demonstration of armed fight on the 'Id day in the mosque. The Apostle of Allah (ﷺ) invited me (to see that fight). I placed my head on his shoulder and began to see their sport till it was I who turned away from watching them}}
\hadithdefcmd{muslim}{2067}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَحْيَى بْنُ زَكَرِيَّاءَ بْنِ أَبِي زَائِدَةَ، ح وَحَدَّثَنَا ابْنُ، نُمَيْرٍ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، كِلاَهُمَا عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرَا فِي الْمَسْجِدِ ‏.‏\hadithno{2067}\hadithtrans{This hadith has been narrated by Hisham with the same chain of transmitters but (the narrators) did not make mention of the mosque}}
\hadithdefcmd{muslim}{2068}{وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ دِينَارٍ، وَعُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، كُلُّهُمْ عَنْ أَبِي، عَاصِمٍ - وَاللَّفْظُ لِعُقْبَةَ - قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، أَخْبَرَنِي عُبَيْدُ بْنُ عُمَيْرٍ، أَخْبَرَتْنِي عَائِشَةُ، أَنَّهَا قَالَتْ لِلَعَّابِينَ وَدِدْتُ أَنِّي أَرَاهُمْ قَالَتْ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقُمْتُ عَلَى الْبَابِ أَنْظُرُ بَيْنَ أُذُنَيْهِ وَعَاتِقِهِ وَهُمْ يَلْعَبُونَ فِي الْمَسْجِدِ ‏.‏ قَالَ عَطَاءٌ فُرْسٌ أَوْ حَبَشٌ ‏.‏ قَالَ وَقَالَ لِي ابْنُ عَتِيقٍ بَلْ حَبَشٌ ‏.‏\hadithno{2068}\hadithtrans{A'isha said that she sent a message to the players (of this armed fight) saying:I like to see them (fighting). She further said: The Messenger of Allah (ﷺ) stood up and I stood at the door (behind him) and saw (this fight) between his ears and his shoulders they played in the mosque. 'Ata' (one of the narra- tors) said: Were they persians or Abyssinians? Ibn 'Atiq told me they were Abyssinians}}
\hadithdefcmd{muslim}{2069}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ بَيْنَمَا الْحَبَشَةُ يَلْعَبُونَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِحِرَابِهِمْ إِذْ دَخَلَ عُمَرُ بْنُ الْخَطَّابِ فَأَهْوَى إِلَى الْحَصْبَاءِ يَحْصِبُهُمْ بِهَا ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ دَعْهُمْ يَا عُمَرُ\hadithno{2069}\hadithtrans{Abu Huraira reported:While the Abyssinians were busy playing with their arms in the presence of the Messenger of Allah (ﷺ) 'Umar b. Khattab came there. He bent down to take up pebbles to throw at them (in order to make them go off). The Messenger of Allah (ﷺ) said to him: 'Umar, leave them alone}}
