% Auto-generated chapter 3 for nasai
% Hadiths in this chapter: 49

\hadithdefcmd{nasai}{348}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ بْنِ مُحَمَّدِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ، - رضى الله عنه - عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ نُرَى إِلاَّ الْحَجَّ فَلَمَّا كُنَّا بِسَرِفَ حِضْتُ فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَبْكِي فَقَالَ ‏"‏ مَا لَكِ أَنَفِسْتِ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ هَذَا أَمْرٌ كَتَبَهُ اللَّهُ عَزَّ وَجَلَّ عَلَى بَنَاتِ آدَمَ فَاقْضِي مَا يَقْضِي الْحَاجُّ غَيْرَ أَنْ لاَ تَطُوفِي بِالْبَيْتِ ‏"‏ ‏.‏\hadithno{348}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"We went out with the Messenger of Allah (ﷺ) with no intention other than Hajj. When he was in Sarif I began menstruating. The Messenger of Allah (ﷺ) entered upon me and I was weeping. He said: 'What is the matter with you? Has you Nifas begun?' I said: 'Yes.' He said: 'This is something that Allah the Mighty and Sublime has decreed for the daughters of Adam. Do what the pilgrims do but do not perform Tawaf around the House}}
\hadithdefcmd{nasai}{349}{أَخْبَرَنَا عِمْرَانُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، - وَهُوَ ابْنُ سَمَاعَةَ - قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ أَخْبَرَنِي هِشَامُ بْنُ عُرْوَةَ، عَنْ عُرْوَةَ، أَنَّ فَاطِمَةَ بِنْتَ قَيْسٍ، مِنْ بَنِي أَسَدِ قُرَيْشٍ أَنَّهَا أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَتْ أَنَّهَا تُسْتَحَاضُ فَزَعَمَتْ أَنَّهُ قَالَ لَهَا ‏ "‏ إِنَّمَا ذَلِكِ عِرْقٌ فَإِذَا أَقْبَلَتِ الْحَيْضَةُ فَدَعِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْتَسِلِي وَاغْسِلِي عَنْكِ الدَّمَ ثُمَّ صَلِّي ‏"‏ ‏.‏\hadithno{349}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Fatimah bint Qais from Banu Asad Quraish that she came to the Prophet (ﷺ) and mentioned that she suffered from Istihadah. She said that he said to her:"That is a vein, so when the time of menstruation comes, stop praying, and when it goes, take your bath and wash the blood from yourself then pray}}
\hadithdefcmd{nasai}{350}{أَخْبَرَنَا هِشَامُ بْنُ عَمَّارٍ، قَالَ حَدَّثَنَا سَهْلُ بْنُ هَاشِمٍ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَقْبَلَتِ الْحِيضَةُ فَدَعِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْتَسِلِي ‏"‏ ‏.‏\hadithno{350}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Prophet (ﷺ) said:"When the time of menstruation comes, stop praying, and when it goes, perform Ghusl}}
\hadithdefcmd{nasai}{351}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتِ اسْتَفْتَتْ أُمُّ حَبِيبَةَ بِنْتُ جَحْشٍ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أُسْتَحَاضُ فَقَالَ ‏ "‏ إِنَّ ذَلِكِ عِرْقٌ فَاغْتَسِلِي ثُمَّ صَلِّي ‏"‏ ‏.‏ فَكَانَتْ تَغْتَسِلُ عِنْدَ كُلِّ صَلاَةٍ ‏.‏\hadithno{351}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"Umm Habibah bint Jahsh asked the Messenger of Allah (ﷺ): 'O Messenger of Allah, I suffer from Istihadah.' He said: 'That is a vein, so perform Ghusl, then pray.' And she used to perform Ghusl for each prayer}}
\hadithdefcmd{nasai}{352}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ إِنَّ أُمَّ حَبِيبَةَ سَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الدَّمِ - فَقَالَتْ عَائِشَةُ رَأَيْتُ مِرْكَنَهَا مَلآنَ دَمًا - فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ امْكُثِي قَدْرَ مَا كَانَتْ تَحْبِسُكِ حِيضَتُكِ ثُمَّ اغْتَسِلِي ‏"‏ ‏.‏وَأَخْبَرَنَا بِهِ قُتَيْبَةُ مَرَّةً أُخْرَى وَلَمْ يَذْكُرْ فِيهِ جَعْفَرَ بْنَ رَبِيعَةَ\hadithno{352}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that Umm Habibah asked the Messenger of Allah (ﷺ) about bleeding. 'Aishah said:"I saw her wash tub filled with blood." The Messenger of Allah (ﷺ) said to her: "Stop (praying) for as long as your period used to last, then perform Ghusl. And Qutayba told us about it again, and he did not mention Ja`far ibn Rabi`ah in it}}
\hadithdefcmd{nasai}{353}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ إِنَّ أُمَّ حَبِيبَةَ سَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الدَّمِ - فَقَالَتْ عَائِشَةُ رَأَيْتُ مِرْكَنَهَا مَلآنَ دَمًا - فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ امْكُثِي قَدْرَ مَا كَانَتْ تَحْبِسُكِ حِيضَتُكِ ثُمَّ اغْتَسِلِي ‏"‏ ‏.‏وَأَخْبَرَنَا بِهِ قُتَيْبَةُ مَرَّةً أُخْرَى وَلَمْ يَذْكُرْ فِيهِ جَعْفَرَ بْنَ رَبِيعَةَ\hadithno{353}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that Umm Habibah asked the Messenger of Allah (ﷺ) about bleeding. 'Aishah said:"I saw her wash tub filled with blood." The Messenger of Allah (ﷺ) said to her: "Stop (praying) for as long as your period used to last, then perform Ghusl. And Qutayba told us about it again, and he did not mention Ja`far ibn Rabi`ah in it}}
\hadithdefcmd{nasai}{354}{أَنْبَأَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، قَالَ أَخْبَرَنِي عَنْ نَافِعٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ سَأَلَتِ امْرَأَةٌ النَّبِيَّ صلى الله عليه وسلم قَالَتْ إِنِّي أُسْتَحَاضُ فَلاَ أَطْهُرُ أَفَأَدَعُ الصَّلاَةَ قَالَ ‏ "‏ لاَ وَلَكِنْ دَعِي قَدْرَ تِلْكَ الأَيَّامِ وَاللَّيَالِي الَّتِي كُنْتِ تَحِيضِينَ فِيهَا ثُمَّ اغْتَسِلِي وَاسْتَثْفِرِي وَصَلِّي ‏"‏ ‏.‏\hadithno{354}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Umm Salamah said:"A woman asked the Prophet (ﷺ): 'I suffer from Istihadah and I never become pure; should I stop praying?' He said: 'No. Stop praying for the number of days and nights that you used to menstruate, then perform Ghusl, wrap a cloth around yourself, and pray}}
\hadithdefcmd{nasai}{355}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أُمِّ سَلَمَةَ، أَنَّ امْرَأَةً، كَانَتْ تُهَرَاقُ الدَّمَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم اسْتَفْتَتْ لَهَا أُمُّ سَلَمَةَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لِتَنْظُرْ عَدَدَ اللَّيَالِي وَالأَيَّامِ الَّتِي كَانَتْ تَحِيضُ مِنَ الشَّهْرِ قَبْلَ أَنْ يُصِيبَهَا الَّذِي أَصَابَهَا فَلْتَتْرُكِ الصَّلاَةَ قَدْرَ ذَلِكَ مِنَ الشَّهْرِ فَإِذَا خَلَّفَتْ ذَلِكَ فَلْتَغْتَسِلْ ثُمَّ لْتَسْتَثْفِرْ بِالثَّوْبِ ثُمَّ لْتُصَلِّي ‏"‏ ‏.‏\hadithno{355}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Salamah that a woman suffered from constant bleeding during the time of the Messenger of Allah (ﷺ), so Umm Salamah consulted the Prophet (ﷺ) for her. He said:"Let her count the number of nights and days that she used to menstruate each month before this happened to her, and let her stop praying for that period of time each month. Then when that is over let her perform Ghusl, then wrap a cloth around herself, and pray}}
\hadithdefcmd{nasai}{356}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ بْنِ دَاوُدَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا إِسْحَاقُ، - وَهُوَ ابْنُ بَكْرِ بْنِ مُضَرَ - قَالَ حَدَّثَنِي أَبِي، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ، - وَهُوَ ابْنُ أُسَامَةَ بْنِ الْهَادِ - عَنْ أَبِي بَكْرٍ، - وَهُوَ ابْنُ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ - عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ إِنَّ أُمَّ حَبِيبَةَ بِنْتَ جَحْشٍ الَّتِي كَانَتْ تَحْتَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَأَنَّهَا اسْتُحِيضَتْ لاَ تَطْهُرُ فَذُكِرَ شَأْنُهَا لِرَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَتْ بِالْحِيضَةِ وَلَكِنَّهَا رَكْضَةٌ مِنَ الرَّحِمِ لِتَنْظُرْ قَدْرَ قُرْئِهَا الَّتِي كَانَتْ تَحِيضُ لَهَا فَلْتَتْرُكِ الصَّلاَةَ ثُمَّ تَنْظُرْ مَا بَعْدَ ذَلِكَ فَلْتَغْتَسِلْ عِنْدَ كُلِّ صَلاَةٍ ‏"‏ ‏.‏\hadithno{356}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that Umm Habibah bint Jahsh who was married to 'Abdur-Rahman bin 'Awf suffered from Istihadah and did not become pure. Her situation was mentioned to the Messenger of Allah (ﷺ) and he said:"That is not menstruation, rather it is a kick in the womb, so let her work out the length of the menses that she used to have, and stop praying (for that period of time), then after that let her perform Ghusl for every for every prayer}}
\hadithdefcmd{nasai}{357}{أَخْبَرَنَا أَبُو مُوسَى، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ ابْنَةَ جَحْشٍ، كَانَتْ تُسْتَحَاضُ سَبْعَ سِنِينَ فَسَأَلَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لَيْسَتْ بِالْحَيْضَةِ إِنَّمَا هُوَ عِرْقٌ ‏"‏ ‏.‏ فَأَمَرَهَا أَنْ تَتْرُكَ الصَّلاَةَ قَدْرَ أَقْرَائِهَا وَحِيضَتِهَا وَتَغْتَسِلَ وَتُصَلِّيَ فَكَانَتْ تَغْتَسِلُ عِنْدَ كُلِّ صَلاَةٍ ‏.‏\hadithno{357}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that Umm Habibah bint Jahsh used to suffer from Istihadah for seven years. She asked the Prophet (ﷺ) and he said:"That is not menstruation, rather it is a vein. Tell her not to pray for the period of time that her period used to last, then let her perform Ghusl and pray." She used to perform Ghusl for every prayer}}
\hadithdefcmd{nasai}{358}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ، عَنِ الْمُنْذِرِ بْنِ الْمُغِيرَةِ، عَنْ عُرْوَةَ، أَنَّ فَاطِمَةَ بِنْتَ أَبِي حُبَيْشٍ، حَدَّثَتْهُ أَنَّهَا، أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَشَكَتْ إِلَيْهِ الدَّمَ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا ذَلِكِ عِرْقٌ فَانْظُرِي إِذَا أَتَاكِ قَرْؤُكِ فَلاَ تُصَلِّي وَإِذَا مَرَّ قَرْؤُكِ فَلْتَطَهَّرِي ثُمَّ صَلِّي مَا بَيْنَ الْقُرْءِ إِلَى الْقُرْءِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ قَدْ رَوَى هَذَا الْحَدِيثَ هِشَامُ بْنُ عُرْوَةَ عَنْ عُرْوَةَ وَلَمْ يَذْكُرْ فِيهِ مَا ذَكَرَ الْمُنْذِرُ ‏.‏\hadithno{358}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Urwah that Fatimah bint Abi Hubaish narrated that she came to the Messenger of Allah (ﷺ) and complained to him about bleeding. The Messenger of Allah (ﷺ) said to her:"That is a vein, so when your period comes, do not pray, and when your period is over, purify yourself and pray in between one period and the next." Abu 'Abdur-Rahman said: Hisham bin 'Urwah reported this Hadith from 'Urwah, and he did not mention what Al-Mundhir mentioned in it}}
\hadithdefcmd{nasai}{359}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدَةُ، وَوَكِيعٌ، وَأَبُو مُعَاوِيَةَ قَالُوا حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتْ فَاطِمَةُ بِنْتُ أَبِي حُبَيْشٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنِّي امْرَأَةٌ أُسْتَحَاضُ فَلاَ أَطْهُرُ أَفَأَدَعُ الصَّلاَةَ قَالَ ‏ "‏ لاَ إِنَّمَا ذَلِكِ عِرْقٌ وَلَيْسَتْ بِالْحِيضَةِ فَإِذَا أَقْبَلَتِ الْحِيضَةُ فَدَعِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْسِلِي عَنْكِ الدَّمَ وَصَلِّي ‏"‏ ‏.‏\hadithno{359}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated that 'Aishah said:Fatimah bint Abi Hubaish came to the Messenger of Allah (ﷺ) and said: "I am a woman who suffers from Istihadah and I never become pure. Should I stop praying?" He said: "No, that is a vein, it is not menstruation. When your period comes, stop praying, and when it goes, wash the blood from yourself and pray}}
\hadithdefcmd{nasai}{360}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، مُسْتَحَاضَةً عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم قِيلَ لَهَا إِنَّهُ عِرْقٌ عَانِدٌ وَأُمِرَتْ أَنْ تُؤَخِّرَ الظُّهْرَ وَتُعَجِّلَ الْعَصْرَ وَتَغْتَسِلَ لَهُمَا غُسْلاً وَاحِدًا وَتُؤَخِّرَ الْمَغْرِبَ وَتُعَجِّلَ الْعِشَاءَ وَتَغْتَسِلَ لَهُمَا غُسْلاً وَاحِدًا وَتَغْتَسِلَ لِصَلاَةِ الصُّبْحِ غُسْلاً وَاحِدًا ‏.‏\hadithno{360}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that a woman who suffered from Istihadah at the time of the Messenger of Allah (ﷺ) was told that it was a stubborn vein (i.e., one that would not stop bleeding). She was told to delay Zuhr and bring 'Asr forward, and to perform one Ghusl for both, and to delay Maghrib and bring 'Isha' forward, and to perform one Ghusl for both, and she would perform one Ghusl for Subh}}
\hadithdefcmd{nasai}{361}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنِ الْقَاسِمِ، عَنْ زَيْنَبَ بِنْتِ جَحْشٍ، قَالَتْ قُلْتُ لِلنَّبِيِّ صلى الله عليه وسلم إِنَّهَا مُسْتَحَاضَةٌ ‏.‏ فَقَالَ ‏ "‏ تَجْلِسُ أَيَّامَ أَقْرَائِهَا ثُمَّ تَغْتَسِلُ وَتُؤَخِّرُ الظُّهْرَ وَتُعَجِّلُ الْعَصْرَ وَتَغْتَسِلُ وَتُصَلِّي وَتُؤَخِّرُ الْمَغْرِبَ وَتُعَجِّلُ الْعِشَاءَ وَتَغْتَسِلُ وَتُصَلِّيهِمَا جَمِيعًا وَتَغْتَسِلُ لِلْفَجْرِ ‏"‏ ‏.‏\hadithno{361}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Zainab bint Jahsh said:"I said to the Prophet (ﷺ) that I was suffering from Istihadah. He said: 'Do not pray during the days of your period, then perform Ghusl and delay Zuhr and bring Maghrib and bring 'Isha' forward and pray them together, and perform Ghusl for Fajr}}
\hadithdefcmd{nasai}{362}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، - وَهُوَ ابْنُ عَلْقَمَةَ بْنِ وَقَّاصٍ - عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ فَاطِمَةَ بِنْتِ أَبِي حُبَيْشٍ، أَنَّهَا كَانَتْ تُسْتَحَاضُ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ دَمُ الْحَيْضِ - فَإِنَّهُ دَمٌ أَسْوَدُ يُعْرَفُ - فَأَمْسِكِي عَنِ الصَّلاَةِ وَإِذَا كَانَ الآخَرُ فَتَوَضَّئِي فَإِنَّمَا هُوَ عِرْقٌ ‏"‏ ‏.‏ قَالَ مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ هَذَا مِنْ كِتَابِهِ ‏.‏\hadithno{362}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Fatimah bint Abi Hubaish that she suffered from Istihadah and the Messenger of Allah (ﷺ) said to her:"If it is menstrual blood then it is blood that is black and recognizable, so stop prying, and if it is other than that then perform Wudu', for it is just a vein}}
\hadithdefcmd{nasai}{363}{وَأَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، مِنْ حِفْظِهِ قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ فَاطِمَةَ بِنْتَ أَبِي حُبَيْشٍ، كَانَتْ تُسْتَحَاضُ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ دَمَ الْحَيْضِ دَمٌ أَسْوَدُ يُعْرَفُ فَإِذَا كَانَ ذَلِكِ فَأَمْسِكِي عَنِ الصَّلاَةِ فَإِذَا كَانَ الآخَرُ فَتَوَضَّئِي وَصَلِّي ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ قَدْ رَوَى هَذَا الْحَدِيثَ غَيْرُ وَاحِدٍ وَلَمْ يَذْكُرْ أَحَدٌ مِنْهُمْ مَا ذَكَرَ ابْنُ أَبِي عَدِيٍّ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{363}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Aishah that Fatimah bint Abi Hubaish suffered from Istihadah. The Messenger of Allah (ﷺ) said to her:"Menstrual blood is blood that is black and recognizable, so if it is like that, then stop praying, and if it is otherwise, then perform Wudu' and pray." Abu 'Abdur-Rahman said: Others reported this Hadith, and none of them mentioned what Ibn 'Adi mentioned, and Allah knows best}}
\hadithdefcmd{nasai}{364}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، عَنْ حَمَّادٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتِ اسْتُحِيضَتْ فَاطِمَةُ بِنْتُ أَبِي حُبَيْشٍ فَسَأَلَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أُسْتَحَاضُ فَلاَ أَطْهُرُ أَفَأَدَعُ الصَّلاَةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا ذَلِكِ عِرْقٌ وَلَيْسَتْ بِالْحِيضَةِ فَإِذَا أَقْبَلَتِ الْحِيضَةُ فَدَعِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْسِلِي عَنْكِ الدَّمَ وَتَوَضَّئِي وَصَلِّي فَإِنَّمَا ذَلِكِ عِرْقٌ وَلَيْسَتْ بِالْحَيْضَةِ ‏"‏ ‏.‏ قِيلَ لَهُ فَالْغُسْلُ قَالَ ‏"‏ وَذَلِكَ لاَ يَشُكُّ فِيهِ أَحَدٌ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ قَدْ رَوَى هَذَا الْحَدِيثَ غَيْرُ وَاحِدٍ عَنْ هِشَامِ بْنِ عُرْوَةَ وَلَمْ يَذْكُرْ فِيهِ ‏"‏ وَتَوَضَّئِي ‏"‏ ‏.‏ غَيْرُ حَمَّادٍ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{364}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"Fatimah bint Abi Hubaish suffered from Istihadah and she asked the Prophet (ﷺ): 'O Messenger of Allah, I suffer from Istihadah and I do not become pure; should I stop praying?' The Messenger of Allah (ﷺ) said: 'That is a vein and is not menstruation. When your period comes, stop praying, and when it goes wash the traces of blood from yourself and do Wudu'. That is a vein and is not menstruation.'" It was said to him (one of the narrators): "What about Ghusl?" He said: "No one is in doubt about that}}
\hadithdefcmd{nasai}{365}{أَخْبَرَنَا سُوَيْدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ فَاطِمَةَ بِنْتَ أَبِي حُبَيْشٍ، أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أُسْتَحَاضُ فَلاَ أَطْهُرُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا ذَلِكِ عِرْقٌ وَلَيْسَتْ بِالْحِيضَةِ فَإِذَا أَقْبَلَتِ الْحِيضَةُ فَأَمْسِكِي عَنِ الصَّلاَةِ وَإِذَا أَدْبَرَتْ فَاغْسِلِي عَنْكِ الدَّمَ وَصَلِّي ‏"‏ ‏.‏\hadithno{365}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"Fatimah bint Abi Hubaish said to the Messenger of Allah (ﷺ): 'O Messenger of Allah (ﷺ), I do not become pure. Should I stop praying?' The Messenger of Allah (ﷺ) said: 'That is a vein and is not menstruation. When your period comes, stop praying, and when it has passed, then wash the blood from yourself and pray}}
\hadithdefcmd{nasai}{366}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَتْ فَاطِمَةُ بِنْتُ أَبِي حُبَيْشٍ لِرَسُولِ اللَّهِ صلى الله عليه وسلم لاَ أَطْهُرُ أَفَأَدَعُ الصَّلاَةَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا ذَلِكِ عِرْقٌ وَلَيْسَتْ بِالْحِيضَةِ فَإِذَا أَقْبَلَتِ الْحِيضَةُ فَدَعِي الصَّلاَةَ وَإِذَا ذَهَبَ قَدْرُهَا فَاغْسِلِي عَنْكِ الدَّمَ وَصَلِّي ‏"‏ ‏.‏\hadithno{366}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:Fatimah bint Abi Hubaish said to the Messenger of Allah (ﷺ): "O Messenger of Allah (ﷺ), I do not become pure. Should I stop praying?" The Messenger of Allah (ﷺ) said: "That is a vein and is not menstruation. When your period comes, stop praying, and when the same amount of time as your regular period has passed, then wash the blood from yourself and pray}}
\hadithdefcmd{nasai}{367}{أَخْبَرَنَا أَبُو الأَشْعَثِ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ سَمِعْتُ هِشَامًا، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ بِنْتَ أَبِي حُبَيْشٍ، قَالَتْ يَا رَسُولَ اللَّهِ إِنِّي لاَ أَطْهُرُ أَفَأَتْرُكُ الصَّلاَةَ قَالَ ‏"‏ لاَ إِنَّمَا هُوَ عِرْقٌ ‏"‏ ‏.‏ قَالَ خَالِدٌ وَفِيمَا قَرَأْتُ عَلَيْهِ ‏"‏ وَلَيْسَتْ بِالْحِيضَةِ فَإِذَا أَقْبَلَتِ الْحِيضَةُ فَدَعِي الصَّلاَةَ وَإِذَا أَدْبَرَتْ فَاغْسِلِي عَنْكِ الدَّمَ ثُمَّ صَلِّي ‏"‏ ‏.‏\hadithno{367}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the daughter of Abu Hubaish said:"O Messenger of Allah, I do not become pure, so should I stop praying? He said: "no, that is a vein." - (One of the narrators) Khalid said, in what I read from him - "and it is not menstruation, so when your period comes, stop praying, and when it goes, wash the blood from yourself and pray}}
\hadithdefcmd{nasai}{368}{أَخْبَرَنَا عَمْرُو بْنُ زُرَارَةَ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، قَالَ قَالَتْ أُمُّ عَطِيَّةَ كُنَّا لاَ نَعُدُّ الصُّفْرَةَ وَالْكُدْرَةَ شَيْئًا ‏.‏\hadithno{368}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Muhammad said:"Umm 'Atiyah said: 'We used not to regard yellowish and brownish discharge as anything important}}
\hadithdefcmd{nasai}{369}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ كَانَتِ الْيَهُودُ إِذَا حَاضَتِ الْمَرْأَةُ مِنْهُمْ لَمْ يُؤَاكِلُوهُنَّ وَلاَ يُشَارِبُوهُنَّ وَلاَ يُجَامِعُوهُنَّ فِي الْبُيُوتِ فَسَأَلُوا النَّبِيَّ صلى الله عليه وسلم فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَيَسْأَلُونَكَ عَنِ الْمَحِيضِ قُلْ هُوَ أَذًى ‏\}‏ الآيَةَ فَأَمَرَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُؤَاكِلُوهُنَّ وَيُشَارِبُوهُنَّ وَيُجَامِعُوهُنَّ فِي الْبُيُوتِ وَأَنْ يَصْنَعُوا بِهِنَّ كُلَّ شَىْءٍ مَا خَلاَ الْجِمَاعَ ‏.‏ فَقَالَتِ الْيَهُودُ مَا يَدَعُ رَسُولُ اللَّهِ صلى الله عليه وسلم شَيْئًا مِنْ أَمْرِنَا إِلاَّ خَالَفَنَا ‏.‏ فَقَامَ أُسَيْدُ بْنُ حُضَيْرٍ وَعَبَّادُ بْنُ بِشْرٍ فَأَخْبَرَا رَسُولَ اللَّهِ صلى الله عليه وسلم قَالاَ أَنُجَامِعُهُنَّ فِي الْمَحِيضِ فَتَمَعَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم تَمَعُّرًا شَدِيدًا حَتَّى ظَنَنَّا أَنَّهُ قَدْ غَضِبَ فَقَامَا فَاسْتَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم هَدِيَّةَ لَبَنٍ فَبَعَثَ فِي آثَارِهِمَا فَرَدَّهُمَا فَسَقَاهُمَا فَعُرِفَ أَنَّهُ لَمْ يَغْضَبْ عَلَيْهِمَا ‏.‏\hadithno{369}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"When one of their womenfolk menstruated, the Jews would not eat or drink with them, or mix with them in their houses. They (the Companions) asked the Prophet of Allah (ﷺ) about that, and Allah, the Mighty and Sublime, revealed the Ayah: They ask you concerning menstruation. Say: "That is an Adha (a harmful thing).[2] So the Messenger of Allah (ﷺ) commanded them to eat and drink with them (menstruating women) and to mix them in their houses, and to do everything with them except intercourse. The Jews said: 'The Messenger of Allah (ﷺ) does not leave anything of our affairs except he goes against it.' Usaid bin Hudair and 'Abbad bin Bishr went and told the Messenger of Allah (ﷺ) and they said: 'Should we have intercourse with them when they are menstruating?' The expression of the Messenger of Allah (ﷺ) changed greatly until we thought he was angry with them, and they left. Then the Messenger of Allah (ﷺ) received a gift of milk, so he sent someone to bring them back and he gave them some to drink, so we knew that he was not angry with them." [1] Al-Baqarah 2:222 [2] Al-Baqarah 2:}}
\hadithdefcmd{nasai}{370}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، قَالَ حَدَّثَنِي الْحَكَمُ، عَنْ عَبْدِ الْحَمِيدِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الرَّجُلِ يَأْتِي امْرَأَتَهُ وَهِيَ حَائِضٌ يَتَصَدَّقُ بِدِينَارٍ أَوْ بِنِصْفِ دِينَارٍ ‏.‏\hadithno{370}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Abbas from the Prophet (ﷺ) concerning a man who has had intercourse with his wife while she was menstruating:"Let him give a Dinar or half a Dinar in charity}}
\hadithdefcmd{nasai}{371}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، ح وَأَنْبَأَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي ح، وَأَنْبَأَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، - وَهُوَ ابْنُ الْحَارِثِ - قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ، أَنَّ زَيْنَبَ بِنْتَ أَبِي سَلَمَةَ، حَدَّثَتْهُ أَنَّ أُمَّ سَلَمَةَ حَدَّثَتْهَا قَالَتْ، بَيْنَمَا أَنَا مُضْطَجِعَةٌ، مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ حِضْتُ فَانْسَلَلْتُ فَأَخَذْتُ ثِيَابَ حَيْضَتِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَفِسْتِ ‏"‏ ‏.‏ قُلْتُ نَعَمْ فَدَعَانِي فَاضْطَجَعْتُ مَعَهُ فِي الْخَمِيلَةِ ‏.‏ وَاللَّفْظُ لِعُبَيْدِ اللَّهِ بْنِ سَعِيدٍ ‏.‏\hadithno{371}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umm Salamah narrated:"While I was lying down with the Messenger of Allah (ﷺ) under a blanket, my period came so I slipped away and put on the clothes I used to wear when I was menstruating. The Messenger of Allah (ﷺ) said: 'Are you menstruating?' I said: 'Yes.' Then he called me to lie down with him under the blanket." This is the wording of 'Ubaidullah bin Sa'eed.[1] [1] That is, one of the narrators in one of the chains, as the author reported it through different chains, as he did when it preceded, see No}}
\hadithdefcmd{nasai}{372}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، عَنْ جَابِرِ بْنِ صُبْحٍ، قَالَ سَمِعْتُ خِلاَسًا، يُحَدِّثُ عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم نَبِيتُ فِي الشِّعَارِ الْوَاحِدِ وَأَنَا طَامِثٌ حَائِضٌ فَإِنْ أَصَابَهُ مِنِّي شَىْءٌ غَسَلَ مَكَانَهُ لَمْ يَعْدُهُ ثُمَّ صَلَّى فِيهِ ثُمَّ يَعُودُ فَإِنْ أَصَابَهُ مِنِّي شَىْءٌ فَعَلَ مِثْلَ ذَلِكَ غَسَلَ مَكَانَهُ لَمْ يَعْدُهُ وَصَلَّى فِيهِ ‏.‏\hadithno{372}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) and I would sleep under a single blanket when I was menstruating. If anything got on him from me, he would wash that spot and no more, and pray in it, then come back. If anything got on it again from me, he would do likewise and no more, and he would pray in it}}
\hadithdefcmd{nasai}{373}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ شُرَحْبِيلَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُ إِحْدَانَا إِذَا كَانَتْ حَائِضًا أَنْ تَشُدَّ إِزَارَهَا ثُمَّ يُبَاشِرُهَا ‏.‏\hadithno{373}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) would tell one of us, if she was menstruating, to tie her Izar (waist wrap) tightly then he would fondle her}}
\hadithdefcmd{nasai}{374}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ إِحْدَانَا إِذَا حَاضَتْ أَمَرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تَتَّزِرَ ثُمَّ يُبَاشِرُهَا ‏.‏\hadithno{374}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"If one of us was menstruating, the Messenger of Allah (ﷺ) would tell her to put on an Izar (waist wrap) then he would fondle her}}
\hadithdefcmd{nasai}{375}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنِ ابْنِ عَيَّاشٍ، - وَهُوَ أَبُو بَكْرٍ - عَنْ صَدَقَةَ بْنِ سَعِيدٍ، ثُمَّ ذَكَرَ كَلِمَةً مَعْنَاهَا حَدَّثَنَا جُمَيْعُ بْنُ عُمَيْرٍ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ مَعَ أُمِّي وَخَالَتِي فَسَأَلَتَاهَا كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْنَعُ إِذَا حَاضَتْ إِحْدَاكُنَّ قَالَتْ كَانَ يَأْمُرُنَا إِذَا حَاضَتْ إِحْدَانَا أَنْ تَتَّزِرَ بِإِزَارٍ وَاسِعٍ ثُمَّ يَلْتَزِمُ صَدْرَهَا وَثَدْيَيْهَا ‏.‏\hadithno{375}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Jumai' bin 'Umair said:"I entered upon 'Aishah with my mother and maternal aunt, and we asked her what the Prophet (ﷺ) used to do when one of (his wives) was menstruating. She said: He would tell us, when when of us menstruated, to wrap a wide Izar around herself then he would embrace her chest and breasts}}
\hadithdefcmd{nasai}{376}{أَخْبَرَنَا الْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، عَنْ يُونُسَ، وَاللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ حَبِيبٍ، مَوْلَى عُرْوَةَ عَنْ بُدَيَّةَ، - وَكَانَ اللَّيْثُ يَقُولُ نَدَبَةَ - مَوْلاَةِ مَيْمُونَةَ عَنْ مَيْمُونَةَ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُبَاشِرُ الْمَرْأَةَ مِنْ نِسَائِهِ وَهِيَ حَائِضٌ إِذَا كَانَ عَلَيْهَا إِزَارٌ يَبْلُغُ أَنْصَافَ الْفَخِذَيْنِ وَالرُّكْبَتَيْنِ فِي حَدِيثِ اللَّيْثِ تَحْتَجِزُ بِهِ ‏.‏\hadithno{376}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Maimunah said:"The Messenger of Allah (ﷺ) would fondle one of his wives when she was menstruating, if she wore and Izar (waist wrap) that reached halfway down her thighs or to her knees}}
\hadithdefcmd{nasai}{377}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدِ بْنِ جَمِيلِ بْنِ طَرِيفٍ، قَالَ أَنْبَأَنَا يَزِيدُ بْنُ الْمِقْدَامِ بْنِ شُرَيْحِ بْنِ هَانِئٍ، عَنْ أَبِيهِ، عَنْ شُرَيْحٍ، أَنَّهُ سَأَلَ عَائِشَةَ هَلْ تَأْكُلُ الْمَرْأَةُ مَعَ زَوْجِهَا وَهِيَ طَامِثٌ قَالَتْ نَعَمْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُونِي فَآكُلُ مَعَهُ وَأَنَا عَارِكٌ كَانَ يَأْخُذُ الْعَرْقَ فَيُقْسِمُ عَلَىَّ فِيهِ فَأَعْتَرِقُ مِنْهُ ثُمَّ أَضَعُهُ فَيَأْخُذُهُ فَيَعْتَرِقُ مِنْهُ وَيَضَعُ فَمَهُ حَيْثُ وَضَعْتُ فَمِي مِنَ الْعَرْقِ وَيَدْعُو بِالشَّرَابِ فَيُقْسِمُ عَلَىَّ فِيهِ مِنْ قَبْلِ أَنْ يَشْرَبَ مِنْهُ فَآخُذُهُ فَأَشْرَبُ مِنْهُ ثُمَّ أَضَعُهُ فَيَأْخُذُهُ فَيَشْرَبُ مِنْهُ وَيَضَعُ فَمَهُ حَيْثُ وَضَعْتُ فَمِي مِنَ الْقَدَحِ ‏.‏\hadithno{377}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Shuraih that he asked 'Aishah:"Can a woman eat with her husband while she is menstruating?' She said: 'Yes. The Messenger of Allah (ﷺ) would call me to eat with him while I was menstruating. He would take a piece of bone on which some bits of meat were left and insist that I take it first, so I would nibble a little from it, then put it down. Then he would take it and nibble from it, and he would put his mouth where mine had been on the bone. Then he would call for a drink and insist that I take it first before he drank from it. So I would take it and drink from it, then put it down, then he would take it and drink from it, putting his mouth where mine had been on the cup}}
\hadithdefcmd{nasai}{378}{أَخْبَرَنِي أَيُّوبُ بْنُ مُحَمَّدٍ الْوَزَّانُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنِ الأَعْمَشِ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَضَعُ فَاهُ عَلَى الْمَوْضِعِ الَّذِي أَشْرَبُ مِنْهُ وَيَشْرَبُ مِنْ فَضْلِ شَرَابِي وَأَنَا حَائِضٌ ‏.‏\hadithno{378}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Al-Miqdam bin Shuraih, from his father, that 'Aishah said:"The Messenger of Allah (ﷺ) would put his mouth on the place from which I had drunk, and he would drink from my leftovers when I was menstruating}}
\hadithdefcmd{nasai}{379}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مِسْعَرٍ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عَائِشَةَ، تَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُنَاوِلُنِي الإِنَاءَ فَأَشْرَبُ مِنْهُ وَأَنَا حَائِضٌ ثُمَّ أُعْطِيهِ فَيَتَحَرَّى مَوْضِعَ فَمِي فَيَضَعُهُ عَلَى فِيهِ ‏.‏\hadithno{379}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Al-Miqdam bin Shuraih that his father said:"I heard 'Aishah say: 'The Messenger of Allah (ﷺ) would give me the vessel and I would drink from it, when I was menstruating, then I would give it to him and he would look for the place where I had put my mouth and put that to his mouth}}
\hadithdefcmd{nasai}{380}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا مِسْعَرٌ، وَسُفْيَانُ، عَنِ الْمِقْدَامِ بْنِ شُرَيْحٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَشْرَبُ مِنَ الْقَدَحِ وَأَنَا حَائِضٌ، فَأُنَاوِلُهُ النَّبِيَّ صلى الله عليه وسلم فَيَضَعُ فَاهُ عَلَى مَوْضِعِ فِيَّ فَيَشْرَبُ مِنْهُ وَأَتَعَرَّقُ مِنَ الْعَرْقِ وَأَنَا حَائِضٌ فَأُنَاوِلُهُ النَّبِيَّ صلى الله عليه وسلم فَيَضَعُ فَاهُ عَلَى مَوْضِعِ فِيَّ ‏.‏\hadithno{380}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"I would drink when I was menstruating, then I would hand it to the Prophet (ﷺ), and he would put his mouth where mine had been and drink. And I would nibble at a bone on which some bits of meat were left when I was menstruating, then I would give it to the Prophet (ﷺ) and he would put his mouth where my mouth had been}}
\hadithdefcmd{nasai}{381}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ حُجْرٍ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَأْسُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي حِجْرِ إِحْدَانَا وَهِيَ حَائِضٌ وَهُوَ يَقْرَأُ الْقُرْآنَ ‏.‏\hadithno{381}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The head of the Messenger of Allah (ﷺ) would rest in the lap of one of us when she was menstruating, and he would recite Qur'an}}
\hadithdefcmd{nasai}{382}{أَخْبَرَنَا عَمْرُو بْنُ زُرَارَةَ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ مُعَاذَةَ الْعَدَوِيَّةِ، قَالَتْ سَأَلَتِ امْرَأَةٌ عَائِشَةَ أَتَقْضِي الْحَائِضُ الصَّلاَةَ فَقَالَتْ أَحَرُورِيَّةٌ أَنْتِ قَدْ كُنَّا نَحِيضُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلاَ نَقْضِي وَلاَ نُؤْمَرُ بِقَضَاءٍ ‏.‏\hadithno{382}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Mu'adhah Al-'Adawiyyah said:"A woman asked 'Aishah: 'Should a menstruating woman make up the Salah she misses? She said: 'Are you a Haruri? [1] We used to menstruate during the time of Allah's Messenger (ﷺ) but we did not make up the missed Salah nor were we commanded to do so.'" [1] Meaning are you one of the Khawarij. Harura is a place associated with a group of the Khawarij}}
\hadithdefcmd{nasai}{383}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، قَالَ قَالَ أَبُو هُرَيْرَةَ بَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ إِذْ قَالَ ‏"‏ يَا عَائِشَةُ نَاوِلِينِي الثَّوْبَ ‏"‏ ‏.‏ فَقَالَتْ إِنِّي لاَ أُصَلِّي ‏.‏ فَقَالَ ‏"‏ إِنَّهُ لَيْسَ فِي يَدِكِ ‏"‏ ‏.‏ فَنَاوَلَتْهُ ‏.‏\hadithno{383}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah said:"While the Messenger of Allah (ﷺ) was in the Masjid, he said: 'O 'Aishah, hand me the garment.' She said: 'I am not praying.' He said: 'It is not in your hand.' So she gave it to him}}
\hadithdefcmd{nasai}{384}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ عَبِيدَةَ، عَنِ الأَعْمَشِ، ح وَأَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ ثَابِتِ بْنِ عُبَيْدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، قَالَ قَالَتْ عَائِشَةُ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَاوِلِينِي الْخُمْرَةَ مِنَ الْمَسْجِدِ ‏"‏ ‏.‏ فَقُلْتُ إِنِّي حَائِضٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَيْسَتْ حَيْضَتُكِ فِي يَدِكِ ‏"‏ ‏.‏\hadithno{384}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah (ﷺ) said: 'Give me the mat from the MAsjid.' She said: 'I am menstruating.' The Messenger of Allah (ﷺ) said: 'Your menstruation is not in your hand}}
\hadithdefcmd{nasai}{384p2}{قَالَ إِسْحَاقُ أَنْبَأَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{384.2}\hadithtrans{(Another chain) with similarity}}
\hadithdefcmd{nasai}{385}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، عَنْ مَنْبُوذٍ، عَنْ أُمِّهِ، أَنَّ مَيْمُونَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَضَعُ رَأْسَهُ فِي حِجْرِ إِحْدَانَا فَيَتْلُو الْقُرْآنَ وَهِيَ حَائِضٌ وَتَقُومُ إِحْدَانَا بِخُمْرَتِهِ إِلَى الْمَسْجِدِ فَتَبْسُطُهَا وَهِيَ حَائِضٌ ‏.‏\hadithno{385}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Maimunah said:"The Messenger of Allah (ﷺ) used to lay his head in the lap of one of us and recite Qur'an while she was menstruating, and one of us would take the mat to the Masjid and spread it out when she was menstruating}}
\hadithdefcmd{nasai}{386}{أَخْبَرَنَا نَصْرُ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا كَانَتْ تُرَجِّلُ رَأْسَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهِيَ حَائِضٌ وَهُوَ مُعْتَكِفٌ فَيُنَاوِلُهَا رَأْسَهُ وَهِيَ فِي حُجْرَتِهَا ‏.‏\hadithno{386}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that she used to comb the hair of the Messenger of Allah (ﷺ) when she was menstruating and he was performing I'tikaf. He would put his head out to her while she was in her room}}
\hadithdefcmd{nasai}{387}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنِي سُفْيَانُ، قَالَ حَدَّثَنِي مَنْصُورٌ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُدْنِي إِلَىَّ رَأْسَهُ وَهُوَ مُعْتَكِفٌ فَأَغْسِلُهُ وَأَنَا حَائِضٌ ‏.‏\hadithno{387}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Prophet (ﷺ) would put his head out while he was performing I'tikaf and I would wash it, while I was menstruating}}
\hadithdefcmd{nasai}{388}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا الْفُضَيْلُ، - وَهُوَ ابْنُ عِيَاضٍ - عَنِ الأَعْمَشِ، عَنْ تَمِيمِ بْنِ سَلَمَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُخْرِجُ رَأْسَهُ مِنَ الْمَسْجِدِ وَهُوَ مُعْتَكِفٌ فَأَغْسِلُهُ وَأَنَا حَائِضٌ ‏.‏\hadithno{388}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah:"The Messenger of Allah (ﷺ) used to put his head out of the Masjid while he was performing I'tikaf, and I would wash it, while I was menstruating}}
\hadithdefcmd{nasai}{389}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أُرَجِّلُ رَأْسَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا حَائِضٌ ‏.‏\hadithno{389}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"I used to comb the hair of the Messenger of Allah (ﷺ) while I was menstruating}}
\hadithdefcmd{nasai}{390}{أَخْبَرَنَا عَمْرُو بْنُ زُرَارَةَ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ حَفْصَةَ، قَالَتْ كَانَتْ أُمُّ عَطِيَّةَ لاَ تَذْكُرُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِلاَّ قَالَتْ بِأَبَا ‏.‏ فَقُلْتُ أَسَمِعْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ كَذَا وَكَذَا قَالَتْ نَعَمْ بِأَبَا قَالَ ‏ "‏ لِتَخْرُجِ الْعَوَاتِقُ وَذَوَاتُ الْخُدُورِ وَالْحُيَّضُ فَيَشْهَدْنَ الْخَيْرَ وَدَعْوَةَ الْمُسْلِمِينَ وَتَعْتَزِلِ الْحُيَّضُ الْمُصَلَّى ‏"‏ ‏.‏\hadithno{390}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Hafsah said:"Umm 'Atiyah would never mention the Messenger of Allah (ﷺ) without saying: 'May my father be ransomed for him.' I said: 'Did you hear the Messenger of Allah (ﷺ) say such and such?' And she said: 'Yes, may my father be ransomed for him.' He said: 'Let the mature girls, virgins staying in seclusion, and menstruating woman go out and witness the good occasions and the supplications of the Muslims, but let the menstruating women keep away from the prayer place}}
\hadithdefcmd{nasai}{391}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، قَالَ أَخْبَرَنِي مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّ صَفِيَّةَ بِنْتَ حُيَىٍّ قَدْ حَاضَتْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَعَلَّهَا تَحْبِسُنَا أَلَمْ تَكُنْ طَافَتْ مَعَكُنَّ بِالْبَيْتِ ‏"‏ ‏.‏ قَالَتْ بَلَى ‏.‏ قَالَ ‏"‏ فَاخْرُجْنَ ‏"‏ ‏.‏\hadithno{391}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that she said to the Messenger of Allah (ﷺ):"Safiyyah bint Huyai began menstruating." The Messenger of Allah (ﷺ) said: "Perhaps she has detained us. Did she not circumambulate the House with you?" She said: "Yes." He said: "Then you can leave}}
\hadithdefcmd{nasai}{392}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، فِي حَدِيثِ أَسْمَاءَ بِنْتِ عُمَيْسٍ حِينَ نُفِسَتْ بِذِي الْحُلَيْفَةِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لأَبِي بَكْرٍ ‏ "‏ مُرْهَا أَنْ تَغْتَسِلَ وَتُهِلَّ ‏"‏ ‏.‏\hadithno{392}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir bin 'Abdullah concerning Asma' bint Umais that when she gave birth at Dhul-Hulaifah, the Messenger of Allah (ﷺ) said to Abu Bakr:"Tell her to perform Ghusl and (begin the Talbiyah)}}
\hadithdefcmd{nasai}{393}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ عَبْدِ الْوَارِثِ، عَنْ حُسَيْنٍ، - يَعْنِي الْمُعَلِّمَ - عَنِ ابْنِ بُرَيْدَةَ، عَنْ سَمُرَةَ، قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى أُمِّ كَعْبٍ مَاتَتْ فِي نِفَاسِهَا فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الصَّلاَةِ فِي وَسَطِهَا ‏.‏\hadithno{393}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Samurah said:"I offered the funeral prayer with the Messenger of Allah (ﷺ) for Umm Ka'b who had died during childbirth, and during the prayer, the Messenger of Allah (ﷺ) stood at her middle}}
\hadithdefcmd{nasai}{394}{أَخْبَرَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، قَالَ حَدَّثَنَا حَمَّادٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، - وَكَانَتْ تَكُونُ فِي حِجْرِهَا - أَنَّ امْرَأَةً اسْتَفْتَتِ النَّبِيَّ صلى الله عليه وسلم عَنْ دَمِ الْحَيْضِ يُصِيبُ الثَّوْبَ فَقَالَ ‏ "‏ حُتِّيهِ وَاقْرُصِيهِ وَانْضَحِيهِ وَصَلِّي فِيهِ ‏"‏ ‏.‏\hadithno{394}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Asma' bint Abi Bakr that a woman asked the Messenger of Allah (ﷺ) about menstrual blood that gets on clothes. He said:"Scratch it, then rub it with water, then sprinkle water over it, and pray in it}}
\hadithdefcmd{nasai}{395}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي أَبُو الْمِقْدَامِ، ثَابِتٌ الْحَدَّادُ عَنْ عَدِيِّ بْنِ دِينَارٍ، قَالَ سَمِعْتُ أُمَّ قَيْسٍ بِنْتَ مِحْصَنٍ، أَنَّهَا سَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ دَمِ الْحِيضَةِ يُصِيبُ الثَّوْبَ قَالَ ‏ "‏ حُكِّيهِ بِضِلَعٍ وَاغْسِلِيهِ بِمَاءٍ وَسِدْرٍ ‏"‏ ‏.‏\hadithno{395}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Adi bin Dinar said:"I heard Umm Qais bint Mihsan say that she asked the Messenger of Allah (ﷺ) about menstrual blood that gets on one's clothes. He said: 'Scratch it with a stick and wash it with water and lotus leaves}}
