% Auto-generated chapter 35 for bukhari
% Hadiths in this chapter: 16

\hadithdefcmd{bukhari}{2239}{حَدَّثَنَا عَمْرُو بْنُ زُرَارَةَ، أَخْبَرَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، أَخْبَرَنَا ابْنُ أَبِي نَجِيحٍ، عَنْ عَبْدِ اللَّهِ بْنِ كَثِيرٍ، عَنْ أَبِي الْمِنْهَالِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ، وَالنَّاسُ يُسْلِفُونَ فِي الثَّمَرِ الْعَامَ وَالْعَامَيْنِ ـ أَوْ قَالَ عَامَيْنِ أَوْ ثَلاَثَةً‏.‏ شَكَّ إِسْمَاعِيلُ ـ فَقَالَ ‏ "‏ مَنْ سَلَّفَ فِي تَمْرٍ فَلْيُسْلِفْ فِي كَيْلٍ مَعْلُومٍ، وَوَزْنٍ مَعْلُومٍ ‏"‏‏.‏\hadithno{2239}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) came to Medina and the people used to pay in advance the price of fruits to be delivered within one or two years. (The sub-narrator is in doubt whether it was one to two years or two to three years.) The Prophet (ﷺ) said, "Whoever pays money in advance for dates (to be delivered later) should pay it for known specified weight and measure (of the dates)}}
\hadithdefcmd{bukhari}{2239p2}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا إِسْمَاعِيلُ، عَنِ ابْنِ أَبِي نَجِيحٍ، بِهَذَا ‏ "‏ فِي كَيْلٍ مَعْلُومٍ وَوَزْنٍ مَعْلُومٍ ‏"‏‏.‏\hadithno{2239.2}\hadithtrans{Narrated Ibn Abi Najih:as above, mentioning only specific measure}}
\hadithdefcmd{bukhari}{2240}{حَدَّثَنَا صَدَقَةُ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، أَخْبَرَنَا ابْنُ أَبِي نَجِيحٍ، عَنْ عَبْدِ اللَّهِ بْنِ كَثِيرٍ، عَنْ أَبِي الْمِنْهَالِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ، وَهُمْ يُسْلِفُونَ بِالتَّمْرِ السَّنَتَيْنِ وَالثَّلاَثَ، فَقَالَ ‏ "‏ مَنْ أَسْلَفَ فِي شَىْءٍ فَفِي كَيْلٍ مَعْلُومٍ وَوَزْنٍ مَعْلُومٍ، إِلَى أَجَلٍ مَعْلُومٍ ‏"‏‏.‏\hadithno{2240}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) came to Medina and the people used to pay in advance the price of dates to be delivered within two or three years. He said (to them), "Whoever pays in advance the price of a thing to be delivered later should pay it for a specified measure at specified weight for a specified period}}
\hadithdefcmd{bukhari}{2240p2}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي ابْنُ أَبِي نَجِيحٍ، وَقَالَ، ‏ "‏ فَلْيُسْلِفْ فِي كَيْلٍ مَعْلُومٍ إِلَى أَجَلٍ مَعْلُومٍ ‏"‏‏.‏\hadithno{2240.2}\hadithtrans{Narrated Ibn Abi Najih:as above, saying, "He should pay the price in advance for a specified measure and for a specified period}}
\hadithdefcmd{bukhari}{2241}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ عَبْدِ اللَّهِ بْنِ كَثِيرٍ، عَنْ أَبِي الْمِنْهَالِ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ قَدِمَ النَّبِيُّ صلى الله عليه وسلم وَقَالَ ‏ "‏ فِي كَيْلٍ مَعْلُومٍ وَوَزْنٍ مَعْلُومٍ إِلَى أَجَلٍ مَعْلُومٍ ‏"‏‏.‏\hadithno{2241}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) came (to Medina) and he told the people (regarding the payment of money in advance that they should pay it) for a known specified measure and a known specified weight and a known specified period}}
\hadithdefcmd{bukhari}{2243}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنِ ابْنِ أَبِي الْمُجَالِدِ،‏.‏ وَحَدَّثَنَا يَحْيَى، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ أَبِي الْمُجَالِدِ، حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي مُحَمَّدٌ،، أَوْ عَبْدُ اللَّهِ بْنُ أَبِي الْمُجَالِدِ قَالَ اخْتَلَفَ عَبْدُ اللَّهِ بْنُ شَدَّادِ بْنِ الْهَادِ وَأَبُو بُرْدَةَ فِي السَّلَفِ، فَبَعَثُونِي إِلَى ابْنِ أَبِي أَوْفَى ـ رضى الله عنه ـ فَسَأَلْتُهُ فَقَالَ إِنَّا كُنَّا نُسْلِفُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ، فِي الْحِنْطَةِ، وَالشَّعِيرِ وَالزَّبِيبِ، وَالتَّمْرِ‏.‏ وَسَأَلْتُ ابْنَ أَبْزَى فَقَالَ مِثْلَ ذَلِكَ‏.‏\hadithno{2243}\hadithtrans{Narrated Shu`ba:Muhammad or `Abdullah bin Abu Al-Mujalid said, "Abdullah bin Shaddad and Abu Burda differed regarding As-Salam, so they sent me to Ibn Abi `Aufa and I asked him about it. He replied, 'In the lifetime of Allah's Messenger (ﷺ), Abu Bakr and `Umar, we used to pay in advance the prices of wheat, barley, dried grapes and dates to be delivered later. I also asked Ibn Abza and he, too, replied as above}}
\hadithdefcmd{bukhari}{2244}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الشَّيْبَانِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي الْمُجَالِدِ، قَالَ بَعَثَنِي عَبْدُ اللَّهِ بْنُ شَدَّادٍ وَأَبُو بُرْدَةَ إِلَى عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى ـ رضى الله عنهما ـ فَقَالاَ سَلْهُ هَلْ كَانَ أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم فِي عَهْدِ النَّبِيِّ صلى الله عليه وسلم يُسْلِفُونَ فِي الْحِنْطَةِ قَالَ عَبْدُ اللَّهِ كُنَّا نُسْلِفُ نَبِيطَ أَهْلِ الشَّأْمِ فِي الْحِنْطَةِ، وَالشَّعِيرِ، وَالزَّيْتِ، فِي كَيْلٍ مَعْلُومٍ، إِلَى أَجَلٍ مَعْلُومٍ‏.‏ قُلْتُ إِلَى مَنْ كَانَ أَصْلُهُ عِنْدَهُ قَالَ مَا كُنَّا نَسْأَلُهُمْ عَنْ ذَلِكَ‏.‏ ثُمَّ بَعَثَانِي إِلَى عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى فَسَأَلْتُهُ فَقَالَ كَانَ أَصْحَابُ النَّبِيِّ صلى الله عليه وسلم يُسْلِفُونَ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ نَسْأَلْهُمْ أَلَهُمْ حَرْثٌ أَمْ لاَ\hadithno{2244}\hadithtrans{Narrated Muhammad bin Al-Mujalid:`Abdullah bin Shaddad and Abu Burda sent me to `Abdullah bin Abi `Aufa and told me to ask `Abdullah whether the people in the lifetime of the Prophet (ﷺ) used to pay in advance for wheat (to be delivered later). `Abdullah replied, "We used to pay in advance to the peasants of Sham for wheat, barley and olive oil of a known specified measure to be delivered in a specified period." I asked (him), "Was the price paid (in advance) to those who had the things to be delivered later?" `Abdullah bin `Aufa replied, "We did not use to ask them about that." Then they sent me to `Abdur Rahman bin Abza and I asked him. He replied, "The companions of the Prophet (ﷺ) used to practice Salam in the lifetime of the Prophet; and we did not use to ask them whether they had standing crops or not}}
\hadithdefcmd{bukhari}{2245}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنِ الشَّيْبَانِيِّ، عَنْ مُحَمَّدِ بْنِ أَبِي مُجَالِدٍ، بِهَذَا وَقَالَ فَنُسْلِفُهُمْ فِي الْحِنْطَةِ وَالشَّعِيرِ‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ الْوَلِيدِ عَنْ سُفْيَانَ حَدَّثَنَا الشَّيْبَانِيُّ وَقَالَ وَالزَّيْتِ‏.‏ حَدَّثَنَا قُتَيْبَةُ حَدَّثَنَا جَرِيرٌ عَنِ الشَّيْبَانِيِّ وَقَالَ فِي الْحِنْطَةِ وَالشَّعِيرِ وَالزَّبِيبِ‏.‏\hadithno{2245}\hadithtrans{Narrated Muhammad bin Abi Al-Mujalid:as above (446) and said, "We used to pay them in advance for wheat and barley (to be delivered later). Narrated Ash-Shaibani--"And also for oil." Narrated Ash-Shaibani: who said "We used to pay in advance for wheat barley and dried grapes}}
\hadithdefcmd{bukhari}{2246}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنَا عَمْرٌو، قَالَ سَمِعْتُ أَبَا الْبَخْتَرِيِّ الطَّائِيَّ، قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ السَّلَمِ، فِي النَّخْلِ‏.‏ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ بَيْعِ النَّخْلِ، حَتَّى يُؤْكَلَ مِنْهُ وَحَتَّى يُوزَنَ‏.‏ فَقَالَ الرَّجُلُ وَأَىُّ شَىْءٍ يُوزَنُ قَالَ رَجُلٌ إِلَى جَانِبِهِ حَتَّى يُحْرَزَ‏.‏ وَقَالَ مُعَاذٌ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، قَالَ أَبُو الْبَخْتَرِيِّ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ نَهَى النَّبِيُّ صلى الله عليه وسلم مِثْلَهُ‏.‏\hadithno{2246}\hadithtrans{Narrated Abu Bakhtari at-Tai:I asked Ibn `Abbas about Salam for (the fruits of) date-palms. He replied "The Prophet (ﷺ) forbade the sale of dates on the trees till they became fit for eating and could be weighed." A man asked what to be weighed (as the dates were still on the trees). Another man sitting beside Ibn `Abbas replied, "Till they are cut and stored." Narrated Abu Al-Bakhtari: I heard Ibn `Abbas (saying) that the Prophet (ﷺ) forbade ... etc. as above}}
\hadithdefcmd{bukhari}{2248}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، عَنْ أَبِي الْبَخْتَرِيِّ، قَالَ سَأَلْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ عَنِ السَّلَمِ، فِي النَّخْلِ فَقَالَ نُهِيَ عَنْ بَيْعِ النَّخْلِ، حَتَّى يَصْلُحَ، وَعَنْ بَيْعِ الْوَرِقِ، نَسَاءً بِنَاجِزٍ‏.‏ وَسَأَلْتُ ابْنَ عَبَّاسٍ عَنِ السَّلَمِ، فِي النَّخْلِ، فَقَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ بَيْعِ النَّخْلِ حَتَّى يُؤْكَلَ مِنْهُ، أَوْ يَأْكُلَ مِنْهُ، وَحَتَّى يُوزَنَ‏.‏\hadithno{2248}\hadithtrans{Narrated Abu Al-Bakhtari:I asked Ibn `Umar about Salam (the fruits of) date-palms. He replied, "The Prophet (ﷺ) forbade the sale of dates till their benefit becomes evident and fit for eating and also the sale of silver (for gold) on credit." I asked Ibn `Abbas about Salam for dates and he replied, "The Prophet (ﷺ) forbade the sale of dates till they were fit for eating and could be estimated}}
\hadithdefcmd{bukhari}{2250}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، عَنْ أَبِي الْبَخْتَرِيِّ، سَأَلْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ عَنِ السَّلَمِ، فِي النَّخْلِ فَقَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ بَيْعِ الثَّمَرِ حَتَّى يَصْلُحَ، وَنَهَى عَنِ الْوَرِقِ بِالذَّهَبِ نَسَاءً بِنَاجِزٍ‏.‏ وَسَأَلْتُ ابْنَ عَبَّاسٍ فَقَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنْ بَيْعِ النَّخْلِ حَتَّى يَأْكُلَ أَوْ يُؤْكَلَ، وَحَتَّى يُوزَنَ‏.‏ قُلْتُ وَمَا يُوزَنُ قَالَ رَجُلٌ عِنْدَهُ حَتَّى يُحْرَزَ‏.‏\hadithno{2250}\hadithtrans{Narrated Abu Al-Bakhtari:I asked Ibn `Umar about Salam for dates. Ibn `Umar replied, "The Prophet (ﷺ) forbade the sale (of the fruits) of date-palms until they were fit for eating and also forbade the sale of silver for gold on credit." I also asked Ibn `Abbas about it. Ibn `Abbas replied, "The Prophet (ﷺ) forbade the sale of dates till they were fit for eating, and could be weighed." I asked him, "What is to be weighed (as the dates are on the trees)?" A man sitting by Ibn `Abbas said, "It means till they are cut and stored}}
\hadithdefcmd{bukhari}{2251}{حَدَّثَنَا مُحَمَّدٌ، حَدَّثَنَا يَعْلَى، حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتِ اشْتَرَى رَسُولُ اللَّهِ صلى الله عليه وسلم طَعَامًا مِنْ يَهُودِيٍّ بِنَسِيئَةٍ، وَرَهَنَهُ دِرْعًا لَهُ مِنْ حَدِيدٍ‏.‏\hadithno{2251}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) bought some foodstuff (barley) from a Jew on credit and mortgaged his iron armor to him (the armor stands for a guarantor)}}
\hadithdefcmd{bukhari}{2252}{حَدَّثَنِي مُحَمَّدُ بْنُ مَحْبُوبٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الأَعْمَشُ، قَالَ تَذَاكَرْنَا عِنْدَ إِبْرَاهِيمَ الرَّهْنَ فِي السَّلَفِ فَقَالَ حَدَّثَنِي الأَسْوَدُ عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم اشْتَرَى مِنْ يَهُودِيٍّ طَعَامًا إِلَى أَجَلٍ مَعْلُومٍ، وَارْتَهَنَ مِنْهُ دِرْعًا مِنْ حَدِيدٍ‏.‏\hadithno{2252}\hadithtrans{Narrated Al-A`mash:We argued at Ibrahim's dwelling place about mortgaging in Salam. He said, "Aisha said, 'The Prophet (ﷺ) bought some foodstuff from a Jew on credit and the payment was to be made by a definite period, and he mortgaged his iron armor to him}}
\hadithdefcmd{bukhari}{2253}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ عَبْدِ اللَّهِ بْنِ كَثِيرٍ، عَنْ أَبِي الْمِنْهَالِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ وَهُمْ يُسْلِفُونَ فِي الثِّمَارِ السَّنَتَيْنِ وَالثَّلاَثَ، فَقَالَ ‏"‏ أَسْلِفُوا فِي الثِّمَارِ فِي كَيْلٍ مَعْلُومٍ إِلَى أَجَلٍ مَعْلُومٍ ‏"‏‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ الْوَلِيدِ حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا ابْنُ أَبِي نَجِيحٍ، وَقَالَ، ‏"‏ فِي كَيْلٍ مَعْلُومٍ وَوَزْنٍ مَعْلُومٍ ‏"‏‏.‏\hadithno{2253}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) came to Medina and the people used to pay in advance the prices of fruits to be delivered within two to three years. The Prophet (ﷺ) said (to them), "Buy fruits by paying their prices in advance on condition that the fruits are to be delivered to you according to a fixed specified measure within a fixed specified period." Ibn Najih said, " ... by specified measure and specified weight}}
\hadithdefcmd{bukhari}{2255}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا سُفْيَانُ، عَنْ سُلَيْمَانَ الشَّيْبَانِيِّ، عَنْ مُحَمَّدِ بْنِ أَبِي مُجَالِدٍ، قَالَ أَرْسَلَنِي أَبُو بُرْدَةَ وَعَبْدُ اللَّهِ بْنُ شَدَّادٍ إِلَى عَبْدِ الرَّحْمَنِ بْنِ أَبْزَى وَعَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى فَسَأَلْتُهُمَا عَنِ السَّلَفِ،‏.‏ فَقَالاَ كُنَّا نُصِيبُ الْمَغَانِمَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَكَانَ يَأْتِينَا أَنْبَاطٌ مِنْ أَنْبَاطِ الشَّأْمِ فَنُسْلِفُهُمْ فِي الْحِنْطَةِ وَالشَّعِيرِ وَالزَّبِيبِ إِلَى أَجَلٍ مُسَمًّى‏.‏ قَالَ قُلْتُ أَكَانَ لَهُمْ زَرْعٌ، أَوْ لَمْ يَكُنْ لَهُمْ زَرْعٌ قَالاَ مَا كُنَّا نَسْأَلُهُمْ عَنْ ذَلِكَ‏.‏\hadithno{2255}\hadithtrans{Narrated Muhammad bin Abi Al-Mujalid:Abu Burda and `Abdullah bin Shaddad sent me to `Abdur Rahman bin Abza and `Abdullah bin Abi `Aufa to ask them about the Salaf (Salam). They said, "We used to get war booty while we were with Allah's Messenger (ﷺ) and when the peasants of Sham came to us we used to pay them in advance for wheat, barley, and oil to be delivered within a fixed period." I asked them, "Did the peasants own standing crops or not?" They replied, "We never asked them about it}}
\hadithdefcmd{bukhari}{2256}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، أَخْبَرَنَا جُوَيْرِيَةُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ كَانُوا يَتَبَايَعُونَ الْجَزُورَ إِلَى حَبَلِ الْحَبَلَةِ، فَنَهَى النَّبِيُّ صلى الله عليه وسلم عَنْهُ‏.‏ فَسَّرَهُ نَافِعٌ أَنْ تُنْتَجَ النَّاقَةُ مَا فِي بَطْنِهَا‏.‏\hadithno{2256}\hadithtrans{Narrated `Abdullah:The people used to sell camels on the basis of Habal-al-Habala. The Prophet (ﷺ) forbade such sale. Nafi` explained Habal-al-Habala by saying. "The camel is to be delivered to the buyer after the she-camel gives birth}}
