% Auto-generated chapter 44 for bukhari
% Hadiths in this chapter: 15

\hadithdefcmd{bukhari}{2410}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، قَالَ عَبْدُ الْمَلِكِ بْنُ مَيْسَرَةَ أَخْبَرَنِي قَالَ سَمِعْتُ النَّزَّالَ، سَمِعْتُ عَبْدَ اللَّهِ، يَقُولُ سَمِعْتُ رَجُلاً، قَرَأَ آيَةً سَمِعْتُ مِنَ النَّبِيِّ، صلى الله عليه وسلم خِلاَفَهَا، فَأَخَذْتُ بِيَدِهِ، فَأَتَيْتُ بِهِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ كِلاَكُمَا مُحْسِنٌ ‏"‏‏.‏ قَالَ شُعْبَةُ أَظُنُّهُ قَالَ ‏"‏ لاَ تَخْتَلِفُوا فَإِنَّ مَنْ كَانَ قَبْلَكُمُ اخْتَلَفُوا فَهَلَكُوا ‏"‏‏.‏\hadithno{2410}\hadithtrans{Narrated `Abdullah:I heard a man reciting a verse (of the Holy Qur'an) but I had heard the Prophet (ﷺ) reciting it differently. So, I caught hold of the man by the hand and took him to Allah's Messenger (ﷺ) who said, "Both of you are right." Shu`ba, the sub-narrator said, "I think he said to them, "Don't differ, for the nations before you differed and perished (because of their differences)}}
\hadithdefcmd{bukhari}{2411}{حَدَّثَنَا يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، وَعَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ اسْتَبَّ رَجُلاَنِ رَجُلٌ مِنَ الْمُسْلِمِينَ وَرَجُلٌ مِنَ الْيَهُودِ، قَالَ الْمُسْلِمُ وَالَّذِي اصْطَفَى مُحَمَّدًا عَلَى الْعَالَمِينَ، فَقَالَ الْيَهُودِيُّ وَالَّذِي اصْطَفَى مُوسَى عَلَى الْعَالَمِينَ‏.‏ فَرَفَعَ الْمُسْلِمُ يَدَهُ عِنْدَ ذَلِكَ فَلَطَمَ وَجْهَ الْيَهُودِيِّ، فَذَهَبَ الْيَهُودِيُّ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرَهُ بِمَا كَانَ مِنْ أَمْرِهِ وَأَمْرِ الْمُسْلِمِ، فَدَعَا النَّبِيُّ صلى الله عليه وسلم الْمُسْلِمَ فَسَأَلَهُ عَنْ ذَلِكَ، فَأَخْبَرَهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تُخَيِّرُونِي عَلَى مُوسَى، فَإِنَّ النَّاسَ يَصْعَقُونَ يَوْمَ الْقِيَامَةِ، فَأَصْعَقُ مَعَهُمْ، فَأَكُونُ أَوَّلَ مَنْ يُفِيقُ، فَإِذَا مُوسَى بَاطِشٌ جَانِبَ الْعَرْشِ، فَلاَ أَدْرِي أَكَانَ فِيمَنْ صَعِقَ فَأَفَاقَ قَبْلِي، أَوْ كَانَ مِمَّنِ اسْتَثْنَى اللَّهُ ‏"‏‏.‏\hadithno{2411}\hadithtrans{Narrated Abu Huraira:Two persons, a Muslim and a Jew, quarreled. The Muslim said, "By Him Who gave Muhammad superiority over all the people! The Jew said, "By Him Who gave Moses superiority over all the people!" At that the Muslim raised his hand and slapped the Jew on the face. The Jew went to the Prophet and informed him of what had happened between him and the Muslim. The Prophet (ﷺ) sent for the Muslim and asked him about it. The Muslim informed him of the event. The Prophet (ﷺ) said, "Do not give me superiority over Moses, for on the Day of Resurrection all the people will fall unconscious and I will be one of them, but I will. be the first to gain consciousness, and will see Moses standing and holding the side of the Throne (of Allah). I will not know whether (Moses) has also fallen unconscious and got up before me, or Allah has exempted him from that stroke}}
\hadithdefcmd{bukhari}{2412}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ جَاءَ يَهُودِيٌّ، فَقَالَ يَا أَبَا الْقَاسِمِ ضَرَبَ وَجْهِي رَجُلٌ مِنْ أَصْحَابِكَ‏.‏ فَقَالَ ‏"‏ مَنْ ‏"‏‏.‏ قَالَ رَجُلٌ مِنَ الأَنْصَارِ‏.‏ قَالَ ‏"‏ ادْعُوهُ ‏"‏‏.‏ فَقَالَ ‏"‏ أَضَرَبْتَهُ ‏"‏‏.‏ قَالَ سَمِعْتُهُ بِالسُّوقِ يَحْلِفُ وَالَّذِي اصْطَفَى مُوسَى عَلَى الْبَشَرِ‏.‏ قُلْتُ أَىْ خَبِيثُ، عَلَى مُحَمَّدٍ صلى الله عليه وسلم فَأَخَذَتْنِي غَضْبَةٌ ضَرَبْتُ وَجْهَهُ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ تُخَيِّرُوا بَيْنَ الأَنْبِيَاءِ، فَإِنَّ النَّاسَ يَصْعَقُونَ يَوْمَ الْقِيَامَةِ، فَأَكُونُ أَوَّلَ مَنْ تَنْشَقُّ عَنْهُ الأَرْضُ، فَإِذَا أَنَا بِمُوسَى آخِذٌ بِقَائِمَةٍ مِنْ قَوَائِمِ الْعَرْشِ، فَلاَ أَدْرِي أَكَانَ فِيمَنْ صَعِقَ، أَمْ حُوسِبَ بِصَعْقَةِ الأُولَى ‏"‏‏.‏\hadithno{2412}\hadithtrans{Narrated Abu Sa`id Al-Khudri:While Allah's Messenger (ﷺ) was sitting, a Jew came and said, "O Abul Qasim! One of your companions has slapped me on my face." The Prophet (ﷺ) asked who that was. He replied that he was one of the Ansar. The Prophet (ﷺ) sent for him, and on his arrival, he asked him whether he had beaten the Jew. He (replied in the affirmative and) said, "I heard him taking an oath in the market saying, 'By Him Who gave Moses superiority over all the human beings.' I said, 'O wicked man! (Has Allah given Moses superiority) even over Muhammad I became furious and slapped him over his face." The Prophet (ﷺ) said, "Do not give a prophet superiority over another, for on the Day of Resurrection all the people will fall unconscious and I will be the first to emerge from the earth, and will see Moses standing and holding one of the legs of the Throne. I will not know whether Moses has fallen unconscious or the first unconsciousness was sufficient for him}}
\hadithdefcmd{bukhari}{2413}{حَدَّثَنَا مُوسَى، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ أَنَّ يَهُودِيًّا، رَضَّ رَأْسَ جَارِيَةٍ بَيْنَ حَجَرَيْنِ، قِيلَ مَنْ فَعَلَ هَذَا بِكِ أَفُلاَنٌ، أَفُلاَنٌ حَتَّى سُمِّيَ الْيَهُودِيُّ فَأَوْمَتْ بِرَأْسِهَا، فَأُخِذَ الْيَهُودِيُّ فَاعْتَرَفَ، فَأَمَرَ بِهِ النَّبِيُّ صلى الله عليه وسلم فَرُضَّ رَأْسُهُ بَيْنَ حَجَرَيْنِ‏.‏\hadithno{2413}\hadithtrans{Narrated Anas:A Jew crushed the head of a girl between two stones. The girl was asked who had crushed her head, and some names were mentioned before her, and when the name of the Jew was mentioned, she nodded agreeing. The Jew was captured and when he confessed, the Prophet (ﷺ) ordered that his head be crushed between two stones}}
\hadithdefcmd{bukhari}{2414}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ كَانَ رَجُلٌ يُخْدَعُ فِي الْبَيْعِ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا بَايَعْتَ فَقُلْ لاَ خِلاَبَةَ ‏"‏‏.‏ فَكَانَ يَقُولُهُ‏.‏\hadithno{2414}\hadithtrans{Narrated Ibn `Umar:A man was often cheated in buying. The Prophet (ﷺ) said to him, "When you buy something, say (to the seller), No cheating." The man used to say so thenceforward}}
\hadithdefcmd{bukhari}{2415}{حَدَّثَنَا عَاصِمُ بْنُ عَلِيٍّ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ ـ رضى الله عنه ـ أَنَّ رَجُلاً، أَعْتَقَ عَبْدًا لَهُ، لَيْسَ لَهُ مَالٌ غَيْرُهُ، فَرَدَّهُ النَّبِيُّ صلى الله عليه وسلم، فَابْتَاعَهُ مِنْهُ نُعَيْمُ بْنُ النَّحَّامِ‏.‏\hadithno{2415}\hadithtrans{Narrated Jabir:A man manumitted a slave and he had no other property than that, so the Prophet (ﷺ) canceled the manumission (and sold the slave for him). Nu'aim bin Al-Nahham bought the slave from him}}
\hadithdefcmd{bukhari}{2416}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ حَلَفَ عَلَى يَمِينٍ وَهْوَ فِيهَا فَاجِرٌ لِيَقْتَطِعَ بِهَا مَالَ امْرِئٍ مُسْلِمٍ لَقِيَ اللَّهَ وَهْوَ عَلَيْهِ غَضْبَانُ ‏"‏‏.‏ قَالَ فَقَالَ الأَشْعَثُ فِيَّ وَاللَّهِ كَانَ ذَلِكَ، كَانَ بَيْنِي وَبَيْنَ رَجُلٍ مِنَ الْيَهُودِ أَرْضٌ فَجَحَدَنِي، فَقَدَّمْتُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلَكَ بَيِّنَةٌ ‏"‏‏.‏ قُلْتُ لاَ‏.‏ قَالَ فَقَالَ لِلْيَهُودِيِّ ‏"‏ احْلِفْ ‏"‏‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِذًا يَحْلِفَ، وَيَذْهَبَ بِمَالِي، فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏إِنَّ الَّذِينَ يَشْتَرُونَ بِعَهْدِ اللَّهِ وَأَيْمَانِهِمْ ثَمَنًا قَلِيلاً‏\}‏ إِلَى آخِرِ الآيَةِ‏.‏\hadithno{2416}\hadithtrans{Narrated `Abdullah bin Mas`ud:Allah's Messenger (ﷺ) said, "Whoever takes a false oath so as to take the property of a Muslim (illegally) will meet Allah while He will be angry with him." Al-Ash'ath said: By Allah, that saying concerned me. I had common land with a Jew, and the Jew later on denied my ownership, so I took him to the Prophet who asked me whether I had a proof of my ownership. When I replied in the negative, the Prophet asked the Jew to take an oath. I said, "O Allah's Messenger (ﷺ)! He will take an oath and deprive me of my property." So, Allah revealed the following verse: "Verily! Those who purchase a little gain at the cost of Allah's covenant and their oaths}}
\hadithdefcmd{bukhari}{2418}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ كَعْبٍ ـ رضى الله عنه ـ أَنَّهُ تَقَاضَى ابْنَ أَبِي حَدْرَدٍ دَيْنًا كَانَ لَهُ عَلَيْهِ فِي الْمَسْجِدِ، فَارْتَفَعَتْ أَصْوَاتُهُمَا حَتَّى سَمِعَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهْوَ فِي بَيْتِهِ، فَخَرَجَ إِلَيْهِمَا، حَتَّى كَشَفَ سِجْفَ حُجْرَتِهِ فَنَادَى ‏"‏ يَا كَعْبُ ‏"‏‏.‏ قَالَ لَبَّيْكَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ ضَعْ مِنْ دَيْنِكَ هَذَا ‏"‏‏.‏ فَأَوْمَأَ إِلَيْهِ، أَىِ الشَّطْرَ‏.‏ قَالَ لَقَدْ فَعَلْتُ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ قُمْ فَاقْضِهِ ‏"‏‏.‏\hadithno{2418}\hadithtrans{Narrated `Abdullah bin Ka`b bin Malik:Ka`b demanded his debt back from Ibn Abi Hadrad in the Mosque and their voices grew louder till Allah's Messenger (ﷺ) heard them while he was in his house. He came out to them raising the curtain of his room and addressed Ka`b, "O Ka`b!" Ka`b replied, "Labaik, O Allah's Messenger (ﷺ)." (He said to him), "Reduce your debt to one half," gesturing with his hand. Ka`b said, "I have done so, O Allah's Apostle!" On that the Prophet (ﷺ) said to Ibn Abi Hadrad, "Get up and repay the debt, to him}}
\hadithdefcmd{bukhari}{2419}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدٍ الْقَارِيِّ، أَنَّهُ قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ يَقُولُ سَمِعْتُ هِشَامَ بْنَ حَكِيمِ بْنِ حِزَامٍ، يَقْرَأُ سُورَةَ الْفُرْقَانِ عَلَى غَيْرِ مَا أَقْرَؤُهَا، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَقْرَأَنِيهَا، وَكِدْتُ أَنْ أَعْجَلَ عَلَيْهِ، ثُمَّ أَمْهَلْتُهُ حَتَّى انْصَرَفَ، ثُمَّ لَبَّبْتُهُ بِرِدَائِهِ فَجِئْتُ بِهِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ إِنِّي سَمِعْتُ هَذَا يَقْرَأُ عَلَى غَيْرِ مَا أَقْرَأْتَنِيهَا، فَقَالَ لِي ‏"‏ أَرْسِلْهُ ‏"‏‏.‏ ثُمَّ قَالَ لَهُ ‏"‏ اقْرَأْ ‏"‏‏.‏ فَقَرَأَ‏.‏ قَالَ ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏‏.‏ ثُمَّ قَالَ لِي ‏"‏ اقْرَأْ ‏"‏‏.‏ فَقَرَأْتُ فَقَالَ ‏"‏ هَكَذَا أُنْزِلَتْ‏.‏ إِنَّ الْقُرْآنَ أُنْزِلَ عَلَى سَبْعَةِ أَحْرُفٍ فَاقْرَءُوا مِنْهُ مَا تَيَسَّرَ ‏"‏‏.‏\hadithno{2419}\hadithtrans{Narrated `Umar bin Al-Khattab:I heard Hisham bin Hakim bin Hizam reciting Surat-al-Furqan in a way different to that of mine. Allah's Messenger (ﷺ) had taught it to me (in a different way). So, I was about to quarrel with him (during the prayer) but I waited till he finished, then I tied his garment round his neck and seized him by it and brought him to Allah's Messenger (ﷺ) and said, "I have heard him reciting Surat-al-Furqan in a way different to the way you taught it to me." The Prophet (ﷺ) ordered me to release him and asked Hisham to recite it. When he recited it, Allah's Apostle said, "It was revealed in this way." He then asked me to recite it. When I recited it, he said, "It was revealed in this way. The Qur'an has been revealed in seven different ways, so recite it in the way that is easier for you}}
\hadithdefcmd{bukhari}{2420}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَقَدْ هَمَمْتُ أَنْ آمُرَ بِالصَّلاَةِ فَتُقَامَ ثُمَّ أُخَالِفَ إِلَى مَنَازِلِ قَوْمٍ لاَ يَشْهَدُونَ الصَّلاَةَ فَأُحَرِّقَ عَلَيْهِمْ ‏"‏‏.‏\hadithno{2420}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "No doubt, I intended to order somebody to pronounce the Iqama of the (compulsory congregational) prayer and then I would go to the houses of those who do not attend the prayer and burn their houses over them}}
\hadithdefcmd{bukhari}{2421}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ عَبْدَ بْنَ زَمْعَةَ، وَسَعْدَ بْنَ أَبِي وَقَّاصٍ، اخْتَصَمَا إِلَى النَّبِيِّ صلى الله عليه وسلم فِي ابْنِ أَمَةِ زَمْعَةَ فَقَالَ سَعْدٌ يَا رَسُولَ اللَّهِ أَوْصَانِي أَخِي إِذَا قَدِمْتُ أَنْ أَنْظُرَ ابْنَ أَمَةِ زَمْعَةَ فَأَقْبِضَهُ، فَإِنَّهُ ابْنِي‏.‏ وَقَالَ عَبْدُ بْنُ زَمْعَةَ أَخِي وَابْنُ أَمَةِ أَبِي، وُلِدَ عَلَى فِرَاشِ أَبِي‏.‏ فَرَأَى النَّبِيُّ صلى الله عليه وسلم شَبَهًا بَيِّنًا فَقَالَ ‏ "‏ هُوَ لَكَ يَا عَبْدُ بْنَ زَمْعَةَ، الْوَلَدُ لِلْفِرَاشِ، وَاحْتَجِبِي مِنْهُ يَا سَوْدَةُ ‏"‏‏.‏\hadithno{2421}\hadithtrans{Narrated Aisha:Abu bin Zam`a and Sa`d bin Abi Waqqas carried the case of their claim of the (ownership) of the son of a slave-girl of Zam`a before the Prophet. Sa`d said, "O Allah's Messenger (ﷺ)! My brother, before his death, told me that when I would return (to Mecca), I should search for the son of the slave-girl of Zam`a and take him into my custody as he was his son." 'Abu bin Zam`a said, 'He is my brother and the son of the slave-girl of my father, and was born on my father's bed." The Prophet (ﷺ) noticed a resemblance between `Utba and the boy but he said, "O 'Abu bin Zam`a! You will get this boy, as the son goes to the owner of the bed. You, Sauda, screen yourself from the boy}}
\hadithdefcmd{bukhari}{2422}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنهما ـ يَقُولُ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْلاً قِبَلَ نَجْدٍ، فَجَاءَتْ بِرَجُلٍ مِنْ بَنِي حَنِيفَةَ يُقَالُ لَهُ ثُمَامَةُ بْنُ أُثَالٍ سَيِّدُ أَهْلِ الْيَمَامَةِ، فَرَبَطُوهُ بِسَارِيَةٍ مِنْ سَوَارِي الْمَسْجِدِ، فَخَرَجَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا عِنْدَكَ يَا ثُمَامَةُ ‏"‏‏.‏ قَالَ عِنْدِي يَا مُحَمَّدُ خَيْرٌ‏.‏ فَذَكَرَ الْحَدِيثَ قَالَ ‏"‏ أَطْلِقُوا ثُمَامَةَ ‏"‏‏.‏\hadithno{2422}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) sent horsemen to Najd and they arrested and brought a man called Thumama bin Uthal, the chief of Yamama, and they fastened him to one of the pillars of the Mosque. When Allah's Apostle came up to him; he asked, "What have you to say, O Thumama?" He replied, "I have good news, O Muhammad!" Abu Huraira narrated the whole narration which ended with the order of the Prophet "Release him}}
\hadithdefcmd{bukhari}{2423}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ بَعَثَ النَّبِيُّ صلى الله عليه وسلم خَيْلاً قِبَلَ نَجْدٍ، فَجَاءَتْ بِرَجُلٍ مِنْ بَنِي حَنِيفَةَ يُقَالُ لَهُ ثُمَامَةُ بْنُ أُثَالٍ فَرَبَطُوهُ بِسَارِيَةٍ مِنْ سَوَارِي الْمَسْجِدِ‏.‏\hadithno{2423}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) sent some horsemen to Najd and they arrested and brought a man called Thumama bin Uthal from the tribe of Bani Hanifa, and they fastened him to one of the pillars of the Mosque}}
\hadithdefcmd{bukhari}{2424}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، حَدَّثَنَا جَعْفَرُ بْنُ رَبِيعَةَ،‏.‏ وَقَالَ غَيْرُهُ حَدَّثَنِي اللَّيْثُ، قَالَ حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ الأَنْصَارِيِّ، عَنْ كَعْبِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ كَانَ لَهُ عَلَى عَبْدِ اللَّهِ بْنِ أَبِي حَدْرَدٍ الأَسْلَمِيِّ دَيْنٌ، فَلَقِيَهُ فَلَزِمَهُ، فَتَكَلَّمَا حَتَّى ارْتَفَعَتْ أَصْوَاتُهُمَا، فَمَرَّ بِهِمَا النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ يَا كَعْبُ ‏"‏‏.‏ وَأَشَارَ بِيَدِهِ كَأَنَّهُ يَقُولُ النِّصْفَ، فَأَخَذَ نِصْفَ مَا عَلَيْهِ وَتَرَكَ نِصْفًا‏.‏\hadithno{2424}\hadithtrans{Narrated `Abdullah bin Ka`b bin Malik Al-Ansari from Ka`b bin Malik:That `Abdullah bin Abi Hadrad Al-Aslami owed him some debt. Ka`b met him and caught hold of him and they started talking and their voices grew loudest. The Prophet (ﷺ) passed by them and addressed Ka`b, pointing out to him to reduce the debt to one half. So, Ka`b got one half of the debt and exempted the debtor from the other half}}
\hadithdefcmd{bukhari}{2425}{حَدَّثَنَا إِسْحَاقُ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرِ بْنِ حَازِمٍ، أَخْبَرَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ خَبَّابٍ، قَالَ كُنْتُ قَيْنًا فِي الْجَاهِلِيَّةِ وَكَانَ لِي عَلَى الْعَاصِ بْنِ وَائِلٍ دَرَاهِمُ، فَأَتَيْتُهُ أَتَقَاضَاهُ فَقَالَ لاَ أَقْضِيكَ حَتَّى تَكْفُرَ بِمُحَمَّدٍ، فَقُلْتُ لاَ وَاللَّهِ لاَ أَكْفُرُ بِمُحَمَّدٍ صلى الله عليه وسلم حَتَّى يُمِيتَكَ اللَّهُ ثُمَّ يَبْعَثَكَ‏.‏ قَالَ فَدَعْنِي حَتَّى أَمُوتَ ثُمَّ أُبْعَثَ فَأُوتَى مَالاً وَوَلَدًا، ثُمَّ أَقْضِيَكَ‏.‏ فَنَزَلَتْ ‏\{‏أَفَرَأَيْتَ الَّذِي كَفَرَ بِآيَاتِنَا وَقَالَ لأُوتَيَنَّ مَالاً وَوَلَدًا‏\}‏ الآيَةَ‏.‏\hadithno{2425}\hadithtrans{Narrated Khabbab:I was a blacksmith In the Pre-Islamic period of ignorance, and 'Asi bin Wail owed me some money. I went to him to demand it, but he said to me, "I will not pay you unless you reject faith in Muhammad." I replied, "By Allah, I will never disbelieve Muhammad till Allah lets you die and then resurrects you." He said, "Then wait till I die and come to life again, for then I will be given property and offspring and will pay your right." So, thus revelation came: "Have you seen him who disbelieved in Our signs and yet says, 'I will be given property and offspring?}}
