% Auto-generated chapter 4 for malik
% Hadiths in this chapter: 3

\hadithdefcmd{malik}{222}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَحَدَكُمْ إِذَا قَامَ يُصَلِّي جَاءَهُ الشَّيْطَانُ فَلَبَسَ عَلَيْهِ حَتَّى لاَ يَدْرِي كَمْ صَلَّى فَإِذَا وَجَدَ ذَلِكَ أَحَدُكُمْ فَلْيَسْجُدْ سَجْدَتَيْنِ وَهُوَ جَالِسٌ ‏"‏ ‏.‏\hadithno{222}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Abu Salama ibn Abdar-Rahman ibn Awf from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "When you stand in prayer, Shaytan comes to you and confuses you until you do not know how much you have prayed. If you find that happening do two sajdas from the sitting position}}
\hadithdefcmd{malik}{223}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنِّي لأَنْسَى أَوْ أُنَسَّى لأَسُنَّ ‏"‏ ‏.‏\hadithno{223}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, said, "I forget or I am made to forget so that I may establish the sunna}}
\hadithdefcmd{malik}{224}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَجُلاً، سَأَلَ الْقَاسِمَ بْنَ مُحَمَّدٍ فَقَالَ إِنِّي أَهِمُ فِي صَلاَتِي فَيَكْثُرُ ذَلِكَ عَلَىَّ ‏.‏ فَقَالَ الْقَاسِمُ بْنُ مُحَمَّدٍ امْضِ فِي صَلاَتِكَ فَإِنَّهُ لَنْ يَذْهَبَ عَنْكَ حَتَّى تَنْصَرِفَ وَأَنْتَ تَقُولُ مَا أَتْمَمْتُ صَلاَتِي ‏.‏\hadithno{224}\hadithgrade{Salim al-Hilali: Maqtu Daif}\hadithtrans{Yahya related to me from Malik that he had heard that a man questioned al-Qasim ibn Muhammad saying, "My imagination works in the prayer, and it happens to me a lot." Al-Qasim ibn Muhammad said, "Go on with your prayer, for it will not go away from you until you go away saying, 'I have not completed my prayer}}
