% Auto-generated chapter 34 for tirmidhi
% Hadiths in this chapter: 25

\hadithdefcmd{tirmidhi}{2270}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا اقْتَرَبَ الزَّمَانُ لَمْ تَكَدْ رُؤْيَا الْمُؤْمِنِ تَكْذِبُ وَأَصْدَقُهُمْ رُؤْيَا أَصْدَقُهُمْ حَدِيثًا وَرُؤْيَا الْمُسْلِمِ جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ وَالرُّؤْيَا ثَلاَثٌ فَالرُّؤْيَا الصَّالِحَةُ بُشْرَى مِنَ اللَّهِ وَالرُّؤْيَا مِنْ تَحْزِينِ الشَّيْطَانِ وَالرُّؤْيَا مِمَّا يُحَدِّثُ بِهَا الرَّجُلُ نَفْسَهُ فَإِذَا رَأَى أَحَدُكُمْ مَا يَكْرَهُ فَلْيَقُمْ وَلْيَتْفُلْ وَلاَ يُحَدِّثْ بِهَا النَّاسَ قَالَ وَأُحِبُّ الْقَيْدَ فِي النَّوْمِ وَأَكْرَهُ الْغُلَّ الْقَيْدُ ثَبَاتٌ فِي الدِّينِ ‏"‏ ‏.‏ قَالَ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2270}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (s.a.w) said:"When time draws near, the dreams of a believer will hardly ever fail to come true, and the most truthful of them in dreams will be the truest in speech among them. The dream of a Muslim is a portion among the forty-six portions of Prophet-hood. And dreams are of three types: The righteous dream which is good news from Allah, dreams in which the Shaithan frightens someone, and dreams about something that has happened to the man himself. So when one of you sees what he dislikes, then he should get up and spit, and not tell any of the people- he said:- and I like the fetters in a dream while I dislike the iron collar." And the interpretation of fetters is being firm in the religion}}
\hadithdefcmd{tirmidhi}{2271}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، أَنَّهُ سَمِعَ أَنَسًا، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ رُؤْيَا الْمُؤْمِنِ جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي رَزِينٍ الْعُقَيْلِيِّ وَأَبِي سَعِيدٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَوْفِ بْنِ مَالِكٍ وَابْنِ عُمَرَ وَأَنَسٍ ‏.‏ قَالَ وَحَدِيثُ عُبَادَةَ حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2271}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ubadah bin As-Samit narrated that the Prophet (s.a.w) said:"The dreams of the believer are a portion of the forty-six portions of Prophet-hood}}
\hadithdefcmd{tirmidhi}{2272}{حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ يَعْنِي ابْنَ زِيَادٍ، حَدَّثَنَا الْمُخْتَارُ بْنُ فُلْفُلٍ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الرِّسَالَةَ وَالنُّبُوَّةَ قَدِ انْقَطَعَتْ فَلاَ رَسُولَ بَعْدِي وَلاَ نَبِيَّ ‏"‏ ‏.‏ قَالَ فَشَقَّ ذَلِكَ عَلَى النَّاسِ فَقَالَ ‏"‏ لَكِنِ الْمُبَشِّرَاتُ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَا الْمُبَشِّرَاتُ قَالَ ‏"‏ رُؤْيَا الْمُسْلِمِ وَهِيَ جُزْءٌ مِنْ أَجْزَاءِ النُّبُوَّةِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَحُذَيْفَةَ بْنِ أَسِيدٍ وَابْنِ عَبَّاسٍ وَأُمِّ كُرْزٍ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ الْمُخْتَارِ بْنِ فُلْفُلٍ ‏.‏\hadithno{2272}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Anas bin Malik narrated:"The Messenger of Allah (s.a.w) said: 'Indeed Messenger-ship and Prophethood have been terminated, so there shall be no Messenger after me, nor a Prophet.'" He(Anas) said:"The people were concerned about that, so he (s.a.w) said: 'But there will be Mubash-shirat.' So they said: 'O Messenger of Allah! What is Mubash-shirat?' He said: 'The Muslim's dreams, for it is a portion of the portions of Prophethood}}
\hadithdefcmd{tirmidhi}{2273}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ رَجُلٍ، مِنْ أَهْلِ مِصْرَ قَالَ سَأَلْتُ أَبَا الدَّرْدَاءِ عَنْ قَوْلِ اللَّهِ تَعَالَى‏:‏ ‏(‏لَهُمُ الْبُشْرَى فِي الْحَيَاةِ الدُّنْيَا ‏)‏ فَقَالَ مَا سَأَلَنِي عَنْهَا أَحَدٌ غَيْرَكَ إِلاَّ رَجُلٌ وَاحِدٌ مُنْذُ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا سَأَلَنِي عَنْهَا أَحَدٌ غَيْرَكَ مُنْذُ أُنْزِلَتْ هِيَ الرُّؤْيَا الصَّالِحَةُ يَرَاهَا الْمُسْلِمُ أَوْ تُرَى لَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُبَادَةَ بْنِ الصَّامِتِ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2273}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ata' bin Yasar narrated from a man among the inhabitants of Egypt who said:I asked Abu Ad-Darda about the saying of Allah, Most High: 'For them are glad tidings in the life of the present world' so he said: 'No one other than you asked me about it, except for one man, since I asked the Messenger of Allah (s.a.w), he said: 'No one other than you has asked me about it since it was revealed: This Ayah refers to the righteous dreams which the Muslim sees or which are seen about him}}
\hadithdefcmd{tirmidhi}{2274}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ دَرَّاجٍ، عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ أَصْدَقُ الرُّؤْيَا بِالأَسْحَارِ ‏"‏\hadithno{2274}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed narrated that the Prophet (s.a.w) said:"The most truthful of dreams are in the last hours of the night}}
\hadithdefcmd{tirmidhi}{2275}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا حَرْبُ بْنُ شَدَّادٍ، وَعِمْرَانُ الْقَطَّانُ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، قَالَ نُبِّئْتُ عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ قَوْلِهِ ‏(‏لَهُمُ الْبُشْرَى فِي الْحَيَاةِ الدُّنْيَا ‏)‏ قَالَ ‏"‏ هِيَ الرُّؤْيَا الصَّالِحَةُ يَرَاهَا الْمُؤْمِنُ أَوْ تُرَى لَهُ ‏"‏ ‏.‏ قَالَ حَرْبٌ فِي حَدِيثِهِ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{2275}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It is narrated from 'Ubadah bin As-Samit, who said:"[I asked] the Messenger of Allah (s.a.w) about For them are glad tidings in the life of the present world. He said: 'This refers to the righteous dreams which the Muslim sees or which are seen about him}}
\hadithdefcmd{tirmidhi}{2276}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ رَآنِي فِي الْمَنَامِ فَقَدْ رَآنِي فَإِنَّ الشَّيْطَانَ لاَ يَتَمَثَّلُ بِي ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي قَتَادَةَ وَابْنِ عَبَّاسٍ وَأَبِي سَعِيدٍ وَجَابِرٍ وَأَنَسٍ وَأَبِي مَالِكٍ الأَشْجَعِيِّ عَنْ أَبِيهِ وَأَبِي بَكْرَةَ وَأَبِي جُحَيْفَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2276}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah narrated that the Prophet (s.a.w) said:"Whoever saw me (in a dream) while sleeping then he has indeed seen me. For indeed the Shaitan can not resemble me}}
\hadithdefcmd{tirmidhi}{2277}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي قَتَادَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الرُّؤْيَا مِنَ اللَّهِ وَالْحُلْمُ مِنَ الشَّيْطَانِ فَإِذَا رَأَى أَحَدُكُمْ شَيْئًا يَكْرَهُهُ فَلْيَنْفُثْ عَنْ يَسَارِهِ ثَلاَثَ مَرَّاتٍ وَلْيَسْتَعِذْ بِاللَّهِ مِنْ شَرِّهَا فَإِنَّهَا لاَ تَضُرُّهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي سَعِيدٍ وَجَابِرٍ وَأَنَسٍ ‏.‏ قَالَ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2277}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Qatadah narrated that the Messenger of Allah (s.a.w) said:"Dreams are from Allah and Hulum are from Shaitan. So when one of you sees something that bothers him, then let him spit on his left three times, and let him seek refuge in Allah from its evil. Then it will not harm him}}
\hadithdefcmd{tirmidhi}{2278}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، قَالَ أَخْبَرَنِي يَعْلَى بْنُ عَطَاءٍ، قَالَ سَمِعْتُ وَكِيعَ بْنَ عُدُسٍ، عَنْ أَبِي رَزِينٍ الْعُقَيْلِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ رُؤْيَا الْمُؤْمِنِ جُزْءٌ مِنْ أَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ وَهِيَ عَلَى رِجْلِ طَائِرٍ مَا لَمْ يَتَحَدَّثْ بِهَا فَإِذَا تَحَدَّثَ بِهَا سَقَطَتْ ‏"‏ ‏.‏ قَالَ وَأَحْسَبُهُ قَالَ ‏"‏ وَلاَ يُحَدِّثُ بِهَا إِلاَّ لَبِيبًا أَوْ حَبِيبًا ‏"‏ ‏.‏\hadithno{2278}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Waki' bin 'Udus narrated that Abu Razin Al-'Uqaili said:" The Messenger of Allah (s.a.w) said: " The believer's dreams are a portion of the forty portions of Prophet-hood. And it is (as if it is) on the leg of a bird, as long as it is not spoken of. But when it is spoken of it drops." I think he said: " And it should not be discussed except with an intelligent one or a beloved one}}
\hadithdefcmd{tirmidhi}{2279}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا شُعْبَةُ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ وَكِيعِ بْنِ عُدُسٍ، عَنْ عَمِّهِ أَبِي رَزِينٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ رُؤْيَا الْمُسْلِمِ جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ وَهِيَ عَلَى رِجْلِ طَائِرٍ مَا لَمْ يُحَدِّثْ بِهَا فَإِذَا حَدَّثَ بِهَا وَقَعَتْ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو رَزِينٍ الْعُقَيْلِيُّ اسْمُهُ لَقِيطُ بْنُ عَامِرٍ ‏.‏ وَرَوَى حَمَّادُ بْنُ سَلَمَةَ عَنْ يَعْلَى بْنِ عَطَاءٍ فَقَالَ عَنْ وَكِيعِ بْنِ حُدُسٍ وَقَالَ شُعْبَةُ وَأَبُو عَوَانَةَ وَهُشَيْمٌ عَنْ يَعْلَى بْنِ عَطَاءٍ عَنْ وَكِيعِ بْنِ عُدُسٍ وَهَذَا أَصَحُّ ‏.‏\hadithno{2279}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Waki' bin 'Udus narrated from Abu Razin that the Prophet (s.a.w) said:" The Muslim's dreams are a portion of the forty-six portions of Prophet-hood. And it is (as if it is) on the leg of a bird, as long as it is not spoken of. But when it is spoken of it falls}}
\hadithdefcmd{tirmidhi}{2280}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي عُبَيْدِ اللَّهِ السَّلِيمِيُّ الْبَصْرِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الرُّؤْيَا ثَلاَثٌ فَرُؤْيَا حَقٌّ وَرُؤْيَا يُحَدِّثُ بِهَا الرَّجُلُ نَفْسَهُ وَرُؤْيَا تَحْزِينٌ مِنَ الشَّيْطَانِ فَمَنْ رَأَى مَا يَكْرَهُ فَلْيَقُمْ فَلْيُصَلِّ ‏"‏ ‏.‏ وَكَانَ يَقُولُ ‏"‏ يُعْجِبُنِي الْقَيْدُ وَأَكْرَهُ الْغُلَّ الْقَيْدُ ثَبَاتٌ فِي الدِّينِ ‏"‏ ‏.‏ وَكَانَ يَقُولُ ‏"‏ مَنْ رَآنِي فَإِنِّي أَنَا هُوَ فَإِنَّهُ لَيْسَ لِلشَّيْطَانِ أَنْ يَتَمَثَّلَ بِي ‏"‏ ‏.‏ وَكَانَ يَقُولُ ‏"‏ لاَ تُقَصُّ الرُّؤْيَا إِلاَّ عَلَى عَالِمٍ أَوْ نَاصِحٍ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَنَسٍ وَأَبِي بَكْرَةَ وَأُمِّ الْعَلاَءِ وَابْنِ عُمَرَ وَعَائِشَةَ وَأَبِي مُوسَى وَجَابِرٍ وَأَبِي سَعِيدٍ وَابْنِ عَبَّاسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2280}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurarirah narrated that the Messenger of Allah (s.a.w) said:"Dreams are of three types: The true dream, dreams about something that has happened to the man himself, and dreams in which the Shaitan frightens someone. So whoever sees what he dislikes, then he should get up and perform Salah." And he would say: "I like fetters and I dislike the iron collar." And he would say: " Whoever has seen me (in a dream) then it is I , for indeed Shaitan is not able to resemble me." And he would say: "The dream is not to be narrated except to a knowledgeable person or a sincere advisor}}
\hadithdefcmd{tirmidhi}{2281}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الأَعْلَى، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ عَلِيٍّ، قَالَ أُرَاهُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَذَبَ فِي حُلْمِهِ كُلِّفَ يَوْمَ الْقِيَامَةِ عَقْدَ شَعِيرَةٍ ‏"‏ ‏.‏\hadithno{2281}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu 'Abdur-Rahman(As-Sulami) narrated from 'Ali and I think he said:" From the Prophet(s.a.w), who said: "Whoever lies about his dream, he will be required to knot barely kernels on the Day of Judgement}}
\hadithdefcmd{tirmidhi}{2282}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الأَعْلَى، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنِ عَلِيٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ وَأَبِي شُرَيْحٍ وَوَاثِلَةَ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ مِنَ الْحَدِيثِ الأَوَّلِ ‏.‏\hadithno{2282}\hadithgrade{Zubair Ali Zai: Hasan}\hadithtrans{(another chain) from Abu 'Abdur-Rahman As-Sulami who narrated from 'Ali from the Prophet with similar narrations. [He said:This narration is Hasan.] There are narration on this topic from Ibn 'Abbas, Abu Hurairah, Abu Shuraih and Wathilah bin Al-Asqa}}
\hadithdefcmd{tirmidhi}{2283}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَحَلَّمَ كَاذِبًا كُلِّفَ يَوْمَ الْقِيَامَةِ أَنْ يَعْقِدَ بَيْنَ شَعِيرَتَيْنِ وَلَنْ يَعْقِدَ بَيْنَهُمَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2283}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ibn 'Abbas narrated that the Prophet (s.a.w) said:"Whoever lies about having a dream, he will be required to knot two barely kernels together on the Day Of Judgment., and he will never be able to knot them together}}
\hadithdefcmd{tirmidhi}{2284}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ حَمْزَةَ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ بَيْنَمَا أَنَا نَائِمٌ إِذْ أُتِيتُ بِقَدَحِ لَبَنٍ فَشَرِبْتُ مِنْهُ ثُمَّ أَعْطَيْتُ فَضْلِي عُمَرَ بْنَ الْخَطَّابِ ‏"‏ ‏.‏ قَالُوا فَمَا أَوَّلْتَهُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الْعِلْمَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي بَكْرَةَ وَابْنِ عَبَّاسٍ وَعَبْدِ اللَّهِ بْنِ سَلاَمٍ وَخُزَيْمَةَ وَالطُّفَيْلِ بْنِ سَخْبَرَةَ وَسَمُرَةَ وَأَبِي أُمَامَةَ وَجَابِرٍ ‏.‏ قَالَ حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{2284}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'Umar narrated that the Messenger of Allah (s.a.w) said:"While I was sleeping , I was brought a cup of milk and I drank from it. Then I gave what I had left to 'Umar bin Al-Khattab." They said; "How did you interpret it O Messenger of Allah?" He said: "Knowledge}}
\hadithdefcmd{tirmidhi}{2285}{حَدَّثَنَا الْحُسَيْنُ بْنُ مُحَمَّدٍ الْجُرَيْرِيُّ الْبَلْخِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ بَعْضِ، أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَمَا أَنَا نَائِمٌ رَأَيْتُ النَّاسَ يُعْرَضُونَ عَلَىَّ وَعَلَيْهِمْ قُمُصٌ مِنْهَا مَا يَبْلُغُ الثُّدِيَّ وَمِنْهَا مَا يَبْلُغُ أَسْفَلَ مِنْ ذَلِكَ فَعُرِضَ عَلَىَّ عُمَرُ وَعَلَيْهِ قَمِيصٌ يَجُرُّهُ ‏"‏ ‏.‏ قَالُوا فَمَا أَوَّلْتَهُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الدِّينَ ‏"‏ ‏.‏\hadithno{2285}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Umamah bin Sahl bin Hunaif narrated from some of the companions of the Prophet (s.a.w) that the Prophet (s.a.w) said:"While I was sleeping I saw people presented before me, and that they were wearing shirts. Some of them (the shirts) reaching their breasts, and some of them reaching below that." He said: "Then 'Umar was presented before me and he was wearing a shirt that was dragging." They said: "How did you interpret that O Messenger of Allah?" He said: "The religion}}
\hadithdefcmd{tirmidhi}{2286}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، عَنْ أَبِيهِ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِمَعْنَاهُ ‏.‏ قَالَ وَهَذَا أَصَحُّ ‏.‏\hadithno{2286}\hadithgrade{Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Umamah bin Sahl bin Hunaif narrated from Abu Sa'eed al-Khudri that the Prophet (s.a.w) said:similar in meaning (to no)}}
\hadithdefcmd{tirmidhi}{2287}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا أَشْعَثُ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ذَاتَ يَوْمٍ ‏ "‏ مَنْ رَأَى مِنْكُمْ رُؤْيَا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ أَنَا رَأَيْتُ كَأَنَّ مِيزَانًا نَزَلَ مِنَ السَّمَاءِ فَوُزِنْتَ أَنْتَ وَأَبُو بَكْرٍ فَرَجَحْتَ أَنْتَ بِأَبِي بَكْرٍ وَوُزِنَ أَبُو بَكْرٍ وَعُمَرُ فَرَجَحَ أَبُو بَكْرٍ وَوُزِنَ عُمَرُ وَعُثْمَانُ فَرَجَحَ عُمَرُ ثُمَّ رُفِعَ الْمِيزَانُ ‏.‏ فَرَأَيْنَا الْكَرَاهِيَةَ فِي وَجْهِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2287}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Bakrah narrated:"One day the Prophet (s.a.w) said: "'Who among you had a dream?' A man said: "I did. I saw as if a scale had descended from the Heavens in which you and Abu Bakr were weighed So you outweighed Abu Bakr. Abu Bkar and 'Umar were weighed, and Abu Bakr outweighed ('Umar). 'Umar and 'Uthman were weighed and 'Umar outweighed ('Uthman). Then the scale was raised up.' Then I saw dislike in the the face of Messenger of Allah (s.a.w)}}
\hadithdefcmd{tirmidhi}{2288}{حَدَّثَنَا أَبُو مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، حَدَّثَنِي عُثْمَانُ بْنُ عَبْدِ الرَّحْمَنِ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ وَرَقَةَ فَقَالَتْ لَهُ خَدِيجَةُ إِنَّهُ كَانَ صَدَّقَكَ وَلَكِنَّهُ مَاتَ قَبْلَ أَنْ تَظْهَرَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُرِيتُهُ فِي الْمَنَامِ وَعَلَيْهِ ثِيَابٌ بَيَاضٌ وَلَوْ كَانَ مِنْ أَهْلِ النَّارِ لَكَانَ عَلَيْهِ لِبَاسٌ غَيْرُ ذَلِكَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَعُثْمَانُ بْنُ عَبْدِ الرَّحْمَنِ لَيْسَ عِنْدَ أَهْلِ الْحَدِيثِ بِالْقَوِيِّ ‏.‏\hadithno{2288}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah said:"The Messenger of Allah (s.a.w) was asked about Waraqah. Khadijah said to him: 'He believed in you, but he died before your advent.' So the Messenger of Allah (s.a.w) said: 'I saw him in a dream, and upon him were white garments. If he were among the inhabitants of the Fire then he would have been wearing other than that}}
\hadithdefcmd{tirmidhi}{2289}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي مُوسَى بْنُ عُقْبَةَ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ رُؤْيَا النَّبِيِّ، صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ قَالَ ‏ "‏ رَأَيْتُ النَّاسَ اجْتَمَعُوا فَنَزَعَ أَبُو بَكْرٍ ذَنُوبًا أَوْ ذَنُوبَيْنِ فِيهِ ضَعْفٌ وَاللَّهُ يَغْفِرُ لَهُ ثُمَّ قَامَ عُمَرُ فَنَزَعَ فَاسْتَحَالَتْ غَرْبًا فَلَمْ أَرَ عَبْقَرِيًّا يَفْرِي فَرِيَّهُ حَتَّى ضَرَبَ النَّاسُ بِعَطَنٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَهَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ ابْنِ عُمَرَ ‏.‏\hadithno{2289}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Salim bin 'Abdullah narrated from 'Abdullah bin 'Umar about the dream of the Prophet (s.a.w) and Abu Bakr and 'Umar, so he said:"I saw that the people had gathered, so Abu Bakr drew a bucket or two buckets- in him was some weakness- and Allah forgive him. Then 'Umar stood to draw and the bucket turned into a very large one, and I have never seen a strong man toiling so hard until it was as if the people had gathered at a (camel) watering hole}}
\hadithdefcmd{tirmidhi}{2290}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي مُوسَى بْنُ عُقْبَةَ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ رُؤْيَا النَّبِيِّ، صلى الله عليه وسلم قَالَ ‏ "‏ رَأَيْتُ امْرَأَةً سَوْدَاءَ ثَائِرَةَ الرَّأْسِ خَرَجَتْ مِنَ الْمَدِينَةِ حَتَّى قَامَتْ بِمَهْيَعَةَ وَهِيَ الْجُحْفَةُ وَأَوَّلْتُهَا وَبَاءَ الْمَدِينَةِ يُنْقَلُ إِلَى الْجُحْفَةِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{2290}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Salim bin 'Abdullah narrated from his father about the dream of the Prophet (s.a.w) who said:"I saw a black woman with unkempt hair going out of Al-Madinah, until she stood in Mabaya'ah, and it is Al-Juhfah. So I interpreted that to be an epidemic in Al-Madinah that would spread to Al-Juhfah}}
\hadithdefcmd{tirmidhi}{2291}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ فِي آخِرِ الزَّمَانِ لاَ تَكَادُ رُؤْيَا الْمُؤْمِنِ تَكْذِبُ وَأَصْدَقُهُمْ رُؤْيَا أَصْدَقُهُمْ حَدِيثًا وَالرُّؤْيَا ثَلاَثٌ الْحَسَنَةُ بُشْرَى مِنَ اللَّهِ وَالرُّؤْيَا يُحَدِّثُ الرَّجُلُ بِهَا نَفْسَهُ وَالرُّؤْيَا تَحْزِينٌ مِنَ الشَّيْطَانِ فَإِذَا رَأَى أَحَدُكُمْ رُؤْيَا يَكْرَهُهَا فَلاَ يُحَدِّثْ بِهَا أَحَدًا وَلْيَقُمْ فَلْيُصَلِّ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ ‏"‏ يُعْجِبُنِي الْقَيْدُ وَأَكْرَهُ الْغُلَّ الْقَيْدُ ثَبَاتٌ فِي الدِّينِ ‏"‏ ‏.‏ قَالَ وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ رُؤْيَا الْمُؤْمِنِ جُزْءٌ مِنْ سِتَّةٍ وَأَرْبَعِينَ جُزْءًا مِنَ النُّبُوَّةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى عَبْدُ الْوَهَّابِ الثَّقَفِيُّ هَذَا الْحَدِيثَ عَنْ أَيُّوبَ مَرْفُوعًا وَرَوَاهُ حَمَّادُ بْنُ زَيْدٍ عَنْ أَيُّوبَ وَوَقَفَهُ ‏.‏\hadithno{2291}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurrairah narrated that the Messenger of Allah (s.a.w) said:"In the end of time, the dreams of a believer will hardly ever fail to come true, and the most truthful of them in dreams will be the truest in speech among them. And dreams are three types: The good dreams wihich is glad tidings from Allah, dreams about something that has happened to the man himself, and dreams in which the Shaitan frightens someone. So when one of you sees what he dislikes, then he should get up and perform Salat." Abu Hurairah said: "I like fetters and dislikes, the iron collar. And fetters refers to being firm in the religion." He said: "The Prophet (s. a. w) said: 'Dreams are a portion among the forty\_six portions of Prophethood}}
\hadithdefcmd{tirmidhi}{2292}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ الْبَغْدَادِيُّ، حَدَّثَنَا أَبُو الْيَمَانِ، عَنْ شُعَيْبٍ، وَهُوَ ابْنُ أَبِي حَمْزَةَ عَنِ ابْنِ أَبِي حُسَيْنٍ، وَهُوَ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ أَبِي حُسَيْنٍ عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَأَيْتُ فِي الْمَنَامِ كَأَنَّ فِي يَدَىَّ سِوَارَيْنِ مِنْ ذَهَبٍ فَهَمَّنِي شَأْنُهُمَا فَأُوحِيَ إِلَىَّ أَنْ أَنْفُخَهُمَا فَنَفَخْتُهُمَا فَطَارَا فَأَوَّلْتُهُمَا كَاذِبَيْنِ يَخْرُجَانِ مِنْ بَعْدِي يُقَالُ لأَحَدِهِمَا مُسَيْلِمَةُ صَاحِبُ الْيَمَامَةِ وَالْعَنْسِيُّ صَاحِبُ صَنْعَاءَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ صَحِيحٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{2292}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn 'abbas narrated fro Abu Hurairah that the Messengr of Allah (s.a.w) said:"I had a dream while sleeping as if there were two gold bracelets in my hands which bothered me very much. So it was reveled to me to blow them off. I blew them off and they flew away. I interpreted thwm to be two liars who would appear after me. One of them caled Masalamah of Yamamah, and (the other) Al-'ansi of San'a'." (sahih)}}
\hadithdefcmd{tirmidhi}{2293}{حَدَّثَنَا الْحُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ أَبُو هُرَيْرَةَ يُحَدِّثُ أَنَّ رَجُلاً، جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنِّي رَأَيْتُ اللَّيْلَةَ ظُلَّةً يَنْطِفُ مِنْهَا السَّمْنُ وَالْعَسَلُ وَرَأَيْتُ النَّاسَ يَسْتَقُونَ بِأَيْدِيهِمْ فَالْمُسْتَكْثِرُ وَالْمُسْتَقِلُّ وَرَأَيْتُ سَبَبًا وَاصِلاً مِنَ السَّمَاءِ إِلَى الأَرْضِ وَأَرَاكَ يَا رَسُولَ اللَّهِ أَخَذْتَ بِهِ فَعَلَوْتَ ثُمَّ أَخَذَ بِهِ رَجُلٌ بَعْدَكَ فَعَلاَ ثُمَّ أَخَذَ بِهِ رَجُلٌ بَعْدَهُ فَعَلاَ ثُمَّ أَخَذَ بِهِ رَجُلٌ فَقُطِعَ بِهِ ثُمَّ وُصِلَ لَهُ فَعَلاَ بِهِ ‏.‏ فَقَالَ أَبُو بَكْرٍ أَىْ رَسُولَ اللَّهِ بِأَبِي أَنْتَ وَأُمِّي وَاللَّهِ لَتَدَعَنِّي أَعْبُرْهَا فَقَالَ ‏"‏ اعْبُرْهَا ‏"‏ ‏.‏ فَقَالَ أَمَّا الظُّلَّةُ فَظُلَّةُ الإِسْلاَمِ وَأَمَّا مَا يَنْطِفُ مِنَ السَّمْنِ وَالْعَسَلِ فَهُوَ الْقُرْآنُ لِينُهُ وَحَلاَوَتُهُ وَأَمَّا الْمُسْتَكْثِرُ وَالْمُسْتَقِلُّ فَهُوَ الْمُسْتَكْثِرُ مِنَ الْقُرْآنِ وَالْمُسْتَقِلُّ مِنْهُ وَأَمَّا السَّبَبُ الْوَاصِلُ مِنَ السَّمَاءِ إِلَى الأَرْضِ فَهُوَ الْحَقُّ الَّذِي أَنْتَ عَلَيْهِ فَأَخَذْتَ بِهِ فَيُعْلِيكَ اللَّهُ ثُمَّ يَأْخُذُ بِهِ بَعْدَكَ رَجُلٌ آخَرُ فَيَعْلُو بِهِ ثُمَّ يَأْخُذُ بِهِ بَعْدَهُ رَجُلٌ آخَرُ فَيَعْلُو بِهِ ثُمَّ يَأْخُذُ رَجُلٌ آخَرُ فَيَنْقَطِعُ بِهِ ثُمَّ يُوصَلُ لَهُ فَيَعْلُو أَىْ رَسُولَ اللَّهِ لَتُحَدِّثَنِّي أَصَبْتُ أَوْ أَخْطَأْتُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَصَبْتَ بَعْضًا وَأَخْطَأْتَ بَعْضًا ‏"‏ قَالَ أَقْسَمْتُ بِأَبِي أَنْتَ وَأُمِّي لَتُخْبِرَنِّي مَا الَّذِي أَخْطَأْتُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ تُقْسِمْ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{2293}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that a man came to the Prophet (s.a.w) and said:"I had a dream of a cloud with shade dripping butter and honey. I saw the people scooping it up with their hands, some taking much and some taking little. I saw a rope extending from the sky to the earth. Then I saw you O Messenger of Allah ! You took hold of it and went up, then a man took hold of it after you do so, then a man took hold of it after him to do so. Then a man took hold of it and it was severed, and then connected for him, and he did so (i.e. , went up)." Abu Bakr said: "May my father and mother be ransomed for you O Messenger of Allah! Allow me to interpret it." He said: "Interpret it." so he said: "As for the cloud with its shade, it is Islam. As for what the butter and honey that dropped from it, this is the Quran and its delicateness and sweetness. It means some of them gathered much of the Quran and some of them a little. As for the rope extending from the sky to the earth, it is the truth which you are upon, you clug to it and Allah exalted you. Then another man will take hold of it after you and ascend on it, then after him, another man will take hold of it and ascend on it. Then another [man] will take hold of it but it will break, then be connected so he will ascend on it. Inform me O Messenger of Allah! Am I correct or am I mistaken?" The Prophet (s.a.w) said: "You are correct in some of it and mistaken in some of it." He (i.e., Abu Bakr) said: "I swear to you by my father and my mother O Messenger of Allah! Inform me in what I was mistaken?" The Prophet(s.a.w) said: "Do not swear}}
\hadithdefcmd{tirmidhi}{2294}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرِ بْنِ حَازِمٍ، عَنْ أَبِيهِ، عَنْ أَبِي رَجَاءٍ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا صَلَّى بِنَا الصُّبْحَ أَقْبَلَ عَلَى النَّاسِ بِوَجْهِهِ وَقَالَ ‏ "‏ هَلْ رَأَى أَحَدٌ مِنْكُمُ اللَّيْلَةَ رُؤْيَا ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَيُرْوَى هَذَا الْحَدِيثُ عَنْ عَوْفٍ وَجَرِيرِ بْنِ حَازِمٍ عَنْ أَبِي رَجَاءٍ عَنْ سَمُرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي قِصَّةٍ طَوِيلَةٍ ‏.‏ قَالَ وَهَكَذَا رَوَى مُحَمَّدُ بْنُ بَشَّارٍ هَذَا الْحَدِيثَ عَنْ وَهْبِ بْنِ جَرِيرٍ مُخْتَصَرًا ‏.‏\hadithno{2294}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Samurah bin Jundub narrated :"When the Messenger of Allah (s.a.w) had led us in Subh(Fajr prayer), he turned to face the people and said: 'Did any of you have a dream during the night?'" [He said:] This Hadith is Hasan Sahih. This Hadith has been related from 'Awf and Jarir bin Hazim, from Abu Raja', from sumarah from the Prophet(s.a.w) with the story in its entirety. [He said:] This is how Bundar reported this Hadith, with its brevity, from Wahib bin Jarir}}
