% Auto-generated chapter 30 for nasai
% Hadiths in this chapter: 61

\hadithdefcmd{nasai}{3611}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَىُّ الصَّدَقَةِ أَعْظَمُ أَجْرًا قَالَ ‏ "‏ أَنْ تَصَدَّقَ وَأَنْتَ صَحِيحٌ شَحِيحٌ تَخْشَى الْفَقْرَ وَتَأْمُلُ الْبَقَاءَ وَلاَ تُمْهِلْ حَتَّى إِذَا بَلَغَتِ الْحُلْقُومَ قُلْتَ لِفُلاَنٍ كَذَا وَقَدْ كَانَ لِفُلاَنٍ ‏"‏‏.‏\hadithno{3611}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"A man came to the Prophet and said: 'O Messenger of Allah, what kind of charity brings the greatest reward?' He said: 'To give in charity when you are healthy and feeling miserly, and fearing poverty and hoping for a long life. Do not wait until the (death rattle) reaches the throat and then say: "This is for so and so," and it nearly became the property of so and so (the heirs)}}
\hadithdefcmd{nasai}{3612}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنِ الْحَارِثِ بْنِ سُوَيْدٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيُّكُمْ مَالُ وَارِثِهِ أَحَبُّ إِلَيْهِ مِنْ مَالِهِ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ مَا مِنَّا مِنْ أَحَدٍ إِلاَّ مَالُهُ أَحَبُّ إِلَيْهِ مِنْ مَالِ وَارِثِهِ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اعْلَمُوا أَنَّهُ لَيْسَ مِنْكُمْ مِنْ أَحَدٍ إِلاَّ مَالُ وَارِثِهِ أَحَبُّ إِلَيْهِ مِنْ مَالِهِ مَالُكَ مَا قَدَّمْتَ وَمَالُ وَارِثِكَ مَا أَخَّرْتَ ‏"‏‏.‏\hadithno{3612}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah said: 'For whom among you is the wealth of his heirs dearer to him than his own wealth?' They said: 'O Messenger of Allah, there is no one among us for whom his own wealth is not dearer to him than the wealth of his heirs.' The Messenger of Allah said: 'Know that there is no one among you for whom the wealth of his heirs is not dearer than his own wealth. Your wealth is that which you have sent on ahead, and the wealth of your heirs is that which you have kept}}
\hadithdefcmd{nasai}{3613}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ ‏\{‏أَلْهَاكُمُ التَّكَاثُرُ * حَتَّى زُرْتُمُ الْمَقَابِرَ‏\}‏ قَالَ يَقُولُ ابْنُ آدَمَ مَالِي مَالِي وَإِنَّمَا مَالُكَ مَا أَكَلْتَ فَأَفْنَيْتَ أَوْ لَبِسْتَ فَأَبْلَيْتَ أَوْ تَصَدَّقْتَ فَأَمْضَيْتَ ‏"‏‏.‏\hadithno{3613}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Mutarrif, from his father, that the Prophet said:"The mutual rivalry (for piling up of worldly things) diverts you, 'Until you visit the graves (i.e. till you die).' The son of Adam says: 'My wealth, my wealth,' but your wealth is what you eat and consume, or what you wear and it wears out, or what you give in charity and send on ahead (for the Hereafter)}}
\hadithdefcmd{nasai}{3614}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ أَبَا إِسْحَاقَ، سَمِعَ أَبَا حَبِيبَةَ الطَّائِيَّ، قَالَ أَوْصَى رَجُلٌ بِدَنَانِيرَ فِي سَبِيلِ اللَّهِ فَسُئِلَ أَبُو الدَّرْدَاءِ فَحَدَّثَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الَّذِي يَعْتِقُ أَوْ يَتَصَدَّقُ عِنْدَ مَوْتِهِ مَثَلُ الَّذِي يُهْدِي بَعْدَ مَا يَشْبَعُ ‏"‏‏.‏\hadithno{3614}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Habibah At-Ta'i said:"A man made a will leaving some Dinars (to be spent) in the cause of Allah. Abu Ad-Darda' was asked about that, and he narrated that the Prophet said: 'The likeness of the one who frees a slave or gives some charity when he is dying, is that of a man who gives a gift after he has eaten his fill}}
\hadithdefcmd{nasai}{3615}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا الْفُضَيْلُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا حَقُّ امْرِئٍ مُسْلِمٍ لَهُ شَىْءٌ يُوصَى فِيهِ أَنْ يَبِيتَ لَيْلَتَيْنِ إِلاَّ وَوَصِيَّتُهُ مَكْتُوبَةٌ عِنْدَهُ ‏"‏‏.‏\hadithno{3615}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'It is not befitting for a Muslim who has anything concerning which a will should be made, to abide for two nights without having a written will with him}}
\hadithdefcmd{nasai}{3616}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا حَقُّ امْرِئٍ مُسْلِمٍ لَهُ شَىْءٌ يُوصَى فِيهِ يَبِيتُ لَيْلَتَيْنِ إِلاَّ وَوَصِيَّتُهُ مَكْتُوبَةٌ عِنْدَهُ ‏"‏‏.‏\hadithno{3616}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah said:"It is not befitting for a Muslim who has anything concerning which a will should be made, to abide for two nights without having a written will with him}}
\hadithdefcmd{nasai}{3617}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ نُعَيْمٍ، قَالَ حَدَّثَنَا حِبَّانُ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، عَنِ ابْنِ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَوْلَهُ‏.‏\hadithno{3617}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{(The same) was narrated from Ibn 'Awn, from Nafi', from Ibn 'Umar}}
\hadithdefcmd{nasai}{3618}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ فَإِنَّ سَالِمًا أَخْبَرَنِي عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا حَقُّ امْرِئٍ مُسْلِمٍ تَمُرُّ عَلَيْهِ ثَلاَثُ لَيَالٍ إِلاَّ وَعِنْدَهُ وَصِيَّتُهُ ‏"‏‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ مَا مَرَّتْ عَلَىَّ مُنْذُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ذَلِكَ إِلاَّ وَعِنْدِي وَصِيَّتِي‏.‏\hadithno{3618}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that the Prophet said:"It is not befitting for a Muslim to abide for three nights without having his will with him." 'Abdullah bin 'Umar said: "Since I heard this from the Messenger of Allah, I have always had my will with me}}
\hadithdefcmd{nasai}{3619}{أَخْبَرَنَا أَحْمَدُ بْنُ يَحْيَى بْنِ الْوَزِيرِ بْنِ سُلَيْمَانَ، قَالَ سَمِعْتُ ابْنَ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، وَعَمْرُو بْنُ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا حَقُّ امْرِئٍ مُسْلِمٍ لَهُ شَىْءٌ يُوصَى فِيهِ فَيَبِيتُ ثَلاَثَ لَيَالٍ إِلاَّ وَوَصِيَّتُهُ عِنْدَهُ مَكْتُوبَةٌ ‏"‏‏.‏\hadithno{3619}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salim bin 'Abdullah, from his father, that the Messenger of Allah said:"It is not right for a Muslim who has anything concerning which a will should be made, to abide for more than three nights without having a written will with him}}
\hadithdefcmd{nasai}{3620}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا مَالِكُ بْنُ مِغْوَلٍ، قَالَ حَدَّثَنَا طَلْحَةُ، قَالَ سَأَلْتُ ابْنَ أَبِي أَوْفَى أَوْصَى رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ لاَ‏.‏ قُلْتُ كَيْفَ كَتَبَ عَلَى الْمُسْلِمِينَ الْوَصِيَّةَ قَالَ أَوْصَى بِكِتَابِ اللَّهِ‏.‏\hadithno{3620}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Talha said:"I asked Ibn Abi Awfa: 'Did the Messenger of Allah leave a will?' He said: 'No.' I said: 'How come it is prescribed for the Muslims to make wills?' He said: 'He left instructions urging the Muslims to adhere to the Book of Allah}}
\hadithdefcmd{nasai}{3621}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، قَالَ حَدَّثَنَا مُفَضَّلٌ، عَنِ الأَعْمَشِ، وَأَنْبَأَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، وَأَحْمَدُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ مَا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم دِينَارًا وَلاَ دِرْهَمًا وَلاَ شَاةً وَلاَ بَعِيرًا وَلاَ أَوْصَى بِشَىْءٍ‏.‏\hadithno{3621}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah did not leave behind a Dinar or a Dirham, or a sheep or a camel, and he did not leave any will}}
\hadithdefcmd{nasai}{3622}{أَخْبَرَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا مُصْعَبٌ، حَدَّثَنَا دَاوُدُ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ مَا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم دِرْهَمًا وَلاَ دِينَارًا وَلاَ شَاةً وَلاَ بَعِيرًا وَمَا أَوْصَى‏.‏\hadithno{3622}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah did not leave behind a Dirham or a Dinar, or a sheep or a camel, and he did not leave any will}}
\hadithdefcmd{nasai}{3623}{أَخْبَرَنَا جَعْفَرُ بْنُ مُحَمَّدِ بْنِ الْهُذَيْلِ، وَأَحْمَدُ بْنُ يُوسُفَ، قَالاَ حَدَّثَنَا عَاصِمُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا حَسَنُ بْنُ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ مَا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم دِرْهَمًا وَلاَ دِينَارًا وَلاَ شَاةً وَلاَ بَعِيرًا وَلاَ أَوْصَى‏.‏ لَمْ يَذْكُرْ جَعْفَرٌ دِينَارًا وَلاَ دِرْهَمًا‏.‏\hadithno{3623}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah did not leave behind a Dirham or a Dinar, or a sheep or a camel, and he did not leave any will." Ja'far did not mention "Dinar or Dirham}}
\hadithdefcmd{nasai}{3624}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَزْهَرُ، قَالَ أَنْبَأَنَا ابْنُ عَوْنٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ يَقُولُونَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَوْصَى إِلَى عَلِيٍّ رضى الله عنه لَقَدْ دَعَا بِالطَّسْتِ لِيَبُولَ فِيهَا فَانْخَنَثَتْ نَفْسُهُ صلى الله عليه وسلم وَمَا أَشْعُرُ فَإِلَى مَنْ أَوْصَى\hadithno{3624}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated that 'Aishah said:"They say that the Messenger of Allah made a will concerning 'Ali, may Allah be pleased with him. But he called for a vessel in which to urinate, then he went limp without me realizing it. So to whom did he leave a will?}}
\hadithdefcmd{nasai}{3625}{أَخْبَرَنِي أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عَارِمٌ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنِ ابْنِ عَوْنٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَيْسَ عِنْدَهُ أَحَدٌ غَيْرِي - قَالَتْ - وَدَعَا بِالطَّسْتِ‏.‏\hadithno{3625}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah died when no one was with him except me." She said: "And he called for a vessel}}
\hadithdefcmd{nasai}{3626}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ مَرِضْتُ مَرَضًا أَشْفَيْتُ مِنْهُ فَأَتَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُنِي فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ لِي مَالاً كَثِيرًا وَلَيْسَ يَرِثُنِي إِلاَّ ابْنَتِي أَفَأَتَصَدَّقُ بِثُلُثَىْ مَالِي قَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ فَالشَّطْرَ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ فَالثُّلُثَ قَالَ ‏"‏ الثُّلُثَ وَالثُّلُثُ كَثِيرٌ إِنَّكَ أَنْ تَتْرُكَ وَرَثَتَكَ أَغْنِيَاءَ خَيْرٌ لَهُمْ مِنْ أَنْ تَتْرُكَهُمْ عَالَةً يَتَكَفَّفُونَ النَّاسَ ‏"‏‏.‏\hadithno{3626}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Amir bin Sa'd that his father said:"I became ill with a sickness from which I later recovered. The Messenger of Allah came to visit me, and I said: 'O Messenger of Allah, I have a great deal of wealth and I have no heir except my daughter. Shall I give two-thirds of my wealth in charity?' He said: 'No.' I said: 'Half?' He said: 'No.' I said: 'One-third?' He said: '(Give) one-third, and one-third is a lot. It is better to leave your heirs independent of means, than to leave them poor and holding out their hands to people}}
\hadithdefcmd{nasai}{3627}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، وَأَحْمَدُ بْنُ سُلَيْمَانَ، - وَاللَّفْظُ لأَحْمَدَ - قَالاَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ سَعْدٍ، قَالَ جَاءَنِي النَّبِيُّ صلى الله عليه وسلم يَعُودُنِي وَأَنَا بِمَكَّةَ قُلْتُ يَا رَسُولَ اللَّهِ أُوصِي بِمَالِي كُلِّهِ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ فَالشَّطْرَ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ فَالثُّلُثَ قَالَ ‏"‏ الثُّلُثَ وَالثُّلُثُ كَثِيرٌ إِنَّكَ أَنْ تَدَعَ وَرَثَتَكَ أَغْنِيَاءَ خَيْرٌ مِنْ أَنْ تَدَعَهُمْ عَالَةً يَتَكَفَّفُونَ النَّاسَ يَتَكَفَّفُونَ فِي أَيْدِيهِمْ ‏"‏‏.‏\hadithno{3627}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Sa'd said:"The Prophet came to visit me when I was in Makkah. I said: 'O Messenger of Allah, shall I bequeath all my money?' He said: 'No.' I said: 'One-half?' He said: 'No.' I said: 'One-third?' He said: '(Bequeath) one-third, and one-third is a lot. If you leave your heirs independent of means, that is better than if you leave them poor and holding out their hands to people}}
\hadithdefcmd{nasai}{3628}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَعُودُهُ وَهُوَ بِمَكَّةَ وَهُوَ يَكْرَهُ أَنْ يَمُوتَ بِالأَرْضِ الَّتِي هَاجَرَ مِنْهَا قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ رَحِمَ اللَّهُ سَعْدَ ابْنَ عَفْرَاءَ أَوْ يَرْحَمُ اللَّهُ سَعْدَ ابْنَ عَفْرَاءَ ‏"‏‏.‏ وَلَمْ يَكُنْ لَهُ إِلاَّ ابْنَةٌ وَاحِدَةٌ قَالَ يَا رَسُولَ اللَّهِ أُوصِي بِمَالِي كُلِّهِ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ النِّصْفَ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قُلْتُ فَالثُّلُثَ قَالَ ‏"‏ الثُّلُثَ وَالثُّلُثُ كَثِيرٌ إِنَّكَ أَنْ تَدَعَ وَرَثَتَكَ أَغْنِيَاءَ خَيْرٌ مِنْ أَنْ تَدَعَهُمْ عَالَةً يَتَكَفَّفُونَ النَّاسَ مَا فِي أَيْدِيهِمْ ‏"‏‏.‏\hadithno{3628}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amir bin Sa'd that his father said:"The Prophet used to visit him when he was in Makkah, and he did not want to die in the land from which he had emigrated. The Prophet said: 'May Allah have mercy on Sa'd bin 'Afra.' He had only one daughter, and he said: 'O Messenger of Allah, shall I bequeath all my wealth?' He said: 'No.' I said: 'Half?' He said: 'No.' I said: 'One-third?' He said: 'One-third, and one-third is a lot. For you to leave your heirs independent of means is better than if you were to leave them poor, holding out their hands to people}}
\hadithdefcmd{nasai}{3629}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا مِسْعَرٌ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي بَعْضُ، آلِ سَعْدٍ قَالَ مَرِضَ سَعْدٌ فَدَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أُوصِي بِمَالِي كُلِّهِ قَالَ ‏ "‏ لاَ ‏"‏‏.‏ وَسَاقَ الْحَدِيثَ‏.‏\hadithno{3629}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{One from the family of Sa'd narrated:"Sa'd fell sick and the Messenger of Allah entered upon him and he said: 'O Messenger of Allah, shall I bequeath all my money?' He said: 'No.'" And he quoted the same Hadith}}
\hadithdefcmd{nasai}{3630}{أَخْبَرَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، قَالَ حَدَّثَنَا عَبْدُ الْكَبِيرِ بْنُ عَبْدِ الْمَجِيدِ، قَالَ حَدَّثَنَا بُكَيْرُ بْنُ مِسْمَارٍ، قَالَ سَمِعْتُ عَامِرَ بْنَ سَعْدٍ، عَنْ أَبِيهِ، أَنَّهُ اشْتَكَى بِمَكَّةَ فَجَاءَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَآهُ سَعْدٌ بَكَى وَقَالَ يَا رَسُولَ اللَّهِ أَمُوتُ بِالأَرْضِ الَّتِي هَاجَرْتَ مِنْهَا قَالَ ‏"‏ لاَ إِنْ شَاءَ اللَّهُ ‏"‏‏.‏ وَقَالَ يَا رَسُولَ اللَّهِ أُوصِي بِمَالِي كُلِّهِ فِي سَبِيلِ اللَّهِ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قَالَ يَعْنِي بِثُلُثَيْهِ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قَالَ فَنِصْفَهُ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قَالَ فَثُلُثَهُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الثُّلُثَ وَالثُّلُثُ كَثِيرٌ إِنَّكَ أَنْ تَتْرُكَ بَنِيكَ أَغْنِيَاءَ خَيْرٌ مِنْ أَنْ تَتْرُكَهُمْ عَالَةً يَتَكَفَّفُونَ النَّاسَ ‏"‏‏.‏\hadithno{3630}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Amir bin Sa'd (narrated) from his father that he fell sick in Makkah and the Messenger of Allah came to him. When Sa'd saw him, he wept and said:"O Messenger of Allah, am I to die in the land from which I emigrated?" He said: "No, if Allah wills." He said: "O Messenger of Allah, shall I bequeath all of my wealth in the cause of Allah?" He said: "No." He said: "Two-thirds?" He said: "No." He said: "Half of it?" He said: "No." He said: "One-third of it?" The Messenger of Allah said: "One-third, and one-third is a lot. If you leave your sons independent of means that is better than if you leave them poor, holding out their hands to people}}
\hadithdefcmd{nasai}{3631}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ عَادَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مَرَضِي فَقَالَ ‏"‏ أَوْصَيْتَ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ بِكَمْ ‏"‏‏.‏ قُلْتُ بِمَالِي كُلِّهِ فِي سَبِيلِ اللَّهِ‏.‏ قَالَ ‏"‏ فَمَا تَرَكْتَ لِوَلدِكَ ‏"‏‏.‏ قُلْتُ هُمْ أَغْنِيَاءُ‏.‏ قَالَ ‏"‏ أَوْصِ بِالْعُشْرِ ‏"‏‏.‏ فَمَا زَالَ يَقُولُ وَأَقُولُ حَتَّى قَالَ ‏"‏ أَوْصِ بِالثُّلُثِ وَالثُّلُثُ كَثِيرٌ أَوْ كَبِيرٌ ‏"‏‏.‏\hadithno{3631}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif}\hadithtrans{It was narrated that Sa'd bin Abi Waqqas said:"The Messenger of Allah visited me when I was sick, and said: 'Have you made a will?' I said: 'Yes.' He said: 'How much?' I said: 'For all my wealth to be given in the cause of Allah.' He said: 'What have you left for your children?' I said: 'They are rich (independent of means).' He said: 'Bequeath one-tenth.' And we kept discussing it until he said: 'Bequeath one-third, and one-third is much or large}}
\hadithdefcmd{nasai}{3632}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ سَعْدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم عَادَهُ فِي مَرَضِهِ فَقَالَ يَا رَسُولَ اللَّهِ أُوصِي بِمَالِي كُلِّهِ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قَالَ فَالشَّطْرَ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قَالَ فَالثُّلُثَ قَالَ ‏"‏ الثُّلُثَ وَالثُّلُثُ كَثِيرٌ أَوْ كَبِيرٌ ‏"‏‏.‏\hadithno{3632}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Sa'd that the Prophet visited him when he was sick, and he said:"O Messenger of Allah, shall I bequeath all of my wealth?" He said: "No." He said: "Half?" He said: "No." He said: "One-third?" He said: "One-third, and one-third is much or large}}
\hadithdefcmd{nasai}{3633}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْوَلِيدِ الْفَحَّامُ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ رَبِيعَةَ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَى سَعْدًا يَعُودُهُ فَقَالَ لَهُ سَعْدٌ يَا رَسُولَ اللَّهِ أُوصِي بِثُلُثَىْ مَالِي قَالَ ‏"‏ لاَ ‏"‏‏.‏ قَالَ فَأُوصِي بِالنِّصْفِ قَالَ ‏"‏ لاَ ‏"‏‏.‏ قَالَ فَأُوصِي بِالثُّلُثِ قَالَ ‏"‏ نَعَمِ الثُّلُثَ وَالثُّلُثُ كَثِيرٌ أَوْ كَبِيرٌ إِنَّكَ أَنْ تَدَعَ وَرَثَتَكَ أَغْنِيَاءَ خَيْرٌ مِنْ أَنْ تَدَعَهُمْ فُقَرَاءَ يَتَكَفَّفُونَ ‏"‏‏.‏\hadithno{3633}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Aishah that the Messenger of Allah came to visit Sa'd (when he was sick). Sa'd said to him:"O Messenger of Allah, shall I bequeath two-thirds of my wealth?" He said: "No." He said: "Shall I bequeath half?" He said: "No." He said: "Shall I bequeath one-third?" He said: "Yes, one-third, and one-third is much or large. If you leave your heirs independent of means that is better than if you leave them poor, holding out their hands}}
\hadithdefcmd{nasai}{3634}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَوْ غَضَّ النَّاسُ إِلَى الرُّبُعِ لأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الثُّلُثَ وَالثُّلُثُ كَثِيرٌ أَوْ كَبِيرٌ ‏"‏‏.‏\hadithno{3634}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"If the people were to reduce (their bequests) to one-quarter (of their wealth, that would be better), because the Messenger of Allah said: 'One-third, and one-third is much or large}}
\hadithdefcmd{nasai}{3635}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا حَجَّاجُ بْنُ الْمِنْهَالِ، قَالَ حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ يُونُسَ بْنِ جُبَيْرٍ، عَنْ مُحَمَّدِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، سَعْدِ بْنِ مَالِكٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم جَاءَهُ وَهُوَ مَرِيضٌ فَقَالَ إِنَّهُ لَيْسَ لِي وَلَدٌ إِلاَّ ابْنَةٌ وَاحِدَةٌ فَأُوصِي بِمَالِي كُلِّهِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ ‏"‏‏.‏ قَالَ فَأُوصِي بِنِصْفِهِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ ‏"‏‏.‏ قَالَ فَأُوصِي بِثُلُثِهِ قَالَ ‏"‏ الثُّلُثَ وَالثُّلُثُ كَثِيرٌ ‏"‏‏.‏\hadithno{3635}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Muhammad bin Sa'd, from his father Sa'd bin Malik, that the Prophet came to him when he was sick and he said:"I do not have any children apart from one daughter. Shall I bequeath all my wealth?" The Prophet said: "No." He said: "Shall I bequeath half of it?" The Prophet said: "No." He said: "Shall I bequeath one-third of it?" He said: "One-third, and one-third is much or large}}
\hadithdefcmd{nasai}{3636}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا بْنِ دِينَارٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ شَيْبَانَ، عَنْ فِرَاسٍ، عَنِ الشَّعْبِيِّ، قَالَ حَدَّثَنِي جَابِرُ بْنُ عَبْدِ اللَّهِ، أَنَّ أَبَاهُ، اسْتُشْهِدَ يَوْمَ أُحُدٍ وَتَرَكَ سِتَّ بَنَاتٍ وَتَرَكَ عَلَيْهِ دَيْنًا فَلَمَّا حَضَرَ جُدَادُ النَّخْلِ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ قَدْ عَلِمْتَ أَنَّ وَالِدِي اسْتُشْهِدَ يَوْمَ أُحُدٍ وَتَرَكَ دَيْنًا كَثِيرًا وَإِنِيِّ أُحِبُّ أَنْ يَرَاكَ الْغُرَمَاءُ‏.‏ قَالَ ‏"‏ اذْهَبْ فَبَيْدِرْ كُلَّ تَمْرٍ عَلَى نَاحِيَةٍ ‏"‏‏.‏ فَفَعَلْتُ ثُمَّ دَعَوْتُهُ فَلَمَّا نَظَرُوا إِلَيْهِ كَأَنَّمَا أُغْرُوا بِي تِلْكَ السَّاعَةَ فَلَمَّا رَأَى مَا يَصْنَعُونَ أَطَافَ حَوْلَ أَعْظَمِهَا بَيْدَرًا ثَلاَثَ مَرَّاتٍ ثُمَّ جَلَسَ عَلَيْهِ ثُمَّ قَالَ ‏"‏ ادْعُ أَصْحَابَكَ ‏"‏‏.‏ فَمَا زَالَ يَكِيلُ لَهُمْ حَتَّى أَدَّى اللَّهُ أَمَانَةَ وَالِدِي وَأَنَا رَاضٍ أَنْ يُؤَدِّيَ اللَّهُ أَمَانَةَ وَالِدِي لَمْ تَنْقُصْ تَمْرَةً وَاحِدَةً‏.‏\hadithno{3636}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Jabir bin 'Abdullah narrated that his father was martyred on the Day of Uhud, and he left behind six daughters, and some outstanding debts. When the time to pick the dates came, I went to the Messenger of Allah and said:"You know that my father was martyred on the Day of Uhud and he left behind a great deal of debt. I would like the creditors to see you." He said: "Go and pile up the dates in separate heaps." I did that, then I called him. When they saw him, it was as if they started to put pressure on me at that time. When he saw what they were doing, he went around the biggest heap three times, then he sat on it then said: "Call your companions (the creditors)." Then he kept on weighing them out for them, until Allah cleared all my father's debts. I am pleased that Allah cleared my father's debts without even a single date being missed}}
\hadithdefcmd{nasai}{3637}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ سَلاَّمٍ، قَالَ حَدَّثَنَا إِسْحَاقُ، - وَهُوَ الأَزْرَقُ - قَالَ حَدَّثَنَا زَكَرِيَّا، عَنِ الشَّعْبِيِّ، عَنْ جَابِرٍ، أَنَّ أَبَاهُ، تُوُفِّيَ وَعَلَيْهِ دَيْنٌ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أَبِي تُوُفِّيَ وَعَلَيْهِ دَيْنٌ وَلَمْ يَتْرُكْ إِلاَّ مَا يُخْرِجُ نَخْلُهُ وَلاَ يَبْلُغُ مَا يُخْرِجُ نَخْلُهُ مَا عَلَيْهِ مِنَ الدَّيْنِ دُونَ سِنِينَ فَانْطَلِقْ مَعِي يَا رَسُولَ اللَّهِ لِكَىْ لاَ يَفْحُشَ عَلَىَّ الْغُرَّامُ فَأَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم يَدُورُ بَيْدَرًا بَيْدَرًا فَسَلَّمَ حَوْلَهُ وَدَعَا لَهُ ثُمَّ جَلَسَ عَلَيْهِ وَدَعَا الْغُرَّامَ فَأَوْفَاهُمْ وَبَقِيَ مِثْلُ مَا أَخَذُوا‏.‏\hadithno{3637}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir that his father died owing debts. "I came to the Prophet and said:'(O Messenger of Allah!) My father has died owing debts, and he has not left anything but what his date-palms produce. What his date-palms produce will not pay off his debts for years. Come with me, O Messenger of Allah, so that the creditors will not be harsh with me.' The Messenger of Allah went to each heap, saying Salams and supplicating for it, then sitting on it. He called the creditors and paid them off, and what was left was as much as what they had taken}}
\hadithdefcmd{nasai}{3638}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مُغِيرَةَ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرٍ، قَالَ تُوُفِّيَ عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ حَرَامٍ - قَالَ - وَتَرَكَ دَيْنًا فَاسْتَشْفَعْتُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى غُرَمَائِهِ أَنْ يَضَعُوا مِنْ دَيْنِهِ شَيْئًا فَطَلَبَ إِلَيْهِمْ فَأَبَوْا فَقَالَ لِي النَّبِيُّ صلى الله عليه وسلم ‏"‏ اذْهَبْ فَصَنِّفْ تَمْرَكَ أَصْنَافًا الْعَجْوَةَ عَلَى حِدَةٍ وَعَذْقَ ابْنِ زَيْدٍ عَلَى حِدَةٍ وَأَصْنَافَهُ ثُمَّ ابْعَثْ إِلَىَّ ‏"‏‏.‏ قَالَ فَفَعَلْتُ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَلَسَ فِي أَعْلاَهُ أَوْ فِي أَوْسَطِهِ ثُمَّ قَالَ ‏"‏ كِلْ لِلْقَوْمِ ‏"‏‏.‏ قَالَ فَكِلْتُ لَهُمْ حَتَّى أَوْفَيْتُهُمْ ثُمَّ بَقِيَ تَمْرِي كَأَنْ لَمْ يَنْقُصْ مِنْهُ شَىْءٌ‏.‏\hadithno{3638}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir said:"Abdullah bin 'Amr bin Haram died, leaving behind debts. I asked the Messenger of Allah to intercede with his creditors so that they would waive part of the debt. He asked them to do that but they refused. The Prophet said to me: 'Go and sort your dates into their different kinds: The 'Ajwah on one side, the cluster of Ibn Zaid on another side, and so on. Then send for me.' I did that, then the Messenger of Allah came and sat at the head or in the middle of the heaps. Then he said: 'Measure them out for the people.' So I measured them out for them until I had paid them all off, and my dates were left as if nothing had been taken from them}}
\hadithdefcmd{nasai}{3639}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يُونُسَ بْنِ مُحَمَّدٍ، - حَرَمِيٌّ - قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا حَمَّادٌ، عَنْ عَمَّارِ بْنِ أَبِي عَمَّارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ لِيَهُودِيٍّ عَلَى أَبِي تَمْرٌ فَقُتِلَ يَوْمَ أُحُدٍ وَتَرَكَ حَدِيقَتَيْنِ وَتَمْرُ الْيَهُودِيِّ يَسْتَوْعِبُ مَا فِي الْحَدِيقَتَيْنِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلْ لَكَ أَنْ تَأْخُذَ الْعَامَ نِصْفَهُ وَتُؤَخِّرَ نِصْفَهُ ‏"‏‏.‏ فَأَبَى الْيَهُودِيُّ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلْ لَكَ أَنْ تَأْخُذَ الْجُدَادَ ‏"‏‏.‏ فَآذِنِّي فَآذَنْتُهُ فَجَاءَ هُوَ وَأَبُو بَكْرٍ فَجَعَلَ يُجَدُّ وَيُكَالُ مِنْ أَسْفَلِ النَّخْلِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُو بِالْبَرَكَةِ حَتَّى وَفَيْنَاهُ جَمِيعَ حَقِّهِ مِنْ أَصْغَرِ الْحَدِيقَتَيْنِ - فِيمَا يَحْسِبُ عَمَّارٌ - ثُمَّ أَتَيْتُهُمْ بِرُطَبٍ وَمَاءٍ فَأَكَلُوا وَشَرِبُوا ثُمَّ قَالَ ‏"‏ هَذَا مِنَ النَّعِيمِ الَّذِي تُسْأَلُونَ عَنْهُ ‏"‏‏.‏\hadithno{3639}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"My father owed some dates to a Jew. He was killed on the Day of Uhud and he left behind two gardens. The dates owed to the Jew would take up everything in the two gardens. The Prophet said: 'Can you take half this year and half next year?' But the Jew refused. The Prophet said: 'When the time to pick the dates comes, call me.' So I called him and he came, accompanied by Abu Bakr. The dates were picked and weighed from the lowest part of the palm trees, and the Messenger of Allah was praying for blessing, until we paid off everything that we owed him from the smaller of the two gardens, as calculated by 'Ammar. Then I brought them some fresh dates and water and they ate and drank, then he said: 'This is part of the blessing concerning which you will be questioned}}
\hadithdefcmd{nasai}{3640}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ حَدِيثِ عَبْدِ الْوَهَّابِ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ تُوُفِّيَ أَبِي وَعَلَيْهِ دَيْنٌ فَعَرَضْتُ عَلَى غُرَمَائِهِ أَنْ يَأْخُذُوا الثَّمَرَةَ بِمَا عَلَيْهِ فَأَبَوْا وَلَمْ يَرَوْا فِيهِ وَفَاءً فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ قَالَ ‏"‏ إِذَا جَدَدْتَهُ فَوَضَعْتَهُ فِي الْمِرْبَدِ فَآذِنِّي ‏"‏‏.‏ فَلَمَّا جَدَدْتُهُ وَوَضَعْتُهُ فِي الْمِرْبَدِ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَجَاءَ وَمَعَهُ أَبُو بَكْرٍ وَعُمَرُ فَجَلَسَ عَلَيْهِ وَدَعَا بِالْبَرَكَةِ ثُمَّ قَالَ ‏"‏ ادْعُ غُرَمَاءَكَ فَأَوْفِهِمْ ‏"‏‏.‏ قَالَ فَمَا تَرَكْتُ أَحَدًا لَهُ عَلَى أَبِي دَيْنٌ إِلاَّ قَضَيْتُهُ وَفَضَلَ لِي ثَلاَثَةَ عَشَرَ وَسْقًا فَذَكَرْتُ ذَلِكَ لَهُ فَضَحِكَ وَقَالَ ‏"‏ ائْتِ أَبَا بَكْرٍ وَعُمَرَ فَأَخْبِرْهُمَا ذَلِكَ ‏"‏‏.‏ فَأَتَيْتُ أَبَا بَكْرٍ وَعُمَرَ فَأَخْبَرْتُهُمَا فَقَالاَ قَدْ عَلِمْنَا إِذْ صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا صَنَعَ أَنَّهُ سَيَكُونُ ذَلِكَ‏.‏\hadithno{3640}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"My father died owing debts. I offered to his creditors that they could take the fruits in lieu of what he owed them, but they refused as they thought that it would not cover the debt. I went to the Messenger of Allah and told him about that, he said: 'When you pick the dates and have put them in the Mirbad (place for drying dates), call me.' When I had picked the dates and put them in the Mirbad, I went to the Messenger of Allah and he came, accompanied by Abu Bakr and 'Umar. He sat on (the dates) and prayed for blessing. Then he said: 'Call your creditors and pay them off.' I did not leave anyone to whom my father owed anything but I paid him off, and I had thirteen Wasqs left over. I mentioned that to him and he smiled and said: 'Go to Abu Bakr and 'Umar and tell them about that.' So I went to Abu Bakr and 'Umar and told them about that, and they said: 'We knew, when the Messenger of Allah did what he did, that this would happen}}
\hadithdefcmd{nasai}{3641}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ، عَنْ عَمْرِو بْنِ خَارِجَةَ، قَالَ خَطَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّ اللَّهَ قَدْ أَعْطَى كُلَّ ذِي حَقٍّ حَقَّهُ وَلاَ وَصِيَّةَ لِوَارِثٍ ‏"‏‏.‏\hadithno{3641}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Amr bin Kharijah said:"The Messenger of Allah delivered a Khutbah and said: 'Allah has given every person who has rights his due, and there is no bequest to an heir}}
\hadithdefcmd{nasai}{3642}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا سَعِيدٌ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، أَنَّ ابْنَ غَنْمٍ، ذَكَرَ أَنَّ ابْنَ خَارِجَةَ، ذَكَرَ لَهُ أَنَّهُ شَهِدَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَخْطُبُ النَّاسَ عَلَى رَاحِلَتِهِ وَإِنَّهَا لَتَقْصَعُ بِجِرَّتِهَا وَإِنَّ لُعَابَهَا لَيَسِيلُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي خُطْبَتِهِ ‏ "‏ إِنَّ اللَّهَ قَدْ قَسَّمَ لِكُلِّ إِنْسَانٍ قِسْمَهُ مِنَ الْمِيرَاثِ فَلاَ تَجُوزُ لِوَارِثٍ وَصِيَّةٌ ‏"‏‏.‏\hadithno{3642}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Shahr bin Hawshab that Ibn Ghanm mentioned that Ibn Kharijah told him that he saw the Messenger of Allah addressing the people from atop his mount, which was chewing its cud and its saliva was dripping down. The Messenger of Allah said in his Khutbah:"Allah has given each person a share of the inheritance, and it is not permissible to give bequests to an heir}}
\hadithdefcmd{nasai}{3643}{أَخْبَرَنَا عُتْبَةُ بْنُ عَبْدِ اللَّهِ الْمَرْوَزِيُّ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ قَتَادَةَ، عَنْ عَمْرِو بْنِ خَارِجَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ عَزَّ اسْمُهُ قَدْ أَعْطَى كُلَّ ذِي حَقٍّ حَقَّهُ وَلاَ وَصِيَّةَ لِوَارِثٍ ‏"‏‏.‏\hadithno{3643}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Amr bin Kharijah said:"The Messenger of Allah said: 'Allah, Mighty is His Name, has given every person who has rights his due, and there is no bequest to an heir}}
\hadithdefcmd{nasai}{3644}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَمَّا نَزَلَتْ ‏\{‏وَأَنْذِرْ عَشِيرَتَكَ الأَقْرَبِينَ‏\}‏ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم قُرَيْشًا فَاجْتَمَعُوا فَعَمَّ وَخَصَّ فَقَالَ ‏"‏ يَا بَنِي كَعْبِ بْنِ لُؤَىٍّ يَا بَنِي مُرَّةَ بْنِ كَعْبٍ يَا بَنِي عَبْدِ شَمْسٍ وَيَا بَنِي عَبْدِ مَنَافٍ وَيَا بَنِي هَاشِمٍ وَيَا بَنِي عَبْدِ الْمُطَّلِبِ أَنْقِذُوا أَنْفُسَكُمْ مِنَ النَّارِ وَيَا فَاطِمَةُ أَنْقِذِي نَفْسَكِ مِنَ النَّارِ إِنِّي لاَ أَمْلِكُ لَكُمْ مِنَ اللَّهِ شَيْئًا غَيْرَ أَنَّ لَكُمْ رَحِمًا سَأَبُلُّهَا بِبِلاَلِهَا ‏"‏‏.‏\hadithno{3644}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"When the following was revealed: 'And warn your tribe (O Muhammad) of near kindred,' the Messenger of Allah called the Quraish and they gathered, and he spoke in general and specific terms, then he said: 'O Banu Ka'b bin Lu'ayy! O Banu Murrah bin Ka'b! O Banu 'Abd Shams! O Banu 'Abd Manaf! O Banu Hisham! O Banu 'Abdul-Muttalib! Save yourselves from the Fire! O Fatimah! Save yourself from the Fire. I cannot avail you anything before Allah, but I will uphold the ties of kinship with you}}
\hadithdefcmd{nasai}{3645}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، قَالَ أَنْبَأَنَا إِسْرَائِيلُ، عَنْ مُعَاوِيَةَ، - وَهُوَ ابْنُ إِسْحَاقَ - عَنْ مُوسَى بْنِ طَلْحَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا بَنِي عَبْدِ مَنَافٍ اشْتَرُوا أَنْفُسَكُمْ مِنْ رَبِّكُمْ إِنِّي لاَ أَمْلِكُ لَكُمْ مِنَ اللَّهِ شَيْئًا يَا بَنِي عَبْدِ الْمُطَّلِبِ اشْتَرُوا أَنْفُسَكُمْ مِنْ رَبِّكُمْ إِنِّي لاَ أَمْلِكُ لَكُمْ مِنَ اللَّهِ شَيْئًا وَلَكِنْ بَيْنِي وَبَيْنَكُمْ رَحِمٌ أَنَا بَالُّهَا بِبِلاَلِهَا ‏"‏‏.‏\hadithno{3645}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Musa bin Talhah said:"The Messenger of Allah said: 'O Banu 'Abd Manaf! Buy your souls from your Lord. I cannot avail you anything before Allah. Abu Banu 'Abdul-Muttalib! Buy your souls from your Lord. I cannot avail you anything before Allah. But between me and you there are ties of kinship which I will uphold}}
\hadithdefcmd{nasai}{3646}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ أُنْزِلَ عَلَيْهِ ‏\{‏وَأَنْذِرْ عَشِيرَتَكَ الأَقْرَبِينَ‏\}‏ قَالَ ‏"‏ يَا مَعْشَرَ قُرَيْشٍ اشْتَرُوا أَنْفُسَكُمْ مِنَ اللَّهِ لاَ أُغْنِي عَنْكُمْ مِنَ اللَّهِ شَيْئًا يَا بَنِي عَبْدِ الْمُطَّلِبِ لاَ أُغْنِي عَنْكُمْ مِنَ اللَّهِ شَيْئًا يَا عَبَّاسُ بْنَ عَبْدِ الْمُطَّلِبِ لاَ أُغْنِي عَنْكَ مِنَ اللَّهِ شَيْئًا يَا صَفِيَّةُ عَمَّةَ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ أُغْنِي عَنْكِ مِنَ اللَّهِ شَيْئًا يَا فَاطِمَةُ بِنْتَ مُحَمَّدٍ سَلِينِي مَا شِئْتِ لاَ أُغْنِي عَنْكِ مِنَ اللَّهِ شَيْئًا ‏"‏‏.‏\hadithno{3646}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said, when the Verse: 'And warn your tribe (O Muhammad) of near kindred.' was revealed: 'O Quraish! Buy your souls from your Lord; I cannot avail you anything before Allah. O Banu 'Abdul-Muttalib! I cannot avail you anything before Allah. O 'Abbas bin 'Abdul-Muttalib! I cannot avail you anything before Allah. O Safiyyah, paternal aunt of the Messenger of Allah! I cannot avail you anything before Allah. O Fatimah bint Muhammad! Ask me for whatever you want, I cannot avail you anything before Allah}}
\hadithdefcmd{nasai}{3647}{أَخْبَرَنَا مُحَمَّدُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا بِشْرُ بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ أُنْزِلَ عَلَيْهِ ‏\{‏وَأَنْذِرْ عَشِيرَتَكَ الأَقْرَبِينَ‏\}‏ فَقَالَ ‏"‏ يَا مَعْشَرَ قُرَيْشٍ اشْتَرُوا أَنْفُسَكُمْ مِنَ اللَّهِ لاَ أُغْنِي عَنْكُمْ مِنَ اللَّهِ شَيْئًا يَا بَنِي عَبْدِ مَنَافٍ لاَ أُغْنِي عَنْكُمْ مِنَ اللَّهِ شَيْئًا يَا عَبَّاسُ بْنَ عَبْدِ الْمُطَّلِبِ لاَ أُغْنِي عَنْكَ مِنَ اللَّهِ شَيْئًا يَا صَفِيَّةُ عَمَّةَ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ أُغْنِي عَنْكِ مِنَ اللَّهِ شَيْئًا يَا فَاطِمَةُ سَلِينِي مَا شِئْتِ لاَ أُغْنِي عَنْكِ مِنَ اللَّهِ شَيْئًا ‏"‏‏.‏\hadithno{3647}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Hurairah said:"The Messenger of Allah stood up when the following was revealed to him: 'And warn your tribe (O Muhammad) of near kindred,' and said: 'O Quraish! Buy your souls from your Lord, I cannot avail you anything before Allah. O Banu 'Abd Manaf! I cannot avail you anything before Allah. O 'Abbas bin 'Abdul-Muttalib! I cannot avail you anything before Allah. O Safiyyah, paternal aunt of the Messenger of Allah! I cannot avail you anything before Allah. O Fatimah! Ask me for whatever you want, I cannot avail you anything before Allah}}
\hadithdefcmd{nasai}{3648}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا هِشَامٌ، - وَهُوَ ابْنُ عُرْوَةَ - عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏وَأَنْذِرْ عَشِيرَتَكَ الأَقْرَبِينَ‏\}‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا فَاطِمَةُ ابْنَةَ مُحَمَّدٍ يَا صَفِيَّةُ بِنْتَ عَبْدِ الْمُطَّلِبِ يَا بَنِي عَبْدِ الْمُطَّلِبِ لاَ أُغْنِي عَنْكُمْ مِنَ اللَّهِ شَيْئًا سَلُونِي مِنْ مَالِي مَا شِئْتُمْ ‏"‏‏.‏\hadithno{3648}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"When this verse- 'And warn your tribe (O Muhammad) of near kindred'- was revealed, the Messenger of Allah said: 'O Fatimah, daughter of Muhammad! O Safiyyah bint 'Abdul-Muttalib! O Banu 'Abdul-Muttalib! I cannot avail you anything before Allah; ask me for whatever you want of my wealth}}
\hadithdefcmd{nasai}{3649}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَجُلاً، قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّ أُمِّي افْتُلِتَتْ نَفْسُهَا وَإِنَّهَا لَوْ تَكَلَّمَتْ تَصَدَّقَتْ أَفَأَتَصَدَّقُ عَنْهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَعَمْ ‏"‏‏.‏ فَتَصَدَّقَ عَنْهَا‏.‏\hadithno{3649}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Aishah that a man said to the Messenger of Allah:"My mother died unexpectedly; if she had been able to speak she would have given charity. Should I give charity on her behalf?" The Messenger of Allah said: "Yes." So he gave charity on her behalf}}
\hadithdefcmd{nasai}{3650}{أَنْبَأَنَا الْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ سَعِيدِ بْنِ عَمْرِو بْنِ شُرَحْبِيلَ بْنِ سَعِيدِ بْنِ سَعْدِ بْنِ عُبَادَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ خَرَجَ سَعْدُ بْنُ عُبَادَةَ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي بَعْضِ مَغَازِيهِ وَحَضَرَتْ أُمَّهُ الْوَفَاةُ بِالْمَدِينَةِ فَقِيلَ لَهَا أَوْصِي‏.‏ فَقَالَتْ فِيمَ أُوصِي الْمَالُ مَالُ سَعْدٍ‏.‏ فَتُوُفِّيَتْ قَبْلَ أَنْ يَقْدَمَ سَعْدٌ فَلَمَّا قَدِمَ سَعْدٌ ذُكِرَ ذَلِكَ لَهُ فَقَالَ يَا رَسُولَ اللَّهِ هَلْ يَنْفَعُهَا أَنْ أَتَصَدَّقَ عَنْهَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ نَعَمْ ‏"‏‏.‏ فَقَالَ سَعْدٌ حَائِطُ كَذَا وَكَذَا صَدَقَةٌ عَنْهَا لِحَائِطٍ سَمَّاهُ‏.‏\hadithno{3650}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Sa'eed bin 'Amr bin Shurahbil bin Sa'eed bin Sa'd bin 'Ubadah, from his father, that his grandfather said:"Sa'd bin 'Ubadah went out with the Prophet on one of his campaigns, and death came to his mother in Al-Madinah. It was said to her (as she was dying): 'Make a will.' She said: 'To whom shall I make a will? The wealth belongs to Sa'd.' Then she died before Sa'd came. When Sa'd came, he was told about that and he said: 'O Messenger of Allah, will it benefit her if I give in charity on her behalf?' The Prophet said: 'Yes.' Sa'd said: 'Such and such a garden is given in charity on her behalf' -regarding a garden that he named}}
\hadithdefcmd{nasai}{3651}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا الْعَلاَءُ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا مَاتَ الإِنْسَانُ انْقَطَعَ عَمَلُهُ إِلاَّ مِنْ ثَلاَثَةٍ مِنْ صَدَقَةٍ جَارِيَةٍ وَعِلْمٍ يُنْتَفَعُ بِهِ وَوَلَدٍ صَالِحٍ يَدْعُو لَهُ ‏"‏‏.‏\hadithno{3651}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"When a man dies all his good deeds come to an end except three: Ongoing charity (Sadaqah Jariyah), beneficial knowledge and a righteous son who prays for him}}
\hadithdefcmd{nasai}{3652}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، قَالَ لِلنَّبِيِّ صلى الله عليه وسلم إِنَّ أَبِي مَاتَ وَتَرَكَ مَالاً وَلَمْ يُوصِ فَهَلْ يُكَفِّرُ عَنْهُ أَنْ أَتَصَدَّقَ عَنْهُ قَالَ ‏ "‏ نَعَمْ ‏"‏‏.‏\hadithno{3652}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that a man said to the Prophet:"My father died and left behind wealth, but he did not leave a will. Will it expiate for him if I give charity on his behalf?}}
\hadithdefcmd{nasai}{3653}{أَخْبَرَنَا مُوسَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنِ الشَّرِيدِ بْنِ سُوَيْدٍ الثَّقَفِيِّ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ إِنَّ أُمِّي أَوْصَتْ أَنْ تُعْتَقَ عَنْهَا رَقَبَةٌ وَإِنَّ عِنْدِي جَارِيَةً نُوبِيَّةً أَفَيُجْزِئُ عَنِّي أَنْ أَعْتِقَهَا عَنْهَا قَالَ ‏"‏ ائْتِنِي بِهَا ‏"‏‏.‏ فَأَتَيْتُهُ بِهَا فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ رَبُّكِ ‏"‏‏.‏ قَالَتِ اللَّهُ‏.‏ قَالَ ‏"‏ مَنْ أَنَا ‏"‏‏.‏ قَالَتْ أَنْتَ رَسُولُ اللَّهِ‏.‏ قَالَ ‏"‏ فَأَعْتِقْهَا فَإِنَّهَا مُؤْمِنَةٌ ‏"‏‏.‏\hadithno{3653}\hadithgrade{Abu Ghuddah: Hasan Isnaad; Al-Albani: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ash-Sharid bin Suwaid Ath-Thaqafi said:"I came to the Messenger of Allah and said: 'My mother left a will saying that a slave should be freed on her behalf. I have a Nubian slave girl; will it suffice if I free her on her behalf?' He said: 'Bring her here.' The Prophet said to her: 'Who is your Lord?' She said: 'Allah.' He said: 'Who am I?' She said: 'The Messenger of Allah.' He said: 'Set her free , for she is a believer}}
\hadithdefcmd{nasai}{3654}{أَخْبَرَنَا الْحُسَيْنُ بْنُ عِيسَى، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ سَعْدًا، سَأَلَ النَّبِيَّ صلى الله عليه وسلم إِنَّ أُمِّي مَاتَتْ وَلَمْ تُوصِ أَفَأَتَصَدَّقُ عَنْهَا قَالَ ‏ "‏ نَعَمْ ‏"‏‏.‏\hadithno{3654}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Abbas that Sa'd asked the Prophet:"My mother died and did not leave a will; shall I give charity on her behalf?" He said: "Yes}}
\hadithdefcmd{nasai}{3655}{أَخْبَرَنَا أَحْمَدُ بْنُ الأَزْهَرِ، قَالَ حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، قَالَ حَدَّثَنَا زَكَرِيَّا بْنُ إِسْحَاقَ، قَالَ حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمَّهُ تُوُفِّيَتْ أَفَيَنْفَعُهَا إِنْ تَصَدَّقْتُ عَنْهَا قَالَ ‏ "‏ نَعَمْ ‏"‏‏.‏ قَالَ فَإِنَّ لِي مَخْرَفًا فَأُشْهِدُكَ أَنِّي قَدْ تَصَدَّقْتُ بِهِ عَنْهَا‏.‏\hadithno{3655}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Abbas that a man said:"O Messenger of Allah, my mother died; will it benefit her if I give in charity on her behalf?" He said: "Yes." He said: "I have a garden and I ask you to bear witness that I am giving it in charity on her behalf}}
\hadithdefcmd{nasai}{3656}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا عَفَّانُ، قَالَ حَدَّثَنَا سُلَيْمَانُ بْنُ كَثِيرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ سَعْدِ بْنِ عُبَادَةَ، أَنَّهُ أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنَّ أُمِّي مَاتَتْ وَعَلَيْهَا نَذْرٌ أَفَيُجْزِئُ عَنْهَا أَنْ أَعْتِقَ عَنْهَا قَالَ ‏ "‏ أَعْتِقْ عَنْ أُمِّكَ ‏"‏‏.‏\hadithno{3656}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Sa'd bin 'Ubadah that he came to the Prophet and said:"My mother has died and she had a vow to fulfill. Will it suffice if I free a slave on her behalf?" He said: "Free a slave on behalf of your mother}}
\hadithdefcmd{nasai}{3657}{أَخْبَرَنَا مُحَمَّدُ بْنُ أَحْمَدَ أَبُو يُوسُفَ الصَّيْدَلاَنِيُّ، عَنْ عِيسَى، - وَهُوَ ابْنُ يُونُسَ - عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، أَخْبَرَهُ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ سَعْدِ بْنِ عُبَادَةَ، أَنَّهُ اسْتَفْتَى النَّبِيَّ صلى الله عليه وسلم فِي نَذْرٍ كَانَ عَلَى أُمِّهِ فَتُوُفِّيَتْ قَبْلَ أَنْ تَقْضِيَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْضِهِ عَنْهَا ‏"‏‏.‏\hadithno{3657}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Sa'd bin 'Ubadah that he consulted the Prophet about a vow which his mother had to fulfill, but she died before doing so. The Messenger of Allah said:"Fulfill it on her behalf}}
\hadithdefcmd{nasai}{3658}{أَخْبَرَنَا مُحَمَّدُ بْنُ صَدَقَةَ الْحِمْصِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، أَخْبَرَهُ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ سَعْدِ بْنِ عُبَادَةَ، أَنَّهُ اسْتَفْتَى النَّبِيَّ صلى الله عليه وسلم فِي نَذْرٍ كَانَ عَلَى أُمِّهِ فَمَاتَتْ قَبْلَ أَنْ تَقْضِيَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْضِهِ عَنْهَا ‏"‏‏.‏\hadithno{3658}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Sa'd bin 'Ubadah that he consulted the Prophet about a vow which his mother had to fulfill, but she died before doing so. The Messenger of Allah said:"Fulfill it on her behalf}}
\hadithdefcmd{nasai}{3659}{أَخْبَرَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ بْنِ مَزْيَدَ، قَالَ أَخْبَرَنِي أَبِي قَالَ، حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ أَخْبَرَنِي الزُّهْرِيُّ، أَنَّ عُبَيْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ، أَخْبَرَهُ عَنِ ابْنِ عَبَّاسٍ، قَالَ اسْتَفْتَى سَعْدٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي نَذْرٍ كَانَ عَلَى أُمِّهِ فَتُوُفِّيَتْ قَبْلَ أَنْ تَقْضِيَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْضِهِ عَنْهَا ‏"‏‏.‏\hadithno{3659}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"Sa'd consulted the Messenger of Allah about a vow which his mother had to fulfill, but she died before doing so. The Messenger of Allah said: 'Fulfill it on her behalf}}
\hadithdefcmd{nasai}{3660}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ سَعْدَ بْنَ عُبَادَةَ، اسْتَفْتَى النَّبِيَّ صلى الله عليه وسلم فِي نَذْرٍ كَانَ عَلَى أُمِّهِ فَتُوُفِّيَتْ قَبْلَ أَنْ تَقْضِيَهُ فَقَالَ ‏ "‏ اقْضِهِ عَنْهَا ‏"‏‏.‏\hadithno{3660}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Harith bin Miskin said, it being read to him while I was listening:"From Sufyan, from Az-Zuhri, from 'Ubaidullah bin 'Abdullah, from Ibn 'Abbas, that Sa'd bin 'Ubadah consulted the Prophet about a vow which his mother had to fulfill, but she died before doing so. The Messenger of Allah said: 'Fulfill it on her behalf}}
\hadithdefcmd{nasai}{3661}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ سَعْدٍ، أَنَّهُ قَالَ مَاتَتْ أُمِّي وَعَلَيْهَا نَذْرٌ فَسَأَلْتُ النَّبِيَّ صلى الله عليه وسلم فَأَمَرَنِي أَنْ أَقْضِيَهُ عَنْهَا‏.‏\hadithno{3661}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{Muhammad bin 'Abdullah bin Yazid said:"Sufyan narrated to us from Az-Zuhri, from 'Ubaidullah bin 'Abdullah, from Ibn 'Abbas, that Sa'd said: 'My mother died and there was an (outstanding) vow that she had to fulfill. I asked the Prophet and he told me to fulfill it on her behalf}}
\hadithdefcmd{nasai}{3662}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ اسْتَفْتَى سَعْدُ بْنُ عُبَادَةَ الأَنْصَارِيُّ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي نَذْرٍ كَانَ عَلَى أُمِّهِ فَتُوُفِّيَتْ قَبْلَ أَنْ تَقْضِيَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اقْضِهِ عَنْهَا ‏"‏‏.‏\hadithno{3662}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"Sa'd bin 'Ubadah Al-Ansari consulted the Messenger of Allah about an (outstanding) vow that his mother had to fulfill, but she died before doing so. The Messenger of Allah said: 'Fulfill it on her behalf}}
\hadithdefcmd{nasai}{3663}{أَخْبَرَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، عَنْ عَبْدَةَ، عَنْ هِشَامٍ، - هُوَ ابْنُ عُرْوَةَ - عَنْ بَكْرِ بْنِ وَائِلٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ سَعْدُ بْنُ عُبَادَةَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنَّ أُمِّي مَاتَتْ وَعَلَيْهَا نَذْرٌ وَلَمْ تَقْضِهِ قَالَ ‏ "‏ اقْضِهِ عَنْهَا ‏"‏‏.‏\hadithno{3663}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:Sa'd bin 'Ubadah came to the Prophet and said: "My mother has died and she had a vow to fulfill but she did not do so." He said: "Fulfill it on her behalf}}
\hadithdefcmd{nasai}{3664}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ سَعْدِ بْنِ عُبَادَةَ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أُمِّي مَاتَتْ أَفَأَتَصَدَّقُ عَنْهَا قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ قُلْتُ فَأَىُّ الصَّدَقَةِ أَفْضَلُ قَالَ ‏"‏ سَقْىُ الْمَاءِ ‏"‏‏.‏\hadithno{3664}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sa'd bin 'Ubadah said:"I said: 'O Messenger of Allah, my mother has died; shall I give in charity on her behalf?' He said: 'Yes.' I said: 'What kind of charity is best?' He said: 'Providing drinking water}}
\hadithdefcmd{nasai}{3665}{أَخْبَرَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، عَنْ وَكِيعٍ، عَنْ هِشَامٍ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ سَعْدِ بْنِ عُبَادَةَ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَىُّ الصَّدَقَةِ أَفْضَلُ قَالَ ‏ "‏ سَقْىُ الْمَاءِ ‏"‏‏.‏\hadithno{3665}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sa'd bin 'Ubadah said:"I said: 'O Messenger of Allah, what kind of charity is best?' He said: 'Providing drinking water}}
\hadithdefcmd{nasai}{3666}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، عَنْ حَجَّاجٍ، قَالَ سَمِعْتُ شُعْبَةَ، يُحَدِّثُ عَنْ قَتَادَةَ، قَالَ سَمِعْتُ الْحَسَنَ، يُحَدِّثُ عَنْ سَعْدِ بْنِ عُبَادَةَ، أَنَّ أُمَّهُ، مَاتَتْ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمِّي مَاتَتْ أَفَأَتَصَدَّقُ عَنْهَا قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ قَالَ فَأَىُّ الصَّدَقَةِ أَفْضَلُ قَالَ ‏"‏ سَقْىُ الْمَاءِ ‏"‏‏.‏ فَتِلْكَ سِقَايَةُ سَعْدٍ بِالْمَدِينَةِ‏.‏\hadithno{3666}\hadithgrade{Abu Ghuddah: Hasan Lighairihi; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sa'd bin 'Ubadah that his mother died. He said:"O Messenger of Allah, my mother has died; can I give charity on her behalf?" He said: "Yes." He said: "What kind of charity is best?" He said: "Providing drinking water." And that is the drinking-fountain of Sa'd in Al-Madinah}}
\hadithdefcmd{nasai}{3667}{أَخْبَرَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي أَيُّوبَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ سَالِمِ بْنِ أَبِي سَالِمٍ الْجَيْشَانِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا أَبَا ذَرٍّ إِنِّي أَرَاكَ ضَعِيفًا وَإِنِّي أُحِبُّ لَكَ مَا أُحِبُّ لِنَفْسِي لاَ تَأَمَّرَنَّ عَلَى اثْنَيْنِ وَلاَ تَوَلَّيَنَّ عَلَى مَالِ يَتِيمٍ ‏"‏‏.‏\hadithno{3667}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Dharr said:"The Messenger of Allah said to me: 'O Abu Dharr, I think that you are weak, and I like for you what I like for myself. Do not accept a position of Amir over two people, and do not agree to be the guardian of an orphan's property}}
\hadithdefcmd{nasai}{3668}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ حُسَيْنٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنِّي فَقِيرٌ لَيْسَ لِي شَىْءٌ وَلِي يَتِيمٌ‏.‏ قَالَ ‏ "‏ كُلْ مِنْ مَالِ يَتِيمِكَ غَيْرَ مُسْرِفٍ وَلاَ مُبَاذِرٍ وَلاَ مُتَأَثِّلٍ ‏"‏‏.‏\hadithno{3668}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, from his grandfather, that a man came to the Prophet and said:"I am poor and I do not have anything, and I have an orphan (under my care)." He said: "Eat from the property of your orphan without being extravagant, wasteful or keeping it as capital for yourself}}
\hadithdefcmd{nasai}{3669}{أَخْبَرَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ الصَّلْتِ، قَالَ حَدَّثَنَا أَبُو كُدَيْنَةَ، عَنْ عَطَاءٍ، - وَهُوَ ابْنُ السَّائِبِ - عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏وَلاَ تَقْرَبُوا مَالَ الْيَتِيمِ إِلاَّ بِالَّتِي هِيَ أَحْسَنُ‏\}‏ وَ‏\{‏إِنَّ الَّذِينَ يَأْكُلُونَ أَمْوَالَ الْيَتَامَى ظُلْمًا‏\}‏ قَالَ اجْتَنَبَ النَّاسُ مَالَ الْيَتِيمِ وَطَعَامَهُ فَشَقَّ ذَلِكَ عَلَى الْمُسْلِمِينَ فَشَكَوْا ذَلِكَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَنْزَلَ اللَّهُ ‏\{‏وَيَسْأَلُونَكَ عَنِ الْيَتَامَى قُلْ إِصْلاَحٌ لَهُمْ خَيْرٌ‏\}‏ إِلَى قَوْلِهِ ‏\{‏لأَعْنَتَكُمْ‏\}‏‏.‏\hadithno{3669}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said:"When these Verses were revealed - 'And come not near to the orphan's property, except to improve it,' and 'Verily, those who unjustly eat up the property of orphans' - the people avoided the property and food of the orphans. That caused hardship to the Muslims and they complained about that to the Prophet. Then Allah revealed: 'And they ask you concerning orphans. Say: The best thing is to work honestly in their property, and if you mix your affairs with theirs, then they are your brothers. And Allah knows him who means mischief (e.g. to swallow their property) from him who means good (e.g. to save their property). And if Allah had wished, He could have put you into difficulties}}
\hadithdefcmd{nasai}{3670}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عِمْرَانُ بْنُ عُيَيْنَةَ، قَالَ حَدَّثَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ ‏\{‏إِنَّ الَّذِينَ يَأْكُلُونَ أَمْوَالَ الْيَتَامَى ظُلْمًا‏\}‏ قَالَ كَانَ يَكُونُ فِي حِجْرِ الرَّجُلِ الْيَتِيمَ فَيَعْزِلُ لَهُ طَعَامَهُ وَشَرَابَهُ وَآنِيَتَهُ فَشَقَّ ذَلِكَ عَلَى الْمُسْلِمِينَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏وَإِنْ تُخَالِطُوهُمْ فَإِخْوَانُكُمْ‏\}‏ ‏\{‏فِي الدِّينِ‏\}‏ فَأَحَلَّ لَهُمْ خُلْطَتَهُمْ‏.‏\hadithno{3670}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Abbas said -concerning the Verse:"Verily, those who unjustly eat up the property of orphans" -A man would have an orphan in his care, and he would keep his food, drink and vessels separate. This caused hardship to the Muslims, so Allah, the Mighty and Sublime, revealed: "And they ask you concerning orphans. Say: The best thing is to work honestly in their property, and if you mix your affairs with theirs, then they are your brothers" (in religion), so it is permissible for you to mix with them}}
\hadithdefcmd{nasai}{3671}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ اجْتَنِبُوا السَّبْعَ الْمُوبِقَاتِ ‏"‏‏.‏ قِيلَ يَا رَسُولَ اللَّهِ مَا هِيَ قَالَ ‏"‏ الشِّرْكُ بِاللَّهِ وَالشُّحُّ وَقَتْلُ النَّفْسِ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ وَأَكْلُ الرِّبَا وَأَكْلُ مَالِ الْيَتِيمِ وَالتَّوَلِّي يَوْمَ الزَّحْفِ وَقَذْفُ الْمُحْصَنَاتِ الْغَافِلاَتِ الْمُؤْمِنَاتِ ‏"‏‏.‏\hadithno{3671}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Avoid the seven sins that doom one to Hell." It was said: "O Messenger of Allah, what are they?" He said: "Associating others with Allah (Shirk), magic, killing a soul whom Allah has forbidden killing, except in cases dictated by Islamic law, consuming Riba, consuming the property of orphans, fleeing on the day of the march (to battlefield), and slandering chaste women who never even think of anything touching their chastity and are good believers}}
