% Auto-generated chapter 13 for malik
% Hadiths in this chapter: 6

\hadithdefcmd{malik}{449}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ عَمْرِو بْنِ حَزْمٍ، أَنَّهُ سَمِعَ عَبَّادَ بْنَ تَمِيمٍ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ زَيْدٍ الْمَازِنِيَّ، يَقُولُ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْمُصَلَّى فَاسْتَسْقَى وَحَوَّلَ رِدَاءَهُ حِينَ اسْتَقْبَلَ الْقِبْلَةَ ‏.‏\hadithno{449}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr ibn Amr ibn Hazm that he had heard Abbad ibn Tamim say that he had heard Abdullah ibn Zayd al-Mazini say, "The Messenger of Allah, may Allah bless him and grant him peace, came out to the place of prayer and asked for rain, and when he faced the qibla he turned his cloak inside out." Malik was asked how many rakas there were in the prayer of asking for rain and he said, "Two rakas, and the imam does the prayer before he gives the khutba. He prays two rakas, and then he gives a khutba and makes dua, facing the qibla and turning his cloak inside out. He recites out loud in both rakas, and when he turns his cloak inside out he puts what is on his right on his left, and what is on his left on his right, and all the people turn their cloaks inside out when the imam does so, and face the qibla, sitting}}
\hadithdefcmd{malik}{450}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا اسْتَسْقَى قَالَ ‏ "‏ اللَّهُمَّ اسْقِ عِبَادَكَ وَبَهِيمَتَكَ وَانْشُرْ رَحْمَتَكَ وَأَحْىِ بَلَدَكَ الْمَيِّتَ ‏"‏ ‏.‏\hadithno{450}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Amr ibn Shuayb that the Messenger of Allah, may Allah bless him and grant him peace, said, when he asked for rain, "O Allah, give water to Your slaves and Your animals, and spread Your mercy, and give life to Your dead land}}
\hadithdefcmd{malik}{451}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ هَلَكَتِ الْمَوَاشِي وَتَقَطَّعَتِ السُّبُلُ فَادْعُ اللَّهَ ‏.‏ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَمُطِرْنَا مِنَ الْجُمُعَةِ إِلَى الْجُمُعَةِ ‏.‏ قَالَ فَجَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ تَهَدَّمَتِ الْبُيُوتُ وَانْقَطَعَتِ السُّبُلُ وَهَلَكَتِ الْمَوَاشِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ ظُهُورَ الْجِبَالِ وَالآكَامِ وَبُطُونَ الأَوْدِيَةِ وَمَنَابِتَ الشَّجَرِ ‏"‏ ‏.‏ قَالَ فَانْجَابَتْ عَنِ الْمَدِينَةِ انْجِيَابَ الثَّوْبِ ‏.‏\hadithno{451}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Sharik ibn Abdullah ibn Abi Namir that Anas ibn Malik said, "A man came to the Messenger of Allah, may Allah bless him and grant him peace, and said, 'Messenger of Allah, our animals are dying and our camels are too weak to travel, so make dua to Allah.' The Messenger of Allah, may Allah bless him and grant him peace, made dua, and it rained on us from one jumua to the next." Anas continued, "Then a man came to the Messenger of Allah, may Allah bless him and grant him peace, and said, 'Messenger of Allah, our houses have fallen down, the paths are blocked, and our flocks are dying.' The Messenger of Allah, may Allah bless him and grant him peace, said, 'O Allah, (only) the mountain and hill-tops, the valley bottoms, and the places where trees grow.' " Anas added, "It cleared away from Madina like a garment being removed." Malik said, about a man who missed the prayer of asking for rain but caught the khutba, and wished to pray in the mosque, or in his house when he returned, "He is free to do so, or not, as he wishes}}
\hadithdefcmd{malik}{452}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّهُ قَالَ صَلَّى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الصُّبْحِ بِالْحُدَيْبِيَةِ عَلَى إِثْرِ سَمَاءٍ كَانَتْ مِنَ اللَّيْلِ فَلَمَّا انْصَرَفَ أَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏"‏ أَتَدْرُونَ مَاذَا قَالَ رَبُّكُمْ ‏"‏ ‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ قَالَ أَصْبَحَ مِنْ عِبَادِي مُؤْمِنٌ بِي وَكَافِرٌ بِي فَأَمَّا مَنْ قَالَ مُطِرْنَا بِفَضْلِ اللَّهِ وَرَحْمَتِهِ فَذَلِكَ مُؤْمِنٌ بِي كَافِرٌ بِالْكَوْكَبِ وَأَمَّا مَنْ قَالَ مُطِرْنَا بِنَوْءِ كَذَا وَكَذَا فَذَلِكَ كَافِرٌ بِي مُؤْمِنٌ بِالْكَوْكَبِ ‏"‏ ‏.‏\hadithno{452}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Salih ibn Kaysan from Ubaydullah ibn Abdullah ibn Utba ibn Masud that Zayd ibn Khalid al- Juhani said, "The Messenger of Allah, may Allah bless him and grant him peace, took the subh prayer with us at Hudaybiyya after it had rained in the night. When he had finished he went up to the people and said, 'Do you know what your Lord has said?' They said, 'Allah and His Messenger know best.' He said, 'Some of my slaves have begun the morning believing in Me, and others have begun it rejecting Me. As for those who say, 'We were rained on by the overflowing favour of Allah and His mercy,' they believe in Me and reject the stars. But as for those who say, 'We were rained on by such and such a star, they reject Me and believe in the stars}}
\hadithdefcmd{malik}{453}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ إِذَا أَنْشَأَتْ بَحْرِيَّةً ثُمَّ تَشَاءَمَتْ فَتِلْكَ عَيْنٌ غُدَيْقَةٌ ‏"‏ ‏.‏\hadithno{453}\hadithgrade{Salim al-Hilali: Mawdu}\hadithtrans{Yahya related to me from Malik that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, used to say, "When a cloud appears from the direction of the sea and then goes towards ash-Sham, it will be an abundant source of rain}}
\hadithdefcmd{malik}{454}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ أَنَّ أَبَا هُرَيْرَةَ، كَانَ يَقُولُ إِذَا أَصْبَحَ وَقَدْ مُطِرَ النَّاسُ مُطِرْنَا بِنَوْءِ الْفَتْحِ ثُمَّ يَتْلُو هَذِهِ الآيَةَ ‏\{‏مَا يَفْتَحِ اللَّهُ لِلنَّاسِ مِنْ رَحْمَةٍ فَلاَ مُمْسِكَ لَهَا وَمَا يُمْسِكْ فَلاَ مُرْسِلَ لَهُ مِنْ بَعْدِهِ ‏\}‏\hadithno{454}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik that he had heard that Abu Hurayra used to say, when morning came after it had rained on the people, "We have been rained upon by the rain of Allah's opening," and would then recite the ayat, "Whatever Allah opens to man of His mercy no-one can withhold, and whatever He withholds no-one can send forward after Him. " (Sura 35 ayat)}}
