% Auto-generated chapter 19 for ibnmajah
% Hadiths in this chapter: 20

\hadithdefcmd{ibnmajah}{2512}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ ذصلى الله عليه وسلم بَاعَ الْمُدَبَّرَ ‏.‏\hadithno{2512}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Jabir that:the Messenger of Allah (ﷺ) sold a Mudabbar}}
\hadithdefcmd{ibnmajah}{2513}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ دَبَّرَ رَجُلٌ مِنَّا غُلاَمًا وَلَمْ يَكُنْ لَهُ مَالٌ غَيْرُهُ فَبَاعَهُ النَّبِيُّ صلى الله عليه وسلم فَاشْتَرَاهُ ابْنُ النَّحَّامِ رَجُلٌ مِنْ بَنِي عَدِيٍّ ‏.‏\hadithno{2513}\hadithgrade{Al-Albani: Sahih Hadith; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:“A man among us promised freedom to a slave after his death, and he did not have any property other than him (this slave). So the Prophet (ﷺ) sold him, and Ibn (Nahham), a man from Banu 'Adi, bought him.”}}
\hadithdefcmd{ibnmajah}{2514}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ ظَبْيَانَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ الْمُدَبَّرُ مِنَ الثُّلُثِ ‏"‏ ‏.‏ قَالَ ابْنُ مَاجَهْ سَمِعْتُ عُثْمَانَ - يَعْنِي ابْنَ أَبِي شَيْبَةَ - يَقُولُ هَذَا خَطَأٌ يَعْنِي حَدِيثَ ‏"‏ الْمُدَبَّرُ مِنَ الثُّلُثِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ لَيْسَ لَهُ أَصْلٌ ‏.‏\hadithno{2514}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn`Umar that the Prophet (ﷺ) said:“The Mudabbar is part of the one third of the estate.”}}
\hadithdefcmd{ibnmajah}{2515}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا شَرِيكٌ، عَنْ حُسَيْنِ بْنِ عَبْدِ اللَّهِ بْنِ عُبَيْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا رَجُلٍ وَلَدَتْ أَمَتُهُ مِنْهُ فَهِيَ مُعْتَقَةٌ عَنْ دُبُرٍ مِنْهُ ‏"‏ ‏.‏\hadithno{2515}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn`Abbas that the Messenger of Allah (ﷺ) said:“Any man whose slave won an bears him a child, she will be free after he dies.”}}
\hadithdefcmd{ibnmajah}{2516}{حَدَّثَنَا أَحْمَدُ بْنُ يُوسُفَ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا أَبُو بَكْرٍ يَعْنِي النَّهْشَلِيَّ، عَنِ الْحُسَيْنِ بْنِ عَبْدِ اللَّهِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ذُكِرَتْ أُمُّ إِبْرَاهِيمَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ ‏ "‏ أَعْتَقَهَا وَلَدُهَا ‏"‏ ‏.‏\hadithno{2516}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn`Abbas said:“Mention was made of the mother of Ibrahim in the presence of the Messenger of Allah (ﷺ), and he said: 'Her son set her free.'”}}
\hadithdefcmd{ibnmajah}{2517}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ كُنَّا نَبِيعُ سَرَارِينَا وَأُمَّهَاتِ أَوْلاَدِنَا وَالنَّبِيُّ صلى الله عليه وسلم فِينَا حَىٌّ لاَ نَرَى بِذَلِكَ بَأْسًا ‏.‏\hadithno{2517}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir bin `Abdullah was heard to say:“We used to sell our slave women and the mothers of our children (Umahat Awaldina) when the Prophet (ﷺ) was still living among us, and we did not see anything wrong with that.”}}
\hadithdefcmd{ibnmajah}{2518}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَبْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ كُلُّهُمْ حَقٌّ عَلَى اللَّهِ عَوْنُهُ الْغَازِي فِي سَبِيلِ اللَّهِ وَالْمُكَاتَبُ الَّذِي يُرِيدُ الأَدَاءَ وَالنَّاكِحُ الَّذِي يُرِيدُ التَّعَفُّفَ ‏"‏ ‏.‏\hadithno{2518}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah (ra) said that the Messenger of Allah (ﷺ) said "Three who's support is a right upon Allah:the warrior in the path of Allah, the mukatab seeking to fulfill (his manumission debt), and the one getting married seeking chastity}}
\hadithdefcmd{ibnmajah}{2519}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَمُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ حَجَّاجٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا عَبْدٍ كُوتِبَ عَلَى مِائَةِ أُوقِيَّةٍ فَأَدَّاهَا إِلاَّ عَشْرَ أُوقِيَّاتٍ فَهُوَ رَقِيقٌ ‏"‏ ‏.‏\hadithno{2519}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from `Amr bin Shu'aib , from his father, from his grandfather that the Messenger of Allah (ﷺ) said:“Any slave who has made a contract to buy his freedom for one hundread Uqiyyah and pays it all except ten Uqiyyah; he is still a slave.” (One Uqiyyah is equal to 40 Dirham)}}
\hadithdefcmd{ibnmajah}{2520}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ نَبْهَانَ، - مَوْلَى أُمِّ سَلَمَةَ - عَنْ أُمِّ سَلَمَةَ، أَنَّهَا أَخْبَرَتْ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا كَانَ لإِحْدَاكُنَّ مُكَاتَبٌ وَكَانَ عِنْدَهُ مَا يُؤَدِّي فَلْتَحْتَجِبْ مِنْهُ ‏"‏ ‏.‏\hadithno{2520}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Umm Salamah that the Prophet (ﷺ) said:“If anyone of you (women) has a Mukatab, and he has enough (wealth) to pay off (his contact of manumission), she must veil herself from him.”}}
\hadithdefcmd{ibnmajah}{2521}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ بَرِيرَةَ أَتَتْهَا وَهِيَ مُكَاتَبَةٌ قَدْ كَاتَبَهَا أَهْلُهَا عَلَى تِسْعِ أَوَاقٍ فَقَالَتْ لَهَا إِنْ شَاءَ أَهْلُكِ عَدَدْتُ لَهُمْ عَدَّةً وَاحِدَةً وَكَانَ الْوَلاَءُ لِي قَالَ فَأَتَتْ أَهْلَهَا فَذَكَرَتْ ذَلِكَ لَهُمْ فَأَبَوْا إِلاَّ أَنْ تَشْتَرِطَ الْوَلاَءَ لَهُمْ فَذَكَرَتْ عَائِشَةُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ افْعَلِي ‏"‏ ‏.‏ قَالَتْ فَقَامَ النَّبِيُّ صلى الله عليه وسلم فَخَطَبَ النَّاسَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ مَا بَالُ رِجَالٍ يَشْتَرِطُونَ شُرُوطًا لَيْسَتْ فِي كِتَابِ اللَّهِ كُلُّ شَرْطٍ لَيْسَ فِي كِتَابِ اللَّهِ فَهُوَ بَاطِلٌ وَإِنْ كَانَ مِائَةَ شَرْطٍ كِتَابُ اللَّهِ أَحَقُّ وَشَرْطُ اللَّهِ أَوْثَقُ وَالْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏\hadithno{2521}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Hisham bin 'Urwah, from his father, about 'Aishah the wife of the Prophet (ﷺ) - :that Barirah came to her when she was came to her when she was Muktabah, and her masters had written a contract of manumission for nine Uqiyyah. She (`Aishah) said: “If your masters wish I will pay them that in one sum, and the right of inheritance will belong to me.” He said: “So she went to her masters and told them about that, but they insisted that the right of inheritance should belong to them. `Aishah mentioned that to the Prophet (ﷺ) and he said: 'Do it.' Then the Prophet (ﷺ) stood up and addressed the people. He praised and glorified Allah (SWT), then he said: 'What is the matter with some people who stipulated conditions that are not in the Book of Allah (SWT)? Every conditions that is not in the Book of Allah (SWT) is invalid, even if there are one hundred conditions. The Book of Allah(SWT) is more deserving of being followed and the conditions of Allah (SWT) are more binding. And the Wala belongs to the one who manumits (the slave).”}}
\hadithdefcmd{ibnmajah}{2522}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ شُرَحْبِيلَ بْنِ السِّمْطِ، قَالَ قُلْتُ لِكَعْبٍ يَا كَعْبَ بْنَ مُرَّةَ حَدِّثْنَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاحْذَرْ ‏.‏ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَعْتَقَ امْرَأً مُسْلِمًا كَانَ فِكَاكَهُ مِنَ النَّارِ يُجْزِئُ بِكُلِّ عَظْمٍ مِنْهُ عَظْمٌ مِنْهُ وَمَنْ أَعْتَقَ امْرَأَتَيْنِ مُسْلِمَتَيْنِ كَانَتَا فِكَاكَهُ مِنَ النَّارِ يُجْزِئُ بِكُلِّ عَظْمَيْنِ مِنْهُمَا عَظْمٌ مِنْهُ ‏"‏ ‏.‏\hadithno{2522}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Shurahbil bin Simt said:I said to Ka'b bin Murrah, tell us a Hadith from the Messenger of Allah (ﷺ), but be careful. He said: I heard the Messenger of Allah (ﷺ) say: “Whoever frees a Muslim man, he will be his ransom from the Fire; each of his bones will suffice (as a ransom) for each of his bones. Whoever frees two Muslim women, they will be his ransom from the Fire; each of their two bones will suffice (as a ransom) for each of his bones.”}}
\hadithdefcmd{ibnmajah}{2523}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ أَبِي مُرَاوِحٍ، عَنْ أَبِي ذَرٍّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَىُّ الرِّقَابِ أَفْضَلُ قَالَ ‏ "‏ أَنْفَسُهَا عِنْدَ أَهْلِهَا وَأَغْلاَهَا ثَمَنًا ‏"‏ ‏.‏\hadithno{2523}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Dharr said:“I said: 'O Messenger of Allah (ﷺ), which slave is best?' He said: ‘The one who is most precious to his master and most valuable in price.' ”}}
\hadithdefcmd{ibnmajah}{2524}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ الْبُرْسَانِيُّ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ قَتَادَةَ، وَعَاصِمٍ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ مَلَكَ ذَا رَحِمٍ مَحْرَمٍ فَهُوَ حُرٌّ ‏"‏ ‏.‏\hadithno{2524}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Samurah bin Jundub that the Prophet (ﷺ) said:“Whoever becomes the master of a Mahram relative (with whom marriage is not lawful), he becomes free.”}}
\hadithdefcmd{ibnmajah}{2525}{حَدَّثَنَا رَاشِدُ بْنُ سَعِيدٍ الرَّمْلِيُّ، وَعُبَيْدُ اللَّهِ بْنُ الْجَهْمِ الأَنْمَاطِيُّ، قَالاَ حَدَّثَنَا ضَمْرَةُ بْنُ رَبِيعَةَ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ مَلَكَ ذَا رَحِمٍ مَحْرَمٍ فَهُوَ حُرٌّ ‏"‏ ‏.‏\hadithno{2525}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn`Umar that the Messenger of Allah (ﷺ) said:“Whoever becomes the master of a Mahram relative, he becomes free.”}}
\hadithdefcmd{ibnmajah}{2526}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ سَعِيدِ بْنِ جُمْهَانَ، عَنْ سَفِينَةَ أَبِي عَبْدِ الرَّحْمَنِ، قَالَ أَعْتَقَتْنِي أُمُّ سَلَمَةَ وَاشْتَرَطَتْ عَلَىَّ أَنْ أَخْدُمَ النَّبِيَّ صلى الله عليه وسلم مَا عَاشَ ‏.‏\hadithno{2526}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from that Safinah - Abu 'Abdur-Rahman-said :“Umm Salamah freed me but stipulated that I should serve the Prophet (ﷺ) as long he lived.”}}
\hadithdefcmd{ibnmajah}{2527}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، وَمُحَمَّدُ بْنُ بِشْرٍ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ نَصِيبًا لَهُ فِي مَمْلُوكٍ أَوْ شِقْصًا فَعَلَيْهِ خَلاَصُهُ مِنْ مَالِهِ إِنْ كَانَ لَهُ مَالٌ فَإِنْ لَمْ يَكُنْ لَهُ مَالٌ اسْتُسْعِيَ الْعَبْدُ فِي قِيمَتِهِ غَيْرَ مَشْقُوقٍ عَلَيْهِ ‏"‏ ‏.‏\hadithno{2527}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever frees his share of a slave or part of his share, must pay from his wealth if he has any wealth if he has any wealth (in order to buy the rest of the slave's freedom). If he does not have wealth, then the slave should be asked to work for the price (of his freedom), without that causing him too much hardship.”}}
\hadithdefcmd{ibnmajah}{2529}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ لَهِيعَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، جَمِيعًا عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ عَبْدًا وَلَهُ مَالٌ فَمَالُ الْعَبْدِ لَهُ إِلاَّ أَنْ يَشْتَرِطَ السَّيِّدُ مَالَهُ فَيَكُونَ لَهُ ‏"‏ ‏.‏ وَقَالَ ابْنُ لَهِيعَةَ إِلاَّ أَنْ يَسْتَثْنِيَهُ السَّيِّدُ ‏.‏\hadithno{2529}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn`Umar that the Messenger of Allah (ﷺ) said:“Whoever frees a slave who has some wealth, the slave's wealth belongs to him, unless the master stipulates that it will belong to him.”}}
\hadithdefcmd{ibnmajah}{2530}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا سَعِيدُ بْنُ مُحَمَّدٍ الْجَرْمِيُّ، حَدَّثَنَا الْمُطَّلِبُ بْنُ زِيَادٍ، عَنْ إِسْحَاقَ بْنِ إِبْرَاهِيمَ، عَنْ جَدِّهِ، عُمَيْرٍ - وَهُوَ مَوْلَى ابْنِ مَسْعُودٍ - أَنَّ عَبْدَ اللَّهِ، قَالَ لَهُ يَا عُمَيْرُ إِنِّي أُعْتِقُكَ عِتْقًا هَنِيئًا إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَيُّمَا رَجُلٍ أَعْتَقَ غُلاَمًا وَلَمْ يُسَمِّ مَالَهُ فَالْمَالُ لَهُ ‏"‏ ‏.‏ فَأَخْبِرْنِي مَا مَالُكَ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا الْمُطَّلِبُ بْنُ زِيَادٍ، عَنْ إِسْحَاقَ بْنِ إِبْرَاهِيمَ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ لِجَدِّي فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{2530}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ishaq bin Ibrahim, from his grandfather 'Umair, who was the freed slave of Ibn Mas'ud, that `Abdullah said to him:“O Umair, I have set you free in a good way. I heard the Messenger of Allah (ﷺ) say: 'Any man who frees a slave and does not say anything about his (the slave's) wealth, it belongs to him (the slave).' So tell me, how much wealth do you have?” Another chain reports a similar hadith}}
\hadithdefcmd{ibnmajah}{2531}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ زَيْدِ بْنِ جُبَيْرٍ، عَنْ أَبِي يَزِيدَ الضِّنِّيِّ، عَنْ مَيْمُونَةَ بِنْتِ سَعْدٍ، - مَوْلاَةِ النَّبِيِّ صلى الله عليه وسلم - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنْ وَلَدِ الزِّنَا فَقَالَ ‏ "‏ نَعْلاَنِ أُجَاهِدُ فِيهِمَا خَيْرٌ مِنْ أَنْ أُعْتِقَ وَلَدَ الزِّنَا ‏"‏ ‏.‏\hadithno{2531}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Maimunah bint Sa`d, the freed slave woman of the Prophet (ﷺ) that :the Messenger of Allah (ﷺ) was asked about illegitimate children. He said: “Two sandals in which I wage Jihad are better than freeing an illegitimate child.”}}
\hadithdefcmd{ibnmajah}{2532}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ خَلَفٍ الْعَسْقَلاَنِيُّ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، أَنَّهَا كَانَ لَهَا غُلاَمٌ وَجَارِيَةٌ زَوْجٌ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أُرِيدُ أَنْ أُعْتِقَهُمَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ أَعْتَقْتِهِمَا فَابْدَئِي بِالرَّجُلِ قَبْلَ الْمَرْأَةِ ‏"‏ ‏.‏\hadithno{2532}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that :`Aishah had a male slave and a female slave who were married. She said: “O Messenger of Allah (ﷺ), I want to free them both.” The Messenger of Allah (ﷺ) said: “If you free them, then start with the man before the woman.”}}
