% Auto-generated chapter 60 for malik
% Hadiths in this chapter: 1

\hadithdefcmd{malik}{1857}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، اسْتَعْمَلَ مَوْلًى لَهُ يُدْعَى هُنَيًّا عَلَى الْحِمَى فَقَالَ يَا هُنَىُّ اضْمُمْ جَنَاحَكَ عَنِ النَّاسِ وَاتَّقِ دَعْوَةَ الْمَظْلُومِ فَإِنَّ دَعْوَةَ الْمَظْلُومِ مُسْتَجَابَةٌ وَأَدْخِلْ رَبَّ الصُّرَيْمَةِ وَرَبَّ الْغُنَيْمَةِ وَإِيَّاىَ وَنَعَمَ ابْنِ عَوْفٍ وَنَعَمَ ابْنِ عَفَّانَ فَإِنَّهُمَا إِنْ تَهْلِكْ مَاشِيَتُهُمَا يَرْجِعَا إِلَى نَخْلٍ وَزَرْعٍ وَإِنَّ رَبَّ الصُّرَيْمَةِ وَرَبَّ الْغُنَيْمَةِ إِنْ تَهْلِكْ مَاشِيَتُهُمَا يَأْتِنِي بِبَنِيهِ فَيَقُولُ يَا أَمِيرَ الْمُؤْمِنِينَ يَا أَمِيرَ الْمُؤْمِنِينَ ‏.‏ أَفَتَارِكُهُمْ أَنَا لاَ أَبَا لَكَ فَالْمَاءُ وَالْكَلأُ أَيْسَرُ عَلَىَّ مِنَ الذَّهَبِ وَالْوَرِقِ وَايْمُ اللَّهِ إِنَّهُمْ لَيَرَوْنَ أَنِّي قَدْ ظَلَمْتُهُمْ إِنَّهَا لَبِلاَدُهُمْ وَمِيَاهُهُمْ قَاتَلُوا عَلَيْهَا فِي الْجَاهِلِيَّةِ وَأَسْلَمُوا عَلَيْهَا فِي الإِسْلاَمِ وَالَّذِي نَفْسِي بِيَدِهِ لَوْلاَ الْمَالُ الَّذِي أَحْمِلُ عَلَيْهِ فِي سَبِيلِ اللَّهِ مَا حَمَيْتُ عَلَيْهِمْ مِنْ بِلاَدِهِمْ شِبْرًا ‏.‏\hadithno{1857}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Aslam from his father that Umar ibn al-Khattab gave a mawla of his called Hunayy charge over the hima. He said, "Hunayy! Do not harm the people. Fear the supplication of the wronged, for the supplication of the wronged is answered. Let the one with a small herd of camels and the one with a small herd of sheep enter, but be wary of the livestock of Ibn Awf and the livestock of Ibn Affan. If their livestock are destroyed, they will return to palm-trees and agriculture. If the livestock of the one with a small herd of camels and the one with a small herd of sheep are destroyed, he will bring his children to me crying, 'Amir al-muminin! Amir al-Muminin!' Shall I neglect them? Water and pasturage are of less value to me than gold and silver. By Allah, they think that I have wronged them. This is their land and their water. They fought for it in the jahiliyya and became muslims on it in Islam. By He in whose hand my self is! Were it not for the mounts which I give to be ridden in the way of Allah, I would not have turned a span of their land into hima}}
