% Auto-generated chapter 22 for ibnmajah
% Hadiths in this chapter: 24

\hadithdefcmd{ibnmajah}{2695}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي وَأَبُو مُعَاوِيَةَ ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، - قَالَ أَبُو بَكْرٍ وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ - عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ مَا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم دِينَارًا وَلاَ دِرْهَمًا وَلاَ شَاةً وَلاَ بَعِيرًا وَلاَ أَوْصَى بِشَىْءٍ ‏.‏\hadithno{2695}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Aishah said:“The Messenger of Allah (ﷺ) did not leave behind a Dinar nor a Dirham, nor a sheep, nor a camel, and he did not make a will concerning anything.”}}
\hadithdefcmd{ibnmajah}{2696}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ مَالِكِ بْنِ مِغْوَلٍ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، قَالَ قُلْتُ لِعَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى أَوْصَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَىْءٍ قَالَ لاَ ‏.‏ قُلْتُ فَكَيْفَ أَمَرَ الْمُسْلِمِينَ بِالْوَصِيَّةِ قَالَ أَوْصَى بِكِتَابِ اللَّهِ ‏.‏ قَالَ مَالِكٌ وَقَالَ طَلْحَةُ بْنُ مُصَرِّفٍ قَالَ الْهُزَيْلُ بْنُ شُرَحْبِيلَ أَبُو بَكْرٍ كَانَ يَتَأَمَّرُ عَلَى وَصِيِّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَدَّ أَبُو بَكْرٍ أَنَّهُ وَجَدَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم عَهْدًا فَخَزَمَ أَنْفَهُ بِخِزَامٍ ‏.‏\hadithno{2696}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Malik bin Mighwal that Talhah bin Musarrif said:“I said to Abdullah bin Abu Awfa: 'Did the Messenger of Allah (ﷺ) make a will concerning anything?' He said: 'No.' I said: 'How come he told the Muslims to make wills?' He said: 'He enjoined (them to adhere to) the book of Allah (SWT).” Malik said: “Talhah bin Musarrif said: 'Huzail bin Shurahbil said: “Abu Bakr was granted leadership according to the will of Allah's Messenger (ﷺ)?” (Rather) Abu Bakr wished that the found a covenant (in that regard) from Allah's Messenger (ﷺ), so he could fetter his nose with a (camel's) nose ring.”}}
\hadithdefcmd{ibnmajah}{2697}{حَدَّثَنَا أَحْمَدُ بْنُ الْمِقْدَامِ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَتْ عَامَّةُ وَصِيَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ حَضَرَتْهُ الْوَفَاةُ وَهُوَ يُغَرْغِرُ بِنَفْسِهِ ‏ "‏ الصَّلاَةَ وَمَا مَلَكَتْ أَيْمَانُكُمْ ‏"‏ ‏.‏\hadithno{2697}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“What the Messenger of Allah (ﷺ) most enjoined when he was dying and breathing his last was: The prayer; and those whom your right hands possess.”}}
\hadithdefcmd{ibnmajah}{2698}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ مُغِيرَةَ، عَنْ أُمِّ مُوسَى، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ كَانَ آخِرُ كَلاَمِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ الصَّلاَةَ وَمَا مَلَكَتْ أَيْمَانُكُمْ ‏"‏ ‏.‏\hadithno{2698}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Ali bin Abu Talib said:“The last words of the Prophet (ﷺ) were: The prayer; and those whom your right hands prossess.”}}
\hadithdefcmd{ibnmajah}{2699}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا حَقُّ امْرِئٍ مُسْلِمٍ أَنْ يَبِيتَ لَيْلَتَيْنِ وَلَهُ شَىْءٌ يُوصِي فِيهِ إِلاَّ وَوَصِيَّتُهُ مَكْتُوبَةٌ عِنْدَهُ ‏"‏ ‏.‏\hadithno{2699}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah (ﷺ) said:“The Muslim man has no right to spend two nights, if he has something for which a will should be made, without having a written will with him.”}}
\hadithdefcmd{ibnmajah}{2700}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا دُرُسْتُ بْنُ زِيَادٍ، حَدَّثَنَا يَزِيدُ الرَّقَاشِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَحْرُومُ مَنْ حُرِمَ وَصِيَّتَهُ ‏"‏ ‏.‏\hadithno{2700}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“The one who is deprived is the one who is deprived of a will.”}}
\hadithdefcmd{ibnmajah}{2701}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ يَزِيدَ بْنِ عَوْفٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ مَاتَ عَلَى وَصِيَّةٍ مَاتَ عَلَى سَبِيلٍ وَسُنَّةٍ وَمَاتَ عَلَى تُقًى وَشَهَادَةٍ وَمَاتَ مَغْفُورًا لَهُ ‏"‏ ‏.‏\hadithno{2701}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin Abdullah that the Messenger of Allah (ﷺ) said:“Whoever dies leaving a will, he dies on the right path and Sunnah, and he dies with piety and witness, and he dies forgiven.”}}
\hadithdefcmd{ibnmajah}{2702}{حَدَّثَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، حَدَّثَنَا رَوْحُ بْنُ عَوْفٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا حَقُّ امْرِئٍ مُسْلِمٍ يَبِيتُ لَيْلَتَيْنِ وَلَهُ شَىْءٌ يُوصِي بِهِ إِلاَّ وَوَصِيَّتُهُ مَكْتُوبَةٌ عِنْدَهُ ‏"‏ ‏.‏\hadithno{2702}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Umar that the Prophet (ﷺ) said:“The Muslim man has no right to spend two nights, if he has something for which will should be made, without having a written will with him.”}}
\hadithdefcmd{ibnmajah}{2703}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ زَيْدٍ الْعَمِّيِّ، عَنْ أَبِيهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ فَرَّ مِنْ مِيرَاثِ وَارِثِهِ قَطَعَ اللَّهُ مِيرَاثَهُ مِنَ الْجَنَّةِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2703}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“Whoever tries to avoid giving the inheritance to his heirs, Allah (SWT) will deprive him of his inheritance in Paradise on the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{2704}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ بْنُ هَمَّامٍ، أَنْبَأَنَا مَعْمَرٌ، عَنْ أَشْعَثَ بْنِ عَبْدِ اللَّهِ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الرَّجُلَ لَيَعْمَلُ بِعَمَلِ أَهْلِ الْخَيْرِ سَبْعِينَ سَنَةً فَإِذَا أَوْصَى حَافَ فِي وَصِيَّتِهِ فَيُخْتَمُ لَهُ بِشَرِّ عَمَلِهِ فَيَدْخُلُ النَّارَ وَإِنَّ الرَّجُلَ لَيَعْمَلُ بِعَمَلِ أَهْلِ الشَّرِّ سَبْعِينَ سَنَةً فَيَعْدِلُ فِي وَصِيَّتِهِ فَيُخْتَمُ لَهُ بِخَيْرِ عَمَلِهِ فَيَدْخُلُ الْجَنَّةَ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ وَاقْرَءُوا إِنْ شِئْتُمْ ‏\{تِلْكَ حُدُودُ اللَّهِ\}‏ إِلَى قَوْلِهِ \{عَذَابٌ مُهِينٌ\}‏\hadithno{2704}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“A man may do the deeds of the people of goodness for seventy years, then when he makes his will, he is unjust in his will, so he ends (his life) with evil deeds and enters Hell. And a man may do the people of evil for seventy years, then he is just in his will, so he ends (his life) with good deeds and enters Paradise.”Abu Hurairah said: “Recite, if you wish: “These are the limits (set by) Allah (STW) up to His saying: 'a disgraceful torment'”}}
\hadithdefcmd{ibnmajah}{2705}{حَدَّثَنَا يَحْيَى بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ، عَنْ أَبِي حَلْبَسٍ، عَنْ خُلَيْدِ بْنِ أَبِي خُلَيْدٍ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَضَرَتْهُ الْوَفَاةُ فَأَوْصَى وَكَانَتْ وَصِيَّتُهُ عَلَى كِتَابِ اللَّهِ كَانَتْ كَفَّارَةً لِمَا تَرَكَ مِنْ زَكَاتِهِ فِي حَيَاتِهِ ‏"‏ ‏.‏\hadithno{2705}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif}\hadithtrans{It was narrated from Mu'awiyah bin Qurrah, from his father that the Messenger of Allah (ﷺ) said:“Whoever makes a will as death approaches, and his will is in accordance with the book of Allah (SWT) it will be an expiation for whatever he did not pay of his Zakah during his lifetime.”}}
\hadithdefcmd{ibnmajah}{2706}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، وَابْنِ، شُبْرُمَةَ عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ نَبِّئْنِي بِأَحَقِّ النَّاسِ مِنِّي بِحُسْنِ الصُّحْبَةِ فَقَالَ ‏"‏ نَعَمْ وَأَبِيكَ لَتُنَبَّأَنَّ أُمُّكَ ‏"‏ ‏.‏ قَالَ ثُمَّ مَنْ قَالَ ‏"‏ ثُمَّ أُمُّكَ ‏"‏ ‏.‏ قَالَ ثُمَّ مَنْ قَالَ ‏"‏ ثُمَّ أُمُّكَ ‏"‏ ‏.‏ قَالَ ثُمَّ مَنْ قَالَ ‏"‏ ثُمَّ أَبُوكَ ‏"‏ ‏.‏ قَالَ نَبِّئْنِي يَا رَسُولَ اللَّهِ عَنْ مَالِي كَيْفَ أَتَصَدَّقُ فِيهِ قَالَ ‏"‏ نَعَمْ وَاللَّهِ لَتُنَبَّأَنَّ أَنْ تَصَدَّقَ وَأَنْتَ صَحِيحٌ شَحِيحٌ تَأْمُلُ الْعَيْشَ وَتَخَافُ الْفَقْرَ وَلاَ تُمْهِلْ حَتَّى إِذَا بَلَغَتْ نَفْسُكَ هَاهُنَا قُلْتَ مَالِي لِفُلاَنٍ وَمَالِي لِفُلاَنٍ وَهُوَ لَهُمْ وَإِنْ كَرِهْتَ ‏"‏ ‏.‏\hadithno{2706}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:“A man came to the Prophet (ﷺ) and said: “O Messenger of Allah (ﷺ), tell me, which of the people has most right to my good companionship?' He said: 'Yes, by your father, you will certainly be told.' He said: 'Your mother,' He said: 'Then who?' He said: Then your mother.' He said: 'Then who?' He said: Then your mother.' He said: 'Then who?' He said: Then your father.' He said: 'Tell me, O Messenger of Allah (ﷺ) about my wealth- how should I give in charity?' He said: 'Yes, by Allah (SWT) you will certainly be told. You should give in charity when you are still healthy and greedy for wealth, hoping for a long life and fearing poverty. Do not tarry until your soul reaches here and you say: “My wealth of for so-and-so,” and “My wealth of for so-and-so,” and it will be for them even though you dislike that.'”}}
\hadithdefcmd{ibnmajah}{2707}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا حَرِيزُ بْنُ عُثْمَانَ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ مَيْسَرَةَ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ بُسْرِ بْنِ جَحَّاشٍ الْقُرَشِيِّ، قَالَ بَزَقَ النَّبِيُّ صلى الله عليه وسلم فِي كَفِّهِ ثُمَّ وَضَعَ أَصْبُعَهُ السَّبَّابَةَ وَقَالَ ‏ "‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ أَنَّى تُعْجِزُنِي ابْنَ آدَمَ وَقَدْ خَلَقْتُكَ مِنْ مِثْلِ هَذِهِ فَإِذَا بَلَغَتْ نَفْسُكَ هَذِهِ - وَأَشَارَ إِلَى حَلْقِهِ - قُلْتَ أَتَصَدَّقُ وَأَنَّى أَوَانُ الصَّدَقَةِ ‏"‏ ‏.‏\hadithno{2707}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Busr bin Jahhash Al-Quraishi that :the Prophet (ﷺ) spat in his palm then pointed to it with his index finger and said: “Allah (SWT) says: 'Do you think you can escape from My punishment, O son of Adam, when I have created you from something like this? When your soul reaches here' - and (the Prophet (ﷺ)) pointed to his throat - 'You say: I give charity.' But it is too late for charity?”}}
\hadithdefcmd{ibnmajah}{2708}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَالْحُسَيْنُ بْنُ الْحَسَنِ الْمَرْوَزِيُّ، وَسَهْلٌ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ مَرِضْتُ عَامَ الْفَتْحِ حَتَّى أَشْفَيْتُ عَلَى الْمَوْتِ فَعَادَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ أَىْ رَسُولَ اللَّهِ إِنَّ لِي مَالاً كَثِيرًا وَلَيْسَ يَرِثُنِي إِلاَّ ابْنَتِي أَفَأَتَصَدَّقُ بِثُلُثَىْ مَالِي قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قُلْتُ فَالشَّطْرُ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قُلْتُ فَالثُّلُثُ قَالَ ‏"‏ الثُّلُثُ وَالثُّلُثُ كَثِيرٌ إِنَّكَ أَنْ تَتْرُكَ وَرَثَتَكَ أَغْنِيَاءَ خَيْرٌ مِنْ أَنْ تَتْرُكَهُمْ عَالَةً يَتَكَفَّفُونَ النَّاسَ ‏"‏ ‏.‏\hadithno{2708}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Amir bin Sa'd that his father said:“I became sick during the year of the Conquest, and was at death's door. The Messenger of Allah (ﷺ) came to visit me and I said: 'O Messenger of Allah (ﷺ), I have a great deal of wealth and no one will inherit from me apart from my daughter. Can I give two thirds of my wealth in charity?' He said: 'No.' I said: 'Then half?' He said: 'No.' I said: 'One third?' He said: One third and one third is a lot. If you leave your heirs rich that is better than leaving them destitute and begging from people.”}}
\hadithdefcmd{ibnmajah}{2709}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ طَلْحَةَ بْنِ عَمْرٍو، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ تَصَدَّقَ عَلَيْكُمْ عِنْدَ وَفَاتِكُمْ بِثُلُثِ أَمْوَالِكُمْ زِيَادَةً لَكُمْ فِي أَعْمَالِكُمْ ‏"‏ ‏.‏\hadithno{2709}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Allah (SWT) has been charitable with you over the disposal of one third of your wealth at the time of your death, so that you may be able to add to the record of your good deeds.”}}
\hadithdefcmd{ibnmajah}{2710}{حَدَّثَنَا صَالِحُ بْنُ مُحَمَّدِ بْنِ يَحْيَى بْنِ سَعِيدٍ الْقَطَّانِ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَنْبَأَنَا مُبَارَكُ بْنُ حَسَّانَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا ابْنَ آدَمَ اثْنَتَانِ لَمْ تَكُنْ لَكَ وَاحِدَةٌ مِنْهُمَا جَعَلْتُ لَكَ نَصِيبًا مِنْ مَالِكَ حِينَ أَخَذْتُ بِكَظَمِكَ لأُطَهِّرَكَ بِهِ وَأُزَكِّيَكَ وَصَلاَةُ عِبَادِي عَلَيْكَ بَعْدَ انْقِضَاءِ أَجَلِكَ ‏"‏ ‏.‏\hadithno{2710}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn Umar that the Messenger of Allah (ﷺ) said:“(Allah says) O son of Adam! I have given you two things which you do not deserve (except by mercy of Allah (SWT)): I allow you to dispose of a share of your wealth when you are on your deathbed, in order to cleanse and purify you, and my slaves pray for you after your life is over.”}}
\hadithdefcmd{ibnmajah}{2711}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ وَدِدْتُ أَنَّ النَّاسَ، غَضُّوا مِنَ الثُّلُثِ إِلَى الرُّبُعِ لأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الثُّلُثُ كَبِيرٌ - أَوْ كَثِيرٌ - ‏"‏ ‏.‏\hadithno{2711}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn Abbas said:“I would like the people to reduce (the will) from one third to one quarter, because the Messenger of Allah (ﷺ) said: 'One third is a lot.'”}}
\hadithdefcmd{ibnmajah}{2712}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ، عَنْ عَمْرِو بْنِ خَارِجَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَطَبَهُمْ وَهُوَ عَلَى رَاحِلَتِهِ وَإِنَّ رَاحِلَتَهُ لَتَقْصَعُ بِجِرَّتِهَا وَإِنَّ لُغَامَهَا لَيَسِيلُ بَيْنَ كَتِفَىَّ قَالَ ‏"‏ إِنَّ اللَّهَ قَسَمَ لِكُلِّ وَارِثٍ نَصِيبَهُ مِنَ الْمِيرَاثِ فَلاَ يَجُوزُ لِوَارِثٍ وَصِيَّةٌ الْوَلَدُ لِلْفِرَاشِ وَلِلْعَاهِرِ الْحَجَرُ وَمَنِ ادَّعَى إِلَى غَيْرِ أَبِيهِ أَوْ تَوَلَّى غَيْرَ مَوَالِيهِ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يُقْبَلُ مِنْهُ صَرْفٌ وَلاَ عَدْلٌ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ عَدْلٌ وَلاَ صَرْفٌ ‏"‏ ‏.‏\hadithno{2712}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Kharijah:“The Prophet (ﷺ) addressed them when he was on his camel. His camel was chewing its cud and its saliva was dripping between my shoulders. He said: 'Allah (SWT) has allocated for each heir his share of the inheritance, so it is not permissible (to make) a bequest for an heir. The child belong to the bed and the adulterer gets the stone. Whoever claims to belong to someone other than his father, or (a freed slave) who claims that his Wala is for other than his Mavali, upon him will be the curse of Allah, the angels and all the people, and no charge nor equitable exchange will be accepted from him.” Or he said: “No equitable exchange nor change.”}}
\hadithdefcmd{ibnmajah}{2713}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا شُرَحْبِيلُ بْنُ مُسْلِمٍ الْخَوْلاَنِيُّ، سَمِعْتُ أَبَا أُمَامَةَ الْبَاهِلِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي خُطْبَتِهِ عَامَ حِجَّةِ الْوَدَاعِ ‏ "‏ إِنَّ اللَّهَ قَدْ أَعْطَى كُلَّ ذِي حَقٍّ حَقَّهُ فَلاَ وَصِيَّةَ لِوَارِثٍ ‏"‏ ‏.‏\hadithno{2713}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Shurahbil bin Muslim Al-Khawlani narrated from Abu Umamah Al-Bahili that the heard :the Messenger of Allah (ﷺ) say in his sermon, during the year of the Farewell pilgrimage: “Allah (SWT) has given each person who has rights his rights, and there is no bequest for in heir.”}}
\hadithdefcmd{ibnmajah}{2714}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبِ بْنِ شَابُورَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ بْنِ جَابِرٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، أَنَّهُ حَدَّثَهُ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ إِنِّي لَتَحْتَ نَاقَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَسِيلُ عَلَىَّ لُعَابُهَا فَسَمِعْتُهُ يَقُولُ ‏ "‏ إِنَّ اللَّهَ قَدْ أَعْطَى كُلَّ ذِي حَقٍّ حَقَّهُ أَلاَ لاَ وَصِيَّةَ لِوَارِثٍ ‏"‏ ‏.‏\hadithno{2714}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:“I was under the she-camel of the Messenger of Allah (ﷺ) and its saliva was dripping between my shoulders, and I heard him say: 'Allah (SWT) has given each person who has rights his rights, but there is no bequest for an heir.”}}
\hadithdefcmd{ibnmajah}{2715}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالدَّيْنِ قَبْلَ الْوَصِيَّةِ وَأَنْتُمْ تَقْرَءُونَهَا ‏\{مِنْ بَعْدِ وَصِيَّةٍ يُوصِي بِهَا أَوْ دَيْنٍ \}‏ وَإِنَّ أَعْيَانَ بَنِي الأُمِّ لَيَتَوَارَثُونَ دُونَ بَنِي الْعَلاَّتِ ‏.‏\hadithno{2715}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Ali said:“The Messenger of Allah (ﷺ) ruled that the debts should be paid off before the execution of the will. You recite: '(The distribution in all cases is) after the payment of legacies he may have bequeathed or debts.' The sons of one mother (from the same father) inherit from one another, but not the sons from different mothers (but the same father).”}}
\hadithdefcmd{ibnmajah}{2716}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ إِنَّ أَبِي مَاتَ وَتَرَكَ مَالاً وَلَمْ يُوصِ فَهَلْ يُكَفِّرُ عَنْهُ أَنْ تَصَدَّقْتُ عَنْهُ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏\hadithno{2716}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that a man asked the Messenger of Allah (ﷺ):“My father died and left behind wealth, but he did not make a will. Will it expiate for him if I give charity on his behalf?” He said: “Yes.”}}
\hadithdefcmd{ibnmajah}{2717}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنَّ أُمِّي افْتُلِتَتْ نَفْسُهَا وَلَمْ تُوصِ وَإِنِّي أَظُنُّهَا لَوْ تَكَلَّمَتْ لَتَصَدَّقَتْ فَلَهَا أَجْرٌ إِنْ تَصَدَّقْتُ عَنْهَا وَلِيَ أَجْرٌ فَقَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏\hadithno{2717}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Aishah that a man came to the Prophet (ﷺ) and said:“My mother died unexpectedly and she had not made a will. I think that if she could have spoken, she would have given in charity. Will she have a reward if I give in charity on her behalf, and will I have a reward?” He said: “Yes.”}}
\hadithdefcmd{ibnmajah}{2718}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ لاَ أَجِدُ شَيْئًا وَلَيْسَ لِي مَالٌ وَلِي يَتِيمٌ لَهُ مَالٌ قَالَ ‏"‏ كُلْ مِنْ مَالِ يَتِيمِكَ غَيْرَ مُسْرِفٍ وَلاَ مُتَأَثِّلٍ مَالاً ‏"‏ ‏.‏ قَالَ وَأَحْسِبُهُ قَالَ ‏"‏ وَلاَ تَقِي مَالَكَ بِمَالِهِ ‏"‏ ‏.‏\hadithno{2718}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib from his father, that his a grandfather said:“A man came to the Prophet (ﷺ) and said: 'I do not have anything and I have no wealth, but I have an orphan (under my care) who has wealth.” He said: “Eat from the wealth of your orphan, without being extravagant or use it for trade.” He (narrator) said: “And I think he said: 'Do not preserve your wealth using his instead.'”}}
