% Auto-generated chapter 14 for malik
% Hadiths in this chapter: 15

\hadithdefcmd{malik}{455}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ رَافِعِ بْنِ إِسْحَاقَ، مَوْلًى لآلِ الشِّفَاءِ - وَكَانَ يُقَالُ لَهُ مَوْلَى أَبِي طَلْحَةَ - أَنَّهُ سَمِعَ أَبَا أَيُّوبَ الأَنْصَارِيَّ صَاحِبَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ بِمِصْرَ يَقُولُ وَاللَّهِ مَا أَدْرِي كَيْفَ أَصْنَعُ بِهَذِهِ الْكَرَايِيسِ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا ذَهَبَ أَحَدُكُمُ الْغَائِطَ أَوِ الْبَوْلَ فَلاَ يَسْتَقْبِلِ الْقِبْلَةَ وَلاَ يَسْتَدْبِرْهَا بِفَرْجِهِ ‏"‏ ‏.‏\hadithno{455}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ishaq ibn Abdullah ibn Abi Talha that Rafiibn Ishaq, a mawla of the family of ash-Shifa who was known as the mawla of Abu Talha, heard Abu Ayyub al-Ansari, one of the companions of the Messenger of Allah, may Allah bless him and grant him peace, say, while he was in Egypt, "By Allah! I don't know how to deal with these lavatories." The Messenger of Allah, may Allah bless him and grant him peace, said, "When you go to defecate or urinate, do not expose your genitals towards the qibla, and do not put your back to it}}
\hadithdefcmd{malik}{456}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ رَجُلٍ، مِنَ الأَنْصَارِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ تُسْتَقْبَلَ الْقِبْلَةُ لِغَائِطٍ أَوْ بَوْلٍ ‏.‏\hadithno{456}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from one of the Ansar that the Messenger of Allah, may Allah bless him and grant him peace, forbade defecating or urinating while facing the qibla}}
\hadithdefcmd{malik}{457}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمِّهِ، وَاسِعِ بْنِ حَبَّانَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ كَانَ يَقُولُ إِنَّ أُنَاسًا يَقُولُونَ إِذَا قَعَدْتَ عَلَى حَاجَتِكَ فَلاَ تَسْتَقْبِلِ الْقِبْلَةَ وَلاَ بَيْتَ الْمَقْدِسِ - قَالَ عَبْدُ اللَّهِ - لَقَدِ ارْتَقَيْتُ عَلَى ظَهْرِ بَيْتٍ لَنَا فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى لَبِنَتَيْنِ مُسْتَقْبِلَ بَيْتِ الْمَقْدِسِ لِحَاجَتِهِ ثُمَّ قَالَ لَعَلَّكَ مِنَ الَّذِينَ يُصَلُّونَ عَلَى أَوْرَاكِهِمْ ‏.‏ قَالَ قُلْتُ لاَ أَدْرِي وَاللَّهِ ‏.‏\hadithno{457}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Muhammad ibn Yahya ibn Habban from his paternal uncle, Wasi ibn Habban, that Abdullah ibn Umar said, "People say, 'When you sit to relieve yourself, do not face the qibla or the Bayt al-Maqdis.' " Abdullah continued, "I went upon top of a house of ours and saw the Messenger of Allah, may Allah bless him and grant him peace, (squatting) on two unfired bricks facing the Bayt al-Maqdis, relieving himself." Ibn Umar added, "Perhaps you are one of those who pray folded on their haunches." Wasi replied, "I don't know, by Allah}}
\hadithdefcmd{malik}{458}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى بُصَاقًا فِي جِدَارِ الْقِبْلَةِ فَحَكَّهُ ثُمَّ أَقْبَلَ عَلَى النَّاسِ فَقَالَ ‏ "‏ إِذَا كَانَ أَحَدُكُمْ يُصَلِّي فَلاَ يَبْصُقْ قِبَلَ وَجْهِهِ فَإِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى قِبَلَ وَجْهِهِ إِذَا صَلَّى ‏"‏ ‏.‏\hadithno{458}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Malik said that he meant someone who, when he prostrated, kept his body close to the ground. Yahya related to me from Malik from Nafi from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, saw spittle on the wall of the qibla and scraped it off. Then he went up to the people and said, "Do not spit in front of you when you are praying, because Allah, the Blessed and Exalted, is in front of you when you pray}}
\hadithdefcmd{malik}{459}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى\hadithno{459}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Hisham ibn Urwa from his father from A'isha, the wife of the Prophet, mayAllah bless him and grant him peace, that the Prophet, may Allah bless him and grant him peace, saw spittle, or mucus or phlegm, on the wall of the qibla and scraped it off}}
\hadithdefcmd{malik}{460}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ بَيْنَمَا النَّاسُ بِقُبَاءٍ فِي صَلاَةِ الصُّبْحِ إِذْ جَاءَهُمْ آتٍ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أُنْزِلَ عَلَيْهِ اللَّيْلَةَ قُرْآنٌ وَقَدْ أُمِرَ أَنْ يَسْتَقْبِلَ الْكَعْبَةَ فَاسْتَقْبِلُوهَا وَكَانَتْ وُجُوهُهُمْ إِلَى الشَّامِ فَاسْتَدَارُوا إِلَى الْكَعْبَةِ ‏.‏\hadithno{460}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Dinar that Abdullah ibn Umar said, "On one occasion when the people were praying subhat Quba a man came to them and said, 'A piece of Qur'an was sent down to the Messenger of Allah, may Allah bless him and grant him peace, last night, and he was ordered to face the Kaba, so face it.' They had been facing ash-Sham, so they turned round and faced the Kaba}}
\hadithdefcmd{malik}{461}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّهُ قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بَعْدَ أَنْ قَدِمَ الْمَدِينَةَ سِتَّةَ عَشَرَ شَهْرًا نَحْوَ بَيْتِ الْمَقْدِسِ ثُمَّ حُوِّلَتِ الْقِبْلَةُ قَبْلَ بَدْرٍ بِشَهْرَيْنِ ‏.‏\hadithno{461}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Said ibn al-Musayyab said, "The Messenger of Allah, may Allah bless him and grant him peace, prayed towards the Baytal-Maqdis for sixteen months after arriving in Madina. Then the qibla was moved, two months before the battle of Badr}}
\hadithdefcmd{malik}{462}{حَدَّثَنِي عَنْ مَالِكٍ، عَنْ نَافِعٍ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، قَالَ مَا بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ قِبْلَةٌ إِذَا تُوُجِّهَ قِبَلَ الْبَيْتِ ‏.‏\hadithno{462}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Nafi that Umar ibn al-Khattab said, "Any direction that is between east and west can be taken as a qibla if the person praying is face-on to the House}}
\hadithdefcmd{malik}{463}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ رَبَاحٍ، وَعُبَيْدِ اللَّهِ بْنِ أَبِي عَبْدِ اللَّهِ، عَنْ أَبِي عَبْدِ اللَّهِ، سَلْمَانَ الأَغَرِّ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةٌ فِي مَسْجِدِي هَذَا خَيْرٌ مِنْ أَلْفِ صَلاَةٍ فِيمَا سِوَاهُ إِلاَّ الْمَسْجِدَ الْحَرَامَ ‏"‏ ‏.‏\hadithno{463}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Zayd ibn Rabah and Ubaydullah ibn Abi Abdullah Salman al-Agharr from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "A prayer in this mosque of mine is better than a thousand prayers in any other mosque, except the Masjid al-Haram (in Makka)}}
\hadithdefcmd{malik}{464}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَوْ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا بَيْنَ بَيْتِي وَمِنْبَرِي رَوْضَةٌ مِنْ رِيَاضِ الْجَنَّةِ وَمِنْبَرِي عَلَى حَوْضِي ‏"‏ ‏.‏\hadithno{464}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Khubayb ibn Abd ar-Rahman from Hafs ibn Asim from Abu Hurayra or from Abu Said al-Khudri that the Messenger of Allah, may Allah bless him and grant him peace, said, "What is between my house and my mimbar is one of the meadows of the Garden, and my mimbar is on my watering-place (al-Hawd)}}
\hadithdefcmd{malik}{465}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ الْمَازِنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا بَيْنَ بَيْتِي وَمِنْبَرِي رَوْضَةٌ مِنْ رِيَاضِ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{465}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abdullah ibn Abi Bakr from Abbad ibn Tamim from Abdullah ibn Zayd al-Mazini that the Messenger of Allah, may Allah bless him and grant him peace, said, "What is between my house and my mimbar is one of the meadows of the Garden}}
\hadithdefcmd{malik}{466}{حَدَّثَنِي يَحْيَى، عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَمْنَعُوا إِمَاءَ اللَّهِ مَسَاجِدَ اللَّهِ ‏"‏ ‏.‏\hadithno{466}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that Abdullah ibn Umar said, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'Do not forbid the female slaves of Allah from (going into) the mosques of Allah}}
\hadithdefcmd{malik}{467}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ بُسْرِ بْنِ سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا شَهِدَتْ إِحْدَاكُنَّ صَلاَةَ الْعِشَاءِ فَلاَ تَمَسَّنَّ طِيبًا ‏"‏ ‏.‏\hadithno{467}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he had heard from Busr ibn Said that the Messenger of Allah, may Allah bless him and grant him peace, said, "None of you women should use perfume when you are present at the isha prayer}}
\hadithdefcmd{malik}{468}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَاتِكَةَ بِنْتِ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ، امْرَأَةِ عُمَرَ بْنِ الْخَطَّابِ أَنَّهَا كَانَتْ تَسْتَأْذِنُ عُمَرَ بْنَ الْخَطَّابِ إِلَى الْمَسْجِدِ فَيَسْكُتُ فَتَقُولُ وَاللَّهِ لأَخْرُجَنَّ إِلاَّ أَنْ تَمْنَعَنِي ‏.‏ فَلاَ يَمْنَعُهَا ‏.‏\hadithno{468}\hadithgrade{Salim al-Hilali: Mauquf Daif}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said that Atika bint Zayd ibn Amr ibn Nufayl, the wife of Umar ibn al-Khattab, used to ask Umar ibn al-Khattab for permission to go to the mosque. He would keep silent, so she would say, "By Allah, I will go out, unless you forbid me," and he would not forbid her}}
\hadithdefcmd{malik}{469}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ لَوْ أَدْرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا أَحْدَثَ النِّسَاءُ لَمَنَعَهُنَّ الْمَسَاجِدَ كَمَا مُنِعَهُ نِسَاءُ بَنِي إِسْرَائِيلَ ‏.‏ قَالَ يَحْيَى بْنُ سَعِيدٍ فَقُلْتُ لِعَمْرَةَ أَوَمُنِعَ نِسَاءُ بَنِي إِسْرَائِيلَ الْمَسَاجِدَ قَالَتْ نَعَمْ ‏.‏\hadithno{469}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Yahya ibn Said from Amra bint Abd ar-Rahman that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "If the Messenger of Allah, may Allah bless him and grant him peace, had seen what women do now, he would have forbidden them to go into the mosques, just as the women of the Bani Israil were forbidden." Yahya ibn Said said that he asked Amra, "Were the women of the Bani Israil forbidden to go into the mosques?" and she said, "Yes}}
