% Auto-generated chapter 29 for abudawud
% Hadiths in this chapter: 49

\hadithdefcmd{abudawud}{3855}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ النَّمَرِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ أُسَامَةَ بْنِ شَرِيكٍ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَأَصْحَابُهُ كَأَنَّمَا عَلَى رُءُوسِهِمُ الطَّيْرُ فَسَلَّمْتُ ثُمَّ قَعَدْتُ فَجَاءَ الأَعْرَابُ مِنْ هَا هُنَا وَهَا هُنَا فَقَالُوا يَا رَسُولَ اللَّهِ أَنَتَدَاوَى فَقَالَ ‏ "‏ تَدَاوَوْا فَإِنَّ اللَّهَ عَزَّ وَجَلَّ لَمْ يَضَعْ دَاءً إِلاَّ وَضَعَ لَهُ دَوَاءً غَيْرَ دَاءٍ وَاحِدٍ الْهَرَمُ ‏"‏ ‏.‏\hadithno{3855}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Usamah ibn Sharik: I came to the Prophet (ﷺ) and his Companions were sitting as if they had birds on their heads. I saluted and sat down. The desert Arabs then came from here and there. They asked: Messenger of Allah, should we make use of medical treatment? He replied: Make use of medical treatment, for Allah has not made a disease without appointing a remedy for it, with the exception of one disease, namely old age}}
\hadithdefcmd{abudawud}{3856}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو دَاوُدَ، وَأَبُو عَامِرٍ - وَهَذَا لَفْظُ أَبِي عَامِرٍ - عَنْ فُلَيْحِ بْنِ سُلَيْمَانَ، عَنْ أَيُّوبَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ صَعْصَعَةَ الأَنْصَارِيِّ، عَنْ يَعْقُوبَ بْنِ أَبِي يَعْقُوبَ، عَنْ أُمِّ الْمُنْذِرِ بِنْتِ قَيْسٍ الأَنْصَارِيَّةِ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَعَهُ عَلِيٌّ عَلَيْهِ السَّلاَمُ وَعَلِيٌّ نَاقِهٌ وَلَنَا دَوَالِي مُعَلَّقَةٌ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْكُلُ مِنْهَا وَقَامَ عَلِيٌّ لِيَأْكُلَ فَطَفِقَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ لِعَلِيٍّ ‏"‏ مَهْ إِنَّكَ نَاقِهٌ ‏"‏ ‏.‏ حَتَّى كَفَّ عَلِيٌّ عَلَيْهِ السَّلاَمُ ‏.‏ قَالَتْ وَصَنَعْتُ شَعِيرًا وَسِلْقًا فَجِئْتُ بِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا عَلِيُّ أَصِبْ مِنْ هَذَا فَهُوَ أَنْفَعُ لَكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ هَارُونُ الْعَدَوِيَّةِ ‏.‏\hadithno{3856}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm al-Mundhar bint Qays al-Ansariyyah: The Messenger of Allah (ﷺ) came to visit me, accompanied by Ali who was convalescing. We had some ripe dates hung up. The Messenger of Allah (ﷺ) got up and began to eat from them. Ali also got up to eat, but the Messenger of Allah (ﷺ) said repeatedly to Ali: Stop, Ali, for you are convalescing, and Ali stopped. She said: I then prepared some barley and beer-root and brought it. The Messenger of Allah (ﷺ) then said: Take some of this, Ali, for it will be more beneficial for you. AbuDawud said: The narrator Harun said: al-Adawiyyah (i.e. Umm al-Mundhar)}}
\hadithdefcmd{abudawud}{3857}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنْ كَانَ فِي شَىْءٍ مِمَّا تَدَاوَيْتُمْ بِهِ خَيْرٌ فَالْحِجَامَةُ ‏"‏ ‏.‏\hadithno{3857}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurayrah: The Prophet (ﷺ) said: The best medical treatment you apply is cupping}}
\hadithdefcmd{abudawud}{3858}{حَدَّثَنَا مُحَمَّدُ بْنُ الْوَزِيرِ الدِّمَشْقِيُّ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ حَسَّانَ - حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الْمَوَالِي، حَدَّثَنَا فَائِدٌ، مَوْلَى عُبَيْدِ اللَّهِ بْنِ عَلِيِّ بْنِ أَبِي رَافِعٍ عَنْ مَوْلاَهُ، عُبَيْدِ اللَّهِ بْنِ عَلِيِّ بْنِ أَبِي رَافِعٍ عَنْ جَدَّتِهِ، سَلْمَى خَادِمِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ مَا كَانَ أَحَدٌ يَشْتَكِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَجَعًا فِي رَأْسِهِ إِلاَّ قَالَ ‏"‏ احْتَجِمْ ‏"‏ ‏.‏ وَلاَ وَجَعًا فِي رِجْلَيْهِ إِلاَّ قَالَ ‏"‏ اخْضِبْهُمَا ‏"‏ ‏.‏\hadithno{3858}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salmah: the maid-servant of the Messenger of Allah (ﷺ), said: No one complained to the Messenger of Allah (ﷺ) of a headache but he told him to get himself cupped, or of a pain in his legs but he told him to dye them with henna}}
\hadithdefcmd{abudawud}{3859}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، وَكَثِيرُ بْنُ عُبَيْدٍ، قَالاَ حَدَّثَنَا الْوَلِيدُ، عَنِ ابْنِ ثَوْبَانَ، عَنْ أَبِيهِ، عَنْ أَبِي كَبْشَةَ الأَنْمَارِيِّ، - قَالَ كَثِيرٌ إِنَّهُ حَدَّثَهُ - أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَحْتَجِمُ عَلَى هَامَتِهِ وَبَيْنَ كَتِفَيْهِ وَهُوَ يَقُولُ ‏ "‏ مَنْ أَهْرَاقَ مِنْ هَذِهِ الدِّمَاءِ فَلاَ يَضُرُّهُ أَنْ لاَ يَتَدَاوَى بِشَىْءٍ لِشَىْءٍ ‏"‏ ‏.‏\hadithno{3859}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Kabshah al-Ansari: The Messenger of Allah (ﷺ) used to have himself cupped on the top of his head and between his shoulders, and that he used to say: If anyone pours out any of his blood, he will not suffer if he applies no medical treatment for anything}}
\hadithdefcmd{abudawud}{3860}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا جَرِيرٌ، - يَعْنِي ابْنَ حَازِمٍ - حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم احْتَجَمَ ثَلاَثًا فِي الأَخْدَعَيْنِ وَالْكَاهِلِ ‏.‏ قَالَ مَعْمَرٌ احْتَجَمْتُ فَذَهَبَ عَقْلِي حَتَّى كُنْتُ أُلَقَّنُ فَاتِحَةَ الْكِتَابِ فِي صَلاَتِي ‏.‏ وَكَانَ احْتَجَمَ عَلَى هَامَتِهِ ‏.‏\hadithno{3860}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) had himself cupped three times in the veins at the sides of the neck and on the shoulder. Ma'mar said: I got myself cupped, and I lost my memory so much so that I was instructed Surat al-Fatihah by others in my prayer. He had himself cupped at the top of his head}}
\hadithdefcmd{abudawud}{3861}{حَدَّثَنَا أَبُو تَوْبَةَ الرَّبِيعُ بْنُ نَافِعٍ، حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْجُمَحِيُّ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ احْتَجَمَ لِسَبْعَ عَشْرَةَ وَتِسْعَ عَشْرَةَ وَإِحْدَى وَعِشْرِينَ كَانَ شِفَاءً مِنْ كُلِّ دَاءٍ ‏"‏ ‏.‏\hadithno{3861}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurayrah: The Prophet (ﷺ) said: If anyone has himself cupped on the 17th, 19th and 21st it will be a remedy for every disease}}
\hadithdefcmd{abudawud}{3862}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، أَخْبَرَنِي أَبُو بَكْرَةَ، بَكَّارُ بْنُ عَبْدِ الْعَزِيزِ أَخْبَرَتْنِي عَمَّتِي، كَبْشَةُ بِنْتُ أَبِي بَكْرَةَ - وَقَالَ غَيْرُ مُوسَى كَيِّسَةُ بِنْتُ أَبِي بَكْرَةَ - أَنَّ أَبَاهَا، كَانَ يَنْهَى أَهْلَهُ عَنِ الْحِجَامَةِ، يَوْمَ الثُّلاَثَاءِ وَيَزْعُمُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ يَوْمَ الثُّلاَثَاءِ يَوْمُ الدَّمِ وَفِيهِ سَاعَةٌ لاَ يَرْقَأُ ‏.‏\hadithno{3862}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Kabshah daughter of AbuBakrah: (the narrator other than Musa said that Kayyisah daughter of AbuBakrah) She said that her father used to forbid his family to have themselves cupped on a Tuesday, and used to assert on the authority of the Messenger of Allah (ﷺ) that Tuesday is the day of blood in which there is an hour when it does not stop}}
\hadithdefcmd{abudawud}{3863}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم احْتَجَمَ عَلَى وَرِكِهِ مِنْ وَثْءٍ كَانَ بِهِ ‏.‏\hadithno{3863}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) had himself cupped above the thigh for a contusion from which he suffered}}
\hadithdefcmd{abudawud}{3864}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ بَعَثَ النَّبِيُّ صلى الله عليه وسلم إِلَى أُبَىٍّ طَبِيبًا فَقَطَعَ مِنْهُ عِرْقًا ‏.‏\hadithno{3864}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (2207)}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) sent a physician to Ubayy (ibn Ka'b), and he cut his vein}}
\hadithdefcmd{abudawud}{3865}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ مُطَرِّفٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ الْكَىِّ فَاكْتَوَيْنَا فَمَا أَفْلَحْنَ وَلاَ أَنْجَحْنَ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَانَ يَسْمَعُ تَسْلِيمَ الْمَلاَئِكَةِ فَلَمَّا اكْتَوَى انْقَطَعَ عَنْهُ فَلَمَّا تَرَكَ رَجَعَ إِلَيْهِ ‏.‏\hadithno{3865}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Imran ibn Husayn: The Prophet (ﷺ) forbade to cauterise; we cauterised but they (cauterisation) did not benefit us, nor proved useful for us. Abu Dawud said: He used to hear the salutation of the angels: When he cauterized, it stopped. When he abandoned, it returned to him}}
\hadithdefcmd{abudawud}{3866}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَوَى سَعْدَ بْنَ مُعَاذٍ مِنْ رَمِيَّتِهِ ‏.‏\hadithno{3866}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2208)}\hadithtrans{Jabir said:The Prophet (ﷺ) cauterized Sa’d b. Mu’adh from the wound of an arrow}}
\hadithdefcmd{abudawud}{3867}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَحْمَدُ بْنُ إِسْحَاقَ، حَدَّثَنَا وُهَيْبٌ، عَنْ عَبْدِ اللَّهِ بْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَعَطَ ‏.‏\hadithno{3867}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5691) Sahih Muslim (1202 After  1577)}\hadithtrans{Ibn’Abbas said:The Messenger of Allah (ﷺ) snuffed medicine}}
\hadithdefcmd{abudawud}{3868}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا عَقِيلُ بْنُ مَعْقِلٍ، قَالَ سَمِعْتُ وَهْبَ بْنَ مُنَبِّهٍ، يُحَدِّثُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ النُّشْرَةِ فَقَالَ ‏ "‏ هُوَ مِنْ عَمَلِ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{3868}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) was asked about a charm for one who is possessed (nashrah). He replied: It pertains to the work of the devil}}
\hadithdefcmd{abudawud}{3869}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، حَدَّثَنَا شُرَحْبِيلُ بْنُ يَزِيدَ الْمَعَافِرِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ رَافِعٍ التَّنُوخِيِّ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا أُبَالِي مَا أَتَيْتُ إِنْ أَنَا شَرِبْتُ تِرْيَاقًا أَوْ تَعَلَّقْتُ تَمِيمَةً أَوْ قُلْتُ الشِّعْرَ مِنْ قِبَلِ نَفْسِي ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا كَانَ لِلنَّبِيِّ صلى الله عليه وسلم خَاصَّةً وَقَدْ رَخَّصَ فِيهِ قَوْمٌ يَعْنِي التِّرْيَاقَ ‏.‏\hadithno{3869}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: I heard the Messenger of Allah (ﷺ) say: If I drink an antidote, or tie an amulet, or compose poetry, I am the type who does not care what he does. Abu Dawud said: THis was peculiar to the Prophet (ﷺ), but some people have allowed to use it, i.e. antidote}}
\hadithdefcmd{abudawud}{3870}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ مُجَاهِدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الدَّوَاءِ الْخَبِيثِ ‏.‏\hadithno{3870}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurayrah: The Messenger of Allah (ﷺ) prohibited unclean medicine}}
\hadithdefcmd{abudawud}{3871}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ سَعِيدِ بْنِ خَالِدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عُثْمَانَ، أَنَّ طَبِيبًا، سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنْ ضِفْدَعٍ يَجْعَلُهَا فِي دَوَاءٍ فَنَهَاهُ النَّبِيُّ صلى الله عليه وسلم عَنْ قَتْلِهَا ‏.‏\hadithno{3871}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbdurRahman ibn Uthman: When a physician consulted the Prophet (ﷺ) about putting frogs in medicine, he forbade him to kill them}}
\hadithdefcmd{abudawud}{3872}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَسَا سُمًّا فَسُمُّهُ فِي يَدِهِ يَتَحَسَّاهُ فِي نَارِ جَهَنَّمَ خَالِدًا مُخَلَّدًا فِيهَا أَبَدًا ‏"‏ ‏.‏\hadithno{3872}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying:If anyone drinks poison, the poison will be in his hand (on the Day of Judgement) and he will drink it in Hell-fire and he will live in it eternally}}
\hadithdefcmd{abudawud}{3873}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكٍ، عَنْ عَلْقَمَةَ بْنِ وَائِلٍ، عَنْ أَبِيهِ، ذَكَرَ طَارِقَ بْنَ سُوَيْدٍ أَوْ سُوَيْدَ بْنَ طَارِقٍ سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنِ الْخَمْرِ فَنَهَاهُ ثُمَّ سَأَلَهُ فَنَهَاهُ فَقَالَ لَهُ يَا نَبِيَّ اللَّهِ إِنَّهَا دَوَاءٌ ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ وَلَكِنَّهَا دَاءٌ ‏"‏ ‏.‏\hadithno{3873}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1984)}\hadithtrans{Narrated Tariq ibn Suwayd or Suwayd ibn Tariq: Wa'il said: Tariq ibn Suwayd or Suwayd ibn Tariq asked the Prophet (ﷺ) about wine, but he forbade it. He again asked him, but he forbade him. He said to him: Prophet of Allah, it is a medicine. The Prophet (ﷺ) said: No it is a disease}}
\hadithdefcmd{abudawud}{3874}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَادَةَ الْوَاسِطِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ ثَعْلَبَةَ بْنِ مُسْلِمٍ، عَنْ أَبِي عِمْرَانَ الأَنْصَارِيِّ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ أَنْزَلَ الدَّاءَ وَالدَّوَاءَ وَجَعَلَ لِكُلِّ دَاءٍ دَوَاءً فَتَدَاوَوْا وَلاَ تَدَاوَوْا بِحَرَامٍ ‏"‏ ‏.‏\hadithno{3874}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu al-Darda: The Prophet (ﷺ) said: Allah has sent down both the disease and the cure, and He has appointed a cure for every disease, so treat yourselves medically, but use nothing unlawful}}
\hadithdefcmd{abudawud}{3875}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ سَعْدٍ، قَالَ مَرِضْتُ مَرَضًا أَتَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم يَعُودُنِي فَوَضَعَ يَدَهُ بَيْنَ ثَدْيَىَّ حَتَّى وَجَدْتُ بَرْدَهَا عَلَى فُؤَادِي فَقَالَ ‏ "‏ إِنَّكَ رَجُلٌ مَفْئُودٌ ائْتِ الْحَارِثَ بْنَ كَلَدَةَ أَخَا ثَقِيفٍ فَإِنَّهُ رَجْلٌ يَتَطَبَّبُ فَلْيَأْخُذْ سَبْعَ تَمَرَاتٍ مِنْ عَجْوَةِ الْمَدِينَةِ فَلْيَجَأْهُنَّ بِنَوَاهُنَّ ثُمَّ لِيَلُدَّكَ بِهِنَّ ‏"‏ ‏.‏\hadithno{3875}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Sa'd: I suffered from an illness. The Messenger of Allah (ﷺ) came to pay a visit to me. He put his hands between my nipples and I felt its coolness at my heart. He said: You are a man suffering from heart sickness. Go to al-Harith ibn Kaladah, brother of Thaqif. He is a man who gives medical treatment. He should take seven ajwah dates of Medina and grind them with their kernels, and then put them into your mouth}}
\hadithdefcmd{abudawud}{3876}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هَاشِمُ بْنُ هَاشِمٍ، عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَصَبَّحَ سَبْعَ تَمَرَاتِ عَجْوَةٍ لَمْ يَضُرُّهُ ذَلِكَ الْيَوْمَ سَمٌّ وَلاَ سِحْرٌ ‏"‏ ‏.‏\hadithno{3876}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5769) Sahih Muslim (2047)}\hadithtrans{Sa’d b. Abl Waqqas reported the prophet (ﷺ) as saying:He who has a morning meal of seven ‘Ajwah dates will not suffer from any harm that day through poison or magic}}
\hadithdefcmd{abudawud}{3877}{حَدَّثَنَا مُسَدَّدٌ، وَحَامِدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، قَالَتْ دَخَلْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِابْنٍ لِي قَدْ أَعْلَقْتُ عَلَيْهِ مِنَ الْعُذْرَةِ فَقَالَ ‏ "‏ عَلاَمَ تَدْغَرْنَ أَوْلاَدَكُنَّ بِهَذَا الْعِلاَقِ عَلَيْكُنَّ بِهَذَا الْعُودِ الْهِنْدِيِّ فَإِنَّ فِيهِ سَبْعَةَ أَشْفِيَةٍ مِنْهَا ذَاتُ الْجَنْبِ يُسْعَطُ مِنَ الْعُذْرَةِ وَيُلَدُّ مِنْ ذَاتِ الْجَنْبِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ يَعْنِي بِالْعُودِ الْقُسْطَ ‏.‏\hadithno{3877}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5713) Sahih Muslim (2214)}\hadithtrans{Umm Qasis, daughter of Mihsan said :I brought my son to the Messenger of Allah (ﷺ) while I had compressed his uvula for its swelling. He said : Why do you afflict your children by squeezing for a swelling in the Uvula ? Apply this Indian aloes wood, for it contain seven types of remedies, among them being a remedy for pleurisy. It is applied through the nose for a swelling of the uvula poured into the side of the mouth for pleurisy. Abu Dawud said : By aloes wood he meant costus}}
\hadithdefcmd{abudawud}{3878}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبَسُوا مِنْ ثِيَابِكُمُ الْبَيَاضَ فَإِنَّهَا مِنْ خَيْرِ ثِيَابِكُمْ وَكَفِّنُوا فِيهَا مَوْتَاكُمْ وَإِنَّ خَيْرَ أَكْحَالِكُمُ الإِثْمِدُ يَجْلُو الْبَصَرَ وَيُنْبِتُ الشَّعْرَ ‏"‏ ‏.‏\hadithno{3878}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: Wear your white garments, for they are among your best garments, and shroud your dead in them. Among the best types of collyrium you use is antimony (ithmid): it clears the vision and makes the hair sprout}}
\hadithdefcmd{abudawud}{3879}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْعَيْنُ حَقٌّ ‏"‏ ‏.‏\hadithno{3879}\hadithgrade{Al-Albani: Sahih Mutawatir; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Mutawatir; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5740) Sahih Muslim (2187)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying :The evil is genuine}}
\hadithdefcmd{abudawud}{3880}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ كَانَ يُؤْمَرُ الْعَائِنُ فَيَتَوَضَّأُ ثُمَّ يَغْتَسِلُ مِنْهُ الْمَعِينُ ‏.‏\hadithno{3880}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The man casting evil would be commanded to perform ablution, and then the man affected was washed with it}}
\hadithdefcmd{abudawud}{3881}{حَدَّثَنَا الرَّبِيعُ بْنُ نَافِعٍ أَبُو تَوْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ مُهَاجِرٍ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ بْنِ السَّكَنِ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَقْتُلُوا أَوْلاَدَكُمْ سِرًّا فَإِنَّ الْغَيْلَ يُدْرِكُ الْفَارِسَ فَيُدَعْثِرُهُ عَنْ فَرَسِهِ ‏"‏ ‏.‏\hadithno{3881}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Asma', daughter of Yazid ibn as-Sakan,: I heard the Messenger of Allah (ﷺ) as saying: Do not kill your children secretly, for the milk, with which a child is suckled while his mother is pregnant, overtakes the horseman and throws him from his horse}}
\hadithdefcmd{abudawud}{3882}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم عَنْ جُدَامَةَ الأَسَدِيَّةِ أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَقَدْ هَمَمْتُ أَنْ أَنْهَى عَنِ الْغَيْلَةِ حَتَّى ذُكِّرْتُ أَنَّ الرُّومَ وَفَارِسَ يَفْعَلُونَ ذَلِكَ فَلاَ يَضُرُّ أَوْلاَدَهُمْ ‏"‏ ‏.‏ قَالَ مَالِكٌ الْغَيْلَةُ أَنْ يَمَسَّ الرَّجُلُ امْرَأَتَهُ وَهِيَ تُرْضِعُ ‏.‏\hadithno{3882}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1442)}\hadithtrans{Judamat al-Asadiyyah said that she heard the Messenger of Allah (May peace be upon him) Say:I intended to prohibit suckling during pregnancy (ghailah), but I considered the Greeks and the Persians and saw that they practiced it, without any injury being caused to their children thereby. Malik said : Ghailah means that a man has intercourse with a women while she is suckling a child}}
\hadithdefcmd{abudawud}{3883}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ يَحْيَى بْنِ الْجَزَّارِ، عَنِ ابْنِ أَخِي، زَيْنَبَ امْرَأَةِ عَبْدِ اللَّهِ عَنْ زَيْنَبَ، امْرَأَةِ عَبْدِ اللَّهِ عَنْ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ الرُّقَى وَالتَّمَائِمَ وَالتِّوَلَةَ شِرْكٌ ‏"‏ ‏.‏ قَالَتْ قُلْتُ لِمَ تَقُولُ هَذَا وَاللَّهِ لَقَدْ كَانَتْ عَيْنِي تَقْذِفُ وَكُنْتُ أَخْتَلِفُ إِلَى فُلاَنٍ الْيَهُودِيِّ يَرْقِينِي فَإِذَا رَقَانِي سَكَنَتْ ‏.‏ فَقَالَ عَبْدُ اللَّهِ إِنَّمَا ذَاكِ عَمَلُ الشَّيْطَانِ كَانَ يَنْخَسُهَا بِيَدِهِ فَإِذَا رَقَاهَا كَفَّ عَنْهَا إِنَّمَا كَانَ يَكْفِيكِ أَنْ تَقُولِي كَمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ أَذْهِبِ الْبَاسَ رَبَّ النَّاسِ اشْفِ أَنْتَ الشَّافِي لاَ شِفَاءَ إِلاَّ شِفَاؤُكَ شِفَاءً لاَ يُغَادِرُ سَقَمًا ‏"‏ ‏.‏\hadithno{3883}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: Zaynab, the wife of Abdullah ibn Mas'ud, told that Abdullah said: I heard the Messenger of Allah (ﷺ) saying: spells, charms and love-potions are polytheism. I asked: Why do you say this? I swear by Allah, when my eye was discharging I used to go to so-and-so, the Jew, who applied a spell to me. When he applied the spell to me, it calmed down. Abdullah said: That was just the work of the Devil who was picking it with his hand, and when he uttered the spell on it, he desisted. All you need to do is to say as the Messenger of Allah (ﷺ) used to say: Remove the harm, O Lord of men, and heal. Thou art the Healer. There is no remedy but Thine which leaves no disease behind}}
\hadithdefcmd{abudawud}{3884}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ مَالِكِ بْنِ مِغْوَلٍ، عَنْ حُصَيْنٍ، عَنِ الشَّعْبِيِّ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ رُقْيَةَ إِلاَّ مِنْ عَيْنٍ أَوْ حُمَةٍ ‏"‏ ‏.‏\hadithno{3884}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Imran ibn Husayn: The Prophet (ﷺ) said: No spell is to be used except for the evil eye or a scorpion sting}}
\hadithdefcmd{abudawud}{3885}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، وَابْنُ السَّرْحِ، - قَالَ أَحْمَدُ حَدَّثَنَا ابْنُ وَهْبٍ، وَقَالَ ابْنُ السَّرْحِ، - أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنَا دَاوُدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ يُوسُفَ بْنِ مُحَمَّدٍ، - وَقَالَ ابْنُ صَالِحٍ مُحَمَّدِ بْنِ يُوسُفَ بْنِ ثَابِتِ بْنِ قَيْسِ بْنِ شَمَّاسٍ - عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ دَخَلَ عَلَى ثَابِتِ بْنِ قَيْسٍ - قَالَ أَحْمَدُ - وَهُوَ مَرِيضٌ فَقَالَ ‏ "‏ اكْشِفِ الْبَاسَ رَبَّ النَّاسِ ‏"‏ ‏.‏ عَنْ ثَابِتِ بْنِ قَيْسٍ ثُمَّ أَخَذَ تُرَابًا مِنْ بَطْحَانَ فَجَعَلَهُ فِي قَدَحٍ ثُمَّ نَفَثَ عَلَيْهِ بِمَاءٍ وَصَبَّهُ عَلَيْهِ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ ابْنُ السَّرْحِ يُوسُفُ بْنُ مُحَمَّدٍ وَهُوَ الصَّوَابُ ‏.‏\hadithno{3885}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Thabit ibn Qays ibn Shammas: The Messenger of Allah (ﷺ) entered upon Thabit ibn Qays. The version of Ahmad (ibn Salih) has: When he was ill He (the Prophet) said: Remove the harm, O Lord of men, from Thabit ibn Qays ibn Shammas. He then took some dust of Bathan, and put it in a bowel, and then mixed it with water and blew in it, and poured it on him. Abu Dawud said: Ibn al-Sarh said: Yusuf bin Muhammad is correct (and not Muhammad bin Yusuf)}}
\hadithdefcmd{abudawud}{3886}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مُعَاوِيَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنْ عَوْفِ بْنِ مَالِكٍ، قَالَ كُنَّا نَرْقِي فِي الْجَاهِلِيَّةِ فَقُلْنَا يَا رَسُولَ اللَّهِ كَيْفَ تَرَى فِي ذَلِكَ فَقَالَ ‏ "‏ اعْرِضُوا عَلَىَّ رُقَاكُمْ لاَ بَأْسَ بِالرُّقَى مَا لَمْ تَكُنْ شِرْكًا ‏"‏ ‏.‏\hadithno{3886}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2200)}\hadithtrans{‘Awf b. Malik said :In the pre-Islamic period we used to apply spells and we asked: Messenger of Allah ! how do you look upon it ? He replied : Submit your spells to me. There is no harm in spells so long as they involve no polytheism}}
\hadithdefcmd{abudawud}{3887}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مَهْدِيٍّ الْمِصِّيصِيُّ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ أَبِي بَكْرِ بْنِ سُلَيْمَانَ بْنِ أَبِي حَثْمَةَ، عَنِ الشِّفَاءِ بِنْتِ عَبْدِ اللَّهِ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا عِنْدَ حَفْصَةَ فَقَالَ لِي ‏ "‏ أَلاَ تُعَلِّمِينَ هَذِهِ رُقْيَةَ النَّمْلَةِ كَمَا عَلَّمْتِيهَا الْكِتَابَةَ ‏"‏ ‏.‏\hadithno{3887}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ash-Shifa', daughter of Abdullah,: The Messenger of Allah (ﷺ) entered when I was with Hafsah, and he said to me: Why do you not teach this one the spell for skin eruptions as you taught her writing}}
\hadithdefcmd{abudawud}{3888}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، حَدَّثَتْنِي جَدَّتِي الرَّبَابُ، قَالَتْ سَمِعْتُ سَهْلَ بْنَ حُنَيْفٍ، يَقُولُ مَرَرْنَا بِسَيْلٍ فَدَخَلْتُ فَاغْتَسَلْتُ فِيهِ فَخَرَجْتُ مَحْمُومًا فَنُمِيَ ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مُرُوا أَبَا ثَابِتٍ يَتَعَوَّذْ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ يَا سَيِّدِي وَالرُّقَى صَالِحَةٌ فَقَالَ ‏"‏ لاَ رُقْيَةَ إِلاَّ فِي نَفْسٍ أَوْ حُمَةٍ أَوْ لَدْغَةٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الْحُمَةُ مِنَ الْحَيَّاتِ وَمَا يَلْسَعُ ‏.‏\hadithno{3888}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Sahl ibn Hunayf: I passed by a river. I entered it and took a bath in it. When I came out, I had fever. The Messenger of Allah (ﷺ) was informed about it. He said: Ask AbuThabit to seek refuge in Allah from that I asked: O my Lord, will the spell be useful? He replied: No, the spell is to be used except for the evil eye or a snake bite or a scorpion sting. Abu Dawud said: Humah means the biting of snakes and sting of the poisonous insects}}
\hadithdefcmd{abudawud}{3889}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ، حَدَّثَنَا شَرِيكٌ، ح وَحَدَّثَنَا الْعَبَّاسُ الْعَنْبَرِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا شَرِيكٌ، عَنِ الْعَبَّاسِ بْنِ ذَرِيحٍ، عَنِ الشَّعْبِيِّ، - قَالَ الْعَبَّاسُ - عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ رُقْيَةَ إِلاَّ مِنْ عَيْنٍ أَوْ حُمَةٍ أَوْ دَمٍ يَرْقَأُ ‏"‏ ‏.‏ لَمْ يَذْكُرِ الْعَبَّاسُ الْعَيْنَ وَهَذَا لَفْظُ سُلَيْمَانَ بْنِ دَاوُدَ ‏.‏\hadithno{3889}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas reported the Prophet (ﷺ) as saying :No spell is to be used except for the evil eye, or sting of poisonous insects, or bleeding. The narrator al-‘Abhas did mention the words “evil eye”. The is the version of Sulaiman b. Dawud}}
\hadithdefcmd{abudawud}{3890}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، قَالَ قَالَ أَنَسٌ - يَعْنِي - لِثَابِتٍ أَلاَ أَرْقِيكَ بِرُقْيَةِ رَسُولِ اللَّهِ قَالَ بَلَى ‏.‏ قَالَ فَقَالَ ‏ "‏ اللَّهُمَّ رَبَّ النَّاسِ مُذْهِبَ الْبَاسِ اشْفِ أَنْتَ الشَّافِي لاَ شَافِيَ إِلاَّ أَنْتَ اشْفِهِ شِفَاءً لاَ يُغَادِرُ سَقَمًا ‏"‏ ‏.‏\hadithno{3890}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5742)}\hadithtrans{Anas said to Thabit :Should I not use the spell of the Messenger of Allah (ﷺ) for you ? He said : Yes. He then said : O Allah, Lord of men, Remover of the harm, heal, Thou art the healer. There is no healer but Thou; given him a remedy which leaves no disease behind}}
\hadithdefcmd{abudawud}{3891}{حَدَّثَنَا عَبْدُ اللَّهِ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، أَنَّ عَمْرَو بْنَ عَبْدِ اللَّهِ بْنِ كَعْبٍ السُّلَمِيَّ، أَخْبَرَهُ أَنَّ نَافِعَ بْنَ جُبَيْرٍ أَخْبَرَهُ عَنْ عُثْمَانَ بْنِ أَبِي الْعَاصِ، أَنَّهُ أَتَى النَّبِيَّ صلى الله عليه وسلم قَالَ عُثْمَانُ وَبِي وَجَعٌ قَدْ كَادَ يُهْلِكُنِي قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ امْسَحْهُ بِيَمِينِكَ سَبْعَ مَرَّاتٍ وَقُلْ أَعُوذُ بِعِزَّةِ اللَّهِ وَقُدْرَتِهِ مِنْ شَرِّ مَا أَجِدُ ‏"‏ ‏.‏ قَالَ فَفَعَلْتُ ذَلِكَ فَأَذْهَبَ اللَّهُ عَزَّ وَجَلَّ مَا كَانَ بِي فَلَمْ أَزَلْ آمُرُ بِهِ أَهْلِي وَغَيْرَهُمْ ‏.‏\hadithno{3891}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Uthman b. Abl al-As said that he came to the Messenger of Allah (ﷺ). ‘Uthman said :I had a pain which was about to destroy me. So the Prophet (ﷺ) said : Wipe it with your right hand seven times and say : “I seek refuge in the dominance of Allah, and His might from the evil of what I find.” Then I did it. Allah removed (the pain) that I had, and I kept on suggesting it to my family and to others}}
\hadithdefcmd{abudawud}{3892}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ مَوْهَبٍ الرَّمْلِيُّ، حَدَّثَنَا اللَّيْثُ، عَنْ زِيَادِ بْنِ مُحَمَّدٍ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ الْقُرَظِيِّ، عَنْ فَضَالَةَ بْنِ عُبَيْدٍ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ اشْتَكَى مِنْكُمْ شَيْئًا أَوِ اشْتَكَاهُ أَخٌ لَهُ فَلْيَقُلْ رَبُّنَا اللَّهُ الَّذِي فِي السَّمَاءِ تَقَدَّسَ اسْمُكَ أَمْرُكَ فِي السَّمَاءِ وَالأَرْضِ كَمَا رَحْمَتُكَ فِي السَّمَاءِ فَاجْعَلْ رَحْمَتَكَ فِي الأَرْضِ اغْفِرْ لَنَا حُوبَنَا وَخَطَايَانَا أَنْتَ رَبُّ الطَّيِّبِينَ أَنْزِلْ رَحْمَةً مِنْ رَحْمَتِكَ وَشِفَاءً مِنْ شِفَائِكَ عَلَى هَذَا الْوَجَعِ فَيَبْرَأُ ‏"‏ ‏.‏\hadithno{3892}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbudDarda': I heard the Messenger of Allah (ﷺ) say: If any of you is suffering from anything or his brother is suffering, he should say: Our Lord is Allah Who is in the heaven, holy is Thy name, Thy command reigns supreme in the heaven and the earth, as Thy mercy in the heaven, make Thy mercy in the earth; forgive us our sins, and our errors; Thou art the Lord of good men; send down mercy from Thy mercy, and remedy, and remedy from Thy remedy on this pain so that it is healed up}}
\hadithdefcmd{abudawud}{3893}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُعَلِّمُهُمْ مِنَ الْفَزَعِ كَلِمَاتٍ ‏ "‏ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّةِ مِنْ غَضَبِهِ وَشَرِّ عِبَادِهِ وَمِنْ هَمَزَاتِ الشَّيَاطِينِ وَأَنْ يَحْضُرُونِ ‏"‏ ‏.‏ وَكَانَ عَبْدُ اللَّهِ بْنُ عَمْرٍو يُعَلِّمُهُنَّ مَنْ عَقَلَ مِنْ بَنِيهِ وَمَنْ لَمْ يَعْقِلْ كَتَبَهُ فَأَعْلَقَهُ عَلَيْهِ ‏.‏\hadithno{3893}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) sued to teach them the following words in the case of alarm: I seek refuge in Allah's perfect words from His anger, the evil of His servants, the evil suggestions of the devils and their presence. Abdullah ibn Amr used to teach them to those of his children who had reached puberty, and he wrote them down (on some material) and hung on the child who had not reached puberty}}
\hadithdefcmd{abudawud}{3894}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي سُرَيْجٍ الرَّازِيُّ، أَخْبَرَنَا مَكِّيُّ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا يَزِيدُ بْنُ أَبِي عُبَيْدٍ، قَالَ رَأَيْتُ أَثَرَ ضَرْبَةٍ فِي سَاقِ سَلَمَةَ فَقُلْتُ مَا هَذِهِ قَالَ أَصَابَتْنِي يَوْمَ خَيْبَرَ فَقَالَ النَّاسُ أُصِيبَ سَلَمَةُ فَأُتِيَ بِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَنَفَثَ فِيَّ ثَلاَثَ نَفَثَاتٍ فَمَا اشْتَكَيْتُهَا حَتَّى السَّاعَةِ ‏.‏\hadithno{3894}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4206)}\hadithtrans{Yazid b. Abi ‘Ubaid said :I saw a sign of injury in the shin of Salamah. I asked : What is this ? He replied : I was afflicted. I was afflicted by it on the day of Khaibar. The people said : Salamah has been afflicted. I was then brought to the Prophet (ﷺ). He blew on me three times. I did not feel any pain up till now}}
\hadithdefcmd{abudawud}{3895}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ رَبِّهِ، - يَعْنِي ابْنَ سَعِيدٍ - عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ لِلإِنْسَانِ إِذَا اشْتَكَى يَقُولُ بِرِيقِهِ ثُمَّ قَالَ بِهِ فِي التُّرَابِ ‏ "‏ تُرْبَةُ أَرْضِنَا بِرِيقَةِ بَعْضِنَا يُشْفَى سَقِيمُنَا بِإِذْنِ رَبِّنَا ‏"‏ ‏.‏\hadithno{3895}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5745) Sahih Muslim (2194)}\hadithtrans{‘A’ishah said :When a man complained of pain the Prophet (ﷺ) said to him pointing to his saliva and mixing it with dust :(This is) the dust of our earth, mixed with saliva of us, so that our sick is remedied with the permission of our lord}}
\hadithdefcmd{abudawud}{3896}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ زَكَرِيَّا، قَالَ حَدَّثَنِي عَامِرٌ، عَنْ خَارِجَةَ بْنِ الصَّلْتِ التَّمِيمِيِّ، عَنْ عَمِّهِ، أَنَّهُ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَسْلَمَ ثُمَّ أَقْبَلَ رَاجِعًا مِنْ عِنْدِهِ فَمَرَّ عَلَى قَوْمٍ عِنْدَهُمْ رَجُلٌ مَجْنُونٌ مُوثَقٌ بِالْحَدِيدِ فَقَالَ أَهْلُهُ إِنَّا حُدِّثْنَا أَنَّ صَاحِبَكُمْ هَذَا قَدْ جَاءَ بِخَيْرٍ فَهَلْ عِنْدَكَ شَىْءٌ تُدَاوِيهِ فَرَقَيْتُهُ بِفَاتِحَةِ الْكِتَابِ فَبَرَأَ فَأَعْطُونِي مِائَةَ شَاةٍ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَقَالَ ‏"‏ هَلْ إِلاَّ هَذَا ‏"‏ ‏.‏ وَقَالَ مُسَدَّدٌ فِي مَوْضِعٍ آخَرَ ‏"‏ هَلْ قُلْتَ غَيْرَ هَذَا ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ قَالَ ‏"‏ خُذْهَا فَلَعَمْرِي لَمَنْ أَكَلَ بِرُقْيَةِ بَاطِلٍ لَقَدْ أَكَلْتَ بِرُقْيَةِ حَقٍّ ‏"‏ ‏.‏\hadithno{3896}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Alaqah ibn Sahar at-Tamimi: Alaqah came to the Messenger of Allah (ﷺ) and embraced Islam. He then came back from him and passed some people who had a lunatic fettered in chains. His people said: We are told that your companion has brought some good. Have you something with which you can cure him? I then recited Surat al-Fatihah and he was cured. They gave me one hundred sheep. I then came to the Messenger of Allah (ﷺ) and informed him of it. He asked: Is it only this? The narrator, Musaddad, said in his other version: Did you say anything other than this? I said: No. He said: Take it, for by my life, some accept if for a worthless chain, but you have done so for a genuine one}}
\hadithdefcmd{abudawud}{3897}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي السَّفَرِ، عَنِ الشَّعْبِيِّ، عَنْ خَارِجَةَ بْنِ الصَّلْتِ، عَنْ عَمِّهِ، أَنَّهُ مَرَّ - قَالَ - فَرَقَاهُ بِفَاتِحَةِ الْكِتَابِ ثَلاَثَةَ أَيَّامٍ غُدْوَةً وَعَشِيَّةً كُلَّمَا خَتَمَهَا جَمَعَ بُزَاقَهُ ثُمَّ تَفَلَ فَكَأَنَّمَا أُنْشِطَ مِنْ عِقَالٍ فَأَعْطَوْهُ شَيْئًا فَأَتَى النَّبِيَّ صلى الله عليه وسلم ثُمَّ ذَكَرَ مَعْنَى حَدِيثِ مُسَدَّدٍ ‏.‏\hadithno{3897}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Kharijah b. al-Salt quoted his parental uncle as saying that he passed (some people) :He recited Surat al-Fatihah over him for three days morning and evening. Whenever he finished it, he collected some of his saliva and spat it out, and he seemed as if he were set free from a bond. They gave him something as payment. He then came to the Prophet (ﷺ). He then transmitted the rest of the tradition to the same effect as Musaddad narrated}}
\hadithdefcmd{abudawud}{3898}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَجُلاً، مِنْ أَسْلَمَ قَالَ كُنْتُ جَالِسًا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَاءَ رَجُلٌ مِنْ أَصْحَابِهِ فَقَالَ يَا رَسُولَ اللَّهِ لُدِغْتُ اللَّيْلَةَ فَلَمْ أَنَمْ حَتَّى أَصْبَحْتُ ‏.‏ قَالَ ‏"‏ مَاذَا ‏"‏ ‏.‏ قَالَ عَقْرَبٌ ‏.‏ قَالَ ‏"‏ أَمَا إِنَّكَ لَوْ قُلْتَ حِينَ أَمْسَيْتَ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّاتِ مِنْ شَرِّ مَا خَلَقَ لَمْ تَضُرَّكَ إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏\hadithno{3898}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuSalih Zakwan as-Samman: A man from Aslam tribe said: I was sitting with the Messenger of Allah (ﷺ). A man from among his Companions came and said: Messenger of Allah! I have been stung last night, and I could not sleep till morning. He asked: What was that? He replied: A scorpion. He said: Oh, had you said in the evening: "I take refuge in the perfect words of Allah from the evil of what He created," nothing would have harmed you, Allah willing}}
\hadithdefcmd{abudawud}{3899}{حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنِي الزُّبَيْدِيُّ، عَنِ الزُّهْرِيِّ، عَنْ طَارِقٍ، - يَعْنِي ابْنَ مُخَاشِنٍ - عَنْ أَبِي هُرَيْرَةَ، قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِلَدِيغٍ لَدَغَتْهُ عَقْرَبٌ قَالَ فَقَالَ ‏"‏ لَوْ قَالَ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّةِ مِنْ شَرِّ مَا خَلَقَ لَمْ يُلْدَغْ ‏"‏ ‏.‏ أَوْ ‏"‏ لَمْ تَضُرَّهُ ‏"‏ ‏.‏\hadithno{3899}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: A man who was stung by a scorpion was brought to the Prophet (ﷺ). He said: Had he said the word: "I seek refuge in the perfect words of Allah from the evil of what He created, "he would not have been stung, or he said, "It would not have harmed him}}
\hadithdefcmd{abudawud}{3900}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ أَبِي الْمُتَوَكِّلِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَهْطًا، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم انْطَلَقُوا فِي سَفْرَةٍ سَافَرُوهَا فَنَزَلُوا بِحَىٍّ مِنْ أَحْيَاءِ الْعَرَبِ فَقَالَ بَعْضُهُمْ إِنَّ سَيِّدَنَا لُدِغَ فَهَلْ عِنْدَ أَحَدٍ مِنْكُمْ شَىْءٌ يَنْفَعُ صَاحِبَنَا فَقَالَ رَجُلٌ مِنَ الْقَوْمِ نَعَمْ وَاللَّهِ إِنِّي لأَرْقِي وَلَكِنِ اسْتَضَفْنَاكُمْ فَأَبَيْتُمْ أَنْ تُضَيِّفُونَا مَا أَنَا بِرَاقٍ حَتَّى تَجْعَلُوا لِي جُعْلاً ‏.‏ فَجَعَلُوا لَهُ قَطِيعًا مِنَ الشَّاءِ فَأَتَاهُ فَقَرَأَ عَلَيْهِ أُمَّ الْكِتَابِ وَيَتْفُلُ حَتَّى بَرَأَ كَأَنَّمَا أُنْشِطَ مِنْ عِقَالٍ ‏.‏ قَالَ فَأَوْفَاهُمْ جُعْلَهُمُ الَّذِي صَالَحُوهُمْ عَلَيْهِ فَقَالُوا اقْتَسِمُوا ‏.‏ فَقَالَ الَّذِي رَقَى لاَ تَفْعَلُوا حَتَّى نَأْتِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَنَسْتَأْمِرَهُ ‏.‏ فَغَدَوْا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرُوا لَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مِنْ أَيْنَ عَلِمْتُمْ أَنَّهَا رُقْيَةٌ أَحْسَنْتُمُ اقْتَسِمُوا وَاضْرِبُوا لِي مَعَكُمْ بِسَهْمٍ ‏"‏ ‏.‏\hadithno{3900}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2276) Sahih Muslim (2201)}\hadithtrans{Abu Sa’d al-KHudri said :Some of the Companions of the Prophet (ﷺ) went on a journey. They alighted with a certain clan of the Arabs. Someone of them said : Our chief has been stung by a scorpion or bitten by a snake. Has any of you something which gives relief to our chief? A man of the people said : Yes, I swear by Allah. I shall apply charm ; but we asked you for hospitality and you denied it to us. I shall not apply charm until you give me some payment. So they promised to give some sheep to him. He came to him and recited Surat al-Fatihah over him and spat till he was cured, and ha seemed as if he were set free from a bond. So they gave him the payment that was agreed between them. They said : Apportion them. The man who applied charm said : Do not do it until we approach the Apostle of allah (ﷺ) said: From where did you learn that it was a charm ? you have done right. Apportion them, and give me a share along with you}}
\hadithdefcmd{abudawud}{3901}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي السَّفَرِ، عَنِ الشَّعْبِيِّ، عَنْ خَارِجَةَ بْنِ الصَّلْتِ التَّمِيمِيِّ، عَنْ عَمِّهِ، قَالَ أَقْبَلْنَا مِنْ عِنْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَتَيْنَا عَلَى حَىٍّ مِنَ الْعَرَبِ فَقَالُوا إِنَّا أُنْبِئْنَا أَنَّكُمْ جِئْتُمْ مِنْ عِنْدِ هَذَا الرَّجُلِ بِخَيْرٍ فَهَلْ عِنْدَكُمْ مِنْ دَوَاءٍ أَوْ رُقْيَةٍ فَإِنَّ عِنْدَنَا مَعْتُوهًا فِي الْقُيُودِ قَالَ فَقُلْنَا نَعَمْ ‏.‏ قَالَ فَجَاءُوا بِمَعْتُوهٍ فِي الْقُيُودِ - قَالَ - فَقَرَأْتُ عَلَيْهِ فَاتِحَةَ الْكِتَابِ ثَلاَثَةَ أَيَّامٍ غُدْوَةً وَعَشِيَّةً كُلَّمَا خَتَمْتُهَا أَجْمَعُ بُزَاقِي ثُمَّ أَتْفُلُ فَكَأَنَّمَا نُشِطَ مِنْ عِقَالٍ قَالَ فَأَعْطَوْنِي جُعْلاً فَقُلْتُ لاَ حَتَّى أَسْأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ كُلْ فَلَعَمْرِي مَنْ أَكَلَ بِرُقْيَةِ بَاطِلٍ لَقَدْ أَكَلْتَ بِرُقْيَةِ حَقٍّ ‏"‏ ‏.‏\hadithno{3901}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Alaqah ibn Sahar at-Tamimi: We proceeded from the Messenger of Allah (ﷺ) and came to a clan of the Arabs. They said: We have been told that you have brought what is good from this man. Have you any medicine or a charm, for we have a lunatic in chains? We said: Yes. Then they brought a lunatic in chains. He said: I recited Surat al-Fatihah over him for three days, morning and evening. Whenever I finished it, I would collect my saliva and spit it out, and he seemed as if he were set free from a bond. He said: They gave me some payment, but I said: No, not until I ask the Messenger of Allah (ﷺ). He (the Prophet) said: Accept it, for, by my life, some accept it for a worthless charm, but you have done so for a genuine one}}
\hadithdefcmd{abudawud}{3902}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا اشْتَكَى يَقْرَأُ فِي نَفْسِهِ بِالْمُعَوِّذَاتِ وَيَنْفُثُ فَلَمَّا اشْتَدَّ وَجَعُهُ كُنْتُ أَقْرَأُ عَلَيْهِ وَأَمْسَحُ عَلَيْهِ بِيَدِهِ رَجَاءَ بَرَكَتِهَا ‏.‏\hadithno{3902}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5016) Sahih Muslim (2192)}\hadithtrans{Narrated A'ishah:the wife of Prophet (ﷺ) said: When the Messenger of Allah (ﷺ) suffered from some pain, he recited mu'awwadhat in his heart and blew (them over him). When the pain became severe, I recited (them) over him and wiped him with his hand in the hope of its blessing}}
\hadithdefcmd{abudawud}{3903}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا نُوحُ بْنُ يَزِيدَ بْنِ سَيَّارٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ أَرَادَتْ أُمِّي أَنْ تُسَمِّنِّي لِدُخُولِي عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمْ أَقْبَلْ عَلَيْهَا بِشَىْءٍ مِمَّا تُرِيدُ حَتَّى أَطْعَمَتْنِي الْقِثَّاءَ بِالرُّطَبِ فَسَمِنْتُ عَلَيْهِ كَأَحْسَنِ السِّمَنِ ‏.‏\hadithno{3903}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: My mother intended to make me gain weight to send me to the (house of) the Messenger of Allah (ﷺ). But nothing which she desired benefited me till she gave me cucumber with fresh dates to eat. Then I gained as much weight (as she desired)}}
