% Auto-generated chapter 32 for malik
% Hadiths in this chapter: 2

\hadithdefcmd{malik}{1386}{حَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ خَرَجَ عَبْدُ اللَّهِ وَعُبَيْدُ اللَّهِ ابْنَا عُمَرَ بْنِ الْخَطَّابِ فِي جَيْشٍ إِلَى الْعِرَاقِ فَلَمَّا قَفَلاَ مَرَّا عَلَى أَبِي مُوسَى الأَشْعَرِيِّ وَهُوَ أَمِيرُ الْبَصْرَةِ فَرَحَّبَ بِهِمَا وَسَهَّلَ ثُمَّ قَالَ لَوْ أَقْدِرُ لَكُمَا عَلَى أَمْرٍ أَنْفَعُكُمَا بِهِ لَفَعَلْتُ ‏.‏ ثُمَّ قَالَ بَلَى هَا هُنَا مَالٌ مِنْ مَالِ اللَّهِ أُرِيدُ أَنْ أَبْعَثَ بِهِ إِلَى أَمِيرِ الْمُؤْمِنِينَ فَأُسْلِفُكُمَاهُ فَتَبْتَاعَانِ بِهِ مَتَاعًا مِنْ مَتَاعِ الْعِرَاقِ ثُمَّ تَبِيعَانِهِ بِالْمَدِينَةِ فَتُؤَدِّيَانِ رَأْسَ الْمَالِ إِلَى أَمِيرِ الْمُؤْمِنِينَ وَيَكُونُ الرِّبْحُ لَكُمَا فَقَالاَ وَدِدْنَا ذَلِكَ ‏.‏ فَفَعَلَ وَكَتَبَ إِلَى عُمَرَ بْنِ الْخَطَّابِ أَنْ يَأْخُذَ مِنْهُمَا الْمَالَ فَلَمَّا قَدِمَا بَاعَا فَأُرْبِحَا فَلَمَّا دَفَعَا ذَلِكَ إِلَى عُمَرَ قَالَ أَكُلُّ الْجَيْشِ أَسْلَفَهُ مِثْلَ مَا أَسْلَفَكُمَا قَالاَ لاَ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ ابْنَا أَمِيرِ الْمُؤْمِنِينَ فَأَسْلَفَكُمَا أَدِّيَا الْمَالَ وَرِبْحَهُ ‏.‏ فَأَمَّا عَبْدُ اللَّهِ فَسَكَتَ وَأَمَّا عُبَيْدُ اللَّهِ فَقَالَ مَا يَنْبَغِي لَكَ يَا أَمِيرَ الْمُؤْمِنِينَ هَذَا لَوْ نَقَصَ هَذَا الْمَالُ أَوْ هَلَكَ لَضَمِنَّاهُ ‏.‏ فَقَالَ عُمَرُ أَدِّيَاهُ ‏.‏ فَسَكَتَ عَبْدُ اللَّهِ وَرَاجَعَهُ عُبَيْدُ اللَّهِ ‏.‏ فَقَالَ رَجُلٌ مِنْ جُلَسَاءِ عُمَرَ يَا أَمِيرَ الْمُؤْمِنِينَ لَوْ جَعَلْتَهُ قِرَاضًا ‏.‏ فَقَالَ عُمَرُ قَدْ جَعَلْتُهُ قِرَاضًا ‏.‏ فَأَخَذَ عُمَرُ رَأْسَ الْمَالِ وَنِصْفَ رِبْحِهِ وَأَخَذَ عَبْدُ اللَّهِ وَعُبَيْدُ اللَّهِ ابْنَا عُمَرَ بْنِ الْخَطَّابِ نِصْفَ رِبْحِ الْمَالِ ‏.‏\hadithno{1386}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Malik related to me from Zayd ibn Aslam that his father said, "Abdullah and Ubaydullah, the sons of Umar ibn al-Khattab went out with the army to Iraq. On the way home, they passed by Abu Musa al- Ashari who was the amir of Basra. He greeted them and made them welcome, and told them that if there was anything he could do to help them, he would do it. Then he said, 'There is some of the property of Allah which I want to send to the amir al-muminin, so I will lend it to you, and you can buy wares from Iraq and sell them in Madina. Then give the principal to the amir al-muminin, and you keep the profit.' They said that they would like to do it, and so he gave them the money and wrote to Umar ibn al-Khattab to take the money from them. When they came to sell they made a profit, and when they paid the principal to Umar he asked, 'Did he lend everyone in the army the like of what he lent you?' They said, 'No.' Umar ibn al-Khattab said, 'He made you the loan, because you are the sons of the amir al-muminin, so pay the principal and the profit.' Abdullah was silent. Ubaydullah said, 'You do not need to do this, amir al-muminin. Had the principal decreased or been destroyed, we would have guaranteed it.' Umar said, 'Pay it.' Abdullah was silent, and Ubaydullah repeated it. A man who was sitting with Umar said, 'Amir al-muminin, better that you make it a qirad. 'Umar said, 'I have made it qirad.' Umar then took the principal and half of the profit, and Abdullah and Ubaydullah, the sons of Umar ibn al-Khattab took half of the profit}}
\hadithdefcmd{malik}{1387}{وَحَدَّثَنِي مَالِكٌ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ عُثْمَانَ بْنَ عَفَّانَ، أَعْطَاهُ مَالاً قِرَاضًا يَعْمَلُ فِيهِ عَلَى أَنَّ الرِّبْحَ بَيْنَهُمَا ‏.‏\hadithno{1387}\hadithgrade{Salim al-Hilali: Mauquf Hasan}\hadithtrans{Malik related to me from al-Ala ibn Abd ar-Rahman from his father from his father that Uthman ibn Affan gave him some money as qirad to use provided the profit was shared between them}}
