% Auto-generated chapter 52 for muslim
% Hadiths in this chapter: 79

\hadithdefcmd{muslim}{7045}{حَدَّثَنِي أَبُو بَكْرِ بْنُ إِسْحَاقَ، حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنِي الْمُغِيرَةُ، - يَعْنِي الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّهُ لَيَأْتِي الرَّجُلُ الْعَظِيمُ السَّمِينُ يَوْمَ الْقِيَامَةِ لاَ يَزِنُ عِنْدَ اللَّهِ جَنَاحَ بَعُوضَةٍ اقْرَءُوا ‏\{‏ فَلاَ نُقِيمُ لَهُمْ يَوْمَ الْقِيَامَةِ وَزْنًا‏\}‏ ‏"‏ ‏.‏\hadithno{7045}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:A bulky person would be brought on the Day of judgment and he would not carry the weight to the eye of Allah equal even to that of a gnat. Nor shall We set up a balance for them on the Day of Resurrection" (xviii)}}
\hadithdefcmd{muslim}{7046}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا فُضَيْلٌ، - يَعْنِي ابْنَ عِيَاضٍ - عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ السَّلْمَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ جَاءَ حَبْرٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا مُحَمَّدُ أَوْ يَا أَبَا الْقَاسِمِ إِنَّ اللَّهَ تَعَالَى يُمْسِكُ السَّمَوَاتِ يَوْمَ الْقِيَامَةِ عَلَى إِصْبَعٍ وَالأَرَضِينَ عَلَى إِصْبَعٍ وَالْجِبَالَ وَالشَّجَرَ عَلَى إِصْبَعٍ وَالْمَاءَ وَالثَّرَى عَلَى إِصْبَعٍ وَسَائِرَ الْخَلْقِ عَلَى إِصْبَعٍ ثُمَّ يَهُزُّهُنَّ فَيَقُولُ أَنَا الْمَلِكُ أَنَا الْمَلِكُ ‏.‏ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم تَعَجُّبًا مِمَّا قَالَ الْحَبْرُ تَصْدِيقًا لَهُ ثُمَّ قَرَأَ ‏\{‏ وَمَا قَدَرُوا اللَّهَ حَقَّ قَدْرِهِ وَالأَرْضُ جَمِيعًا قَبْضَتُهُ يَوْمَ الْقِيَامَةِ وَالسَّمَوَاتُ مَطْوِيَّاتٌ بِيَمِينِهِ سُبْحَانَهُ وَتَعَالَى عَمَّا يُشْرِكُونَ‏\}‏\hadithno{7046}\hadithtrans{Abdullah b. Mas'ud reported that a Jewish scholar came to Allah's Apostle (may peace he upon him) and said:Muhammad, or Abu al-Qasim, verily, Allah, the Exalted and Glorious would carry the Heavens on the Day of Judgment upon one finger and earths upon one finger and the mountains and trees upon one finger and the ocean and moist earth upon one finger, and in fact the whole of the creation upon one finger, and then He would stir them and say: I am your Lord, I am your Lord. Thereupon Allah's Messenger (ﷺ) smiled testifying what that scholar had said. He then recited this verse:" And they honour not Allah with the honour due to Him; and the whole earth will be in His grip on the Day of Resurrection and the heaven rolled up in His right hand. Glory be to Him I and highly Exalted is He above what they associate (with Him)" (Az-Zumar:)}}
\hadithdefcmd{muslim}{7047}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، كِلاَهُمَا عَنْ جَرِيرٍ، عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ قَالَ جَاءَ حَبْرٌ مِنَ الْيَهُودِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ فُضَيْلٍ وَلَمْ يَذْكُرْ ثُمَّ يَهُزُّهُنَّ ‏.‏ وَقَالَ فَلَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ضَحِكَ حَتَّى بَدَتْ نَوَاجِذُهُ تَعَجُّبًا لِمَا قَالَ تَصْدِيقًا لَهُ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ‏\{‏ وَمَا قَدَرُوا اللَّهَ حَقَّ قَدْرِهِ‏\}‏ ‏"‏ ‏.‏ وَتَلاَ الآيَةَ ‏.‏\hadithno{7047}\hadithtrans{This hadlth has been narrated on the authority of Mansur with the same chain of truemittm (and the words are):A Jew scholar came to Allah's Messenger (ﷺ). The rest of the hadith is the same, but there is no mention of" then He would stir them." But there is this addition:" I saw Allah's Messengcr (ﷺ) smiling so much that his front teeth appeared and testifying him (th Jew scholar) ; then Allah's Messenger (ﷺ) recited the verse:" And they honour not Allah with the honour due to Him" (xxxix)}}
\hadithdefcmd{muslim}{7048}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ سَمِعْتُ إِبْرَاهِيمَ، يَقُولُ سَمِعْتُ عَلْقَمَةَ، يَقُولُ قَالَ عَبْدُ اللَّهِ جَاءَ رَجُلٌ مِنْ أَهْلِ الْكِتَابِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا أَبَا الْقَاسِمِ إِنَّ اللَّهَ يُمْسِكُ السَّمَوَاتِ عَلَى إِصْبَعٍ وَالأَرَضِينَ عَلَى إِصْبَعٍ وَالشَّجَرَ وَالثَّرَى عَلَى إِصْبَعٍ وَالْخَلاَئِقَ عَلَى إِصْبَعٍ ثُمَّ يَقُولُ أَنَا الْمَلِكُ أَنَا الْمَلِكُ ‏.‏ قَالَ فَرَأَيْتُ النَّبِيَّ صلى الله عليه وسلم ضَحِكَ حَتَّى بَدَتْ نَوَاجِذُهُ ثُمَّ قَرَأَ ‏\{‏ وَمَا قَدَرُوا اللَّهَ حَقَّ قَدْرِهِ‏\}‏\hadithno{7048}\hadithtrans{Abdullah reported that a person from the People of the Book came to Allah's Apostle (may peace he upon him) and said:Abu al-Qasim, verily, Allah holds the Heavens upon one finger and the earths upon one finger and the trees and moist earth upon one finger and in fact the whole of the creation upon one finger and then say: I am the King. I am the King. And he (the narrator) further said: I saw Allah's Messenger (ﷺ) smiling until his front teeth became visible and then he recited the verse: "And they measure not the power of Allah with His true measure" (39:)}}
\hadithdefcmd{muslim}{7049}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ وَعَلِيُّ بْنُ خَشْرَمٍ قَالاَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي، شَيْبَةَ حَدَّثَنَا جَرِيرٌ، كُلُّهُمْ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّ فِي، حَدِيثِهِمْ جَمِيعًا وَالشَّجَرَ عَلَى إِصْبَعٍ وَالثَّرَى عَلَى إِصْبَعٍ وَلَيْسَ فِي حَدِيثِ جَرِيرٍ وَالْخَلاَئِقَ عَلَى إِصْبَعٍ ‏.‏ وَلَكِنْ فِي حَدِيثِهِ وَالْجِبَالَ عَلَى إِصْبَعٍ ‏.‏ وَزَادَ فِي حَدِيثِ جَرِيرٍ تَصْدِيقًا لَهُ تَعَجُّبًا لِمَا قَالَ ‏.‏\hadithno{7049}\hadithtrans{This hadith has been narrated on the authority of A'mash with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{7050}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي ابْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، كَانَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَقْبِضُ اللَّهُ تَبَارَكَ وَتَعَالَى الأَرْضَ يَوْمَ الْقِيَامَةِ وَيَطْوِي السَّمَاءَ بِيَمِينِهِ ثُمَّ يَقُولُ أَنَا الْمَلِكُ أَيْنَ مُلُوكُ الأَرْضِ ‏"‏ ‏.‏\hadithno{7050}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:Allah, the Exalted and Glorious, will take in His grip the Earth on the Day of Judgment and He would roll up the sky in His right hand and would say: I am the Lord; where are the sovereigns of the world?}}
\hadithdefcmd{muslim}{7051}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُمَرَ بْنِ حَمْزَةَ، عَنْ سَالِمِ، بْنِ عَبْدِ اللَّهِ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَطْوِي اللَّهُ عَزَّ وَجَلَّ السَّمَوَاتِ يَوْمَ الْقِيَامَةِ ثُمَّ يَأْخُذُهُنَّ بِيَدِهِ الْيُمْنَى ثُمَّ يَقُولُ أَنَا الْمَلِكُ أَيْنَ الْجَبَّارُونَ أَيْنَ الْمُتَكَبِّرُونَ ثُمَّ يَطْوِي الأَرَضِينَ بِشِمَالِهِ ثُمَّ يَقُولُ أَنَا الْمَلِكُ أَيْنَ الْجَبَّارُونَ أَيْنَ الْمُتَكَبِّرُونَ ‏"‏ ‏.‏\hadithno{7051}\hadithtrans{Abdullah b. 'Umar reported Allah's Messenger (ﷺ) saying:Allah, the Exalted and Glorious, would fold the Heavens on the Day of Judgment and then He would place them on His right hand and say: I am the Lord; where are the haughty and where are the proud (today)? He would fold the' earth (placing it) on the left hand and say: I am the Lord; where are the haughty and where are the proud (today)?}}
\hadithdefcmd{muslim}{7052}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - حَدَّثَنِي أَبُو حَازِمٍ عَنْ عُبَيْدِ اللَّهِ بْنِ مِقْسَمٍ، أَنَّهُ نَظَرَ إِلَى عَبْدِ اللَّهِ بْنِ عُمَرَ كَيْفَ يَحْكِي رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَأْخُذُ اللَّهُ عَزَّ وَجَلَّ سَمَوَاتِهِ وَأَرَضِيهِ بِيَدَيْهِ فَيَقُولُ أَنَا اللَّهُ - وَيَقْبِضُ أَصَابِعَهُ وَيَبْسُطُهَا - أَنَا الْمَلِكُ ‏"‏ حَتَّى نَظَرْتُ إِلَى الْمِنْبَرِ يَتَحَرَّكُ مِنْ أَسْفَلِ شَىْءٍ مِنْهُ حَتَّى إِنِّي لأَقُولُ أَسَاقِطٌ هُوَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم\hadithno{7052}\hadithtrans{Abdullah b. Miqsam reported that he saw Abdullah b. Umar as he narrated Allah's Messenger (ﷺ) as saying:Allah, the Exalted and Glorious, would take in His hand His Heavens and His Earth, and would say: I am Allah. And He would clench His fingers and then would open them (and say): I am your Lord. I saw the pulpit in commotion from underneath because of something (vib-ating) there. And (I felt this commotion so much) that I said (to myself): It may not fall with Allah's Massenger (ﷺ) upon it}}
\hadithdefcmd{muslim}{7053}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، حَدَّثَنِي أَبِي، عَنْ عُبَيْدِ، اللَّهِ بْنِ مِقْسَمٍ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ وَهُوَ يَقُولُ ‏ "‏ يَأْخُذُ الْجَبَّارُ عَزَّ وَجَلَّ سَمَوَاتِهِ وَأَرَضِيهِ بِيَدَيْهِ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ نَحْوَ حَدِيثِ يَعْقُوبَ ‏.‏\hadithno{7053}\hadithtrans{Abdullah b. Miqsam reported that 'Abdullah b. 'Umar reported:I saw Allah'h Messenger (ﷺ) upon the pulpit and he was saying that the Mighty Lord, the Exalted and Glorious would take hold of the Heavens and earth in His hand. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{7054}{حَدَّثَنِي سُرَيْجُ بْنُ يُونُسَ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي إِسْمَاعِيلُ بْنُ أُمَيَّةَ، عَنْ أَيُّوبَ بْنِ خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ رَافِعٍ، مَوْلَى أُمِّ سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، قَالَ أَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِي فَقَالَ ‏ "‏ خَلَقَ اللَّهُ عَزَّ وَجَلَّ التُّرْبَةَ يَوْمَ السَّبْتِ وَخَلَقَ فِيهَا الْجِبَالَ يَوْمَ الأَحَدِ وَخَلَقَ الشَّجَرَ يَوْمَ الاِثْنَيْنِ وَخَلَقَ الْمَكْرُوهَ يَوْمَ الثُّلاَثَاءِ وَخَلَقَ النُّورَ يَوْمَ الأَرْبِعَاءِ وَبَثَّ فِيهَا الدَّوَابَّ يَوْمَ الْخَمِيسِ وَخَلَقَ آدَمَ عَلَيْهِ السَّلاَمُ بَعْدَ الْعَصْرِ مِنْ يَوْمِ الْجُمُعَةِ فِي آخِرِ الْخَلْقِ وَفِي آخِرِ سَاعَةٍ مِنْ سَاعَاتِ الْجُمُعَةِ فِيمَا بَيْنَ الْعَصْرِ إِلَى اللَّيْلِ ‏"‏ ‏.‏ قَالَ إِبْرَاهِيمُ حَدَّثَنَا الْبِسْطَامِيُّ، - وَهُوَ الْحُسَيْنُ بْنُ عِيسَى - وَسَهْلُ بْنُ عَمَّارٍ وَإِبْرَاهِيمُ ابْنُ بِنْتِ حَفْصٍ وَغَيْرُهُمْ عَنْ حَجَّاجٍ، بِهَذَا الْحَدِيثِ ‏.‏\hadithno{7054}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) took hold of my hands and said:Allah, the Exalted and Glorious, created the clay on Saturday and He created the mountains on Sunday and He created the trees on Monday and He created the things entailing labour on Tuesday and created light on Wednesday and He caused the animals to spread on Thursday and created Adam (peace be upon him) after 'Asr on Friday; the last creation at the last hour of the hours of Friday, i. e. between afternoon and night. This hadith is narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{7055}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ أَبِي، كَثِيرٍ حَدَّثَنِي أَبُو حَازِمِ بْنُ دِينَارٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُحْشَرُ النَّاسُ يَوْمَ الْقِيَامَةِ عَلَى أَرْضٍ بَيْضَاءَ عَفْرَاءَ كَقُرْصَةِ النَّقِيِّ لَيْسَ فِيهَا عَلَمٌ لأَحَدٍ ‏"‏ ‏.‏\hadithno{7055}\hadithtrans{Sahl b. Sa'd reported that Allah's Messenger (ﷺ) said:The people will be assembled on the Day of Resurrection on a white plain with a reddish tinge like the loaf of white bread with no marks set up for anyone}}
\hadithdefcmd{muslim}{7056}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ دَاوُدَ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ يَوْمَ تُبَدَّلُ الأَرْضُ غَيْرَ الأَرْضِ وَالسَّمَوَاتُ‏\}‏ فَأَيْنَ يَكُونُ النَّاسُ يَوْمَئِذٍ يَا رَسُولَ اللَّهِ فَقَالَ ‏"‏ عَلَى الصِّرَاطِ ‏"‏ ‏.‏\hadithno{7056}\hadithtrans{A'isha reported:I asked Allah's Messenger (ﷺ) about the words of Allah, the Exalted and Glorious:" The day when the earth would be changed for another earth and Heaven would be changed for another Heaven (XiV. 48), (and inquired: ) (Allah's Messenger), where would the people be on that day? He said: They would be on the Sirat}}
\hadithdefcmd{muslim}{7057}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي خَالِدُ بْنُ يَزِيدَ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ تَكُونُ الأَرْضُ يَوْمَ الْقِيَامَةِ خُبْزَةً وَاحِدَةً يَكْفَؤُهَا الْجَبَّارُ بِيَدِهِ كَمَا يَكْفَأُ أَحَدُكُمْ خُبْزَتَهُ فِي السَّفَرِ نُزُلاً لأَهْلِ الْجَنَّةِ ‏"‏ ‏.‏ قَالَ فَأَتَى رَجُلٌ مِنَ الْيَهُودِ فَقَالَ بَارَكَ الرَّحْمَنُ عَلَيْكَ أَبَا الْقَاسِمِ أَلاَ أُخْبِرُكَ بِنُزُلِ أَهْلِ الْجَنَّةِ يَوْمَ الْقِيَامَةِ قَالَ ‏"‏ بَلَى ‏"‏ ‏.‏ قَالَ تَكُونُ الأَرْضُ خُبْزَةً وَاحِدَةً - كَمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم - قَالَ فَنَظَرَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ ضَحِكَ حَتَّى بَدَتْ نَوَاجِذُهُ قَالَ أَلاَ أُخْبِرُكَ بِإِدَامِهِمْ قَالَ ‏"‏ بَلَى ‏"‏ ‏.‏ قَالَ إِدَامُهُمْ بَالاَمُ وَنُونٌ ‏.‏ قَالُوا وَمَا هَذَا قَالَ ثَوْرٌ وَنُونٌ يَأْكُلُ مِنْ زَائِدَةِ كَبِدِهِمَا سَبْعُونَ أَلْفًا ‏.‏\hadithno{7057}\hadithtrans{Abu al-Sa'id Khudri reported Allah's Messenger (ﷺ) as saying that the earth would turn to be one single bread on the Day of Resurrection and the Almighty would turn it in His hand as one of you turns a loaf while on a journey. It would be a feast arranged in the honour of the people of Paradise. He (the narrator) further narrated that a person from among the Jews came and he said:Abu al-Qasim, may the Compassionate Lord be pleased with you! May I inform you about the feast arranged in honour of the people of Paradise on the Day of Resurrection? He said: Do it, of course. He said: The earth would become one single bread. Then Allah's Messenger (ﷺ) looked towards us and laughed until his molar teeth became visible. He then again said: May I inform you about that with which they would season it? He said: Do it, of course. He said: Their seasoning would be balim and fish. The Companions of the Prophet (ﷺ) said: What is this balam? He said: Ox and fish from whose excessive livers seventy thousand people would be able to eat}}
\hadithdefcmd{muslim}{7058}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا قُرَّةُ، حَدَّثَنَا مُحَمَّدٌ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَوْ تَابَعَنِي عَشْرَةٌ مِنَ الْيَهُودِ لَمْ يَبْقَ عَلَى ظَهْرِهَا يَهُودِيٌّ إِلاَّ أَسْلَمَ ‏"‏ ‏.‏\hadithno{7058}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:If ten scholars of the Jews would follow me, no Jew would be left upon the surface of the earth who would not embrace Islam}}
\hadithdefcmd{muslim}{7059}{حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنِي إِبْرَاهِيمُ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ بَيْنَمَا أَنَا أَمْشِي، مَعَ النَّبِيِّ صلى الله عليه وسلم فِي حَرْثٍ وَهُوَ مُتَّكِئٌ عَلَى عَسِيبٍ إِذْ مَرَّ بِنَفَرٍ مِنَ الْيَهُودِ فَقَالَ بَعْضُهُمْ لِبَعْضٍ سَلُوهُ عَنِ الرُّوحِ فَقَالُوا مَا رَابَكُمْ إِلَيْهِ لاَ يَسْتَقْبِلُكُمْ بِشَىْءٍ تَكْرَهُونَهُ ‏.‏ فَقَالُوا سَلُوهُ فَقَامَ إِلَيْهِ بَعْضُهُمْ فَسَأَلَهُ عَنِ الرُّوحِ - قَالَ - فَأَسْكَتَ النَّبِيُّ صلى الله عليه وسلم فَلَمْ يَرُدَّ عَلَيْهِ شَيْئًا فَعَلِمْتُ أَنَّهُ يُوحَى إِلَيْهِ - قَالَ - فَقُمْتُ مَكَانِي فَلَمَّا نَزَلَ الْوَحْىُ قَالَ ‏\{‏ وَيَسْأَلُونَكَ عَنِ الرُّوحِ قُلِ الرُّوحُ مِنْ أَمْرِ رَبِّي وَمَا أُوتِيتُمْ مِنَ الْعِلْمِ إِلاَّ قَلِيلاً‏\}‏\hadithno{7059}\hadithtrans{Abdullah (b. Mas`ud) reported:As I was going along with Allah's Apostle (ﷺ) in a cultivable land and he (the Holy Prophet) was walking with the support of a wood, a group of Jews happened to meet him. Some of them said to the others: Ask him about the Soul. They said: What is your doubt about it? There is a possibility that you may ask him about anything (the answer of) which you may not like. They said: Ask him. So one amongst them asked him about the Soul. Allah's Messenger (ﷺ) kept quiet and he gave no reply and I came to know that revelation was being sent to him, so I stood at my place and thus this revelation descended upon him:" They ask thee about the Soul. Say: The Soul is by the Commandment of my Lord, and of Knowledge you are given but a little" (xvii)}}
\hadithdefcmd{muslim}{7060}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَعَلِيُّ بْنُ خَشْرَمٍ، قَالاَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كِلاَهُمَا عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنْتُ أَمْشِي مَعَ النَّبِيِّ صلى الله عليه وسلم فِي حَرْثٍ بِالْمَدِينَةِ ‏.‏ بِنَحْوِ حَدِيثِ حَفْصٍ غَيْرَ أَنَّ فِي حَدِيثِ وَكِيعٍ وَمَا أُوتِيتُمْ مِنَ الْعِلْمِ إِلاَّ قَلِيلاً ‏.‏ وَفِي حَدِيثِ عِيسَى بْنِ يُونُسَ وَمَا أُوتُوا ‏.‏ مِنْ رِوَايَةِ ابْنِ خَشْرَمٍ ‏.‏\hadithno{7060}\hadithtrans{Abdullah reported:I was walking along with Allah's Apostle (ﷺ) in a field of Medina. The rest of the hadith is the same, but there is a slight variation of wording}}
\hadithdefcmd{muslim}{7061}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ إِدْرِيسَ، يَقُولُ سَمِعْتُ الأَعْمَشَ، يَرْوِيهِ عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم فِي نَخْلٍ يَتَوَكَّأُ عَلَى عَسِيبٍ ‏.‏ ثُمَّ ذَكَرَ نَحْوَ حَدِيثِهِمْ عَنِ الأَعْمَشِ وَقَالَ فِي رِوَايَتِهِ وَمَا أُوتِيتُمْ مِنَ الْعِلْمِ إِلاَّ قَلِيلاً ‏.‏\hadithno{7061}\hadithtrans{Abdullah reported that Allah's Apostle (ﷺ) was reclining against a tree in the garden. The rest of the hadith is the same with a slight variation of wording}}
\hadithdefcmd{muslim}{7062}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَبْدُ اللَّهِ بْنُ سَعِيدٍ الأَشَجُّ، - وَاللَّفْظُ لِعَبْدِ اللَّهِ - قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ خَبَّابٍ، قَالَ كَانَ لِي عَلَى الْعَاصِ بْنِ وَائِلٍ دَيْنٌ فَأَتَيْتُهُ أَتَقَاضَاهُ فَقَالَ لِي لَنْ أَقْضِيَكَ حَتَّى تَكْفُرَ بِمُحَمَّدٍ - قَالَ - فَقُلْتُ لَهُ إِنِّي لَنْ أَكْفُرَ بِمُحَمَّدٍ حَتَّى تَمُوتَ ثُمَّ تُبْعَثَ ‏.‏ قَالَ وَإِنِّي لَمَبْعُوثٌ مِنْ بَعْدِ الْمَوْتِ فَسَوْفَ أَقْضِيكَ إِذَا رَجَعْتُ إِلَى مَالٍ وَوَلَدٍ ‏.‏ قَالَ وَكِيعٌ كَذَا قَالَ الأَعْمَشُ قَالَ فَنَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ أَفَرَأَيْتَ الَّذِي كَفَرَ بِآيَاتِنَا وَقَالَ لأُوتَيَنَّ مَالاً وَوَلَدًا‏\}‏ إِلَى قَوْلِهِ ‏\{‏ وَيَأْتِينَا فَرْدًا‏\}‏\hadithno{7062}\hadithtrans{Khabbab reported that Al-`As b. Wa'il owed debt to me. I came to him in order to demand that. He said:I will never repay you unless you belie Muhammad. I said: I would never belie Muhammad until you die and you are again raised up. He said: When I would be raised up after death, I would repay your debt when I would get my property and children back. Waki` said: This is how Al-A`mash has narrated and it was on this occasion that this verse was revealed: "Hast thou seen him who disbelieves in Our message and says: I shall certainly be given wealth and children" (xix, 77) up to "he would come to Us alone" (xix)}}
\hadithdefcmd{muslim}{7063}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، كُلُّهُمْ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ وَكِيعٍ وَفِي حَدِيثِ جَرِيرٍ قَالَ كُنْتُ قَيْنًا فِي الْجَاهِلِيَّةِ فَعَمِلْتُ لِلْعَاصِ بْنِ وَائِلٍ عَمَلاً فَأَتَيْتُهُ أَتَقَاضَاهُ ‏.‏\hadithno{7063}\hadithtrans{This hadith has been narrated on the authority of Khabbib through another chain of transmitters and the words are. I in the pre-Islamic days used to work as an iron-smith. I did some work for 'As b. Wa'il and came to him for getting the remuneration of my wages}}
\hadithdefcmd{muslim}{7064}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْحَمِيدِ الزِّيَادِيِّ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ أَبُو جَهْلٍ اللَّهُمَّ إِنْ كَانَ هَذَا هُوَ الْحَقَّ مِنْ عِنْدِكَ فَأَمْطِرْ عَلَيْنَا حِجَارَةً مِنَ السَّمَاءِ أَوِ ائْتِنَا بِعَذَابٍ أَلِيمٍ ‏.‏ فَنَزَلَتْ ‏\{‏ وَمَا كَانَ اللَّهُ لِيُعَذِّبَهُمْ وَأَنْتَ فِيهِمْ وَمَا كَانَ اللَّهُ مُعَذِّبَهُمْ وَهُمْ يَسْتَغْفِرُونَ * وَمَا لَهُمْ أَلاَّ يُعَذِّبَهُمُ اللَّهُ وَهُمْ يَصُدُّونَ عَنِ الْمَسْجِدِ الْحَرَامِ‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏\hadithno{7064}\hadithtrans{Anas b. Malik reported that Abu Jahl said:O Allah, if he is true, then shower upon us the volley of stones from the sky or inflict upon us a grievous torment, and it was on this occasion that this verse was revealed:" 'Allah would never torment them so long as you are amongst them. And Allah is not going to torment them as long as they seek forgiveness. And why is it that Allah should not torment them and they prevent people from coming to the sacred mosque...." (viii. 34) to the end}}
\hadithdefcmd{muslim}{7065}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الْقَيْسِيُّ، قَالاَ حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، حَدَّثَنِي نُعَيْمُ بْنُ أَبِي هِنْدٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ أَبُو جَهْلٍ هَلْ يُعَفِّرُ مُحَمَّدٌ وَجْهَهُ بَيْنَ أَظْهُرِكُمْ قَالَ فَقِيلَ نَعَمْ ‏.‏ فَقَالَ وَاللاَّتِ وَالْعُزَّى لَئِنْ رَأَيْتُهُ يَفْعَلُ ذَلِكَ لأَطَأَنَّ عَلَى رَقَبَتِهِ أَوْ لأُعَفِّرَنَّ وَجْهَهُ فِي التُّرَابِ - قَالَ - فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يُصَلِّي زَعَمَ لِيَطَأَ عَلَى رَقَبَتِهِ - قَالَ - فَمَا فَجِئَهُمْ مِنْهُ إِلاَّ وَهُوَ يَنْكِصُ عَلَى عَقِبَيْهِ وَيَتَّقِي بِيَدَيْهِ - قَالَ - فَقِيلَ لَهُ مَا لَكَ فَقَالَ إِنَّ بَيْنِي وَبَيْنَهُ لَخَنْدَقًا مِنْ نَارٍ وَهَوْلاً وَأَجْنِحَةً ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ دَنَا مِنِّي لاَخْتَطَفَتْهُ الْمَلاَئِكَةُ عُضْوًا عُضْوًا ‏"‏ ‏.‏ قَالَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ لاَ نَدْرِي فِي حَدِيثِ أَبِي هُرَيْرَةَ أَوْ شَىْءٌ بَلَغَهُ ‏\{‏ كَلاَّ إِنَّ الإِنْسَانَ لَيَطْغَى * أَنْ رَآهُ اسْتَغْنَى * إِنَّ إِلَى رَبِّكَ الرُّجْعَى * أَرَأَيْتَ الَّذِي يَنْهَى * عَبْدًا إِذَا صَلَّى * أَرَأَيْتَ إِنْ كَانَ عَلَى الْهُدَى * أَوْ أَمَرَ بِالتَّقْوَى * أَرَأَيْتَ إِنْ كَذَّبَ وَتَوَلَّى‏\}‏ - يَعْنِي أَبَا جَهْلٍ - ‏\{‏ أَلَمْ يَعْلَمْ بِأَنَّ اللَّهَ يَرَى * كَلاَّ لَئِنْ لَمْ يَنْتَهِ لَنَسْفَعًا بِالنَّاصِيَةِ * نَاصِيَةٍ كَاذِبَةٍ خَاطِئَةٍ * فَلْيَدْعُ نَادِيَهُ * سَنَدْعُ الزَّبَانِيَةَ * كَلاَّ لاَ تُطِعْهُ‏\}‏ زَادَ عُبَيْدُ اللَّهِ فِي حَدِيثِهِ قَالَ وَأَمَرَهُ بِمَا أَمَرَهُ بِهِ ‏.‏ وَزَادَ ابْنُ عَبْدِ الأَعْلَى فَلْيَدْعُ نَادِيَهُ يَعْنِي قَوْمَهُ ‏.‏\hadithno{7065}\hadithtrans{Abu Huraira reported that Abu Jahl asked (people) whether Muhammad placed his face (on the ground) in their presence. It was said to him:Yes. He said: By Lat and `Uzza. If I were to see him do that, I would trample his neck, or I would smear his face with dust. He came to Allah's Messenger (ﷺ) as he was engaged in prayer and thought of trampling his neck (and the people say) that he came near him but turned upon his heels and tried to repulse something with his hands. It was said to him: What is the matter with you? He said: There is between me and him a ditch of fire and terror and wings. Thereupon Allah's Messenger (may peace he upon him) said: If he were to come near me the angels would have torn him to pieces. Then Allah, the Exalted and Glorious, revealed this verse- (the narrator) said: We do not know whether it is the hadith transmitted by Abu Huraira or something conveyed to him from another source: "Nay, man is surely inordinate, because he looks upon himself as self-sufficient. Surely to thy Lord is the return. Hast thou seen him who forbids a servant when he prays? Seest thou if he is on the right way, or enjoins observance of piety? Seest thou if he [Abu Jahl] denies and turns away? Knowest he not that Allah sees? Nay, if he desists not, We will seize him by the forelock-a lying, sinful forelock. Then let him summon his council. We will summon the guards of the Hell. Nay! Obey not thou him" (lcvi, 6-19). (Rather prostrate thyself.) Ubaidullah made this addition: It was after this that (prostration) was enjoined upon and Ibn Abd al-Ala made this addition that by "Nadiyah" he meant his people}}
\hadithdefcmd{muslim}{7066}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، قَالَ كُنَّا عِنْدَ عَبْدِ اللَّهِ جُلُوسًا وَهُوَ مُضْطَجِعٌ بَيْنَنَا فَأَتَاهُ رَجُلٌ فَقَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ إِنَّ قَاصًّا عِنْدَ أَبْوَابِ كِنْدَةَ يَقُصُّ وَيَزْعُمُ أَنَّ آيَةَ الدُّخَانِ تَجِيءُ فَتَأْخُذُ بِأَنْفَاسِ الْكُفَّارِ وَيَأْخُذُ الْمُؤْمِنِينَ مِنْهُ كَهَيْئَةِ الزُّكَامِ فَقَالَ عَبْدُ اللَّهِ وَجَلَسَ وَهُوَ غَضْبَانُ يَا أَيُّهَا النَّاسُ اتَّقُوا اللَّهَ مَنْ عَلِمَ مِنْكُمْ شَيْئًا فَلْيَقُلْ بِمَا يَعْلَمُ وَمَنْ لَمْ يَعْلَمْ فَلْيَقُلِ اللَّهُ أَعْلَمُ فَإِنَّهُ أَعْلَمُ لأَحَدِكُمْ أَنْ يَقُولَ لِمَا لاَ يَعْلَمُ اللَّهُ أَعْلَمُ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ قَالَ لِنَبِيِّهِ صلى الله عليه وسلم ‏\{‏ قُلْ مَا أَسْأَلُكُمْ عَلَيْهِ مِنْ أَجْرٍ وَمَا أَنَا مِنَ الْمُتَكَلِّفِينَ‏\}‏ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا رَأَى مِنَ النَّاسِ إِدْبَارًا فَقَالَ ‏"‏ اللَّهُمَّ سَبْعٌ كَسَبْعِ يُوسُفَ ‏"‏ ‏.‏ قَالَ فَأَخَذَتْهُمْ سَنَةٌ حَصَّتْ كُلَّ شَىْءٍ حَتَّى أَكَلُوا الْجُلُودَ وَالْمَيْتَةَ مِنَ الْجُوعِ وَيَنْظُرُ إِلَى السَّمَاءِ أَحَدُهُمْ فَيَرَى كَهَيْئَةِ الدُّخَانِ فَأَتَاهُ أَبُو سُفْيَانَ فَقَالَ يَا مُحَمَّدُ إِنَّكَ جِئْتَ تَأْمُرُ بِطَاعَةِ اللَّهِ وَبِصِلَةِ الرَّحِمِ وَإِنَّ قَوْمَكَ قَدْ هَلَكُوا فَادْعُ اللَّهَ لَهُمْ - قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ فَارْتَقِبْ يَوْمَ تَأْتِي السَّمَاءُ بِدُخَانٍ مُبِينٍ * يَغْشَى النَّاسَ هَذَا عَذَابٌ أَلِيمٌ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ إِنَّكُمْ عَائِدُونَ‏\}‏ ‏.‏ قَالَ أَفَيُكْشَفُ عَذَابُ الآخِرَةِ ‏\{‏ يَوْمَ نَبْطِشُ الْبَطْشَةَ الْكُبْرَى إِنَّا مُنْتَقِمُونَ‏\}‏ فَالْبَطْشَةُ يَوْمَ بَدْرٍ وَقَدْ مَضَتْ آيَةُ الدُّخَانِ وَالْبَطْشَةُ وَاللِّزَامُ وَآيَةُ الرُّومِ ‏.‏\hadithno{7066}\hadithtrans{Masruq reported:We were sitting in the company of Abdullah and he was lying on the bed that a person came and said: Abd Abd al-Rabmin, a story-teller at the gates of Kinda says that the verse (of the Qur'an) which deals with the" smoke" implies that which is about to come and it would hold the breath of the infidels and would inflict the believers with cold. Thereupon Abdullah got up and said in anger. O people, fear Allah and say only that which one knows amongst you and do not say which he does not know and he should simply say: Allah has the best knowledge for He has the best knowledge amongst all of you. It does not behove him to say that which he does not know. Allah has the best knowledge of it. Verily Allah, the Exalted and Glorious, said to His Prophet (ﷺ) to state:" I do not ask from you any remuneration and I am not the one to put you in trouble," and when Allah's Mesqenger (ﷺ) saw people turning back (from religion) he said: O Allah, afflict thern with seven famines as was done in the case of Yusuf, so they were afflicted with famine by which they were forced to eat everything until they were obliged to eat the hides and the dead bodies because of hunger, and every one of them looked towards the sky and he found a smoke. And Abu Sufyan came and he said: Muhammad, you have come to command us to obey Allah and cement the ties of blood- relation whereas your people are undone; supplicate Allah for tlicm. Thereupon Allah, the Exalted and Glorious, said:" Wait for the day when there would be clear smoke from the sky which would envelop people and that would be grievous torivent" up to the words:" you are going to return to (evil)." (if this verse implied the torment of the next life) could the chastisement of the next (life) be averted (as the Qur'an states): On the day when We seize (them) with the most violent seizing; surely We shall exact retribution" (xliv. 16)? The seizing (in the hadith) implies that of the Day of Badr. And so far as the sign of smoke, seizing, inevitability and signs of Rome are concern- ed, they have become things of the past now}}
\hadithdefcmd{muslim}{7067}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، ح وَحَدَّثَنِي أَبُو سَعِيدٍ، الأَشَجُّ أَخْبَرَنَا وَكِيعٌ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، كُلُّهُمْ عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لِيَحْيَى - قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمِ بْنِ صُبَيْحٍ، عَنْ مَسْرُوقٍ، قَالَ جَاءَ إِلَى عَبْدِ اللَّهِ رَجُلٌ فَقَالَ تَرَكْتُ فِي الْمَسْجِدِ رَجُلاً يُفَسِّرُ الْقُرْآنَ بِرَأْيِهِ يُفَسِّرُ هَذِهِ الآيَةَ ‏\{‏ يَوْمَ تَأْتِي السَّمَاءُ بِدُخَانٍ مُبِينٍ‏\}‏ قَالَ يَأْتِي النَّاسَ يَوْمَ الْقِيَامَةِ دُخَانٌ فَيَأْخُذُ بِأَنْفَاسِهِمْ حَتَّى يَأْخُذَهُمْ مِنْهُ كَهَيْئَةِ الزُّكَامِ ‏.‏ فَقَالَ عَبْدُ اللَّهِ مَنْ عَلِمَ عِلْمًا فَلْيَقُلْ بِهِ وَمَنْ لَمْ يَعْلَمْ فَلْيَقُلِ اللَّهُ أَعْلَمُ فَإِنَّ مِنْ فِقْهِ الرَّجُلِ أَنْ يَقُولَ لِمَا لاَ عِلْمَ لَهُ بِهِ اللَّهُ أَعْلَمُ ‏.‏ إِنَّمَا كَانَ هَذَا أَنَّ قُرَيْشًا لَمَّا اسْتَعْصَتْ عَلَى النَّبِيِّ صلى الله عليه وسلم دَعَا عَلَيْهِمْ بِسِنِينَ كَسِنِي يُوسُفَ فَأَصَابَهُمْ قَحْطٌ وَجَهْدٌ حَتَّى جَعَلَ الرَّجُلُ يَنْظُرُ إِلَى السَّمَاءِ فَيَرَى بَيْنَهُ وَبَيْنَهَا كَهَيْئَةِ الدُّخَانِ مِنَ الْجَهْدِ وَحَتَّى أَكَلُوا الْعِظَامَ فَأَتَى النَّبِيَّ صلى الله عليه وسلم رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ اسْتَغْفِرِ اللَّهَ لِمُضَرَ فَإِنَّهُمْ قَدْ هَلَكُوا فَقَالَ ‏"‏ لِمُضَرَ إِنَّكَ لَجَرِيءٌ ‏"‏ ‏.‏ قَالَ فَدَعَا اللَّهَ لَهُمْ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ إِنَّا كَاشِفُو الْعَذَابِ قَلِيلاً إِنَّكُمْ عَائِدُونَ‏\}‏ قَالَ فَمُطِرُوا فَلَمَّا أَصَابَتْهُمُ الرَّفَاهِيَةُ - قَالَ - عَادُوا إِلَى مَا كَانُوا عَلَيْهِ - قَالَ - فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ فَارْتَقِبْ يَوْمَ تَأْتِي السَّمَاءُ بِدُخَانٍ مُبِينٍ * يَغْشَى النَّاسَ هَذَا عَذَابٌ أَلِيمٌ‏\}‏ ‏\{‏ يَوْمَ نَبْطِشُ الْبَطْشَةَ الْكُبْرَى إِنَّا مُنْتَقِمُونَ‏\}‏ قَالَ يَعْنِي يَوْمَ بَدْرٍ ‏.‏\hadithno{7067}\hadithtrans{Masruq reported that there came to Abdullah a person and said:I have left behind in the mosque a man who explains the Qur'an according to his personal discretion and he explained this verse:" So wait for the day when the Heaven brings a clear smoke." He says that a smoke would come to the people on the Day of Resurrection anl it will withhold breath and they would be inflicted with cold. 'Abdullah said: He who has knowledge should say something and he who has no knowledge should simply say: Allah is best aware. This reflects the understanding of a person that he should say about that which he does not know that it is Allah who knows best. The fact is that when the Quraish disobeyed Allah's Apostle (ﷺ) he supplicated Allah that they should be afflicted with famine and starvation as was done in case of Yusuf. And they were so much hard pressed that a person would ace the sky and he would see between him and the sky something like smoke and they were so much hard pressed that they began to cat the bones, and a person came to Allah's Apostle (ﷺ) and said: Allah's Messenger. seek forgiveness for the tribe of Mudar for (its people) have been undone. The Messenger (ﷺ) said: For Mudar? You are overbold, but he supplicated Allah for them. It was upon this that this verse was revealed:" We shall remove the chastisement a little, but they will surely return to evil" (xliv. 15). lie (the narrator) said: There was a downpoor of rain upon them. When there was some relief for them they returned to the same position as they had been before, and Allah, the Exalted and Glorious, revealed this verse:" So wait for the day when the heaven brings a clear smoke enveloping people. This is a grievous torment on the day when We seize them with the most violent seizing; surely, We shall exact retribution." And this (seizing) implied (Battle) of Badr}}
\hadithdefcmd{muslim}{7068}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ خَمْسٌ قَدْ مَضَيْنَ الدُّخَانُ وَاللِّزَامُ وَالرُّومُ وَالْبَطْشَةُ وَالْقَمَرُ ‏.‏\hadithno{7068}\hadithtrans{Abdullah said that five signs have (become things) of the past (and have proved the truth of the Holy Prophet):(Enveloping) by the smoke, inevitable (punishment to the Meccans at Badr), (the victory of) Rome, (violent) seizing (of the Meccans at Badr) and (the splitting up of) the Moon}}
\hadithdefcmd{muslim}{7069}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{7069}\hadithtrans{This hadith has been narrated on the authority of A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{7070}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ عَزْرَةَ، عَنِ الْحَسَنِ الْعُرَنِيِّ، عَنْ يَحْيَى بْنِ الْجَزَّارِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ أُبَىِّ، بْنِ كَعْبٍ فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ وَلَنُذِيقَنَّهُمْ مِنَ الْعَذَابِ الأَدْنَى دُونَ الْعَذَابِ الأَكْبَرِ‏\}‏ قَالَ مَصَائِبُ الدُّنْيَا وَالرُّومُ وَالْبَطْشَةُ أَوِ الدُّخَانُ ‏.‏ شُعْبَةُ الشَّاكُّ فِي الْبَطْشَةِ أَوِ الدُّخَانِ ‏.‏\hadithno{7070}\hadithtrans{Ubayy b. Ka'b reported that the words of Allah, the Exalted and Glorious:" We will, surely, make them taste the lesser punishment before the severer punishment (that haply they may return)" (xxxii. 21) imply the torments of the world. (victory of) Rome, seizing (of the Meccans), or smoke. And Shalba was in doubt about seizing or smoke}}
\hadithdefcmd{muslim}{7071}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ أَبِي، نَجِيحٍ عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ، قَالَ انْشَقَّ الْقَمَرُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِشِقَّتَيْنِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اشْهَدُوا ‏"‏ ‏.‏\hadithno{7071}\hadithtrans{Abu Ma'mar reported on the authority of Abdullah that the moon was split up during lifetime by Allah's Messenger (ﷺ) in two parts and Allah's Messenger (ﷺ) said:Bear testimony to this}}
\hadithdefcmd{muslim}{7072}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ جَمِيعًا عَنْ أَبِي، مُعَاوِيَةَ ح وَحَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي كِلاَهُمَا، عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا مِنْجَابُ بْنُ الْحَارِثِ التَّمِيمِيُّ، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا ابْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ بَيْنَمَا نَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِنًى إِذَا انْفَلَقَ الْقَمَرُ فِلْقَتَيْنِ فَكَانَتْ فِلْقَةٌ وَرَاءَ الْجَبَلِ وَفِلْقَةٌ دُونَهُ فَقَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اشْهَدُوا ‏"‏ ‏.‏\hadithno{7072}\hadithtrans{This hadith has been transmitted on the authority of Abdullah b. Mas'ud (who said):We were along with Allah's Messenger (ﷺ) at Mina, that moon was split up into two. One of its parts was behind the mountain and the other one was on this side of the mountain. Allah's Messenger (may peace be upbn him) said to us: Bear witness to this}}
\hadithdefcmd{muslim}{7073}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ انْشَقَّ الْقَمَرُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِلْقَتَيْنِ فَسَتَرَ الْجَبَلُ فِلْقَةً وَكَانَتْ فِلْقَةٌ فَوْقَ الْجَبَلِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ اشْهَدْ ‏"‏ ‏.‏\hadithno{7073}\hadithtrans{Abdullah b. Mas'ud reported that the moon was split up in two parts during the lifetime of Allah's Messenger (ﷺ). The mountain covered one of its parts and one part of it was above the mountain and Allah's Messenger (ﷺ) said:Bear witness to this}}
\hadithdefcmd{muslim}{7074}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ ذَلِكَ ‏.‏\hadithno{7074}\hadithtrans{Another chain of transmitters reported the like of this hadith}}
\hadithdefcmd{muslim}{7075}{وَحَدَّثَنِيهِ بِشْرُ بْنُ خَالِدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، كِلاَهُمَا عَنْ شُعْبَةَ، بِإِسْنَادِ ابْنِ مُعَاذٍ عَنْ شُعْبَةَ، نَحْوَ حَدِيثِهِ غَيْرَ أَنَّ فِي، حَدِيثِ ابْنِ أَبِي عَدِيٍّ فَقَالَ ‏ "‏ اشْهَدُوا اشْهَدُوا ‏"‏ ‏.‏\hadithno{7075}\hadithtrans{This hadith has been transmitted on the authority of Shu'ba with a slight variation of wording}}
\hadithdefcmd{muslim}{7078}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَأَبُو دَاوُدَ ح وَحَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ جَعْفَرٍ، وَأَبُو دَاوُدَ كُلُّهُمْ عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ انْشَقَّ الْقَمَرُ فِرْقَتَيْنِ ‏.‏ وَفِي حَدِيثِ أَبِي دَاوُدَ انْشَقَّ الْقَمَرُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{7078}\hadithtrans{Anas reported that the moon was split up in two parts and in the hadith recorded in Abu Dawud, the words are:" The moon was split up into two parts during the life of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{7079}{حَدَّثَنَا مُوسَى بْنُ قُرَيْشٍ التَّمِيمِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ بَكْرِ بْنِ مُضَرَ، حَدَّثَنِي أَبِي، حَدَّثَنَا جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّ الْقَمَرَ انْشَقَّ عَلَى زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{7079}\hadithtrans{Ibn 'Abbas reported that the moon was split up during the lifetime of Allah's Messenger (may peace he upon him)}}
\hadithdefcmd{muslim}{7082}{وَحَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الأَعْمَشِ، حَدَّثَنَا سَعِيدُ بْنُ، جُبَيْرٍ عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ قَيْسٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أَحَدٌ أَصْبَرَ عَلَى أَذًى يَسْمَعُهُ مِنَ اللَّهِ تَعَالَى إِنَّهُمْ يَجْعَلُونَ لَهُ نِدًّا وَيَجْعَلُونَ لَهُ وَلَدًا وَهُوَ مَعَ ذَلِكَ يَرْزُقُهُمْ وَيُعَافِيهِمْ وَيُعْطِيهِمْ ‏"‏ ‏.‏\hadithno{7082}\hadithtrans{Abdullah b. Qais reported from Allah's Messenger (ﷺ) that none is more forbearing in listening to the most irksome things than Allah, the Exalted. They associate rivals with him, attribute sonhood to Him, but in spite of this He provides them sustenance, grants them safety, confers upon them so many things}}
\hadithdefcmd{muslim}{7083}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَقُولُ اللَّهُ تَبَارَكَ وَتَعَالَى لأَهْوَنِ أَهْلِ النَّارِ عَذَابًا لَوْ كَانَتْ لَكَ الدُّنْيَا وَمَا فِيهَا أَكُنْتَ مُفْتَدِيًا بِهَا فَيَقُولُ نَعَمْ فَيَقُولُ قَدْ أَرَدْتُ مِنْكَ أَهْوَنَ مِنْ هَذَا وَأَنْتَ فِي صُلْبِ آدَمَ أَنْ لاَ تُشْرِكَ - أَحْسَبُهُ قَالَ - وَلاَ أُدْخِلَكَ النَّارَ فَأَبَيْتَ إِلاَّ الشِّرْكَ ‏"‏ ‏.‏\hadithno{7083}\hadithtrans{Anas b. Malik reported Allah's Messenger (ﷺ) as saying:Allah, the Exalted and High, would say to one who shall have to undergo the least torture (on the Day of Resurrection): Would you like to go as ransom if you had all worldly riches; he would say: Yes. Allah would say to him: When you were in the loins of Adam, I demanded from you something easier than this that you should not associate anything with Me. (The narrator says): I think He also said: I would not cause you to enter Hell-Fire but you defied and attributed Divinity (to others besides Me)}}
\hadithdefcmd{muslim}{7084}{حَدَّثَنَاهُ مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عِمْرَانَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ إِلاَّ قَوْلَهُ ‏ "‏ وَلاَ أُدْخِلَكَ النَّارَ ‏"‏ ‏.‏ فَإِنَّهُ لَمْ يَذْكُرْهُ ‏.‏\hadithno{7084}\hadithtrans{This hadith has been narrated on the authority of Anas b. Malik through another chain of transmitters, but with a slight variation of wording (and the words are):I shall cause him to enter Hell." (The words subsequent to these) have not been mentioned}}
\hadithdefcmd{muslim}{7085}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنَا أَبِي، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ يُقَالُ لِلْكَافِرِ يَوْمَ الْقِيَامَةِ أَرَأَيْتَ لَوْ كَانَ لَكَ مِلْءُ الأَرْضِ ذَهَبًا أَكُنْتَ تَفْتَدِي بِهِ فَيَقُولُ نَعَمْ ‏.‏ فَيُقَالُ لَهُ قَدْ سُئِلْتَ أَيْسَرَ مِنْ ذَلِكَ ‏"‏ ‏.‏\hadithno{7085}\hadithtrans{Anas b. Malik reported that Allah's Messenger (may peace be u n him) said:It would be said to the non-believers on the Day of Resurrection: If you were to possess gold, filling the whole earth, would you like to secure your freedom by paying that? He would say: Yes. Thereupon it would be said to him: Something easier (than this) was demanded from you (but you paid no heed to it)}}
\hadithdefcmd{muslim}{7086}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، ح وَحَدَّثَنِي عَمْرُو بْنُ زُرَارَةَ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي ابْنَ عَطَاءٍ - كِلاَهُمَا عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ فَيُقَالُ لَهُ كَذَبْتَ قَدْ سُئِلْتَ مَا هُوَ أَيْسَرُ مِنْ ذَلِكَ ‏"‏ ‏.‏\hadithno{7086}\hadithtrans{Anas reported this hadlth through another chain of transmitters and the words are:" It would be said to him: You have told a lie; what had been demanded from you was quite easier than this (the belief in the Oneness of Allah)}}
\hadithdefcmd{muslim}{7087}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا يُونُسُ، بْنُ مُحَمَّدٍ حَدَّثَنَا شَيْبَانُ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ كَيْفَ يُحْشَرُ الْكَافِرُ عَلَى وَجْهِهِ يَوْمَ الْقِيَامَةِ قَالَ ‏ "‏ أَلَيْسَ الَّذِي أَمْشَاهُ عَلَى رِجْلَيْهِ فِي الدُّنْيَا قَادِرًا عَلَى أَنْ يُمْشِيَهُ عَلَى وَجْهِهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ قَتَادَةُ بَلَى وَعِزَّةِ رَبِّنَا ‏.‏\hadithno{7087}\hadithtrans{Anas b. Malik reported that a person said:Allah's Messenger, how the non-believers be made to assemble on the Day of Resurrection (by crawling) on their faces? Thereupon he said: Is He Who is powerful to make them walk on their feet not powerful enough to make them (crawl) upon their faces on the Day of Resurrection? Qatada said: Of course, it is so. (He adjured): By the might of our Lord}}
\hadithdefcmd{muslim}{7088}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، الْبُنَانِيِّ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُؤْتَى بِأَنْعَمِ أَهْلِ الدُّنْيَا مِنْ أَهْلِ النَّارِ يَوْمَ الْقِيَامَةِ فَيُصْبَغُ فِي النَّارِ صَبْغَةً ثُمَّ يُقَالُ يَا ابْنَ آدَمَ هَلْ رَأَيْتَ خَيْرًا قَطُّ هَلْ مَرَّ بِكَ نَعِيمٌ قَطُّ فَيَقُولُ لاَ وَاللَّهِ يَا رَبِّ ‏.‏ وَيُؤْتَى بِأَشَدِّ النَّاسِ بُؤْسًا فِي الدُّنْيَا مِنْ أَهْلِ الْجَنَّةِ فَيُصْبَغُ صَبْغَةً فِي الْجَنَّةِ فَيُقَالُ لَهُ يَا ابْنَ آدَمَ هَلْ رَأَيْتَ بُؤْسًا قَطُّ هَلْ مَرَّ بِكَ شِدَّةٌ قَطُّ فَيَقُولُ لاَ وَاللَّهِ يَا رَبِّ مَا مَرَّ بِي بُؤُسٌ قَطُّ وَلاَ رَأَيْتُ شِدَّةً قَطُّ ‏"‏ ‏.‏\hadithno{7088}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said that one amongst the denizens of Hell who had led a life of ease and plenty amongst the people of the world would be made to dip in Fire only once on the Day of Resurrection and then it would be said to him:O, son of Adam, did you find any comfort, did you happen to get any material blessing? He would say: By Allah, no, my Lord. And then that person from amongst the persons of the world be brought who had led the most miserable life (in the world) from amongst the inmates of Paradise. and he would be made to dip once in Paradise and it would be said to him. 0, son of Adam, did you face, any hardship? Or had any distress fallen to your lot? And he would say: By Allah, no,0 my Lord, never did I face any hardship or experience any distress}}
\hadithdefcmd{muslim}{7089}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا هَمَّامُ بْنُ يَحْيَى، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ لاَ يَظْلِمُ مُؤْمِنًا حَسَنَةً يُعْطَى بِهَا فِي الدُّنْيَا وَيُجْزَى بِهَا فِي الآخِرَةِ وَأَمَّا الْكَافِرُ فَيُطْعَمُ بِحَسَنَاتِ مَا عَمِلَ بِهَا لِلَّهِ فِي الدُّنْيَا حَتَّى إِذَا أَفْضَى إِلَى الآخِرَةِ لَمْ تَكُنْ لَهُ حَسَنَةٌ يُجْزَى بِهَا ‏"‏ ‏.‏\hadithno{7089}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said:Verily, Allah does not treat a believer unjustly in regard to his virtues. He would confer upon him (His blessing) in this world and would give him reward in the Hereafter. And as regards a non-believer, he would be made to taste the reward (of virtue in this world) what he has done for himself so much that when it would be the Hereafter, he would find no virtue for which he should be rewarded}}
\hadithdefcmd{muslim}{7090}{حَدَّثَنَا عَاصِمُ بْنُ النَّضْرِ التَّيْمِيُّ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ حَدَّثَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْكَافِرَ إِذَا عَمِلَ حَسَنَةً أُطْعِمَ بِهَا طُعْمَةً مِنَ الدُّنْيَا وَأَمَّا الْمُؤْمِنُ فَإِنَّ اللَّهَ يَدَّخِرُ لَهُ حَسَنَاتِهِ فِي الآخِرَةِ وَيُعْقِبُهُ رِزْقًا فِي الدُّنْيَا عَلَى طَاعَتِهِ ‏"‏ ‏.‏\hadithno{7090}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) thus told him:When a non-believer does good he is made to taste Its reward in this world. And so far as the believer is concerned, Allah stores (the reward) of his virtues for the Hereafter and provides him sustenance in accordance with his obedience to Him}}
\hadithdefcmd{muslim}{7091}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الرُّزِّيُّ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِهِمَا ‏.‏\hadithno{7091}\hadithtrans{This hadith has been narrated on the authority of Anas b. Malik through another chain of transmitters}}
\hadithdefcmd{muslim}{7092}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلُ الْمُؤْمِنِ كَمَثَلِ الزَّرْعِ لاَ تَزَالُ الرِّيحُ تُمِيلُهُ وَلاَ يَزَالُ الْمُؤْمِنُ يُصِيبُهُ الْبَلاَءُ وَمَثَلُ الْمُنَافِقِ كَمَثَلِ شَجَرَةِ الأَرْزِ لاَ تَهْتَزُّ حَتَّى تَسْتَحْصِدَ ‏"‏ ‏.‏\hadithno{7092}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The Similitude of a believer is that of (a standing) crop which the air continues to toss from one side to another; in the same way a believer always (receives the strokes) of misfortune. The similitude of a hypocrite is that of a cypress tree which does not move until it is uprooted}}
\hadithdefcmd{muslim}{7093}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، عَنْ عَبْدِ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّ فِي، حَدِيثِ عَبْدِ الرَّزَّاقِ مَكَانَ قَوْلِهِ تُمِيلُهُ ‏ "‏ تُفِيئُهُ ‏"‏ ‏.‏\hadithno{7093}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters, but with a slight variation of wording}}
\hadithdefcmd{muslim}{7094}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَمُحَمَّدُ بْنُ بِشْرٍ، قَالاَ حَدَّثَنَا زَكَرِيَّاءُ بْنُ أَبِي زَائِدَةَ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، حَدَّثَنِي ابْنُ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، كَعْبٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلُ الْمُؤْمِنِ كَمَثَلِ الْخَامَةِ مِنَ الزَّرْعِ تُفِيئُهَا الرِّيحُ وَتَصْرَعُهَا مَرَّةً وَتَعْدِلُهَا أُخْرَى حَتَّى تَهِيجَ وَمَثَلُ الْكَافِرِ كَمَثَلِ الأَرْزَةِ الْمُجْذِيَةِ عَلَى أَصْلِهَا لاَ يُفِيئُهَا شَىْءٌ حَتَّى يَكُونَ انْجِعَافُهَا مَرَّةً وَاحِدَةً ‏"‏ ‏.‏\hadithno{7094}\hadithtrans{Ka'b reported that Allah's Messenger (ﷺ) said that the similitude of a believer is that of a standing crop in a field which is shaken by wind and then it comes to its original position but it stands at its roots. The similitude of a non-believer is that of a cypress tree which stands on its roots and nothing shakes it but it is uprooted (with) one (violent stroke)}}
\hadithdefcmd{muslim}{7095}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلُ الْمُؤْمِنِ كَمَثَلِ الْخَامَةِ مِنَ الزَّرْعِ تُفِيئُهَا الرِّيَاحُ تَصْرَعُهَا مَرَّةً وَتَعْدِلُهَا حَتَّى يَأْتِيَهُ أَجَلُهُ وَمَثَلُ الْمُنَافِقِ مَثَلُ الأَرْزَةِ الْمُجْذِيَةِ الَّتِي لاَ يُصِيبُهَا شَىْءٌ حَتَّى يَكُونَ انْجِعَافُهَا مَرَّةً وَاحِدَةً ‏"‏ ‏.‏\hadithno{7095}\hadithtrans{Ka'b b. Malik reported on the authority of his father that the similitude of a believer is that of a standing crop. The wind sometimes shakes it and sometimes raises it up and then it comes to its destined end. And the similitude of a hypocrite is that of a cypress tree which is not affected by anything but is uprooted once for all}}
\hadithdefcmd{muslim}{7096}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، وَمَحْمُودُ بْنُ غَيْلاَنَ، قَالاَ حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، حَدَّثَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم غَيْرَ أَنَّ مَحْمُودًا قَالَ فِي رِوَايَتِهِ عَنْ بِشْرٍ ‏"‏ وَمَثَلُ الْكَافِرِ كَمَثَلِ الأَرْزَةِ ‏"‏ ‏.‏ وَأَمَّا ابْنُ حَاتِمٍ فَقَالَ ‏"‏ مَثَلُ الْمُنَافِقِ ‏"‏ ‏.‏ كَمَا قَالَ زُهَيْرٌ ‏.‏\hadithno{7096}\hadithtrans{This hadith has been narrated through a couple of other chains of transmitters, one which says "the similitude of the disbeliever" instead and another which agrees with the wording of the previous hadith}}
\hadithdefcmd{muslim}{7097}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ بَشَّارٍ، وَعَبْدُ اللَّهِ بْنُ هَاشِمٍ، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ سُفْيَانَ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، - قَالَ ابْنُ هَاشِمٍ عَنْ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، وَقَالَ ابْنُ بَشَّارٍ، عَنِ ابْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، - عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِ حَدِيثِهِمْ وَقَالاَ جَمِيعًا فِي حَدِيثِهِمَا عَنْ يَحْيَى، ‏ "‏ وَمَثَلُ الْكَافِرِ مَثَلُ الأَرْزَةِ ‏"‏ ‏.‏\hadithno{7097}\hadithtrans{This hadith has been narrated on the authority of Ibn Ka'b through another chain of transmitters but with " "the similitude of the disbeliever is that of a cypress tree}}
\hadithdefcmd{muslim}{7098}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، - وَاللَّفْظُ لِيَحْيَى - قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، أَنَّهُ سَمِعَ عَبْدَ، اللَّهِ بْنَ عُمَرَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنَ الشَّجَرِ شَجَرَةً لاَ يَسْقُطُ وَرَقُهَا وَإِنَّهَا مَثَلُ الْمُسْلِمِ فَحَدِّثُونِي مَا هِيَ ‏"‏ ‏.‏ فَوَقَعَ النَّاسُ فِي شَجَرِ الْبَوَادِي ‏.‏ قَالَ عَبْدُ اللَّهِ وَوَقَعَ فِي نَفْسِي أَنَّهَا النَّخْلَةُ فَاسْتَحْيَيْتُ ثُمَّ قَالُوا حَدِّثْنَا مَا هِيَ يَا رَسُولَ اللَّهِ قَالَ فَقَالَ ‏"‏ هِيَ النَّخْلَةُ ‏"‏ ‏.‏ قَالَ فَذَكَرْتُ ذَلِكَ لِعُمَرَ قَالَ لأَنْ تَكُونَ قُلْتَ هِيَ النَّخْلَةُ أَحَبُّ إِلَىَّ مِنْ كَذَا وَكَذَا ‏.‏\hadithno{7098}\hadithtrans{Abdullah b. Umar reported that Allah's Messenger (ﷺ) said:There is a tree amongst trees, the leaves of which do not wither and that is like a Muslim; tell me which that (tree) can be? The people began to think of the trees of the forest. Abdullah said: I thought that it could be the date-palm tree, but I felt hesitant (to say that). They (the Companions) then said: Allah's Messenger, (kindly) tell us which that can be? Thereupon he said: It is the date-palm tree. I made a mention of that to 'Umar, whereupon he said: Had you said that it meant the date-palin tree, this statement of yours (would have been dearer to me) than such and such things}}
\hadithdefcmd{muslim}{7099}{حَدَّثَنِي مُحَمَّدُ بْنُ عُبَيْدٍ الْغُبَرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي الْخَلِيلِ، الضُّبَعِيِّ عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا لأَصْحَابِهِ ‏"‏ أَخْبِرُونِي عَنْ شَجَرَةٍ مَثَلُهَا مَثَلُ الْمُؤْمِنِ ‏"‏ ‏.‏ فَجَعَلَ الْقَوْمُ يَذْكُرُونَ شَجَرًا مِنْ شَجَرِ الْبَوَادِي ‏.‏ قَالَ ابْنُ عُمَرَ وَأُلْقِيَ فِي نَفْسِي أَوْ رُوعِيَ أَنَّهَا النَّخْلَةُ فَجَعَلْتُ أُرِيدُ أَنْ أَقُولَهَا فَإِذَا أَسْنَانُ الْقَوْمِ فَأَهَابُ أَنْ أَتَكَلَّمَ فَلَمَّا سَكَتُوا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هِيَ النَّخْلَةُ ‏"‏ ‏.‏\hadithno{7099}\hadithtrans{Ibn Umar reported that Allah's Messenger (ﷺ) one day said to his Companions:Tell me about a tree which has resemblance with a believer. The people began to mention (different) trees of the forest. Ibn 'Umar said: It was instilled in my mind or in my heart and it stuck therein that it implied the date- palm tree. I made up my mind to make a mention of that but could not do that because of the presence of the elderly people there. When there was a hush amongst them (after they had expressed their views), Allah's Messenger (ﷺ) said: It Is the date-palm tree}}
\hadithdefcmd{muslim}{7100}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، قَالَ صَحِبْتُ ابْنَ عُمَرَ إِلَى الْمَدِينَةِ فَمَا سَمِعْتُهُ يُحَدِّثُ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ حَدِيثًا وَاحِدًا قَالَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَأُتِيَ بِجُمَّارٍ ‏.‏ فَذَكَرَ بِنَحْوِ حَدِيثِهِمَا ‏.‏\hadithno{7100}\hadithtrans{Mujahid said:(I have had the privilege) of accompanying Ibn 'Umar up to Medina but I did not hear him narrate anything from Allah's Messenger (ﷺ) except one hadith. And he said: We were in the presence of Allah's Messenger (ﷺ) that there was brought to him the kernel of a date. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{7101}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سَيْفٌ، قَالَ سَمِعْتُ مُجَاهِدًا، يَقُولُ سَمِعْتُ ابْنَ، عُمَرَ يَقُولُ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِجُمَّارٍ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِهِمْ ‏.‏\hadithno{7101}\hadithtrans{Mujahid reported:I heard Ibn 'Umar as saying: There was brought to Allah's Messenger (ﷺ) the kernel. The rest of the hadith is tile same}}
\hadithdefcmd{muslim}{7102}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَخْبِرُونِي بِشَجَرَةٍ شِبْهِ أَوْ كَالرَّجُلِ الْمُسْلِمِ لاَ يَتَحَاتُّ وَرَقُهَا ‏"‏ ‏.‏ قَالَ إِبْرَاهِيمُ لَعَلَّ مُسْلِمًا قَالَ وَتُؤْتِي أُكُلَهَا ‏.‏ وَكَذَا وَجَدْتُ عِنْدَ غَيْرِي أَيْضًا وَلاَ تُؤْتِي أُكُلَهَا كُلَّ حِينٍ ‏.‏ قَالَ ابْنُ عُمَرَ فَوَقَعَ فِي نَفْسِي أَنَّهَا النَّخْلَةُ وَرَأَيْتُ أَبَا بَكْرٍ وَعُمَرَ لاَ يَتَكَلَّمَانِ فَكَرِهْتُ أَنْ أَتَكَلَّمَ أَوْ أَقُولَ شَيْئًا فَقَالَ عُمَرُ لأَنْ تَكُونَ قُلْتَهَا أَحَبُّ إِلَىَّ مِنْ كَذَا وَكَذَا ‏.‏\hadithno{7102}\hadithtrans{Ibn Umar reported:We were'in the company of Allah's Messenger (ﷺ) that he said: Tell me of a tree which has resemblance to a Muslim and the leaves of which do not wither. Ibrahim said that perhaps Imam Muslim had stated like this: It constantly bears fruit but I have, however, seen [It does not bear fruit constantly]. Ibn Umar said: It crossed my mind that it could be the date-palm tree, but as I saw Aba Bakr and Umar observe silence, I did not deem it fit that I should speak or I should say something. 'Umar said: Had you said so, it would have been dearer to me than such and such thing}}
\hadithdefcmd{muslim}{7103}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، عُثْمَانُ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ الشَّيْطَانَ قَدْ أَيِسَ أَنْ يَعْبُدَهُ الْمُصَلُّونَ فِي جَزِيرَةِ الْعَرَبِ وَلَكِنْ فِي التَّحْرِيشِ بَيْنَهُمْ ‏"‏ ‏.‏\hadithno{7103}\hadithtrans{Jabir reported:I heard Allah's Apostle (ﷺ) as saying: Verily, the Satan has lost all hopes that the worshippers would ever worship (him) in the peninsula of Arabia, but he (is hopeful) that he would sow the seed of dissension amongst them}}
\hadithdefcmd{muslim}{7104}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{7104}\hadithtrans{This hadith has been narrated on the authority of A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{7105}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، عُثْمَانُ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ عَرْشَ إِبْلِيسَ عَلَى الْبَحْرِ فَيَبْعَثُ سَرَايَاهُ فَيَفْتِنُونَ النَّاسَ فَأَعْظَمُهُمْ عِنْدَهُ أَعْظَمُهُمْ فِتْنَةً ‏"‏ ‏.‏\hadithno{7105}\hadithtrans{Jabir reported:I heard Allah's Messenger (way peace be upon him) as saying: The throne of Iblis is upon the ocean and he sends detachments (to different parts) inorder to put people to trial and the most important figure in his eyes is one who is most notorious in sowing the seed of dissension}}
\hadithdefcmd{muslim}{7106}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ - وَاللَّفْظُ لأَبِي كُرَيْبٍ - قَالاَ أَخْبَرَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ إِبْلِيسَ يَضَعُ عَرْشَهُ عَلَى الْمَاءِ ثُمَّ يَبْعَثُ سَرَايَاهُ فَأَدْنَاهُمْ مِنْهُ مَنْزِلَةً أَعْظَمُهُمْ فِتْنَةً يَجِيءُ أَحَدُهُمْ فَيَقُولُ فَعَلْتُ كَذَا وَكَذَا فَيَقُولُ مَا صَنَعْتَ شَيْئًا قَالَ ثُمَّ يَجِيءُ أَحَدُهُمْ فَيَقُولُ مَا تَرَكْتُهُ حَتَّى فَرَّقْتُ بَيْنَهُ وَبَيْنَ امْرَأَتِهِ - قَالَ - فَيُدْنِيهِ مِنْهُ وَيَقُولُ نِعْمَ أَنْتَ ‏"‏ ‏.‏ قَالَ الأَعْمَشُ أُرَاهُ قَالَ ‏"‏ فَيَلْتَزِمُهُ ‏"‏ ‏.‏\hadithno{7106}\hadithtrans{Jabir reported that Allah's Messenger (ﷺ) said:Iblis places his throne upon water; he then sends detachments (for creating dissension) ; the nearer to him in rank are those who are most notorious in creating dissension. One of them comes and says: "I did so and so." And he says: "You have done nothing." Then one amongst them comes and says: "I did not spare so and so until I sowed the seed of discord between a husband and a wife." The Satan goes near him and says: "You have done well." A'mash said: He then embraces him}}
\hadithdefcmd{muslim}{7107}{حَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَبْعَثُ الشَّيْطَانُ سَرَايَاهُ فَيَفْتِنُونَ النَّاسَ فَأَعْظَمُهُمْ عِنْدَهُ مَنْزِلَةً أَعْظَمُهُمْ فِتْنَةً ‏"‏ ‏.‏\hadithno{7107}\hadithtrans{Jabir reported that Allah's Apostle (may peace be upqn him) said:The Satan sends detachments of his own in order to put people to trial and the highest in rank, in his eyes, is one who is most notorious in sowing the seed of dissension}}
\hadithdefcmd{muslim}{7108}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، عُثْمَانُ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ إِلاَّ وَقَدْ وُكِّلَ بِهِ قَرِينُهُ مِنَ الْجِنِّ ‏"‏ ‏.‏ قَالُوا وَإِيَّاكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَإِيَّاىَ إِلاَّ أَنَّ اللَّهَ أَعَانَنِي عَلَيْهِ فَأَسْلَمَ فَلاَ يَأْمُرُنِي إِلاَّ بِخَيْرٍ ‏"‏ ‏.‏\hadithno{7108}\hadithtrans{Abdullah b. Mas'ud reported that Allah's Messenger (ﷺ) said:There is none amongst you with whom is not an attache from amongst the jinn (devil). They (the Companions) said: Allah's Messenger, with you too? Thereupon he said: Yes, but Allah helps me against him and so I am safe from his hand and he does not command me but for good}}
\hadithdefcmd{muslim}{7109}{حَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِيَانِ ابْنَ مَهْدِيٍّ - عَنْ سُفْيَانَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ عَمَّارِ بْنِ رُزَيْقٍ، كِلاَهُمَا عَنْ مَنْصُورٍ، بِإِسْنَادِ جَرِيرٍ ‏.‏ مِثْلَ حَدِيثِهِ غَيْرَ أَنَّ فِي حَدِيثِ سُفْيَانَ ‏ "‏ وَقَدْ وُكِّلَ بِهِ قَرِينُهُ مِنَ الْجِنِّ وَقَرِينُهُ مِنَ الْمَلاَئِكَةِ ‏"‏ ‏.‏\hadithno{7109}\hadithtrans{This hadith has been narrated on the authority of Mansiir with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{7110}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي أَبُو صَخْرٍ، عَنِ ابْنِ، قُسَيْطٍ حَدَّثَهُ أَنَّ عُرْوَةَ حَدَّثَهُ أَنَّ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم حَدَّثَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ مِنْ عِنْدِهَا لَيْلاً ‏.‏ قَالَتْ فَغِرْتُ عَلَيْهِ فَجَاءَ فَرَأَى مَا أَصْنَعُ فَقَالَ ‏"‏ مَا لَكِ يَا عَائِشَةُ أَغِرْتِ ‏"‏ ‏.‏ فَقُلْتُ وَمَا لِي لاَ يَغَارُ مِثْلِي عَلَى مِثْلِكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَقَدْ جَاءَكِ شَيْطَانُكِ ‏"‏ ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ أَوَمَعِيَ شَيْطَانٌ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قُلْتُ وَمَعَ كُلِّ إِنْسَانٍ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قُلْتُ وَمَعَكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَعَمْ وَلَكِنْ رَبِّي أَعَانَنِي عَلَيْهِ حَتَّى أَسْلَمَ ‏"‏ ‏.‏\hadithno{7110}\hadithtrans{A'isha the wife of Allah's Apostle (ﷺ), reported that one day Allah's Messenger (ﷺ) came out of her (apartment) during the night and she felt jealous. Then he came and he saw me (in what agitated state of mind) I was. He said:A'isha, what has happened to you? Do you feel jealous? Thereupon she said: How can it be (that a woman like me) should not feel jealous in regard to a husband like you. Thereupon Allah's Messenger (ﷺ) said: It was your devil who had come to you, and she said: Allah's Messenger, is there along with me a devil? He said: Yes. I said: Is a devil attached to everyone? He said: Yes. I (Aisha) again said: Allah's Messenger, is it with you also? He said: Yes, but my Lord has helped me against him and as such I am absolutely safe from his mischief}}
\hadithdefcmd{muslim}{7113}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ مَا مِنْ أَحَدٍ يُدْخِلُهُ عَمَلُهُ الْجَنَّةَ ‏"‏ ‏.‏ فَقِيلَ وَلاَ أَنْتَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَلاَ أَنَا إِلاَّ أَنْ يَتَغَمَّدَنِي رَبِّي بِرَحْمَةٍ ‏"‏ ‏.‏\hadithno{7113}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There is none whose deeds alone would entitle him to get into Paradise. It was said to him: And, Allah's Messenger, not even you? Thereupon he said: Not even I, but that my Lord wraps me in Mercy}}
\hadithdefcmd{muslim}{7114}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنْ أَبِي، هُرَيْرَةَ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَيْسَ أَحَدٌ مِنْكُمْ يُنْجِيهِ عَمَلُهُ ‏"‏ ‏.‏ قَالُوا وَلاَ أَنْتَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَلاَ أَنَا إِلاَّ أَنْ يَتَغَمَّدَنِيَ اللَّهُ مِنْهُ بِمَغْفِرَةٍ وَرَحْمَةٍ ‏"‏ ‏.‏ وَقَالَ ابْنُ عَوْنٍ بِيَدِهِ هَكَذَا وَأَشَارَ عَلَى رَأْسِهِ ‏"‏ وَلاَ أَنَا إِلاَّ أَنْ يَتَغَمَّدَنِيَ اللَّهُ مِنْهُ بِمَغْفِرَةٍ وَرَحْمَةٍ ‏"‏ ‏.‏\hadithno{7114}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There is none amongst you whose deeds alone would attain salvation for him. They (the Companions) said: Allah's Messenger, not even you? He (the Holy Prophet) said: Not even I, but that Allah wraps me in Mercy and He grants me pardon. Ibn 'Aun pointed towards his head with his hand saying: Not even I, but that Allah wraps me in His Forgiveness and Mercy}}
\hadithdefcmd{muslim}{7115}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَيْسَ أَحَدٌ يُنْجِيهِ عَمَلُهُ ‏"‏ ‏.‏ قَالُوا وَلاَ أَنْتَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَلاَ أَنَا إِلاَّ أَنْ يَتَدَارَكَنِيَ اللَّهُ مِنْهُ بِرَحْمَةٍ ‏"‏ ‏.‏\hadithno{7115}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There is none whose deeds alone can'secure salvation for him. They said: Allah's Messenger, not even you? Thereupon he said: Not even I, but that, the Mercy of Allah should take hold of me}}
\hadithdefcmd{muslim}{7116}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا أَبُو عَبَّادٍ، يَحْيَى بْنُ عَبَّادٍ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، حَدَّثَنَا ابْنُ شِهَابٍ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَنْ يُدْخِلَ أَحَدًا مِنْكُمْ عَمَلُهُ الْجَنَّةَ ‏"‏ ‏.‏ قَالُوا وَلاَ أَنْتَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَلاَ أَنَا إِلاَّ أَنْ يَتَغَمَّدَنِيَ اللَّهُ مِنْهُ بِفَضْلٍ وَرَحْمَةٍ ‏"‏ ‏.‏\hadithno{7116}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:None amongst you can get. into Paradise by virtue of his deeds alone. They said: Allah's Messenger, not even you? Thereupon he said: Not even I, but that Allah should wrap me in His Grace and Mercy}}
\hadithdefcmd{muslim}{7117}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَارِبُوا وَسَدِّدُوا وَاعْلَمُوا أَنَّهُ لَنْ يَنْجُوَ أَحَدٌ مِنْكُمْ بِعَمَلِهِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَلاَ أَنْتَ قَالَ ‏"‏ وَلاَ أَنَا إِلاَّ أَنْ يَتَغَمَّدَنِيَ اللَّهُ بِرَحْمَةٍ مِنْهُ وَفَضْلٍ ‏"‏ ‏.‏\hadithno{7117}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Observe moderation in deeds (and if it is not possible, try to be near moderation) and understand that none amongst you can attain salvation because of his deeds alone. They said: Allah's Messenger, not even you? Thereupon he said: Not even I, but that Allah should wrap me in His Mercy and Grace}}
\hadithdefcmd{muslim}{7118}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{7118}\hadithtrans{This hadith has been narrated on the authority of Jabir through another chain of transmitters}}
\hadithdefcmd{muslim}{7119}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، بِالإِسْنَادَيْنِ جَمِيعًا كَرِوَايَةِ ابْنِ نُمَيْرٍ ‏.‏\hadithno{7119}\hadithtrans{A hadith like this has been narrated on the authority of A'mash through two other chains of transmitters. The wording is, however, the same}}
\hadithdefcmd{muslim}{7120}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ وَزَادَ ‏ "‏ وَأَبْشِرُوا ‏"‏ ‏.‏\hadithno{7120}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters with this addition:" Give them glad tidings}}
\hadithdefcmd{muslim}{7121}{حَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يُدْخِلُ أَحَدًا مِنْكُمْ عَمَلُهُ الْجَنَّةَ وَلاَ يُجِيرُهُ مِنَ النَّارِ وَلاَ أَنَا إِلاَّ بِرَحْمَةٍ مِنَ اللَّهِ ‏"‏ ‏.‏\hadithno{7121}\hadithtrans{Jabir reported:I heard Allah's Apostle (ﷺ) as saying: None of you would get into Paradise because of his good deeds alone, and he would not be rescued from Fire, not even I, but because of the Mercy of Allah}}
\hadithdefcmd{muslim}{7122}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، أَخْبَرَنَا مُوسَى بْنُ، عُقْبَةَ ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا بَهْزٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا مُوسَى، بْنُ عُقْبَةَ قَالَ سَمِعْتُ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، يُحَدِّثُ عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا كَانَتْ تَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَدِّدُوا وَقَارِبُوا وَأَبْشِرُوا فَإِنَّهُ لَنْ يُدْخِلَ الْجَنَّةَ أَحَدًا عَمَلُهُ ‏"‏ ‏.‏ قَالُوا وَلاَ أَنْتَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَلاَ أَنَا إِلاَّ أَنْ يَتَغَمَّدَنِيَ اللَّهُ مِنْهُ بِرَحْمَةٍ وَاعْلَمُوا أَنَّ أَحَبَّ الْعَمَلِ إِلَى اللَّهِ أَدْوَمُهُ وَإِنْ قَلَّ ‏"‏ ‏.‏\hadithno{7122}\hadithtrans{A'isha, the wife of Allah's Apostle (ﷺ), reported that Allah's Messenger (ﷺ) used to say:Observe moderation (in doing deeds), and if you fail to observe it perfectly, try to do as much as you can do (to live up to this ideal of moderation) and be happy for none would be able to get into Paradise because of his deeds alone. They (the Companions of the Holy Prophet) said: Allah's Messenger, not even you? Thereupon he said: Not even I, but that Allah wraps me in His Mercy, and bear this in mind that the deed loved most by Allah is one which is done constantly even though it is small}}
\hadithdefcmd{muslim}{7123}{وَحَدَّثَنَاهُ حَسَنٌ الْحُلْوَانِيُّ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، بْنُ الْمُطَّلِبِ عَنْ مُوسَى بْنِ عُقْبَةَ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ ‏ "‏ وَأَبْشِرُوا ‏"‏ ‏.‏\hadithno{7123}\hadithtrans{This hadith has been narrated on the authority of Musa b. `Uqba with the same chain of transmitters and he did not make a mention of:"Be happy}}
\hadithdefcmd{muslim}{7124}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنِ الْمُغِيرَةِ بْنِ، شُعْبَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى حَتَّى انْتَفَخَتْ قَدَمَاهُ فَقِيلَ لَهُ أَتَكَلَّفُ هَذَا وَقَدْ غَفَرَ اللَّهُ لَكَ مَا تَقَدَّمَ مِنْ ذَنْبِكَ وَمَا تَأَخَّرَ فَقَالَ ‏ "‏ أَفَلاَ أَكُونُ عَبْدًا شَكُورًا ‏"‏ ‏.‏\hadithno{7124}\hadithtrans{Mughira b. Shu'ba reported that Allah's Apostle (ﷺ) worshipped so much that his feet were swollen. It was said to him:(Why do you undergo so much hardship despite the fact that) Allah has pardoned for you your earlier and later sins? Thereupon he said: May I not (prove myself) to be a grateful servant (of Allah)?}}
\hadithdefcmd{muslim}{7125}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، سَمِعَ الْمُغِيرَةَ بْنَ شُعْبَةَ، يَقُولُ قَامَ النَّبِيُّ صلى الله عليه وسلم حَتَّى وَرِمَتْ قَدَمَاهُ قَالُوا قَدْ غَفَرَ اللَّهُ لَكَ مَا تَقَدَّمَ مِنْ ذَنْبِكَ وَمَا تَأَخَّرَ ‏.‏ قَالَ ‏ "‏ أَفَلاَ أَكُونُ عَبْدًا شَكُورًا ‏"‏ ‏.‏\hadithno{7125}\hadithtrans{This hadith has been transmitted on the authority of Mughira b. Shu'ba and the words are:Allah's Apostle (ﷺ) kept standing in prayer (for such long hours) that his feet were swollen. They (his Companions) said: Verily, Allah has pardoned for thee the earlier and the later of thine sins. Thereupon he said: Should I not prove myself to be a grateful servant (of Allah)?}}
\hadithdefcmd{muslim}{7126}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، وَهَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي أَبُو صَخْرٍ، عَنِ ابْنِ قُسَيْطٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا صَلَّى قَامَ حَتَّى تَفَطَّرَ رِجْلاَهُ قَالَتْ عَائِشَةُ يَا رَسُولَ اللَّهِ أَتَصْنَعُ هَذَا وَقَدْ غُفِرَ لَكَ مَا تَقَدَّمَ مِنْ ذَنْبِكَ وَمَا تَأَخَّرَ فَقَالَ ‏ "‏ يَا عَائِشَةُ أَفَلاَ أَكُونُ عَبْدًا شَكُورًا ‏"‏ ‏.‏\hadithno{7126}\hadithtrans{A'isha reported that when Allah's Messenger (ﷺ) occupied himself in prayer, he observed such a (long) qiyam (posture of standing in prayer) that his feet were swollen. A'isha said:Allah's Messenger you do this (in spite of the fact) that your earlier and later sins have been pardoned for you? Thereupon, he said. A'isha should I not prove myself to be a thanksgiving servant (of Allah)?}}
\hadithdefcmd{muslim}{7127}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، وَأَبُو مُعَاوِيَةَ ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، قَالَ كُنَّا جُلُوسًا عِنْدَ بَابِ عَبْدِ اللَّهِ نَنْتَظِرُهُ فَمَرَّ بِنَا يَزِيدُ بْنُ مُعَاوِيَةَ النَّخَعِيُّ فَقُلْنَا أَعْلِمْهُ بِمَكَانِنَا ‏.‏ فَدَخَلَ عَلَيْهِ فَلَمْ يَلْبَثْ أَنْ خَرَجَ عَلَيْنَا عَبْدُ اللَّهِ فَقَالَ إِنِّي أُخْبَرُ بِمَكَانِكُمْ فَمَا يَمْنَعُنِي أَنْ أَخْرُجَ إِلَيْكُمْ إِلاَّ كَرَاهِيَةُ أَنْ أُمِلَّكُمْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَتَخَوَّلُنَا بِالْمَوْعِظَةِ فِي الأَيَّامِ مَخَافَةَ السَّآمَةِ عَلَيْنَا ‏.‏\hadithno{7127}\hadithtrans{Shaqiq reported:We were sitting at the door of Abdullah (b. Mas'ud) waiting for him (to come out and deliver a sermon to us). It was at this time that there happened to pass by us Yazid b. Mu'awiya an-Nakha'i. We said: Inform him ('Abdullah b. Mas'ud) of our presence here. He went in and Abdullah b. Mas'ud lost no time in coming out to us and said: I was informed of your presence here but nothing hindered me to come out to you but the fact that I did not like to bore you (by stuffing your minds with sermons) as Allah's Messenger (ﷺ) did not deliver us sermon on certain days fearing that it might prove to be boring for us}}
\hadithdefcmd{muslim}{7128}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا ابْنُ إِدْرِيسَ، ح وَحَدَّثَنَا مِنْجَابُ بْنُ الْحَارِثِ التَّمِيمِيُّ، حَدَّثَنَا ابْنُ مُسْهِرٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ خَشْرَمٍ، قَالاَ أَخْبَرَنَا عِيسَى، بْنُ يُونُسَ ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، كُلُّهُمْ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ ‏.‏ وَزَادَ مِنْجَابٌ فِي رِوَايَتِهِ عَنِ ابْنِ مُسْهِرٍ قَالَ الأَعْمَشُ وَحَدَّثَنِي عَمْرُو بْنُ مُرَّةَ عَنْ شَقِيقٍ عَنْ عَبْدِ اللَّهِ مِثْلَهُ ‏.‏\hadithno{7128}\hadithtrans{This hadith has been narrated on the authority of 'Abdullah through other chains of transmitters}}
\hadithdefcmd{muslim}{7129}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا فُضَيْلُ بْنُ عِيَاضٍ، عَنْ مَنْصُورٍ، عَنْ شَقِيقٍ أَبِي وَائِلٍ، قَالَ كَانَ عَبْدُ اللَّهِ يُذَكِّرُنَا كُلَّ يَوْمِ خَمِيسٍ فَقَالَ لَهُ رَجُلٌ يَا أَبَا عَبْدِ الرَّحْمَنِ إِنَّا نُحِبُّ حَدِيثَكَ وَنَشْتَهِيهِ وَلَوَدِدْنَا أَنَّكَ حَدَّثْتَنَا كُلَّ يَوْمٍ ‏.‏ فَقَالَ مَا يَمْنَعُنِي أَنْ أُحَدِّثَكُمْ إِلاَّ كَرَاهِيَةُ أَنْ أُمِلَّكُمْ ‏.‏ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَتَخَوَّلُنَا بِالْمَوْعِظَةِ فِي الأَيَّامِ كَرَاهِيَةَ السَّآمَةِ عَلَيْنَا ‏.‏\hadithno{7129}\hadithtrans{Shaqiq b. Wi'il reported that 'Abdullah used to give us sermon on every Thursday. A person said:Abu 'Abd al-Rahman, we love your talk and so we yearn (to listen to you) and earnestly desire that you should deliver us lecture every day. Thereupon he said: There is nothing to hinder me in giving you talk (every day) but the fact that you may be bored. Allah's Messenger (ﷺ) did not deliver sermons on certain days (fearing that we might be bored)}}
