% Auto-generated chapter 9 for muslim
% Hadiths in this chapter: 19

\hadithdefcmd{muslim}{2070}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، أَنَّهُ سَمِعَ عَبَّادَ بْنَ تَمِيمٍ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ زَيْدٍ الْمَازِنِيَّ، يَقُولُ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْمُصَلَّى فَاسْتَسْقَى وَحَوَّلَ رِدَاءَهُ حِينَ اسْتَقْبَلَ الْقِبْلَةَ ‏.‏\hadithno{2070}\hadithtrans{Abdullah b. Zaid b. Mazini reported:The Messenger of Allah (ﷺ) went to the place of prayer and prayed for rain and turned round his mantle while facing the Qibla}}
\hadithdefcmd{muslim}{2071}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَمِّهِ، قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم إِلَى الْمُصَلَّى فَاسْتَسْقَى وَاسْتَقْبَلَ الْقِبْلَةَ وَقَلَبَ رِدَاءَهُ وَصَلَّى رَكْعَتَيْنِ ‏.‏\hadithno{2071}\hadithtrans{Ibn Tamim narrated on the authority of his uncle ('Abdullah b. Zaid) that the Messenger of Allah (ﷺ) went out to the place of prayer and prayed for rain and faced towards Qibla, and turned round his mantle and prayed two rak'ahs}}
\hadithdefcmd{muslim}{2072}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ أَخْبَرَنِي أَبُو بَكْرِ بْنُ مُحَمَّدِ بْنِ عَمْرٍو، أَنَّ عَبَّادَ بْنَ تَمِيمٍ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ زَيْدٍ الأَنْصَارِيَّ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ إِلَى الْمُصَلَّى يَسْتَسْقِي وَأَنَّهُ لَمَّا أَرَادَ أَنْ يَدْعُوَ اسْتَقْبَلَ الْقِبْلَةَ وَحَوَّلَ رِدَاءَهُ ‏.‏\hadithno{2072}\hadithtrans{Abdullah b. Zaid al-Ansari reported that the Messenger of Allah (ﷺ) went out to the place of prayer in order to offer prayer for rainfall. And when he intended to make supplication he faced Qibla and turned round his mantle}}
\hadithdefcmd{muslim}{2073}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ، شِهَابٍ قَالَ أَخْبَرَنِي عَبَّادُ بْنُ تَمِيمٍ الْمَازِنِيُّ، أَنَّهُ سَمِعَ عَمَّهُ، وَكَانَ، مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا يَسْتَسْقِي فَجَعَلَ إِلَى النَّاسِ ظَهْرَهُ يَدْعُو اللَّهَ وَاسْتَقْبَلَ الْقِبْلَةَ وَحَوَّلَ رِدَاءَهُ ثُمَّ صَلَّى رَكْعَتَيْنِ ‏.‏\hadithno{2073}\hadithtrans{Abbad b. Tamim Mazini heard his uncle, who was one of the Companions of the Messenger of Allah (ﷺ), as saying:The Messenger of Allah (ﷺ) went out one day in order to pray for rain. He turned his back towards people, supplicated before Allah, facing towards Qibla, and turned his mantle round and then observed two rak'ahs of prayer}}
\hadithdefcmd{muslim}{2074}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، عَنْ شُعْبَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَرْفَعُ يَدَيْهِ فِي الدُّعَاءِ حَتَّى يُرَى بَيَاضُ إِبْطَيْهِ ‏.‏\hadithno{2074}\hadithtrans{Anas reported:I saw the Messenger of Allah (ﷺ) raising his hands (high enough) in supplication (for rain) that the whiteness of his armpits became visible}}
\hadithdefcmd{muslim}{2075}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اسْتَسْقَى فَأَشَارَ بِظَهْرِ كَفَّيْهِ إِلَى السَّمَاءِ\hadithno{2075}\hadithtrans{Anas b. Malik reported that the Messenger of Allah (ﷺ) prayed for rain pointing the back of his hands to the sky}}
\hadithdefcmd{muslim}{2076}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، وَعَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ لاَ يَرْفَعُ يَدَيْهِ فِي شَىْءٍ مِنْ دُعَائِهِ إِلاَّ فِي الاِسْتِسْقَاءِ حَتَّى يُرَى بَيَاضُ إِبْطَيْهِ ‏.‏ غَيْرَ أَنَّ عَبْدَ الأَعْلَى قَالَ يُرَى بَيَاضُ إِبْطِهِ أَوْ بَيَاضُ إِبْطَيْهِ ‏.‏\hadithno{2076}\hadithtrans{Anas reported that the Messenger of Allah (ﷺ) was not accustomed to raice his hands in any supplication he made except when praying for rain. (He would then raise [his hands] high enough) that the whiteness of his armpits became visible. 'Abd al-A'la said that (he was in doubt whether it was) the whiteness of his armpit or armpits}}
\hadithdefcmd{muslim}{2077}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، أَنَّحَدَّثَهُمْ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2077}\hadithtrans{This hadith has been narrated by Anas b. Malik through another chain of transmitters}}
\hadithdefcmd{muslim}{2078}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ شَرِيكِ بْنِ أَبِي نَمِرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّجُمُعَةٍ مِنْ بَابٍ كَانَ نَحْوَ دَارِ الْقَضَاءِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ يَخْطُبُ فَاسْتَقْبَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم قَائِمًا ثُمَّ قَالَ يَا رَسُولَ اللَّهِ هَلَكَتِ الأَمْوَالُ وَانْقَطَعَتِ السُّبُلُ فَادْعُ اللَّهِ يُغِثْنَا ‏.‏ قَالَ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ أَغِثْنَا اللَّهُمَّ أَغِثْنَا اللَّهُمَّ أَغِثْنَا ‏"‏ ‏.‏ قَالَ أَنَسٌ وَلاَ وَاللَّهِ مَا نَرَى فِي السَّمَاءِ مِنْ سَحَابٍ وَلاَ قَزَعَةٍ وَمَا بَيْنَنَا وَبَيْنَ سَلْعٍ مِنْ بَيْتٍ وَلاَ دَارٍ - قَالَ - فَطَلَعَتْ مِنْ وَرَائِهِ سَحَابَةٌ مِثْلُ التُّرْسِ فَلَمَّا تَوَسَّطَتِ السَّمَاءَ انْتَشَرَتْ ثُمَّ أَمْطَرَتْ - قَالَ - فَلاَ وَاللَّهِ مَا رَأَيْنَا الشَّمْسَ سَبْتًا - قَالَ - ثُمَّ دَخَلَ رَجُلٌ مِنْ ذَلِكَ الْبَابِ فِي الْجُمُعَةِ الْمُقْبِلَةِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ يَخْطُبُ فَاسْتَقْبَلَهُ قَائِمًا فَقَالَ يَا رَسُولَ اللَّهِ هَلَكَتِ الأَمْوَالُ وَانْقَطَعَتِ السُّبُلُ فَادْعُ اللَّهَ يُمْسِكْهَا عَنَّا - قَالَ - فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَيْهِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ حَوْلَنَا وَلاَ عَلَيْنَا اللَّهُمَّ عَلَى الآكَامِ وَالظِّرَابِ وَبُطُونِ الأَوْدِيَةِ وَمَنَابِتِ الشَّجَرِ ‏"‏ ‏.‏ فَانْقَلَعَتْ وَخَرَجْنَا نَمْشِي فِي الشَّمْسِ ‏.‏ قَالَ شَرِيكٌ فَسَأَلْتُ أَنَسَ بْنَ مَالِكٍ أَهُوَ الرَّجُلُ الأَوَّلُ قَالَ لاَ أَدْرِي ‏.‏\hadithno{2078}\hadithtrans{Anas b. Malik reported that a person entered the mosque through the door situated on theside of Daral-Qada' during Friday (prayer) and the messenger of Allah (ﷺ) was delivering the sermon while standing. He came and stood in front of the Messenger of Allah (ﷺ) and said:Messenger of Allah, the camels died and the passages were blocked; so supplicate Allah to send down rain upon us. The Messenger of Allah (ﷺ) raised his hands and then said: (O Allah, send down rain upon us; O Allah, send dowp rain upon us; O Allah, send down rain upon us. Anas said: By Allah, we did not see any cloud or any patch of it, and there was neither any house or building standing between us and the (hillock) Sal'a. There appeared a cloud in the shape of a shield from behind it, and as it (came high) in the sky it spread and then there was a downpour of rain. By Allah, we did not see the sun throughout the week. Then (that very man) came on the coming Friday through the same door when the Messenger of Allah (ﷺ) was standing and delivering the sermon. He stood in front of him and said: Messenger of Allah, our animals died and the passages blocked. Supplicate Allah to stop the rain for us. The Messenger of Allah (ﷺ) again raised his hands and said: O Allah, let it (rain) fall in our suburbs and not on us, O Allah (send it down) on the hillocks and small mountains and the river-beds and at places where trees grow. The rain stopped, and as we stepped out we were walking in sun- shine. He (the narrator) said to Sharik: I asked Anas b. Malik if he was the same man. He said: I do not know}}
\hadithdefcmd{muslim}{2079}{وَحَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، حَدَّثَنِي إِسْحَاقُ، بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَصَابَتِ النَّاسَ سَنَةٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَخْطُبُ النَّاسَ عَلَى الْمِنْبَرِ يَوْمَ الْجُمُعَةِ إِذْ قَامَ أَعْرَابِيٌّ فَقَالَ يَا رَسُولَ اللَّهِ هَلَكَ الْمَالُ وَجَاعَ الْعِيَالُ ‏.‏ وَسَاقَ الْحَدِيثَ بِمَعْنَاهُ ‏.‏ وَفِيهِ قَالَ ‏ "‏ اللَّهُمَّ حَوَالَيْنَا وَلاَ عَلَيْنَا ‏"‏ ‏.‏ قَالَ فَمَا يُشِيرُ بِيَدِهِ إِلَى نَاحِيَةٍ إِلاَّ تَفَرَّجَتْ حَتَّى رَأَيْتُ الْمَدِينَةَ فِي مِثْلِ الْجَوْبَةِ وَسَالَ وَادِي قَنَاةَ شَهْرًا ‏.‏ وَلَمْ يَجِئْ أَحَدٌ مِنْ نَاحِيَةٍ إِلاَّ أَخْبَرَ بِجَوْدٍ ‏.‏\hadithno{2079}\hadithtrans{Anas b. Malik reported:The people were in the grip of famine during the lifetime of the Messenger of Allah (ﷺ), and (once) as the Messenger of Allah (ﷺ) was delivering the sermon standing on the pulpit on Friday, a bedouin stood up and said: Messenger of Allah, the animals died and the children suffered starvation. The rest of the hadith is the same (and the words are) that he (the Holy Prophet) said: O Allah, send down rain in our suburbs but not on us. He (the narrator) said: To whichever directions he pointed with his hands, the clouds broke up and I saw Medina like the opening of a (courtyard) and the stream of Qanat flowed for one month, and none came from any part (of Arabia) but with the news of heavy rainfall}}
\hadithdefcmd{muslim}{2080}{وَحَدَّثَنِي عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، وَمُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، قَالاَ حَدَّثَنَا مُعْتَمِرٌ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ يَوْمَ الْجُمُعَةِ فَقَامَ إِلَيْهِ النَّاسُ فَصَاحُوا وَقَالُوا يَا نَبِيَّ اللَّهِ قَحِطَ الْمَطَرُ وَاحْمَرَّ الشَّجَرُ وَهَلَكَتِ الْبَهَائِمُ ‏.‏ وَسَاقَ الْحَدِيثَ وَفِيهِ مِنْ رِوَايَةِ عَبْدِ الأَعْلَى فَتَقَشَّعَتْ عَنِ الْمَدِينَةِ ‏.‏ فَجَعَلَتْ\hadithno{2080}\hadithtrans{Anas b. Malik reported that while the Messenger of Allah (ﷺ) was delivering the sermon on Friday, people stood up before him and said in a loud voice:Apostle of Allah, there is a drought and the trees have become yellow, the animals have died; and the rest of the hadith is the same, and in the narration transmitted by 'Abd al-A'la the words are:" The clouds cleard from Medina and it began to rain around it and not a single drop of rain fell in Medina. And as I looked towards Medina, I found it hollow like (the hollowness of) a basin}}
\hadithdefcmd{muslim}{2081}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ سُلَيْمَانَ بْنِ الْمُغِيرَةِ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، بِنَحْوِهِ وَزَادَ فَأَلَّفَ اللَّهُ بَيْنَ السَّحَابِ وَمَكَثْنَا حَتَّى رَأَيْتُ الرَّجُلَ الشَّدِيدَ تُهِمُّهُ نَفْسُهُ أَنْ يَأْتِيَ أَهْلَهُ ‏.‏\hadithno{2081}\hadithtrans{This hadith has been narrated on the authority of Anas but with this addition:" Allah gathered the clouds and as we (were obliged) to stay back I saw that even the strong man, impelled by a desire to go to his family, (could not do so)}}
\hadithdefcmd{muslim}{2082}{وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي أُسَامَةُ، أَنَّ حَفْصَ بْنَ، عُبَيْدِ اللَّهِ بْنِ أَنَسِ بْنِ مَالِكٍ حَدَّثَهُ أَنَّهُ، سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ جَاءَ أَعْرَابِيٌّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ الْجُمُعَةِ وَهُوَ عَلَى الْمِنْبَرِ ‏.‏ وَاقْتَصَّ الْحَدِيثَ وَزَادَ فَرَأَيْتُ السَّحَابَ يَتَمَزَّقُ كَأَنَّهُ الْمُلاَءُ حِينَ تُطْوَى ‏.‏\hadithno{2082}\hadithtrans{Ubaidullah b. Anas b. Malik heard (his father) Anas b. Malik as saying:A bedouin came to the Messenger of Allah (ﷺ) on Friday as he was (delivering the sermon on his) pulpit; and the rest of the hadith is the same but with this addition:" I saw the cloud clearing just as a sheet is folded}}
\hadithdefcmd{muslim}{2083}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسٍ، قَالَ قَالَ أَنَسٌ أَصَابَنَا وَنَحْنُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مَطَرٌ قَالَ فَحَسَرَ رَسُولُ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ ثَوْبَهُ حَتَّى أَصَابَهُ مِنْ الْمَطَرِ فَقُلْنَا يَا رَسُولَ اللَّهِ لِمَ صَنَعْتَ هَذَا قَالَ لِأَنَّهُ حَدِيثُ عَهْدٍ بِرَبِّهِ تَعَالَى\hadithno{2083}\hadithtrans{Anas (b. Malik) reported:It rained upon us as we were with the Messenger of Allah (ﷺ). The Messenger of Allah (way peace be upon him) removed his cloth (from a part of his body) till the rain fell on it. We said: Messenger of Allah, why did you do this? He said: It is because it (the rainfall) has just come from the Exalted Lord}}
\hadithdefcmd{muslim}{2084}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ جَعْفَرٍ، - وَهُوَ ابْنُ مُحَمَّدٍ - عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، أَنَّهُ سَمِعَ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا كَانَ يَوْمُ الرِّيحِ وَالْغَيْمِ عُرِفَ ذَلِكَ فِي وَجْهِهِ أَقْبَلَ وَأَدْبَرَ فَإِذَا مَطَرَتْ سُرَّ بِهِ وَذَهَبَ عَنْهُ ذَلِكَ ‏.‏ قَالَتْ عَائِشَةُ فَسَأَلْتُهُ فَقَالَ ‏"‏ إِنِّي خَشِيتُ أَنْ يَكُونَ عَذَابًا سُلِّطَ عَلَى أُمَّتِي ‏"‏ ‏.‏ وَيَقُولُ إِذَا رَأَى الْمَطَرَ ‏"‏ رَحْمَةٌ‏"‏ ‏.‏\hadithno{2084}\hadithtrans{Ata' b. Abi Rabah reported that he heard 'A'isha, the wife of the Messenger of Allah (way peace be upon him), as saying:When there was on any day windstorm or dark cloud (its effects) could be read on the face of the Messenger of Allah (ﷺ), and he moved forward and backward (in a state of anxiety) ; and when it rained, he was delighted and it (the state of restlessness) disappeared. 'A'isha said: I asked him the reason of this anxiety and he said: I was afraid that it might be a calamity that might fall upon my Ummah, and when he saw rainfall he said: It is the mercy (of Allah)}}
\hadithdefcmd{muslim}{2085}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ سَمِعْتُ ابْنَ جُرَيْجٍ، يُحَدِّثُنَا عَنْ عَطَاءِ، بْنِ أَبِي رَبَاحٍ عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا عَصَفَتِ الرِّيحُ قَالَ ‏"‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ خَيْرَهَا وَخَيْرَ مَا فِيهَا وَخَيْرَ مَا أُرْسِلَتْ بِهِ وَأَعُوذُ بِكَ مِنْ شَرِّهَا وَشَرِّ مَا فِيهَا وَشَرِّ مَا أُرْسِلَتْ بِهِ ‏"‏ ‏.‏ قَالَتْ وَإِذَا تَخَيَّلَتِ السَّمَاءُ تَغَيَّرَ لَوْنُهُ وَخَرَجَ وَدَخَلَ وَأَقْبَلَ وَأَدْبَرَ فَإِذَا مَطَرَتْ سُرِّيَ عَنْهُ فَعَرَفْتُ ذَلِكَ فِي وَجْهِهِ ‏.‏ قَالَتْ عَائِشَةُ فَسَأَلْتُهُ فَقَالَ ‏"‏ لَعَلَّهُ يَا عَائِشَةُ كَمَا قَالَ قَوْمُ عَادٍ ‏\{‏ فَلَمَّا رَأَوْهُ عَارِضًا مُسْتَقْبِلَ أَوْدِيَتِهِمْ قَالُوا هَذَا عَارِضٌ مُمْطِرُنَا‏\}‏ ‏"‏ ‏.‏\hadithno{2085}\hadithtrans{Ata' b. Rabah reported on the authority of 'A'isha, the wife of the Messenger of Allah (way peace be upon him), who said:Whenever the wind was stormy, the Messenger of Allah (ﷺ) used to say: O Allah! I ask Thee for what is good in it, and the good which it contains, and the good of that which it was sent for. I seek refuge with Thee from what is evil in it, what evil it contains, and the evil of that what it was sent for; and when there was a thunder and lightning in the sky, his colour underwent a change, and he went out and in, backwards and forwards; and when the rain came, he felt relieved, and I noticed that (the sign of relief) on his face. 'A'isha asked him (about it) and he said: It may be as the people of 'Ad said: When they saw a cloud formation coming to their valley they said:" It is a cloud which would give us rain" (Qur'an, xlvi)}}
\hadithdefcmd{muslim}{2086}{وَحَدَّثَنِي هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنَا عَمْرُو بْنُ الْحَارِثِ، أَنَّ أَبَا النَّضْرِ، حَدَّثَهُ عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم مُسْتَجْمِعًا ضَاحِكًا حَتَّى أَرَى مِنْهُ لَهَوَاتِهِ إِنَّمَا كَانَ يَتَبَسَّمُ - قَالَتْ- وَكَانَ إِذَا رَأَى غَيْمًا أَوْ رِيحًا عُرِفَ ذَلِكَ فِي وَجْهِهِ ‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ أَرَى النَّاسَ\hadithno{2086}\hadithtrans{A'isha, the wife of the Messenger of Allah (ﷺ), reported:I never saw Allah's Messenger (ﷺ) laugh to such an extent that I could see his uvula-whereas he used to smile only-and when he saw dark clouds or wind, (the signs of fear) were depicted on his face. I said: Messenger of Allah, I find people being happy when they ace the dark cloud in the hope that it would bring rain, but I find that when you see that (the cloud) there is an anxiety on your face. He said: 'A'isha, I am afraid that there may be a calamity in it, for a people was afflicted with wind, when the people saw the calamity they said:" It is a cloud which would give us rain" (Qur'an. xlvi)}}
\hadithdefcmd{muslim}{2087}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ نُصِرْتُ بِالصَّبَا وَأُهْلِكَتْ عَادٌ بِالدَّبُورِ ‏"‏ ‏.‏\hadithno{2087}\hadithtrans{Ibn 'Abbas reported Allah's Messenger (ﷺ) as saying:I have been helped by the east wind and the 'Ad were destroyed by the west wind}}
\hadithdefcmd{muslim}{2088}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ بْنِ مُحَمَّدِ بْنِ أَبَانٍ الْجُعْفِيُّ، حَدَّثَنَا عَبْدَةُ، - يَعْنِي ابْنَ سُلَيْمَانَ - كِلاَهُمَا عَنِ الأَعْمَشِ، عَنْ مَسْعُودِ بْنِ مَالِكٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{2088}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Abbas through another chain of transmitters}}
