% Auto-generated chapter 39 for bukhari
% Hadiths in this chapter: 9

\hadithdefcmd{bukhari}{2290}{وَقَالَ أَبُو الزِّنَادِ عَنْ مُحَمَّدِ بْنِ حَمْزَةَ بْنِ عَمْرٍو الأَسْلَمِيِّ، عَنْ أَبِيهِ، أَنَّ عُمَرَ ـ رضى الله عنه ـ بَعَثَهُ مُصَدِّقًا، فَوَقَعَ رَجُلٌ عَلَى جَارِيَةِ امْرَأَتِهِ، فَأَخَذَ حَمْزَةُ مِنَ الرَّجُلِ كَفِيلاً حَتَّى قَدِمَ عَلَى عُمَرَ، وَكَانَ عُمَرُ قَدْ جَلَدَهُ مِائَةَ جَلْدَةٍ، فَصَدَّقَهُمْ، وَعَذَرَهُ بِالْجَهَالَةِ‏.‏ وَقَالَ جَرِيرٌ وَالأَشْعَثُ لِعَبْدِ اللَّهِ بْنِ مَسْعُودٍ فِي الْمُرْتَدِّينَ اسْتَتِبْهُمْ، وَكَفِّلْهُمْ‏.‏ فَتَابُوا وَكَفَلَهُمْ عَشَائِرُهُمْ‏.‏ وَقَالَ حَمَّادٌ إِذَا تَكَفَّلَ بِنَفْسٍ فَمَاتَ فَلاَ شَىْءَ عَلَيْهِ‏.‏ وَقَالَ الْحَكَمُ يَضْمَنُ‏.‏\hadithno{2290}\hadithtrans{Narrated Muhammad bin 'Amr Al-Aslami that his father Hamza said:'Umar (ra) sent him (i.e. Hamza) as a Sadaqa / Zakat collector. A man had committed illegal sexual intercourse with the slave girl of his wife. Hamza took (personal) sureties for the adulterer till they came to 'Umar. 'Umar had lashed the adulterer one hundred lashes. 'Umar confirmed their claim (that the adulterer had already been punished) and excused him because of being Ignorant. Jarir Al-Ash'ath said to Ibn Mas'ud regarding renegades (i.e., those who became infidels after embracing Islam), "Let them repent and take (personal) sureties for them." They repented and their relatives stood sureties for them. According to Hammad, if somebody stands surety for another person and that person dies, the person giving surety will be released from responsibility. According to Al-Hakam, his responsibilities continues}}
\hadithdefcmd{bukhari}{2291}{قَالَ أَبُو عَبْدِ اللَّهِ وَقَالَ اللَّيْثُ حَدَّثَنِي جَعْفَرُ بْنُ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَّهُ ذَكَرَ رَجُلاً مِنْ بَنِي إِسْرَائِيلَ سَأَلَ بَعْضَ بَنِي إِسْرَائِيلَ أَنْ يُسْلِفَهُ أَلْفَ دِينَارٍ، فَقَالَ ائْتِنِي بِالشُّهَدَاءِ أُشْهِدُهُمْ‏.‏ فَقَالَ كَفَى بِاللَّهِ شَهِيدًا‏.‏ قَالَ فَأْتِنِي بِالْكَفِيلِ‏.‏ قَالَ كَفَى بِاللَّهِ كَفِيلاً‏.‏ قَالَ صَدَقْتَ‏.‏ فَدَفَعَهَا إِلَيْهِ إِلَى أَجَلٍ مُسَمًّى، فَخَرَجَ فِي الْبَحْرِ، فَقَضَى حَاجَتَهُ، ثُمَّ الْتَمَسَ مَرْكَبًا يَرْكَبُهَا، يَقْدَمُ عَلَيْهِ لِلأَجَلِ الَّذِي أَجَّلَهُ، فَلَمْ يَجِدْ مَرْكَبًا، فَأَخَذَ خَشَبَةً، فَنَقَرَهَا فَأَدْخَلَ فِيهَا أَلْفَ دِينَارٍ، وَصَحِيفَةً مِنْهُ إِلَى صَاحِبِهِ، ثُمَّ زَجَّجَ مَوْضِعَهَا، ثُمَّ أَتَى بِهَا إِلَى الْبَحْرِ، فَقَالَ اللَّهُمَّ إِنَّكَ تَعْلَمُ أَنِّي كُنْتُ تَسَلَّفْتُ فُلاَنًا أَلْفَ دِينَارٍ، فَسَأَلَنِي كَفِيلاً، فَقُلْتُ كَفَى بِاللَّهِ كَفِيلاً، فَرَضِيَ بِكَ، وَسَأَلَنِي شَهِيدًا، فَقُلْتُ كَفَى بِاللَّهِ شَهِيدًا، فَرَضِيَ بِكَ، وَأَنِّي جَهَدْتُ أَنْ أَجِدَ مَرْكَبًا، أَبْعَثُ إِلَيْهِ الَّذِي لَهُ فَلَمْ أَقْدِرْ، وَإِنِّي أَسْتَوْدِعُكَهَا‏.‏ فَرَمَى بِهَا فِي الْبَحْرِ حَتَّى وَلَجَتْ فِيهِ، ثُمَّ انْصَرَفَ، وَهْوَ فِي ذَلِكَ يَلْتَمِسُ مَرْكَبًا، يَخْرُجُ إِلَى بَلَدِهِ، فَخَرَجَ الرَّجُلُ الَّذِي كَانَ أَسْلَفَهُ، يَنْظُرُ لَعَلَّ مَرْكَبًا قَدْ جَاءَ بِمَالِهِ، فَإِذَا بِالْخَشَبَةِ الَّتِي فِيهَا الْمَالُ، فَأَخَذَهَا لأَهْلِهِ حَطَبًا، فَلَمَّا نَشَرَهَا وَجَدَ الْمَالَ وَالصَّحِيفَةَ، ثُمَّ قَدِمَ الَّذِي كَانَ أَسْلَفَهُ، فَأَتَى بِالأَلْفِ دِينَارٍ، فَقَالَ وَاللَّهِ مَا زِلْتُ جَاهِدًا فِي طَلَبِ مَرْكَبٍ لآتِيَكَ بِمَالِكَ، فَمَا وَجَدْتُ مَرْكَبًا قَبْلَ الَّذِي أَتَيْتُ فِيهِ‏.‏ قَالَ هَلْ كُنْتَ بَعَثْتَ إِلَىَّ بِشَىْءٍ قَالَ أُخْبِرُكَ أَنِّي لَمْ أَجِدْ مَرْكَبًا قَبْلَ الَّذِي جِئْتُ فِيهِ‏.‏ قَالَ فَإِنَّ اللَّهَ قَدْ أَدَّى عَنْكَ الَّذِي بَعَثْتَ فِي الْخَشَبَةِ فَانْصَرِفْ بِالأَلْفِ الدِّينَارِ رَاشِدًا ‏"‏‏.‏\hadithno{2291}\hadithtrans{Narrated Abu Huraira: The Prophet (ﷺ) said, "An Israeli man asked another Israeli to lend him one thousand Dinars. The second man required witnesses. The former replied, 'Allah is sufficient as a witness.' The second said, 'I want a surety.' The former replied, 'Allah is sufficient as a surety.' The second said, 'You are right,' and lent him the money for a certain period. The debtor went across the sea. When he finished his job, he searched for a conveyance so that he might reach in time for the repayment of the debt, but he could not find any. So, he took a piece of wood and made a hole in it, inserted in it one thousand Dinars and a letter to the lender and then closed (i.e. sealed) the hole tightly. He took the piece of wood to the sea and said. 'O Allah! You know well that I took a loan of one thousand Dinars from so-and-so. He demanded a surety from me but I told him that Allah's Guarantee was sufficient and he accepted Your guarantee. He then asked for a witness and I told him that Allah was sufficient as a Witness, and he accepted You as a Witness. No doubt, I tried hard to find a conveyance so that I could pay his money but could not find, so I hand over this money to You.' Saying that, he threw the piece of wood into the sea till it went out far into it, and then he went away. Meanwhile he started searching for a conveyance in order to reach the creditor's country. One day the lender came out of his house to see whether a ship had arrived bringing his money, and all of a sudden he saw the piece of wood in which his money had been deposited. He took it home to use for fire. When he sawed it, he found his money and the letter inside it. Shortly after that, the debtor came bringing one thousand Dinars to him and said, 'By Allah, I had been trying hard to get a boat so that I could bring you your money, but failed to get one before the one I have come by.' The lender asked, 'Have you sent something to me?' The debtor replied, 'I have told you I could not get a boat other than the one I have come by.' The lender said, 'Allah has delivered on your behalf the money you sent in the piece of wood. So, you may keep your one thousand Dinars and depart guided on the right path}}
\hadithdefcmd{bukhari}{2292}{حَدَّثَنَا الصَّلْتُ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ إِدْرِيسَ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما – ‏\{‏وَلِكُلٍّ جَعَلْنَا مَوَالِيَ‏\}‏ قَالَ وَرَثَةً ‏\{‏وَالَّذِينَ عَقَدَتْ أَيْمَانُكُمْ‏\}‏ قَالَ كَانَ الْمُهَاجِرُونَ لَمَّا قَدِمُوا الْمَدِينَةَ يَرِثُ الْمُهَاجِرُ الأَنْصَارِيَّ دُونَ ذَوِي رَحِمِهِ لِلأُخُوَّةِ الَّتِي آخَى النَّبِيُّ صلى الله عليه وسلم بَيْنَهُمْ، فَلَمَّا نَزَلَتْ ‏\{‏وَلِكُلٍّ جَعَلْنَا مَوَالِيَ‏\}‏ نَسَخَتْ، ثُمَّ قَالَ ‏\{‏وَالَّذِينَ عَقَدَتْ أَيْمَانُكُمْ ‏\}‏ إِلاَّ النَّصْرَ وَالرِّفَادَةَ وَالنَّصِيحَةَ، وَقَدْ ذَهَبَ الْمِيرَاثُ وَيُوصِي لَهُ‏.‏\hadithno{2292}\hadithtrans{Narrated Sa`id bin Jubair:Ibn `Abbas said, "In the verse: To every one We have appointed ' (Muwaliya Muwaliya means one's) heirs (4.33).' (And regarding the verse) 'And those with whom your right hands have made a pledge.' Ibn `Abbas said, "When the emigrants came to the Prophet (ﷺ) in Medina, the emigrant would inherit the Ansari while the latter's relatives would not inherit him because of the bond of brotherhood which the Prophet established between them (i.e. the emigrants and the Ansar). When the verse: 'And to everyone We have appointed heirs' (4.33) was revealed, it canceled (the bond (the pledge) of brotherhood regarding inheritance)." Then he said, "The verse: To those also to whom your right hands have pledged, remained valid regarding cooperation and mutual advice, while the matter of inheritance was excluded and it became permissible to assign something in one's testament to the person who had the right of inheriting before}}
\hadithdefcmd{bukhari}{2293}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَدِمَ عَلَيْنَا عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ فَآخَى رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَهُ وَبَيْنَ سَعْدِ بْنِ الرَّبِيعِ‏.‏\hadithno{2293}\hadithtrans{Narrated Anas:`Abdur-Rahman bin `Auf came to us and Allah's Messenger (ﷺ) established a bond of brotherhood between him and Sa`d bin Rabi`a}}
\hadithdefcmd{bukhari}{2294}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا عَاصِمٌ، قَالَ قُلْتُ لأَنَسٍ رضى الله عنه أَبَلَغَكَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ حِلْفَ فِي الإِسْلاَمِ ‏"‏‏.‏ فَقَالَ قَدْ حَالَفَ النَّبِيُّ صلى الله عليه وسلم بَيْنَ قُرَيْشٍ وَالأَنْصَارِ فِي دَارِي‏.‏\hadithno{2294}\hadithtrans{Narrated `Asim:I heard Anas bin Malik, "Have you ever heard that the Prophet (ﷺ) said, 'There is no alliance in Islam?' " He replied, "The Prophet (ﷺ) made alliance between Quraish and the Ansar in my house}}
\hadithdefcmd{bukhari}{2295}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِجَنَازَةٍ، لِيُصَلِّيَ عَلَيْهَا، فَقَالَ ‏"‏ هَلْ عَلَيْهِ مِنْ دَيْنٍ ‏"‏‏.‏ قَالُوا لاَ‏.‏ فَصَلَّى عَلَيْهِ، ثُمَّ أُتِيَ بِجَنَازَةٍ أُخْرَى، فَقَالَ ‏"‏ هَلْ عَلَيْهِ مَنْ دَيْنٍ ‏"‏‏.‏ قَالُوا نَعَمْ‏.‏ قَالَ ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ ‏"‏‏.‏ قَالَ أَبُو قَتَادَةَ عَلَىَّ دَيْنُهُ يَا رَسُولَ اللَّهِ‏.‏ فَصَلَّى عَلَيْهِ‏.‏\hadithno{2295}\hadithtrans{Narrated Salama bin Al-Akwa`:A dead person was brought to the Prophet (ﷺ) so that he might lead the funeral prayer for him. He asked, "Is he in debt?" When the people replied in the negative, he led the funeral prayer. Another dead person was brought and he asked, "Is he in debt?" They said, "Yes." He (refused to lead the prayer and) said, "Lead the prayer of your friend." Abu Qatada said, "O Allah's Messenger (ﷺ)! I undertake to pay his debt." Allah's Messenger (ﷺ) then led his funeral prayer}}
\hadithdefcmd{bukhari}{2296}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، سَمِعَ مُحَمَّدَ بْنَ عَلِيٍّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهم ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَوْ قَدْ جَاءَ مَالُ الْبَحْرَيْنِ، قَدْ أَعْطَيْتُكَ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏‏.‏ فَلَمْ يَجِئْ مَالُ الْبَحْرَيْنِ حَتَّى قُبِضَ النَّبِيُّ صلى الله عليه وسلم فَلَمَّا جَاءَ مَالُ الْبَحْرَيْنِ أَمَرَ أَبُو بَكْرٍ فَنَادَى مَنْ كَانَ لَهُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم عِدَةٌ أَوْ دَيْنٌ فَلْيَأْتِنَا‏.‏ فَأَتَيْتُهُ، فَقُلْتُ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِي كَذَا وَكَذَا، فَحَثَى لِي حَثْيَةً فَعَدَدْتُهَا فَإِذَا هِيَ خَمْسُمِائَةٍ، وَقَالَ خُذْ مِثْلَيْهَا‏.‏\hadithno{2296}\hadithtrans{Narrated Jabir bin `Abdullah:Once the Prophet (ﷺ) said (to me), "If the money of Bahrain comes, I will give you a certain amount of it." The Prophet (ﷺ) had breathed his last before the money of Bahrain arrived. When the money of Bahrain reached, Abu Bakr announced, "Whoever was promised by the Prophet (ﷺ) should come to us." I went to Abu Bakr and said, "The Prophet (ﷺ) promised me so and so." Abu Bakr gave me a handful of coins and when I counted them, they were five-hundred in number. Abu Bakr then said, "Take twice the amount you have taken (besides)}}
\hadithdefcmd{bukhari}{2297}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ لَمْ أَعْقِلْ أَبَوَىَّ إِلاَّ وَهُمَا يَدِينَانِ الدِّينَ‏.‏ وَقَالَ أَبُو صَالِحٍ حَدَّثَنِي عَبْدُ اللَّهِ عَنْ يُونُسَ عَنِ الزُّهْرِيِّ قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَمْ أَعْقِلْ أَبَوَىَّ قَطُّ، إِلاَّ وَهُمَا يَدِينَانِ الدِّينَ، وَلَمْ يَمُرَّ عَلَيْنَا يَوْمٌ إِلاَّ يَأْتِينَا فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم طَرَفَىِ النَّهَارِ بُكْرَةً وَعَشِيَّةً، فَلَمَّا ابْتُلِيَ الْمُسْلِمُونَ خَرَجَ أَبُو بَكْرٍ مُهَاجِرًا قِبَلَ الْحَبَشَةِ، حَتَّى إِذَا بَلَغَ بَرْكَ الْغِمَادِ لَقِيَهُ ابْنُ الدَّغِنَةِ ـ وَهْوَ سَيِّدُ الْقَارَةِ ـ فَقَالَ أَيْنَ تُرِيدُ يَا أَبَا بَكْرٍ فَقَالَ أَبُو بَكْرٍ أَخْرَجَنِي قَوْمِي فَأَنَا أُرِيدُ أَنْ أَسِيحَ فِي الأَرْضِ فَأَعْبُدَ رَبِّي‏.‏ قَالَ ابْنُ الدَّغِنَةِ إِنَّ مِثْلَكَ لاَ يَخْرُجُ وَلاَ يُخْرَجُ، فَإِنَّكَ تَكْسِبُ الْمَعْدُومَ، وَتَصِلُ الرَّحِمَ، وَتَحْمِلُ الْكَلَّ، وَتَقْرِي الضَّيْفَ، وَتُعِينُ عَلَى نَوَائِبِ الْحَقِّ، وَأَنَا لَكَ جَارٌ فَارْجِعْ فَاعْبُدْ رَبَّكَ بِبِلاَدِكَ‏.‏ فَارْتَحَلَ ابْنُ الدَّغِنَةِ، فَرَجَعَ مَعَ أَبِي بَكْرٍ، فَطَافَ فِي أَشْرَافِ كُفَّارِ قُرَيْشٍ، فَقَالَ لَهُمْ إِنَّ أَبَا بَكْرٍ لاَ يَخْرُجُ مِثْلُهُ، وَلاَ يُخْرَجُ، أَتُخْرِجُونَ رَجُلاً يُكْسِبُ الْمَعْدُومَ، وَيَصِلُ الرَّحِمَ، وَيَحْمِلُ الْكَلَّ، وَيَقْرِي الضَّيْفَ، وَيُعِينُ عَلَى نَوَائِبِ الْحَقِّ‏.‏ فَأَنْفَذَتْ قُرَيْشٌ جِوَارَ ابْنِ الدَّغِنَةِ وَآمَنُوا أَبَا بَكْرٍ وَقَالُوا لاِبْنِ الدَّغِنَةِ مُرْ أَبَا بَكْرٍ فَلْيَعْبُدْ رَبَّهُ فِي دَارِهِ، فَلْيُصَلِّ وَلْيَقْرَأْ مَا شَاءَ، وَلاَ يُؤْذِينَا بِذَلِكَ، وَلاَ يَسْتَعْلِنْ بِهِ، فَإِنَّا قَدْ خَشِينَا أَنْ يَفْتِنَ أَبْنَاءَنَا وَنِسَاءَنَا‏.‏ قَالَ ذَلِكَ ابْنُ الدَّغِنَةِ لأَبِي بَكْرٍ، فَطَفِقَ أَبُو بَكْرٍ يَعْبُدُ رَبَّهُ فِي دَارِهِ، وَلاَ يَسْتَعْلِنُ بِالصَّلاَةِ وَلاَ الْقِرَاءَةِ فِي غَيْرِ دَارِهِ، ثُمَّ بَدَا لأَبِي بَكْرٍ فَابْتَنَى مَسْجِدًا بِفِنَاءِ دَارِهِ، وَبَرَزَ فَكَانَ يُصَلِّي فِيهِ، وَيَقْرَأُ الْقُرْآنَ، فَيَتَقَصَّفُ عَلَيْهِ نِسَاءُ الْمُشْرِكِينَ وَأَبْنَاؤُهُمْ، يَعْجَبُونَ وَيَنْظُرُونَ إِلَيْهِ، وَكَانَ أَبُو بَكْرٍ رَجُلاً بَكَّاءً لاَ يَمْلِكُ دَمْعَهُ حِينَ يَقْرَأُ الْقُرْآنَ، فَأَفْزَعَ ذَلِكَ أَشْرَافَ قُرَيْشٍ مِنَ الْمُشْرِكِينَ، فَأَرْسَلُوا إِلَى ابْنِ الدَّغِنَةِ فَقَدِمَ عَلَيْهِمْ، فَقَالُوا لَهُ إِنَّا كُنَّا أَجَرْنَا أَبَا بَكْرٍ عَلَى أَنْ يَعْبُدَ رَبَّهُ فِي دَارِهِ، وَإِنَّهُ جَاوَزَ ذَلِكَ، فَابْتَنَى مَسْجِدًا بِفِنَاءِ دَارِهِ، وَأَعْلَنَ الصَّلاَةَ وَالْقِرَاءَةَ، وَقَدْ خَشِينَا أَنْ يَفْتِنَ أَبْنَاءَنَا وَنِسَاءَنَا، فَأْتِهِ فَإِنْ أَحَبَّ أَنْ يَقْتَصِرَ عَلَى أَنْ يَعْبُدَ رَبَّهُ فِي دَارِهِ فَعَلَ، وَإِنْ أَبَى إِلاَّ أَنْ يُعْلِنَ ذَلِكَ فَسَلْهُ أَنْ يَرُدَّ إِلَيْكَ ذِمَّتَكَ، فَإِنَّا كَرِهْنَا أَنْ نُخْفِرَكَ، وَلَسْنَا مُقِرِّينَ لأَبِي بَكْرٍ الاِسْتِعْلاَنَ‏.‏ قَالَتْ عَائِشَةُ فَأَتَى ابْنُ الدَّغِنَةِ أَبَا بَكْرٍ، فَقَالَ قَدْ عَلِمْتَ الَّذِي عَقَدْتُ لَكَ عَلَيْهِ، فَإِمَّا أَنْ تَقْتَصِرَ عَلَى ذَلِكَ وَإِمَّا أَنْ تَرُدَّ إِلَىَّ ذِمَّتِي، فَإِنِّي لاَ أُحِبُّ أَنْ تَسْمَعَ الْعَرَبُ أَنِّي أُخْفِرْتُ فِي رَجُلٍ عَقَدْتُ لَهُ‏.‏ قَالَ أَبُو بَكْرٍ إِنِّي أَرُدُّ إِلَيْكَ جِوَارَكَ، وَأَرْضَى بِجِوَارِ اللَّهِ‏.‏ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَئِذٍ بِمَكَّةَ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ أُرِيتُ دَارَ هِجْرَتِكُمْ، رَأَيْتُ سَبْخَةً ذَاتَ نَخْلٍ بَيْنَ لاَبَتَيْنِ ‏"‏‏.‏ وَهُمَا الْحَرَّتَانِ، فَهَاجَرَ مَنْ هَاجَرَ قِبَلَ الْمَدِينَةِ حِينَ ذَكَرَ ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم، وَرَجَعَ إِلَى الْمَدِينَةِ بَعْضُ مَنْ كَانَ هَاجَرَ إِلَى أَرْضِ الْحَبَشَةِ، وَتَجَهَّزَ أَبُو بَكْرٍ مُهَاجِرًا، فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ عَلَى رِسْلِكَ فَإِنِّي أَرْجُو أَنْ يُؤْذَنَ لِي ‏"‏‏.‏ قَالَ أَبُو بَكْرٍ هَلْ تَرْجُو ذَلِكَ بِأَبِي أَنْتَ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ فَحَبَسَ أَبُو بَكْرٍ نَفْسَهُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لِيَصْحَبَهُ وَعَلَفَ رَاحِلَتَيْنِ كَانَتَا عِنْدَهُ وَرَقَ السَّمُرِ أَرْبَعَةَ أَشْهُرٍ‏.‏\hadithno{2297}\hadithtrans{Narrated Aisha:(wife of the Prophet) Since I reached the age when I could remember things, I have seen my parents worshipping according to the right faith of Islam. Not a single day passed but Allah's Messenger (ﷺ) visited us both in the morning and in the evening. When the Muslims were persecuted, Abu Bakr set out for Ethiopia as an emigrant. When he reached a place called Bark-al-Ghimad, he met Ibn Ad-Daghna, the chief of the Qara tribe, who asked Abu Bakr, "Where are you going?" Abu Bakr said, "My people have turned me out of the country and I would like to tour the world and worship my Lord." Ibn Ad- Daghna said, "A man like you will not go out, nor will he be turned out as you help the poor earn their living, keep good relation with your Kith and kin, help the disabled (or the dependents), provide guests with food and shelter, and help people during their troubles. I am your protector. So, go back and worship your Lord at your home." Ibn Ad-Daghna went along with Abu Bakr and took him to the chiefs of Quraish saying to them, "A man like Abu Bakr will not go out, nor will he be turned out. Do you turn out a man who helps the poor earn their living, keeps good relations with Kith and kin, helps the disabled, provides guests with food and shelter, and helps the people during their troubles?" So, Quraish allowed Ibn Ad-Daghna's guarantee of protection and told Abu Bakr that he was secure, and said to Ibn Ad-Daghna, "Advise Abu Bakr to worship his Lord in his house and to pray and read what he likes and not to hurt us and not to do these things publicly, for we fear that our sons and women may follow him." Ibn Ad-Daghna told Abu Bakr of all that, so Abu Bakr continued worshipping his Lord in his house and did not pray or recite Qur'an aloud except in his house. Later on Abu Bakr had an idea of building a mosque in the court yard of his house. He fulfilled that idea and started praying and reciting Qur'an there publicly. The women and the offspring of the pagans started gathering around him and looking at him astonishingly. Abu Bakr was a softhearted person and could not help weeping while reciting Qur'an. This horrified the pagan chiefs of Quraish. They sent for Ibn Ad-Daghna and when he came, they said, "We have given Abu Bakr protection on condition that he will worship his Lord in his house, but he has transgressed that condition and has built a mosque in the court yard of his house and offered his prayer and recited Qur'an in public. We are afraid lest he mislead our women and offspring. So, go to him and tell him that if he wishes he can worship his Lord in his house only, and if not, then tell him to return your pledge of protection as we do not like to betray you by revoking your pledge, nor can we tolerate Abu Bakr's public declaration of Islam (his worshipping). `Aisha added: Ibn Ad-Daghna came to Abu Bakr and said, "You know the conditions on which I gave you protection, so you should either abide by those conditions or revoke my protection, as I do not like to hear the 'Arabs saying that Ibn Ad-Daghna gave the pledge of protection to a person and his people did not respect it." Abu Bakr said, "I revoke your pledge of protection and am satisfied with Allah's protection." At that time Allah's Messenger (ﷺ) was still in Mecca and he said to his companions, "Your place of emigration has been shown to me. I have seen salty land, planted with date-palms and situated between two mountains which are the two ,Harras." So, when the Prophet (ﷺ) told it, some of the companions migrated to Medina, and some of those who had migrated to Ethiopia returned to Medina. When Abu Bakr prepared for emigration, Allah's Messenger (ﷺ) said to him, "Wait, for I expect to be permitted to emigrate." Abu Bakr asked, "May my father be sacrificed for your sake, do you really expect that?" Allah's Messenger (ﷺ) replied in the affirmative. So, Abu Bakr postponed his departure in order to accompany Allah's Messenger (ﷺ) and fed two camels which he had, with the leaves of Samor trees for four months}}
\hadithdefcmd{bukhari}{2298}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُؤْتَى بِالرَّجُلِ الْمُتَوَفَّى عَلَيْهِ الدَّيْنُ فَيَسْأَلُ ‏"‏ هَلْ تَرَكَ لِدَيْنِهِ فَضْلاً ‏"‏‏.‏ فَإِنْ حُدِّثَ أَنَّهُ تَرَكَ لِدَيْنِهِ وَفَاءً صَلَّى، وَإِلاَّ قَالَ لِلْمُسْلِمِينَ ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ ‏"‏‏.‏ فَلَمَّا فَتَحَ اللَّهُ عَلَيْهِ الْفُتُوحَ قَالَ ‏"‏ أَنَا أَوْلَى بِالْمُؤْمِنِينَ مِنْ أَنْفُسِهِمْ، فَمَنْ تُوُفِّيَ مِنَ الْمُؤْمِنِينَ فَتَرَكَ دَيْنًا فَعَلَىَّ قَضَاؤُهُ، وَمَنْ تَرَكَ مَالاً فَلِوَرَثَتِهِ ‏"‏‏.‏\hadithno{2298}\hadithtrans{Narrated Abu Huraira:Whenever a dead man in debt was brought to Allah's Messenger (ﷺ) he would ask, "Has he left anything to repay his debt?" If he was informed that he had left something to repay his debts, he would offer his funeral prayer, otherwise he would tell the Muslims to offer their friend's funeral prayer. When Allah made the Prophet (ﷺ) wealthy through conquests, he said, "I am more rightful than other believers to be the guardian of the believers, so if a Muslim dies while in debt, I am responsible for the repayment of his debt, and whoever leaves wealth (after his death) it will belong to his heirs}}
