% Auto-generated chapter 47 for malik
% Hadiths in this chapter: 18

\hadithdefcmd{malik}{1633}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّ مُعَاذَ بْنَ جَبَلٍ، قَالَ آخِرُ مَا أَوْصَانِي بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ وَضَعْتُ رِجْلِي فِي الْغَرْزِ أَنْ قَالَ ‏ "‏ أَحْسِنْ خُلُقَكَ لِلنَّاسِ يَا مُعَاذُ بْنَ جَبَلٍ ‏"‏ ‏.‏\hadithno{1633}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik that Muadh ibn Jabal said, "The last advice the Messenger of Allah, may Allah bless him and grant him peace, gave me when I put my foot in the stirrup was that he said, 'Make your character good for the people, Muadh ibn Jabal}}
\hadithdefcmd{malik}{1634}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ مَا خُيِّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي أَمْرَيْنِ قَطُّ إِلاَّ أَخَذَ أَيْسَرَهُمَا مَا لَمْ يَكُنْ إِثْمًا فَإِنْ كَانَ إِثْمًا كَانَ أَبْعَدَ النَّاسِ مِنْهُ وَمَا انْتَقَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِنَفْسِهِ إِلاَّ أَنْ تُنْتَهَكَ حُرْمَةُ اللَّهِ فَيَنْتَقِمُ لِلَّهِ بِهَا ‏.‏\hadithno{1634}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Urwa ibn az- Zubayr that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "The Messenger of Allah, may Allah bless him and grant him peace, did not have to choose between two matters, but that he chose the easier of them as long as it was not a wrong action. If it was a wrong action, he was the furthest of people from it. The Messenger of Allah, may Allah bless him and grant him peace, did not take revenge for himself unless the limits of Allah were violated. Then he took revenge for it for Allah}}
\hadithdefcmd{malik}{1635}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَلِيِّ بْنِ حُسَيْنِ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مِنْ حُسْنِ إِسْلاَمِ الْمَرْءِ تَرْكُهُ مَا لاَ يَعْنِيهِ ‏"‏ ‏.‏\hadithno{1635}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Ali ibn Husayn ibn Ali ibn Abi Talib that the Messenger of Allah, may Allah bless him and grant him peace, said, "Part of the excellence of a man's Islam is that he leaves what does not concern him}}
\hadithdefcmd{malik}{1636}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ بَلَغَهُ عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتِ اسْتَأْذَنَ رَجُلٌ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ عَائِشَةُ وَأَنَا مَعَهُ فِي الْبَيْتِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بِئْسَ ابْنُ الْعَشِيرَةِ ‏"‏ ‏.‏ ثُمَّ أَذِنَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَتْ عَائِشَةُ فَلَمْ أَنْشَبْ أَنْ سَمِعْتُ ضَحِكَ رَسُولِ اللَّهِ صلى الله عليه وسلم مَعَهُ فَلَمَّا خَرَجَ الرَّجُلُ قُلْتُ يَا رَسُولَ اللَّهِ قُلْتَ فِيهِ مَا قُلْتَ ثُمَّ لَمْ تَنْشَبْ أَنْ ضَحِكْتَ مَعَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ شَرِّ النَّاسِ مَنِ اتَّقَاهُ النَّاسُ لِشَرِّهِ ‏"‏ ‏.‏\hadithno{1636}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik that he had heard that A'isha, the wife of the Prophet, may Allah bless him and grant him peace, said, "A man asked permission to come in to see the Messenger of Allah, may Allah bless him and grant him peace. I was with him in the house and the Messenger of Allah, may Allah bless him and grant him peace, said, 'He is an evil member of his tribe.' Then the Messenger of Allah, may Allah bless him and grant him peace, gave him permission." A'isha continued, "It was not long before I heard the Messenger of Allah, may Allah bless him and grant him peace, laughing with him. When the man left, I said, 'Messenger of Allah, you said what you said about him, and then before long you were laughing with him.' The Messenger of Allah, may Allah bless him and grant him peace, replied, 'Among the most evil of people is the one whom people are cautious with because of his evil}}
\hadithdefcmd{malik}{1637}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَمِّهِ أَبِي سُهَيْلِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، عَنْ كَعْبِ الأَحْبَارِ، أَنَّهُ قَالَ إِذَا أَحْبَبْتُمْ أَنْ تَعْلَمُوا مَا لِلْعَبْدِ عِنْدَ رَبِّهِ فَانْظُرُوا مَاذَا يَتْبَعُهُ مِنْ حُسْنِ الثَّنَاءِ ‏.‏\hadithno{1637}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik from his paternal uncle, Abu Suhayl ibn Malik from his father that Kab al-Ahbar said, "If you want to know what a slave has with his Lord, then look at whatever good praise follows him}}
\hadithdefcmd{malik}{1638}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ بَلَغَنِي أَنَّ الْمَرْءَ، لَيُدْرِكُ بِحُسْنِ خُلُقِهِ دَرَجَةَ الْقَائِمِ بِاللَّيْلِ الظَّامِي بِالْهَوَاجِرِ ‏.‏\hadithno{1638}\hadithgrade{Salim al-Hilali: Hasan}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said, "I have heard that by his good character a man can reach the degree of the one who stands in prayer at night and the one who is thirsty from fasting in the heat of the day}}
\hadithdefcmd{malik}{1639}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَنَّهُ قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، يَقُولُ أَلاَ أُخْبِرُكُمْ بِخَيْرٍ، مِنْ كَثِيرٍ مِنَ الصَّلاَةِ وَالصَّدَقَةِ قَالُوا بَلَى ‏.‏ قَالَ إِصْلاَحُ ذَاتِ الْبَيْنِ وَإِيَّاكُمْ وَالْبِغْضَةَ فَإِنَّهَا هِيَ الْحَالِقَةُ ‏.‏\hadithno{1639}\hadithgrade{Salim al-Hilali: Maqtu Sahih}\hadithtrans{Yahya related to me from Malik that Yahya ibn Said said that he heard Said ibn al-Musayyab say, "Shall I tell you what is better than much prayer and sadaqa?" They said, "Yes." He said, "Mending discord. And beware of hatred - it strips you (of your deen)}}
\hadithdefcmd{malik}{1640}{وَحَدَّثَنِي عَنْ مَالِكٍ، أَنَّهُ قَدْ بَلَغَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بُعِثْتُ لأُتَمِّمَ حُسْنَ الأَخْلاَقِ ‏"‏ ‏.‏\hadithno{1640}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik that he had heard that the Messenger of Allah, may Allah bless him and grant him peace, said, "I was sent to perfect good character}}
\hadithdefcmd{malik}{1641}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سَلَمَةَ بْنِ صَفْوَانَ بْنِ سَلَمَةَ الزُّرَقِيِّ، عَنْ زَيْدِ بْنِ طَلْحَةَ بْنِ رُكَانَةَ، يَرْفَعُهُ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِكُلِّ دِينٍ خُلُقٌ وَخُلُقُ الإِسْلاَمِ الْحَيَاءُ ‏"‏ ‏.‏\hadithno{1641}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Yahya related to me from Malik from Salama ibn Safwan ibn Salama az-Zuraqi that Zayd ibn Talha ibn Rukana, who attributed it to the Prophet, may Allah bless him and grant him peace, said, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'Every deen has an innate character. The character of Islam is modesty}}
\hadithdefcmd{malik}{1642}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ عَلَى رَجُلٍ وَهُوَ يَعِظُ أَخَاهُ فِي الْحَيَاءِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دَعْهُ فَإِنَّ الْحَيَاءَ مِنَ الإِيمَانِ ‏"‏ ‏.‏\hadithno{1642}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Salim ibn Abdullah from Abdullah ibn Umar that the Messenger of Allah, may Allah bless him and grant him peace, passed by a man who was chiding his brother about modesty. The Messenger of Allah, may Allah bless him and grant him peace, said, "Leave him. Modesty is part of iman}}
\hadithdefcmd{malik}{1643}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّ رَجُلاً، أَتَى إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ عَلِّمْنِي كَلِمَاتٍ أَعِيشُ بِهِنَّ وَلاَ تُكْثِرْ عَلَىَّ فَأَنْسَى ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَغْضَبْ ‏"‏ ‏.‏\hadithno{1643}\hadithgrade{Salim al-Hilali: Sahih Lighairihi}\hadithtrans{Malik related to me from Ibn Shihab from Humayd ibn Abd ar-Rahman ibn Awf that a man came to the Messenger of Allah, may Allah bless him and grant him peace, and said, "Messenger of Allah, teach me some words which I can live by. Do not make them too much for me, lest I forget." The Messenger of Allah, may Allah bless him and grant him peace, said, "Do not be angry}}
\hadithdefcmd{malik}{1644}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ الشَّدِيدُ بِالصُّرَعَةِ إِنَّمَا الشَّدِيدُ الَّذِي يَمْلِكُ نَفْسَهُ عِنْدَ الْغَضَبِ ‏"‏ ‏.‏\hadithno{1644}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Said ibn al- Musayyab from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "A strong person is not the person who throws his adversaries to the ground. A strong person is the person who contains himself when he is angry}}
\hadithdefcmd{malik}{1645}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لِمُسْلِمٍ أَنْ يُهَاجِرَ أَخَاهُ فَوْقَ ثَلاَثِ لَيَالٍ يَلْتَقِيَانِ فَيُعْرِضُ هَذَا وَيُعْرِضُ هَذَا وَخَيْرُهُمَا الَّذِي يَبْدَأُ بِالسَّلاَمِ ‏"‏ ‏.‏\hadithno{1645}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Ata ibn Yazid al-Laythi from Abu Ayyub al-Ansari that the Messenger of Allah, may Allah bless him and grant him peace, said, "It is not halal for a muslim to shun his brother for more than three nights, that is they meet, and this one turns away and that one turns away. The better of the two is the one who says the greeting first}}
\hadithdefcmd{malik}{1646}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَبَاغَضُوا وَلاَ تَحَاسَدُوا وَلاَ تَدَابَرُوا وَكُونُوا عِبَادَ اللَّهِ إِخْوَانًا وَلاَ يَحِلُّ لِمُسْلِمٍ أَنْ يُهَاجِرَ أَخَاهُ فَوْقَ ثَلاَثِ لَيَالٍ ‏"‏ ‏.‏\hadithno{1646}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Ibn Shihab from Anas ibn Malik that the Messenger of Allah, may Allah bless him and grant him peace, said, "Do not be angry with each other and do not envy each other and do not turn away from each other, and be slaves of Allah, brothers. It is not halal for a muslim to shun his brother for more than three nights}}
\hadithdefcmd{malik}{1647}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِيَّاكُمْ وَالظَّنَّ فَإِنَّ الظَّنَّ أَكْذَبُ الْحَدِيثِ وَلاَ تَجَسَّسُوا وَلاَ تَحَسَّسُوا وَلاَ تَنَافَسُوا وَلاَ تَحَاسَدُوا وَلاَ تَبَاغَضُوا وَلاَ تَدَابَرُوا وَكُونُوا عِبَادَ اللَّهِ إِخْوَانًا ‏"‏ ‏.‏\hadithno{1647}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Abu'z-Zinad from al-Araj from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "Beware of suspicion. Suspicion is the most untrue speech. Do not spy and do not eavesdrop. Do not compete with each other and do not envy each other and do not hate each other and do not shun each other. Be slaves of Allah, brothers}}
\hadithdefcmd{malik}{1648}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ عَطَاءِ بْنِ أَبِي مُسْلِمٍ عَبْدِ اللَّهِ الْخُرَاسَانِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَصَافَحُوا يَذْهَبِ الْغِلُّ وَتَهَادَوْا تَحَابُّوا وَتَذْهَبِ الشَّحْنَاءُ ‏"‏ ‏.‏\hadithno{1648}\hadithgrade{Salim al-Hilali: Daif}\hadithtrans{Yahya related to me from Malik from Ata ibn Abi Muslim that Abdullah al-Khurasani said, "The Messenger of Allah, may Allah bless him and grant him peace, said, 'Shake hands and rancour will disappear. Give presents to each other and love each other and enmity will disappear}}
\hadithdefcmd{malik}{1649}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تُفْتَحُ أَبْوَابُ الْجَنَّةِ يَوْمَ الاِثْنَيْنِ وَيَوْمَ الْخَمِيسِ فَيُغْفَرُ لِكُلِّ عَبْدٍ مُسْلِمٍ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا إِلاَّ رَجُلاً كَانَتْ بَيْنَهُ وَبَيْنَ أَخِيهِ شَحْنَاءُ فَيُقَالُ أَنْظِرُوا هَذَيْنِ حَتَّى يَصْطَلِحَا أَنْظِرُوا هَذَيْنِ حَتَّى يَصْطَلِحَا ‏"‏ ‏.‏\hadithno{1649}\hadithgrade{Salim al-Hilali: Sahih}\hadithtrans{Yahya related to me from Malik from Suhayl ibn Abi Salih from his father from Abu Hurayra that the Messenger of Allah, may Allah bless him and grant him peace, said, "The doors of the Garden are opened on Monday and Thursday. Every muslim slave who does not associate anything with Allah is forgiven except for the man who has enmity between him and his brother. It is said, 'Leave these two until they have made a reconciliation. Leave these two until they have made a reconciliation}}
\hadithdefcmd{malik}{1650}{وَحَدَّثَنِي عَنْ مَالِكٍ، عَنْ مُسْلِمِ بْنِ أَبِي مَرْيَمَ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ تُعْرَضُ أَعْمَالُ النَّاسِ كُلَّ جُمُعَةٍ مَرَّتَيْنِ يَوْمَ الاِثْنَيْنِ وَيَوْمَ الْخَمِيسِ فَيُغْفَرُ لِكُلِّ عَبْدٍ مُؤْمِنٍ إِلاَّ عَبْدًا كَانَتْ بَيْنَهُ وَبَيْنَ أَخِيهِ شَحْنَاءُ فَيُقَالُ اتْرُكُوا هَذَيْنِ حَتَّى يَفِيئَا ‏.‏ أَوِ ارْكُوا هَذَيْنِ حَتَّى يَفِيئَا ‏.‏\hadithno{1650}\hadithgrade{Salim al-Hilali: Mauquf Sahih}\hadithtrans{Yahya related to me from Malik from Muslim ibn Abi Maryam from Abu Salih as-Samman that Abu Hurayra said, "The actions of people are presented twice each week, on Monday and Thursday. Every trusting slave is forgiven except for a slave who has enmity between him and his brother. It is said, 'Leave these two until they turn in tawba. Leave these two until they turn in tawba}}
