% Auto-generated chapter 74 for bukhari
% Hadiths in this chapter: 65

\hadithdefcmd{bukhari}{5575}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ شَرِبَ الْخَمْرَ فِي الدُّنْيَا، ثُمَّ لَمْ يَتُبْ مِنْهَا، حُرِمَهَا فِي الآخِرَةِ ‏"‏‏.‏\hadithno{5575}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "Whoever drinks alcoholic drinks in the world and does not repent (before dying), will be deprived of it in the Hereafter}}
\hadithdefcmd{bukhari}{5576}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ لَيْلَةَ أُسْرِيَ بِهِ بِإِيلِيَاءَ بِقَدَحَيْنِ مِنْ خَمْرٍ، وَلَبَنٍ فَنَظَرَ إِلَيْهِمَا، ثُمَّ أَخَذَ اللَّبَنَ، فَقَالَ جِبْرِيلُ الْحَمْدُ لِلَّهِ الَّذِي هَدَاكَ لِلْفِطْرَةِ، وَلَوْ أَخَذْتَ الْخَمْرَ غَوَتْ أُمَّتُكَ‏.‏ تَابَعَهُ مَعْمَرٌ وَابْنُ الْهَادِ وَعُثْمَانُ بْنُ عُمَرَ وَالزُّبَيْدِيُّ عَنِ الزُّهْرِيِّ‏.‏\hadithno{5576}\hadithtrans{Narrated Abu Huraira:On the night Allah's Messenger (ﷺ) was taken on a night journey (Miraj) two cups, one containing wine and the other milk, were presented to him at Jerusalem. He looked at it and took the cup of milk. Gabriel said, "Praise be to Allah Who guided you to Al-Fitra (the right path); if you had taken (the cup of) wine, your nation would have gone astray}}
\hadithdefcmd{bukhari}{5577}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ سَمِعْتُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم حَدِيثًا لاَ يُحَدِّثُكُمْ بِهِ غَيْرِي قَالَ ‏ "‏ مِنْ أَشْرَاطِ السَّاعَةِ أَنْ يَظْهَرَ الْجَهْلُ، وَيَقِلَّ الْعِلْمُ، وَيَظْهَرَ الزِّنَا، وَتُشْرَبَ الْخَمْرُ، وَيَقِلَّ الرِّجَالُ، وَيَكْثُرَ النِّسَاءُ، حَتَّى يَكُونَ لِخَمْسِينَ امْرَأَةً قَيِّمُهُنَّ رَجُلٌ وَاحِدٌ ‏"‏‏.‏\hadithno{5577}\hadithtrans{Narrated Anas:I heard from Allah's Messenger (ﷺ) a narration which none other than I will narrate to you. The Prophet, said, "From among the portents of the our are the following: General ignorance (in religious affairs) will prevail, (religious) knowledge will decrease, illegal sexual intercourse will prevail, alcoholic drinks will be drunk (in abundance), men will decrease and women will increase so much so that for every fifty women there will be one man to look after them}}
\hadithdefcmd{bukhari}{5578}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، وَابْنَ الْمُسَيَّبِ، يَقُولاَنِ قَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ يَزْنِي الزَّانِي حِينَ يَزْنِي وَهْوَ مُؤْمِنٌ، وَلاَ يَشْرَبُ الْخَمْرَ حِينَ يَشْرَبُهَا وَهْوَ مُؤْمِنٌ، وَلاَ يَسْرِقُ السَّارِقُ حِينَ يَسْرِقُ وَهْوَ مُؤْمِنٌ ‏"‏‏.‏ قَالَ ابْنُ شِهَابٍ وَأَخْبَرَنِي عَبْدُ الْمَلِكِ بْنُ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ أَنَّ أَبَا بَكْرٍ كَانَ يُحَدِّثُهُ عَنْ أَبِي هُرَيْرَةَ ثُمَّ يَقُولُ كَانَ أَبُو بَكْرٍ يُلْحِقُ مَعَهُنَّ ‏"‏ وَلاَ يَنْتَهِبُ نُهْبَةً ذَاتَ شَرَفٍ، يَرْفَعُ النَّاسُ إِلَيْهِ أَبْصَارَهُمْ فِيهَا حِينَ يَنْتَهِبُهَا وَهْوَ مُؤْمِنٌ ‏"‏‏.‏\hadithno{5578}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "An adulterer, at the time he is committing illegal sexual intercourse is not a believer; and a person, at the time of drinking an alcoholic drink is not a believer; and a thief, at the time of stealing, is not a believer." Ibn Shihab said: `Abdul Malik bin Abi Bakr bin `Abdur-Rahman bin Al- Harith bin Hisham told me that Abu Bakr used to narrate that narration to him on the authority of Abu Huraira. He used to add that Abu Bakr used to mention, besides the above cases, "And he who robs (takes illegally something by force) while the people are looking at him, is not a believer at the time he is robbing (taking)}}
\hadithdefcmd{bukhari}{5579}{حَدَّثَنَا الْحَسَنُ بْنُ صَبَّاحٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سَابِقٍ، حَدَّثَنَا مَالِكٌ ـ هُوَ ابْنُ مِغْوَلٍ ـ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ لَقَدْ حُرِّمَتِ الْخَمْرُ، وَمَا بِالْمَدِينَةِ مِنْهَا شَىْءٌ‏.‏\hadithno{5579}\hadithtrans{Narrated Ibn `Umar:"Alcoholic drinks were prohibited (by Allah) when there was nothing of it (special kind of wine) in Medina}}
\hadithdefcmd{bukhari}{5580}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو شِهَابٍ عَبْدُ رَبِّهِ بْنُ نَافِعٍ، عَنْ يُونُسَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسٍ، قَالَ حُرِّمَتْ عَلَيْنَا الْخَمْرُ حِينَ حُرِّمَتْ وَمَا نَجِدُ ـ يَعْنِي بِالْمَدِينَةِ ـ خَمْرَ الأَعْنَابِ إِلاَّ قَلِيلاً، وَعَامَّةُ خَمْرِنَا الْبُسْرُ وَالتَّمْرُ‏.‏\hadithno{5580}\hadithtrans{Narrated Anas:"Alcoholic drinks were prohibited at the time we could rarely find wine made from grapes in Medina, for most of our liquors were made from unripe and ripe dates}}
\hadithdefcmd{bukhari}{5581}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ أَبِي حَيَّانَ، حَدَّثَنَا عَامِرٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَامَ عُمَرُ عَلَى الْمِنْبَرِ فَقَالَ أَمَّا بَعْدُ نَزَلَ تَحْرِيمُ الْخَمْرِ وَهْىَ مِنْ خَمْسَةٍ الْعِنَبِ وَالتَّمْرِ وَالْعَسَلِ وَالْحِنْطَةِ وَالشَّعِيرِ، وَالْخَمْرُ مَا خَامَرَ الْعَقْلَ‏.‏\hadithno{5581}\hadithtrans{Narrated Ibn `Umar:`Umar stood up on the pulpit and said, "Now then, prohibition of alcoholic drinks have been revealed, and these drinks are prepared from five things, i.e.. grapes, dates, honey, wheat or barley And an alcoholic drink is that, that disturbs the mind}}
\hadithdefcmd{bukhari}{5582}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ كُنْتُ أَسْقِي أَبَا عُبَيْدَةَ وَأَبَا طَلْحَةَ وَأُبَىَّ بْنَ كَعْبٍ مِنْ فَضِيخِ زَهْوٍ وَتَمْرٍ فَجَاءَهُمْ آتٍ فَقَالَ إِنَّ الْخَمْرَ قَدْ حُرِّمَتْ‏.‏ فَقَالَ أَبُو طَلْحَةَ قُمْ يَا أَنَسُ فَأَهْرِقْهَا‏.‏ فَأَهْرَقْتُهَا‏.‏\hadithno{5582}\hadithtrans{Narrated Anas bin Malik:I was serving Abu 'Ubaida, Abu Talha and Ubai bin Ka`b with a drink prepared from ripe and unripe dates. Then somebody came to them and said, "Alcoholic drinks have been prohibited." (On hearing that) Abu Talha said, "Get up. O Anas, and pour (throw) it out! So I poured (threw) it out}}
\hadithdefcmd{bukhari}{5583}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ أَنَسًا، قَالَ كُنْتُ قَائِمًا عَلَى الْحَىِّ أَسْقِيهِمْ ـ عُمُومَتِي وَأَنَا أَصْغَرُهُمُ ـ الْفَضِيخَ، فَقِيلَ حُرِّمَتِ الْخَمْرُ‏.‏ فَقَالُوا أَكْفِئْهَا‏.‏ فَكَفَأْتُهَا‏.‏ قُلْتُ لأَنَسٍ مَا شَرَابُهُمْ قَالَ رُطَبٌ وَبُسْرٌ‏.‏ فَقَالَ أَبُو بَكْرِ بْنُ أَنَسٍ وَكَانَتْ خَمْرَهُمْ‏.‏ فَلَمْ يُنْكِرْ أَنَسٌ‏.‏ وَحَدَّثَنِي بَعْضُ أَصْحَابِي أَنَّهُ سَمِعَ أَنَسًا يَقُولُ كَانَتْ خَمْرَهُمْ يَوْمَئِذٍ‏.‏\hadithno{5583}\hadithtrans{Narrated Anas:While I was waiting on my uncles and serving them with (wine prepared from) dates----and I was the youngest of them----it was said, "Alcoholic drinks have been prohibited." So they said (to me), "Throw it away." So I threw it away}}
\hadithdefcmd{bukhari}{5584}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا يُوسُفُ أَبُو مَعْشَرٍ الْبَرَّاءُ، قَالَ سَمِعْتُ سَعِيدَ بْنَ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي بَكْرُ بْنُ عَبْدِ اللَّهِ، أَنَّ أَنَسَ بْنَ مَالِكٍ، حَدَّثَهُمْ أَنَّ الْخَمْرَ حُرِّمَتْ، وَالْخَمْرُ يَوْمَئِذٍ الْبُسْرُ وَالتَّمْرُ‏.‏\hadithno{5584}\hadithtrans{Narrated Anas bin Malik:Alcoholic drinks were prohibited. At that time these drinks used to be prepared from unripe and ripe dates}}
\hadithdefcmd{bukhari}{5585}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ، قَالَتْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْبِتْعِ فَقَالَ ‏ "‏ كُلُّ شَرَابٍ أَسْكَرَ فَهْوَ حَرَامٌ ‏"‏‏.‏\hadithno{5585}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) was asked about Al-Bit. He said, "All drinks that intoxicate are unlawful (to drink)}}
\hadithdefcmd{bukhari}{5586}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْبِتْعِ وَهْوَ نَبِيذُ الْعَسَلِ، وَكَانَ أَهْلُ الْيَمَنِ يَشْرَبُونَهُ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ شَرَابٍ أَسْكَرَ فَهْوَ حَرَامٌ ‏"‏‏.‏\hadithno{5586}\hadithtrans{Narrated 'Aisha: Allah's Messenger (ﷺ) was asked about Al-Bit a liquor prepared from honey which the Yemenites used to drink. Allah's Messenger (ﷺ) said, "All drinks that intoxicate are unlawful (to drink)}}
\hadithdefcmd{bukhari}{5587}{وَعَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَنْتَبِذُوا فِي الدُّبَّاءِ، وَلاَ فِي الْمُزَفَّتِ ‏"‏‏.‏ وَكَانَ أَبُو هُرَيْرَةَ يُلْحِقُ مَعَهَا الْحَنْتَمَ وَالنَّقِيرَ‏.‏\hadithno{5587}\hadithtrans{Anas bin Malik said: Allah's Messenger (ﷺ) said, "Do not make drinks in Ad-Dubba' nor in Al-Muzaffat. Abu Huraira used to add to them Al-Hantam and An-Naqir}}
\hadithdefcmd{bukhari}{5588}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي رَجَاءٍ، حَدَّثَنَا يَحْيَى، عَنْ أَبِي حَيَّانَ التَّيْمِيِّ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ خَطَبَ عُمَرُ عَلَى مِنْبَرِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّهُ قَدْ نَزَلَ تَحْرِيمُ الْخَمْرِ، وَهْىَ مِنْ خَمْسَةِ أَشْيَاءَ الْعِنَبِ وَالتَّمْرِ وَالْحِنْطَةِ وَالشَّعِيرِ وَالْعَسَلِ، وَالْخَمْرُ مَا خَامَرَ الْعَقْلَ، وَثَلاَثٌ وَدِدْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يُفَارِقْنَا حَتَّى يَعْهَدَ إِلَيْنَا عَهْدًا الْجَدُّ وَالْكَلاَلَةُ وَأَبْوَابٌ مِنْ أَبْوَابِ الرِّبَا‏.‏ قَالَ قُلْتُ يَا أَبَا عَمْرٍو فَشَىْءٌ يُصْنَعُ بِالسِّنْدِ مِنَ الرُّزِّ‏.‏ قَالَ ذَاكَ لَمْ يَكُنْ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم أَوْ قَالَ عَلَى عَهْدِ عُمَرَ‏.‏ وَقَالَ حَجَّاجُ عَنْ حَمَّادٍ عَنْ أَبِي حَيَّانَ مَكَانَ الْعِنَبِ الزَّبِيبَ‏.‏\hadithno{5588}\hadithtrans{Narrated Ibn `Umar:`Umar delivered a sermon on the pulpit of Allah's Messenger (ﷺ), saying, "Alcoholic drinks were prohibited by Divine Order, and these drinks used to be prepared from five things, i.e., grapes, dates, wheat, barley and honey. Alcoholic drink is that, that disturbs the mind." `Umar added, "I wish Allah's Apostle had not left us before he had given us definite verdicts concerning three matters, i.e., how much a grandfather may inherit (of his grandson), the inheritance of Al-Kalala (the deceased person among whose heirs there is no father or son), and various types of Riba(1 ) (usury)}}
\hadithdefcmd{bukhari}{5589}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي السَّفَرِ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، قَالَ الْخَمْرُ يُصْنَعُ مِنْ خَمْسَةٍ مِنَ الزَّبِيبِ وَالتَّمْرِ وَالْحِنْطَةِ وَالشَّعِيرِ وَالْعَسَلِ‏.‏\hadithno{5589}\hadithtrans{Narrated 'Umar: "Alcoholic drinks are prepared from five things, i.e., raisins, dates. wheat, barley and honey}}
\hadithdefcmd{bukhari}{5590}{وَقَالَ هِشَامُ بْنُ عَمَّارٍ حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ بْنِ جَابِرٍ، حَدَّثَنَا عَطِيَّةُ بْنُ قَيْسٍ الْكِلاَبِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ غَنْمٍ الأَشْعَرِيُّ، قَالَ حَدَّثَنِي أَبُو عَامِرٍ ـ أَوْ أَبُو مَالِكٍ ـ الأَشْعَرِيُّ وَاللَّهِ مَا كَذَبَنِي سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَيَكُونَنَّ مِنْ أُمَّتِي أَقْوَامٌ يَسْتَحِلُّونَ الْحِرَ وَالْحَرِيرَ وَالْخَمْرَ وَالْمَعَازِفَ، وَلَيَنْزِلَنَّ أَقْوَامٌ إِلَى جَنْبِ عَلَمٍ يَرُوحُ عَلَيْهِمْ بِسَارِحَةٍ لَهُمْ، يَأْتِيهِمْ ـ يَعْنِي الْفَقِيرَ ـ لِحَاجَةٍ فَيَقُولُوا ارْجِعْ إِلَيْنَا غَدًا‏.‏ فَيُبَيِّتُهُمُ اللَّهُ وَيَضَعُ الْعَلَمَ، وَيَمْسَخُ آخَرِينَ قِرَدَةً وَخَنَازِيرَ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏‏.‏\hadithno{5590}\hadithtrans{Narrated Abu 'Amir or Abu Malik Al-Ash'ari: that he heard the Prophet (ﷺ) saying, "From among my followers there will be some people who will consider illegal sexual intercourse, the wearing of silk, the drinking of alcoholic drinks and the use of musical instruments, as lawful. And there will be some people who will stay near the side of a mountain and in the evening their shepherd will come to them with their sheep and ask them for something, but they will say to him, 'Return to us tomorrow.' Allah will destroy them during the night and will let the mountain fall on them, and He will transform the rest of them into monkeys and pigs and they will remain so till the Day of Resurrection}}
\hadithdefcmd{bukhari}{5591}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي حَازِمٍ، قَالَ سَمِعْتُ سَهْلاً، يَقُولُ أَتَى أَبُو أُسَيْدٍ السَّاعِدِيُّ فَدَعَا رَسُولَ اللَّهِ صلى الله عليه وسلم فِي عُرْسِهِ، فَكَانَتِ امْرَأَتُهُ خَادِمَهُمْ وَهْىَ الْعَرُوسُ‏.‏ قَالَتْ أَتَدْرُونَ مَا سَقَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْقَعْتُ لَهُ تَمَرَاتٍ مِنَ اللَّيْلِ فِي تَوْرٍ‏.‏\hadithno{5591}\hadithtrans{Narrated Sahl:Abu Usaid As-Sa`idi came and invited Allah's Messenger (ﷺ) on the occasion of his wedding. His wife who was the bride, was serving them. Do you know what drink she prepared for Allah's Messenger (ﷺ) ? She had soaked some dates in water in a Tur overnight}}
\hadithdefcmd{bukhari}{5592}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ سَالِمٍ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الظُّرُوفِ فَقَالَتِ الأَنْصَارُ إِنَّهُ لاَ بُدَّ لَنَا مِنْهَا‏.‏ قَالَ ‏ "‏ فَلاَ إِذًا ‏"‏‏.‏ وَقَالَ خَلِيفَةُ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ حَدَّثَنَا سُفْيَانُ عَنْ مَنْصُورٍ عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ عَنْ جَابِرٍ بِهَذَا حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ حَدَّثَنَا سُفْيَانُ بِهَذَا وَقَالَ فِيهِ لَمَّا نَهَى النَّبِيُّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ عَنْ الْأَوْعِيَةِ\hadithno{5592}\hadithtrans{Narrated Jabir:Allah's Messenger (ﷺ) forbade the use of (certain) containers, but the Ansar said, "We cannot dispense with them." The Prophet (ﷺ) then said, "If so, then use them}}
\hadithdefcmd{bukhari}{5593}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ سُلَيْمَانَ بْنِ أَبِي مُسْلِمٍ الأَحْوَلِ، عَنْ مُجَاهِدٍ، عَنْ أَبِي عِيَاضٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ـ رضى الله عنهما ـ قَالَ لَمَّا نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ الأَسْقِيَةِ قِيلَ لِلنَّبِيِّ صلى الله عليه وسلم لَيْسَ كُلُّ النَّاسِ يَجِدُ سِقَاءً فَرَخَّصَ لَهُمْ فِي الْجَرِّ غَيْرِ الْمُزَفَّتِ‏.‏\hadithno{5593}\hadithtrans{Narrated `Abdullah bin `Amr:When the Prophet (ﷺ) forbade the use of certain containers (that were used for preparing alcoholic drinks), somebody said to the Prophet (ﷺ) . "But not all the people can find skins." So he allowed them to use clay jars not covered with pitch}}
\hadithdefcmd{bukhari}{5594}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنِي سُلَيْمَانُ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنِ الْحَارِثِ بْنِ سُوَيْدٍ، عَنْ عَلِيٍّ ـ رضى الله عنه ـ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ الدُّبَّاءِ وَالْمُزَفَّتِ‏.‏ حَدَّثَنَا عُثْمَانُ حَدَّثَنَا جَرِيرٌ عَنِ الأَعْمَشِ بِهَذَا‏.‏\hadithno{5594}\hadithtrans{Narrated `Ali:the Prophet (ﷺ) forbade the use of Ad-Dubba' and Al Muzaffat. A'mash also narrated this}}
\hadithdefcmd{bukhari}{5595}{حَدَّثَنِي عُثْمَانُ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، قُلْتُ لِلأَسْوَدِ هَلْ سَأَلْتَ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ عَمَّا يُكْرَهُ أَنْ يُنْتَبَذَ فِيهِ فَقَالَ نَعَمْ قُلْتُ يَا أُمَّ الْمُؤْمِنِينَ عَمَّا نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ يُنْتَبَذَ فِيهِ قَالَتْ نَهَانَا فِي ذَلِكَ أَهْلَ الْبَيْتِ أَنْ نَنْتَبِذَ فِي الدُّبَّاءِ وَالْمُزَفَّتِ‏.‏ قُلْتُ أَمَا ذَكَرْتِ الْجَرَّ وَالْحَنْتَمَ قَالَ إِنَّمَا أُحَدِّثُكَ مَا سَمِعْتُ، أَفَأُحَدِّثُ مَا لَمْ أَسْمَعْ\hadithno{5595}\hadithtrans{Narrated Ibrahim:I asked Al-Aswad, "Did you ask `Aisha, Mother of the Believers, about the containers in which it is disliked to prepare (non-alcoholic) drinks?" He said, "Yes, I said to her, 'O Mother of the Believers! What containers did the Prophet (ﷺ) forbid to use for preparing (non-alcoholic) drinks?" She said, 'The Prophet forbade us, (his family), to prepare (non-alcoholic) drinks in Ad-Dubba and Al-Muzaffat.' I asked, 'Didn't you mention Al Jar and Al Hantam?' She said, 'I tell what I have heard; shall I tell you what I have not heard?}}
\hadithdefcmd{bukhari}{5596}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا الشَّيْبَانِيُّ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى ـ رضى الله عنهما ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ الْجَرِّ الأَخْضَرِ‏.‏ قُلْتُ أَنَشْرَبُ فِي الأَبْيَضِ قَالَ لاَ‏.‏\hadithno{5596}\hadithtrans{Narrated Ash-Shaibani:I heard `Abdullah bin Abi `Aufa saying, "The Prophet (ﷺ) forbade the use of green jars." I said, "Shall we drink out of white jars?" He said, "No}}
\hadithdefcmd{bukhari}{5597}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ الْقَارِيُّ، عَنْ أَبِي حَازِمٍ، قَالَ سَمِعْتُ سَهْلَ بْنَ سَعْدٍ، أَنَّ أَبَا أُسَيْدٍ السَّاعِدِيَّ، دَعَا النَّبِيَّ صلى الله عليه وسلم لِعُرْسِهِ، فَكَانَتِ امْرَأَتُهُ خَادِمَهُمْ يَوْمَئِذٍ وَهْىَ الْعَرُوسُ‏.‏ فَقَالَتْ مَا تَدْرُونَ مَا أَنْقَعْتُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَنْقَعْتُ لَهُ تَمَرَاتٍ مِنَ اللَّيْلِ فِي تَوْرٍ‏.‏\hadithno{5597}\hadithtrans{Narrated Sahl bin Sa`d:Abu Usaid As Sa`idi invited the Prophet (ﷺ) to his wedding banquet. At that time his wife was serving them and she was the bride. She said, ''Do you know what (kind of syrup) I soaked (made) for Allah's Apostle? I soaked some dates in water in a Tur (bowl) overnight}}
\hadithdefcmd{bukhari}{5598}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي الْجُوَيْرِيَةِ، قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ عَنِ الْبَاذَقِ،‏.‏ فَقَالَ سَبَقَ مُحَمَّدٌ صلى الله عليه وسلم الْبَاذَقَ، فَمَا أَسْكَرَ فَهْوَ حَرَامٌ‏.‏ قَالَ الشَّرَابُ الْحَلاَلُ الطَّيِّبُ‏.‏ قَالَ لَيْسَ بَعْدَ الْحَلاَلِ الطَّيِّبِ إِلاَّ الْحَرَامُ الْخَبِيثُ‏.‏\hadithno{5598}\hadithtrans{Narrated Abu Al-Juwairiyya:I asked Ibn `Abbas about Al-Badhaq. He said, "Muhammad prohibited alcoholic drinks before It was called Al-Badhaq (by saying), 'Any drink that intoxicates is unlawful.' I said, 'What about good lawful drinks?' He said,'Apart from what is lawful and good, all other things are unlawful and not good (unclean Al-Khabith)}}
\hadithdefcmd{bukhari}{5599}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُحِبُّ الْحَلْوَاءَ وَالْعَسَلَ‏.‏\hadithno{5599}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to like sweet edible things and honey}}
\hadithdefcmd{bukhari}{5600}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ إِنِّي لأَسْقِي أَبَا طَلْحَةَ وَأَبَا دُجَانَةَ وَسُهَيْلَ ابْنَ الْبَيْضَاءِ خَلِيطَ بُسْرٍ وَتَمْرٍ إِذْ حُرِّمَتِ الْخَمْرُ، فَقَذَفْتُهَا وَأَنَا سَاقِيهِمْ وَأَصْغَرُهُمْ، وَإِنَّا نَعُدُّهَا يَوْمَئِذٍ الْخَمْرَ‏.‏ وَقَالَ عَمْرُو بْنُ الْحَارِثِ حَدَّثَنَا قَتَادَةُ سَمِعَ أَنَسًا‏.‏\hadithno{5600}\hadithtrans{Narrated Anas:While I was serving Abu Talha. Abu Dujana and Abu Suhail bin Al-Baida' with a drink made from a mixture of unripe and ripe dates, alcoholic drinks, were made unlawful, whereupon I threw it away, and I was their butler and the youngest of them, and we used to consider that drink as an alcoholic drink in those days}}
\hadithdefcmd{bukhari}{5601}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، أَنَّهُ سَمِعَ جَابِرًا ـ رضى الله عنه ـ يَقُولُ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ الزَّبِيبِ وَالتَّمْرِ وَالْبُسْرِ وَالرُّطَبِ‏.‏\hadithno{5601}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) forbade the drinking of alcoholic drinks prepared from raisins, dates, unripe dates and fresh ripe dates}}
\hadithdefcmd{bukhari}{5602}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا هِشَامٌ، أَخْبَرَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ يُجْمَعَ بَيْنَ التَّمْرِ وَالزَّهْوِ، وَالتَّمْرِ وَالزَّبِيبِ، وَلْيُنْبَذْ كُلُّ وَاحِدٍ مِنْهُمَا عَلَى حِدَةٍ‏.‏\hadithno{5602}\hadithtrans{Narrated Abu Qatada:The Prophet (ﷺ) forbade the mixing of ripe and unripe dates and also the mixing of dates and raisins (for preparing a syrup) but the syrup of each kind of fruit should be prepared separately. ( One may have such drinks as long as it is fresh)}}
\hadithdefcmd{bukhari}{5603}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةَ أُسْرِيَ بِهِ بِقَدَحِ لَبَنٍ وَقَدَحِ خَمْرٍ‏.‏\hadithno{5603}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) was presented a bowl of milk and a bowl of wine on the night he was taken on a journey (Al-Mi'raj)}}
\hadithdefcmd{bukhari}{5604}{حَدَّثَنَا الْحُمَيْدِيُّ، سَمِعَ سُفْيَانَ، أَخْبَرَنَا سَالِمٌ أَبُو النَّضْرِ، أَنَّهُ سَمِعَ عُمَيْرًا، مَوْلَى أُمِّ الْفَضْلِ يُحَدِّثُ عَنْ أُمِّ الْفَضْلِ، قَالَتْ شَكَّ النَّاسُ فِي صِيَامِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ عَرَفَةَ، فَأَرْسَلْتُ إِلَيْهِ بِإِنَاءٍ فِيهِ لَبَنٌ فَشَرِبَ‏.‏ فَكَانَ سُفْيَانُ رُبَّمَا قَالَ شَكَّ النَّاسُ فِي صِيَامِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ عَرَفَةَ فَأَرْسَلَتْ إِلَيْهِ أُمُّ الْفَضْلِ‏.‏ فَإِذَا وُقِفَ عَلَيْهِ قَالَ هُوَ عَنْ أُمِّ الْفَضْلِ‏.‏\hadithno{5604}\hadithtrans{Narrated Um Al-Fadl:The people doubted whether Allah's Messenger (ﷺ) was fasting or the Day of `Arafat or not. So I sent a cup containing milk to him and he drank it}}
\hadithdefcmd{bukhari}{5605}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، وَأَبِي، سُفْيَانَ عَنْ جَابِرِ بْنِ عَبْداللَّهِ، قَالَ جَاءَ أَبُو حُمَيْدٍ بِقَدَحٍ مِنْ لَبَنٍ مِنَ النَّقِيعِ، فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَّ خَمَّرْتَهُ وَلَوْ أَنْ تَعْرُضَ عَلَيْهِ عُودًا ‏"‏‏.‏\hadithno{5605}\hadithtrans{Narrated Jabir bin `Abdullah:Abu Humaid brought a cup of mix from a place called Al-Naqi. Allah's Messenger (ﷺ) said to him, "Will you not cover it, even by placing a stick across its}}
\hadithdefcmd{bukhari}{5606}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ سَمِعْتُ أَبَا صَالِحٍ، يَذْكُرُ ـ أُرَاهُ ـ عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ جَاءَ أَبُو حُمَيْدٍ ـ رَجُلٌ مِنَ الأَنْصَارِ ـ مِنَ النَّقِيعِ بِإِنَاءٍ مِنْ لَبَنٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَلاَّ خَمَّرْتَهُ، وَلَوْ أَنْ تَعْرُضَ عَلَيْهِ عُودًا ‏"‏‏.‏ وَحَدَّثَنِي أَبُو سُفْيَانَ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا‏.‏\hadithno{5606}\hadithtrans{Narrated Jabir:Abu Humaid, an Ansari man, came from AnNaqi carrying a cup of milk to the Prophet. The Prophet (ﷺ) said, "Will you not cover it even by placing a stick across it?}}
\hadithdefcmd{bukhari}{5607}{حَدَّثَنِي مَحْمُودٌ، أَخْبَرَنَا النَّضْرُ، أَخْبَرَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ ـ رضى الله عنه ـ قَالَ قَدِمَ النَّبِيُّ صلى الله عليه وسلم مِنْ مَكَّةَ وَأَبُو بَكْرٍ مَعَهُ قَالَ أَبُو بَكْرٍ مَرَرْنَا بِرَاعٍ وَقَدْ عَطِشَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ أَبُو بَكْرٍ ـ رضى الله عنه ـ فَحَلَبْتُ كُثْبَةً مِنْ لَبَنٍ فِي قَدَحٍ، فَشَرِبَ حَتَّى رَضِيتُ، وَأَتَانَا سُرَاقَةُ بْنُ جُعْشُمٍ عَلَى فَرَسٍ فَدَعَا عَلَيْهِ، فَطَلَبَ إِلَيْهِ سُرَاقَةُ أَنْ لاَ يَدْعُوَ عَلَيْهِ، وَأَنْ يَرْجِعَ فَفَعَلَ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{5607}\hadithtrans{Narrated Al-Bara:The Prophet (ﷺ) came from Mecca with Abu Bakr. Abu Bakr said "We passed by a shepherd and at that time Allah's Messenger (ﷺ) was thirsty. I milked a little milk in a bowl and Allah's Messenger (ﷺ) drank till I was pleased. Suraqa bin Ju'shum came to us riding a horse (chasing us). The Prophet (ﷺ) invoked evil upon him, whereupon Suraqa requested him not to invoke evil upon him, in which case he would go back. The Prophet (ﷺ) agreed}}
\hadithdefcmd{bukhari}{5608}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ نِعْمَ الصَّدَقَةُ اللِّقْحَةُ الصَّفِيُّ مِنْحَةً، وَالشَّاةُ الصَّفِيُّ مِنْحَةً، تَغْدُو بِإِنَاءٍ، وَتَرُوحُ بِآخَرَ ‏"‏‏.‏\hadithno{5608}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The best object of charity is a she-camel which has (newly) given birth and gives plenty of milk, or a she-goat which gives plenty of milk; and is given to somebody to utilize its milk by milking one bowl in the morning and one in the evening}}
\hadithdefcmd{bukhari}{5609}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ الأَوْزَاعِيِّ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم شَرِبَ لَبَنًا فَمَضْمَضَ وَقَالَ ‏ "‏ إِنَّ لَهُ دَسَمًا ‏"‏‏.‏\hadithno{5609}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) drank milk and then rinsed his mouth and said, "It contains fat}}
\hadithdefcmd{bukhari}{5610}{وَقَالَ إِبْرَاهِيمُ بْنُ طَهْمَانَ عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رُفِعْتُ إِلَى السِّدْرَةِ فَإِذَا أَرْبَعَةُ أَنْهَارٍ، نَهَرَانِ ظَاهِرَانِ، وَنَهَرَانِ بَاطِنَانِ، فَأَمَّا الظَّاهِرَانِ النِّيلُ وَالْفُرَاتُ، وَأَمَّا الْبَاطِنَانِ فَنَهَرَانِ فِي الْجَنَّةِ فَأُتِيتُ بِثَلاَثَةِ أَقْدَاحٍ، قَدَحٌ فِيهِ لَبَنٌ، وَقَدَحٌ فِيهِ عَسَلٌ، وَقَدَحٌ فِيهِ خَمْرٌ، فَأَخَذْتُ الَّذِي فِيهِ اللَّبَنُ فَشَرِبْتُ فَقِيلَ لِي أَصَبْتَ الْفِطْرَةَ أَنْتَ وَأُمَّتُكَ ‏"‏‏.‏ قَالَ هِشَامٌ وَسَعِيدٌ وَهَمَّامٌ عَنْ قَتَادَةَ عَنْ أَنَسِ بْنِ مَالِكٍ عَنْ مَالِكِ بْنِ صَعْصَعَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الأَنْهَارِ نَحْوَهُ، وَلَمْ يَذْكُرُوا ثَلاَثَةَ أَقْدَاحٍ‏.‏\hadithno{5610}\hadithtrans{The Prophet (ﷺ) added:I was raised to the Lote Tree and saw four rivers, two of which were coming out and two going in. Those which were coming out were the Nile and the Euphrates, and those which were going in were two rivers in paradise. Then I was given three bowls, one containing milk, and another containing honey, and a third containing wine. I took the bowl containing milk and drank it. It was said to me, "You and your followers will be on the right path (of Islam)}}
\hadithdefcmd{bukhari}{5611}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ أَبُو طَلْحَةَ أَكْثَرَ أَنْصَارِيٍّ بِالْمَدِينَةِ مَالاً مِنْ نَخْلٍ، وَكَانَ أَحَبُّ مَالِهِ إِلَيْهِ بَيْرَحَاءَ، وَكَانَتْ مُسْتَقْبِلَ الْمَسْجِدِ، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْخُلُهَا وَيَشْرَبُ مِنْ مَاءٍ فِيهَا طَيِّبٍ‏.‏ قَالَ أَنَسٌ فَلَمَّا نَزَلَتْ ‏\{‏لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ قَامَ أَبُو طَلْحَةَ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ يَقُولُ ‏\{‏لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ وَإِنَّ أَحَبَّ مَالِي إِلَىَّ بَيْرُحَاءَ، وَإِنَّهَا صَدَقَةٌ لِلَّهِ أَرْجُو بِرَّهَا وَذُخْرَهَا عِنْدَ اللَّهِ فَضَعْهَا يَا رَسُولَ اللَّهِ حَيْثُ أَرَاكَ اللَّهُ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَخٍ ذَلِكَ مَالٌ رَابِحٌ ـ أَوْ رَايِحٌ شَكَّ عَبْدُ اللَّهِ ـ وَقَدْ سَمِعْتُ مَا قُلْتَ وَإِنِّي أَرَى أَنْ تَجْعَلَهَا فِي الأَقْرَبِينَ ‏"‏‏.‏ فَقَالَ أَبُو طَلْحَةَ أَفْعَلُ يَا رَسُولَ اللَّهِ، فَقَسَمَهَا أَبُو طَلْحَةَ فِي أَقَارِبِهِ وَفِي بَنِي عَمِّهِ‏.‏ وَقَالَ إِسْمَاعِيلُ وَيَحْيَى بْنُ يَحْيَى رَايِحٌ‏.‏\hadithno{5611}\hadithtrans{Narrated Anas bin Malik:Abu Talha had the largest number of datepalms from amongst the Ansars of Medina. The dearest of his property to him was Bairuha garden which was facing the (Prophet's) Mosque. Allah's Messenger (ﷺ) used to enter it and drink of its good fresh water. When the Holy Verse:-- 'By no means shall you attain righteousness unless you spend (in charity) of that which you love.' (3.92) was revealed, Abu Talha got up and said, "O Allah's Messenger (ﷺ)! Allah says: By no means shall you attain righteousness unless you spend of that which you love,' and the dearest of my property to me is the Bairuha garden and I want to give it in charity in Allah's Cause, seeking to be rewarded by Allah for that. So you can spend it, O Allah's Messenger (ﷺ), where-ever Allah instructs you. ' Allah's Apostle said, "Good! That is a perishable (or profitable) wealth" (`Abdullah is in doubt as to which word was used.) He said, "I have heard what you have said but in my opinion you'd better give it to your kith and kin." On that Abu Talha said, "I will do so, O Allah's Messenger (ﷺ)!" Abu Talha distributed that garden among his kith and kin and cousins}}
\hadithdefcmd{bukhari}{5612}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم شَرِبَ لَبَنًا، وَأَتَى دَارَهُ فَحَلَبْتُ شَاةً فَشُبْتُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْبِئْرِ، فَتَنَاوَلَ الْقَدَحَ فَشَرِبَ، وَعَنْ يَسَارِهِ أَبُو بَكْرٍ وَعَنْ يَمِينِهِ أَعْرَابِيٌّ، فَأَعْطَى الأَعْرَابِيَّ فَضْلَهُ، ثُمَّ قَالَ ‏ "‏ الأَيْمَنَ فَالأَيْمَنَ ‏"‏‏.‏\hadithno{5612}\hadithtrans{Narrated Anas bin Malik:I saw Allah's Messenger (ﷺ) drinking milk. He came to my house and I milked a sheep and then mixed the milk with water from the well for Allah's Messenger (ﷺ). He took the bowl and drank while on his left there was sitting Abu Bakr, and on his right there was a bedouin. He then gave the remaining milk to the bedouin and said, "The right! The right (first)}}
\hadithdefcmd{bukhari}{5613}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ سَعِيدِ بْنِ الْحَارِثِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَى رَجُلٍ مِنَ الأَنْصَارِ وَمَعَهُ صَاحِبٌ لَهُ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنْ كَانَ عِنْدَكَ مَاءٌ بَاتَ هَذِهِ اللَّيْلَةَ فِي شَنَّةٍ، وَإِلاَّ كَرَعْنَا ‏"‏‏.‏ قَالَ وَالرَّجُلُ يُحَوِّلُ الْمَاءَ فِي حَائِطِهِ ـ قَالَ ـ فَقَالَ الرَّجُلُ يَا رَسُولَ اللَّهِ عِنْدِي مَاءٌ بَائِتٌ فَانْطَلِقْ إِلَى الْعَرِيشِ ـ قَالَ ـ فَانْطَلَقَ بِهِمَا، فَسَكَبَ فِي قَدَحٍ، ثُمَّ حَلَبَ عَلَيْهِ مِنْ دَاجِنٍ لَهُ ـ قَالَ ـ فَشَرِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ شَرِبَ الرَّجُلُ الَّذِي جَاءَ مَعَهُ‏.‏\hadithno{5613}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) and one of his companions entered upon an Ansari man and the Prophet (ﷺ) said to him, "If you have water kept overnight in a water skin, (give us), otherwise we will drink water by putting our mouth in it." The man was watering his garden then. He said, "O Allah's Messenger (ﷺ)! I have water kept overnight; let us go to the shade." So he took them both there and poured water into a bowl and milked a domestic goat of his in it. Allah's Messenger (ﷺ) drank, and then the man who had come along with him, drank}}
\hadithdefcmd{bukhari}{5614}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ أَخْبَرَنِي هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُعْجِبُهُ الْحَلْوَاءُ وَالْعَسَلُ‏.‏\hadithno{5614}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to like sweet edible things (syrup, etc.) and honey}}
\hadithdefcmd{bukhari}{5615}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا مِسْعَرٌ، عَنْ عَبْدِ الْمَلِكِ بْنِ مَيْسَرَةَ، عَنِ النَّزَّالِ، قَالَ أَتَى عَلِيٌّ ـ رضى الله عنه ـ عَلَى باب الرَّحَبَةِ، فَشَرِبَ قَائِمًا فَقَالَ إِنَّ نَاسًا يَكْرَهُ أَحَدُهُمْ أَنْ يَشْرَبَ وَهْوَ قَائِمٌ، وَإِنِّي رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم فَعَلَ كَمَا رَأَيْتُمُونِي فَعَلْتُ‏.‏\hadithno{5615}\hadithtrans{Narrated An-Nazzal:Ali came to the gate of the courtyard (of the Mosque) and drank (water) while he was standing and said, "Some people dislike to drink while standing, but I saw the Prophet (ﷺ) doing (drinking water) as you have seen me doing now}}
\hadithdefcmd{bukhari}{5616}{حَدَّثَنَا آدَمُ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ مَيْسَرَةَ، سَمِعْتُ النَّزَّالَ بْنَ سَبْرَةَ، يُحَدِّثُ عَنْ عَلِيٍّ ـ رضى الله عنه ـ أَنَّهُ صَلَّى الظُّهْرَ ثُمَّ قَعَدَ فِي حَوَائِجِ النَّاسِ فِي رَحَبَةِ الْكُوفَةِ حَتَّى حَضَرَتْ صَلاَةُ الْعَصْرِ، ثُمَّ أُتِيَ بِمَاءٍ فَشَرِبَ وَغَسَلَ وَجْهَهُ وَيَدَيْهِ وَذَكَرَ رَأْسَهُ وَرِجْلَيْهِ، ثُمَّ قَامَ فَشَرِبَ فَضْلَهُ وَهْوَ قَائِمٌ ثُمَّ قَالَ إِنَّ نَاسًا يَكْرَهُونَ الشُّرْبَ قَائِمًا وَإِنَّ النَّبِيَّ صلى الله عليه وسلم صَنَعَ مِثْلَ مَا صَنَعْتُ‏.‏\hadithno{5616}\hadithtrans{Narrated An-Nazzal bin Sabra:`Ali offered the Zuhr prayer and then sat down in the wide courtyard (of the Mosque) of Kufa in order to deal with the affairs of the people till the `Asr prayer became due. Then water was brought to him and he drank of it, washed his face, hands, head and feet. Then he stood up and drank the remaining water while he was standing. and said, "Some people dislike to drink water while standing thought the Prophet did as I have just done}}
\hadithdefcmd{bukhari}{5617}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ شَرِبَ النَّبِيُّ صلى الله عليه وسلم قَائِمًا مِنْ زَمْزَمَ‏.‏\hadithno{5617}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) drank Zamzam (water) while standing}}
\hadithdefcmd{bukhari}{5618}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، أَخْبَرَنَا أَبُو النَّضْرِ، عَنْ عُمَيْرٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ أُمِّ الْفَضْلِ بِنْتِ الْحَارِثِ، أَنَّهَا أَرْسَلَتْ إِلَى النَّبِيِّ صلى الله عليه وسلم بِقَدَحِ لَبَنٍ، وَهُوَ وَاقِفٌ عَشِيَّةَ عَرَفَةَ، فَأَخَذَ بِيَدِهِ فَشَرِبَهُ‏.‏ زَادَ مَالِكٌ عَنْ أَبِي النَّضْرِ عَلَى بَعِيرِهِ‏.‏\hadithno{5618}\hadithtrans{Narrated Um Al-Fadl:(daughter of Al-Harith) that she sent a bowl of milk to the Prophet (ﷺ) while he was standing (at `Arafat) in the afternoon of the Day of `Arafat. He took it in his hands and drank it. Narrated Abu Nadr: The Prophet was on the back of his camel}}
\hadithdefcmd{bukhari}{5619}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِلَبَنٍ قَدْ شِيبَ بِمَاءٍ، وَعَنْ يَمِينِهِ أَعْرَابِيٌّ وَعَنْ شِمَالِهِ أَبُو بَكْرٍ، فَشَرِبَ، ثُمَّ أَعْطَى الأَعْرَابِيَّ، وَقَالَ ‏ "‏ الأَيْمَنَ الأَيْمَنَ ‏"‏‏.‏\hadithno{5619}\hadithtrans{Narrated Anas bin Malik:Milk mixed with water was brought to Allah's Messenger (ﷺ) while a bedouin was on his right and Abu Bakr was on his left. He drank (of it) and then gave (it) to the bedouin and said, 'The right" "The right (first)}}
\hadithdefcmd{bukhari}{5620}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي حَازِمِ بْنِ دِينَارٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِشَرَابٍ فَشَرِبَ مِنْهُ، وَعَنْ يَمِينِهِ غُلاَمٌ وَعَنْ يَسَارِهِ الأَشْيَاخُ‏.‏ فَقَالَ لِلْغُلاَمِ ‏ "‏ أَتَأْذَنُ لِي أَنْ أُعْطِيَ هَؤُلاَءِ ‏"‏‏.‏ فَقَالَ الْغُلاَمُ وَاللَّهِ يَا رَسُولَ اللَّهِ لاَ أُوثِرُ بِنَصِيبِي مِنْكَ أَحَدًا‏.‏ قَالَ فَتَلَّهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي يَدِهِ‏.‏\hadithno{5620}\hadithtrans{Narrated Sahl bin Sa`d:Allah's Messenger (ﷺ) was offered something to drink. He drank of it while on his right was a boy and on his left were some elderly people. He said to the boy, "May I give these (elderly) people first?" The boy said, "By Allah, O Allah's Messenger (ﷺ)! I will not give up my share from you to somebody else." On that Allah's Messenger (ﷺ) placed the cup in the hand of that boy}}
\hadithdefcmd{bukhari}{5621}{حَدَّثَنَا يَحْيَى بْنُ صَالِحٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ سَعِيدِ بْنِ الْحَارِثِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَى رَجُلٍ مِنَ الأَنْصَارِ وَمَعَهُ صَاحِبٌ لَهُ، فَسَلَّمَ النَّبِيُّ صلى الله عليه وسلم وَصَاحِبُهُ، فَرَدَّ الرَّجُلُ فَقَالَ يَا رَسُولَ اللَّهِ بِأَبِي أَنْتَ وَأُمِّي‏.‏ وَهْىَ سَاعَةٌ حَارَّةٌ، وَهْوَ يُحَوِّلُ فِي حَائِطٍ لَهُ ـ يَعْنِي الْمَاءَ ـ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنْ كَانَ عِنْدَكَ مَاءٌ بَاتَ فِي شَنَّةٍ وَإِلاَّ كَرَعْنَا ‏"‏‏.‏ وَالرَّجُلُ يُحَوِّلُ الْمَاءَ فِي حَائِطٍ فَقَالَ الرَّجُلُ يَا رَسُولَ اللَّهِ عِنْدِي مَاءٌ بَاتَ فِي شَنَّةٍ‏.‏ فَانْطَلَقَ إِلَى الْعَرِيشِ فَسَكَبَ فِي قَدَحٍ مَاءً، ثُمَّ حَلَبَ عَلَيْهِ مِنْ دَاجِنٍ لَهُ، فَشَرِبَ النَّبِيُّ صلى الله عليه وسلم ثُمَّ أَعَادَ، فَشَرِبَ الرَّجُلُ الَّذِي جَاءَ مَعَهُ‏.‏\hadithno{5621}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) and one of his companions entered upon an Ansari man. The Prophet (ﷺ) and his companion greeted (the man) and he replied, "O Allah's Messenger (ﷺ)! Let my father and mother be sacrificed for you! It is hot," while he was watering his garden. The Prophet (ﷺ) asked him, "If you have water kept overnight in a water skin, (give us), or else we will drink by putting our mouths in the basin." The man was watering the garden The man said, "O Allah's Messenger (ﷺ)! I have water kept overnight in a water-skin. He went to the shade and poured some water into a bowl and milked some milk from a domestic goat in it. The Prophet (ﷺ) drank and then gave the bowl to the man who had come along with him to drink}}
\hadithdefcmd{bukhari}{5622}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ أَنَسًا ـ رضى الله عنه ـ قَالَ كُنْتُ قَائِمًا عَلَى الْحَىِّ أَسْقِيهِمْ ـ عُمُومَتِي وَأَنَا أَصْغَرُهُمُ ـ الْفَضِيخَ، فَقِيلَ حُرِّمَتِ الْخَمْرُ‏.‏ فَقَالَ أَكْفِئْهَا‏.‏ فَكَفَأْنَا‏.‏ قُلْتُ لأَنَسٍ مَا شَرَابُهُمْ قَالَ رُطَبٌ وَبُسْرٌ‏.‏ فَقَالَ أَبُو بَكْرِ بْنُ أَنَسٍ وَكَانَتْ خَمْرَهُمْ‏.‏ فَلَمْ يُنْكِرْ أَنَسٌ‏.‏ وَحَدَّثَنِي بَعْضُ أَصْحَابِي أَنَّهُ سَمِعَ أَنَسًا يَقُولُ كَانَتْ خَمْرَهُمْ يَوْمَئِذٍ‏.‏\hadithno{5622}\hadithtrans{Narrated Anas:I was waiting on my uncles, serving them with an alcoholic drink prepared from dates, and I was the youngest of them. (Suddenly) it was said that alcoholic drinks had been prohibited. So they said (to me), 'Throw it away." And I threw it away The sub-narrator said: I asked Anas what their drink was (made from), He replied, "(From) ripe dates and unripe dates}}
\hadithdefcmd{bukhari}{5623}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَطَاءٌ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ جُنْحُ اللَّيْلِ ـ أَوْ أَمْسَيْتُمْ ـ فَكُفُّوا صِبْيَانَكُمْ، فَإِنَّ الشَّيَاطِينَ تَنْتَشِرُ حِينَئِذٍ، فَإِذَا ذَهَبَ سَاعَةٌ مِنَ اللَّيْلِ فَحُلُّوهُمْ، فَأَغْلِقُوا الأَبْوَابَ وَاذْكُرُوا اسْمَ اللَّهِ، فَإِنَّ الشَّيْطَانَ لاَ يَفْتَحُ بَابًا مُغْلَقًا، وَأَوْكُوا قِرَبَكُمْ وَاذْكُرُوا اسْمَ اللَّهِ، وَخَمِّرُوا آنِيَتَكُمْ وَاذْكُرُوا اسْمَ اللَّهِ، وَلَوْ أَنْ تَعْرُضُوا عَلَيْهَا شَيْئًا وَأَطْفِئُوا، مَصَابِيحَكُمْ ‏"‏‏.‏\hadithno{5623}\hadithtrans{Narrated Jabir bin `Abdullah:Allah's Messenger (ﷺ) said, "When night falls (or when it is evening), stop your children from going out, for the devils spread out at that time. But when an hour of the night has passed, release them and close the doors and mention Allah's Name, for Satan does not open a closed door. Tie the mouth of your waterskin and mention Allah's Name; cover your containers and utensils and mention Allah's Name. Cover them even by placing something across it, and extinguish your lamps}}
\hadithdefcmd{bukhari}{5624}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هَمَّامٌ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَطْفِئُوا الْمَصَابِيحَ إِذَا رَقَدْتُمْ، وَغَلِّقُوا الأَبْوَابَ، وَأَوْكُوا الأَسْقِيَةَ، وَخَمِّرُوا الطَّعَامَ وَالشَّرَابَ ـ وَأَحْسِبُهُ قَالَ ـ وَلَوْ بِعُودٍ تَعْرُضُهُ عَلَيْهِ ‏"‏‏.‏\hadithno{5624}\hadithtrans{Narrated Jabir:Allah's Messenger (ﷺ) said, "Extinguish the lamps when you go to bed; close your doors; tie the mouths of your water skins, and cover the food and drinks." I think he added, ". . . even with a stick you place across the container}}
\hadithdefcmd{bukhari}{5625}{حَدَّثَنَا آدَمُ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ اخْتِنَاثِ الأَسْقِيَةِ‏.‏ يَعْنِي أَنْ تُكْسَرَ أَفْوَاهُهَا فَيُشْرَبَ مِنْهَا‏.‏\hadithno{5625}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) forbade the bending of the mouths of water skins for the sake of drinking from them}}
\hadithdefcmd{bukhari}{5626}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنِ اخْتِنَاثِ الأَسْقِيَةِ‏.‏ قَالَ عَبْدُ اللَّهِ قَالَ مَعْمَرٌ أَوْ غَيْرُهُ هُوَ الشُّرْبُ مِنْ أَفْوَاهِهَا‏.‏\hadithno{5626}\hadithtrans{Narrated Abu Sa`id Al-Khudri:I heard Allah's Messenger (ﷺ) forbidding the drinking of water by bending the mouths of water skins, i.e., drinking from the mouths directly}}
\hadithdefcmd{bukhari}{5627}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَيُّوبُ، قَالَ لَنَا عِكْرِمَةُ أَلاَ أُخْبِرُكُمْ بِأَشْيَاءَ، قِصَارٍ حَدَّثَنَا بِهَا أَبُو هُرَيْرَةَ، نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الشُّرْبِ مِنْ فَمِ الْقِرْبَةِ أَوِ السِّقَاءِ، وَأَنْ يَمْنَعَ جَارَهُ أَنْ يَغْرِزَ خَشَبَهُ فِي دَارِهِ‏.‏\hadithno{5627}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) forbade drinking directly from the mouth of a water skin or other leather containers. and forbade preventing one's neighbor from fixing a peg in (the wall of) one's house}}
\hadithdefcmd{bukhari}{5628}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، أَخْبَرَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ نَهَى النَّبِيُّ صلى الله عليه وسلم أَنْ يُشْرَبَ مِنْ فِي السِّقَاءِ‏.‏\hadithno{5628}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) forbade the drinking of water directly from the mouth of a water skin}}
\hadithdefcmd{bukhari}{5629}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ نَهَى النَّبِيُّ صلى الله عليه وسلم عَنِ الشُّرْبِ مِنْ فِي السِّقَاءِ‏.‏\hadithno{5629}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) forbade the drinking of water direct from the mouth of a water-skin}}
\hadithdefcmd{bukhari}{5630}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا شَرِبَ أَحَدُكُمْ فَلاَ يَتَنَفَّسْ فِي الإِنَاءِ، وَإِذَا بَالَ أَحَدُكُمْ فَلاَ يَمْسَحْ ذَكَرَهُ بِيَمِينِهِ، وَإِذَا تَمَسَّحَ أَحَدُكُمْ فَلاَ يَتَمَسَّحْ بِيَمِينِهِ ‏"‏‏.‏\hadithno{5630}\hadithtrans{Narrated Abu Qatada:Allah's Messenger (ﷺ) said, "When you drink (water), do not breath in the vessel; and when you urinate, do not touch your penis with your right hand. And when you cleanse yourself after defecation, do not use your right hand}}
\hadithdefcmd{bukhari}{5631}{حَدَّثَنَا أَبُو عَاصِمٍ، وَأَبُو نُعَيْمٍ قَالاَ حَدَّثَنَا عَزْرَةُ بْنُ ثَابِتٍ، قَالَ أَخْبَرَنِي ثُمَامَةُ بْنُ عَبْدِ اللَّهِ، قَالَ كَانَ أَنَسٌ يَتَنَفَّسُ فِي الإِنَاءِ مَرَّتَيْنِ أَوْ ثَلاَثًا، وَزَعَمَ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَتَنَفَّسُ ثَلاَثًا‏.‏\hadithno{5631}\hadithtrans{Narrated Thumama bin `Abdullah:Anas used to breathe twice or thrice in the vessel (while drinking) and used to say that the Prophet; used to take three breaths while drinking}}
\hadithdefcmd{bukhari}{5632}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنِ ابْنِ أَبِي لَيْلَى، قَالَ كَانَ حُذَيْفَةُ بِالْمَدَايِنِ فَاسْتَسْقَى، فَأَتَاهُ دِهْقَانٌ بِقَدَحِ فِضَّةٍ، فَرَمَاهُ بِهِ فَقَالَ إِنِّي لَمْ أَرْمِهِ إِلاَّ أَنِّي نَهَيْتُهُ فَلَمْ يَنْتَهِ، وَإِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَانَا عَنِ الْحَرِيرِ وَالدِّيبَاجِ وَالشُّرْبِ فِي آنِيَةِ الذَّهَبِ وَالْفِضَّةِ وَقَالَ ‏ "‏ هُنَّ لَهُمْ فِي الدُّنْيَا وَهْىَ لَكُمْ فِي الآخِرَةِ ‏"‏‏.‏\hadithno{5632}\hadithtrans{Narrated Ibn Abi Laila:While Hudhaita was at Mada'in, he asked for water. The chief of the village brought him a silver vessel. Hudhaifa threw it away and said, "I have thrown it away because I told him not to use it, but he has not stopped using it. The Prophet (ﷺ) forbade us to wear clothes of silk or Dibaj, and to drink in gold or silver utensils, and said, 'These things are for them (unbelievers) in this world and for you (Muslims) in the Hereafter}}
\hadithdefcmd{bukhari}{5633}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ أَبِي لَيْلَى، قَالَ خَرَجْنَا مَعَ حُذَيْفَةَ وَذَكَرَ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَشْرَبُوا فِي آنِيَةِ الذَّهَبِ وَالْفِضَّةِ، وَلاَ تَلْبَسُوا الْحَرِيرَ وَالدِّيبَاجَ، فَإِنَّهَا لَهُمْ فِي الدُّنْيَا وَلَكُمْ فِي الآخِرَةِ ‏"‏‏.‏\hadithno{5633}\hadithtrans{Narrated Hudhaifa:The Prophet (ﷺ) said, "Do not drink in gold or silver utensils, and do not wear clothes of silk or Dibaj, for these things are for them (unbelievers) in this world and for you in the Hereafter}}
\hadithdefcmd{bukhari}{5634}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، عَنْ زَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الَّذِي يَشْرَبُ فِي إِنَاءِ الْفِضَّةِ إِنَّمَا يُجَرْجِرُ فِي بَطْنِهِ نَارَ جَهَنَّمَ ‏"‏‏.‏\hadithno{5634}\hadithtrans{Narrated Um Salama:(the wife of the Prophet) Allah's Messenger (ﷺ) said, "He who drinks in silver utensils is only filling his `Abdomen with Hell Fire}}
\hadithdefcmd{bukhari}{5635}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَشْعَثِ بْنِ سُلَيْمٍ، عَنْ مُعَاوِيَةَ بْنِ سُوَيْدِ بْنِ مُقَرِّنٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَبْعٍ، وَنَهَانَا عَنْ سَبْعٍ، أَمَرَنَا بِعِيَادَةِ الْمَرِيضِ، وَاتِّبَاعِ الْجِنَازَةِ، وَتَشْمِيتِ الْعَاطِسِ، وَإِجَابَةِ الدَّاعِي، وَإِفْشَاءِ السَّلاَمِ، وَنَصْرِ الْمَظْلُومِ وَإِبْرَارِ الْمُقْسِمِ، وَنَهَانَا عَنْ خَوَاتِيمِ الذَّهَبِ، وَعَنِ الشُّرْبِ فِي الْفِضَّةِ ـ أَوْ قَالَ آنِيَةِ الْفِضَّةِ ـ وَعَنِ الْمَيَاثِرِ وَالْقَسِّيِّ، وَعَنْ لُبْسِ الْحَرِيرِ وَالدِّيبَاجِ وَالإِسْتَبْرَقِ‏.‏\hadithno{5635}\hadithtrans{Narrated Al-Bara' bin `Azib:Allah's Messenger (ﷺ) ordered us to do seven things and forbade us from seven. He ordered us to visit the sick, to follow funeral processions, (to say) to a sneezer, (May Allah bestow His Mercy on you, if he says, Praise be to Allah), to accept invitations, to greet (everybody), to help the oppressed and to help others to fulfill their oaths. He forbade us to wear gold rings, to drink in silver (utensils), to use Mayathir (silken carpets placed on saddles), to wear Al-Qissi (a kind of silken cloth), to wear silk, Dibaj or Istabraq (two kinds of silk)}}
\hadithdefcmd{bukhari}{5636}{حَدَّثَنِي عَمْرُو بْنُ عَبَّاسٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ سَالِمٍ أَبِي النَّضْرِ، عَنْ عُمَيْرٍ، مَوْلَى أُمِّ الْفَضْلِ عَنْ أُمِّ الْفَضْلِ، أَنَّهُمْ شَكُّوا فِي صَوْمِ النَّبِيِّ صلى الله عليه وسلم يَوْمَ عَرَفَةَ، فَبُعِثَ إِلَيْهِ بِقَدَحٍ مِنْ لَبَنٍ فَشَرِبَهُ‏.‏\hadithno{5636}\hadithtrans{Narrated Um Al-Fadl:that the people were in doubt whether the Prophet (ﷺ) was fasting on the Day of `Arafat or not, so a (wooden) drinking vessel full of milk was sent to him, and he drank it}}
\hadithdefcmd{bukhari}{5637}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ ـ رضى الله عنه ـ قَالَ ذُكِرَ لِلنَّبِيِّ صلى الله عليه وسلم امْرَأَةٌ مِنَ الْعَرَبِ، فَأَمَرَ أَبَا أُسَيْدٍ السَّاعِدِيَّ أَنْ يُرْسِلَ إِلَيْهَا فَأَرْسَلَ إِلَيْهَا، فَقَدِمَتْ فَنَزَلَتْ فِي أُجُمِ بَنِي سَاعِدَةَ، فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم حَتَّى جَاءَهَا فَدَخَلَ عَلَيْهَا فَإِذَا امْرَأَةٌ مُنَكِّسَةٌ رَأْسَهَا، فَلَمَّا كَلَّمَهَا النَّبِيُّ صلى الله عليه وسلم قَالَتْ أَعُوذُ بِاللَّهِ مِنْكَ‏.‏ فَقَالَ ‏"‏ قَدْ أَعَذْتُكِ مِنِّي ‏"‏‏.‏ فَقَالُوا لَهَا أَتَدْرِينَ مَنْ هَذَا قَالَتْ لاَ‏.‏ قَالُوا هَذَا رَسُولُ اللَّهِ صلى الله عليه وسلم جَاءَ لِيَخْطُبَكِ‏.‏ قَالَتْ كُنْتُ أَنَا أَشْقَى مِنْ ذَلِكَ‏.‏ فَأَقْبَلَ النَّبِيُّ صلى الله عليه وسلم يَوْمَئِذٍ حَتَّى جَلَسَ فِي سَقِيفَةِ بَنِي سَاعِدَةَ هُوَ وَأَصْحَابُهُ، ثُمَّ قَالَ ‏"‏ اسْقِنَا يَا سَهْلُ ‏"‏‏.‏ فَخَرَجْتُ لَهُمْ بِهَذَا الْقَدَحِ فَأَسْقَيْتُهُمْ فِيهِ، فَأَخْرَجَ لَنَا سَهْلٌ ذَلِكَ الْقَدَحَ فَشَرِبْنَا مِنْهُ‏.‏ قَالَ ثُمَّ اسْتَوْهَبَهُ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ بَعْدَ ذَلِكَ فَوَهَبَهُ لَهُ‏.‏\hadithno{5637}\hadithtrans{Narrated Sahl bin Sa`d:An Arab lady was mentioned to the Prophet (ﷺ) so he asked Abu Usaid As-Sa`idi to send for her, and he sent for her and she came and stayed in the castle of Bani Sa`ida. The Prophet (ﷺ) came out and went to her and entered upon her. Behold, it was a lady sitting with a drooping head. When the Prophet (ﷺ) spoke to her, she said, "I seek refuge with Allah from you." He said, "I grant you refuge from me." They said to her, "Do you know who this is?" She said, "No." They said, "This is Allah's Messenger (ﷺ) who has come to command your hand in marriage." She said, "I am very unlucky to lose this chance." Then the Prophet and his companions went towards the shed of Bani Sa`ida and sat there. Then he said, "Give us water, O Sahl!" So I took out this drinking bowl and gave them water in it. The sub-narrator added: Sahl took out for us that very drinking bowl and we all drank from it. Later on `Umar bin `Abdul `Aziz requested Sahl to give it to him as a present, and he gave it to him as a present}}
\hadithdefcmd{bukhari}{5638}{حَدَّثَنَا الْحَسَنُ بْنُ مُدْرِكٍ، قَالَ حَدَّثَنِي يَحْيَى بْنُ حَمَّادٍ، أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، قَالَ رَأَيْتُ قَدَحَ النَّبِيِّ صلى الله عليه وسلم عِنْدَ أَنَسِ بْنِ مَالِكٍ، وَكَانَ قَدِ انْصَدَعَ فَسَلْسَلَهُ بِفِضَّةٍ قَالَ وَهْوَ قَدَحٌ جَيِّدٌ عَرِيضٌ مِنْ نُضَارٍ‏.‏ قَالَ قَالَ أَنَسٌ لَقَدْ سَقَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي هَذَا الْقَدَحِ أَكْثَرَ مِنْ كَذَا وَكَذَا‏.‏ قَالَ وَقَالَ ابْنُ سِيرِينَ إِنَّهُ كَانَ فِيهِ حَلْقَةٌ مِنْ حَدِيدٍ فَأَرَادَ أَنَسٌ أَنْ يَجْعَلَ مَكَانَهَا حَلْقَةً مِنْ ذَهَبٍ أَوْ فِضَّةٍ فَقَالَ لَهُ أَبُو طَلْحَةَ لاَ تُغَيِّرَنَّ شَيْئًا صَنَعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَتَرَكَهُ‏.‏\hadithno{5638}\hadithtrans{Narrated `Asim al-Ahwal:I saw the drinking bowl of the Prophet (ﷺ) with Anas bin Malik, and it had been broken, and he had mended it with silver plates. That drinking bowl was quite wide and made of Nadar wood, Anas said, "I gave water to the Prophet (ﷺ) in that bowl more than so-and-so (for a long period)." Ibn Seereen said: Around that bowl there was an iron ring, and Anas wanted to replace it with a silver or gold ring, but Abu Talha said to him, "Do not change a thing that Allah's Messenger (ﷺ) has made." So Anas left it as it was}}
\hadithdefcmd{bukhari}{5639}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، قَالَ حَدَّثَنِي سَالِمُ بْنُ أَبِي الْجَعْدِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ هَذَا الْحَدِيثَ قَالَ قَدْ رَأَيْتُنِي مَعَ النَّبِيِّ صلى الله عليه وسلم وَقَدْ حَضَرَتِ الْعَصْرُ وَلَيْسَ مَعَنَا مَاءٌ غَيْرَ فَضْلَةٍ فَجُعِلَ فِي إِنَاءٍ، فَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِهِ فَأَدْخَلَ يَدَهُ فِيهِ وَفَرَّجَ أَصَابِعَهُ ثُمَّ قَالَ ‏ "‏ حَىَّ عَلَى أَهْلِ الْوُضُوءِ، الْبَرَكَةُ مِنَ اللَّهِ ‏"‏‏.‏ فَلَقَدْ رَأَيْتُ الْمَاءَ يَتَفَجَّرُ مِنْ بَيْنِ أَصَابِعِهِ، فَتَوَضَّأَ النَّاسُ وَشَرِبُوا، فَجَعَلْتُ لاَ آلُو مَا جَعَلْتُ فِي بَطْنِي مِنْهُ، فَعَلِمْتُ أَنَّهُ بَرَكَةٌ‏.‏ قُلْتُ لِجَابِرٍ كَمْ كُنْتُمْ يَوْمَئِذٍ قَالَ أَلْفًا وَأَرْبَعَمِائَةٍ‏.‏ تَابَعَهُ عَمْرٌو عَنْ جَابِرٍ‏.‏ وَقَالَ حُصَيْنٌ وَعَمْرُو بْنُ مُرَّةَ عَنْ سَالِمٍ عَنْ جَابِرٍ خَمْسَ عَشْرَةَ مِائَةً‏.‏ وَتَابَعَهُ سَعِيدُ بْنُ الْمُسَيَّبِ عَنْ جَابِرٍ‏.‏\hadithno{5639}\hadithtrans{Narrated Jabir bin `Abdullah:I was with the Prophet (ﷺ) and the time for the `Asr prayer became due. We had no water with us except a little which was put in a vessel and was brought to the Prophet (ﷺ) . He put his hand into it and spread out his fingers and then said, "Come along! Hurry up! All those who want to perform ablution. The blessing is from Allah.'' I saw the water gushing out from his fingers. So the people performed the ablution and drank, and I tried to drink more of that water (beyond my thirst and capacity), for I knew that it was a blessing. The sub-narrator said: I asked Jabir, "How many persons were you then?" He replied, "We were one-thousand four hundred men." Salim said: Jabir said}}
