% Auto-generated chapter 26 for abudawud
% Hadiths in this chapter: 28

\hadithdefcmd{abudawud}{3641}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، سَمِعْتُ عَاصِمَ بْنَ رَجَاءِ بْنِ حَيْوَةَ، يُحَدِّثُ عَنْ دَاوُدَ بْنِ جَمِيلٍ، عَنْ كَثِيرِ بْنِ قَيْسٍ، قَالَ كُنْتُ جَالِسًا مَعَ أَبِي الدَّرْدَاءِ فِي مَسْجِدِ دِمَشْقَ فَجَاءَهُ رَجُلٌ فَقَالَ يَا أَبَا الدَّرْدَاءِ إِنِّي جِئْتُكَ مِنْ مَدِينَةِ الرَّسُولِ صلى الله عليه وسلم لِحَدِيثٍ بَلَغَنِي أَنَّكَ تُحَدِّثُهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا جِئْتُ لِحَاجَةٍ ‏.‏ قَالَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ سَلَكَ طَرِيقًا يَطْلُبُ فِيهِ عِلْمًا سَلَكَ اللَّهُ بِهِ طَرِيقًا مِنْ طُرُقِ الْجَنَّةِ وَإِنَّ الْمَلاَئِكَةَ لَتَضَعُ أَجْنِحَتَهَا رِضًا لِطَالِبِ الْعِلْمِ وَإِنَّ الْعَالِمَ لَيَسْتَغْفِرُ لَهُ مَنْ فِي السَّمَوَاتِ وَمَنْ فِي الأَرْضِ وَالْحِيتَانُ فِي جَوْفِ الْمَاءِ وَإِنَّ فَضْلَ الْعَالِمِ عَلَى الْعَابِدِ كَفَضْلِ الْقَمَرِ لَيْلَةَ الْبَدْرِ عَلَى سَائِرِ الْكَوَاكِبِ وَإِنَّ الْعُلَمَاءَ وَرَثَةُ الأَنْبِيَاءِ وَإِنَّ الأَنْبِيَاءَ لَمْ يُوَرِّثُوا دِينَارًا وَلاَ دِرْهَمًا وَرَّثُوا الْعِلْمَ فَمَنْ أَخَذَهُ أَخَذَ بِحَظٍّ وَافِرٍ ‏"‏ ‏.‏\hadithno{3641}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Kathir ibn Qays: Kathir ibn Qays said: I was sitting with AbudDarda' in the mosque of Damascus. A man came to him and said: AbudDarda, I have come to you from the town of the Messenger of Allah (ﷺ) for a tradition that I have heard you relate from the Messenger of Allah (ﷺ). I have come for no other purpose. He said: I heard the Messenger of Allah (ﷺ) say: If anyone travels on a road in search of knowledge, Allah will cause him to travel on one of the roads of Paradise. The angels will lower their wings in their great pleasure with one who seeks knowledge, the inhabitants of the heavens and the Earth and the fish in the deep waters will ask forgiveness for the learned man. The superiority of the learned man over the devout is like that of the moon, on the night when it is full, over the rest of the stars. The learned are the heirs of the Prophets, and the Prophets leave neither dinar nor dirham, leaving only knowledge, and he who takes it takes an abundant portion}}
\hadithdefcmd{abudawud}{3642}{حَدَّثَنَا مُحَمَّدُ بْنُ الْوَزِيرِ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ، قَالَ لَقِيتُ شَبِيبَ بْنَ شَيْبَةَ فَحَدَّثَنِي بِهِ، عَنْ عُثْمَانَ بْنِ أَبِي سَوْدَةَ، عَنْ أَبِي الدَّرْدَاءِ، - يَعْنِي عَنِ النَّبِيِّ صلى الله عليه وسلم - بِمَعْنَاهُ ‏.‏\hadithno{3642}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Abu al-Darda through a different chain of narrators to the same effect from the Holy Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{3643}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زَائِدَةُ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ رَجُلٍ يَسْلُكُ طَرِيقًا يَطْلُبُ فِيهِ عِلْمًا إِلاَّ سَهَّلَ اللَّهُ لَهُ بِهِ طَرِيقَ الْجَنَّةِ وَمَنْ أَبْطَأَ بِهِ عَمَلُهُ لَمْ يُسْرِعْ بِهِ نَسَبُهُ ‏"‏ ‏.‏\hadithno{3643}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah reported the Prophet (ﷺ) as saying:If anyone pursues a path in search of knowledge, Allah will thereby make easy for him a path to paradise; and he who is made slow by his actions will not be speeded by his genealogy}}
\hadithdefcmd{abudawud}{3644}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ ثَابِتٍ الْمَرْوَزِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي ابْنُ أَبِي نَمْلَةَ الأَنْصَارِيُّ، عَنْ أَبِيهِ، أَنَّهُ بَيْنَمَا هُوَ جَالِسٌ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَعِنْدَهُ رَجُلٌ مِنَ الْيَهُودِ مُرَّ بِجَنَازَةٍ فَقَالَ يَا مُحَمَّدُ هَلْ تَتَكَلَّمُ هَذِهِ الْجَنَازَةُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اللَّهُ أَعْلَمُ ‏"‏ ‏.‏ فَقَالَ الْيَهُودِيُّ إِنَّهَا تَتَكَلَّمُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا حَدَّثَكُمْ أَهْلُ الْكِتَابِ فَلاَ تُصَدِّقُوهُمْ وَلاَ تُكَذِّبُوهُمْ وَقُولُوا آمَنَّا بِاللَّهِ وَرُسُلِهِ فَإِنْ كَانَ بَاطِلاً لَمْ تُصَدِّقُوهُ وَإِنْ كَانَ حَقًّا لَمْ تُكَذِّبُوهُ ‏"‏ ‏.‏\hadithno{3644}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuNamlah al-Ansari: When he was sitting with the Messenger of Allah (ﷺ) and a Jew was also with him, a funeral passed by him. He (the Jew) asked (Him): Muhammad, does this funeral speak? The Prophet (ﷺ) said: Allah has more knowledge. The Jew said: It speaks. The Messenger of Allah (ﷺ) said: Whatever the people of the Book tell you, do not verify them, nor falsify them, but say: We believe in Allah and His Apostle. If it is false, do not confirm it, and if it is right, do not falsify it}}
\hadithdefcmd{abudawud}{3645}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا ابْنُ أَبِي الزِّنَادِ، عَنْ أَبِيهِ، عَنْ خَارِجَةَ، - يَعْنِي ابْنَ زَيْدِ بْنِ ثَابِتٍ - قَالَ قَالَ زَيْدُ بْنُ ثَابِتٍ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَتَعَلَّمْتُ لَهُ كِتَابَ يَهُودَ وَقَالَ ‏ "‏ إِنِّي وَاللَّهِ مَا آمَنُ يَهُودَ عَلَى كِتَابِي ‏"‏ ‏.‏ فَتَعَلَّمْتُهُ فَلَمْ يَمُرَّ بِي إِلاَّ نِصْفُ شَهْرٍ حَتَّى حَذَقْتُهُ فَكُنْتُ أَكْتُبُ لَهُ إِذَا كَتَبَ وَأَقْرَأُ لَهُ إِذَا كُتِبَ إِلَيْهِ ‏.‏\hadithno{3645}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Zayd ibn Thabit: The Messenger of Allah (ﷺ) ordered me (to learn the writing of the Jews), so I learnt for him the writing of the Jews. He said: I swear by Allah, I do not trust Jews in respect of writing for me. So I learnt it, and only a fortnight passed before I mastered it. I would write for him when he wrote (to them), and read to him when something was written to him}}
\hadithdefcmd{abudawud}{3646}{حَدَّثَنَا مُسَدَّدٌ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ بْنِ الأَخْنَسِ، عَنِ الْوَلِيدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي مُغِيثٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ كُنْتُ أَكْتُبُ كُلَّ شَىْءٍ أَسْمَعُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أُرِيدُ حِفْظَهُ فَنَهَتْنِي قُرَيْشٌ وَقَالُوا أَتَكْتُبُ كُلَّ شَىْءٍ تَسْمَعُهُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم بَشَرٌ يَتَكَلَّمُ فِي الْغَضَبِ وَالرِّضَا فَأَمْسَكْتُ عَنِ الْكِتَابِ فَذَكَرْتُ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَأَوْمَأَ بِأُصْبُعِهِ إِلَى فِيهِ فَقَالَ ‏ "‏ اكْتُبْ فَوَالَّذِي نَفْسِي بِيَدِهِ مَا يَخْرُجُ مِنْهُ إِلاَّ حَقٌّ ‏"‏ ‏.‏\hadithno{3646}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: I used to write everything which I heard from the Messenger of Allah (ﷺ). I intended (by it) to memorise it. The Quraysh prohibited me saying: Do you write everything that you hear from him while the Messenger of Allah (ﷺ) is a human being: he speaks in anger and pleasure? So I stopped writing, and mentioned it to the Messenger of Allah (ﷺ). He signalled with his finger to him mouth and said: Write, by Him in Whose hand my soul lies, only right comes out from it}}
\hadithdefcmd{abudawud}{3647}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا أَبُو أَحْمَدَ، حَدَّثَنَا كَثِيرُ بْنُ زَيْدٍ، عَنِ الْمُطَّلِبِ بْنِ عَبْدِ اللَّهِ بْنِ حَنْطَبٍ، قَالَ دَخَلَ زَيْدُ بْنُ ثَابِتٍ عَلَى مُعَاوِيَةَ فَسَأَلَهُ عَنْ حَدِيثٍ، فَأَمَرَ إِنْسَانًا يَكْتُبُهُ فَقَالَ لَهُ زَيْدٌ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَنَا أَنْ لاَ نَكْتُبَ شَيْئًا مِنْ حَدِيثِهِ فَمَحَاهُ ‏.‏\hadithno{3647}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Muttalib bin 'Abd Allah bin Hantab: Al-Muttalib ibn Abdullah ibn Hantab said: Zayd ibn Thabit entered upon Mu'awiyah and asked him about a tradition. He ordered a man to write it. Zayd said: The Messenger of Allah (ﷺ) ordered us not to write any of his traditions. So he erased it}}
\hadithdefcmd{abudawud}{3648}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو شِهَابٍ، عَنِ الْحَذَّاءِ، عَنْ أَبِي الْمُتَوَكِّلِ النَّاجِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ مَا كُنَّا نَكْتُبُ غَيْرَ التَّشَهُّدِ وَالْقُرْآنِ ‏.‏\hadithno{3648}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Saeed Al-Khudri said:"We used not to write anything but the Tasha-hud and the Qur'an}}
\hadithdefcmd{abudawud}{3649}{حَدَّثَنَا مُؤَمَّلٌ، قَالَ حَدَّثَنَا الْوَلِيدُ، ح وَحَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ بْنِ مَزْيَدٍ، قَالَ أَخْبَرَنِي أَبِي، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ، قَالَ لَمَّا فُتِحَتْ مَكَّةُ قَامَ النَّبِيُّ صلى الله عليه وسلم فَذَكَرَ الْخُطْبَةَ خُطْبَةَ النَّبِيِّ صلى الله عليه وسلم قَالَ فَقَامَ رَجُلٌ مِنْ أَهْلِ الْيَمَنِ يُقَالُ لَهُ أَبُو شَاهٍ فَقَالَ يَا رَسُولَ اللَّهِ اكْتُبُوا لِي ‏.‏ فَقَالَ ‏ "‏ اكْتُبُوا لأَبِي شَاهٍ ‏"‏ ‏.‏\hadithno{3649}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2434) Sahih Muslim (1355)}\hadithtrans{Abu Hurairah said :When Mecca was conquered, the Holy Prophet (peace be upon him) stood up. He (Abu Hurairah) then mentioned the sermon of the Holy Prophet (ﷺ). He said: A man of the Yemen, who was called Abu Shah, got up and said: Messenger of Allah! Write it for me. He said: Write it for Abu Shah}}
\hadithdefcmd{abudawud}{3650}{حَدَّثَنَا عَلِيُّ بْنُ سَهْلٍ الرَّمْلِيُّ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ قُلْتُ لأَبِي عَمْرٍو مَا يَكْتُبُوهُ قَالَ الْخُطْبَةَ الَّتِي سَمِعَهَا يَوْمَئِذٍ مِنْهُ ‏.‏\hadithno{3650}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-Walid said :I asked Abu `Amr: What are they writing? He said: The sermon which he heard that day}}
\hadithdefcmd{abudawud}{3651}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا خَالِدٌ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدٌ، - الْمَعْنَى - عَنْ بَيَانِ بْنِ بِشْرٍ، - قَالَ مُسَدَّدٌ أَبُو بِشْرٍ - عَنْ وَبَرَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، قَالَ قُلْتُ لِلزُّبَيْرِ مَا يَمْنَعُكَ أَنْ تُحَدِّثَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم كَمَا يُحَدِّثُ عَنْهُ أَصْحَابُهُ فَقَالَ أَمَا وَاللَّهِ لَقَدْ كَانَ لِي مِنْهُ وَجْهٌ وَمَنْزِلَةٌ وَلَكِنِّي سَمِعْتُهُ يَقُولُ ‏ "‏ مَنْ كَذَبَ عَلَىَّ مُتَعَمِّدًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{3651}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (107)}\hadithtrans{Abd Allah bin al-Zubair said on the authority of the father :I asked al-Zubair : What prevents you from narrating traditions from the Messenger of Allah (ﷺ) as his Companions narrate from him? He said: By Allah I was very close to him. But I heard him (ﷺ) say: He who lies about me deliberately will certainly come to his abode in Hell}}
\hadithdefcmd{abudawud}{3652}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ يَحْيَى، حَدَّثَنَا يَعْقُوبُ بْنُ إِسْحَاقَ الْمُقْرِئُ الْحَضْرَمِيُّ، حَدَّثَنَا سُهَيْلُ بْنُ مِهْرَانَ، - أَخُو حَزْمٍ الْقُطَعِيِّ - حَدَّثَنَا أَبُو عِمْرَانَ، عَنْ جُنْدُبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَالَ فِي كِتَابِ اللَّهِ عَزَّ وَجَلَّ بِرَأْيِهِ فَأَصَابَ فَقَدْ أَخْطَأَ ‏"‏ ‏.‏\hadithno{3652}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jundub: The Prophet (ﷺ) said: If anyone interprets the Book of Allah in the light of his opinion even if he is right, he has erred}}
\hadithdefcmd{abudawud}{3653}{حَدَّثَنَا عَمْرُو بْنُ مَرْزُوقٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ أَبِي عَقِيلٍ، هَاشِمِ بْنِ بِلاَلٍ عَنْ سَابِقِ بْنِ نَاجِيَةَ، عَنْ أَبِي سَلاَّمٍ، عَنْ رَجُلٍ، خَدَمَ النَّبِيَّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا حَدَّثَ حَدِيثًا أَعَادَهُ ثَلاَثَ مَرَّاتٍ ‏.‏\hadithno{3653}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{AbuSallam said on the authority of a man who served the Holy Prophet (ﷺ) that whenever he talked, he repeated it three times}}
\hadithdefcmd{abudawud}{3654}{حَدَّثَنَا مُحَمَّدُ بْنُ مَنْصُورٍ الطُّوسِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، قَالَ جَلَسَ أَبُو هُرَيْرَةَ إِلَى جَنْبِ حُجْرَةِ عَائِشَةَ - رضى الله عنها - وَهِيَ تُصَلِّي فَجَعَلَ يَقُولُ اسْمَعِي يَا رَبَّةَ الْحُجْرَةِ مَرَّتَيْنِ ‏.‏ فَلَمَّا قَضَتْ صَلاَتَهَا قَالَتْ أَلاَ تَعْجَبُ إِلَى هَذَا وَحَدِيثِهِ إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُحَدِّثُ الْحَدِيثَ لَوْ شَاءَ الْعَادُّ أَنْ يُحْصِيَهُ أَحْصَاهُ ‏.‏\hadithno{3654}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3567) Sahih Muslim (2493)}\hadithtrans{Urwah said:Abu Hurairah sat beside the apartment of `A’ishah while she was praying. He then began to say: Listen, O lady of the apartment, saying it twice (in quick succession). When she finished her prayer, she said: Are you not surprised at him and the way he narrates traditions from the Apostle of the Allah (ﷺ). When the Apostle of the Allah (ﷺ) gave a talk, a man could count his words if he wished to count}}
\hadithdefcmd{abudawud}{3655}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، حَدَّثَهُ أَنَّ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ أَلاَ يُعْجِبُكَ أَبُو هُرَيْرَةَ جَاءَ فَجَلَسَ إِلَى جَانِبِ حُجْرَتِي يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم يُسْمِعُنِي ذَلِكَ وَكُنْتُ أُسَبِّحُ فَقَامَ قَبْلَ أَنْ أَقْضِيَ سُبْحَتِي وَلَوْ أَدْرَكْتُهُ لَرَدَدْتُ عَلَيْهِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَكُنْ يَسْرُدُ الْحَدِيثَ مِثْلَ سَرْدِكُمْ ‏.‏\hadithno{3655}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (2493)}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Are you not surprised at AbuHurayrah? He came and sat beside my apartment, and began to narrate traditions from the Messenger of Allah (ﷺ) making me hear them. I was saying supererogatory prayer. He got up (and went away) before I finished my prayer. Had I found him, I would have replied to him. The Messenger of Allah (ﷺ) did not narrate traditions quickly one after another as you narrate quickly}}
\hadithdefcmd{abudawud}{3656}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، حَدَّثَنَا عِيسَى، عَنِ الأَوْزَاعِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ سَعْدٍ، عَنِ الصُّنَابِحِيِّ، عَنْ مُعَاوِيَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْغَلُوطَاتِ ‏.‏\hadithno{3656}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'awiyah: The Holy Prophet (ﷺ) forbade the discussion of thorny questions}}
\hadithdefcmd{abudawud}{3657}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو عَبْدِ الرَّحْمَنِ الْمُقْرِئُ، حَدَّثَنَا سَعِيدٌ، - يَعْنِي ابْنَ أَبِي أَيُّوبَ - عَنْ بَكْرِ بْنِ عَمْرٍو، عَنْ مُسْلِمِ بْنِ يَسَارٍ أَبِي عُثْمَانَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَفْتَى ‏"‏ ‏.‏ ح وَحَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ أَخْبَرَنَا ابْنُ وَهْبٍ حَدَّثَنِي يَحْيَى بْنُ أَيُّوبَ عَنْ بَكْرِ بْنِ عَمْرٍو عَنْ عَمْرِو بْنِ أَبِي نُعَيْمَةَ عَنْ أَبِي عُثْمَانَ الطُّنْبُذِيِّ - رَضِيعِ عَبْدِ الْمَلِكِ بْنِ مَرْوَانَ - قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أُفْتِيَ بِغَيْرِ عِلْمٍ كَانَ إِثْمُهُ عَلَى مَنْ أَفْتَاهُ ‏"‏ ‏.‏ زَادَ سُلَيْمَانُ الْمَهْرِيُّ فِي حَدِيثِهِ ‏"‏ وَمَنْ أَشَارَ عَلَى أَخِيهِ بِأَمْرٍ يَعْلَمُ أَنَّ الرُّشْدَ فِي غَيْرِهِ فَقَدْ خَانَهُ ‏"‏ ‏.‏ وَهَذَا لَفْظُ سُلَيْمَانَ ‏.‏\hadithno{3657}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone is given a legal decision ignorantly, the sin rests on the one who gave it. Sulayman al-Mahri added in his version: If anyone advises his brother, knowing that guidance lies in another direction, he has deceived him. These are the wordings of Sulayman}}
\hadithdefcmd{abudawud}{3658}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا عَلِيُّ بْنُ الْحَكَمِ، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سُئِلَ عَنْ عِلْمٍ فَكَتَمَهُ أَلْجَمَهُ اللَّهُ بِلِجَامٍ مِنْ نَارٍ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3658}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: He who is asked something he knows and conceals it will have a bridle of fire put on him on the Day of Resurrection}}
\hadithdefcmd{abudawud}{3659}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالاَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَسْمَعُونَ وَيُسْمَعُ مِنْكُمْ وَيُسْمَعُ مِمَّنْ سَمِعَ مِنْكُمْ ‏"‏ ‏.‏\hadithno{3659}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: You hear (from me), and others will hear from you; and people will hear from them who heard from you}}
\hadithdefcmd{abudawud}{3660}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، حَدَّثَنِي عُمَرُ بْنُ سُلَيْمَانَ، - مِنْ وَلَدِ عُمَرَ بْنِ الْخَطَّابِ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبَانَ، عَنْ أَبِيهِ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ نَضَّرَ اللَّهُ امْرَأً سَمِعَ مِنَّا حَدِيثًا فَحَفِظَهُ حَتَّى يُبَلِّغَهُ فَرُبَّ حَامِلِ فِقْهٍ إِلَى مَنْ هُوَ أَفْقَهُ مِنْهُ وَرُبَّ حَامِلِ فِقْهٍ لَيْسَ بِفَقِيهٍ ‏"‏ ‏.‏\hadithno{3660}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Zayd ibn Thabit: I heard the Messenger of Allah (ﷺ) say: May Allah brighten a man who hears a tradition from us, gets it by heart and passes it on to others. Many a bearer of knowledge conveys it to one who is more versed than he is; and many a bearer of knowledge is not versed in it}}
\hadithdefcmd{abudawud}{3661}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلٍ، - يَعْنِي ابْنَ سَعْدٍ - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ وَاللَّهِ لأَنْ يُهْدَى بِهُدَاكَ رَجْلٌ وَاحِدٌ خَيْرٌ لَكَ مِنْ حُمْرِ النَّعَمِ ‏"‏ ‏.‏\hadithno{3661}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3701) Sahih Muslim (2406)}\hadithtrans{Sahl b. Sa’d reported the prophet (ﷺ) as saying:I swear on Allah, it will be better for you that Allah should give guidance to one man through your agency than that you should acquire the red ones among the camels}}
\hadithdefcmd{abudawud}{3662}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حَدِّثُوا عَنْ بَنِي إِسْرَائِيلَ وَلاَ حَرَجَ ‏"‏ ‏.‏\hadithno{3662}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: relate traditions from the children of Isra'il; there is no harm}}
\hadithdefcmd{abudawud}{3663}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذٌ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي حَسَّانَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ كَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم يُحَدِّثُنَا عَنْ بَنِي إِسْرَائِيلَ حَتَّى يُصْبِحَ مَا يَقُومُ إِلاَّ إِلَى عُظْمِ صَلاَةٍ ‏.‏\hadithno{3663}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) used to relate to us traditions from the children of Isra'il till morning came; he would not get up except for obligatory prayer}}
\hadithdefcmd{abudawud}{3664}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُرَيْجُ بْنُ النُّعْمَانِ، حَدَّثَنَا فُلَيْحٌ، عَنْ أَبِي طُوَالَةَ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ مَعْمَرٍ الأَنْصَارِيِّ، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ تَعَلَّمَ عِلْمًا مِمَّا يُبْتَغَى بِهِ وَجْهُ اللَّهِ عَزَّ وَجَلَّ لاَ يَتَعَلَّمُهُ إِلاَّ لِيُصِيبَ بِهِ عَرَضًا مِنَ الدُّنْيَا لَمْ يَجِدْ عَرْفَ الْجَنَّةِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ يَعْنِي رِيحَهَا ‏.‏\hadithno{3664}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurayrah: The Prophet (ﷺ) said: If anyone acquires knowledge that should be sought seeking the Face of Allah, but he acquires it only to get some worldly advantage, he will not experience the arf, i.e. the fragrance, of Paradise}}
\hadithdefcmd{abudawud}{3665}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا أَبُو مُسْهِرٍ، حَدَّثَنِي عَبَّادُ بْنُ عَبَّادٍ الْخَوَّاصُ، عَنْ يَحْيَى بْنِ أَبِي عَمْرٍو السَّيْبَانِيِّ، عَنْ عَمْرِو بْنِ عَبْدِ اللَّهِ السَّيْبَانِيِّ، عَنْ عَوْفِ بْنِ مَالِكٍ الأَشْجَعِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَقُصُّ إِلاَّ أَمِيرٌ أَوْ مَأْمُورٌ أَوْ مُخْتَالٌ ‏"‏ ‏.‏\hadithno{3665}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Awf ibn Malik al-Ashja'i: I heard the Messenger of Allah (ﷺ) say: Only a ruler, or one put in charge, or one who is presumptuous, gives instructions}}
\hadithdefcmd{abudawud}{3666}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنِ الْمُعَلَّى بْنِ زِيَادٍ، عَنِ الْعَلاَءِ بْنِ بَشِيرٍ الْمُزَنِيِّ، عَنْ أَبِي الصِّدِّيقِ النَّاجِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ جَلَسْتُ فِي عِصَابَةٍ مِنْ ضُعَفَاءِ الْمُهَاجِرِينَ وَإِنَّ بَعْضَهُمْ لَيَسْتَتِرُ بِبَعْضٍ مِنَ الْعُرْىِ وَقَارِئٌ يَقْرَأُ عَلَيْنَا إِذْ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَامَ عَلَيْنَا فَلَمَّا قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَكَتَ الْقَارِئُ فَسَلَّمَ ثُمَّ قَالَ ‏"‏ مَا كُنْتُمْ تَصْنَعُونَ ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ إِنَّهُ كَانَ قَارِئٌ لَنَا يَقْرَأُ عَلَيْنَا فَكُنَّا نَسْتَمِعُ إِلَى كِتَابِ اللَّهِ ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي جَعَلَ مِنْ أُمَّتِي مَنْ أُمِرْتُ أَنْ أَصْبِرَ نَفْسِي مَعَهُمْ ‏"‏ ‏.‏ قَالَ فَجَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَسَطَنَا لِيَعْدِلَ بِنَفْسِهِ فِينَا ثُمَّ قَالَ بِيَدِهِ هَكَذَا فَتَحَلَّقُوا وَبَرَزَتْ وُجُوهُهُمْ لَهُ - قَالَ - فَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَرَفَ مِنْهُمْ أَحَدًا غَيْرِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَبْشِرُوا يَا مَعْشَرَ صَعَالِيكِ الْمُهَاجِرِينَ بِالنُّورِ التَّامِّ يَوْمَ الْقِيَامَةِ تَدْخُلُونَ الْجَنَّةَ قَبْلَ أَغْنِيَاءِ النَّاسِ بِنِصْفِ يَوْمٍ وَذَاكَ خَمْسُمِائَةِ سَنَةٍ ‏"‏ ‏.‏\hadithno{3666}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: I was sitting in the company of the poor members of the emigrants. Some of them were sitting together because of lack of clothing while a reader was reciting to us. All of a sudden the Messenger of Allah (ﷺ) came along and stood beside us. When the Messenger of Allah (ﷺ) stood, the reader stopped and greeted him. He asked: What were you doing? We said: Messenger of Allah! We had a reader who was reciting to us and we were listening to the Book of Allah, the Exalted. The Messenger of Allah (ﷺ) then said: Praise be to Allah Who has put among my people those with whom I have been ordered to stay. The Messenger of Allah (ﷺ) then sat among us so as to be like one of us, and when he had made a sign with his hand they sat in a circle with their faces turned towards him. The narrator said: I think that the Messenger of Allah (ﷺ) did not recognize any of them except me. The Messenger of Allah (ﷺ) then said: Rejoice, you group of poor emigrants, in the announcement that you will have perfect light on the Day of Resurrection. You will enter Paradise half a day before the rich, and that is five hundred years}}
\hadithdefcmd{abudawud}{3667}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي عَبْدُ السَّلاَمِ، - يَعْنِي ابْنَ مُطَهَّرٍ أَبُو ظَفَرٍ - حَدَّثَنَا مُوسَى بْنُ خَلَفٍ الْعَمِّيُّ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ أَقْعُدَ مَعَ قَوْمٍ يَذْكُرُونَ اللَّهَ تَعَالَى مِنْ صَلاَةِ الْغَدَاةِ حَتَّى تَطْلُعَ الشَّمْسُ أَحَبُّ إِلَىَّ مِنْ أَنْ أُعْتِقَ أَرْبَعَةً مِنْ وَلَدِ إِسْمَاعِيلَ وَلأَنْ أَقْعُدَ مَعَ قَوْمٍ يَذْكُرُونَ اللَّهَ مِنْ صَلاَةِ الْعَصْرِ إِلَى أَنْ تَغْرُبَ الشَّمْسُ أَحَبُّ إِلَىَّ مِنْ أَنْ أُعْتِقَ أَرْبَعَةً ‏"‏ ‏.‏\hadithno{3667}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Anas ibn Malik: The Prophet (ﷺ) said: That I sit in the company of the people who remember Allah the Exalted from morning prayer till the sun rises is dearer to me than that I emancipate four slaves from the children of Isma`il, and that I sit with the people who remember Allah from afternoon prayer till the sun sets is dearer to me than that I emancipate four slaves}}
\hadithdefcmd{abudawud}{3668}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَأْ عَلَىَّ سُورَةَ النِّسَاءِ ‏"‏ ‏.‏ قَالَ قُلْتُ أَقْرَأُ عَلَيْكَ وَعَلَيْكَ أُنْزِلَ قَالَ ‏"‏ إِنِّي أُحِبُّ أَنْ أَسْمَعَهُ مِنْ غَيْرِي ‏"‏ ‏.‏ قَالَ فَقَرَأْتُ عَلَيْهِ حَتَّى إِذَا انْتَهَيْتُ إِلَى قَوْلِهِ ‏\{‏ فَكَيْفَ إِذَا جِئْنَا مِنْ كُلِّ أُمَّةٍ بِشَهِيدٍ ‏\}‏ الآيَةَ فَرَفَعْتُ رَأْسِي فَإِذَا عَيْنَاهُ تَهْمِلاَنِ ‏.‏\hadithno{3668}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5049) Sahih Muslim (800)}\hadithtrans{Abd Allah (b. Mas`ud) said:The Messenger of Allah (ﷺ) said to me: recite Surat al-Nisa’. I asked: Shall I recite to you what was sent down to you? He replied: I like to here it from someone else. So I recited (it) until I reached this verse “How then shall it be when We bring from every people a witness?”. Then I raised my head and saw tears falling from his eyes}}
