% Auto-generated chapter 7 for abudawud
% Hadiths in this chapter: 15

\hadithdefcmd{abudawud}{1401}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ بْنِ الْبَرْقِيِّ، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا نَافِعُ بْنُ يَزِيدَ، عَنِ الْحَارِثِ بْنِ سَعِيدٍ الْعُتَقِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مُنَيْنٍ، - مِنْ بَنِي عَبْدِ كُلاَلٍ - عَنْ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَقْرَأَهُ خَمْسَ عَشْرَةَ سَجْدَةً فِي الْقُرْآنِ مِنْهَا ثَلاَثٌ فِي الْمُفَصَّلِ وَفِي سُورَةِ الْحَجِّ سَجْدَتَانِ ‏.‏ قَالَ أَبُو دَاوُدَ رُوِيَ عَنْ أَبِي الدَّرْدَاءِ عَنِ النَّبِيِّ صلى الله عليه وسلم إِحْدَى عَشْرَةَ سَجْدَةً وَإِسْنَادُهُ وَاهٍ ‏.‏\hadithno{1401}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Amr ibn al-'As: The Prophet (ﷺ) taught me fifteen prostrations while reciting the Qur'an, including three in al-Mufassal and two in Surah al-Hajj. Abu Dawud said: Abu al-Darda' has reported eleven prostrations from the Prophet (ﷺ), but chain of this tradition is weak}}
\hadithdefcmd{abudawud}{1402}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ لَهِيعَةَ، أَنَّ مِشْرَحَ بْنَ هَاعَانَ أَبَا الْمُصْعَبِ، حَدَّثَهُ أَنَّ عُقْبَةَ بْنَ عَامِرٍ حَدَّثَهُ قَالَ قُلْتُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَفِي سُورَةِ الْحَجِّ سَجْدَتَانِ قَالَ ‏ "‏ نَعَمْ وَمَنْ لَمْ يَسْجُدْهُمَا فَلاَ يَقْرَأْهُمَا ‏"‏ ‏.‏\hadithno{1402}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Uqbah ibn Amir: I said to the Messenger of Allah (ﷺ): Are there two prostrations in Surah al-Hajj? He replied: Yes; if anyone does not make two prostrations, he should not recite them}}
\hadithdefcmd{abudawud}{1403}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَزْهَرُ بْنُ الْقَاسِمِ، - قَالَ مُحَمَّدٌ رَأَيْتُهُ بِمَكَّةَ - حَدَّثَنَا أَبُو قُدَامَةَ، عَنْ مَطَرٍ الْوَرَّاقِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَسْجُدْ فِي شَىْءٍ مِنَ الْمُفَصَّلِ مُنْذُ تَحَوَّلَ إِلَى الْمَدِينَةِ ‏.‏\hadithno{1403}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) did not make a prostration at any verse in al-Mufassal from the time he moved to Medina}}
\hadithdefcmd{abudawud}{1404}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ قُسَيْطٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ قَرَأْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم النَّجْمَ فَلَمْ يَسْجُدْ فِيهَا ‏.‏\hadithno{1404}\hadithgrade{Al-Albani: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{On the authority of Zaid bin Thabit, he said:"I recited to the Messenger of Allah (ﷺ) (Surat) An-Najm and he did not prostrate in it}}
\hadithdefcmd{abudawud}{1405}{حَدَّثَنَا ابْنُ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنَا أَبُو صَخْرٍ، عَنِ ابْنِ قُسَيْطٍ، عَنْ خَارِجَةَ بْنِ زَيْدِ بْنِ ثَابِتٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ كَانَ زَيْدٌ الإِمَامَ فَلَمْ يَسْجُدْ فِيهَا ‏.‏\hadithno{1405}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{This tradition has also been transmitted by Zaid b. Thabit through a different chain of narrators to the same effect. Abu Dawud said:Zaid was imam (in a prayer) and he did not make prostration}}
\hadithdefcmd{abudawud}{1406}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ سُورَةَ النَّجْمِ فَسَجَدَ فِيهَا وَمَا بَقِيَ أَحَدٌ مِنَ الْقَوْمِ إِلاَّ سَجَدَ فَأَخَذَ رَجُلٌ مِنَ الْقَوْمِ كَفًّا مِنْ حَصًى أَوْ تُرَابٍ فَرَفَعَهُ إِلَى وَجْهِهِ وَقَالَ يَكْفِينِي هَذَا ‏.‏ قَالَ عَبْدُ اللَّهِ فَلَقَدْ رَأَيْتُهُ بَعْدَ ذَلِكَ قُتِلَ كَافِرًا ‏.‏\hadithno{1406}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1070) Sahih Muslim (576)}\hadithtrans{Narrated 'Abd Allah (b. Mas'ud):The Messenger of Allah (ﷺ) recited Surah al-Najm and prostrated himself. No one remained there who did not prostrate (along with him). A man from the people took a handful of pebbles or dust and raised it to his face saying: This is enough for me. 'Abd Allah (b. Mas'ud) said: I later saw him killed as an infidel}}
\hadithdefcmd{abudawud}{1407}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ عَطَاءِ بْنِ مِينَاءَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَجَدْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ‏\{‏ إِذَا السَّمَاءُ انْشَقَّتْ ‏\}‏ وَ ‏\{‏ اقْرَأْ بِاسْمِ رَبِّكَ الَّذِي خَلَقَ ‏\}‏ ‏.‏\hadithno{1407}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (578)}\hadithtrans{Narrated Abu Hurairah:We prostrated ourselves along with the Messenger of Allah (ﷺ) on account of: "When the sky is rent asunder" and "Recite in the name of Your Lord Who created}}
\hadithdefcmd{abudawud}{1408}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ أَبِي، حَدَّثَنَا بَكْرٌ، عَنْ أَبِي رَافِعٍ، قَالَ صَلَّيْتُ مَعَ أَبِي هُرَيْرَةَ الْعَتَمَةَ فَقَرَأَ ‏\{‏ إِذَا السَّمَاءُ انْشَقَّتْ ‏\}‏ فَسَجَدَ فَقُلْتُ مَا هَذِهِ السَّجْدَةُ قَالَ سَجَدْتُ بِهَا خَلْفَ أَبِي الْقَاسِمِ صلى الله عليه وسلم فَلاَ أَزَالُ أَسْجُدُ بِهَا حَتَّى أَلْقَاهُ ‏.‏\hadithno{1408}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1078) Sahih Muslim (578)}\hadithtrans{Narrated Abu Rafi':I offered the night prayer behind Abu Hurairah. He recited Surah Inshiqaq ("When the sky is rent asunder") and prostrated himself. I asked him: What is this prostration ? He replied: I prostrated myself on account of this (surah) behind Abu al-Qasim (i.e. the Prophet). I shall continue prostrating on account of this till I meet him}}
\hadithdefcmd{abudawud}{1409}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَيْسَ ‏\{‏ ص ‏\}‏ مِنْ عَزَائِمِ السُّجُودِ وَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْجُدُ فِيهَا ‏.‏\hadithno{1409}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1069)}\hadithtrans{Narrated Ibn 'Abbas:A prostration when reciting Sad is not one of those which are divinely commanded, but I have seen Messenger of Allah (ﷺ) prostrate himself}}
\hadithdefcmd{abudawud}{1410}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، - يَعْنِي ابْنَ الْحَارِثِ - عَنِ ابْنِ أَبِي هِلاَلٍ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ بْنِ سَعْدِ بْنِ أَبِي سَرْحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ قَالَ قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى الْمِنْبَرِ ‏\{‏ ص ‏\}‏ فَلَمَّا بَلَغَ السَّجْدَةَ نَزَلَ فَسَجَدَ وَسَجَدَ النَّاسُ مَعَهُ فَلَمَّا كَانَ يَوْمٌ آخَرُ قَرَأَهَا فَلَمَّا بَلَغَ السَّجْدَةَ تَشَزَّنَ النَّاسُ لِلسُّجُودِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّمَا هِيَ تَوْبَةُ نَبِيٍّ وَلَكِنِّي رَأَيْتُكُمْ تَشَزَّنْتُمْ لِلسُّجُودِ ‏"‏ ‏.‏ فَنَزَلَ فَسَجَدَ وَسَجَدُوا ‏.‏\hadithno{1410}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Sa'id al-Khudri: The Messenger of Allah (ﷺ) recited surah Sad on the pulpit. When he reached the place of prostration (in the surah), he descended and prostrated himself and the people prostrated with him. When the next day came, he recited it. When he reached the place of prostration (in the surah), the people became ready for prostration. Thereupon the Messenger of Allah (ﷺ) said: This is the repentance of a Prophet ; but I saw you being ready for prostration. So he descended and prostrated himself and the people prostrated along with him}}
\hadithdefcmd{abudawud}{1411}{حَدَّثَنَا مُحَمَّدُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ أَبُو الْجُمَاهِرِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ مُصْعَبِ بْنِ ثَابِتِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ عَامَ الْفَتْحِ سَجْدَةً فَسَجَدَ النَّاسُ كُلُّهُمْ مِنْهُمُ الرَّاكِبُ وَالسَّاجِدُ فِي الأَرْضِ حَتَّى إِنَّ الرَّاكِبَ لَيَسْجُدُ عَلَى يَدِهِ ‏.‏\hadithno{1411}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: In the year of Conquest the Messenger of Allah (ﷺ) recited a verse at which a prostration should be made and all the people prostrated themselves. Some were mounted, and some were prostrating themselves on the ground, and those who were mounted prostrated themselves on their hands}}
\hadithdefcmd{abudawud}{1412}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ أَبِي شُعَيْبٍ، حَدَّثَنَا ابْنُ نُمَيْرٍ، - الْمَعْنَى - عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ عَلَيْنَا السُّورَةَ - قَالَ ابْنُ نُمَيْرٍ فِي غَيْرِ الصَّلاَةِ ثُمَّ اتَّفَقَا - فَيَسْجُدُ وَنَسْجُدُ مَعَهُ حَتَّى لاَ يَجِدُ أَحَدُنَا مَكَانًا لِمَوْضِعِ جَبْهَتِهِ ‏.‏\hadithno{1412}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1075) Sahih Muslim (575)}\hadithtrans{Narrated Ibn 'Umar:The Messenger of Allah (ﷺ) would recite to us a surah (according to the version of Ibn Numair) outside the prayer (the agreed version goes), then he would prostrate along with him, and none of us could find a place for his forehead}}
\hadithdefcmd{abudawud}{1413}{حَدَّثَنَا أَحْمَدُ بْنُ الْفُرَاتِ أَبُو مَسْعُودٍ الرَّازِيُّ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ عَلَيْنَا الْقُرْآنَ فَإِذَا مَرَّ بِالسَّجْدَةِ كَبَّرَ وَسَجَدَ وَسَجَدْنَا ‏.‏ قَالَ عَبْدُ الرَّزَّاقِ وَكَانَ الثَّوْرِيُّ يُعْجِبُهُ هَذَا الْحَدِيثُ ‏.‏ قَالَ أَبُو دَاوُدَ يُعْجِبُهُ لأَنَّهُ كَبَّرَ ‏.‏\hadithno{1413}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Messenger of Allah (ﷺ) used to recite the Qur'an to us. When he came upon the verse containing prostration, he would utter the takbir (Allah is most great) and we would prostrate ourselves along with him. The narrator 'Abd al-Razzaq said: Al-Thawri liked this tradition very much. Abu Dawud said: This was liked by him for this contains the uttering of takbir}}
\hadithdefcmd{abudawud}{1414}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ رَجُلٍ، عَنْ أَبِي الْعَالِيَةِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي سُجُودِ الْقُرْآنِ بِاللَّيْلِ يَقُولُ فِي السَّجْدَةِ مِرَارًا ‏ "‏ سَجَدَ وَجْهِي لِلَّذِي خَلَقَهُ وَشَقَّ سَمْعَهُ وَبَصَرَهُ بِحَوْلِهِ وَقُوَّتِهِ ‏"‏ ‏.‏\hadithno{1414}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) prostrated himself at night when reciting the Qur'an. He said repeatedly: My face prostrates itself to Him Who created it and brought forth its hearing and seeing by His might and power}}
\hadithdefcmd{abudawud}{1415}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ الْعَطَّارُ، حَدَّثَنَا أَبُو بَحْرٍ، حَدَّثَنَا ثَابِتُ بْنُ عُمَارَةَ، حَدَّثَنَا أَبُو تَمِيمَةَ الْهُجَيْمِيُّ، قَالَ لَمَّا بَعَثْنَا الرَّكْبَ - قَالَ أَبُو دَاوُدَ يَعْنِي إِلَى الْمَدِينَةِ قَالَ - كُنْتُ أَقُصُّ بَعْدَ صَلاَةِ الصُّبْحِ فَأَسْجُدُ فَنَهَانِي ابْنُ عُمَرَ فَلَمْ أَنْتَهِ ثَلاَثَ مِرَارٍ ثُمَّ عَادَ فَقَالَ إِنِّي صَلَّيْتُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَعَ أَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ - رضى الله عنهم - فَلَمْ يَسْجُدُوا حَتَّى تَطْلُعَ الشَّمْسُ ‏.‏\hadithno{1415}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuTamimah al-Hujaymi: When we came to Medina accompanying the caravan, I used to preach after the dawn prayer, and prostrate on account of the recitation of the Qur'an. Ibn Umar prohibited me three times, but I did not cease doing that. He then repeated (his prohibition) saying: I prayed behind the Messenger of Allah (ﷺ), AbuBakr, Umar and Uthman, they would not prostrate (on account of the recitation of the Qur'an) till the sun had risen}}
