% Auto-generated chapter 10 for abudawud
% Hadiths in this chapter: 20

\hadithdefcmd{abudawud}{1701}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، قَالَ غَزَوْتُ مَعَ زَيْدِ بْنِ صُوحَانَ وَسَلْمَانَ بْنِ رَبِيعَةَ فَوَجَدْتُ سَوْطًا فَقَالاَ لِي اطْرَحْهُ ‏.‏ فَقُلْتُ لاَ وَلَكِنْ إِنْ وَجَدْتُ صَاحِبَهُ وَإِلاَّ اسْتَمْتَعْتُ بِهِ فَحَجَجْتُ فَمَرَرْتُ عَلَى الْمَدِينَةِ فَسَأَلْتُ أُبَىَّ بْنَ كَعْبٍ فَقَالَ وَجَدْتُ صُرَّةً فِيهَا مِائَةُ دِينَارٍ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ عَرِّفْهَا حَوْلاً ‏"‏ ‏.‏ فَعَرَّفْتُهَا حَوْلاً ثُمَّ أَتَيْتُهُ فَقَالَ ‏"‏ عَرِّفْهَا حَوْلاً ‏"‏ ‏.‏ فَعَرَّفْتُهَا حَوْلاً ثُمَّ أَتَيْتُهُ فَقَالَ ‏"‏ عَرِّفْهَا حَوْلاً ‏"‏ ‏.‏ فَعَرَّفْتُهَا حَوْلاً ثُمَّ أَتَيْتُهُ فَقُلْتُ لَمْ أَجِدْ مَنْ يَعْرِفُهَا ‏.‏ فَقَالَ ‏"‏ احْفَظْ عَدَدَهَا وَوِكَاءَهَا وَوِعَاءَهَا فَإِنْ جَاءَ صَاحِبُهَا وَإِلاَّ فَاسْتَمْتِعْ بِهَا ‏"‏ ‏.‏ وَقَالَ وَلاَ أَدْرِي أَثَلاَثًا قَالَ ‏"‏ عَرِّفْهَا ‏"‏ ‏.‏ أَوْ مَرَّةً وَاحِدَةً ‏.‏\hadithno{1701}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2426) Sahih Muslim (1723)}\hadithtrans{Suwayd ibn Ghaflah said:I fought along with Zayd ibn Suhan and Sulayman ibn Rabi'ah. I found a whip. They said to me: Throw it away. I said: No; if I find its owner (I shall give it to him); if not, I shall use it. Then I performed hajj; and when I reached Medina, I asked Ubayy ibn Ka'b. He said: I found a purse which contained one hundred dinars; so I came to the Prophet (ﷺ). He said to me: Make the matter known for a year. I made it known for a year and then came to him. He then said to me: Make the matter known for a year. So I made it known for a year. I then (again) came to him. He said to me: Make the matter known for a year. Then I came to him and said: I did not find anyone who realises it. He said: Remember, its number, its container and its tie. If its owner comes, (give it to him), otherwise use it yourself. He (the narrator Shu'bah) said: I do not know whether he said the word "make the matter known" three times or once}}
\hadithdefcmd{abudawud}{1702}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، بِمَعْنَاهُ قَالَ ‏ "‏ عَرِّفْهَا حَوْلاً ‏"‏ ‏.‏ وَقَالَ ثَلاَثَ مِرَارٍ قَالَ فَلاَ أَدْرِي قَالَ لَهُ ذَلِكَ فِي سَنَةٍ أَوْ فِي ثَلاَثِ سِنِينَ ‏.‏\hadithno{1702}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2426) Sahih Muslim (1723)}\hadithtrans{The aforesaid tradition has also been transmitted by Shu’bah through a different chain of narrators to the same effect. The version goes :He said : Make it known for a year. He said this three times. He said: I do not know whether he said “for a year” or “for three years”}}
\hadithdefcmd{abudawud}{1703}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا سَلَمَةُ بْنُ كُهَيْلٍ، بِإِسْنَادِهِ وَمَعْنَاهُ قَالَ فِي التَّعْرِيفِ قَالَ عَامَيْنِ أَوْ ثَلاَثَةً ‏.‏ وَقَالَ ‏"‏ اعْرِفْ عَدَدَهَا وَوِعَاءَهَا وَوِكَاءَهَا ‏"‏ ‏.‏ زَادَ ‏"‏ فَإِنْ جَاءَ صَاحِبُهَا فَعَرَفَ عَدَدَهَا وَوِكَاءَهَا فَادْفَعْهَا إِلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ لَيْسَ يَقُولُ هَذِهِ الْكَلِمَةَ إِلاَّ حَمَّادٌ فِي هَذَا الْحَدِيثِ يَعْنِي ‏"‏ فَعَرَفَ عَدَدَهَا ‏"‏ ‏.‏\hadithno{1703}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{The above mentioned tradition has also been transmitted by Salamah. Bin Kuhail through a different chain to the same effect. The version has ; about making the matter known he said ; “ two years or three.” He said :Remember its number, its container and its string. The version adds : If its owner comes, and tells its number and its string, then give it to him. Abu Dawud said : None of the narrators said this word in this tradition except Hammad ; That is, “ If he tells its number.”}}
\hadithdefcmd{abudawud}{1704}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرَ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ يَزِيدَ، مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ اللُّقَطَةِ فَقَالَ ‏"‏ عَرِّفْهَا سَنَةً ثُمَّ اعْرِفْ وِكَاءَهَا وَعِفَاصَهَا ثُمَّ اسْتَنْفِقْ بِهَا فَإِنْ جَاءَ رَبُّهَا فَأَدِّهَا إِلَيْهِ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ فَضَالَّةُ الْغَنَمِ فَقَالَ ‏"‏ خُذْهَا فَإِنَّمَا هِيَ لَكَ أَوْ لأَخِيكَ أَوْ لِلذِّئْبِ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ فَضَالَّةُ الإِبِلِ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى احْمَرَّتْ وَجْنَتَاهُ - أَوِ احْمَرَّ وَجْهُهُ - وَقَالَ ‏"‏ مَا لَكَ وَلَهَا مَعَهَا حِذَاؤُهَا وَسِقَاؤُهَا حَتَّى يَأْتِيَهَا رَبُّهَا ‏"‏ ‏.‏\hadithno{1704}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2436) Sahih Muslim (1722)}\hadithtrans{Zaid bin Khalid al-Juhani said :A man asked the Messenger of Allah (SWAS) about a find. He said: Make the matter known for a year, then note its string and its container and then use it for your purpose. Then if its owner comes, give it to him. He asked : Messenger of Allah, what about a stray sheep? He replied: Take it; that is for you, or for your brother, or for the wolf. He again asked: Messenger of Allah, What about stray camels? The Messenger of Allah (SWAS) became angry so much so that his cheeks became red or ( the narrator is doubtful) his face became red. He replied: What have you to do with them? They have with them their feet and their stomachs (for drink) till their master comes to him}}
\hadithdefcmd{abudawud}{1705}{حَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكٌ، بِإِسْنَادِهِ وَمَعْنَاهُ زَادَ ‏"‏ سِقَاؤُهَا تَرِدُ الْمَاءَ وَتَأْكُلُ الشَّجَرَ ‏"‏ ‏.‏ وَلَمْ يَقُلْ ‏"‏ خُذْهَا ‏"‏ ‏.‏ فِي ضَالَّةِ الشَّاءِ وَقَالَ فِي اللُّقَطَةِ ‏"‏ عَرِّفْهَا سَنَةً فَإِنْ جَاءَ صَاحِبُهَا وَإِلاَّ فَشَأْنَكَ بِهَا ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ ‏"‏ اسْتَنْفِقْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الثَّوْرِيُّ وَسُلَيْمَانُ بْنُ بِلاَلٍ وَحَمَّادُ بْنُ سَلَمَةَ عَنْ رَبِيعَةَ مِثْلَهُ لَمْ يَقُولُوا ‏"‏ خُذْهَا ‏"‏ ‏.‏\hadithno{1705}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The above mentioned tradition has also been transmitted by Malik through a different chain of narrators to the same effect. This version adds:They have their stomachs: They can go down to water and eat trees. He did not say about the stray sheep: take it. About a find he said : Make it known for a year; if it’s owner comes, (give it to him), otherwise use it yourself. This version has not the word : “ spend it”. Abu Dawud said : This tradition has been narrated by al-Thawri, Sulaiman bin Bilal, and Hammad bin Salamah on the authority of Rabi ‘ ah in a similar manner. They did not mention the word “take it”}}
\hadithdefcmd{abudawud}{1706}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، - الْمَعْنَى - قَالاَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ الضَّحَّاكِ، - يَعْنِي ابْنَ عُثْمَانَ - عَنْ سَالِمِ أَبِي النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ اللُّقَطَةِ فَقَالَ ‏ "‏ عَرِّفْهَا سَنَةً فَإِنْ جَاءَ بَاغِيهَا فَأَدِّهَا إِلَيْهِ وَإِلاَّ فَاعْرِفْ عِفَاصَهَا وَوِكَاءَهَا ثُمَّ كُلْهَا فَإِنْ جَاءَ بَاغِيهَا فَأَدِّهَا إِلَيْهِ ‏"‏ ‏.‏\hadithno{1706}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1722)}\hadithtrans{Narrated Zayd ibn Khalid al-Juhani: The Messenger of Allah (ﷺ) was asked about a find. He said: Make it known for a year. If its seeker comes, deliver it to him, otherwise note its container and its string. Then use it; if its seeker comes, deliver it to him}}
\hadithdefcmd{abudawud}{1707}{حَدَّثَنَا أَحْمَدُ بْنُ حَفْصٍ، حَدَّثَنِي أَبِي، حَدَّثَنِي إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ عَبَّادِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ أَبِيهِ، يَزِيدَ مَوْلَى الْمُنْبَعِثِ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّهُ قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَذَكَرَ نَحْوَ حَدِيثِ رَبِيعَةَ ‏.‏ قَالَ وَسُئِلَ عَنِ اللُّقَطَةِ فَقَالَ ‏ "‏ تُعَرِّفُهَا حَوْلاً فَإِنْ جَاءَ صَاحِبُهَا دَفَعْتَهَا إِلَيْهِ وَإِلاَّ عَرَفْتَ وِكَاءَهَا وَعِفَاصَهَا ثُمَّ أَفِضْهَا فِي مَالِكَ فَإِنْ جَاءَ صَاحِبُهَا فَادْفَعْهَا إِلَيْهِ ‏"‏ ‏.‏\hadithno{1707}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The aforesaid tradition has also been transmitted by Zaid bin Khalid al-Juhani through a different chain of narrators. This version has:The Messenger of Allah (SWAS) was asked about a find. He replied : Make the matter known for a year; if its owner comes, give it to him, otherwise note its string and its container and have it along with your property. If its owner comes, deliver it to him}}
\hadithdefcmd{abudawud}{1708}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، وَرَبِيعَةَ، بِإِسْنَادِ قُتَيْبَةَ وَمَعْنَاهُ وَزَادَ فِيهِ ‏"‏ فَإِنْ جَاءَ بَاغِيهَا فَعَرَفَ عِفَاصَهَا وَعَدَدَهَا فَادْفَعْهَا إِلَيْهِ ‏"‏ ‏.‏ وَقَالَ حَمَّادٌ أَيْضًا عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَمْرِو بْنِ شُعَيْبٍ عَنْ أَبِيهِ عَنْ جَدِّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذِهِ الزِّيَادَةُ الَّتِي زَادَ حَمَّادُ بْنُ سَلَمَةَ فِي حَدِيثِ سَلَمَةَ بْنِ كُهَيْلٍ وَيَحْيَى بْنِ سَعِيدٍ وَعُبَيْدِ اللَّهِ بْنِ عُمَرَ وَرَبِيعَةَ ‏"‏ إِنْ جَاءَ صَاحِبُهَا فَعَرَفَ عِفَاصَهَا وَوِكَاءَهَا فَادْفَعْهَا إِلَيْهِ ‏"‏ ‏.‏ لَيْسَتْ بِمَحْفُوظَةٍ ‏"‏ فَعَرَفَ عِفَاصَهَا وَوِكَاءَهَا ‏"‏ ‏.‏ وَحَدِيثُ عُقْبَةَ بْنِ سُوَيْدٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم أَيْضًا قَالَ ‏"‏ عَرِّفْهَا سَنَةً ‏"‏ ‏.‏ وَحَدِيثُ عُمَرَ بْنِ الْخَطَّابِ أَيْضًا عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ عَرِّفْهَا سَنَةً ‏"‏ ‏.‏\hadithno{1708}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1722)}\hadithtrans{The above mentioned tradition has also been transmitted by Yahya bin Sa’id and Rabi’ah through the chain of narrators mentioned by Qutaibah to the same effect. This version adds; if its seeker comes, and recognizes its container and its number, then give it to him. Hammad also narrated it from `Ubaid Allah bin `Umar from `Amr bin Shu’aib, from his father, from his grandfather, from the Prophet (SWAS) something similar. Abu Dawud said :This addition made by Hammad bin Salamah bin Kuhail, Yahya bin Sa’id, `Ubaid Allah bin `Umar and Rabi’ah; “if its owner comes and recognizes its container, and its string,” is not guarded. The version narrated by Uqbah bin Suwaid on the authority of his father from the Prophet (SWAS) has also the words : “make it known for a year”. The version of `Umar bin al-Khattab has also been transmitted from the Prophet (SWAS). This version has : “Make it known for a year”}}
\hadithdefcmd{abudawud}{1709}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدٌ يَعْنِي الطَّحَّانَ، ح وَحَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، - الْمَعْنَى - عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي الْعَلاَءِ، عَنْ مُطَرِّفٍ، - يَعْنِي ابْنَ عَبْدِ اللَّهِ - عَنْ عِيَاضِ بْنِ حِمَارٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ وَجَدَ لُقَطَةً فَلْيُشْهِدْ ذَا عَدْلٍ - أَوْ ذَوَىْ عَدْلٍ - وَلاَ يَكْتُمْ وَلاَ يُغَيِّبْ فَإِنْ وَجَدَ صَاحِبَهَا فَلْيَرُدَّهَا عَلَيْهِ وَإِلاَّ فَهُوَ مَالُ اللَّهِ عَزَّ وَجَلَّ يُؤْتِيهِ مَنْ يَشَاءُ ‏"‏ ‏.‏\hadithno{1709}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Iyad ibn Himar: The Prophet (ﷺ) said: He who finds something should call one or two trusty persons as witnesses and not conceal it or cover it up; then if he finds its owner he should return it to him, otherwise it is Allah's property which He gives to whom He will}}
\hadithdefcmd{abudawud}{1710}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ سُئِلَ عَنِ الثَّمَرِ الْمُعَلَّقِ فَقَالَ ‏"‏ مَنْ أَصَابَ بِفِيهِ مِنْ ذِي حَاجَةٍ غَيْرَ مُتَّخِذٍ خُبْنَةً فَلاَ شَىْءَ عَلَيْهِ وَمَنْ خَرَجَ بِشَىْءٍ مِنْهُ فَعَلَيْهِ غَرَامَةُ مِثْلَيْهِ وَالْعُقُوبَةُ وَمَنْ سَرَقَ مِنْهُ شَيْئًا بَعْدَ أَنْ يُئْوِيَهُ الْجَرِينُ فَبَلَغَ ثَمَنَ الْمِجَنِّ فَعَلَيْهِ الْقَطْعُ ‏"‏ ‏.‏ وَذَكَرَ فِي ضَالَّةِ الإِبِلِ وَالْغَنَمِ كَمَا ذَكَرَهُ غَيْرُهُ قَالَ وَسُئِلَ عَنِ اللُّقَطَةِ فَقَالَ ‏"‏ مَا كَانَ مِنْهَا فِي طَرِيقِ الْمِيتَاءِ أَوِ الْقَرْيَةِ الْجَامِعَةِ فَعَرِّفْهَا سَنَةً فَإِنْ جَاءَ طَالِبُهَا فَادْفَعْهَا إِلَيْهِ وَإِنْ لَمْ يَأْتِ فَهِيَ لَكَ وَمَا كَانَ فِي الْخَرَابِ - يَعْنِي - فَفِيهَا وَفِي الرِّكَازِ الْخُمُسُ ‏"‏ ‏.‏\hadithno{1710}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) was asked about the hanging fruit. He replied: If a needy person takes some and does not take a supply away in his garment, he is not to be blamed, but he who carries any of it away is to be find twice the value and punished, and he who steals any of it after it has been put in the place where dates are dried is to have his hand cut off if its value reaches the price of a shield. Regarding stray camels and sheep he mentioned the same as others have done. He said: He was asked about finds and replied: If it is in a frequented road and a large town, make the matter known for a year, and if its owner comes, give it to him, but if he does not, it belongs to you. If it is in a place which has been a waste from ancient time, or if it is a hidden treasure (belonging to the Islamic period), it is subject to the payment of the fifth}}
\hadithdefcmd{abudawud}{1711}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ، - يَعْنِي ابْنَ كَثِيرٍ - حَدَّثَنِي عَمْرُو بْنُ شُعَيْبٍ، بِإِسْنَادِهِ بِهَذَا قَالَ فِي ضَالَّةِ الشَّاءِ قَالَ ‏ "‏ فَاجْمَعْهَا ‏"‏ ‏.‏\hadithno{1711}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{The above mentioned tradition has also been transmitted by ‘Amr bin Shu’aib through a different chain of narrators. This version adds:regarding the stray sheep he said : “Take it”}}
\hadithdefcmd{abudawud}{1712}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ الأَخْنَسِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، بِهَذَا بِإِسْنَادِهِ قَالَ فِي ضَالَّةِ الْغَنَمِ ‏"‏ لَكَ أَوْ لأَخِيكَ أَوْ لِلذِّئْبِ خُذْهَا قَطُّ ‏"‏ ‏.‏ كَذَا قَالَ فِيهِ أَيُّوبُ وَيَعْقُوبُ بْنُ عَطَاءٍ عَنْ عَمْرِو بْنِ شُعَيْبٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ فَخُذْهَا ‏"‏ ‏.‏\hadithno{1712}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{The aforesaid tradition has also been transmitted by ‘Amr bin Shu’aib through a different chain of narrators. This version has:He said about the stray sheep: You, your brother or the wolf may have them. Do take it. A similar version has been transmitted by Ayyub and Ya’qub bin `Ata from `Amr bin Shu’aid from the Propher (SWAS). He said : then take it}}
\hadithdefcmd{abudawud}{1713}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا ابْنُ الْعَلاَءِ، حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنِ ابْنِ إِسْحَاقَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا ‏.‏ قَالَ فِي ضَالَّةِ الشَّاءِ ‏ "‏ فَاجْمَعْهَا حَتَّى يَأْتِيَهَا بَاغِيهَا ‏"‏ ‏.‏\hadithno{1713}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{The above mentioned tradition has also been narrated by ‘Amr bin Shu’aib from his father, from his grandfather, from the Prophet (SWAS) to the same effect. This version has:regarding the stray sheep he said: Take it (and keep it with you) till its seeker comes to it}}
\hadithdefcmd{abudawud}{1714}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ مِقْسَمٍ، حَدَّثَهُ عَنْ رَجُلٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ، وَجَدَ دِينَارًا فَأَتَى بِهِ فَاطِمَةَ فَسَأَلَتْ عَنْهُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ هُوَ رِزْقُ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏ فَأَكَلَ مِنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَكَلَ عَلِيٌّ وَفَاطِمَةُ فَلَمَّا كَانَ بَعْدَ ذَلِكَ أَتَتْهُ امْرَأَةٌ تَنْشُدُ الدِّينَارَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا عَلِيُّ أَدِّ الدِّينَارَ ‏"‏ ‏.‏\hadithno{1714}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Sa'id al-Khudri: Ali ibn AbuTalib found a dinar and he took it to Fatimah. She asked the Messenger of Allah (ﷺ) about it. He said: This is Allah's provision. Then the Messenger of Allah (ﷺ) ate out of the food (bought with it), and Ali and Fatimah also ate out of that food. But afterwards a woman came crying out about the dinar. The Prophet (ﷺ) said: Pay the dinar, Ali}}
\hadithdefcmd{abudawud}{1715}{حَدَّثَنَا الْهَيْثَمُ بْنُ خَالِدٍ الْجُهَنِيُّ، حَدَّثَنَا وَكِيعٌ، عَنْ سَعْدِ بْنِ أَوْسٍ، عَنْ بِلاَلِ بْنِ يَحْيَى الْعَبْسِيِّ، عَنْ عَلِيٍّ، رضى الله عنه أَنَّهُ الْتَقَطَ دِينَارًا فَاشْتَرَى بِهِ دَقِيقًا فَعَرَفَهُ صَاحِبُ الدَّقِيقِ فَرَدَّ عَلَيْهِ الدِّينَارَ فَأَخَذَهُ عَلِيٌّ وَقَطَعَ مِنْهُ قِيرَاطَيْنِ فَاشْتَرَى بِهِ لَحْمًا ‏.‏\hadithno{1715}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ali ibn Abu Talib: Bilal ibn Yahya al-Absi said: Ali found a dinar and purchased some flour with it. The seller of the flour recognised him and returned the dinar to him. Ali took it, deducted two qirat (carat) from it, and purchased meat with it}}
\hadithdefcmd{abudawud}{1716}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ التِّنِّيسِيُّ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنَا مُوسَى بْنُ يَعْقُوبَ الزَّمْعِيُّ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَخْبَرَهُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ دَخَلَ عَلَى فَاطِمَةَ وَحَسَنٌ وَحُسَيْنٌ يَبْكِيَانِ فَقَالَ مَا يُبْكِيهِمَا قَالَتِ الْجُوعُ فَخَرَجَ عَلِيٌّ فَوَجَدَ دِينَارًا بِالسُّوقِ فَجَاءَ إِلَى فَاطِمَةَ فَأَخْبَرَهَا فَقَالَتِ اذْهَبْ إِلَى فُلاَنٍ الْيَهُودِيِّ فَخُذْ دَقِيقًا فَجَاءَ الْيَهُودِيَّ فَاشْتَرَى بِهِ دَقِيقًا فَقَالَ الْيَهُودِيُّ أَنْتَ خَتَنُ هَذَا الَّذِي يَزْعُمُ أَنَّهُ رَسُولُ اللَّهِ قَالَ نَعَمْ ‏.‏ قَالَ فَخُذْ دِينَارَكَ وَلَكَ الدَّقِيقُ ‏.‏ فَخَرَجَ عَلِيٌّ حَتَّى جَاءَ فَاطِمَةَ فَأَخْبَرَهَا فَقَالَتِ اذْهَبْ إِلَى فُلاَنٍ الْجَزَّارِ فَخُذْ لَنَا بِدِرْهَمٍ لَحْمًا فَذَهَبَ فَرَهَنَ الدِّينَارَ بِدِرْهَمِ لَحْمٍ فَجَاءَ بِهِ فَعَجَنَتْ وَنَصَبَتْ وَخَبَزَتْ وَأَرْسَلَتْ إِلَى أَبِيهَا فَجَاءَهُمْ فَقَالَتْ يَا رَسُولَ اللَّهِ أَذْكُرُ لَكَ فَإِنْ رَأَيْتَهُ لَنَا حَلاَلاً أَكَلْنَاهُ وَأَكَلْتَ مَعَنَا مِنْ شَأْنِهِ كَذَا وَكَذَا ‏.‏ فَقَالَ ‏"‏ كُلُوا بِاسْمِ اللَّهِ ‏"‏ ‏.‏ فَأَكَلُوا فَبَيْنَمَا هُمْ مَكَانَهُمْ إِذَا غُلاَمٌ يَنْشُدُ اللَّهَ وَالإِسْلاَمَ الدِّينَارَ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَدُعِيَ لَهُ فَسَأَلَهُ ‏.‏ فَقَالَ سَقَطَ مِنِّي فِي السُّوقِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا عَلِيُّ اذْهَبْ إِلَى الْجَزَّارِ فَقُلْ لَهُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ لَكَ أَرْسِلْ إِلَىَّ بِالدِّينَارِ وَدِرْهَمُكَ عَلَىَّ ‏"‏ ‏.‏ فَأَرْسَلَ بِهِ فَدَفَعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَيْهِ ‏.‏\hadithno{1716}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sahl bin Sa’d said :`Ali bin Abi Talib entered upon Fatimah while Hasan and Husain were crying. He asked: Why are they crying? She replied: Due to hunger. ‘Ali went out and found a dinar in the market. He then came to Fatima and told her about it. She said: Go to such and such a Jew and get some flour for us. He came to the Jew and purchased flour with it. He said : Are you the son-in-law of him who believes that he is the Messenger of Allah. He said : Yes. The Jew said : Have your dinar with you and you will get the flour. Ali then went out and came to Fatima. He told her about the matter. She then said: Go to such and such a butcher and get some meat for us for a dirham. Ali went out and pawned the dinar for a dirham with him and got the meat, and brought it (to her). She then kneaded the flour, put the utensil on fire and baked the bread. She sent for her father : (i.e. the Prophet (SWAS). He came to them. She said to him : Messenger of Allah, I tell you all the matter. If you think it is lawful for us, we shall eat it and you will eat with us. She said: The matter is such and such. He said: eat in the name of Allah. So they ate it. While they were (eating) at their place, a boy cried adguring in the name of Allah and Islam: He was searching the dinar. The Messenger of Allah (SWAS) commanded and he was called in. He asked him. The boy replied, I lost it somewhere in the market. The Prophet (SWAS) said : `Ali, go to the butcher and tell him that the Messenger of Allah (SWAS) has asked you : send the dinar to me and one dirham of yours will be due on me. The butcher returned it and the Messenger of Allah (SWAS) handed it to him (the boy)}}
\hadithdefcmd{abudawud}{1717}{حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ الدِّمَشْقِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبٍ، عَنِ الْمُغِيرَةِ بْنِ زِيَادٍ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، أَنَّهُ حَدَّثَهُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ رَخَّصَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْعَصَا وَالسَّوْطِ وَالْحَبْلِ وَأَشْبَاهِهِ يَلْتَقِطُهُ الرَّجُلُ يَنْتَفِعُ بِهِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ النُّعْمَانُ بْنُ عَبْدِ السَّلاَمِ عَنِ الْمُغِيرَةِ أَبِي سَلَمَةَ بِإِسْنَادِهِ وَرَوَاهُ شَبَابَةُ عَنْ مُغِيرَةَ بْنِ مُسْلِمٍ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ قَالَ كَانُوا لَمْ يَذْكُرِ النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{1717}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Messenger of Allah (ﷺ) gave us licence to use (for our purpose) a stick, a rope, a whip and things of that type which a man picked up; he may benefit from them}}
\hadithdefcmd{abudawud}{1718}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ عَمْرِو بْنِ مُسْلِمٍ، عَنْ عِكْرِمَةَ، - أَحْسَبُهُ - عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ ضَالَّةُ الإِبِلِ الْمَكْتُومَةِ غَرَامَتُهَا وَمِثْلُهَا مَعَهَا ‏"‏ ‏.‏\hadithno{1718}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurayrah: The Prophet (ﷺ) said: He who hides a stray camel shall pay a fine, and a like compensation with it}}
\hadithdefcmd{abudawud}{1719}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ مَوْهَبٍ، وَأَحْمَدُ بْنُ صَالِحٍ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنْ بُكَيْرٍ، عَنْ يَحْيَى بْنِ عَبْدِ الرَّحْمَنِ بْنِ حَاطِبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عُثْمَانَ التَّيْمِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ لُقَطَةِ الْحَاجِّ ‏.‏ قَالَ أَحْمَدُ قَالَ ابْنُ وَهْبٍ يَعْنِي فِي لُقَطَةِ الْحَاجِّ يَتْرُكُهَا حَتَّى يَجِدَهَا صَاحِبُهَا قَالَ ابْنُ مَوْهَبٍ عَنْ عَمْرٍو ‏.‏\hadithno{1719}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1724)}\hadithtrans{‘Abd al-Rahman bin `Uthman al-Taime said:The Messenger of Allah (SWAS) prohibited taking the find of pilgrims. Ibn Wahb said : One should leave the find of a pilgrim till its owner finds it}}
\hadithdefcmd{abudawud}{1720}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا خَالِدٌ، عَنْ أَبِي حَيَّانَ التَّيْمِيِّ، عَنِ الْمُنْذِرِ بْنِ جَرِيرٍ، قَالَ كُنْتُ مَعَ جَرِيرٍ بِالْبَوَازِيجِ فَجَاءَ الرَّاعِي بِالْبَقَرِ وَفِيهَا بَقَرَةٌ لَيْسَتْ مِنْهَا فَقَالَ لَهُ جَرِيرٌ مَا هَذِهِ قَالَ لَحِقَتْ بِالْبَقَرِ لاَ نَدْرِي لِمَنْ هِيَ ‏.‏ فَقَالَ جَرِيرٌ أَخْرِجُوهَا فَقَدْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَأْوِي الضَّالَّةَ إِلاَّ ضَالٌّ ‏"‏ ‏.‏\hadithno{1720}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Mundhir ibn Jarir: I accompanied Jarir at Bawazij. The shepherd brought the cows. Among them there was a cow that was not one of them. Jarir asked him: What is this? He replied: This was mixed with the cows and we do not know to whom it belongs. Jarir said: Take it out. I heard the Messenger of Allah (ﷺ) say: No one mixes a stray animal (with his animals) but a man who strays from right path}}
