% Auto-generated chapter 13 for muslim
% Hadiths in this chapter: 285

\hadithdefcmd{muslim}{2495}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ أَبِي سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا جَاءَ رَمَضَانُ فُتِّحَتْ أَبْوَابُ الْجَنَّةِ وَغُلِّقَتْ أَبْوَابُ النَّارِ وَصُفِّدَتِ الشَّيَاطِينُ ‏"‏ ‏.‏\hadithno{2495}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When there comes the month of Ramadan, the gates of mercy are opened, and the gates of Hell are locked and the devils are chained}}
\hadithdefcmd{muslim}{2496}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ أَبِي أَنَسٍ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، - رضى الله عنه - يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ رَمَضَانُ فُتِّحَتْ أَبْوَابُ الرَّحْمَةِ وَغُلِّقَتْ أَبْوَابُ جَهَنَّمَ وَسُلْسِلَتِ الشَّيَاطِينُ ‏"‏ ‏.‏\hadithno{2496}\hadithtrans{Narrated Abu Huraira:Abu Huraira reported Allah's Messenger (ﷺ) as saying: When it is the month of Ramadan, the gates of mercy are opened, and the gates of Hell are locked and the devils are chained}}
\hadithdefcmd{muslim}{2497}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَالْحُلْوَانِيُّ، قَالاَ حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي نَافِعُ بْنُ أَبِي أَنَسٍ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، - رضى الله عنه - يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دَخَلَ رَمَضَانُ ‏"‏ ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{2497}\hadithtrans{This hadith is reported by Abu Huraira (with a slight alteration of words) that the Messenger of Allah (ﷺ) said:" When (the month of) Ramadan begins}}
\hadithdefcmd{muslim}{2498}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ ذَكَرَ رَمَضَانَ فَقَالَ ‏ "‏ لاَ تَصُومُوا حَتَّى تَرَوُا الْهِلاَلَ وَلاَ تُفْطِرُوا حَتَّى تَرَوْهُ فَإِنْ أُغْمِيَ عَلَيْكُمْ فَاقْدِرُوا لَهُ ‏"‏ ‏.‏\hadithno{2498}\hadithtrans{Ibn Umar (Allah be pleased with both of them) reported Allah's Messenger (ﷺ) as saying in connection with Ramadan:Do not fast till you see the new moon, and do not break fast till you see it; but if the weather is cloudy calculate about it}}
\hadithdefcmd{muslim}{2499}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ رَمَضَانَ فَضَرَبَ بِيَدَيْهِ فَقَالَ ‏ "‏ الشَّهْرُ هَكَذَا وَهَكَذَا وَهَكَذَا - ثُمَّ عَقَدَ إِبْهَامَهُ فِي الثَّالِثَةِ - فَصُومُوا لِرُؤْيَتِهِ وَأَفْطِرُوا لِرُؤْيَتِهِ فَإِنْ أُغْمِيَ عَلَيْكُمْ فَاقْدِرُوا لَهُ ثَلاَثِينَ ‏"‏ ‏.‏\hadithno{2499}\hadithtrans{Ibn Umar reported that Allah's Messenger (ﷺ) made a mention of Ramadan and he with the gesture of his hand said:The month is thus and thus. (He then withdrew his thumb at the third time). He then said: Fast when you see it, and break your fast when you see it, and if the weather is cloudy calculate it (the months of Sha'ban and Shawwal) as thirty days}}
\hadithdefcmd{muslim}{2500}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ فَإِنْ غُمَّ عَلَيْكُمْ فَاقْدِرُوا ثَلاَثِينَ ‏"‏ ‏.‏ نَحْوَ حَدِيثِ أَبِي أُسَامَةَ ‏.‏\hadithno{2500}\hadithtrans{This hadith is narrated on the authority of 'Ubaidullah with the same chain of transmitters, and he said:If (the sky) is cloudy for you, then calculate thirty days (for the month of Ramadan)}}
\hadithdefcmd{muslim}{2501}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ وَقَالَ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَمَضَانَ فَقَالَ ‏"‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ الشَّهْرُ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ وَقَالَ ‏"‏ فَاقْدِرُوا لَهُ ‏"‏ ‏.‏ وَلَمْ يَقُلْ ‏"‏ ثَلاَثِينَ ‏"‏ ‏.‏\hadithno{2501}\hadithtrans{Ubaidullah narrated on the authority of the same chain of transmitters that the Messenger of Allah (ﷺ) made a mention of Ramadan and said:The month may consist of twenty-nine days, and it may be thus, thus and thus, and (he further) said: Calculate it, but he did not say thirty}}
\hadithdefcmd{muslim}{2502}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الشَّهْرُ تِسْعٌ وَعِشْرُونَ فَلاَ تَصُومُوا حَتَّى تَرَوْهُ وَلاَ تُفْطِرُوا حَتَّى تَرَوْهُ فَإِنْ غُمَّ عَلَيْكُمْ فَاقْدِرُوا لَهُ ‏"‏ ‏.‏\hadithno{2502}\hadithtrans{Ibn'Umar (Allah be pleased with-both of them) reported Allah's Messenger (ﷺ) as saying:The month of Ramadan may consist of twenty-nine days. So do not fast till you have sighted it (the new moon) and do not break fast, till you have sighted it (the new moon of Shawwal), and if the sky is cloudy for you, then calculate}}
\hadithdefcmd{muslim}{2503}{وَحَدَّثَنِي حُمَيْدُ بْنُ مَسْعَدَةَ الْبَاهِلِيُّ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا سَلَمَةُ، - وَهُوَ ابْنُ عَلْقَمَةَ - عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، - رضى الله عنهما - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ فَإِذَا رَأَيْتُمُ الْهِلاَلَ فَصُومُوا وَإِذَا رَأَيْتُمُوهُ فَأَفْطِرُوا فَإِنْ غُمَّ عَلَيْكُمْ فَاقْدِرُوا لَهُ ‏"‏ ‏.‏\hadithno{2503}\hadithtrans{Abdullah b. 'Umar (Allah be pleased with both of them) reported Allah's Messenger (ﷺ) as saying:The month (of Ramadan) may consist of twenty nine days; so when you see the new moon observe fast and when you see (the new moon again at the commencement of the month of Shawwal) then break It, and if the sky is cloudy for you, then calculate it (and complete thirty days)}}
\hadithdefcmd{muslim}{2504}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، - رضى الله عنهما - قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا رَأَيْتُمُوهُ فَصُومُوا وَإِذَا رَأَيْتُمُوهُ فَأَفْطِرُوا فَإِنْ غُمَّ عَلَيْكُمْ فَاقْدِرُوا لَهُ ‏"‏ ‏.‏\hadithno{2504}\hadithtrans{Abdullah b. Umar (Allah be pleased with both of them) reported Allah's Measenger (ﷺ) as saying:When you see the new moon, observe fast, and when you see it (again) then break it, and if the sky is cloudy for you, then calculate it}}
\hadithdefcmd{muslim}{2505}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، حُجْرٍ قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ عَبْدِ اللَّهِ بْنِ، دِينَارٍ أَنَّهُ سَمِعَ ابْنَ عُمَرَ، - رضى الله عنهما - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ لَيْلَةً لاَ تَصُومُوا حَتَّى تَرَوْهُ وَلاَ تُفْطِرُوا حَتَّى تَرَوْهُ إِلاَّ أَنْ يُغَمَّ عَلَيْكُمْ فَإِنْ غُمَّ عَلَيْكُمْ فَاقْدِرُوا لَهُ ‏"‏‏.‏\hadithno{2505}\hadithtrans{Ibn 'Umar (Allah be pleased with both of them) reported Allah's Messenger (ﷺ) as saying:The month may consist of twenty-nine nights. So do not fast till you have sighted it (the new moon) and do not break it till you have sighted it, except when the sky is cloudy for you, and if it is so, then calculate it}}
\hadithdefcmd{muslim}{2506}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ، - رضى الله عنهما - يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الشَّهْرُ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ وَقَبَضَ إِبْهَامَهُ فِي الثَّالِثَةِ ‏.‏\hadithno{2506}\hadithtrans{Ibn Umar (Allah be pleased with both of them) reported Allah's Messenger (ﷺ) as saying:The month is thus and thus and thus (i. e. pointing with his fingers thrice), and he held back his thumb at the third time (in order to show that it can also consist of twenty-nine days)}}
\hadithdefcmd{muslim}{2507}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا حَسَنٌ الأَشْيَبُ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، قَالَ وَأَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ، - رضى الله عنهما - يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ ‏"‏ ‏.‏\hadithno{2507}\hadithtrans{Ibn Umar (Allah be pleased with both of them) reported Allah's Messenger (ﷺ) as saying:The month may consist of twenty-nine days}}
\hadithdefcmd{muslim}{2508}{وَحَدَّثَنَا سَهْلُ بْنُ عُثْمَانَ، حَدَّثَنَا زِيَادُ بْنُ عَبْدِ اللَّهِ الْبَكَّائِيُّ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، - رضى الله عنهما - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الشَّهْرُ هَكَذَا وَهَكَذَا وَهَكَذَا عَشْرًا وَعَشْرًا وَتِسْعًا ‏"‏ ‏.‏\hadithno{2508}\hadithtrans{Abdullah b. 'Umar (Allah be pleased with both of them) reported Allah's Messenger (ﷺ) as saying:The month (of Ramadan) is thus and thus, and thus. i.e. ten, ten and nine}}
\hadithdefcmd{muslim}{2509}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ جَبَلَةَ، قَالَ سَمِعْتُ ابْنَ، عُمَرَ - رضى الله عنهما - يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشَّهْرُ كَذَا وَكَذَا وَكَذَا ‏"‏ ‏.‏ وَصَفَّقَ بِيَدَيْهِ مَرَّتَيْنِ بِكُلِّ أَصَابِعِهِمَا وَنَقَصَ فِي الصَّفْقَةِ الثَّالِثَةِ إِبْهَامَ الْيُمْنَى أَوِ الْيُسْرَى ‏.‏\hadithno{2509}\hadithtrans{Ibn Umar (Allah be pleased with both of them) reported Allah's Messenger (ﷺ) as saying:The month is thus, and thus, and thus, and he flapped his hands with all their fingers twice. but at the third turn, folded his right thumb or left thumb (in order to give an idea of twenty-nine)}}
\hadithdefcmd{muslim}{2510}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عُقْبَةَ، - وَهُوَ ابْنُ حُرَيْثٍ - قَالَ سَمِعْتُ ابْنَ عُمَرَ، - رضى الله عنهما - يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ ‏"‏ ‏.‏ وَطَبَّقَ شُعْبَةُ يَدَيْهِ ثَلاَثَ مِرَارٍ وَكَسَرَ الإِبْهَامَ فِي الثَّالِثَةِ ‏.‏ قَالَ عُقْبَةُ وَأَحْسِبُهُ قَالَ ‏"‏ الشَّهْرُ ثَلاَثُونَ ‏"‏ وَطَبَّقَ كَفَّيْهِ ثَلاَثَ مِرَارٍ ‏.‏\hadithno{2510}\hadithtrans{Ibn 'Umar (Allah be pleased with both of them) reported Allah's Messenger (ﷺ) as saying:The month (of Ramadan) may consist of twenty nine days, and Shu'ba (one of the narrators) (gave a practical demonstration how the Holy prophet (ﷺ) explained to them) by unfolding his hands thrice and folding his thumb at the third turn. 'Uqba (one of the narrators in this chain of transmitters) said: I think that he said that the month consists of thirty days and unfolded his palm three times}}
\hadithdefcmd{muslim}{2511}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ عَمْرِو بْنِ سَعِيدٍ، أَنَّهُ سَمِعَ ابْنَ عُمَرَ، - رضى الله عنهما - يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّا أُمَّةٌ أُمِّيَّةٌ لاَ نَكْتُبُ وَلاَ نَحْسُبُ الشَّهْرُ هَكَذَا وَهَكَذَا وَهَكَذَا - وَعَقَدَ الإِبْهَامَ فِي الثَّالِثَةِ - وَالشَّهْرُ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ يَعْنِي تَمَامَ ثَلاَثِينَ ‏.‏\hadithno{2511}\hadithtrans{Ibn 'Umar (may Allah be pleased with both of them) reported Allah's Apostle as saying:We are an unlettered people who can neither write nor count. The month is thus, and thus. folding his thumb when he said it the third time}}
\hadithdefcmd{muslim}{2512}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ لِلشَّهْرِ الثَّانِي ثَلاَثِينَ ‏.‏\hadithno{2512}\hadithtrans{This hadith has been narrated on the authority of Aswad b. Qais with the same chain of transmitters, but herein no mention has been made of the other month (consisting of) thirty days}}
\hadithdefcmd{muslim}{2513}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا الْحَسَنُ بْنُ عُبَيْدِ، اللَّهِ عَنْ سَعْدِ بْنِ عُبَيْدَةَ، قَالَ سَمِعَ ابْنُ عُمَرَ، - رضى الله عنهما - رَجُلاً يَقُولُ اللَّيْلَةَ لَيْلَةُ النِّصْفِ فَقَالَ لَهُ مَا يُدْرِيكَ أَنَّ اللَّيْلَةَ النِّصْفُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ الشَّهْرُ هَكَذَا وَهَكَذَا ‏"‏ ‏.‏ وَأَشَارَ بِأَصَابِعِهِ الْعَشْرِ مَرَّتَيْنِ ‏"‏ وَهَكَذَا ‏"‏ ‏.‏ فِي الثَّالِثَةِ وَأَشَارَ بِأَصَابِعِهِ كُلِّهَا وَحَبَسَ أَوْ خَنَسَ إِبْهَامَهُ ‏"‏ ‏.‏\hadithno{2513}\hadithtrans{Sa'd b. 'Ubaida reported that Ibn'Umar (Allah be pleased with both of them) heard a person saying:This night is the midnight (of the month). Upon this he said to him: How do you know that it is the midnight (of the month), for I heard the Messenger of Allah (ﷺ) as saying: The month is thus and thus (and he pointed with his ten fingers twice) and thus (i. e. at the third time he pointed with all his fingers but withdrew or folded his thumb)?}}
\hadithdefcmd{muslim}{2514}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ، الْمُسَيَّبِ عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا رَأَيْتُمُ الْهِلاَلَ فَصُومُوا وَإِذَا رَأَيْتُمُوهُ فَأَفْطِرُوا فَإِنْ غُمَّ عَلَيْكُمْ فَصُومُوا ثَلاَثِينَ يَوْمًا ‏"‏ ‏.‏\hadithno{2514}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Whenever you sight the new moon (of the month of Ramadan) observe fast. and when you sight it (the new moon of Shawwal) break it, and if the sky is cloudy for you, then observe fast for thirty days}}
\hadithdefcmd{muslim}{2515}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَلاَّمٍ الْجُمَحِيُّ، حَدَّثَنَا الرَّبِيعُ، - يَعْنِي ابْنَ مُسْلِمٍ - عَنْ مُحَمَّدٍ، - وَهُوَ ابْنُ زِيَادٍ - عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ صُومُوا لِرُؤْيَتِهِ وَأَفْطِرُوا لِرُؤْيَتِهِ فَإِنْ غُمِّيَ عَلَيْكُمْ فَأَكْمِلُوا الْعَدَدَ ‏"‏ ‏.‏\hadithno{2515}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Observe fast on sighting it (the new moon) and break (fast) on sighting it (the new moon), but if the sky is cloudy for you, then complete the number (of thirty)}}
\hadithdefcmd{muslim}{2516}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، - رضى الله عنه - يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صُومُوا لِرُؤْيَتِهِ وَأَفْطِرُوا لِرُؤْيَتِهِ فَإِنْ غُمِّيَ عَلَيْكُمُ الشَّهْرُ فَعُدُّوا ثَلاَثِينَ ‏"‏ ‏.‏\hadithno{2516}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Observe fast on sighting it (the new moon) and break it on sighting it. But if (due to clouds) the actual position of the month is concealed from you, you should then count thirty (days)}}
\hadithdefcmd{muslim}{2517}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ الْعَبْدِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ، عُمَرَ عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - قَالَ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْهِلاَلَ فَقَالَ ‏ "‏ إِذَا رَأَيْتُمُوهُ فَصُومُوا وَإِذَا رَأَيْتُمُوهُ فَأَفْطِرُوا فَإِنْ أُغْمِيَ عَلَيْكُمْ فَعُدُّوا ثَلاَثِينَ ‏"‏ ‏.‏\hadithno{2517}\hadithtrans{Abu Huraira (Allah be pleased with him) narrated that the Messenger of Allah (may peace he upon him) made a mention of the new moon and (in this connection) said:Observe fast when you see it (the new moon) and break fast when you see it (the new moon of Shawwal), but when (the actual position of the month is) concealed from you (on account of cloudy sky), then count thirty days}}
\hadithdefcmd{muslim}{2518}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالَ أَبُو بَكْرٍ حَدَّثَنَا وَكِيعٌ، عَنْ عَلِيِّ، بْنِ مُبَارَكٍ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقَدَّمُوا رَمَضَانَ بِصَوْمِ يَوْمٍ وَلاَ يَوْمَيْنِ إِلاَّ رَجُلٌ كَانَ يَصُومُ صَوْمًا فَلْيَصُمْهُ ‏"‏ ‏.‏\hadithno{2518}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Do not observe fast for a day, or two days ahead of Ramadan except a person who is in the habit of observing a particular fast; he may fast on that day}}
\hadithdefcmd{muslim}{2519}{وَحَدَّثَنَاهُ يَحْيَى بْنُ بِشْرٍ الْحَرِيرِيُّ، حَدَّثَنَا مُعَاوِيَةُ، - يَعْنِي ابْنَ سَلاَّمٍ ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا هِشَامٌ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْمَجِيدِ، حَدَّثَنَا أَيُّوبُ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا حُسَيْنُ بْنُ، مُحَمَّدٍ حَدَّثَنَا شَيْبَانُ، كُلُّهُمْ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{2519}\hadithtrans{This hadith has been narrated on the authority of Yahya b. Abi Kathir with the same chain of transmitters}}
\hadithdefcmd{muslim}{2520}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَقْسَمَ أَنْ لاَ يَدْخُلَ عَلَى أَزْوَاجِهِ شَهْرًا - قَالَ الزُّهْرِيُّ - فَأَخْبَرَنِي عُرْوَةُ عَنْ عَائِشَةَ - رضى الله عنها - قَالَتْ لَمَّا مَضَتْ تِسْعٌ وَعِشْرُونَ لَيْلَةً أَعُدُّهُنَّ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم - قَالَتْ بَدَأَ بِي - فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّكَ أَقْسَمْتَ أَنْ لاَ تَدْخُلَ عَلَيْنَا شَهْرًا وَإِنَّكَ دَخَلْتَ مِنْ تِسْعٍ وَعِشْرِينَ أَعُدُّهُنَّ فَقَالَ ‏ "‏ إِنَّ الشَّهْرَ تِسْعٌ وَعِشْرُونَ ‏"‏ ‏.‏\hadithno{2520}\hadithtrans{Zuhri reported that (once) the Messenger of Allah (ﷺ) took an oath that he would not go to his wives for one Month. Zuhri said that 'Urwa narrated to him from 'A'isha (Allah be pleased with her) that she said:When twenty-nine nights were over, which I had counted, the Messenger of Allah (ﷺ) came to me (he came to me first of all). I said: Messenger of Allah, you had taken an oath that you would not come to us for a month, whereas you have come after twenty nine days which I have counted. Whereupon he said: The month may also consist of twenty-nine days}}
\hadithdefcmd{muslim}{2521}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا لَيْثٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، - رضى الله عنه - أَنَّهُ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم اعْتَزَلَ نِسَاءَهُ شَهْرًا فَخَرَجَ إِلَيْنَا فِي تِسْعٍ وَعِشْرِينَ فَقُلْنَا إِنَّمَا الْيَوْمُ تِسْعٌ وَعِشْرُونَ ‏.‏ فَقَالَ ‏ "‏ إِنَّمَا الشَّهْرُ ‏"‏ ‏.‏ وَصَفَّقَ بِيَدَيْهِ ثَلاَثَ مَرَّاتٍ وَحَبَسَ إِصْبَعًا وَاحِدَةً فِي الآخِرَةِ ‏.‏\hadithno{2521}\hadithtrans{Jabir (Allah be pleased with her) narrated that the Prophet (ﷺ) separated himself from his wives for a month. (His wives said:) He came to us on the twenty-ninth day, whereupon we said: It is the twenty-ninth (day) today. Thereupon he said: So far as the month is concerned, (and he, with a view to explaining it) flapped his hands thrice, but held back one finger at the last turn}}
\hadithdefcmd{muslim}{2522}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، وَحَجَّاجُ بْنُ الشَّاعِرِ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، - رضى الله عنهما - يَقُولُ اعْتَزَلَ النَّبِيُّ صلى الله عليه وسلم نِسَاءَهُ شَهْرًا فَخَرَجَ إِلَيْنَا صَبَاحَ تِسْعٍ وَعِشْرِينَ فَقَالَ بَعْضُ الْقَوْمِ يَا رَسُولَ اللَّهِ إِنَّمَا أَصْبَحْنَا لِتِسْعٍ وَعِشْرِينَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّ الشَّهْرَ يَكُونُ تِسْعًا وَعِشْرِينَ ‏"‏ ‏.‏ ثُمَّ طَبَّقَ النَّبِيُّ صلى الله عليه وسلم بِيَدَيْهِ ثَلاَثًا مَرَّتَيْنِ بِأَصَابِعِ يَدَيْهِ كُلِّهَا وَالثَّالِثَةَ بِتِسْعٍ مِنْهَا ‏.‏\hadithno{2522}\hadithtrans{Abu Zubair is reported to have heard Jabir b. 'Abdullah (Allah be pleased with both of them) as saying:The Apostle of Allah (ﷺ) separated himself from his wives for a month. (His wives said: ) He came to us on the morning of the twenty-ninth. Upon this some, of the people said: It is the morning of twenty- ninth (according to our calculation). Upon this the Messenger of Allah (ﷺ) said: The month. may also consist of twenty-nine days. The Apostle of Allah (ﷺ) then flapped his bands thrice, twice with all the fingers of both his hand (to indicate twenty-nine) and by the third time with nine (fingers)}}
\hadithdefcmd{muslim}{2523}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي يَحْيَى بْنُ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ صَيْفِيٍّ، أَنَّ عِكْرِمَةَ بْنَ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، أَخْبَرَهُ أَنَّ أُمَّ سَلَمَةَ - رضى الله عنها - أَخْبَرَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم حَلَفَ أَنْ لاَ يَدْخُلَ عَلَى بَعْضِ أَهْلِهِ شَهْرًا فَلَمَّا مَضَى تِسْعَةٌ وَعِشْرُونَ يَوْمًا غَدَا عَلَيْهِمْ - أَوْ رَاحَ - فَقِيلَ لَهُ حَلَفْتَ يَا نَبِيَّ اللَّهِ أَنْ لاَ تَدْخُلَ عَلَيْنَا شَهْرًا ‏.‏ قَالَ ‏ "‏ إِنَّ الشَّهْرَ يَكُونُ تِسْعَةً وَعِشْرِينَ يَوْمًا ‏"‏ ‏.‏\hadithno{2523}\hadithtrans{Umm Salama (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) took an oath that he would not go to some of his wives for the whole of the month. When twenty-nine days bad passed he (the Holy Prophet) went to them in the morning or in the evening. Upon this it was said to him:Apostle of Allah, you took an oath that you would not come to us for a month, whereupon he said: The month may also consist of twenty-nine days}}
\hadithdefcmd{muslim}{2524}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا رَوْحٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا الضَّحَّاكُ، - يَعْنِي أَبَا عَاصِمٍ - جَمِيعًا عَنِ ابْنِ جُرَيْجٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{2524}\hadithtrans{A hadith like this has been narrated on the authority of Ibn Juraij with the same chain of transmitters}}
\hadithdefcmd{muslim}{2525}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، حَدَّثَنِي مُحَمَّدُ بْنُ سَعْدٍ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، - رضى الله عنه - قَالَ ضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ عَلَى الأُخْرَى فَقَالَ ‏ "‏ الشَّهْرُ هَكَذَا وَهَكَذَا ‏"‏ ‏.‏ ثُمَّ نَقَصَ فِي الثَّالِثَةِ إِصْبَعًا ‏.‏\hadithno{2525}\hadithtrans{Sa'd b. Abi Waqqas (Allah be pleased with him) said that the Messenger of Allah (ﷺ) struck his hand against the other and (then with the gesture of his two hands) said:The month is thus, thus (two times). He then withdrew (one of) his fingers at the third turn}}
\hadithdefcmd{muslim}{2526}{وَحَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ إِسْمَاعِيلَ، عَنْ مُحَمَّدِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، - رضى الله عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الشَّهْرُ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ عَشْرًا وَعَشْرًا وَتِسْعًا مَرَّةً ‏.‏\hadithno{2526}\hadithtrans{Muhammad b. Sa'd reported on the authority of his father (Sa'd b. Abi Waqqas (Allah be pleased with him) that the Messenger of Allah (ﷺ) had said:Tho month is thus and thus, and thus, i. e. ten, ten and nine}}
\hadithdefcmd{muslim}{2527}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ قُهْزَاذَ، حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ بْنِ شَقِيقٍ، وَسَلَمَةُ، بْنُ سُلَيْمَانَ قَالاَ أَخْبَرَنَا عَبْدُ اللَّهِ، - يَعْنِي ابْنَ الْمُبَارَكِ - أَخْبَرَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، فِي هَذَا الإِسْنَادِ بِمَعْنَى حَدِيثِهِمَا ‏.‏\hadithno{2527}\hadithtrans{This hadith has been narrated by Ibn Abu Khalid with the same chain of transmitters}}
\hadithdefcmd{muslim}{2528}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ مُحَمَّدٍ، - وَهُوَ ابْنُ أَبِي حَرْمَلَةَ - عَنْ كُرَيْبٍ، أَنَّ أُمَّ الْفَضْلِ بِنْتَ الْحَارِثِ، بَعَثَتْهُ إِلَى مُعَاوِيَةَ بِالشَّامِ قَالَ فَقَدِمْتُ الشَّامَ فَقَضَيْتُ حَاجَتَهَا وَاسْتُهِلَّ عَلَىَّ رَمَضَانُ وَأَنَا بِالشَّامِ فَرَأَيْتُ الْهِلاَلَ لَيْلَةَ الْجُمُعَةِ ثُمَّ قَدِمْتُ الْمَدِينَةَ فِي آخِرِ الشَّهْرِ فَسَأَلَنِي عَبْدُ اللَّهِ بْنُ عَبَّاسٍ - رضى الله عنهما - ثُمَّ ذَكَرَ الْهِلاَلَ فَقَالَ مَتَى رَأَيْتُمُ الْهِلاَلَ فَقُلْتُ رَأَيْنَاهُ لَيْلَةَ الْجُمُعَةِ ‏.‏ فَقَالَ أَنْتَ رَأَيْتَهُ فَقُلْتُ نَعَمْ وَرَآهُ النَّاسُ وَصَامُوا وَصَامَ مُعَاوِيَةُ ‏.‏ فَقَالَ لَكِنَّا رَأَيْنَاهُ لَيْلَةَ السَّبْتِ فَلاَ نَزَالُ نَصُومُ حَتَّى نُكْمِلَ ثَلاَثِينَ أَوْ نَرَاهُ ‏.‏ فَقُلْتُ أَوَلاَ تَكْتَفِي بِرُؤْيَةِ مُعَاوِيَةَ وَصِيَامِهِ فَقَالَ لاَ هَكَذَا أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ وَشَكَّ يَحْيَى بْنُ يَحْيَى فِي نَكْتَفِي أَوْ تَكْتَفِي ‏.‏\hadithno{2528}\hadithtrans{Kuraib reported that Umm Fadl, daughter of Harith, sent him (Fadl, i.e. her son) to Mu'awiya in Syria. I (Fadl) arrived in Syria, and did the needful for her. It was there in Syria that the month of Ramadan commenced. I saw the new moon (of Ramadan) on Friday. I then came back to Medina at the end of the month. Abdullah b. 'Abbas (Allah be pleased with him) asked me (about the new moon of Ramadan) and said:When did you see it? I said: We saw it on the night of Friday. He said: (Did) you see it yourself? I said: Yes, and the people also saw it and they fasted and Mu'awiya also fasted, whereupon he said: But we saw it on Saturday night. So we will continue to fast till we complete thirty (fasts) or we see it (the new moon of Shawwal). I said: Is the sighting of the moon by Mu'awiya not valid for you? He said: No; this is how the Messenger of Allah (ﷺ) has commanded us. Yahya b. Yahya was in doubt (whether the word used in the narration by Kuraib) was Naktafi or Taktafi}}
\hadithdefcmd{muslim}{2529}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ حُصَيْنٍ، عَنْ عَمْرِو بْنِ، مُرَّةَ عَنْ أَبِي الْبَخْتَرِيِّ، قَالَ خَرَجْنَا لِلْعُمْرَةِ فَلَمَّا نَزَلْنَا بِبَطْنِ نَخْلَةَ - قَالَ - تَرَاءَيْنَا الْهِلاَلَ فَقَالَ بَعْضُ الْقَوْمِ هُوَ ابْنُ ثَلاَثٍ ‏.‏ وَقَالَ بَعْضُ الْقَوْمِ هُوَ ابْنُ لَيْلَتَيْنِ قَالَ فَلَقِينَا ابْنَ عَبَّاسٍ فَقُلْنَا إِنَّا رَأَيْنَا الْهِلاَلَ فَقَالَ بَعْضُ الْقَوْمِ هُوَ ابْنُ ثَلاَثٍ وَقَالَ بَعْضُ الْقَوْمِ هُوَ ابْنُ لَيْلَتَيْنِ ‏.‏ فَقَالَ أَىَّ لَيْلَةٍ رَأَيْتُمُوهُ قَالَ فَقُلْنَا لَيْلَةَ كَذَا وَكَذَا ‏.‏ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ مَدَّهُ لِلرُّؤْيَةِ فَهُوَ لِلَيْلَةِ رَأَيْتُمُوهُ ‏"‏ ‏.‏\hadithno{2529}\hadithtrans{Abu'l-Bakhtari reported:We went out to perform Umra and when we encamped in the valley of Nakhla, we tried to see the new moon. Some of the people said: It was three nights old, and others (said) that it was two nights old. We then met Ibn 'Abbas and told him we had seen the new moon, but that some of the people said it was three nights old and others that it was two nights old. He asked on which night we had seen it; and when we told him we had seen it on such and such night, he said the Prophet of Allah (ﷺ) had said: Verily Allah deferred it till the time it is seen, so it is to be reckoned from the night you saw it}}
\hadithdefcmd{muslim}{2530}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ أَبَا الْبَخْتَرِيِّ، قَالَ أَهْلَلْنَا رَمَضَانَ وَنَحْنُ بِذَاتِ عِرْقٍ فَأَرْسَلْنَا رَجُلاً إِلَى ابْنِ عَبَّاسٍ - رضى الله عنهما - يَسْأَلُهُ فَقَالَ ابْنُ عَبَّاسٍ - رضى الله عنهما - قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ قَدْ أَمَدَّهُ لِرُؤْيَتِهِ فَإِنْ أُغْمِيَ عَلَيْكُمْ فَأَكْمِلُوا الْعِدَّةَ ‏"‏ ‏.‏\hadithno{2530}\hadithtrans{Abu'l-Bakhtari reported:We saw the new moon of Ramadan as we were at Dhit-i-'Irq. We sent a man to Ibn Abbas (Allah be pleased with both of them) to ask him (whether the sighting of a small moon had something of the nature of defect in it). Upon this Ibn 'Abbas (Allah be pleased with both of them) said that the Messenger of Allah (ﷺ) had said: Verily Allah deferred its sight, but if (the new moon) is hidden from you, then, complete its number (thirty)}}
\hadithdefcmd{muslim}{2531}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ خَالِدٍ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ أَبِي بَكْرَةَ عَنْ أَبِيهِ، - رضى الله عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ شَهْرَا عِيدٍ لاَ يَنْقُصَانِ رَمَضَانُ وَذُو الْحِجَّةِ ‏"‏ ‏.‏\hadithno{2531}\hadithtrans{The son of Abu Bakra reported it on the authority of his father that the Messenger of Allah (ﷺ) had said:The two months of 'Id, Ramadan and Dhu'l-Hijja (are not incomplete)}}
\hadithdefcmd{muslim}{2532}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ إِسْحَاقَ بْنِ سُوَيْدٍ، وَخَالِدٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِي بَكْرَةَ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ شَهْرَا عِيدٍ لاَ يَنْقُصَانِ ‏"‏ ‏.‏ فِي حَدِيثِ خَالِدٍ ‏"‏ شَهْرَا عِيدٍ رَمَضَانُ وَذُو الْحِجَّةِ ‏"‏ ‏.‏\hadithno{2532}\hadithtrans{Abd ar-Rahman b. Abu Bakra reported on the authority of Abu Bakra that the Messenger of Allah (ﷺ) had said:The months of 'Id are not incomplete. And in the hadith narrated by Khalid (the words are):" The months, of 'Id are Ramadan and Dhu'l-Hijja}}
\hadithdefcmd{muslim}{2533}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ حُصَيْنٍ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، - رضى الله عنه - قَالَ لَمَّا نَزَلَتْ ‏\{‏ حَتَّى يَتَبَيَّنَ لَكُمُ الْخَيْطُ الأَبْيَضُ مِنَ الْخَيْطِ الأَسْوَدِ مِنَ الْفَجْرِ‏\}‏ قَالَ لَهُ عَدِيُّ بْنُ حَاتِمٍ يَا رَسُولَ اللَّهِ إِنِّي أَجْعَلُ تَحْتَ وِسَادَتِي عِقَالَيْنِ عِقَالاً أَبْيَضَ وَعِقَالاً أَسْوَدَ أَعْرِفُ اللَّيْلَ مِنَ النَّهَارِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ وِسَادَتَكَ لَعَرِيضٌ إِنَّمَا هُوَ سَوَادُ اللَّيْلِ وَبَيَاضُ النَّهَارِ ‏"‏ ‏.‏\hadithno{2533}\hadithtrans{Adi b. Hatim (Allah be pleased with him) reported that when (this verse) was revealed:" Until the white streak of the dawn becomes distinct from the dark streak" (ii. 187) Adi b. Hatim said: Messenger of Allah, verily I keep underneath my pillow two strings, one white and the other black, by which I distinguish night from dawn. Upon this the Messenger of Allah (ﷺ) said: Your pillow seems to be very large. For the word khait implies the blackness of the night and the whiteness of the dawn}}
\hadithdefcmd{muslim}{2534}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا فُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا أَبُو حَازِمٍ، حَدَّثَنَا سَهْلُ بْنُ سَعْدٍ، قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ وَكُلُوا وَاشْرَبُوا حَتَّى يَتَبَيَّنَ لَكُمُ الْخَيْطُ الأَبْيَضُ مِنَ الْخَيْطِ الأَسْوَدِ‏\}‏ قَالَ كَانَ الرَّجُلُ يَأْخُذُ خَيْطًا أَبْيَضَ وَخَيْطًا أَسْوَدَ فَيَأْكُلُ حَتَّى يَسْتَبِينَهُمَا حَتَّى أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ مِنَ الْفَجْرِ‏\}‏ فَبَيَّنَ ذَلِكَ ‏.‏\hadithno{2534}\hadithtrans{Sahl b. Sa'd said that when this verse was revealed:" Eat and drink till the white streak is distinct from the dark streak," a person would take hold of a white thread and a black thread and keep on eating till he could find them distinct (in the light of the dawn). It was then that Allah, the Majestic and Great, reveiled (the words) min al-fajr (from the dawn), and then it became clear (that the word khait refers to the streak of light in the dawn)}}
\hadithdefcmd{muslim}{2535}{حَدَّثَنِي مُحَمَّدُ بْنُ سَهْلٍ التَّمِيمِيُّ، وَأَبُو بَكْرِ بْنُ إِسْحَاقَ قَالاَ حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا أَبُو غَسَّانَ، حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، - رضى الله عنه - قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ وَكُلُوا وَاشْرَبُوا حَتَّى يَتَبَيَّنَ لَكُمُ الْخَيْطُ الأَبْيَضُ مِنَ الْخَيْطِ الأَسْوَدِ‏\}‏ قَالَ فَكَانَ الرَّجُلُ إِذَا أَرَادَ الصَّوْمَ رَبَطَ أَحَدُهُمْ فِي رِجْلَيْهِ الْخَيْطَ الأَسْوَدَ وَالْخَيْطَ الأَبْيَضَ فَلاَ يَزَالُ يَأْكُلُ وَيَشْرَبُ حَتَّى يَتَبَيَّنَ لَهُ رِئْيُهُمَا فَأَنْزَلَ اللَّهُ بَعْدَ ذَلِكَ ‏\{‏ مِنَ الْفَجْرِ‏\}‏ فَعَلِمُوا أَنَّمَا يَعْنِي بِذَلِكَ اللَّيْلَ وَالنَّهَارَ ‏.‏\hadithno{2535}\hadithtrans{Sahl b. Sa'd (Allah be pleased with him) said:When this verse was revealed." Eat and drink till the white streak becomes distinct from the dark streak for you," the person who decided to observe fast tied on one of his feet a black thread and on the other a white thread. And he went on eating and drinking till he could distinguish (between their colour) on seeing them. It was after this that Allah reveal- ed (the words): min al-fajr. And they (the Muslims) came to know that (the word khait) refers to the night and day}}
\hadithdefcmd{muslim}{2536}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ، سَعِيدٍ حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ، - رضى الله عنه - عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّ بِلاَلاً يُؤَذِّنُ بِلَيْلٍ فَكُلُوا وَاشْرَبُوا حَتَّى تَسْمَعُوا تَأْذِينَ ابْنِ أُمِّ مَكْتُومٍ ‏"‏ ‏.‏\hadithno{2536}\hadithtrans{Abdullah b. Mas'ud (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) had said:Bilal would pronounce Adhan (at the fag end of the night in order to inform the people about the time of the Sahri). So you eat and drink till you hear the Adhan of Ibn Umm Maktum (which was pro- nounced at the conclusion of the Sahri and the commencement of the fast)}}
\hadithdefcmd{muslim}{2537}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، - رضى الله عنهما - قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ بِلاَلاً يُؤَذِّنُ بِلَيْلٍ فَكُلُوا وَاشْرَبُوا حَتَّى تَسْمَعُوا أَذَانَ ابْنِ أُمِّ مَكْتُومٍ ‏"‏ ‏.‏\hadithno{2537}\hadithtrans{Abdullah b. 'Umar (Allah be pleased with both of them) reported:I heard the Messenger of Allah (ﷺ) as saying: Bilal announces Adhan during the night, so you eat and drink, till you hear the Adhan of Ibn Umm Maktum}}
\hadithdefcmd{muslim}{2538}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - قَالَ كَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم مُؤَذِّنَانِ بِلاَلٌ وَابْنُ أُمِّ مَكْتُومٍ الأَعْمَى فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ بِلاَلاً يُؤَذِّنُ بِلَيْلٍ فَكُلُوا وَاشْرَبُوا حَتَّى يُؤَذِّنَ ابْنُ أُمِّ مَكْتُومٍ ‏"‏ ‏.‏ قَالَ وَلَمْ يَكُنْ بَيْنَهُمَا إِلاَّ أَنْ يَنْزِلَ هَذَا وَيَرْقَى هَذَا ‏.‏\hadithno{2538}\hadithtrans{Ibn 'Umar (Allah be pleased with both of them) reported that the Messenger of Allah (ﷺ) had two Mu'adhdhins, Bilal and son of Umm Maktum, the blind. The Messenger of Allah (ﷺ) said:Bilal announces Adhan at (the fag end of the) night (i. e. Sahri), so eat and drink till the son of Umm Maktum announces Adhan. And he (the narrator) said: And the (difference of time) between their (Adhans) was not more than this that one climbed down (from the minaret) and the other climbed up (to announce Adhan)}}
\hadithdefcmd{muslim}{2539}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، حَدَّثَنَا الْقَاسِمُ، عَنْ عَائِشَةَ، - رضى الله عنها - عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{2539}\hadithtrans{A hadith like this has been transmitted on the authority of 'A'isha (Allah be pleased with her)}}
\hadithdefcmd{muslim}{2540}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا عَبْدَةُ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ، بِالإِسْنَادَيْنِ كِلَيْهِمَا ‏.‏ نَحْوَ حَدِيثِ ابْنِ نُمَيْرٍ ‏.‏\hadithno{2540}\hadithtrans{A hadith like this has been narrated on the authority of 'Ubaidullah on the two chains of transmitters}}
\hadithdefcmd{muslim}{2541}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي، عُثْمَانَ عَنِ ابْنِ مَسْعُودٍ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَمْنَعَنَّ أَحَدًا مِنْكُمْ أَذَانُ بِلاَلٍ - أَوْ قَالَ نِدَاءُ بِلاَلٍ - مِنْ سَحُورِهِ فَإِنَّهُ يُؤَذِّنُ - أَوْ قَالَ يُنَادِي - بِلَيْلٍ لِيَرْجِعَ قَائِمَكُمْ وَيُوقِظَ نَائِمَكُمْ ‏"‏ ‏.‏ وَقَالَ ‏"‏ لَيْسَ أَنْ يَقُولَ هَكَذَا وَهَكَذَا - وَصَوَّبَ يَدَهُ وَرَفَعَهَا - حَتَّى يَقُولَ هَكَذَا ‏"‏ ‏.‏ وَفَرَّجَ بَيْنَ إِصْبَعَيْهِ ‏.‏\hadithno{2541}\hadithtrans{Ibn Mas'ud (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying The Adhan of Bilal should not restrain anyone among you from eating Sahur (last meal before daybreak during the month of Ramadan) for he announces Adhan (or he calls) at (the fag end of) the night to make him turn who stands for prayer among you, and to awaken those who are sleeping among you. And he said:The dawn is not like it, as one says (and he lifted his hand) till he (dispersed his fingers) and said: It is like this}}
\hadithdefcmd{muslim}{2542}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبُو خَالِدٍ، - يَعْنِي الأَحْمَرَ - عَنْ سُلَيْمَانَ التَّيْمِيِّ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ ‏"‏ إِنَّ الْفَجْرَ لَيْسَ الَّذِي يَقُولُ هَكَذَا ‏"‏ ‏.‏ وَجَمَعَ أَصَابِعَهُ ثُمَّ نَكَسَهَا إِلَى الأَرْضِ ‏"‏ وَلَكِنِ الَّذِي يَقُولُ هَكَذَا ‏"‏ ‏.‏ وَوَضَعَ الْمُسَبِّحَةَ عَلَى الْمُسَبِّحَةِ وَمَدَّ يَدَيْهِ ‏.‏\hadithno{2542}\hadithtrans{This hadith has been narrated by Sulaiman al-Taimi with the same chain of transmitters (but with a slight variation of words) that he (the Holy Prophet) said:The dawn is not like it as it is said; he then gathered his fingers and lowered them. But he said, it is like this (and he placed the index finger upon the other one and spread his hand)}}
\hadithdefcmd{muslim}{2543}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ، إِبْرَاهِيمَ أَخْبَرَنَا جَرِيرٌ، وَالْمُعْتَمِرُ بْنُ سُلَيْمَانَ، كِلاَهُمَا عَنْ سُلَيْمَانَ التَّيْمِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ وَانْتَهَى حَدِيثُ الْمُعْتَمِرِ عِنْدَ قَوْلِهِ ‏"‏ يُنَبِّهُ نَائِمَكُمْ وَيَرْجِعُ قَائِمَكُمْ ‏"‏ ‏.‏ وَقَالَ إِسْحَاقُ قَالَ جَرِيرٌ فِي حَدِيثِهِ ‏"‏ وَلَيْسَ أَنْ يَقُولَ هَكَذَا وَلَكِنْ يَقُولُ هَكَذَا ‏"‏ ‏.‏ يَعْنِي الْفَجْرَ هُوَ الْمُعْتَرِضُ وَلَيْسَ بِالْمُسْتَطِيلِ ‏.‏\hadithno{2543}\hadithtrans{This hadith has been narrated on the authority of Sulaiman Taimi with the same chain of transmitters and, at the end, it was said that the first Adhan was meant to awaken those who were in slumber amongst them and in order to make them turn who stand in (prayer) among them (towards food at the commencement of the fast). Jarir (one of the narrators) said that the Messenger (ﷺ) did not say like this but he said like it (true dawn) that the streaks of (true dawn ) are horizontal and not vertical}}
\hadithdefcmd{muslim}{2544}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ اللَّهِ بْنِ سَوَادَةَ الْقُشَيْرِيِّ، حَدَّثَنِي وَالِدِي، أَنَّهُ سَمِعَ سَمُرَةَ بْنَ جُنْدُبٍ، يَقُولُ سَمِعْتُ مُحَمَّدًا، صلى الله عليه وسلم يَقُولُ\hadithno{2544}\hadithtrans{Samura b. Jandub reported Muhammad (ﷺ) as saying. The call of Bilal may not mislead any one of you (and he may, under the wrong impression gathered from it, refrain) from taking meal before the commencement of the fast (for the streaks) of this whiteness (which are vertical indicate the false dawn and the true dawn with which the fast commences is that when the streaks of light are) spread}}
\hadithdefcmd{muslim}{2545}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ سَوَادَةَ، عَنْ أَبِيهِ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَغُرَّنَّكُمْ أَذَانُ بِلاَلٍ وَلاَ هَذَا الْبَيَاضُ - لِعَمُودِ الصُّبْحِ - حَتَّى يَسْتَطِيرَ هَكَذَا ‏"‏‏.‏\hadithno{2545}\hadithtrans{Samura b. Jundub reported Allah's Messenger (ﷺ) as saying:The Adhan of Bilal should not mislead you nor the whiteness (of the pillar) of dawn, for it is not the whiteness of the true dawn, but that of the false dawn which is vertical like a pillar and you can eat food till the streaks of whiteness spread like it}}
\hadithdefcmd{muslim}{2546}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - حَدَّثَنَا عَبْدُ اللَّهِ، بْنُ سَوَادَةَ الْقُشَيْرِيُّ عَنْ أَبِيهِ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَغُرَّنَّكُمْ مِنْ سَحُورِكُمْ أَذَانُ بِلاَلٍ وَلاَ بَيَاضُ الأُفُقِ الْمُسْتَطِيلُ هَكَذَا حَتَّى يَسْتَطِيرَ هَكَذَا ‏"‏ ‏.‏ وَحَكَاهُ حَمَّادٌ بِيَدَيْهِ قَالَ يَعْنِي مُعْتَرِضًا ‏.‏\hadithno{2546}\hadithtrans{Samura b. Jundub (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:The Adhan of Bilal may not mislead you with regard to your food at the commencement of the fast, nor the vertical (streaks) of whiteness in the horizon (for it is an indication of false dawn). You should stop eating (food) till (the whiteness) spreads like it. Hammad narrated it and with the gesture of his band he explained, the horizontal position (of the streaks of light)}}
\hadithdefcmd{muslim}{2547}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ سَوَادَةَ، قَالَ سَمِعْتُ سَمُرَةَ، بْنَ جُنْدَبٍ - رضى الله عنه - وَهُوَ يَخْطُبُ يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لاَ يَغُرَّنَّكُمْ نِدَاءُ بِلاَلٍ وَلاَ هَذَا الْبَيَاضُ حَتَّى يَبْدُوَ الْفَجْرُ - أَوْ قَالَ - حَتَّى يَنْفَجِرَ الْفَجْرُ ‏"‏ ‏.‏\hadithno{2547}\hadithtrans{Samura b. Jundub addressed and narrated from the Messenger of Allah (ﷺ) having said (these words):Neither the call of Bilal should mislead you nor this whiteness (of false dawn) till (the true) dawn appears (or he said) till the dawn breaks}}
\hadithdefcmd{muslim}{2548}{وَحَدَّثَنَاهُ ابْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، أَخْبَرَنِي سَوَادَةُ بْنُ حَنْظَلَةَ، الْقُشَيْرِيُّ قَالَ سَمِعْتُ سَمُرَةَ بْنَ جُنْدَبٍ، - رضى الله عنه - يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ هَذَا ‏.‏\hadithno{2548}\hadithtrans{A hadith like this has been narrated on the authority of Samura b. Jundub}}
\hadithdefcmd{muslim}{2549}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ أَخْبَرَنَا هُشَيْمٌ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، ح . وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، عَنِ ابْنِ عُلَيَّةَ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، رضى الله عنه ح . وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، وَعَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَسَحَّرُوا فَإِنَّ فِي السُّحُورِ بَرَكَةً ‏"‏ ‏.‏\hadithno{2549}\hadithtrans{Anas (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Take meal a little before dawn, for there is a blessing in taking meal at that time}}
\hadithdefcmd{muslim}{2550}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ مُوسَى بْنِ عُلَىٍّ، عَنْ أَبِيهِ، عَنْ أَبِي قَيْسٍ، مَوْلَى عَمْرِو بْنِ الْعَاصِ عَنْ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ فَصْلُ مَا بَيْنَ صِيَامِنَا وَصِيَامِ أَهْلِ الْكِتَابِ أَكْلَةُ السَّحَرِ ‏"‏ ‏.‏\hadithno{2550}\hadithtrans{Amr b. al-'As reported Allah's Messenger (ﷺ) as saying:The difference between our fasting and that of the people of the Book is eating shortly before dawn}}
\hadithdefcmd{muslim}{2551}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ جَمِيعًا عَنْ وَكِيعٍ، ح وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، كِلاَهُمَا عَنْ مُوسَى بْنِ عُلَىٍّ، بِهَذَا الإِسْنَادِ .‏\hadithno{2551}\hadithtrans{Musa b. 'Ali has narrated this hadith through the same chain of transmitters}}
\hadithdefcmd{muslim}{2552}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، - رضى الله عنه - قَالَ تَسَحَّرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قُمْنَا إِلَى الصَّلاَةِ ‏.‏ قُلْتُ كَمْ كَانَ قَدْرُ مَا بَيْنَهُمَا قَالَ خَمْسِينَ آيَةً ‏.‏\hadithno{2552}\hadithtrans{Zaid b. Thabit (Allah be pleased with him) said:We took meal shortly before dawn along with the Messenger of Allah (ﷺ). We then stood up for prayer. I said: How much span of time was there between the two (acts, i. e. taking of Sahri and observing of prayer)? He said (a span of reciting) fifty verses}}
\hadithdefcmd{muslim}{2553}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا هَمَّامٌ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا سَالِمُ بْنُ نُوحٍ، حَدَّثَنَا عُمَرُ بْنُ عَامِرٍ، كِلاَهُمَا عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{2553}\hadithtrans{This hadith has been transmitted on the authority of Qatada too}}
\hadithdefcmd{muslim}{2554}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلِ، بْنِ سَعْدٍ - رضى الله عنه - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَزَالُ النَّاسُ بِخَيْرٍ مَا عَجَّلُوا الْفِطْرَ ‏"‏ ‏.‏\hadithno{2554}\hadithtrans{Sahl b. Sa'd (Allah be pleased with him) repotted Allah's Messenger (ﷺ) as saying:The people will continue to prosper as long as they hasten the breaking of the fast}}
\hadithdefcmd{muslim}{2555}{وَحَدَّثَنَاهُ قُتَيْبَةُ، حَدَّثَنَا يَعْقُوبُ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، بْنُ مَهْدِيٍّ عَنْ سُفْيَانَ، كِلاَهُمَا عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، - رضى الله عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{2555}\hadithtrans{A hadith like this has been transmitted by Sahl b. Sa'd}}
\hadithdefcmd{muslim}{2556}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو كُرَيْبٍ مُحَمَّدُ بْنُ الْعَلاَءِ قَالاَ أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ أَبِي عَطِيَّةَ، قَالَ دَخَلْتُ أَنَا وَمَسْرُوقٌ، عَلَى عَائِشَةَ فَقُلْنَا يَا أُمَّ الْمُؤْمِنِينَ رَجُلاَنِ مِنْ أَصْحَابِ مُحَمَّدٍ صلى الله عليه وسلم أَحَدُهُمَا يُعَجِّلُ الإِفْطَارَ وَيُعَجِّلُ الصَّلاَةَ وَالآخَرُ يُؤَخِّرُ الإِفْطَارَ وَيُؤَخِّرُ الصَّلاَةَ ‏.‏ قَالَتْ أَيُّهُمَا الَّذِي يُعَجِّلُ الإِفْطَارَ وَيُعَجِّلُ الصَّلاَةَ قَالَ قُلْنَا عَبْدُ اللَّهِ يَعْنِي ابْنَ مَسْعُودٍ ‏.‏ قَالَتْ كَذَلِكَ كَانَ يَصْنَعُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ زَادَ أَبُو كُرَيْبٍ وَالآخَرُ أَبُو مُوسَى ‏.‏\hadithno{2556}\hadithtrans{Abu 'Atiyya reported:I and Masruq went to 'A'isha and said to her: Mother of the Believers, there are two persons among the Companions of Muhammad (ﷺ) one among whom hastens in breaking the fast and in observing prayer, and the other delays breaking the fast and delays observing prayer. She said: Who among the two hastens in breaking fast and observing prayers? We said, It is 'Abdullah. i. e. son of Mas'ud. whereupon she said: This is how the Messenger of Allah (ﷺ) did. Abu Kuraib added: The second one was Abu Musa}}
\hadithdefcmd{muslim}{2557}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنْ أَبِي عَطِيَّةَ، قَالَ دَخَلْتُ أَنَا وَمَسْرُوقٌ، عَلَى عَائِشَةَ - رضى الله عنها - فَقَالَ لَهَا مَسْرُوقٌ رَجُلاَنِ مِنْ أَصْحَابِ مُحَمَّدٍ صلى الله عليه وسلم كِلاَهُمَا لاَ يَأْلُو عَنِ الْخَيْرِ أَحَدُهُمَا يُعَجِّلُ الْمَغْرِبَ وَالإِفْطَارَ وَالآخَرُ يُؤَخِّرُ الْمَغْرِبَ وَالإِفْطَارَ ‏.‏ فَقَالَتْ مَنْ يُعَجِّلُ الْمَغْرِبَ وَالإِفْطَارَ قَالَ عَبْدُ اللَّهِ ‏. فَقَالَتْ هَكَذَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصْنَعُ ‏.‏\hadithno{2557}\hadithtrans{Abu 'Atiyya reported:I and Misruq went to 'A'isha (Allah be pleased with her) and Masruq said to her: There are two persons among the Companions of Muhammad (ﷺ) none of whom abandons the good, but one of them hastens to observe sunset prayer and break the fast, and the other delays in observing the sunset prayer and in breaking the fast, whereupon she said: Who hastens to observe sunset prayer and break the fast? He said: It is 'Abdullah. Upon this she said: This is how the Messenger of Allah (ﷺ) used to do}}
\hadithdefcmd{muslim}{2558}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو كُرَيْبٍ وَابْنُ نُمَيْرٍ - وَاتَّفَقُوا فِي اللَّفْظِ - قَالَ يَحْيَى أَخْبَرَنَا أَبُو مُعَاوِيَةَ، وَقَالَ ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي وَقَالَ أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، جَمِيعًا عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَاصِمِ بْنِ عُمَرَ، عَنْ عُمَرَ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا أَقْبَلَ اللَّيْلُ وَأَدْبَرَ النَّهَارُ وَغَابَتِ الشَّمْسُ فَقَدْ أَفْطَرَ الصَّائِمُ ‏"‏ ‏.‏ لَمْ يَذْكُرِ ابْنُ نُمَيْرٍ ‏"‏ فَقَدْ ‏"‏ ‏.‏\hadithno{2558}\hadithtrans{Umar (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:When the night approaches and the day retreates and the sun sinks down, then the observer of the fast should break it. Ibn Numair made no mention of the word" then}}
\hadithdefcmd{muslim}{2559}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ أَبِي إِسْحَاقَ الشَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ، بْنِ أَبِي أَوْفَى - رضى الله عنه - قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فِي شَهْرِ رَمَضَانَ فَلَمَّا غَابَتِ الشَّمْسُ قَالَ ‏"‏ يَا فُلاَنُ انْزِلْ فَاجْدَحْ لَنَا ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ إِنَّ عَلَيْكَ نَهَارًا ‏.‏ قَالَ ‏"‏ انْزِلْ فَاجْدَحْ لَنَا ‏"‏ ‏.‏ قَالَ فَنَزَلَ فَجَدَحَ فَأَتَاهُ بِهِ فَشَرِبَ النَّبِيُّ صلى الله عليه وسلم ثُمَّ قَالَ بِيَدِهِ ‏"‏ إِذَا غَابَتِ الشَّمْسُ مِنْ هَا هُنَا وَجَاءَ اللَّيْلُ مِنْ هَا هُنَا فَقَدْ أَفْطَرَ الصَّائِمُ ‏"‏ ‏.‏\hadithno{2559}\hadithtrans{Abdullah b. Abi Aufa reported:We were with the Messenger of Allah (ﷺ) on a journey during the month of Ramadan. When the sun had sunk he said: So and so, get down (from your ride) and prepare the meal of parched barley for us. He said: Messenger of Allah, still (there is light of) day. He (the Holy Prophet) said: Get down and prepare meal of parched barley for us. So he got down and prepared the meal of parched barley and offered him, and the apostle of Allah (ﷺ) drank that (liquid meal). He then told with the gesture of his hand that when the sun sank from that side and the night appeared from that side, then the observer of the fast should break it}}
\hadithdefcmd{muslim}{2560}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، وَعَبَّادُ بْنُ الْعَوَّامِ، عَنِ الشَّيْبَانِيِّ، عَنِ ابْنِ أَبِي أَوْفَى، - رضى الله عنه - قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَلَمَّا غَابَتِ الشَّمْسُ قَالَ لِرَجُلٍ ‏"‏ انْزِلْ فَاجْدَحْ لَنَا ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ لَوْ أَمْسَيْتَ ‏.‏ قَالَ ‏"‏ انْزِلْ فَاجْدَحْ لَنَا ‏"‏ ‏.‏ قَالَ إِنَّ عَلَيْنَا نَهَارًا ‏.‏ فَنَزَلَ فَجَدَحَ لَهُ فَشَرِبَ ثُمَّ قَالَ ‏"‏ إِذَا رَأَيْتُمُ اللَّيْلَ قَدْ أَقْبَلَ مِنْ هَا هُنَا - وَأَشَارَ بِيَدِهِ نَحْوَ الْمَشْرِقِ - فَقَدْ أَفْطَرَ الصَّائِمُ ‏"‏ ‏.‏\hadithno{2560}\hadithtrans{Ibn Abi Aufa (Allah be pleased with him) reported:We were with the Messenger of Allah (ﷺ) on a journey. When the sun sank he said to a person: Get down and prepare barley meal for us. Upon this he said: Messenger of Allah, let there be dusk. (He the Holy Prophet) said: Get down and prepare barley meal for us. He (the person) said: There is still (the light of) day upon us. (But) he got down (in obedience to the command of the Holy Prophet) and prepared a barley meal for him and he (the Holy Prophet) drank that (liquid meal) and then said: When you see the night approaching from that side (west) (and he pointed towards the east with his hand), then the observer of the fast should break it}}
\hadithdefcmd{muslim}{2561}{وَحَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا سُلَيْمَانُ الشَّيْبَانِيُّ، قَالَ سَمِعْتُ عَبْدَ، اللَّهِ بْنَ أَبِي أَوْفَى - رضى الله عنه - يَقُولُ سِرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ صَائِمٌ فَلَمَّا غَرَبَتِ الشَّمْسُ قَالَ ‏ "‏ يَا فُلاَنُ انْزِلْ فَاجْدَحْ لَنَا ‏"‏ ‏.‏ مِثْلَ حَدِيثِ ابْنِ مُسْهِرٍ وَعَبَّادِ بْنِ الْعَوَّامِ ‏.‏\hadithno{2561}\hadithtrans{Abdullah b. Abi Aufa (Allah be pleased with him) reported:We travelled with the Messenger of Allah (ﷺ) as he had been observing fast. When the sun sank he said: So and so, get down and prepare barley meal for us. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2562}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، أَخْبَرَنَا سُفْيَانُ، ح وَحَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا جَرِيرٌ، كِلاَهُمَا عَنِ الشَّيْبَانِيِّ، عَنِ ابْنِ أَبِي أَوْفَى، ح . وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ، جَعْفَرٍ قَالاَ حَدَّثَنَا شُعْبَةُ، عَنِ الشَّيْبَانِيِّ، عَنِ ابْنِ أَبِي أَوْفَى، - رضى الله عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ ابْنِ مُسْهِرٍ وَعَبَّادٍ وَعَبْدِ الْوَاحِدِ وَلَيْسَ فِي حَدِيثِ أَحَدٍ مِنْهُمْ فِي شَهْرِ رَمَضَانَ وَلاَ قَوْلُهُ ‏ "‏ وَجَاءَ اللَّيْلُ مِنْ هَا هُنَا ‏"‏ ‏.‏ إِلاَّ فِي رِوَايَةِ هُشَيْمٍ وَحْدَهُ ‏.‏\hadithno{2562}\hadithtrans{This hadith has been narrated on the authority of Ibn Abi Aufa (Allah be pleased with him) through another chain of transmitters (but with a sight alteration of words):In this hadith transmitted by one of the narrators (neither these words are found): During the month of Ramadan." nor his statement:" And the night prevails from that side (the eastern side)." (These words are found in the narration of) Hushaim only}}
\hadithdefcmd{muslim}{2563}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْوِصَالِ قَالُوا إِنَّكَ تُوَاصِلُ ‏.‏ قَالَ ‏ "‏ إِنِّي لَسْتُ كَهَيْئَتِكُمْ إِنِّي أُطْعَمُ وَأُسْقَى ‏"‏ ‏.‏\hadithno{2563}\hadithtrans{Ibn 'Umar (Allah be pleased with both of them) said that the Messenger of Allah (ﷺ) forbade uninterrupted fasting. They (some of the Companions) said:You yourself fast uninterruptedly, whereupon he said: I am not like you. I am fed and supplied drink (by Allah)}}
\hadithdefcmd{muslim}{2564}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَاصَلَ فِي رَمَضَانَ فَوَاصَلَ النَّاسُ فَنَهَاهُمْ ‏.‏ قِيلَ لَهُ أَنْتَ تُوَاصِلُ قَالَ ‏ "‏ إِنِّي لَسْتُ مِثْلَكُمْ إِنِّي أُطْعَمُ وَأُسْقَى ‏"‏ ‏.‏\hadithno{2564}\hadithtrans{Ibn 'Umar reported that the Messenger of Allah (ﷺ) observed fasts uninterruptedly in Ramadan and the people (in his wake) did this. But he forbade them to do so. It was said to him (to the Holy Prophet):You yourself observe the fasts uninterruptedly (but you forbid us to do so) Upon this he said: I am not like you; I am fed and supplied drink (by Allah)}}
\hadithdefcmd{muslim}{2565}{وَحَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ وَلَمْ يَقُلْ فِي رَمَضَانَ ‏.‏\hadithno{2565}\hadithtrans{A hadith like this has been transmitted by Ibn 'Umar (Allah be pleased with both of them), but he did not make mention of (the words):" During the month of Ramadan}}
\hadithdefcmd{muslim}{2566}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، - رضى الله عنه - قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْوِصَالِ فَقَالَ رَجُلٌ مِنَ الْمُسْلِمِينَ فَإِنَّكَ يَا رَسُولَ اللَّهِ تُوَاصِلُ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَأَيُّكُمْ مِثْلِي إِنِّي أَبِيتُ يُطْعِمُنِي رَبِّي وَيَسْقِينِي ‏"‏ ‏.‏ فَلَمَّا أَبَوْا أَنْ يَنْتَهُوا عَنِ الْوِصَالِ وَاصَلَ بِهِمْ يَوْمًا ثُمَّ يَوْمًا ثُمَّ رَأَوُا الْهِلاَلَ فَقَالَ ‏"‏ لَوْ تَأَخَّرَ الْهِلاَلُ لَزِدْتُكُمْ ‏"‏ ‏.‏ كَالْمُنَكِّلِ لَهُمْ حِينَ أَبَوْا أَنْ يَنْتَهُوا ‏.‏\hadithno{2566}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:The Messenger of Allah (ﷺ) forbade (his Companions) from observing fast uninterruptedly. One of the Muslims said: Messenger of Allah, you yourself observe Saum Wisal, whereupon the Messenger of Allah (ﷺ) said: Who among you is like me? I spend night (in a state) that my Allah feeds me and provides me drink. When they (the Companions of the Holy Prophet) did not agree in abandoning the uninterrupted fast, then the Prophet (ﷺ) also observed this fast with them for a day, and then for a day. They then saw the new moon and he (the Holy Prophet) said: If the appearance of the new moon were delayed. I would have observed more (fasts) with you (and he did it) by way of warning to them as they had not agreed to refrain (from observing Saum Wisal)}}
\hadithdefcmd{muslim}{2567}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ، قَالَ زُهَيْرٌ حَدَّثَنَا جَرِيرٌ، عَنْ عُمَارَةَ، عَنْ أَبِي، زُرْعَةَ عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِيَّاكُمْ وَالْوِصَالَ ‏"‏ ‏.‏ قَالُوا فَإِنَّكَ تُوَاصِلُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِنَّكُمْ لَسْتُمْ فِي ذَلِكَ مِثْلِي إِنِّي أَبِيتُ يُطْعِمُنِي رَبِّي وَيَسْقِينِي فَاكْلَفُوا مِنَ الأَعْمَالِ مَا تُطِيقُونَ ‏"‏ ‏.‏\hadithno{2567}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Abstain from Saum-Wisal. They (his Companions) said: Messenger of Allah, but you observe Saum Wisal. Upon this he said: You are not like me in this matter, for I spend my night (in a state) that my Lord feeds me and provides me drink Devote yourselves to the deeds (the burden of which) you can bear}}
\hadithdefcmd{muslim}{2568}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي، هُرَيْرَةَ - رضى الله عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ فَاكْلَفُوا مَا لَكُمْ بِهِ طَاقَةٌ ‏"‏ ‏.‏\hadithno{2568}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying (the words as said in the previous hadith) but with this alteration (of words):" Take upon yourselves (the burden of the deeds) for which you have the strength to bear}}
\hadithdefcmd{muslim}{2569}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنِ الْوِصَالِ ‏.‏ بِمِثْلِ حَدِيثِ عُمَارَةَ عَنْ أَبِي زُرْعَةَ ‏.‏\hadithno{2569}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) forbade (his Companions) to observe Saum Wisal}}
\hadithdefcmd{muslim}{2570}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا أَبُو النَّضْرِ، هَاشِمُ بْنُ الْقَاسِمِ حَدَّثَنَا سُلَيْمَانُ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، - رضى الله عنه - قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِي رَمَضَانَ فَجِئْتُ فَقُمْتُ إِلَى جَنْبِهِ وَجَاءَ رَجُلٌ آخَرُ فَقَامَ أَيْضًا حَتَّى كُنَّا رَهْطًا فَلَمَّا حَسَّ النَّبِيُّ صلى الله عليه وسلم أَنَّا خَلْفَهُ جَعَلَ يَتَجَوَّزُ فِي الصَّلاَةِ ثُمَّ دَخَلَ رَحْلَهُ فَصَلَّى صَلاَةً لاَ يُصَلِّيهَا عِنْدَنَا ‏.‏ قَالَ قُلْنَا لَهُ حِينَ أَصْبَحْنَا أَفَطِنْتَ لَنَا اللَّيْلَةَ قَالَ فَقَالَ ‏"‏ نَعَمْ ذَاكَ الَّذِي حَمَلَنِي عَلَى الَّذِي صَنَعْتُ ‏"‏ ‏.‏ قَالَ فَأَخَذَ يُوَاصِلُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَذَاكَ فِي آخِرِ الشَّهْرِ فَأَخَذَ رِجَالٌ مِنْ أَصْحَابِهِ يُوَاصِلُونَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا بَالُ رِجَالٍ يُواصِلُونَ إِنَّكُمْ لَسْتُمْ مِثْلِي أَمَا وَاللَّهِ لَوْ تَمَادَّ لِيَ الشَّهْرُ لَوَاصَلْتُ وِصَالاً يَدَعُ الْمُتَعَمِّقُونَ تَعَمُّقَهُمْ ‏"‏ ‏.‏\hadithno{2570}\hadithtrans{Anas (Allah be pleased with him) reported The Messenger of Allah (ﷺ) was observing prayer during Ramadan. I came and stood by his side. Then another man came and he stood likewise till we became a group. When the Messenger of Allah (ﷺ) perceived that we were behind him, he lightened the prayer. He then went to his abode and observed such (a long) prayer (the like of which) he never observed with us. When it was morning we said to him:Did you perceive us during the night? Upon this he said: Yes, it was this (realisation) that induced me to do that which I did. He (the narrator) said: The Messenger of Allah (ﷺ) began to observe Saum Wisal at the end of the month (of Ramadan), and some persons among his Companions began to observe this uninter- rupted fast, whereupon the Messenger of Allah (ﷺ) said: What about such persons who observe uninterrupted fasts? You are not like me. By Allah. if the month were lengthened for me, I would have observed Saum Wisal, so that those who act with an exaggeration would (have been obliged) to abandon their exaggeration}}
\hadithdefcmd{muslim}{2571}{حَدَّثَنَا عَاصِمُ بْنُ النَّضْرِ التَّيْمِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا حُمَيْدٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، - رضى الله عنه - قَالَ وَاصَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي أَوَّلِ شَهْرِ رَمَضَانَ فَوَاصَلَ نَاسٌ مِنَ الْمُسْلِمِينَ فَبَلَغَهُ ذَلِكَ فَقَالَ ‏ "‏ لَوْ مُدَّ لَنَا الشَّهْرُ لَوَاصَلْنَا وِصَالاً يَدَعُ الْمُتَعَمِّقُونَ تَعَمُّقَهُمْ إِنَّكُمْ لَسْتُمْ مِثْلِي - أَوْ قَالَ - إِنِّي لَسْتُ مِثْلَكُمْ إِنِّي أَظَلُّ يُطْعِمُنِي رَبِّي وَيَسْقِينِي ‏"‏ ‏.‏\hadithno{2571}\hadithtrans{Anas (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) observed Saum Wisal during the early part of the month of Ramadan. The people among Muslims also observed uninterrupted fast. This (news) reached him (the Holy Prophet) and he said:Had the month been lengthened for me I would have continued observing Saum Wisal, so that those who act with forced hardness would (have been obliged) to abandon it. You are not like me (or he said): I am not like you. I continue to do so (in a state) that my Lord feeds me and provides me drink}}
\hadithdefcmd{muslim}{2572}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، جَمِيعًا عَنْ عَبْدَةَ، - قَالَ إِسْحَاقُ أَخْبَرَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، - عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ نَهَاهُمُ النَّبِيُّ صلى الله عليه وسلم عَنِ الْوِصَالِ رَحْمَةً لَهُمْ ‏.‏ فَقَالُوا إِنَّكَ تُوَاصِلُ ‏.‏ قَالَ ‏ "‏ إِنِّي لَسْتُ كَهَيْئَتِكُمْ إِنِّي يُطْعِمُنِي رَبِّي وَيَسْقِينِي ‏"‏ ‏.‏\hadithno{2572}\hadithtrans{A'isha (Allah be pleased with her) said:The Apostle of Allah (ﷺ) forbade them (his Companions) to observe Saum Wisal out of mercy for them. They said: You (Holy Prophet) yourself observe it. Upon this he said: I am not like you. My Lord feeds me and provides me drink}}
\hadithdefcmd{muslim}{2573}{حَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَبِّلُ إِحْدَى نِسَائِهِ وَهُوَ صَائِمٌ ‏.‏ ثُمَّ تَضْحَكُ ‏.‏\hadithno{2573}\hadithtrans{A'isha (Allah be pleased with her) said that the Messenger of Allah (ﷺ) kissed one of his wives while he was fasting, and then she ('A'isha) smiled (as she narrated)}}
\hadithdefcmd{muslim}{2574}{حَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا سُفْيَانُ، قَالَ قُلْتُ لِعَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ أَسَمِعْتَ أَبَاكَ يُحَدِّثُ عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُقَبِّلُهَا وَهُوَ صَائِمٌ فَسَكَتَ سَاعَةً ثُمَّ قَالَ نَعَمْ ‏.‏\hadithno{2574}\hadithtrans{Sufyan reported:I said to 'Abd al-Rahman b. Qasim: Have you heard from your father narrating from 'A'isha (Allah be pleased with her) that he kissed her while observing fast? He ('Abd al-Rahman b. Qasim) kept silence for a short while and then said:" Yes}}
\hadithdefcmd{muslim}{2575}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَبِّلُنِي وَهُوَ صَائِمٌ وَأَيُّكُمْ يَمْلِكُ إِرْبَهُ كَمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْلِكُ إِرْبَهُ\hadithno{2575}\hadithtrans{A'isha reported:Allah's Messenger (ﷺ) used to kiss me while observing fast; and who among you can control his desire as the Messenger of Allah (ﷺ) could control his desire}}
\hadithdefcmd{muslim}{2576}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، وَعَلْقَمَةَ، عَنْ عَائِشَةَ، رضى الله عنها ح . وَحَدَّثَنَا شُجَاعُ بْنُ مَخْلَدٍ، حَدَّثَنَا يَحْيَى بْنُ أَبِي زَائِدَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَبِّلُ وَهُوَ صَائِمٌ وَيُبَاشِرُ وَهُوَ صَائِمٌ وَلَكِنَّهُ أَمْلَكُكُمْ لإِرْبِهِ ‏.‏\hadithno{2576}\hadithtrans{A'isha (Allah be pleased with her) reported:Allah's Messenger (ﷺ) used to kiss (his wives) while fasting and embraced (them) while fasting; but he had the greatest mastery over his desire among you}}
\hadithdefcmd{muslim}{2577}{حَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَائِشَةَ، - رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُقَبِّلُ وَهُوَ صَائِمٌ وَكَانَ أَمْلَكَكُمْ لإِرْبِهِ ‏.‏\hadithno{2577}\hadithtrans{A'isha (Allah be pleased with her) reported:The Messenger of Allah (ﷺ) used to kiss (his wives) while fasting; and he had the greatest control over his desire (as compared with you)}}
\hadithdefcmd{muslim}{2578}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُبَاشِرُ وَهُوَ صَائِمٌ ‏.‏\hadithno{2578}\hadithtrans{A'isha (Allah be pleased with her) said that the Messenger of Allah (ﷺ) used to embrace (his wives) while fasting}}
\hadithdefcmd{muslim}{2579}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو عَاصِمٍ، قَالَ سَمِعْتُ ابْنَ عَوْنٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، قَالَ انْطَلَقْتُ أَنَا وَمَسْرُوقٌ، إِلَى عَائِشَةَ - رضى الله عنها - فَقُلْنَا لَهَا أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُبَاشِرُ وَهُوَ صَائِمٌ قَالَتْ نَعَمْ وَلَكِنَّهُ كَانَ أَمْلَكَكُمْ لإِرْبِهِ أَوْ مِنْ أَمْلَكِكُمْ لإِرْبِهِ ‏.‏ شَكَّ أَبُو عَاصِمٍ ‏.‏\hadithno{2579}\hadithtrans{Aswad reported:I and Masruq went to 'A'isha (Allah be pleased with her) and asked. her if the Messenger of Allah (ﷺ) embraced (his wives) while fasting. She said: Yes; but he had the greatest control over his desire among you: or he was one of those who had control over his desire}}
\hadithdefcmd{muslim}{2580}{وَحَدَّثَنِيهِ يَعْقُوبُ الدَّوْرَقِيُّ، حَدَّثَنَا إِسْمَاعِيلُ، عَنِ ابْنِ عَوْنٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، وَمَسْرُوقٍ أَنَّهُمَا دَخَلاَ عَلَى أُمِّ الْمُؤْمِنِينَ يَسْأَلاَنِهَا ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{2580}\hadithtrans{It is further narrated on the authority of Aswad and Masruq that they went to the Mother of the Believers and they asked her (and the rest of the hadith is the same)}}
\hadithdefcmd{muslim}{2581}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، بْنِ أَبِي كَثِيرٍ عَنْ أَبِي سَلَمَةَ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، أَخْبَرَهُ أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ أَخْبَرَهُ أَنَّ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ - رضى الله عنها - أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُقَبِّلُهَا وَهُوَ صَائِمٌ ‏.‏\hadithno{2581}\hadithtrans{Urwa b. Zubair narrated that 'A'isha the Mother of the Believers (Allah be pleased with her) informed him that the Messenger of Allah (ﷺ) kissed her while fasting}}
\hadithdefcmd{muslim}{2582}{وَحَدَّثَنَا يَحْيَى بْنُ بِشْرٍ الْحَرِيرِيُّ، حَدَّثَنَا مُعَاوِيَةُ، - يَعْنِي ابْنَ سَلاَّمٍ - عَنْ يَحْيَى، بْنِ أَبِي كَثِيرٍ بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{2582}\hadithtrans{A hadith like this has been narrated by Yahya b. Abu Kathir with the same chain of transmitters}}
\hadithdefcmd{muslim}{2583}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَبِّلُ فِي شَهْرِ الصَّوْمِ ‏.‏\hadithno{2583}\hadithtrans{A'isha (Allah be pleased with her) reported that the Messenger of Allah (ﷺ) used to kiss her during the month of fasting}}
\hadithdefcmd{muslim}{2584}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، حَدَّثَنَا أَبُو بَكْرٍ النَّهْشَلِيُّ، حَدَّثَنَا زِيَادُ، بْنُ عِلاَقَةَ عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَبِّلُ فِي رَمَضَانَ وَهُوَ صَائِمٌ ‏.‏\hadithno{2584}\hadithtrans{A'isha (Allah be pleased with her) reported that Allah's Messenger (ﷺ) kissed (his wives) during Ramadan while observing fast}}
\hadithdefcmd{muslim}{2585}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنْ عَلِيِّ بْنِ الْحُسَيْنِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُقَبِّلُ وَهُوَ صَائِمٌ ‏.‏\hadithno{2585}\hadithtrans{A'isha (Allah be pleased with her) reported that Allah's Apostle (peace be upon him) kissed (his wives) while fasting}}
\hadithdefcmd{muslim}{2586}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ شُتَيْرِ بْنِ شَكَلٍ، عَنْ حَفْصَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَبِّلُ وَهُوَ صَائِمٌ ‏.‏\hadithno{2586}\hadithtrans{Hafsa (Allah be pleased with her) reported that the Messenger of Allah (ﷺ) kissed (his wives) while fasting}}
\hadithdefcmd{muslim}{2587}{وَحَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ عَنْ جَرِيرٍ، كِلاَهُمَا عَنْ مَنْصُورٍ، عَنْ مُسْلِمٍ، عَنْ شُتَيْرِ بْنِ شَكَلٍ، عَنْ حَفْصَةَ، - رضى الله عنها - عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{2587}\hadithtrans{A hadith like this has been narrated by Hafsa (Allah be pleased with her) through another chain of transmitters}}
\hadithdefcmd{muslim}{2588}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، - وَهُوَ ابْنُ الْحَارِثِ - عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ كَعْبٍ الْحِمْيَرِيِّ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَيُقَبِّلُ الصَّائِمُ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَلْ هَذِهِ ‏"‏ ‏.‏ لأُمِّ سَلَمَةَ فَأَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَصْنَعُ ذَلِكَ فَقَالَ يَا رَسُولَ اللَّهِ قَدْ غَفَرَ اللَّهُ لَكَ مَا تَقَدَّمَ مِنْ ذَنْبِكَ وَمَا تَأَخَّرَ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا وَاللَّهِ إِنِّي لأَتْقَاكُمْ لِلَّهِ وَأَخْشَاكُمْ لَهُ ‏"‏ ‏.‏\hadithno{2588}\hadithtrans{Umar b Abu Salama reported that he asked the Messenger of Allah (ﷺ):Should one observing fast kiss (his wife)? The Messenger of Allah (ﷺ) said to him: Ask her (Umm Salama). She informed him that the Messenger of Allah (ﷺ) did that, where upon he said: Messenger of Allah, Allah pardoned thee all thy sins, the previous and the later ones. Upon this the Messenger of Allah (ﷺ) ) said: By Allah, I am the most God conscious among you and I fear Him most among you}}
\hadithdefcmd{muslim}{2589}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، ح وَحَدَّثَنِي مُحَمَّدُ، بْنُ رَافِعٍ - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدُ الرَّزَّاقِ بْنُ هَمَّامٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَبْدُ الْمَلِكِ، بْنُ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي بَكْرٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، - رضى الله عنه - يَقُصُّ يَقُولُ فِي قَصَصِهِ مَنْ أَدْرَكَهُ الْفَجْرُ جُنُبًا فَلاَ يَصُمْ ‏.‏ فَذَكَرْتُ ذَلِكَ لِعَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ - لأَبِيهِ - فَأَنْكَرَ ذَلِكَ ‏.‏ فَانْطَلَقَ عَبْدُ الرَّحْمَنِ وَانْطَلَقْتُ مَعَهُ حَتَّى دَخَلْنَا عَلَى عَائِشَةَ وَأُمِّ سَلَمَةَ - رضى الله عنهما - فَسَأَلَهُمَا عَبْدُ الرَّحْمَنِ عَنْ ذَلِكَ - قَالَ - فَكِلْتَاهُمَا قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصْبِحُ جُنُبًا مِنْ غَيْرِ حُلُمٍ ثُمَّ يَصُومُ - قَالَ - فَانْطَلَقْنَا حَتَّى دَخَلْنَا عَلَى مَرْوَانَ فَذَكَرَ ذَلِكَ لَهُ عَبْدُ الرَّحْمَنِ ‏.‏ فَقَالَ مَرْوَانُ عَزَمْتُ عَلَيْكَ إِلاَّ مَا ذَهَبْتَ إِلَى أَبِي هُرَيْرَةَ فَرَدَدْتَ عَلَيْهِ مَا يَقُولُ - قَالَ - فَجِئْنَا أَبَا هُرَيْرَةَ وَأَبُو بَكْرٍ حَاضِرُ ذَلِكَ كُلِّهِ - قَالَ - فَذَكَرَ لَهُ عَبْدُ الرَّحْمَنِ فَقَالَ أَبُو هُرَيْرَةَ أَهُمَا قَالَتَاهُ لَكَ قَالَ نَعَمْ ‏.‏ قَالَ هُمَا أَعْلَمُ ‏.‏ ثُمَّ رَدَّ أَبُو هُرَيْرَةَ مَا كَانَ يَقُولُ فِي ذَلِكَ إِلَى الْفَضْلِ بْنِ الْعَبَّاسِ فَقَالَ أَبُو هُرَيْرَةَ سَمِعْتُ ذَلِكَ مِنَ الْفَضْلِ وَلَمْ أَسْمَعْهُ مِنَ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ فَرَجَعَ أَبُو هُرَيْرَةَ عَمَّا كَانَ يَقُولُ فِي ذَلِكَ ‏.‏ قُلْتُ لِعَبْدِ الْمَلِكِ أَقَالَتَا فِي رَمَضَانَ قَالَ كَذَلِكَ كَانَ يُصْبِحُ جُنُبًا مِنْ غَيْرِ حُلُمٍ ثُمَّ يَصُومُ ‏.‏\hadithno{2589}\hadithtrans{Abu Bakr (he is Abu Bakr b. Abd al-Rahman b. Harith) reported:I heard Abu Huraira (Allah be pleased with him) narrating that he who is overtaken by dawn in a state of seminal emission should not observe fast. I made a mention of it to 'Abd al-Rahman b. Harith (i. e. to his father) but he denied it. 'Abd al-Rahman went and I also went along with him till we came to'A'isha and Umm Salama (Allah be pleased with both of them) and Abd al-Rahman asked them about it. Both of them said: (At times it so happened) that the Messenger of Allah (ﷺ) woke up in the morning in a state of junub (but without seminal emission in a dream) and observed fast He (the narrator) said: We then proceeded till we went to Marwan and Abd al-Rahman made a mention of it to him. Upon this Marwan said: I stress upon you (with an oath) that you better go to Abu Huraira and refer to him what is said about it. So we came to Abu Huraira and Abu Bakr had been with us throughout and 'Abd al-Rahman made a mention of it to him, whereupon Abu Huraira said: Did they (the two wives of the Holy Prophet) tell you this? He replied: Yes Upon this (Abu Huraira) said: They have better knowledge. Abu Huraira then attributed that what was said about it to Fadl b. 'Abbas and said: I heard it from Fadl and not from the Messenger of Allah (ﷺ). Abu Huraira then retracted from what he used to say about it. Ibn Juraij (one of the narrators) reported: I asked 'Abd al-Malik, if they (the two wives) said (made the statement) in regard to Ramadan, whereupon he said: It was so, and he (the Holy Prophet) (woke up in the) morning in a state of junub which was not due to the wet dream and then observed fast}}
\hadithdefcmd{muslim}{2590}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، وَأَبِي، بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ قَدْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُدْرِكُهُ الْفَجْرُ فِي رَمَضَانَ وَهُوَ جُنُبٌ مِنْ غَيْرِ حُلُمٍ فَيَغْتَسِلُ وَيَصُومُ ‏.‏\hadithno{2590}\hadithtrans{A'isha, the wife of the Messenger of Allah (ﷺ), said:The dawn broke upon the Messenger of Allah (ﷺ) during the Ramadan in a state of junub not because of sexual dream (but on account of intercourse) and he washed himself and observed fast}}
\hadithdefcmd{muslim}{2591}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، - وَهُوَ ابْنُ الْحَارِثِ - عَنْ عَبْدِ رَبِّهِ، عَنْ عَبْدِ اللَّهِ بْنِ كَعْبٍ الْحِمْيَرِيِّ، أَنَّ أَبَا بَكْرٍ، حَدَّثَهُ أَنَّ مَرْوَانَ أَرْسَلَهُ إِلَى أُمِّ سَلَمَةَ - رضى الله عنها - يَسْأَلُ عَنِ الرَّجُلِ يُصْبِحُ جُنُبًا أَيَصُومُ فَقَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصْبِحُ جُنُبًا مِنْ جِمَاعٍ لاَ مِنْ حُلُمٍ ثُمَّ لاَ يُفْطِرُ وَلاَ يَقْضِي ‏.‏\hadithno{2591}\hadithtrans{Abu Bakr reported that Marwan sent him to Umm Salama to ask whether a person should observe fast who is in a state of junub and the dawn breaks upon him, whereupon she said that the Messenger of Allah (ﷺ) (was at times) junbi on account of intercourse and not due to sexual dream, and the dawn broke upon him, but he neither broke the fast nor recompensed}}
\hadithdefcmd{muslim}{2592}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ أَبِي، بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ عَنْ عَائِشَةَ، وَأُمِّ سَلَمَةَ زَوْجَىِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُمَا قَالَتَا إِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيُصْبِحُ جُنُبًا مِنْ جِمَاعٍ غَيْرِ احْتِلاَمٍ فِي رَمَضَانَ ثُمَّ يَصُومُ ‏.‏\hadithno{2592}\hadithtrans{Abu Bakr b. 'Abd al-Rahman b. al-Harith b. Hisham reported on the authority of 'A'isha and Umm Salama, the wives of the Messenger of Allah (ﷺ):The Messenger of Allah (ﷺ) at times got up in the morning in a state of junub on account of having a sexual intercourse (with his wives during night) but not due to sexual dreams in the month of Ramadan, and would observe fast}}
\hadithdefcmd{muslim}{2593}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ، جَعْفَرٍ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، - وَهُوَ ابْنُ مَعْمَرِ بْنِ حَزْمٍ الأَنْصَارِيُّ أَبُو طُوَالَةَ - أَنَّ أَبَا يُونُسَ، مَوْلَى عَائِشَةَ أَخْبَرَهُ عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّ رَجُلاً، جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم يَسْتَفْتِيهِ وَهِيَ تَسْمَعُ مِنْ وَرَاءِ الْبَابِ فَقَالَ يَا رَسُولَ اللَّهِ تُدْرِكُنِي الصَّلاَةُ وَأَنَا جُنُبٌ أَفَأَصُومُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَأَنَا تُدْرِكُنِي الصَّلاَةُ وَأَنَا جُنُبٌ فَأَصُومُ ‏"‏ ‏.‏ فَقَالَ لَسْتَ مِثْلَنَا يَا رَسُولَ اللَّهِ قَدْ غَفَرَ اللَّهُ لَكَ مَا تَقَدَّمَ مِنْ ذَنْبِكَ وَمَا تَأَخَّرَ ‏.‏ فَقَالَ ‏"‏ وَاللَّهِ إِنِّي لأَرْجُو أَنْ أَكُونَ أَخْشَاكُمْ لِلَّهِ وَأَعْلَمَكُمْ بِمَا أَتَّقِي ‏"‏ ‏.‏\hadithno{2593}\hadithtrans{A'isha reported that a person came to the Apottle of Allah (ﷺ) asking for a fatwa (religious verdict). She ('A'isha) had been overhearing it from behind the curtain. 'A'isha added that he (the person) had said:Messenger of Allah, (the time) of prayer overtakes me as I am in a state of junub; should I observe fast (in this state)? Upon this the Messenger of Allah (ﷺ) said: (At times the time) of prayer overtakes me while I am in a state of junub, and I observe fast (in that very state), whereupon he said: Messenger of Allah, you are not like us Allah has pardoned all your sins, the previous ones and the later ones. Upon this he (the Holy Prophet) said: By Allah, I hope I am the most God-fearirg of you, and possess the best knowledge among you of those (things) against which I should guard}}
\hadithdefcmd{muslim}{2594}{حَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ النَّوْفَلِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي مُحَمَّدُ بْنُ يُوسُفَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، أَنَّهُ سَأَلَ أُمَّ سَلَمَةَ - رضى الله عنها - عَنِ الرَّجُلِ يُصْبِحُ جُنُبًا أَيَصُومُ قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصْبِحُ جُنُبًا مِنْ غَيْرِ احْتِلاَمٍ ثُمَّ يَصُومُ ‏.‏\hadithno{2594}\hadithtrans{Sulaiman b. Yasar reported that he asked Umm Salama whether a person (who gets up) in the morning in a state of junub should observe fast. She said:The Messenger of Allah (ﷺ) (at times) got up in the morning in a state of junub, not because of sexual dreams (but on account of intercourse at night), and then observed fast}}
\hadithdefcmd{muslim}{2595}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ وَابْنُ نُمَيْرٍ كُلُّهُمْ عَنِ ابْنِ عُيَيْنَةَ، - قَالَ يَحْيَى أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ، الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ هَلَكْتُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ وَمَا أَهْلَكَكَ ‏"‏ ‏.‏ قَالَ وَقَعْتُ عَلَى امْرَأَتِي فِي رَمَضَانَ ‏.‏ قَالَ ‏"‏ هَلْ تَجِدُ مَا تُعْتِقُ رَقَبَةً ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَهَلْ تَسْتَطِيعُ أَنْ تَصُومَ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَهَلْ تَجِدُ مَا تُطْعِمُ سِتِّينَ مِسْكِينًا ‏"‏ ‏.‏ قَالَ لاَ - قَالَ - ثُمَّ جَلَسَ فَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِعَرَقٍ فِيهِ تَمْرٌ ‏.‏ فَقَالَ ‏"‏ تَصَدَّقْ بِهَذَا ‏"‏ ‏.‏ قَالَ أَفْقَرَ مِنَّا فَمَا بَيْنَ لاَبَتَيْهَا أَهْلُ بَيْتٍ أَحْوَجُ إِلَيْهِ مِنَّا ‏.‏ فَضَحِكَ النَّبِيُّ صلى الله عليه وسلم حَتَّى بَدَتْ أَنْيَابُهُ ثُمَّ قَالَ ‏"‏ اذْهَبْ فَأَطْعِمْهُ أَهْلَكَ ‏"‏ ‏.‏\hadithno{2595}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that a person came to the Messenger of Allah (ﷺ) and said:Messenger of Allah, I am undone. He (the Holy Prophet) said: What has brought about your ruin? He said: I have had intercourse with my wife during the month of Ramadan. Upon this he (the Holy prophet) said: Can you find a slave to set him free? He said: NO He (the Prophet again) said: Can you observe fast for two consecutive months? He said: No. He (the Holy Prophet) said: Can you provide food to sixty poor people?, He said: No. He then sat down and (in the meanwhile) there was brought to the Messenger of Allah (ﷺ) a basket which contained dates. He (the Holy Prophet) said: Give these (dates) in charity. He (the man) said: Am I to give to one who is poorer than I? There is no family poorer than mine between the two lava plains of Medina. The Apostle of Allah (ﷺ) laughed so that his molar teeth became visible and said: Go and give it to your family to eat}}
\hadithdefcmd{muslim}{2596}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُحَمَّدِ بْنِ مُسْلِمٍ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَ رِوَايَةِ ابْنِ عُيَيْنَةَ وَقَالَ بِعَرَقٍ فِيهِ تَمْرٌ - وَهُوَ الزِّنْبِيلُ - وَلَمْ يَذْكُرْ فَضَحِكَ النَّبِيُّ صلى الله عليه وسلم حَتَّى بَدَتْ أَنْيَابُهُ ‏.‏\hadithno{2596}\hadithtrans{A hadith like this has been narrated on the authority of Muhammad b. Muslim al-Zuhri with the same chain of transmitters, and he said:There was brought an 'araq containing dates, an 'araq being a huge basket. But in this hadith no mention has been made of (the fact) that the Messenger of Allah (ﷺ) laughed till his molar teeth became visible}}
\hadithdefcmd{muslim}{2597}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - أَنَّ رَجُلاً، وَقَعَ بِامْرَأَتِهِ فِي رَمَضَانَ فَاسْتَفْتَى رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏"‏ هَلْ تَجِدُ رَقَبَةً ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ وَهَلْ تَسْتَطِيعُ صِيَامَ شَهْرَيْنِ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَأَطْعِمْ سِتِّينَ مِسْكِينًا ‏"‏ ‏.‏\hadithno{2597}\hadithtrans{Abu Huraira reported that a person had intercourse with his wife during Ramadan (while fasting). He asked for the religious verdict (about it) from the Messenger of Allah (ﷺ), whereupon he (the Holy Prophet) said:Can you find a slave (to grant him freedom)? He said: No. He (the Prophet again) said: Can you afford to observe fasts for two (consecutive) months? He said: No. He (the Holy Prophet) said: Then feed sixty poor men}}
\hadithdefcmd{muslim}{2598}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا إِسْحَاقُ بْنُ عِيسَى، أَخْبَرَنَا مَالِكٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ أَنَّ رَجُلاً، أَفْطَرَ فِي رَمَضَانَ فَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُكَفِّرَ بِعِتْقِ رَقَبَةٍ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ ابْنِ عُيَيْنَةَ ‏.‏\hadithno{2598}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters that a person broke fast in Ramadan whereupon the Messenger of Allah (ﷺ) commanded him to free a slave (as an atonement), and the rest of the hadith is the same as narrated by Ibn Uyaina}}
\hadithdefcmd{muslim}{2599}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، حَدَّثَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ رَجُلاً أَفْطَرَ فِي رَمَضَانَ أَنْ يُعْتِقَ رَقَبَةً أَوْ يَصُومَ شَهْرَيْنِ أَوْ يُطْعِمَ سِتِّينَ مِسْكِينًا ‏.‏\hadithno{2599}\hadithtrans{Humaid b. 'Abd al-Rahman reported that Abu Huraira had narrated to him that the Messenger of Allah (ﷺ) commanded the person (who) broke the fast in Ramadan to free a slave or observe fasts for two (consecutive) months or feed sixty poor persons}}
\hadithdefcmd{muslim}{2600}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِ ابْنِ عُيَيْنَةَ ‏.‏\hadithno{2600}\hadithtrans{This hadith has been narrated with the same chain of transmitters on the authority of Zuhri}}
\hadithdefcmd{muslim}{2601}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ، الرَّحْمَنِ بْنِ الْقَاسِمِ عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّهَا قَالَتْ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ احْتَرَقْتُ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لِمَ ‏"‏ ‏.‏ قَالَ وَطِئْتُ امْرَأَتِي فِي رَمَضَانَ نَهَارًا ‏.‏ قَالَ ‏"‏ تَصَدَّقْ تَصَدَّقْ ‏"‏ ‏.‏ قَالَ مَا عِنْدِي شَىْءٌ ‏.‏ فَأَمَرَهُ أَنْ يَجْلِسَ فَجَاءَهُ عَرَقَانِ فِيهِمَا طَعَامٌ فَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَتَصَدَّقَ بِهِ ‏.‏\hadithno{2601}\hadithtrans{A'isha (Allah be pleased with her) reported that a person came to the Messenger of Allah (ﷺ) and said:I am burnt, whereupon the Messenger of Allah (ﷺ) said: How is it? He (the person) said: I had intercourse with my wife during the day in Ramadan. Upon this (the Holy Prophet) said: Give charity, give charity. He (the person) said: There is nothing with me. He commanded him to sit down, (In the meanwhile) there were brought to him (to the Holy Prophet) two baskets containing eatables, whereupon the Messenger of Allah (ﷺ) told him to give them as sadaqa}}
\hadithdefcmd{muslim}{2602}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، أَخْبَرَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، يَقُولُ أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ الْقَاسِمِ، أَنَّ مُحَمَّدَ بْنَ جَعْفَرِ بْنِ الزُّبَيْرِ، أَخْبَرَهُ أَنَّ عَبَّادَ بْنَ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ حَدَّثَهُ أَنَّهُ، سَمِعَ عَائِشَةَ، - رضى الله عنها - تَقُولُ أَتَى رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ الْحَدِيثَ وَلَيْسَ فِي أَوَّلِ الْحَدِيثِ ‏ "‏ تَصَدَّقْ تَصَدَّقْ ‏"‏ ‏.‏ وَلاَ قَوْلُهُ نَهَارًا ‏.‏\hadithno{2602}\hadithtrans{Abbad b. Abdullah b. Zubair narrated that he heard 'A'isha (Allah be pleased with her) saying:A person came to the Messenger of Allah (ﷺ), and he then narrated the hadith. But (neither these words are found):" Give charity, give charity" (nor) his words:" during the day time}}
\hadithdefcmd{muslim}{2603}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ عَبْدَ الرَّحْمَنِ، بْنَ الْقَاسِمِ حَدَّثَهُ أَنَّ مُحَمَّدَ بْنَ جَعْفَرِ بْنِ الزُّبَيْرِ حَدَّثَهُ أَنَّ عَبَّادَ بْنَ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ حَدَّثَهُ أَنَّهُ، سَمِعَ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ أَتَى رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ فِي رَمَضَانَ فَقَالَ يَا رَسُولَ اللَّهِ احْتَرَقْتُ احْتَرَقْتُ ‏.‏ فَسَأَلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا شَأْنُهُ ‏"‏ ‏.‏ فَقَالَ أَصَبْتُ أَهْلِي ‏.‏ قَالَ ‏"‏ تَصَدَّقْ ‏"‏ ‏.‏ فَقَالَ وَاللَّهِ يَا نَبِيَّ اللَّهِ مَا لِي شَىْءٌ وَمَا أَقْدِرُ عَلَيْهِ ‏.‏ قَالَ ‏"‏ اجْلِسْ ‏"‏ ‏.‏ فَجَلَسَ فَبَيْنَا هُوَ عَلَى ذَلِكَ أَقْبَلَ رَجُلٌ يَسُوقُ حِمَارًا عَلَيْهِ طَعَامٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيْنَ الْمُحْتَرِقُ آنِفًا ‏"‏ ‏.‏ فَقَامَ الرَّجُلُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَصَدَّقْ بِهَذَا ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ أَغَيْرَنَا فَوَاللَّهِ إِنَّا لَجِيَاعٌ مَا لَنَا شَىْءٌ ‏.‏ قَالَ ‏"‏ فَكُلُوهُ ‏"‏ ‏.‏\hadithno{2603}\hadithtrans{Abbad b. Abdullah b. Zubair reported that he had heard 'A'isha, the wife of the Messenger of Allah (ﷺ), as saying:A person came to the Messenger of Allah (ﷺ) in the mosque during (the month of) Ramadan and said: Messenger of Allah, I am burnt, I am burnt, whereupon the Messenger of Allah (ﷺ) asked him as to what the matter was. Upon this he said: I had intercourse with my wife (in a state of fasting) Thereupon he (the Holy Prophet) said: Give charity. Upon this he said: Apostle of Allah, I swear by God, there is nothing with me (to give in charity) as I do not possess anything. He (the Holy Prophet) said: Sit down. So he sat down and he was in this very state when there came a person urging a donkey with a load of eatables upon it. The Messenger of Allah (ﷺ) said: Where is that burnt one who was just here? Thereupon the person stood up. The Messenger of Allah (ﷺ) said: Give this (eatables brought by the man) in charity. Upon this the person said: Messenger of Allah, can there be anyone else (more deserving than I)? By Allah. we are hungry, we have nothing with us. Upon this he (the Holy Prophet) said: Then eat (these eatables)}}
\hadithdefcmd{muslim}{2604}{حَدَّثَنِي يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ، سَعِيدٍ حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - أَنَّهُ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ عَامَ الْفَتْحِ فِي رَمَضَانَ فَصَامَ حَتَّى بَلَغَ الْكَدِيدَ ثُمَّ أَفْطَرَ وَكَانَ صَحَابَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَتَّبِعُونَ الأَحْدَثَ فَالأَحْدَثَ مِنْ أَمْرِهِ ‏.‏\hadithno{2604}\hadithtrans{Ibn Abbas (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) went out during the month of Ramadan in the year of Victory (when Mecca was conquered) and was fasting till he reached Kadid (a canal situated at a distance of forty-two miles from Mecca) and he then broke the fast. And it was the habit of the Companions of the Messenger of Allah (ﷺ) to follow him in every new thing (or act). So they followed him also (in this matter)}}
\hadithdefcmd{muslim}{2605}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ عَنْ سُفْيَانَ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏ قَالَ يَحْيَى قَالَ سُفْيَانُ لاَ أَدْرِي مِنْ قَوْلِ مَنْ هُوَ يَعْنِي وَكَانَ يُؤْخَذُ بِالآخِرِ مِنْ قَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2605}\hadithtrans{This hadith is narrated on the authority of Zuhri with the same chain of transmitters. Yahya (one of the narrators) said that Sufyan (the narrator) had stated:I do not know whose statement it is:" It is the last word of the Messenger of Allah (ﷺ) which is accepted as (final as it abrogates the previous ones)}}
\hadithdefcmd{muslim}{2606}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ قَالَ الزُّهْرِيُّ وَكَانَ الْفِطْرُ آخِرَ الأَمْرَيْنِ وَإِنَّمَا يُؤْخَذُ مِنْ أَمْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالآخِرِ فَالآخِرِ ‏.‏ قَالَ الزُّهْرِيُّ فَصَبَّحَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَكَّةَ لِثَلاَثَ عَشْرَةَ لَيْلَةً خَلَتْ مِنْ رَمَضَانَ ‏.‏\hadithno{2606}\hadithtrans{It has been narrated on the authority of Zuhri with the same chain of transmitters that breaking of fast (in a journey) is the final of the two commands (whether one may fast or one may break it), and it is the last command of the Messenger of Allah (ﷺ) which is to be accepted as final. Zuhri said:The Messenger of Allah (ﷺ) marched on Mecca on the morning of 14th of Ramadan (lit. when thirteen nights had passed)}}
\hadithdefcmd{muslim}{2607}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ مِثْلَ حَدِيثِ اللَّيْثِ ‏.‏ قَالَ ابْنُ شِهَابٍ فَكَانُوا يَتَّبِعُونَ الأَحْدَثَ فَالأَحْدَثَ مِنْ أَمْرِهِ وَيَرَوْنَهُ النَّاسِخَ الْمُحْكَمَ ‏.‏\hadithno{2607}\hadithtrans{A hadlth like this has been transmitted on the authority of Ibn Shibab who said that they (the Compnions of the Holy Prophet) followed the latest of his commands and looked upon it as one abrogating (the previous ones) and the most firm}}
\hadithdefcmd{muslim}{2608}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ سَافَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي رَمَضَانَ فَصَامَ حَتَّى بَلَغَ عُسْفَانَ ثُمَّ دَعَا بِإِنَاءٍ فِيهِ شَرَابٌ فَشَرِبَهُ نَهَارًا لِيَرَاهُ النَّاسُ ثُمَّ أَفْطَرَ حَتَّى دَخَلَ مَكَّةَ ‏.‏ قَالَ ابْنُ عَبَّاسٍ - رضى الله عنهما - فَصَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَفْطَرَ فَمَنْ شَاءَ صَامَ وَمَنْ شَاءَ أَفْطَرَ ‏.‏\hadithno{2608}\hadithtrans{Ibn 'Abbas (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) journeyed during the month of Ramadan in a state of fasting till he reached 'Usfan. He then ordered a cup containing drinking water and he drank that openly so that the people might see it, and broke the fast (and did not resume it) till he reached Mecca. Ibn 'Abbas (Allah be pleased with him) said:Allah's Messenger (ﷺ) fasted and broke the fast, so he who wished fasted and he who wished to break it broke it}}
\hadithdefcmd{muslim}{2609}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الْكَرِيمِ، عَنْ طَاوُسٍ، عَنِ ابْنِ، عَبَّاسٍ - رضى الله عنهما - قَالَ لاَ تَعِبْ عَلَى مَنْ صَامَ وَلاَ عَلَى مَنْ أَفْطَرَ قَدْ صَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي السَّفَرِ وَأَفْطَرَ ‏.‏\hadithno{2609}\hadithtrans{Ibn Abbas (Allah be pleased with him) reported:Do not condemn one who observes fast, or one who does not observe (in a journey). for the Messenger of Allah (ﷺ) observed fast in a journey or he did not observe it (too)}}
\hadithdefcmd{muslim}{2610}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي ابْنَ عَبْدِ الْمَجِيدِ - حَدَّثَنَا جَعْفَرٌ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، - رضى الله عنهما - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ عَامَ الْفَتْحِ إِلَى مَكَّةَ فِي رَمَضَانَ فَصَامَ حَتَّى بَلَغَ كُرَاعَ الْغَمِيمِ فَصَامَ النَّاسُ ثُمَّ دَعَا بِقَدَحٍ مِنْ مَاءٍ فَرَفَعَهُ حَتَّى نَظَرَ النَّاسُ إِلَيْهِ ثُمَّ شَرِبَ فَقِيلَ لَهُ بَعْدَ ذَلِكَ إِنَّ بَعْضَ النَّاسِ قَدْ صَامَ فَقَالَ ‏ "‏ أُولَئِكَ الْعُصَاةُ أُولَئِكَ الْعُصَاةُ ‏"‏ ‏.‏\hadithno{2610}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with both of them) reported that Allah's Messenger (ﷺ) went out to Mecca in Ramadan in the year of Victory, and he and the people fasted till he came to Kura' al-Ghamim and the people also fasted. He then called for a cup of water which he raised till the people saw it, and then he drank. He was told afterwards that some people had continued to fast, and he said:These people are the disobedient ones; these are the disobedient ones}}
\hadithdefcmd{muslim}{2611}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنْ جَعْفَرٍ، بِهَذَا الإِسْنَادِ وَزَادَ فَقِيلَ لَهُ إِنَّ النَّاسَ قَدْ شَقَّ عَلَيْهِمُ الصِّيَامُ وَإِنَّمَا يَنْظُرُونَ فِيمَا فَعَلْتَ ‏.‏ فَدَعَا بِقَدَحٍ مِنْ مَاءٍ بَعْدَ الْعَصْرِ ‏.‏\hadithno{2611}\hadithtrans{This hadith has been narrated by Ja'far with the same chain of transmitters and he added:It was said to him (to the Holy Prophet): There are people to whom fasting has become unbearable and they are waiting how you do. He (the Holy Prophet) then called for a cup of water when it was afternoon. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2612}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ جَمِيعًا عَنْ مُحَمَّدِ، بْنِ جَعْفَرٍ - قَالَ أَبُو بَكْرٍ حَدَّثَنَا غُنْدَرٌ، - عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ سَعْدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ الْحَسَنِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، - رضى الله عنهما - قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَرَأَى رَجُلاً قَدِ اجْتَمَعَ النَّاسُ عَلَيْهِ وَقَدْ ظُلِّلَ عَلَيْهِ فَقَالَ ‏"‏ مَا لَهُ ‏"‏ ‏.‏ قَالُوا رَجُلٌ صَائِمٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَيْسَ مِنَ الْبِرِّ أَنْ تَصُومُوا فِي السَّفَرِ ‏"‏ ‏.‏\hadithno{2612}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with both of them) reported that in the course of a journey Allah's Messenger (ﷺ) saw a man, people crowding around him and providing him a shade. Upon this he (the Holy Prophet) said:What is the matter with him? They said: He is a person observing fast. Whereupon the Messenger of Allah (ﷺ) said: It is no righteousness that you fast on journey}}
\hadithdefcmd{muslim}{2613}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ عَمْرِو بْنِ الْحَسَنِ، يُحَدِّثُ أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، - رضى الله عنهما - يَقُولُ رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً بِمِثْلِهِ ‏.‏\hadithno{2613}\hadithtrans{Amr b. al-Hasan is reported to have said that he heard Jabir b. 'Abdullah (Allah be pleased with both of them) as saying that the Messenger of Allah (ﷺ) saw a man. The rest of the hadith is the same as mentioned above}}
\hadithdefcmd{muslim}{2614}{وَحَدَّثَنَاهُ أَحْمَدُ بْنُ عُثْمَانَ النَّوْفَلِيُّ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ وَزَادَ قَالَ شُعْبَةُ وَكَانَ يَبْلُغُنِي عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ أَنَّهُ كَانَ يَزِيدُ فِي هَذَا الْحَدِيثِ وَفِي هَذَا الإِسْنَادِ أَنَّهُ قَالَ ‏ "‏ عَلَيْكُمْ بِرُخْصَةِ اللَّهِ الَّذِي رَخَّصَ لَكُمْ ‏"‏ ‏.‏ قَالَ فَلَمَّا سَأَلْتُهُ لَمْ يَحْفَظْهُ ‏.‏\hadithno{2614}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters but with this addition that he (the Holy Prophet) said:" Take advantage of the concession of Allah Who Wanted it to you." When he (one of the narrators) asked him (the other one, Yabya b. Abi Kathar) he did not retain it in his mind}}
\hadithdefcmd{muslim}{2615}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامُ بْنُ يَحْيَى، حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، - رضى الله عنه - قَالَ غَزَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لِسِتَّ عَشْرَةَ مَضَتْ مِنْ رَمَضَانَ فَمِنَّا مَنْ صَامَ وَمِنَّا مَنْ أَفْطَرَ فَلَمْ يَعِبِ الصَّائِمُ عَلَى الْمُفْطِرِ وَلاَ الْمُفْطِرُ عَلَى الصَّائِمِ ‏.‏\hadithno{2615}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported:We went out on an expedition with Allah's Messenger (ﷺ) on the 16th of Ramadan. Some of us fasted and some of us broke the fast. But neither the observer of the fast found fault with one who broke it, nor the breaker of the fast found fault with one who observed it}}
\hadithdefcmd{muslim}{2616}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ التَّيْمِيِّ، ح وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ مَهْدِيٍّ، حَدَّثَنَا شُعْبَةُ، وَقَالَ ابْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا هِشَامٌ، وَقَالَ ابْنُ الْمُثَنَّى، حَدَّثَنَا سَالِمُ بْنُ نُوحٍ، حَدَّثَنَا عُمَرُ يَعْنِي ابْنَ عَامِرٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ سَعِيدٍ، كُلُّهُمْ عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ هَمَّامٍ غَيْرَ أَنَّ فِي حَدِيثِ التَّيْمِيِّ وَعُمَرَ بْنِ عَامِرٍ وَهِشَامٍ لِثَمَانَ عَشْرَةَ خَلَتْ وَفِي حَدِيثِ سَعِيدٍ فِي ثِنْتَىْ عَشْرَةَ ‏.‏ وَشُعْبَةَ لِسَبْعَ عَشْرَةَ أَوْ تِسْعَ عَشْرَةَ ‏.‏\hadithno{2616}\hadithtrans{A hadith like this has been narrated on the authority of Qatada with the same chain of transmitters by different narrators (except this difference) that in the hadith transmitted by Taimi and Umar b. Amir and Hisham (the date of setting out is) 18th, and in the hadith transmitted by Sa'id it is the 12th, and in the one transmitted by Shu'ba it is the 17th or 19th}}
\hadithdefcmd{muslim}{2617}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ مُفَضَّلٍ - عَنْ أَبِي مَسْلَمَةَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، - رضى الله عنه - قَالَ كُنَّا نُسَافِرُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَمَضَانَ فَمَا يُعَابُ عَلَى الصَّائِمِ صَوْمُهُ وَلاَ عَلَى الْمُفْطِرِ إِفْطَارُهُ ‏.‏\hadithno{2617}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported:We went out on an expedition with the Messenger of Allah (ﷺ) during Ramadan and neither the observer of the fast was found fault with for his fasting, nor the breaker of the fast for breaking it}}
\hadithdefcmd{muslim}{2618}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، - رضى الله عنه - قَالَ كُنَّا نَغْزُو مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَمَضَانَ فَمِنَّا الصَّائِمُ وَمِنَّا الْمُفْطِرُ فَلاَ يَجِدُ الصَّائِمُ عَلَى الْمُفْطِرِ وَلاَ الْمُفْطِرُ عَلَى الصَّائِمِ يَرَوْنَ أَنَّ مَنْ وَجَدَ قُوَّةً فَصَامَ فَإِنَّ ذَلِكَ حَسَنٌ وَيَرَوْنَ أَنَّ مَنْ وَجَدَ ضَعْفًا فَأَفْطَرَ فَإِنَّ ذَلِكَ حَسَنٌ ‏.‏\hadithno{2618}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported:We went out on an expedition with the Messenger of Allah (ﷺ) during Ramadan. Some of us observed the fast and some of us broke it. Neither the observer of the fast had any grudge against one who broke it, nor the breaker of the fast had any grudge against one who had fasted They knew that he who had strength enough (to bear its rigour) fasted and that was good, and they also found that he who felt weakness (and could not bear the burden) broke it, and that was also good}}
\hadithdefcmd{muslim}{2619}{حَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، وَسَهْلُ بْنُ عُثْمَانَ، وَسُوَيْدُ بْنُ سَعِيدٍ، وَحُسَيْنُ، بْنُ حُرَيْثٍ كُلُّهُمْ عَنْ مَرْوَانَ، - قَالَ سَعِيدٌ أَخْبَرَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، - عَنْ عَاصِمٍ، قَالَ سَمِعْتُ أَبَا نَضْرَةَ، يُحَدِّثُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَجَابِرِ بْنِ عَبْدِ اللَّهِ، - رضى الله عنهم - قَالاَ سَافَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَيَصُومُ الصَّائِمُ وَيُفْطِرُ الْمُفْطِرُ فَلاَ يَعِيبُ بَعْضُهُمْ عَلَى بَعْضٍ ‏.‏\hadithno{2619}\hadithtrans{Abu Nadra reported Abu Sa'id al. Khudri and Jabir b. Abdullah as saying:We travelled with the Messenger of Allah (ﷺ). The observer of the fast observed it, and the breaker of the fast broke it, but none of them found fault with each other}}
\hadithdefcmd{muslim}{2620}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ حُمَيْدٍ، قَالَ سُئِلَ أَنَسٌ - رضى الله عنه - عَنْ صَوْمِ رَمَضَانَ فِي السَّفَرِ فَقَالَ سَافَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَمَضَانَ فَلَمْ يَعِبِ الصَّائِمُ عَلَى الْمُفْطِرِ وَلاَ الْمُفْطِرُ عَلَى الصَّائِمِ ‏.‏\hadithno{2620}\hadithtrans{Humaid reported that Anas (Allah be pleased with him) was asked about fasting during Ramadan while travelling. He said:We travelled with the Messenger of Allah (ﷺ) during the month of Ramadan, but neither the observer of the fast found fault with the breaker of the fast, nor the breaker of the fast found fault with the observer of the fast}}
\hadithdefcmd{muslim}{2621}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ حُمَيْدٍ، قَالَ خَرَجْتُ فَصُمْتُ فَقَالُوا لِي أَعِدْ ‏.‏ قَالَ فَقُلْتُ إِنَّ أَنَسًا أَخْبَرَنِي أَنَّ أَصْحَابَ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانُوا يُسَافِرُونَ فَلاَ يَعِيبُ الصَّائِمُ عَلَى الْمُفْطِرِ وَلاَ الْمُفْطِرُ عَلَى الصَّائِمِ ‏.‏ فَلَقِيتُ ابْنَ أَبِي مُلَيْكَةَ فَأَخْبَرَنِي عَنْ عَائِشَةَ - رضى الله عنها - بِمِثْلِهِ ‏.‏\hadithno{2621}\hadithtrans{Abu Khalid al-Ahmar narrated from Humaid who said:I went out and was fasting; they said to me: Break (lit. go back, repeat). He said that Anas reported that the Companions of the Messenger of Allah (ﷺ) used to set out on a journey and neither the observer of the fast found fault with the breaker of the fast, nor the breaker of the fast found fault with the observer of the fast. (One of the narrators Humaid said): I met Ibn Abi Mulaika who informed me the same thing on the authority of 'A'isha}}
\hadithdefcmd{muslim}{2622}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ عَاصِمٍ، عَنْ مُوَرِّقٍ، عَنْ أَنَسٍ، - رضى الله عنه - قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي السَّفَرِ فَمِنَّا الصَّائِمُ وَمِنَّا الْمُفْطِرُ - قَالَ - فَنَزَلْنَا مَنْزِلاً فِي يَوْمٍ حَارٍّ أَكْثَرُنَا ظِلاًّ صَاحِبُ الْكِسَاءِ وَمِنَّا مَنْ يَتَّقِي الشَّمْسَ بِيَدِهِ - قَالَ - فَسَقَطَ الصُّوَّامُ وَقَامَ الْمُفْطِرُونَ فَضَرَبُوا الأَبْنِيَةَ وَسَقَوُا الرِّكَابَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ذَهَبَ الْمُفْطِرُونَ الْيَوْمَ بِالأَجْرِ ‏"‏ ‏.‏\hadithno{2622}\hadithtrans{Anas (Allah be pleased with him) reported:We were with the Messenger of Allah (ﷺ) on a journey. Some of us had been observing the fast and some of us had not been fasting. We got down at a place on a hot day. Most of us had the cloth for shelter. There were also those amongst us who sheltered (themselves against the rays of the) sun with the help of their hands. The observers of the fast fell down (on account of weakness). Those who had not observed it got up and pitched tents and watered the mounts. Thereupon the Messenger of Allah (ﷺ) said: The breakers of the fast have taken away the reward today}}
\hadithdefcmd{muslim}{2623}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا حَفْصٌ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ مُوَرِّقٍ، عَنْ أَنَسٍ، - رضى الله عنه - قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَصَامَ بَعْضٌ وَأَفْطَرَ بَعْضٌ فَتَحَزَّمَ الْمُفْطِرُونَ وَعَمِلُوا وَضَعُفَ الصُّوَّامُ عَنْ بَعْضِ الْعَمَلِ - قَالَ - فَقَالَ فِي ذَلِكَ ‏ "‏ ذَهَبَ الْمُفْطِرُونَ الْيَوْمَ بِالأَجْرِ ‏"‏ ‏.‏\hadithno{2623}\hadithtrans{Anas (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) was journeying (along with his Companions). Some of them had observed the fast whereas the others had broken it. Those who did not fast girded up their loins and worked, but the observers of the fast were too weak to work. Upon this he (the Messenger of Allah) said:Today the breakers of the fast have gone with the reward}}
\hadithdefcmd{muslim}{2624}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ رَبِيعَةَ، قَالَ حَدَّثَنِي قَزَعَةُ، قَالَ أَتَيْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ - رضى الله عنه - وَهُوَ مَكْثُورٌ عَلَيْهِ فَلَمَّا تَفَرَّقَ النَّاسُ عَنْهُ قُلْتُ إِنِّي لاَ أَسْأَلُكَ عَمَّا يَسْأَلُكَ هَؤُلاَءِ عَنْهُ ‏.‏ سَأَلْتُهُ عَنِ الصَّوْمِ فِي السَّفَرِ فَقَالَ سَافَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى مَكَّةَ وَنَحْنُ صِيَامٌ قَالَ فَنَزَلْنَا مَنْزِلاً فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّكُمْ قَدْ دَنَوْتُمْ مِنْ عَدُوِّكُمْ وَالْفِطْرُ أَقْوَى لَكُمْ ‏"‏ ‏.‏ فَكَانَتْ رُخْصَةً فَمِنَّا مَنْ صَامَ وَمِنَّا مَنْ أَفْطَرَ ثُمَّ نَزَلْنَا مَنْزِلاً آخَرَ فَقَالَ ‏"‏ إِنَّكُمْ مُصَبِّحُو عَدُوِّكُمْ وَالْفِطْرُ أَقْوَى لَكُمْ فَأَفْطِرُوا ‏"‏ ‏.‏ وَكَانَتْ عَزْمَةً فَأَفْطَرْنَا ثُمَّ قَالَ لَقَدْ رَأَيْتُنَا نَصُومُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بَعْدَ ذَلِكَ فِي السَّفَرِ ‏.‏\hadithno{2624}\hadithtrans{Qaza'a reported:I came to Abu Sa'id al-Khudri (Allah be pleased with him) and he was surrounded (by people), and when they dispersed I said to him: I am not going to ask you about what these people were asking. I ask you about fasting on a journey. Upon this he said: We travelled with the Messenger of Allah (ﷺ) towards Mecca and we had been observing fast. We halted at a place. There the Messenger of Allah (ﷺ) said: You are nearing your enemy and breaking of fast would give you greater strength, and that was a concession (given to us). But some of us continued to observe the fast and some of us broke it. We then got down at another place and he (the Holy Prophet) said: You are going to encounter the enemy in the morning and breaking of the fast would give you strength, so break the fast. As it was a point of stress, so we broke the fast. But subsequently we saw ourselves observing the fast with the Messenger of Allah (ﷺ) on a journey}}
\hadithdefcmd{muslim}{2625}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّهَا قَالَتْ سَأَلَ حَمْزَةُ بْنُ عَمْرٍو الأَسْلَمِيُّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصِّيَامِ فِي السَّفَرِ فَقَالَ ‏ "‏ إِنْ شِئْتَ فَصُمْ وَإِنْ شِئْتَ فَأَفْطِرْ ‏"‏ ‏.‏\hadithno{2625}\hadithtrans{A'isha (Allah be pleased with her) reported that Hamza b. 'Amr al-Aslami asked the Messenger of Allah (ﷺ) about fasting on a journey, and he (the Holy Prophet) said:Fast if you like and break it if you like}}
\hadithdefcmd{muslim}{2626}{وَحَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، - وَهُوَ ابْنُ زَيْدٍ - حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّ حَمْزَةَ بْنَ عَمْرٍو الأَسْلَمِيَّ، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي رَجُلٌ أَسْرُدُ الصَّوْمَ ‏.‏ أَفَأَصُومُ فِي السَّفَرِ قَالَ ‏ "‏ صُمْ إِنْ شِئْتَ وَأَ��ْطِرْ إِنْ شِئْتَ ‏"‏ ‏.‏\hadithno{2626}\hadithtrans{A'isha (Allah be pleased with her) reported that Hamza b. Amr al-Aslami asked the Messenger of Allah (ﷺ) thus:Messenger of Allah, I am a person devoted much to fasting. Should I fast during the journey? He (the Holy Prophet) said: Fast if you like and break it if you like}}
\hadithdefcmd{muslim}{2627}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَ حَدِيثِ حَمَّادِ بْنِ زَيْدٍ إِنِّي رَجُلٌ أَسْرُدُ الصَّوْمَ ‏.‏\hadithno{2627}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{2628}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا ابْنُ نُمَيْرٍ، وَقَالَ أَبُو بَكْرٍ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، كِلاَهُمَا عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ أَنَّ حَمْزَةَ، قَالَ إِنِّي رَجُلٌ أَصُومُ أَفَأَصُومُ فِي السَّفَرِ\hadithno{2628}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters that Hamza said:I am a person much used to fasting. Should I fast during the journey? (The rest of the hadith is the same)}}
\hadithdefcmd{muslim}{2629}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَهَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، - قَالَ هَارُونُ حَدَّثَنَا وَقَالَ أَبُو الطَّاهِرِ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ أَبِي الأَسْوَدِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ أَبِي مُرَاوِحٍ، عَنْ حَمْزَةَ بْنِ عَمْرٍو الأَسْلَمِيِّ، - رضى الله عنه - أَنَّهُ قَالَ يَا رَسُولَ اللَّهِ أَجِدُ بِي قُوَّةً عَلَى الصِّيَامِ فِي السَّفَرِ فَهَلْ عَلَىَّ جُنَاحٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هِيَ رُخْصَةٌ مِنَ اللَّهِ فَمَنْ أَخَذَ بِهَا فَحَسَنٌ وَمَنْ أَحَبَّ أَنْ يَصُومَ فَلاَ جُنَاحَ عَلَيْهِ ‏"‏ ‏.‏ قَالَ هَارُونُ فِي حَدِيثِهِ ‏"‏ هِيَ رُخْصَةٌ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ مِنَ اللَّهِ ‏.‏\hadithno{2629}\hadithtrans{Hamza b. 'Amr al-Aslami (Allah be pleased with him) said:Messenger of Allah, I find strength in me for fasting on a journey; is there any sin upon me (in doing it)? Thereupon the Messenger of Allah (ﷺ) said: It is a concession from Allah. He who took advantage of it, it is good for him, and he who preferred to observe fast, there is no sin upon him. Harun (one of the narrators) in his narration said: 'lt is a concession, and he made no mention of" from Allah}}
\hadithdefcmd{muslim}{2630}{حَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ سَعِيدِ بْنِ عَبْدِ الْعَزِيزِ، عَنْ إِسْمَاعِيلَ، بْنِ عُبَيْدِ اللَّهِ عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، - رضى الله عنه - قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي شَهْرِ رَمَضَانَ فِي حَرٍّ شَدِيدٍ حَتَّى إِنْ كَانَ أَحَدُنَا لَيَضَعُ يَدَهُ عَلَى رَأْسِهِ مِنْ شِدَّةِ الْحَرِّ وَمَا فِينَا صَائِمٌ إِلاَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعَبْدُ اللَّهِ بْنُ رَوَاحَةَ ‏.‏\hadithno{2630}\hadithtrans{Abu Darda' (Allah be pleased with him) reported:We set out during the month of Ramadan with the Messenger of Allah (ﷺ) in such an intense heat that one of us would place his hand over his head (in order to protect himself) against the excessive heat, and none among us was observing the fast, except the Messenger of Allah (ﷺ) and 'Abdullah b. Rawaha}}
\hadithdefcmd{muslim}{2631}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ عُثْمَانَ بْنِ حَيَّانَ، الدِّمَشْقِيِّ عَنْ أُمِّ الدَّرْدَاءِ، قَالَتْ قَالَ أَبُو الدَّرْدَاءِ لَقَدْ رَأَيْتُنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ فِي يَوْمٍ شَدِيدِ الْحَرِّ حَتَّى إِنَّ الرَّجُلَ لَيَضَعُ يَدَهُ عَلَى رَأْسِهِ مِنْ شِدَّةِ الْحَرِّ وَمَا مِنَّا أَحَدٌ صَائِمٌ إِلاَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعَبْدُ اللَّهِ بْنُ رَوَاحَةَ ‏.‏\hadithno{2631}\hadithtrans{Abu Darda' reported:We were with the Messenger of Allah (ﷺ) on some of his journeys on an intensely hot day so much so that a person would place his hand on his head (in order to protect himself) against excessive heat, and none amongst us was fasting but the Messenger of Allah (ﷺ) and Abdullah b. Rawaha}}
\hadithdefcmd{muslim}{2632}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي النَّضْرِ، عَنْ عُمَيْرٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ عَنْ أُمِّ الْفَضْلِ بِنْتِ الْحَارِثِ، أَنَّ نَاسًا، تَمَارَوْا عِنْدَهَا يَوْمَ عَرَفَةَ فِي صِيَامِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ بَعْضُهُمْ هُوَ صَائِمٌ وَقَالَ بَعْضُهُمْ لَيْسَ بِصَائِمٍ ‏.‏ فَأَرْسَلْتُ إِلَيْهِ بِقَدَحِ لَبَنٍ وَهُوَ وَاقِفٌ عَلَى بَعِيرِهِ بِعَرَفَةَ فَشَرِبَهُ ‏.‏\hadithno{2632}\hadithtrans{Umm al-Fadl bint- al-Harith reported that some people argued about the fasting of the Messenger of Allah (ﷺ) on the day of 'Arafa. Some of them said that he had been fasting, whereas the others said that he had not been fasting. I sent a cup of milk to him while he was riding his camel at 'Arafa, and he drank it}}
\hadithdefcmd{muslim}{2633}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، عَنْ سُفْيَانَ، عَنْ أَبِي النَّضْرِ، بِهَذَا الإِسْنَادِ ‏.‏ وَلَمْ يَذْكُرْ وَهُوَ وَاقِفٌ عَلَى بَعِيرِهِ ‏.‏ وَقَالَ عَنْ عُمَيْرٍ مَوْلَى أُمِّ الْفَضْلِ ‏.‏\hadithno{2633}\hadithtrans{This hadith has been narrated on the authority of Abu Nadr with the same chain of transmitters, but he did not mention that he was mounting (riding on) his camel}}
\hadithdefcmd{muslim}{2634}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ سَالِمٍ أَبِي، النَّضْرِ بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِ ابْنِ عُيَيْنَةَ وَقَالَ عَنْ عُمَيْرٍ، مَوْلَى أُمِّ الْفَضْلِ ‏.‏\hadithno{2634}\hadithtrans{This hadith has been narrated by Abu Nadr on the authority of Umair, the freed slave of Umm al-Fadl, through the same chain of transmitters}}
\hadithdefcmd{muslim}{2635}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، أَنَّ أَبَا النَّضْرِ، حَدَّثَهُ أَنَّ عُمَيْرًا مَوْلَى ابْنِ عَبَّاسٍ - رضى الله عنهما - حَدَّثَهُ أَنَّهُ، سَمِعَ أُمَّ الْفَضْلِ، - رضى الله عنها - تَقُولُ شَكَّ نَاسٌ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي صِيَامِ يَوْمِ عَرَفَةَ وَنَحْنُ بِهَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَرْسَلْتُ إِلَيْهِ بِقَعْبٍ فِيهِ لَبَنٌ وَهُوَ بِعَرَفَةَ فَشَرِبَهُ ‏.‏\hadithno{2635}\hadithtrans{Umm al-Fadl (Allah be pleased with her) is reported to have said that some people among the Companions of the Messenger of Allah (ﷺ) were in doubt about fasting on the day of 'Arafa and we were with him on that day. I (Umm al-Fadl) sent him a cup of milk and he was halting at 'Arafa, and he drank that}}
\hadithdefcmd{muslim}{2636}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنْ بُكَيْرِ بْنِ، الأَشَجِّ عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ - رضى الله عنهما - عَنْ مَيْمُونَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ إِنَّ النَّاسَ شَكُّوا فِي صِيَامِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ عَرَفَةَ فَأَرْسَلَتْ إِلَيْهِ مَيْمُونَةُ بِحِلاَبِ اللَّبَنِ وَهُوَ وَاقِفٌ فِي الْمَوْقِفِ فَشَرِبَ مِنْهُ وَالنَّاسُ يَنْظُرُونَ إِلَيْهِ ‏.‏\hadithno{2636}\hadithtrans{Kuraib, the freed slave of Ibn 'Abbas (Allah be pleased with him), reported from Maimuna, the wife of the Messenger of Allah (ﷺ), that people had doubt about the fasting of Allah's Messenger (ﷺ) on the day of 'Arafa. Maimuna sent him a cup of milk and he was halting at a place and he drank it and the people were seeing him}}
\hadithdefcmd{muslim}{2637}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَتْ قُرَيْشٌ تَصُومُ عَاشُورَاءَ فِي الْجَاهِلِيَّةِ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُهُ فَلَمَّا هَاجَرَ إِلَى الْمَدِينَةِ صَامَهُ وَأَمَرَ بِصِيَامِهِ فَلَمَّا فُرِضَ شَهْرُ رَمَضَانَ قَالَ ‏ "‏ مَنْ شَاءَ صَامَهُ وَمَنْ شَاءَ تَرَكَهُ ‏"‏ ‏.‏\hadithno{2637}\hadithtrans{A'isha (Allah be pleased with her) reported that the Quraish used to fast on the day of 'Ashura in the pre-Islamic days and the Messenger of Allah (ﷺ) also observed it. When he migrated to Medina, he himself observed this fast and commanded (others) to observe it. But when fasting during the month of Ramadan was made obligatory he said:He who wishes to observe this fast may do so, and he who wishes to abandon it may do so}}
\hadithdefcmd{muslim}{2638}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ فِي أَوَّلِ الْحَدِيثِ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُهُ ‏.‏ وَقَالَ فِي آخِرِ الْحَدِيثِ وَتَرَكَ عَاشُورَاءَ فَمَنْ شَاءَ صَامَهُ وَمَنْ شَاءَ تَرَكَهُ ‏.‏ وَلَمْ يَجْعَلْهُ مِنْ قَوْلِ النَّبِيِّ صلى الله عليه وسلم كَرِوَايَةِ جَرِيرٍ ‏.‏\hadithno{2638}\hadithtrans{This hadith is narrated on the authority of Hisham with the same chain of transmitters, but he made no mention in the first part of the hadith that the Messenger of Allah (ﷺ) used to observe fast, and said about the second part that he abandoned the (fast) of Ashura, and he who wished observed the fast and who wished otherwise abandoned it, and he did not hold it as the words of the Messenger of Allah (ﷺ) as mentioned in the narration transmitted by Jarir}}
\hadithdefcmd{muslim}{2639}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّ يَوْمَ، عَاشُورَاءَ كَانَ يُصَامُ فِي الْجَاهِلِيَّةِ فَلَمَّا جَاءَ الإِسْلاَمُ مَنْ شَاءَ صَامَهُ وَمَنْ شَاءَ تَرَكَهُ ‏.‏\hadithno{2639}\hadithtrans{A'isha (Allah be pleased with her) reported. In the pre-Islamic days fast was observed on the day of Ashura, but with the advent of Islam (its position was ascertained as that of a voluntary fast). Then he who wished to fast fasted, and he who liked to abandon it abandoned it}}
\hadithdefcmd{muslim}{2640}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُ بِصِيَامِهِ قَبْلَ أَنْ يُفْرَضَ رَمَضَانُ فَلَمَّا فُرِضَ رَمَضَانُ كَانَ مَنْ شَاءَ صَامَ يَوْمَ عَاشُورَاءَ وَمَنْ شَاءَ أَفْطَرَ ‏.‏\hadithno{2640}\hadithtrans{A'isha (Allah be pleased with her) reported that the Messenger of Allah (ﷺ) had ordered to observe fast (on 'Ashura) before the fasting in Ramadan was made obligatory. But when it became obligatory, then he who wished fasted on the day of Ashura, and he who wished did not observe it (on that day)}}
\hadithdefcmd{muslim}{2641}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ رُمْحٍ، جَمِيعًا عَنِ اللَّيْثِ بْنِ سَعْدٍ، - قَالَ ابْنُ رُمْحٍ أَخْبَرَنَا اللَّيْثُ، - عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، أَنَّ عِرَاكًا، أَخْبَرَهُ أَنَّ عُرْوَةَ أَخْبَرَهُ أَنَّ عَائِشَةَ أَخْبَرَتْهُ أَنَّ قُرَيْشًا كَانَتْ تَصُومُ عَاشُورَاءَ فِي الْجَاهِلِيَّةِ ثُمَّ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِصِيَامِهِ حَتَّى فُرِضَ رَمَضَانُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ شَاءَ فَلْيَصُمْهُ وَمَنْ شَاءَ فَلْيُفْطِرْهُ ‏"‏ ‏.‏\hadithno{2641}\hadithtrans{A'isha (Allah be pleased with her) reported that the Quraish used to fast on the day of Ashura during the pre-Islamic days. The Messenger of Allah (ﷺ) then commanded to fast on that day till (fasting) in Ramadan became obligatory. Then the Messenger of Allah (ﷺ) said:He who wishes to fast should do so, and he who wishes to break it may do so}}
\hadithdefcmd{muslim}{2642}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عُمَرَ، رضى الله عنهما أَنَّ أَهْلَ، الْجَاهِلِيَّةِ كَانُوا يَصُومُونَ يَوْمَ عَاشُورَاءَ وَأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَامَهُ وَالْمُسْلِمُونَ قَبْلَ أَنْ يُفْتَرَضَ رَمَضَانُ فَلَمَّا افْتُرِضَ رَمَضَانُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ عَاشُورَاءَ يَوْمٌ مِنْ أَيَّامِ اللَّهِ فَمَنْ شَاءَ صَامَهُ وَمَنْ شَاءَ تَرَكَهُ ‏"‏ ‏.‏\hadithno{2642}\hadithtrans{Abdullah b. 'Umar (Allah be pleased with them) reported that (the Arabs of) pre-Islamic days used to observe fast on the day of Ashura and the Messenger of Allah (ﷺ) observed it and the Muslims too (observed it) before fasting in Ramadan became obligatory. But when it became obligatory, the Messenger of Allah (ﷺ) said:'Ashura is one of the days of Allah, so he who wished should observe fast and he who wished otherwise should abandon it}}
\hadithdefcmd{muslim}{2643}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا يَحْيَى، وَهُوَ الْقَطَّانُ ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، كِلاَهُمَا عَنْ عُبَيْدِ اللَّهِ، ‏.‏ بِمِثْلِهِ فِي هَذَا الإِسْنَادِ ‏.‏\hadithno{2643}\hadithtrans{A hadith like this has been narrated on the authority of Abdullah through the same chain of transmitters}}
\hadithdefcmd{muslim}{2644}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما أَنَّهُ ذُكِرَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمُ عَاشُورَاءَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَانَ يَوْمًا يَصُومُهُ أَهْلُ الْجَاهِلِيَّةِ فَمَنْ أَحَبَّ مِنْكُمْ أَنْ يَصُومَهُ فَلْيَصُمْهُ وَمَنْ كَرِهَ فَلْيَدَعْهُ ‏"‏ ‏.‏\hadithno{2644}\hadithtrans{Ibn 'Umar (Allah be pleased with them) said that the day of 'Ashura was mentioned before the Messenger of Allah (may peace he upon him). Thereupon the Messenger of Allah, (ﷺ) said:That was a day on which the people of pre-Islamic days used to observe fast. So he who amongst you likes to observe fast should do so, and he who does not like it should abandon it}}
\hadithdefcmd{muslim}{2645}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ، - يَعْنِي ابْنَ كَثِيرٍ - حَدَّثَنِي نَافِعٌ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، - رضى الله عنهما - حَدَّثَهُ أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي يَوْمِ عَاشُورَاءَ ‏ "‏ إِنَّ هَذَا يَوْمٌ كَانَ يَصُومُهُ أَهْلُ الْجَاهِلِيَّةِ فَمَنْ أَحَبَّ أَنْ يَصُومَهُ فَلْيَصُمْهُ وَمَنْ أَحَبَّ أَنْ يَتْرُكَهُ فَلْيَتْرُكْهُ ‏"‏ ‏.‏ وَكَانَ عَبْدُ اللَّهِ - رضى الله عنه - لاَ يَصُومُهُ إِلاَّ أَنْ يُوَافِقَ صِيَامَهُ ‏.‏\hadithno{2645}\hadithtrans{Abdullah b. 'Umar (Allah be pleased with both of them) reported that he heard the Messenger of Allah (ﷺ) say about the day of Ashura:It is a day on which the people of pre-Islamic days observed fast. So he who liked to fast on this day should do so, and he who liked to abandon it should abandon it. 'Abdullah (Allah be pleased with him) did not observe fast except when it coincided (with the days when he was in the habit of observing voluntary fasts during every month)}}
\hadithdefcmd{muslim}{2646}{وَحَدَّثَنِي مُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا أَبُو مَالِكٍ، عُبَيْدُ اللَّهِ بْنُ الأَخْنَسِ أَخْبَرَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، - رضى الله عنهما - قَالَ ذُكِرَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم صَوْمُ يَوْمِ عَاشُورَاءَ ‏.‏ فَذَكَرَ مِثْلَ حَدِيثِ اللَّيْثِ بْنِ سَعْدٍ سَوَاءً ‏.‏\hadithno{2646}\hadithtrans{Abdullah b. Umar (Allah be pleased with them) reported that the day of 'Ashura was mentioned before the Messenger of Allah (ﷺ) and he narrated a hadith like one (narrated above)}}
\hadithdefcmd{muslim}{2647}{وَحَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ النَّوْفَلِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا عُمَرُ بْنُ مُحَمَّدِ بْنِ، زَيْدٍ الْعَسْقَلاَنِيُّ حَدَّثَنَا سَالِمُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عُمَرَ، - رضى الله عنهما - قَالَ ذُكِرَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمُ عَاشُورَاءَ فَقَالَ ‏ "‏ ذَاكَ يَوْمٌ كَانَ يَصُومُهُ أَهْلُ الْجَاهِلِيَّةِ فَمَنْ شَاءَ صَامَهُ وَمَنْ شَاءَ تَرَكَهُ ‏"‏ ‏.‏\hadithno{2647}\hadithtrans{Abdullah b. Umar (Allah be pleased with them) reported that the day of 'Ashura was mentioned before the Messenger of Allah (ﷺ) and he said:It is a day when the people in the pre-Islamic days need to observe fast, so he who wishes to observe fast should do so, and he who wishes to abandon it should do so}}
\hadithdefcmd{muslim}{2648}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ جَمِيعًا عَنْ أَبِي مُعَاوِيَةَ، قَالَ أَبُو بَكْرٍ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ دَخَلَ الأَشْعَثُ بْنُ قَيْسٍ عَلَى عَبْدِ اللَّهِ وَهُوَ يَتَغَدَّى فَقَالَ يَا أَبَا مُحَمَّدٍ ادْنُ إِلَى الْغَدَاءِ ‏.‏ فَقَالَ أَوَلَيْسَ الْيَوْمُ يَوْمَ عَاشُورَاءَ قَالَ وَهَلْ تَدْرِي مَا يَوْمُ عَاشُورَاءَ قَالَ وَمَا هُوَ قَالَ إِنَّمَا هُوَ يَوْمٌ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُهُ قَبْلَ أَنْ يَنْزِلَ شَهْرُ رَمَضَانَ فَلَمَّا نَزَلَ شَهْرُ رَمَضَانَ تُرِكَ ‏.‏ وَقَالَ أَبُو كُرَيْبٍ تَرَكَهُ ‏.‏\hadithno{2648}\hadithtrans{Abd al-Rahman b. Yazid said:When al-Ash'ath b. Qais entered the house of 'Abdullah he was having his breakfast. He ('Abdullah b. Umar) said: Abd Muhammad (al-Asha'th), come near to the breakfast. Thereupon he said: Is not today the day of 'Ashura? He ('Abd al-Rahman) said: Do you know what the day of 'Ashura is? He said: What is it? He said: It is a day on which the Messenger of Allah (ﷺ) used to observe fast before the (fasting) in the month of Ramadan (became) obligatory. But when it became obligatory the (fasting of 'Ashura) was abandoned (as compulsory). Abu Kuraib said: He (the Holy Prophet) abandoned it}}
\hadithdefcmd{muslim}{2649}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالاَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ وَقَالاَ فَلَمَّا نَزَلَ رَمَضَانُ تَرَكَهُ ‏.‏\hadithno{2649}\hadithtrans{This hadith has been narrated from Jarir on the authority of A'mash with the same chain of transmitters and he said (these words with a little bit of variation from the previous hadith):When (fasting) in Ramadan was (made) obligatory, he abandoned it (the practice of observing fast on Ashura)}}
\hadithdefcmd{muslim}{2650}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، وَيَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ سُفْيَانَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي زُبَيْدٌ الْيَامِيُّ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ قَيْسِ بْنِ سَكَنٍ، أَنَّ الأَشْعَثَ بْنَ قَيْسٍ، دَخَلَ عَلَى عَبْدِ اللَّهِ يَوْمَ عَاشُورَاءَ وَهُوَ يَأْكُلُ فَقَالَ يَا أَبَا مُحَمَّدٍ ادْنُ فَكُلْ ‏.‏ قَالَ إِنِّي صَائِمٌ ‏.‏ قَالَ كُنَّا نَصُومُهُ ثُمَّ تُرِكَ ‏.‏\hadithno{2650}\hadithtrans{Qais b Sakan reported that al-Ash'ath b. Qais went to 'Abdullah on the day of 'Ashura while he was eating. He said:Abu Muhammad, come near and dine. Upon this he said: I am fasting. Thereupon he said: We used to observe fast and then (this practice) was abandoned}}
\hadithdefcmd{muslim}{2651}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ دَخَلَ الأَشْعَثُ بْنُ قَيْسٍ عَلَى ابْنِ مَسْعُودٍ وَهُوَ يَأْكُلُ يَوْمَ عَاشُورَاءَ فَقَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ إِنَّ الْيَوْمَ يَوْمُ عَاشُورَاءَ ‏.‏ فَقَالَ قَدْ كَانَ يُصَامُ قَبْلَ أَنْ يَنْزِلَ رَمَضَانُ فَلَمَّا نَزَلَ رَمَضَانُ تُرِكَ فَإِنْ كُنْتَ مُفْطِرًا فَاطْعَمْ ‏.‏\hadithno{2651}\hadithtrans{Alqama reported that Ash'ath b. Qais went to Ibn Mas'udd while he was eating on the day of Ashura. Thereupon he said:Abu Abd al-Rahman, it is the day of 'Ashura (and you are eating). Upon this he said: Fast was observed on (this day) before the (fasting) in Ramadan was made obligatory, but when it was made obligatory, (fasting on the day of 'Ashura) was abandoned. So if you are not fasting, then take food}}
\hadithdefcmd{muslim}{2652}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَخْبَرَنَا شَيْبَانُ، عَنْ أَشْعَثَ، بْنِ أَبِي الشَّعْثَاءِ عَنْ جَعْفَرِ بْنِ أَبِي ثَوْرٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، - رضى الله عنه - قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُنَا بِصِيَامِ يَوْمِ عَاشُورَاءَ وَيَحُثُّنَا عَلَيْهِ وَيَتَعَاهَدُنَا عِنْدَهُ فَلَمَّا فُرِضَ رَمَضَانُ لَمْ يَأْمُرْنَا وَلَمْ يَنْهَنَا وَلَمْ يَتَعَاهَدْنَا عِنْدَهُ ‏.‏\hadithno{2652}\hadithtrans{Jabir b Samura reported that the Messenger of Allah (ﷺ) commanded us to observe fast on the day of Ashura and exhorted us to do it and was particular about it But when (fasting) in Ramadan was made obligatory, he hence. forth neither commanded us nor forbade us, nor was he so particular about it}}
\hadithdefcmd{muslim}{2653}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ، خَطِيبًا بِالْمَدِينَةِ - يَعْنِي فِي قَدْمَةٍ قَدِمَهَا - خَطَبَهُمْ يَوْمَ عَاشُورَاءَ فَقَالَ أَيْنَ عُلَمَاؤُكُمْ يَا أَهْلَ الْمَدِينَةِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ لِهَذَا الْيَوْمِ ‏ "‏ هَذَا يَوْمُ عَاشُورَاءَ وَلَمْ يَكْتُبِ اللَّهُ عَلَيْكُمْ صِيَامَهُ وَأَنَا صَائِمٌ فَمَنْ أَحَبَّ مِنْكُمْ أَنْ يَصُومَ فَلْيَصُمْ وَمَنْ أَحَبَّ أَنْ يُفْطِرَ فَلْيُفْطِرْ ‏"‏ ‏.‏\hadithno{2653}\hadithtrans{Abd al-Rahman reported that he heard Mu'awiya b. Abu Sufyan delivering a sermon in Medina. i. e. when he came there (for Hajj). He delivered a sermon on the day of 'Ashura and said:People of Medina, where are your scholars? I heard the Messenger of Allah (ﷺ) say on this very day: It is the day of 'Ashura. Allah has not made fasting on This day obligatory for you but I am fasting. He who likes to observe fast among you should do so, and he who likes not to observe it may not observe it}}
\hadithdefcmd{muslim}{2654}{حَدَّثَنِي أَبُو الطَّاهِرِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي مَالِكُ بْنُ أَنَسٍ، عَنِ ابْنِ، شِهَابٍ فِي هَذَا الإِسْنَادِ بِمِثْلِهِ ‏.‏\hadithno{2654}\hadithtrans{A hadith like this has been narrated on the authority of Ibn Shihab through the same chain of transmitters}}
\hadithdefcmd{muslim}{2655}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ فِي مِثْلِ هَذَا الْيَوْمِ ‏ "‏ إِنِّي صَائِمٌ فَمَنْ شَاءَ أَنْ يَصُومَ فَلْيَصُمْ "‏ ‏.‏ وَلَمْ يَذْكُرْ بَاقِيَ حَدِيثِ مَالِكٍ وَيُونُسَ ‏.‏\hadithno{2655}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters that be heard Allah's Apostle (ﷺ) as saying on a similar day:I am fasting today, so he who wishes to observe fast should do so; but he did not make mention of the rest of the hadith}}
\hadithdefcmd{muslim}{2656}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ، عَبَّاسٍ - رضى الله عنهما - قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ فَوَجَدَ الْيَهُودَ يَصُومُونَ يَوْمَ عَاشُورَاءَ فَسُئِلُوا عَنْ ذَلِكَ فَقَالُوا هَذَا الْيَوْمُ الَّذِي أَظْهَرَ اللَّهُ فِيهِ مُوسَى وَبَنِي إِسْرَائِيلَ عَلَى فِرْعَوْنَ فَنَحْنُ نَصُومُهُ تَعْظِيمًا لَهُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ نَحْنُ أَوْلَى بِمُوسَى مِنْكُمْ ‏"‏ ‏.‏ فَأَمَرَ بِصَوْمِهِ ‏.‏\hadithno{2656}\hadithtrans{Ibn Abbas (Allah be pleased with both of them) reported that when Allah's Messenger (ﷺ) came to Medina, he found the Jews observing the fast on the day of Ashura. They (the Jews) were asked about it and they said:It is the day on which Allah granted victory to Moses and (his people) Bani Isra'il over the Pharaoh and we observe fast out of gratitude to Him. Upon this the Messenger of Allah (ﷺ) said: We have a closer connection with Moses than you have, and he commanded to observe fast on this day}}
\hadithdefcmd{muslim}{2657}{وَحَدَّثَنَاهُ ابْنُ بَشَّارٍ، وَأَبُو بَكْرِ بْنُ نَافِعٍ جَمِيعًا عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ أَبِي بِشْرٍ، بِهَذَا الإِسْنَادِ وَقَالَ فَسَأَلَهُمْ عَنْ ذَلِكَ، ‏.‏\hadithno{2657}\hadithtrans{This hadith has been narrated by Ibn Bishr with the same chain of transmitters (but with a slight variation) that he (the Holy Prophet) inquired of them (Jews) about it (fasting on the day of 'Ashura)}}
\hadithdefcmd{muslim}{2658}{وَحَدَّثَنِي ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدِمَ الْمَدِينَةَ فَوَجَدَ الْيَهُودَ صِيَامًا يَوْمَ عَاشُورَاءَ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا هَذَا الْيَوْمُ الَّذِي تَصُومُونَهُ ‏"‏ ‏.‏ فَقَالُوا هَذَا يَوْمٌ عَظِيمٌ أَنْجَى اللَّهُ فِيهِ مُوسَى وَقَوْمَهُ وَغَرَّقَ فِرْعَوْنَ وَقَوْمَهُ فَصَامَهُ مُوسَى شُكْرًا فَنَحْنُ نَصُومُهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَنَحْنُ أَحَقُّ وَأَوْلَى بِمُوسَى مِنْكُمْ ‏"‏ ‏.‏ فَصَامَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَمَرَ بِصِيَامِهِ ‏.‏\hadithno{2658}\hadithtrans{Ibn'Abbas (Allah be pleased with both of them) reported that the Messenger of Allah (ﷺ) arrived in Medina and found the Jews observing fast on the day of 'Ashura. The Messenger of Allah (ﷺ) said to them:What is the (significance) of this day that you observe fast on it? They said: It is the day of great (significance) when Allah delivered Moses and his people, and drowned the Pharaoh and his people, and Moses observed fast out of gratitude and we also observe it. Upon this the Messenger of Allah (ﷺ) said: We have more right, and we have a closer connection with Moses than you have; so Allah's Messenger (ﷺ) observed fast (on the day of 'Ashura), and gave orders that it should be observed}}
\hadithdefcmd{muslim}{2659}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ إِلاَّ أَنَّهُ قَالَ عَنِ ابْنِ سَعِيدِ بْنِ جُبَيْرٍ، لَمْ يُسَمِّهِ ‏.‏\hadithno{2659}\hadithtrans{This hadith has been narrated on the authority of Ayyub with the same chain of transmitters}}
\hadithdefcmd{muslim}{2660}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ أَبِي عُمَيْسٍ، عَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ أَبِي مُوسَى، - رضى الله عنه - قَالَ كَانَ يَوْمُ عَاشُورَاءَ يَوْمًا تُعَظِّمُهُ الْيَهُودُ وَتَتَّخِذُهُ عِيدًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صُومُوهُ أَنْتُمْ ‏"‏ ‏.‏\hadithno{2660}\hadithtrans{Abu Musa (Allah be pleased with him) reported:The day of 'Ashura was one which the Jews respected and they treated it as Id. The Messenger of Allah (ﷺ) said: You also observe fast on this day}}
\hadithdefcmd{muslim}{2661}{وَحَدَّثَنَاهُ أَحْمَدُ بْنُ الْمُنْذِرِ، حَدَّثَنَا حَمَّادُ بْنُ أُسَامَةَ، حَدَّثَنَا أَبُو الْعُمَيْسِ، أَخْبَرَنِي قَيْسٌ، فَذَكَرَ بِهَذَا الإِسْنَادِ مِثْلَهُ وَزَادَ قَالَ أَبُو أُسَامَةَ فَحَدَّثَنِي صَدَقَةُ بْنُ أَبِي عِمْرَانَ عَنْ قَيْسِ بْنِ مُسْلِمٍ عَنْ طَارِقِ بْنِ شِهَابٍ عَنْ أَبِي مُوسَى - رضى الله عنه - قَالَ كَانَ أَهْلُ خَيْبَرَ يَصُومُونَ يَوْمَ عَاشُورَاءَ يَتَّخِذُونَهُ عِيدًا وَيُلْبِسُونَ نِسَاءَهُمْ فِيهِ حُلِيَّهُمْ وَشَارَتَهُمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَصُومُوهُ أَنْتُمْ ‏"‏ ‏.‏\hadithno{2661}\hadithtrans{Abu Musa reported that the people of Khaibar (most of them were Jews) observed fast on the day of 'Ashura and they treated it as 'Id and gave their women ornaments and beautiful dresses to wear. The Messenger of Allah (ﷺ) said:You (only) observe fast on this day}}
\hadithdefcmd{muslim}{2662}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، جَمِيعًا عَنْ سُفْيَانَ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا ابْنُ عُيَيْنَةَ، - عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، سَمِعَ ابْنَ عَبَّاسٍ، - رضى الله عنهما - وَسُئِلَ عَنْ صِيَامِ، يَوْمِ عَاشُورَاءَ ‏.‏ فَقَالَ مَا عَلِمْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَامَ يَوْمًا يَطْلُبُ فَضْلَهُ عَلَى الأَيَّامِ إِلاَّ هَذَا الْيَوْمَ وَلاَ شَهْرًا إِلاَّ هَذَا الشَّهْرَ يَعْنِي رَمَضَانَ ‏.‏\hadithno{2662}\hadithtrans{Ibn Abbas was asked about observing of fast on the day of Ashura, whereupon he said:I do not know Allah's Messenger (ﷺ) singling out any day's fast and considering it more excellent than another, except this day (the day of Ashura) and this month, meaning the month of Ramadan}}
\hadithdefcmd{muslim}{2663}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عُبَيْدُ، اللَّهِ بْنُ أَبِي يَزِيدَ فِي هَذَا الإِسْنَادِ بِمِثْلِهِ ‏.‏\hadithno{2663}\hadithtrans{A hadith like this has been narrated on the authority of 'Ubaidullah b. Abi Yazid}}
\hadithdefcmd{muslim}{2664}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، عَنْ حَاجِبِ بْنِ عُمَرَ، عَنِ الْحَكَمِ بْنِ الأَعْرَجِ، قَالَ انْتَهَيْتُ إِلَى ابْنِ عَبَّاسٍ - رضى الله عنهما - وَهُوَ مُتَوَسِّدٌ رِدَاءَهُ فِي زَمْزَمَ فَقُلْتُ لَهُ أَخْبِرْنِي عَنْ صَوْمِ عَاشُورَاءَ ‏.‏ فَقَالَ إِذَا رَأَيْتَ هِلاَلَ الْمُحَرَّمِ فَاعْدُدْ وَأَصْبِحْ يَوْمَ التَّاسِعِ صَائِمًا ‏.‏ قُلْتُ هَكَذَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُهُ قَالَ نَعَمْ ‏.‏\hadithno{2664}\hadithtrans{Hakam b. al-'Araj reported:I went to Ibn 'Abbas (Allah be Pleased with both of them) and he was reclining using his mantle as a pillow near the fountain of Zamzam. I said to him: Tell me about fasting on Ashura. He said: When you see the new moon of Muharram then count the (days) and observe fast on the 9th. I said to him: Is it how the Messenger of Allah (ﷺ) observed the fast? He said: Yes}}
\hadithdefcmd{muslim}{2665}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ مُعَاوِيَةَ بْنِ عَمْرٍو، حَدَّثَنِي الْحَكَمُ بْنُ الأَعْرَجِ، قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ - رضى الله عنهما - وَهُوَ مُتَوَسِّدٌ رِدَاءَهُ عِنْدَ زَمْزَمَ عَنْ صَوْمِ عَاشُورَاءَ ‏.‏ بِمِثْلِ حَدِيثِ حَاجِبِ بْنِ عُمَرَ ‏.‏\hadithno{2665}\hadithtrans{Hakam b. 'Araj reported:I asked Ibn Abbas (Allah be pleased with them) as he was reclining using his cloak as a pillow near Zamzam about fasting on 'Ashura. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2666}{وَحَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنِي إِسْمَاعِيلُ بْنُ أُمَيَّةَ، أَنَّهُ سَمِعَ أَبَا غَطَفَانَ بْنَ طَرِيفٍ الْمُرِّيَّ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ، بْنَ عَبَّاسٍ - رضى الله عنهما - يَقُولُ حِينَ صَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ عَاشُورَاءَ وَأَمَرَ بِصِيَامِهِ قَالُوا يَا رَسُولَ اللَّهِ إِنَّهُ يَوْمٌ تُعَظِّمُهُ الْيَهُودُ وَالنَّصَارَى ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَإِذَا كَانَ الْعَامُ الْمُقْبِلُ - إِنْ شَاءَ اللَّهُ - صُمْنَا الْيَوْمَ التَّاسِعَ ‏"‏ ‏.‏ قَالَ فَلَمْ يَأْتِ الْعَامُ الْمُقْبِلُ حَتَّى تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم\hadithno{2666}\hadithtrans{Ibn 'Abbas reported that when the Messenger of Allah (ﷺ) fasted on the day of 'Ashura and commanded that it should he observed as a fast, they (his Companions) said to him:Messenger of Allah, it is a day which the Jews and Christians hold in high esteem. Thereupon the Messenger of Allah (ﷺ) said: When the next year comes, God willing, we would observe fast on the 9th But the Messenger of Allah (ﷺ) died before the advent of the next year}}
\hadithdefcmd{muslim}{2667}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الْقَاسِمِ بْنِ عَبَّاسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَيْرٍ، - لَعَلَّهُ قَالَ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَئِنْ بَقِيتُ إِلَى قَابِلٍ لأَصُومَنَّ التَّاسِعَ ‏"‏ ‏.‏ وَفِي رِوَايَةِ أَبِي بَكْرٍ قَالَ يَعْنِي يَوْمَ عَاشُورَاءَ ‏.‏\hadithno{2667}\hadithtrans{Abdullah b 'Abbas reported that the Messenger of Allah (ﷺ) had said:If I live till the next (year), I would definitely observe fast on the 9th, and the narration transmitted by Abu Bakr is:" He meant the day of Ashura}}
\hadithdefcmd{muslim}{2668}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ - عَنْ يَزِيدَ بْنِ أَبِي، عُبَيْدٍ عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، - رضى الله عنه - أَنَّهُ قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً مِنْ أَسْلَمَ يَوْمَ عَاشُورَاءَ فَأَمَرَهُ أَنْ يُؤَذِّنَ فِي النَّاسِ ‏ "‏ مَنْ كَانَ لَمْ يَصُمْ فَلْيَصُمْ وَمَنْ كَانَ أَكَلَ فَلْيُتِمَّ صِيَامَهُ إِلَى اللَّيْلِ ‏"‏ ‏.‏\hadithno{2668}\hadithtrans{Salama b. al-Akwa' (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) sent a person of the tribe of Aslam on the day of 'Ashura and commanded him to declare to the people to observe fast in case they had not observed it, and to complete fast till evening if they had taken food}}
\hadithdefcmd{muslim}{2669}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ الْعَبْدِيُّ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ بْنِ لاَحِقٍ، حَدَّثَنَا خَالِدُ، بْنُ ذَكْوَانَ عَنِ الرُّبَيِّعِ بِنْتِ مُعَوِّذِ بْنِ عَفْرَاءَ، قَالَتْ أَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم غَدَاةَ عَاشُورَاءَ إِلَى قُرَى الأَنْصَارِ الَّتِي حَوْلَ الْمَدِينَةِ ‏ "‏ مَنْ كَانَ أَصْبَحَ صَائِمًا فَلْيُتِمَّ صَوْمَهُ وَمَنْ كَانَ أَصْبَحَ مُفْطِرًا فَلْيُتِمَّ بَقِيَّةَ يَوْمِهِ ‏"‏ ‏.‏ فَكُنَّا بَعْدَ ذَلِكَ نَصُومُهُ وَنُصَوِّمُ صِبْيَانَنَا الصِّغَارَ مِنْهُمْ إِنْ شَاءَ اللَّهُ وَنَذْهَبُ إِلَى الْمَسْجِدِ فَنَجْعَلُ لَهُمُ اللُّعْبَةَ مِنَ الْعِهْنِ فَإِذَا بَكَى أَحَدُهُمْ عَلَى الطَّعَامِ أَعْطَيْنَاهَا إِيَّاهُ عِنْدَ الإِفْطَارِ ‏.‏\hadithno{2669}\hadithtrans{Rubayyi' daughter of Mu'awwidh b. 'Afra' said that the Messenger of Allah (ﷺ) sent (a person) on the morning of Ashura to the villages of Ansar around Medina (with this message):He who got up in the morning fasting (without eating anything) he should complete his fast, and he who had had his breakfast in the morning, he should complete the rest of the day (without food). The Companions said; We henceforth observed fast on it (on the day of 'Ashura) and, God willing, made our children observe that. We went to the mosque and made toys out of wool for them and when anyone felt hungry and wept for food we gave them these toys till it was the time to break the fast}}
\hadithdefcmd{muslim}{2670}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، حَدَّثَنَا أَبُو مَعْشَرٍ الْعَطَّارُ، عَنْ خَالِدِ بْنِ ذَكْوَانَ، قَالَ سَأَلْتُ الرُّبَيِّعَ بِنْتَ مُعَوِّذٍ عَنْ صَوْمِ، عَاشُورَاءَ قَالَتْ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم رُسُلَهُ فِي قُرَى الأَنْصَارِ ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ بِشْرٍ غَيْرَ أَنَّهُ قَالَ وَنَصْنَعُ لَهُمُ اللُّعْبَةَ مِنَ الْعِهْنِ فَنَذْهَبُ بِهِ مَعَنَا فَإِذَا سَأَلُونَا الطَّعَامَ أَعْطَيْنَاهُمُ اللُّعْبَةَ تُلْهِيهِمْ حَتَّى يُتِمُّوا صَوْمَهُمْ ‏.‏\hadithno{2670}\hadithtrans{Khalid b. Dhakwan reported:I asked Rubayyi' daugther of Mu'awwidh about fasting on the day of 'Ashura. Thereupon she said: The Messenger of Allah (may peace he upon him) sent his messenger to the villages of the Ansar, and the rest of the hadith is the same (but with this variation that one of the Companions) said:" We used to make toys out of wool and took (them to the mosque) along with us. When they (the children) asked us for food, we gave them these toys to play with, and these made them forgetful till they completed their fast}}
\hadithdefcmd{muslim}{2671}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ ابْنِ شِهَابٍ عَنْ أَبِي عُبَيْدٍ مَوْلَى ابْنِ أَزْهَرَ أَنَّهُ قَالَ: شَهِدْتُ الْعِيدَ مَعَ عُمَرَ بْنِ الْخَطَّابِ رَضِيَ اللَّهُ عَنْهُ فَجَاءَ فَصَلَّى ثُمَّ انْصَرَفَ فَخَطَبَ النَّاسَ فَقَالَ إِنَّ هَذَيْنِ يَوْمَانِ نَهَى رَسُولُ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ عَنْ صِيَامِهِمَا يَوْمُ فِطْرِكُمْ مِنْ صِيَامِكُمْ وَالْآخَرُ يَوْمٌ تَأْكُلُونَ فِيهِ مِنْ نُسُكِكُمْ\hadithno{2671}\hadithtrans{Abu Ubaid, the freed slave of Ibn Azhar, reported:I observed Id along with Umar b. al-Khattab (Allah be pleased with him). He came (out in an open space) and prayed and (after) completing it addressed the people and said: The Messenger of Allah (ﷺ) has forbidden the observing of fast on these two days. One is the day of Fitr (at the end of your fasts), and the second one, the day when you eat (the meat) of your sacrifices}}
\hadithdefcmd{muslim}{2672}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ صِيَامِ يَوْمَيْنِ يَوْمِ الأَضْحَى وَيَوْمِ الْفِطْرِ ‏.‏\hadithno{2672}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) forbade fasting on these two days. 'Id-ul-Adha and 'Id-ul-Fitr}}
\hadithdefcmd{muslim}{2673}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عَبْدِ الْمَلِكِ، - وَهُوَ ابْنُ عُمَيْرٍ - عَنْ قَزَعَةَ، عَنْ أَبِي سَعِيدٍ، - رضى الله عنه - قَالَ سَمِعْتُ مِنْهُ، حَدِيثًا فَأَعْجَبَنِي فَقُلْتُ لَهُ آنْتَ سَمِعْتَ هَذَا، مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَأَقُولُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مَا لَمْ أَسْمَعْ قَالَ سَمِعْتُهُ يَقُولُ ‏ "‏ لاَ يَصْلُحُ الصِّيَامُ فِي يَوْمَيْنِ يَوْمِ الأَضْحَى وَيَوْمِ الْفِطْرِ مِنْ رَمَضَانَ ‏"‏ ‏.‏\hadithno{2673}\hadithtrans{Qaza'a related from Abu Sa'id. He said:I heard from him (Abu Sa'id) a hadith which impressed me, and I said to him: Did you hear it from the Messenger of Allah (ﷺ)? Thereupon he said: (Is it possible) that (I should) say about the Messenger of Allah (ﷺ) that which I have not heard? I heard him saying: It is not proper to fast on two days, Adha and Fitr (at the end) of Ramadan}}
\hadithdefcmd{muslim}{2674}{وَحَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، - رضى الله عنه - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ صِيَامِ يَوْمَيْنِ يَوْمِ الْفِطْرِ وَيَوْمِ النَّحْرِ ‏.‏\hadithno{2674}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) forbade to observe fast on two days the day of Fitr and the day of Sacrifice ('Id-ul-Adha)}}
\hadithdefcmd{muslim}{2675}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ عَوْنٍ، عَنْ زِيَادِ بْنِ جُبَيْرٍ، قَالَ جَاءَ رَجُلٌ إِلَى ابْنِ عُمَرَ - رضى الله عنهما - فَقَالَ إِنِّي نَذَرْتُ أَنْ أَصُومَ يَوْمًا فَوَافَقَ يَوْمَ أَضْحَى أَوْ فِطْرٍ ‏.‏ فَقَالَ ابْنُ عُمَرَ رضى الله عنهما أَمَرَ اللَّهُ تَعَالَى بِوَفَاءِ النَّذْرِ وَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ صَوْمِ هَذَا الْيَوْمِ ‏.‏\hadithno{2675}\hadithtrans{Ziyad b. Jubair reported that a person came to Ibn 'Umar (Allah be pleased with them) and said:I had taken a vow that I would fast on the day (but it accidentally) synchronises with the day of Adha or the day of Fitr. Thereupon Ibn 'Umar (Allah be pleased with him) said: Allah, the Exalted, has commanded fulfilling of the vow, but the Messenger of Allah (ﷺ) has forbidden the observance of fast on this day}}
\hadithdefcmd{muslim}{2676}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سَعْدُ بْنُ سَعِيدٍ، أَخْبَرَتْنِي عَمْرَةُ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ صَوْمَيْنِ يَوْمِ الْفِطْرِ وَيَوْمِ الأَضْحَى ‏.‏\hadithno{2676}\hadithtrans{A'isha (Allah be pleased with her) said that the Prophet (ﷺ) forbade to observe fast on two days-the day of Fitr and the day of Adha}}
\hadithdefcmd{muslim}{2677}{وَحَدَّثَنَا سُرَيْجُ بْنُ يُونُسَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا خَالِدٌ، عَنْ أَبِي الْمَلِيحِ، عَنْ نُبَيْشَةَ، الْهُذَلِيِّ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيَّامُ التَّشْرِيقِ أَيَّامُ أَكْلٍ وَشُرْبٍ ‏"‏ ‏.‏\hadithno{2677}\hadithtrans{Nubaisha al-Hudhali reported Allah's Messenger (ﷺ) as saying:The days of Tashriq are the days of eating and drinking}}
\hadithdefcmd{muslim}{2678}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - عَنْ خَالِدٍ الْحَذَّاءِ، حَدَّثَنِي أَبُو قِلاَبَةَ، عَنْ أَبِي الْمَلِيحِ، عَنْ نُبَيْشَةَ، قَالَ خَالِدٌ فَلَقِيتُ أَبَا الْمَلِيحِ فَسَأَلْتُهُ فَحَدَّثَنِي بِهِ، فَذَكَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ هُشَيْمٍ وَزَادَ فِيهِ ‏ "‏ وَذِكْرٍ لِلَّهِ ‏"‏ ‏.‏\hadithno{2678}\hadithtrans{Nabaisha reported that Khalid said:I met Abu Malih and asked him and he narrated it to me from the Messenger of Allah (ﷺ). a hadith like one (narrated above) with this addition:" And remembrance of Allah}}
\hadithdefcmd{muslim}{2679}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ سَابِقٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنِ ابْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّهُ حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَهُ وَأَوْسَ بْنَ الْحَدَثَانِ أَيَّامَ التَّشْرِيقِ فَنَادَى ‏ "‏ أَنَّهُ لاَ يَدْخُلُ الْجَنَّةَ إِلاَّ مُؤْمِنٌ ‏.‏ وَأَيَّامُ مِنًى أَيَّامُ أَكْلٍ وَشُرْبٍ ‏"‏ ‏.‏\hadithno{2679}\hadithtrans{Ibn Ka'b b. Malik reported on the authority of his father that the Messenger of Allah (ﷺ) sent him and Aus b. Hadathan during the days of Tashriq to make this announcement:None but the believer would be admitted into Paradise, and the days of Mina' are the days meant for eating and drinking}}
\hadithdefcmd{muslim}{2680}{وَحَدَّثَنَاهُ عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا أَبُو عَامِرٍ عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، حَدَّثَنَا إِبْرَاهِيمُ، بْنُ طَهْمَانَ بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ فَنَادَيَا ‏.‏\hadithno{2680}\hadithtrans{This hadith has been narrated on the authority of Ibrahim b. Tahman with the same chain of transmitters but with this variation that he said:Both of them made the announcement}}
\hadithdefcmd{muslim}{2681}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الْحَمِيدِ بْنِ جُبَيْرٍ، عَنْ مُحَمَّدِ، بْنِ عَبَّادِ بْنِ جَعْفَرٍ سَأَلْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ - رضى الله عنهما - وَهُوَ يَطُوفُ بِالْبَيْتِ أَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ صِيَامِ يَوْمِ الْجُمُعَةِ فَقَالَ نَعَمْ وَرَبِّ هَذَا الْبَيْتِ ‏.‏\hadithno{2681}\hadithtrans{Muhammad b. 'Abbas b. Ja'far reported:I asked Jabir b. 'Abdullah (Allah be pleased with both of them) as he was circumambulating the House (Ka'ba) whether the Messenger of Allah (ﷺ) had forbidden the fasting on Friday, whereupon he said: Yes, by the Lord of this House}}
\hadithdefcmd{muslim}{2682}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَبْدُ الْحَمِيدِ، بْنُ جُبَيْرِ بْنِ شَيْبَةَ أَنَّهُ أَخْبَرَهُ مُحَمَّدُ بْنُ عَبَّادِ بْنِ جَعْفَرٍ، أَنَّهُ سَأَلَ جَابِرَ بْنَ عَبْدِ اللَّهِ - رضى الله عنهما - بِمِثْلِهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2682}\hadithtrans{Muhammad b. 'Abbas b. Ja'far reported that he asked Jabir b. Abdullah (Allah be pleased with them), whether he had heard like this from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{2683}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصٌ، وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي، هُرَيْرَةَ - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَصُمْ أَحَدُكُمْ يَوْمَ الْجُمُعَةِ إِلاَّ أَنْ يَصُومَ قَبْلَهُ أَوْ يَصُومَ بَعْدَهُ ‏"‏ ‏.‏\hadithno{2683}\hadithtrans{Abu Huraira (Allah be pleased with him) reported the Messenger of Allah (ﷺ) as saying:None among you should observe fast on Friday, but only that he observes fast before it and after it}}
\hadithdefcmd{muslim}{2684}{وَحَدَّثَنِي أَبُو كُرَيْبٍ، حَدَّثَنَا حُسَيْنٌ، - يَعْنِي الْجُعْفِيَّ - عَنْ زَائِدَةَ، عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَخْتَصُّوا لَيْلَةَ الْجُمُعَةِ بِقِيَامٍ مِنْ بَيْنِ اللَّيَالِي وَلاَ تَخُصُّوا يَوْمَ الْجُمُعَةِ بِصِيَامٍ مِنْ بَيْنِ الأَيَّامِ إِلاَّ أَنْ يَكُونَ فِي صَوْمٍ يَصُومُهُ أَحَدُكُمْ ‏"‏ ‏.‏\hadithno{2684}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:Do not single out the night (preceding) Friday among the nights for prayer and do not single out Friday among days for fasting but only when anyone among you is accustomed to fast (on dates) which coincide with this day (Friday)}}
\hadithdefcmd{muslim}{2685}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا بَكْرٌ، - يَعْنِي ابْنَ مُضَرَ - عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ بُكَيْرٍ، عَنْ يَزِيدَ، مَوْلَى سَلَمَةَ عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، - رضى الله عنه - قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ وَعَلَى الَّذِينَ يُطِيقُونَهُ فِدْيَةٌ طَعَامُ مِسْكِينٍ‏\}‏ كَانَ مَنْ أَرَادَ أَنْ يُفْطِرَ وَيَفْتَدِيَ ‏.‏ حَتَّى نَزَلَتِ الآيَةُ الَّتِي بَعْدَهَا فَنَسَخَتْهَا ‏.‏\hadithno{2685}\hadithtrans{Salama b. Akwa' (Allah be pleased with him) reported that when this verse was revealed:"And as for those who can fast (but do not) expiation is the feeding of a needy person" (ii. 183), (he who liked to observe fast did observe it) and he who felt reluctant to observe it ate and expiated till the verse was revealed which abrogated it}}
\hadithdefcmd{muslim}{2686}{حَدَّثَنِي عَمْرُو بْنُ سَوَّادٍ الْعَامِرِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنَا عَمْرُو بْنُ، الْحَارِثِ عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ يَزِيدَ، مَوْلَى سَلَمَةَ بْنِ الأَكْوَعِ عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، - رضى الله عنه - أَنَّهُ قَالَ كُنَّا فِي رَمَضَانَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم مَنْ شَاءَ صَامَ وَمَنْ شَاءَ أَفْطَرَ فَافْتَدَى بِطَعَامِ مِسْكِينٍ حَتَّى أُنْزِلَتْ هَذِهِ الآيَةُ ‏\{‏ فَمَنْ شَهِدَ مِنْكُمُ الشَّهْرَ فَلْيَصُمْهُ‏\}‏\hadithno{2686}\hadithtrans{Salama b. Akwa' reported:We, during the lifetime of the Messenger of Allah (ﷺ), in one month of Ramadan (observed fast according to our liking). He who wished to fast lasted and he who wished to break broke it and fed a needy person as an expiation 1544 till this verse was revealed:" He who witnesses among you the month (of Ramadan) he should observe fast during it" (ii)}}
\hadithdefcmd{muslim}{2687}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ أَبِي، سَلَمَةَ قَالَ سَمِعْتُ عَائِشَةَ، - رضى الله عنها - تَقُولُ كَانَ يَكُونُ عَلَىَّ الصَّوْمُ مِنْ رَمَضَانَ فَمَا أَسْتَطِيعُ أَنْ أَقْضِيَهُ إِلاَّ فِي شَعْبَانَ الشُّغُلُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَوْ بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2687}\hadithtrans{Abu Salama reported:I heard 'A'isha (Allah be pleased with her) as saying: I had to complete some of the fasts of Ramadan, but I could not do it but during the month of Sha'ban due to my duties to the Messenger of Allah (ﷺ) or with the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{2688}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا بِشْرُ بْنُ عُمَرَ الزَّهْرَانِيُّ، حَدَّثَنِي سُلَيْمَانُ، بْنُ بِلاَلٍ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ وَذَلِكَ لِمَكَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2688}\hadithtrans{This hadith is narrated on the authority of Yahya b. Sa'id with the same chain of transmitters but with this variation that he said that ('A'isha did not observe fast but in Sha'ban) out of regard for the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{2689}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، حَدَّثَنِي يَحْيَى، بْنُ سَعِيدٍ بِهَذَا الإِسْنَادِ وَقَالَ فَظَنَنْتُ أَنَّ ذَلِكَ لِمَكَانِهَا مِنَ النَّبِيِّ صلى الله عليه وسلم ‏.‏ يَحْيَى يَقُولُهُ ‏.‏\hadithno{2689}\hadithtrans{In another version of the previous hadith, the words are:" Yahya said: I think it was due to the regard for the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{2690}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، ح وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ، كِلاَهُمَا عَنْ يَحْيَى، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرَا فِي الْحَدِيثِ الشُّغْلُ بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2690}\hadithtrans{This hadith is reported on the authority of Yahya with the same chain of transmitters but no mention is made of the duty to the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{2691}{وَحَدَّثَنِي مُحَمَّدُ بْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّهَا قَالَتْ إِنْ كَانَتْ إِحْدَانَا لَتُفْطِرُ فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَا تَقْدِرُ عَلَى أَنْ تَقْضِيَهُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى يَأْتِيَ شَعْبَانُ ‏.‏\hadithno{2691}\hadithtrans{A'isha reported:If one amongst us had to break fasts (of Ramadan due to natural reasons, i. e. menses) during the life of the Messenger of Allah (ﷺ) she could not find it possible to complete them so long she had been in the presence of Allah's Messenger (ﷺ) till Sha'ban commenced}}
\hadithdefcmd{muslim}{2692}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا عَمْرُو بْنُ الْحَارِثِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ مَاتَ وَعَلَيْهِ صِيَامٌ صَامَ عَنْهُ وَلِيُّهُ ‏"‏ ‏.‏\hadithno{2692}\hadithtrans{A'isha (Allah be pleased with her) reported Allah's Messenger (ﷺ) as saying:If anyone dies in a state (that he had to complete) some fasts, his heir must fast on his behalf}}
\hadithdefcmd{muslim}{2693}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ مُسْلِمٍ، الْبَطِينِ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - أَنَّ امْرَأَةً، أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ إِنَّ أُمِّي مَاتَتْ وَعَلَيْهَا صَوْمُ شَهْرٍ ‏.‏ فَقَالَ ‏"‏ أَرَأَيْتِ لَوْ كَانَ عَلَيْهَا دَيْنٌ أَكُنْتِ تَقْضِينَهُ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ فَدَيْنُ اللَّهِ أَحَقُّ بِالْقَضَاءِ ‏"‏ ‏.‏\hadithno{2693}\hadithtrans{Ibn 'Abbas (Allah be pleased with both of them) reported:A woman came to the Messenger of Allah (ﷺ) and said: My mother has died, and fasts of a month are due from her. Thereupon he said: Don't you see that if debt was due from her, would you not pay it? She said: Yes (I would pay on her behalf). Thereupon he said: The debt of Allah deserves its payment more than (the payment of anyone else)}}
\hadithdefcmd{muslim}{2694}{وَحَدَّثَنِي أَحْمَدُ بْنُ عُمَرَ الْوَكِيعِيُّ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ سُلَيْمَانَ، عَنْ مُسْلِمٍ الْبَطِينِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمِّي مَاتَتْ وَعَلَيْهَا صَوْمُ شَهْرٍ أَفَأَقْضِيهِ عَنْهَا فَقَالَ ‏"‏ لَوْ كَانَ عَلَى أُمِّكَ دَيْنٌ أَكُنْتَ قَاضِيَهُ عَنْهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَدَيْنُ اللَّهِ أَحَقُّ أَنْ يُقْضَى ‏"‏ ‏.‏ قَالَ سُلَيْمَانُ فَقَالَ الْحَكَمُ وَسَلَمَةُ بْنُ كُهَيْلٍ جَمِيعًا وَنَحْنُ جُلُوسٌ حِينَ حَدَّثَ مُسْلِمٌ بِهَذَا الْحَدِيثِ فَقَالاَ سَمِعْنَا مُجَاهِدًا يَذْكُرُ هَذَا عَنِ ابْنِ عَبَّاسٍ‏.‏\hadithno{2694}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported:A man came to the Messenger of Allah (ﷺ) and said: Messenger of Allah, my mother has died (in a state) that she had to observe fasts of a month (of Ramadan). Should I complete (them) on her behalf? thereupon he (the Holy Prophet) said: Would you not pay the debt if your mother had died (without paying it)? He said: Yes. He (the Holy Prophet) said: The debt of Allah deserves more that it should he paid}}
\hadithdefcmd{muslim}{2695}{وَحَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، حَدَّثَنَا الأَعْمَشُ، عَنْ سَلَمَةَ، بْنِ كُهَيْلٍ وَالْحَكَمِ بْنِ عُتَيْبَةَ وَمُسْلِمٍ الْبَطِينِ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، وَمُجَاهِدٍ، وَعَطَاءٍ، عَنِ ابْنِ، عَبَّاسٍ - رضى الله عنهما - عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏.‏\hadithno{2695}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Abbas (Allah be pleased with them) from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{2696}{وَحَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، وَابْنُ أَبِي خَلَفٍ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ زَكَرِيَّاءَ، بْنِ عَدِيٍّ - قَالَ عَبْدٌ حَدَّثَنِي زَكَرِيَّاءُ بْنُ عَدِيٍّ، - أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنْ زَيْدِ، بْنِ أَبِي أُنَيْسَةَ حَدَّثَنَا الْحَكَمُ بْنُ عُتَيْبَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أُمِّي مَاتَتْ وَعَلَيْهَا صَوْمُ نَذْرٍ أَفَأَصُومُ عَنْهَا قَالَ ‏"‏ أَرَأَيْتِ لَوْ كَانَ عَلَى أُمِّكِ دَيْنٌ فَقَضَيْتِيهِ أَكَانَ يُؤَدِّي ذَلِكِ عَنْهَا ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ فَصُومِي عَنْ أُمِّكِ ‏"‏ ‏.‏\hadithno{2696}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported:A woman came to the Messenger of Allah (ﷺ) and said: Messenger of Allah, my mother has died and there is due from her a fast of vow; should I fast on her behalf? Thereupon he said: You see that if your mother had died in debt, would it not have been paid on her behalf? She said: Yes. He (the Holy Prophet) said: Then observe fast on behalf of your mother}}
\hadithdefcmd{muslim}{2697}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ أَبُو الْحَسَنِ، عَنْ عَبْدِ اللَّهِ، بْنِ عَطَاءٍ عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، - رضى الله عنه - قَالَ بَيْنَا أَنَا جَالِسٌ، عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ أَتَتْهُ امْرَأَةٌ فَقَالَتْ إِنِّي تَصَدَّقْتُ عَلَى أُمِّي بِجَارِيَةٍ وَإِنَّهَا مَاتَتْ - قَالَ - فَقَالَ ‏"‏ وَجَبَ أَجْرُكِ وَرَدَّهَا عَلَيْكِ الْمِيرَاثُ ‏"‏ ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّهُ كَانَ عَلَيْهَا صَوْمُ شَهْرٍ أَفَأَصُومُ عَنْهَا قَالَ ‏"‏ صُومِي عَنْهَا ‏"‏ ‏.‏ قَالَتْ إِنَّهَا لَمْ تَحُجَّ قَطُّ أَفَأَحُجُّ عَنْهَا قَالَ ‏"‏ حُجِّي عَنْهَا ‏"‏ ‏.‏\hadithno{2697}\hadithtrans{Abdullah b. Buraida (Allah be pleased with him) reported on the authority of his father:When we were sitting with the Messenger of Allah (ﷺ), a woman came to him and said: I had gifted to my mother a maid-servant, and now she (the mother) has died. Thereupon he (the Holy Prophet) said: There is a definite reward for you and she (the maid-servant) has been returned to you as an inheritance. She (that woman) again said: Fasts of a month (of Ramadan) are due upon her; should I observe them on her behalf? He (the Holy Prophet) said: Observe fasts on her behalf. She (again) said: She did not perform Hajj, should I perform it on her behalf? He (the Holy Prophet) said: Perform Hajj on her behalf}}
\hadithdefcmd{muslim}{2698}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَطَاءٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، - رضى الله عنه - قَالَ كُنْتُ جَالِسًا عِنْدَ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ ابْنِ مُسْهِرٍ غَيْرَ أَنَّهُ قَالَ صَوْمُ شَهْرَيْنِ ‏.‏\hadithno{2698}\hadithtrans{Abdullah b. Buraida (Allah be pleased with him) reported on the authority of his father:I was sitting with the Messenger of Allah (ﷺ) ; the rest of the hadith is the same but with this variation that the (the narrator) said:" Fasts of two months}}
\hadithdefcmd{muslim}{2699}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا الثَّوْرِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عَطَاءٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، - رضى الله عنه - قَالَ جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏ فَذَكَرَ بِمِثْلِهِ وَقَالَ صَوْمُ شَهْرٍ ‏.‏\hadithno{2699}\hadithtrans{Ibn Buraida (Allah be pleased with him) reported on the authority of his father:A woman came to the Messenger of Allah (ﷺ), and the rest of the hadith is the same, but he said:" Fasting of one month}}
\hadithdefcmd{muslim}{2700}{وَحَدَّثَنِيهِ إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ سُفْيَانَ، بِهَذَا الإِسْنَادِ وَقَالَ صَوْمُ شَهْرَيْنِ ‏.‏\hadithno{2700}\hadithtrans{This hadith has been narrated on the authority of Sufyan with the same chain of transmitters in which it is said:" Fasting of two months}}
\hadithdefcmd{muslim}{2701}{وَحَدَّثَنِي ابْنُ أَبِي خَلَفٍ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، عَنْ عَبْدِ اللَّهِ بْنِ عَطَاءٍ الْمَكِّيِّ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، - رضى الله عنه - قَالَ أَتَتِ امْرَأَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِهِمْ وَقَالَ صَوْمُ شَهْرٍ ‏.‏\hadithno{2701}\hadithtrans{Buraida (Allah be pleased with him) reported a similar hadith on the authority of his father that a woman came to the Messenger of Allah (ﷺ) and he said:" Fasting for one month}}
\hadithdefcmd{muslim}{2702}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالُوا حَدَّثَنَا سُفْيَانُ، بْنُ عُيَيْنَةَ عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - قَالَ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ رِوَايَةً وَقَالَ عَمْرٌو يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم وَقَالَ زُهَيْرٌ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دُعِيَ أَحَدُكُمْ إِلَى طَعَامٍ وَهُوَ صَائِمٌ فَلْيَقُلْ إِنِّي صَائِمٌ ‏"‏‏.‏\hadithno{2702}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:If any one of you is invited to a meal when he is fasting, he should say:" I am fasting}}
\hadithdefcmd{muslim}{2703}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - رِوَايَةً قَالَ ‏ "‏ إِذَا أَصْبَحَ أَحَدُكُمْ يَوْمًا صَائِمًا فَلاَ يَرْفُثْ وَلاَ يَجْهَلْ فَإِنِ امْرُؤٌ شَاتَمَهُ أَوْ قَاتَلَهُ فَلْيَقُلْ إِنِّي صَائِمٌ إِنِّي صَائِمٌ ‏"‏ ‏.‏\hadithno{2703}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:When any one of you gets up in the morning in the state of fasting, he should neither use obscene language nor do any act of ignorance. And if anyone slanders him or quarrels with him, he should say:" I am fasting, I am fasting}}
\hadithdefcmd{muslim}{2704}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ، شِهَابٍ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، - رضى الله عنه - قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ كُلُّ عَمَلِ ابْنِ آدَمَ لَهُ إِلاَّ الصِّيَامَ هُوَ لِي وَأَنَا أَجْزِي بِهِ فَوَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَخِلْفَةُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏ ‏.‏\hadithno{2704}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Allah, the Majestic and the Exalted, said: Every act of the son of Adam is for him except fasting. It is done for My sake, and I will give a reward for it. By Allah in Whose Hand is the life of Muhammad, the breath of the observer of fast is sweeter to Allah than the fragrance of musk}}
\hadithdefcmd{muslim}{2705}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا الْمُغِيرَةُ، - وَهُوَ الْحِزَامِيُّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الصِّيَامُ جُنَّةٌ ‏"‏ ‏.‏\hadithno{2705}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Fasting is a shield}}
\hadithdefcmd{muslim}{2706}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، عَنْ أَبِي صَالِحٍ الزَّيَّاتِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، - رضى الله عنه - يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ كُلُّ عَمَلِ ابْنِ آدَمَ لَهُ إِلاَّ الصِّيَامَ فَإِنَّهُ لِي وَأَنَا أَجْزِي بِهِ وَالصِّيَامُ جُنَّةٌ فَإِذَا كَانَ يَوْمُ صَوْمِ أَحَدِكُمْ فَلاَ يَرْفُثْ يَوْمَئِذٍ وَلاَ يَسْخَبْ فَإِنْ سَابَّهُ أَحَدٌ أَوْ قَاتَلَهُ فَلْيَقُلْ إِنِّي امْرُؤٌ صَائِمٌ ‏.‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَخُلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ مِنْ رِيحِ الْمِسْكِ وَلِلصَّائِمِ فَرْحَتَانِ يَفْرَحُهُمَا إِذَا أَفْطَرَ فَرِحَ بِفِطْرِهِ وَإِذَا لَقِيَ رَبَّهُ فَرِحَ بِصَوْمِهِ ‏"‏ ‏.‏\hadithno{2706}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Allah the Exalted and Majestic said: Every act of the son of Adam is for him, except fasting. It is (exclusively) meant for Me and I (alone) will reward it. Fasting is a shield. When any one of you is fasting on a day, he should neither indulge in obscene language, nor raise the voice; or if anyone reviles him or tries to quarrel with him he should say: I am a person fasting. By Him, in Whose Hand is the life of Muhammad, the breath of the observer of fast is sweeter to Allah on the Day of judgment than the fragrance of musk. The one who fasts has two (occasions) of joy, one when he breaks the fast he is glad with the breaking of (the fast) and one when he meets his Lord he is glad with his fast}}
\hadithdefcmd{muslim}{2707}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ عَمَلِ ابْنِ آدَمَ يُضَاعَفُ الْحَسَنَةُ عَشْرُ أَمْثَالِهَا إِلَى سَبْعِمِائَةِ ضِعْفٍ قَالَ اللَّهُ عَزَّ وَجَلَّ إِلاَّ الصَّوْمَ فَإِنَّهُ لِي وَأَنَا أَجْزِي بِهِ يَدَعُ شَهْوَتَهُ وَطَعَامَهُ مِنْ أَجْلِي لِلصَّائِمِ فَرْحَتَانِ فَرْحَةٌ عِنْدَ فِطْرِهِ وَفَرْحَةٌ عِنْدَ لِقَاءِ رَبِّهِ ‏.‏ وَلَخُلُوفُ فِيهِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏ ‏.‏\hadithno{2707}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Every (good) deed of the son of Adam would be multiplied, a good deed receiving a tenfold to seven hundredfold reward. Allah, the Exalted and Majestic, has said: With the exception of fasting, for it is done for Me and I will give a reward for it, for one abandons his passion and food for My sake. There are two occasions of joy for one who fasts, joy when he breaks it, and joy when he meets his Lord, and the breath (of an observer of fast) is sweeter to Allah than the fragrance of musk}}
\hadithdefcmd{muslim}{2708}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِي سِنَانٍ، عَنْ أَبِي، صَالِحٍ عَنْ أَبِي هُرَيْرَةَ، وَأَبِي، سَعِيدٍ - رضى الله عنهما - قَالاَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَقُولُ إِنَّ الصَّوْمَ لِي وَأَنَا أَجْزِي بِهِ إِنَّ لِلصَّائِمِ فَرْحَتَيْنِ إِذَا أَفْطَرَ فَرِحَ وَإِذَا لَقِيَ اللَّهَ فَرِحَ ‏.‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَخُلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏ ‏.‏\hadithno{2708}\hadithtrans{Abu Huraira and Abu Sa'id (Allah be pleased with both of them) reported Allah's Messenger (ﷺ) (as saying):Allah, the Exalted and Majestic, said: Fast (is exclusively) meant for Me and I would give its reward. There are two (occasions) of joy for the observer of fast. He feels joy when he breaks the fast and he is happy when he meets Allah. By Allah in Whose Hand is the life of Muhammad, the breath of the observer of fast is sweeter to Allah than the fragrance of musk}}
\hadithdefcmd{muslim}{2709}{وَحَدَّثَنِيهِ إِسْحَاقُ بْنُ عُمَرَ بْنِ سَلِيطٍ الْهُذَلِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُسْلِمٍ - حَدَّثَنَا ضِرَارُ بْنُ مُرَّةَ، - وَهُوَ أَبُو سِنَانٍ - بِهَذَا الإِسْنَادِ قَالَ وَقَالَ ‏ "‏ إِذَا لَقِيَ اللَّهَ فَجَزَاهُ فَرِحَ ‏"‏ ‏.‏\hadithno{2709}\hadithtrans{A hadith like this is narrated on the authority of Abu Sinan with the same chain of transmitters (and the words are):" As he meets Allah, He rewards him, and he is happy}}
\hadithdefcmd{muslim}{2710}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، - وَهُوَ الْقَطَوَانِيُّ - عَنْ سُلَيْمَانَ، بْنِ بِلاَلٍ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ فِي الْجَنَّةِ بَابًا يُقَالُ لَهُ الرَّيَّانُ يَدْخُلُ مِنْهُ الصَّائِمُونَ يَوْمَ الْقِيَامَةِ لاَ يَدْخُلُ مَعَهُمْ أَحَدٌ غَيْرُهُمْ يُقَالُ أَيْنَ الصَّائِمُونَ فَيَدْخُلُونَ مِنْهُ فَإِذَا دَخَلَ آخِرُهُمْ أُغْلِقَ فَلَمْ يَدْخُلْ مِنْهُ أَحَدٌ ‏"‏ ‏.‏\hadithno{2710}\hadithtrans{Sahl b. Sa'd (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:In Paradise there is a gate which is called Rayyan through which only the people who fast would enter on the Day on Resurrection. None else would enter along with them. It would be proclaimed: Where are the people who fast that they should be admitted into it? And when the last of them would enter, it would be closed and no one would enter it}}
\hadithdefcmd{muslim}{2711}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَخْبَرَنِي اللَّيْثُ، عَنِ ابْنِ الْهَادِ، عَنْ سُهَيْلِ بْنِ، أَبِي صَالِحٍ عَنِ النُّعْمَانِ بْنِ أَبِي عَيَّاشٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ عَبْدٍ يَصُومُ يَوْمًا فِي سَبِيلِ اللَّهِ إِلاَّ بَاعَدَ اللَّهُ بِذَلِكَ الْيَوْمِ وَجْهَهُ عَنِ النَّارِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏\hadithno{2711}\hadithtrans{Abu Sa'id al Khudri (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:Every servant of Allah who observes fast for a day in the way of Allah, Allah would remove, because of this day, his face farther from the Fire (of Hell) to the extent of seventy years' distance}}
\hadithdefcmd{muslim}{2712}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنْ سُهَيْلٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{2712}\hadithtrans{This hadith has been narrated by Suhail with the same chain of transmitters}}
\hadithdefcmd{muslim}{2713}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، وَعَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ الْعَبْدِيُّ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، وَسُهَيْلِ بْنِ أَبِي صَالِحٍ، أَنَّهُمَا سَمِعَا النُّعْمَانَ بْنَ، أَبِي عَيَّاشٍ الزُّرَقِيَّ يُحَدِّثُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، - رضى الله عنه - قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ صَامَ يَوْمًا فِي سَبِيلِ اللَّهِ بَاعَدَ اللَّهُ وَجْهَهُ عَنِ النَّارِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏\hadithno{2713}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:He who observes fast for a day in the way of Allah He would remove his face from the Hell to the extent of seventy years' distance}}
\hadithdefcmd{muslim}{2714}{وَحَدَّثَنَا أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا طَلْحَةُ، بْنُ يَحْيَى بْنِ عُبَيْدِ اللَّهِ حَدَّثَتْنِي عَائِشَةُ بِنْتُ طَلْحَةَ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، - رضى الله عنها - قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ ‏"‏ يَا عَائِشَةُ هَلْ عِنْدَكُمْ شَىْءٌ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ مَا عِنْدَنَا شَىْءٌ ‏.‏ قَالَ ‏"‏ فَإِنِّي صَائِمٌ ‏"‏ ‏.‏ قَالَتْ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأُهْدِيَتْ لَنَا هَدِيَّةٌ - أَوْ جَاءَنَا زَوْرٌ - قَالَتْ - فَلَمَّا رَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم قُلْتُ يَا رَسُولَ اللَّهِ أُهْدِيَتْ لَنَا هَدِيَّةٌ - أَوْ جَاءَنَا زَوْرٌ - وَقَدْ خَبَأْتُ لَكَ شَيْئًا ‏.‏ قَالَ ‏"‏ مَا هُوَ ‏"‏ ‏.‏ قُلْتُ حَيْسٌ ‏.‏ قَالَ ‏"‏ هَاتِيهِ ‏"‏ ‏.‏ فَجِئْتُ بِهِ فَأَكَلَ ثُمَّ قَالَ ‏"‏ قَدْ كُنْتُ أَصْبَحْتُ صَائِمًا ‏"‏ ‏.‏ قَالَ طَلْحَةُ فَحَدَّثْتُ مُجَاهِدًا بِهَذَا الْحَدِيثِ فَقَالَ ذَاكَ بِمَنْزِلَةِ الرَّجُلِ يُخْرِجُ الصَّدَقَةَ مِنْ مَالِهِ فَإِنْ شَاءَ أَمْضَاهَا وَإِنْ شَاءَ أَمْسَكَهَا‏.‏\hadithno{2714}\hadithtrans{A'isha, the Mother of the Believers (Allah be pleased with her), reported that one day the Messenger of Allah may peace be upon him) said to me:'A'isha, have you anything (to eat)? I said: 'Messenger of Allah, there is nothing with us. Thereupon he said: I am observing fast. She said: The Messenger of Allah (ﷺ) went out, and there was a present, for us and (at the same time) some visitors dropped in. When the Messenger of Allah (ﷺ) came back, I said to him: Messenger of Allah, a present was given to us, (and in the meanwhile) there came to us visitors (a major Portion of it has been spent on them), but I have saved something for you. He said: What is it? I said: It is hais (a compound of dates and clarified butter). He said: Bring that. So I brought it to him and he ate it and then said: I woke up in the morning observing fast. Talha said: I narrated this hadith to Mujahid and he said: This (observing of voluntary fast) is like a person who sets apart Sadaqa out of his wealth. He may spend it if he likes, or he may retain it if he so likes}}
\hadithdefcmd{muslim}{2715}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ عَمَّتِهِ، عَائِشَةَ بِنْتِ طَلْحَةَ عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ دَخَلَ عَلَىَّ النَّبِيُّ صلى الله عليه وسلم ذَاتَ يَوْمٍ فَقَالَ ‏"‏ هَلْ عِنْدَكُمْ شَىْءٌ ‏"‏ ‏.‏ فَقُلْنَا لاَ ‏.‏ قَالَ ‏"‏ فَإِنِّي إِذًا صَائِمٌ ‏"‏ ‏.‏ ثُمَّ أَتَانَا يَوْمًا آخَرَ فَقُلْنَا يَا رَسُولَ اللَّهِ أُهْدِيَ لَنَا حَيْسٌ ‏.‏ فَقَالَ ‏"‏ أَرِينِيهِ فَلَقَدْ أَصْبَحْتُ صَائِمًا ‏"‏ ‏.‏ فَأَكَلَ ‏.‏\hadithno{2715}\hadithtrans{A'isha, the Mother of the Believers (Allah be pleased with her), reported:The Apostle of Allah (ﷺ) came to me one day and said: Is there anything with you (to eat)? I said: No. Thereupon he said: I shall then be fasting. Then he came to us another day and we said: Messenger of Allah, hais has been offered to us as a gift. Thereupon he said: Show that to me; I had been fasting since morning. He then ate it}}
\hadithdefcmd{muslim}{2716}{وَحَدَّثَنِي عَمْرُو بْنُ مُحَمَّدٍ النَّاقِدُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ هِشَامٍ الْقُرْدُوسِيِّ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ نَسِيَ وَهُوَ صَائِمٌ فَأَكَلَ أَوْ شَرِبَ فَلْيُتِمَّ صَوْمَهُ فَإِنَّمَا أَطْعَمَهُ اللَّهُ وَسَقَاهُ ‏"‏ ‏.‏\hadithno{2716}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:If anyone forgets that he is fasting and eats or drinks he should complete his fast, for it is only Allah Who has fed him and given him drink}}
\hadithdefcmd{muslim}{2717}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، عَنْ عَبْدِ اللَّهِ، بْنِ شَقِيقٍ قَالَ قُلْتُ لِعَائِشَةَ رضى الله عنها هَلْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَصُومُ شَهْرًا مَعْلُومًا سِوَى رَمَضَانَ قَالَتْ وَاللَّهِ إِنْ صَامَ شَهْرًا مَعْلُومًا سِوَى رَمَضَانَ حَتَّى مَضَى لِوَجْهِهِ وَلاَ أَفْطَرَهُ حَتَّى يُصِيبَ مِنْهُ ‏.‏\hadithno{2717}\hadithtrans{Abdullah b. Shaqiq reported:I said to'A'isha (Allah be pleased with her): Did the Messenger of Allah (ﷺ) fast for a full month besides Ramadan? She said: I do not know of any month in which he fasted throughout, but that of the month of Ramadan and (the month) in which he did not fast at all, till he ran the course of his life}}
\hadithdefcmd{muslim}{2718}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا كَهْمَسٌ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ قُلْتُ لِعَائِشَةَ - رضى الله عنها - أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ شَهْرًا كُلَّهُ قَالَتْ مَا عَلِمْتُهُ صَامَ شَهْرًا كُلَّهُ إِلاَّ رَمَضَانَ وَلاَ أَفْطَرَهُ كُلَّهُ حَتَّى يَصُومَ مِنْهُ حَتَّى مَضَى لِسَبِيلِهِ صلى الله عليه وسلم ‏.‏\hadithno{2718}\hadithtrans{Abdullah b. Shaqiq reported:I said to 'A'isha (Allah be pleased with her): Did the Messenger of Allah (ﷺ) observe fast during a month? She said, I do not know of any month in which he fasted throughout except Ramadan and (the month) in which he did not fast at all till he ran the course of his life. May peace be upon him}}
\hadithdefcmd{muslim}{2719}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، وَهِشَامٍ، عَنْ مُحَمَّدٍ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، - قَالَ حَمَّادٌ وَأَظُنُّ أَيُّوبَ قَدْ سَمِعَهُ مِنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، - قَالَ سَأَلْتُ عَائِشَةَ - رضى الله عنها - عَنْ صَوْمِ النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ كَانَ يَصُومُ حَتَّى نَقُولَ قَدْ صَامَ قَدْ صَامَ ‏.‏ وَيُفْطِرُ حَتَّى نَقُولَ قَدْ أَفْطَرَ قَدْ أَفْطَرَ - قَالَتْ - وَمَا رَأَيْتُهُ صَامَ شَهْرًا كَامِلاً مُنْذُ قَدِمَ الْمَدِينَةَ إِلاَّ أَنْ يَكُونَ رَمَضَانَ ‏.‏\hadithno{2719}\hadithtrans{Abdullah b. Shaqiq reported. I asked 'A'isha (Allah be pleased with her) about fasting of the Messenger of Allah (ﷺ). She said:He used to observe fast (at times) so continuously that we said: He has fasted, he has fasted. And (at times) he did not observe fast (for days) and we began to say: He has abandoned fasting, he has abandoned fasting. She said: I did not see him observing fast throughout the whole of the month since he arrived in Medina, but that of Ramadan}}
\hadithdefcmd{muslim}{2720}{وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ سَأَلْتُ عَائِشَةَ - رضى الله عنها - بِمِثْلِهِ وَلَمْ يَذْكُرْ فِي الإِسْنَادِ هِشَامًا وَلاَ مُحَمَّدًا ‏.‏\hadithno{2720}\hadithtrans{A hadith like this has been narrated on the authority of Abdullah b. Shaqiq but in the chain of transmitters no mention is made of Hisham and Muhammad}}
\hadithdefcmd{muslim}{2721}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، - رضى الله عنها - أَنَّهَا قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ حَتَّى نَقُولَ لاَ يُفْطِرُ ‏.‏ وَيُفْطِرُ حَتَّى نَقُولَ لاَ يَصُومُ ‏.‏ وَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَكْمَلَ صِيَامَ شَهْرٍ قَطُّ إِلاَّ رَمَضَانَ وَمَا رَأَيْتُهُ فِي شَهْرٍ أَكْثَرَ مِنْهُ صِيَامًا فِي شَعْبَانَ ‏.‏\hadithno{2721}\hadithtrans{A'isha, the Mother of the Believers (Allah be pleased with her), reported that the Messenger of Allah (ﷺ) used to fast (so continuously) that we said that he would not break, and did not fast at all till we said that he would not fast. And I did not see the Messenger of Allah (ﷺ) completing the fast of a month, but that of Ramadan, and I did not see him fasting more in any other month than that of Sha'ban}}
\hadithdefcmd{muslim}{2722}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنِ ابْنِ أَبِي لَبِيدٍ، عَنْ أَبِي سَلَمَةَ، قَالَ سَأَلْتُ عَائِشَةَ - رضى الله عنها - عَنْ صِيَامِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ كَانَ يَصُومُ حَتَّى نَقُولَ قَدْ صَامَ ‏.‏ وَيُفْطِرُ حَتَّى نَقُولَ قَدْ أَفْطَرَ ‏.‏ وَلَمْ أَرَهُ صَائِمًا مِنْ شَهْرٍ قَطُّ أَكْثَرَ مِنْ صِيَامِهِ مِنْ شَعْبَانَ كَانَ يَصُومُ شَعْبَانَ كُلَّهُ كَانَ يَصُومُ شَعْبَانَ إِلاَّ قَلِيلاً ‏.‏\hadithno{2722}\hadithtrans{Abu Salama reported:I asked 'A'isha (Allah be pleased with her) about the fasting of the Messenger of Allah (ﷺ). She said: He used to observe fast (at times so continuously) that we said: He has fasted (never to break), and he did not observe fast till we said: He has given up perhaps never to fast, and I never saw him observing (voluntary fasts) more in any other month than that of Sha'ban. (lt appeared as if) he observed fast throughout the whole of Sha'ban except a few (days)}}
\hadithdefcmd{muslim}{2723}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ، أَبِي كَثِيرٍ حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ لَمْ يَكُنْ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الشَّهْرِ مِنَ السَّنَةِ أَكْثَرَ صِيَامًا مِنْهُ فِي شَعْبَانَ وَكَانَ يَقُولُ ‏"‏ خُذُوا مِنَ الأَعْمَالِ مَا تُطِيقُونَ فَإِنَّ اللَّهَ لَنْ يَمَلَّ حَتَّى تَمَلُّوا ‏"‏ ‏.‏ وَكَانَ يَقُولُ ‏"‏ أَحَبُّ الْعَمَلِ إِلَى اللَّهِ مَا دَاوَمَ عَلَيْهِ صَاحِبُهُ وَإِنْ قَلَّ ‏"‏ ‏.‏\hadithno{2723}\hadithtrans{A'isha (Allah be pleased with her) reported:The Messenger of Allah (ﷺ) did not observe fast in any month of the year more than in the month of Sha'ban, and used to say: Do as many deeds as you are capable of doing, for Allah will not become weary (of giving you reward), but you would be tired (of doing good deeds) ; and he also said: The deed liked most by Allah is one to which the doer adheres constantly even if it is small}}
\hadithdefcmd{muslim}{2724}{حَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ مَا صَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَهْرًا كَامِلاً قَطُّ غَيْرَ رَمَضَانَ ‏.‏ وَكَانَ يَصُومُ إِذَا صَامَ حَتَّى يَقُولَ الْقَائِلُ لاَ وَاللَّهِ لاَ يُفْطِرُ ‏.‏ وَيُفْطِرُ إِذَا أَفْطَرَ حَتَّى يَقُولَ الْقَائِلُ لاَ وَاللَّهِ لاَ يَصُومُ ‏.‏\hadithno{2724}\hadithtrans{Ibn Abbas (Allah be pleased with both of them) reported:The Messenger of Allah (ﷺ) did not fast throughout any month except during ramadan. And when he observed fast (he fasted so continuously) that one would say that he would not break (them) and when he Abandoned, he abandoned (so continuously) that one would say: By Allah, perhaps he would never fast}}
\hadithdefcmd{muslim}{2725}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ وَأَبُو بَكْرِ بْنُ نَافِعٍ عَنْ غُنْدَرٍ عَنْ شُعْبَةَ عَنْ أَبِي بِشْرٍ بِهَذَا الْإِسْنَادِ وَقَالَ شَهْرًا مُتَتَابِعًا مُنْذُ قَدِمَ الْمَدِينَةَ\hadithno{2725}\hadithtrans{This hadith has been narrated on the authority of Abu Bishr with the same chain of transmitters (with a slight variation of words and these are), that he (the narrator) said:" During any month continuously since he came to Medina}}
\hadithdefcmd{muslim}{2726}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ الأَنْصَارِيُّ، قَالَ سَأَلْتُ سَعِيدَ بْنَ جُبَيْرٍ عَنْ صَوْمِ، رَجَبٍ - وَنَحْنُ يَوْمَئِذٍ فِي رَجَبٍ - فَقَالَ سَمِعْتُ ابْنَ عَبَّاسٍ - رضى الله عنهما - يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ حَتَّى نَقُولَ لاَ يُفْطِرُ ‏.‏ وَيُفْطِرُ حَتَّى نَقُولَ لاَ يَصُومُ ‏.‏\hadithno{2726}\hadithtrans{Uthman b. Hakim al-Ansari said:I asked Sa'id b. Jubair about fasting In Rajab, and we were then passing through the month of Rajab, whereupon he said: I heard Ibn 'Abbas (Allah be pleased with both of them) as saying: The Messenger of Allah (ﷺ) used to observe fast (so continuously) that we (were inclined) to say that he would not break (them) and did not observe them so conti- nuously) that we (were inclined to say) that he would not observe fast}}
\hadithdefcmd{muslim}{2727}{وَحَدَّثَنِيهِ عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، ح وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كِلاَهُمَا عَنْ عُثْمَانَ بْنِ حَكِيمٍ، فِي هَذَا الإِسْنَادِ ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{2727}\hadithtrans{The same hadith as the previous hadith has been transmitted through another chain}}
\hadithdefcmd{muslim}{2728}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ أَبِي خَلَفٍ، قَالاَ حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، رضى الله عنه ح. وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَصُومُ حَتَّى يُقَالَ قَدْ صَامَ قَدْ صَامَ ‏.‏ وَيُفْطِرُ حَتَّى يُقَالَ قَدْ أَفْطَرَ قَدْ أَفْطَرَ ‏.‏\hadithno{2728}\hadithtrans{Anas (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) used to observe fast till it was said that he had observed fast, he had observed fast (perhaps never to break it), and he did not fast till it was said that he had given up fast, he had given up fast (perhaps never to observe it)}}
\hadithdefcmd{muslim}{2729}{حَدَّثَنِي أَبُو الطَّاهِرِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ وَهْبٍ، يُحَدِّثُ عَنْ يُونُسَ، عَنِ ابْنِ، شِهَابٍ ح وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ، قَالَ أُخْبِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّهُ يَقُولُ لأَقُومَنَّ اللَّيْلَ وَلأَصُومَنَّ النَّهَارَ مَا عِشْتُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ آنْتَ الَّذِي تَقُولُ ذَلِكَ ‏"‏ ‏.‏ فَقُلْتُ لَهُ قَدْ قُلْتُهُ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِنَّكَ لاَ تَسْتَطِيعُ ذَلِكَ فَصُمْ وَأَفْطِرْ وَنَمْ وَقُمْ وَصُمْ مِنَ الشَّهْرِ ثَلاَثَةَ أَيَّامٍ فَإِنَّ الْحَسَنَةَ بِعَشْرِ أَمْثَالِهَا وَذَلِكَ مِثْلُ صِيَامِ الدَّهْرِ ‏"‏ ‏.‏ قَالَ قُلْتُ فَإِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ يَوْمًا وَأَفْطِرْ يَوْمَيْنِ ‏"‏ ‏.‏ قَالَ قُلْتُ فَإِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ صُمْ يَوْمًا وَأَفْطِرْ يَوْمًا وَذَلِكَ صِيَامُ دَاوُدَ - عَلَيْهِ السَّلاَمُ - وَهُوَ أَعْدَلُ الصِّيَامِ ‏"‏ ‏.‏ قَالَ قُلْتُ فَإِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ أَفْضَلَ مِنْ ذَلِكَ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عَمْرٍو رضى الله عنهما لأَنْ أَكُونَ قَبِلْتُ الثَّلاَثَةَ الأَيَّامَ الَّتِي قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَحَبُّ إِلَىَّ مِنْ أَهْلِي وَمَالِي ‏.‏\hadithno{2729}\hadithtrans{Abdullah b. 'Amr b. al-'As reported that the Messenger of Allah (ﷺ) was informed that he could stand up for (prayer) throughout the night and observe fast every day so long as he lived. Thereupon the Messenger of Allah (ﷺ) said:Is it you who said this? I said to him: Messenger of Allah, it is I who said that. Thereupon the Messenger of Allah may peace be upon him) said: You are not capable enough to do so. Observe fast and break it; sleep and stand for prayer, and observe fast for three days during the month; for every good is multiplied ten times and this is like fasting for ever. I said: Messenger of Allah. I am capable of doing more than this. Thereupon he said: Fast one day and do not fast for the next two days. I said: Messenger of Allah, I have the strength to do more than that. The Prophet (ﷺ), said: Fast one day and break on the other day. That is known as the fasting of David (peace be upon him) and that is the best fasting. I said: I am capable of doing more than this. Thereupon the Messenger of Allah (ﷺ) said: There is nothing better than this. 'Abdullah b. 'Amr (Allah be pleased with them) said: Had I accepted the three days (fasting during every month) as the Messenger of Allah (ﷺ) had said, it would have been more dear to me than my family and my property}}
\hadithdefcmd{muslim}{2730}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ الرُّومِيُّ، حَدَّثَنَا النَّضْرُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عِكْرِمَةُ، - وَهُوَ ابْنُ عَمَّارٍ - حَدَّثَنَا يَحْيَى، قَالَ انْطَلَقْتُ أَنَا وَعَبْدُ اللَّهِ بْنُ يَزِيدَ، حَتَّى نَأْتِيَ أَبَا سَلَمَةَ فَأَرْسَلْنَا إِلَيْهِ رَسُولاً فَخَرَجَ عَلَيْنَا وَإِذَا عِنْدَ بَابِ دَارِهِ مَسْجِدٌ - قَالَ - فَكُنَّا فِي الْمَسْجِدِ حَتَّى خَرَجَ إِلَيْنَا ‏.‏ فَقَالَ إِنْ تَشَاءُوا أَنْ تَدْخُلُوا وَإِنْ تَشَاءُوا أَنْ تَقْعُدُوا هَا هُنَا ‏.‏ - قَالَ - فَقُلْنَا لاَ بَلْ نَقْعُدُ هَا هُنَا فَحَدِّثْنَا ‏.‏ قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ الْعَاصِ - رضى الله عنهما - قَالَ كُنْتُ أَصُومُ الدَّهْرَ وَأَقْرَأُ الْقُرْآنَ كُلَّ لَيْلَةٍ - قَالَ - فَإِمَّا ذُكِرْتُ لِلنَّبِيِّ صلى الله عليه وسلم وَإِمَّا أَرْسَلَ إِلَىَّ فَأَتَيْتُهُ فَقَالَ لِي ‏"‏ أَلَمْ أُخْبَرْ أَنَّكَ تَصُومُ الدَّهْرَ وَتَقْرَأُ الْقُرْآنَ كُلَّ لَيْلَةٍ ‏"‏ ‏.‏ قُلْتُ بَلَى يَا نَبِيَّ اللَّهِ وَلَمْ أُرِدْ بِذَلِكَ إِلاَّ الْخَيْرَ ‏.‏ قَالَ ‏"‏ فَإِنَّ بِحَسْبِكَ أَنْ تَصُومَ مِنْ كُلِّ شَهْرٍ ثَلاَثَةَ أَيَّامٍ ‏"‏ ‏.‏ قُلْتُ يَا نَبِيَّ اللَّهِ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ فَإِنَّ لِزَوْجِكَ عَلَيْكَ حَقًّا وَلِزَوْرِكَ عَلَيْكَ حَقًّا وَلِجَسَدِكَ عَلَيْكَ حَقًّا - قَالَ - فَصُمْ صَوْمَ دَاوُدَ نَبِيِّ اللَّهِ صلى الله عليه وسلم فَإِنَّهُ كَانَ أَعْبَدَ النَّاسِ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا نَبِيَّ اللَّهِ وَمَا صَوْمُ دَاوُدَ قَالَ ‏"‏ كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا ‏"‏ ‏.‏ قَالَ ‏"‏ وَاقْرَإِ الْقُرْآنَ فِي كُلِّ شَهْرٍ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا نَبِيَّ اللَّهِ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ قَالَ ‏"‏ فَاقْرَأْهُ فِي كُلِّ عِشْرِينَ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا نَبِيَّ اللَّهِ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ قَالَ ‏"‏ فَاقْرَأْهُ فِي كُلِّ عَشْرٍ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا نَبِيَّ اللَّهِ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ فَاقْرَأْهُ فِي كُلِّ سَبْعٍ وَلاَ تَزِدْ عَلَى ذَلِكَ ‏.‏ فَإِنَّ لِزَوْجِكَ عَلَيْكَ حَقًّا وَلِزَوْرِكَ عَلَيْكَ حَقًّا وَلِجَسَدِكَ عَلَيْكَ حَقًّا ‏"‏ ‏.‏ قَالَ فَشَدَّدْتُ فَشُدِّدَ عَلَىَّ ‏.‏ قَالَ وَقَالَ لِيَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّكَ لاَ تَدْرِي لَعَلَّكَ يَطُولُ بِكَ عُمْرٌ ‏"‏ ‏.‏ قَالَ فَصِرْتُ إِلَى الَّذِي قَالَ لِيَ النَّبِيُّ صلى الله عليه وسلم فَلَمَّا كَبِرْتُ وَدِدْتُ أَنِّي كُنْتُ قَبِلْتُ رُخْصَةَ نَبِيِّ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2730}\hadithtrans{Yahya reported:I and 'Abdullah b. Yazid set out till we came to Abu Salama. We sent a messenger to him (in his house in order to inform him about our arrival) and he came to us. There was a mosque near the door of his house, and we were in that mosque, till he came out to us. He said: If you like you may enter (the house) and, if you like, you may sit here (in the mosque). We said: We would rather sit here and (you) relate to us. He (Yahya) then narrated that 'Abdullah b Amr b. al-'As (Allah be pleased with them) told him: I used to observe fast uninterruptedly and recited the (whole of the) Qur'an every night. It (the uninterrupted fasting and recital of the Qur'an every night) was mentioned to the Messenger of Allah (ﷺ) or he sent for me, and I went to him and he said to me: I have been informed that you fast continuously and recite (the whole of the Qur'an) every night. I said: Apostle of Allah, it is right, but I covet thereby nothing but good, whereupon he said: It suffices for you that you should observe fast for three days during every month. I said: Apostle of Allah, I am capable of doing more than this. He said: Your wife has a right upon you, your visitor has a right upon you, your body has a right upon you; so observe the fast of David, the Messenger of Allah (peace be upon him), for he was the best worshipper of Allah. I said: Apostle of Allah, what is the fast of David? He said: He used to fast one day and did not fast the other day. He (also) said: Recite the Qur'an during every month. I said: Apostle of Allah, I am capable of doing more than this, whereupon he said: Recite it in twenty days; recite it in ten days. I said: I am capable of doing more than this, whereupon he said: Recite it every week, and do not exceed beyond this, for your wife has a right upon you, your visitor has a right upon you, your body has a right upon you. He ('Amr b. 'As) said: I was hard to myself and thus I was put to hardship. The Apostle of Allah (ﷺ) had told me: 'You do not know you may live long (thus and bear the hardships for a long time), and I accepted that which the Messenger of Allah (ﷺ) had told me. When I grew old I wished I had availed myself of the concession (granted by) the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{2731}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ يَحْيَى، بْنِ أَبِي كَثِيرٍ بِهَذَا الإِسْنَادِ وَزَادَ فِيهِ بَعْدَ قَوْلِهِ ‏"‏ مِنْ كُلِّ شَهْرٍ ثَلاَثَةَ أَيَّامٍ ‏"‏ ‏"‏ فَإِنَّ لَكَ بِكُلِّ حَسَنَةٍ عَشْرَ أَمْثَالِهَا فَذَلِكَ الدَّهْرُ كُلُّهُ ‏"‏ ‏.‏ وَقَالَ فِي الْحَدِيثِ قُلْتُ وَمَا صَوْمُ نَبِيِّ اللَّهِ دَاوُدَ قَالَ ‏"‏ نِصْفُ الدَّهْرِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ فِي الْحَدِيثِ مِنْ قِرَاءَةِ الْقُرْآنِ شَيْئًا وَلَمْ يَقُلْ ‏"‏ وَإِنَّ لِزَوْرِكَ عَلَيْكَ حَقًّا ‏"‏ ‏.‏ وَلَكِنْ قَالَ ‏"‏ وَإِنَّ لِوَلَدِكَ عَلَيْكَ حَقًّا ‏"‏ ‏.‏\hadithno{2731}\hadithtrans{This hadith has been narrated by Yahya b. Abu Kathir with the same chain of transmitters and he made this addition after these words:During every month, (fasting) for three days, there is for you ten times for every good and that is perpetual fasting (for three days would bring a reward for full thirty days). I said: What is the fast of the Messenger of Allah, David? He said: Half of the age (observing fast on alternate days for the whole life). And in the hadith no mention has been made of the recital of the Qur'an, and he did not say: Your visitor has a right upon you, but (instead) he said: Your son has a right upon you}}
\hadithdefcmd{muslim}{2732}{حَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، مَوْلَى بَنِي زُهْرَةَ عَنْ أَبِي سَلَمَةَ، قَالَ - وَأَحْسِبُنِي قَدْ سَمِعْتُهُ أَنَا مِنْ أَبِي سَلَمَةَ، - عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، - رضى الله عنهما - قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَإِ الْقُرْآنَ فِي كُلِّ شَهْرٍ ‏"‏ ‏.‏ قَالَ قُلْتُ إِنِّي أَجِدُ قُوَّةً ‏.‏ قَالَ ‏"‏ فَاقْرَأْهُ فِي عِشْرِينَ لَيْلَةً ‏"‏ ‏.‏ قَالَ قُلْتُ إِنِّي أَجِدُ قُوَّةً ‏.‏ قَالَ ‏"‏ فَاقْرَأْهُ فِي سَبْعٍ وَلاَ تَزِدْ عَلَى ذَلِكَ ‏"‏ ‏.‏\hadithno{2732}\hadithtrans{Abdullah b. 'Amr (Allah be pleased with them) reported:The Messenger of Allah (ﷺ) said to me: Recite the whole of the Qur'An during every month. I said: I find power (to recite it) in a shorter period. He said: Then recite it in twenty nights. I said: I find power (to recite it in a shorter period even than this), whereupon he said: Then recite it in seven (nights) and do not exceed beyond it}}
\hadithdefcmd{muslim}{2733}{وَحَدَّثَنِي أَحْمَدُ بْنُ يُوسُفَ الأَزْدِيُّ، حَدَّثَنَا عَمْرُو بْنُ أَبِي سَلَمَةَ، عَنِ الأَوْزَاعِيِّ، قِرَاءَةً قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنِ ابْنِ الْحَكَمِ بْنِ ثَوْبَانَ، حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، - رضى الله عنهما - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا عَبْدَ اللَّهِ لاَ تَكُنْ بِمِثْلِ فُلاَنٍ كَانَ يَقُومُ اللَّيْلَ فَتَرَكَ قِيَامَ اللَّيْلِ ‏"‏ ‏.‏\hadithno{2733}\hadithtrans{Abdullah b. 'Amr b. al-'As (Allah be pleased with them) reported that the Messenger of Allah (ﷺ) said:'Abdullah, don't be like so and so who observed prayer during the whole night and then abandoned it (altogether)}}
\hadithdefcmd{muslim}{2734}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ سَمِعْتُ عَطَاءً، يَزْعُمُ أَنَّ أَبَا الْعَبَّاسِ، أَخْبَرَهُ أَنَّهُ، سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ، - رضى الله عنهما - يَقُولُ بَلَغَ النَّبِيَّ صلى الله عليه وسلم أَنِّي أَصُومُ أَسْرُدُ وَأُصَلِّي اللَّيْلَ فَإِمَّا أَرْسَلَ إِلَىَّ وَإِمَّا لَقِيتُهُ فَقَالَ ‏"‏ أَلَمْ أُخْبَرْ أَنَّكَ تَصُومُ وَلاَ تُفْطِرُ وَتُصَلِّي اللَّيْلَ فَلاَ تَفْعَلْ فَإِنَّ لِعَيْنِكَ حَظًّا وَلِنَفْسِكَ حَظًّا وَلأَهْلِكَ حَظًّا ‏.‏ فَصُمْ وَأَفْطِرْ وَصَلِّ وَنَمْ وَصُمْ مِنْ كُلِّ عَشْرَةِ أَيَّامٍ يَوْمًا وَلَكَ أَجْرُ تِسْعَةٍ ‏"‏ ‏.‏ قَالَ إِنِّي أَجِدُنِي أَقْوَى مِنْ ذَلِكَ يَا نَبِيَّ اللَّهِ ‏.‏ قَالَ ‏"‏ فَصُمْ صِيَامَ دَاوُدَ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏ قَالَ وَكَيْفَ كَانَ دَاوُدُ يَصُومُ يَا نَبِيَّ اللَّهِ قَالَ ‏"‏ كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا وَلاَ يَفِرُّ إِذَا لاَقَى ‏"‏ ‏.‏ قَالَ مَنْ لِي بِهَذِهِ يَا نَبِيَّ اللَّهِ قَالَ عَطَاءٌ فَلاَ أَدْرِي كَيْفَ ذَكَرَ صِيَامَ الأَبَدِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ صَامَ مَنْ صَامَ الأَبَدَ لاَ صَامَ مَنْ صَامَ الأَبَدَ لاَ صَامَ مَنْ صَامَ الأَبَدَ ‏"‏ ‏.‏\hadithno{2734}\hadithtrans{Abdu'llah b. 'Amr b. 'As (Allah be pleased with them) reported:It was conveyed to the Messenger of Allah (ﷺ) that I observe fast successively and pray during the whole night. He sent for me or I met him and he (the Holy Prophet) said: It has been conveyed to me that you observe fast continuously and do not break it and pray during the whole night. Don't do that. for there is share for your eyes, share for your own self, share for your family; so observe fast and break it, pray and sleep and observe fast for one day during the ten days, and there is a reward for you (for other) nine (days besides the tenth day of the fast). I said: Apostle of Allah, I find myself more powerful than this. He said: Then observe the fast of David (peace be upon him). He ('Amr) said: Apostle of Allah, how did David observe fast? He (the Holy Prophet) said: He used to fast one day and break it on the other day, and he did not run (from the battlefield) as he encountered (the enemy). He said: Apostle of Allah, who can guarantee this for me (will I also encounter the enemy dauntlessly)? 'Ata', the narrator of the hadith, said: I do not know how there (crept in) the matter of perpetual fast. The Apostle of Allah (ﷺ), however, said: He who observed perpetual fast did not fast at all; he who observed perpetual fast did not fast at all, he who observed perpetual fast did not fast at all}}
\hadithdefcmd{muslim}{2735}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، بِهَذَا الإِسْنَادِ وَقَالَ إِنَّ أَبَا الْعَبَّاسِ الشَّاعِرَ أَخْبَرَهُ ‏.‏ قَالَ مُسْلِمٌ أَبُو الْعَبَّاسِ السَّائِبُ بْنُ فَرُّوخَ مِنْ أَهْلِ مَكَّةَ ثِقَةٌ عَدْلٌ ‏.‏\hadithno{2735}\hadithtrans{This hadith has been narrated by Ibn Juraij with the same chain of transmitters. Imam Muslim has narrated this hadith on the authority of Abu 'Abbas al-Sa'ib b. Farrukh and he was a trustworthy and reliable (narrator) among the people of Mecca}}
\hadithdefcmd{muslim}{2736}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنِي أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ حَبِيبٍ، سَمِعَ أَبَا الْعَبَّاسِ، سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرٍو، - رضى الله عنهما - قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا عَبْدَ اللَّهِ بْنَ عَمْرٍو إِنَّكَ لَتَصُومُ الدَّهْرَ وَتَقُومُ اللَّيْلَ وَإِنَّكَ إِذَا فَعَلْتَ ذَلِكَ هَجَمَتْ لَهُ الْعَيْنُ وَنَهِكَتْ لاَ صَامَ مَنْ صَامَ الأَبَدَ صَوْمُ ثَلاَثَةِ أَيَّامٍ مِنَ الشَّهْرِ صَوْمُ الشَّهْرِ كُلِّهِ ‏"‏ ‏.‏ قُلْتُ فَإِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ فَصُمْ صَوْمَ دَاوُدَ كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا وَلاَ يَفِرُّ إِذَا لاَقَى ‏"‏ ‏.‏\hadithno{2736}\hadithtrans{Abdullah b. Amr (Allah be pleased with both of them) reported:The Messenger of Allah (ﷺ) said to me: 'Abdullah b. Amr, you fast continuously and stand in prayer for the whole of night. If you do like that, your eyes would be highly strained and would sink and lose sight. There is no (reward for) fasting (for him) who fasts perpetually. Fasting for three days during the month is like fasting, the whole of the month. I said: I am capable of doing more than this, whereupon he said: Observe the fast of David. He used to fast one day and break (the other) day. And he did not turn back in the encounter}}
\hadithdefcmd{muslim}{2737}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ بِشْرٍ، عَنْ مِسْعَرٍ، حَدَّثَنَا حَبِيبُ بْنُ أَبِي ثَابِتٍ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ وَنَفِهَتِ النَّفْسُ ‏"‏ ‏.‏\hadithno{2737}\hadithtrans{This hadith is narrated on the authority of Habib b. Abu Thabit with the same chain of transmitters and he said:" And you would become exhausted}}
\hadithdefcmd{muslim}{2738}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ أَبِي الْعَبَّاسِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، - رضى الله عنهما - قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلَمْ أُخْبَرْ أَنَّكَ تَقُومُ اللَّيْلَ وَتَصُومُ النَّهَارَ ‏"‏ ‏.‏ قُلْتُ إِنِّي أَفْعَلُ ذَلِكَ ‏.‏ قَالَ ‏"‏ فَإِنَّكَ إِذَا فَعَلْتَ ذَلِكَ هَجَمَتْ عَيْنَاكَ وَنَفِهَتْ نَفْسُكَ لِعَيْنِكَ حَقٌّ وَلِنَفْسِكَ حَقٌّ وَلأَهْلِكَ حَقٌّ قُمْ وَنَمْ وَصُمْ وَأَفْطِرْ ‏"‏ ‏.‏\hadithno{2738}\hadithtrans{Abdullah b. 'Amr (Allah be pleased with both of them) reported:The Messenger of Allah (ﷺ) said to me: I have been informed that you stand for prayer the whole of night and fast during the day. I said: I do that, whereupon he said: If you did that you in fact strained heavily your eyes and made yourself weak. There is a right of your eyes (upon you) and a right of your self (upon you) and a right of your family (upon you). Stand for prayer and sleep. observe fasts and break (them)}}
\hadithdefcmd{muslim}{2739}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ بْنُ، عُيَيْنَةَ عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَمْرِو بْنِ أَوْسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، - رضى الله عنهما - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَحَبَّ الصِّيَامِ إِلَى اللَّهِ صِيَامُ دَاوُدَ وَأَحَبَّ الصَّلاَةِ إِلَى اللَّهِ صَلاَةُ دَاوُدَ عَلَيْهِ السَّلاَمُ كَانَ يَنَامُ نِصْفَ اللَّيْلِ وَيَقُومُ ثُلُثَهُ وَيَنَامُ سُدُسَهُ وَكَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا ‏"‏ ‏.‏\hadithno{2739}\hadithtrans{Abdullah b. 'Amr (Allah be pleased with both of them) reported Allah's Messenger (ﷺ) as saying:With Allah the best fasting is that of David and the best prayer is that of David (peace be upon him) for he slept half of the night and stood for prayer for the third of it and (then) slept the sixth part of it and he observed fast one day and broke on the other}}
\hadithdefcmd{muslim}{2740}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو، بْنُ دِينَارٍ أَنَّ عَمْرَو بْنَ أَوْسٍ، أَخْبَرَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، - رضى الله عنهما - أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَحَبُّ الصِّيَامِ إِلَى اللَّهِ صِيَامُ دَاوُدَ كَانَ يَصُومُ نِصْفَ الدَّهْرِ وَأَحَبُّ الصَّلاَةِ إِلَى اللَّهِ عَزَّ وَجَلَّ صَلاَةُ دَاوُدَ - عَلَيْهِ السَّلاَمُ - كَانَ يَرْقُدُ شَطْرَ اللَّيْلِ ثُمَّ يَقُومُ ثُمَّ يَرْقُدُ آخِرَهُ يَقُومُ ثُلُثَ اللَّيْلِ بَعْدَ شَطْرِهِ ‏"‏ ‏.‏ قَالَ قُلْتُ لِعَمْرِو بْنِ دِينَارٍ أَعَمْرُو بْنُ أَوْسٍ كَانَ يَقُولُ يَقُومُ ثُلُثَ اللَّيْلِ بَعْدَ شَطْرِهِ قَالَ نَعَمْ ‏.‏\hadithno{2740}\hadithtrans{Abdullah b. 'Amr b. al-'As reported Allah's Messenger (ﷺ) as saying:The best fasting in the eye of Allah is that of David, for he fasted for half of the age (he fasted on alternate days), and the best prayer in the eye of Allah, the Exalted and Majestic, is that of David (peace be upon him), for he slept for half of the night and then stood for prayer and then again slept. He prayed for one-third of the night after midnight. He (the narrator) said: I asked 'Amr b. Dinar whether 'Amr b. Aus said that he stood for prayer one-third of the night after midnight. He said: Yes}}
\hadithdefcmd{muslim}{2741}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، قَالَ أَخْبَرَنِي أَبُو الْمَلِيحِ، قَالَ دَخَلْتُ مَعَ أَبِيكَ عَلَى عَبْدِ اللَّهِ بْنِ عَمْرٍو فَحَدَّثَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذُكِرَ لَهُ صَوْمِي فَدَخَلَ عَلَىَّ فَأَلْقَيْتُ لَهُ وِسَادَةً مِنْ أَدَمٍ حَشْوُهَا لِيفٌ فَجَلَسَ عَلَى الأَرْضِ وَصَارَتِ الْوِسَادَةُ بَيْنِي وَبَيْنَهُ فَقَالَ لِي ‏"‏ أَمَا يَكْفِيكَ مِنْ كُلِّ شَهْرٍ ثَلاَثَةُ أَيَّامٍ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ خَمْسًا ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ سَبْعًا ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ تِسْعًا ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ أَحَدَ عَشَرَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ صَوْمَ فَوْقَ صَوْمِ دَاوُدَ شَطْرُ الدَّهْرِ صِيَامُ يَوْمٍ وَإِفْطَارُ يَوْمٍ ‏"‏ ‏.‏\hadithno{2741}\hadithtrans{Abu Qatada reported that Abu al Malih informed me:I went along with your father to 'Abdullah b. Amr, and he narrated to us that the Messenger of Allah (ﷺ) was informed about my fasting and he came to me, and I placed a leather cushion filled with fibre of date-palms for him. He sat down upon the ground and there was that cushion between me and him, and he said to me: Does three days' fasting in a month not suffice you? I said: Messenger of Allah, (I am capable of observing more fasts). He said: (Would) five (not suffice for you)? I said: Messenger of Allah, (I am capable of observing more fasts) He said: (Would) seven (fasts) not suffice you? I said: Messenger of Allah, (I am capable of observing more fasts). He (the Holy Prophet) then said: (Would) nine (fasts not suffice you)? I said: Messenger of Allah, (I am capable of observing more fasts). He said: (Would) eleven (fasts not suffice you)? I said: Messenger of Allah, (I am capable of observing more fasts than these). Thereupon the Messenger of Allah (ﷺ) said: There is no fasting (better than) the fasting of David which comprises half of the age, fasting a day and not fasting a day}}
\hadithdefcmd{muslim}{2742}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ زِيَادِ بْنِ فَيَّاضٍ، قَالَ سَمِعْتُ أَبَا عِيَاضٍ، عَنْ عَبْدِ، اللَّهِ بْنِ عَمْرٍو - رضى الله عنهما - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُ ‏"‏ صُمْ يَوْمًا وَلَكَ أَجْرُ مَا بَقِيَ ‏"‏ ‏.‏ قَالَ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ يَوْمَيْنِ وَلَكَ أَجْرُ مَا بَقِيَ ‏"‏ ‏.‏ قَالَ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ ثَلاَثَةَ أَيَّامٍ وَلَكَ أَجْرُ مَا بَقِيَ ‏"‏ ‏.‏ قَالَ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ أَرْبَعَةَ أَيَّامٍ وَلَكَ أَجْرُ مَا بَقِيَ ‏"‏ ‏.‏ قَالَ إِنِّي أُطِيقُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ صُمْ أَفْضَلَ الصِّيَامِ عِنْدَ اللَّهِ صَوْمَ دَاوُدَ - عَلَيْهِ السَّلاَمُ - كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا ‏"‏ ‏.‏\hadithno{2742}\hadithtrans{Abdullah b. Amr (Allah be pleased with them) reported that the Messenger of Allah (ﷺ) had said to him:Observe fast for a day and there would be reward for you for the rest (of the days). He said: I am capable of doing more than this. He then said: Observe fast for two days, and there would be reward for you for the rest (of the days). He said: I am capable of doing more than this. He (the Holy Prophet) said: Observe fast for three days and there would be reward for you for the rest of the days. He said: I am capable of doing more than this, whereupon he said: Observe fast for four days and there would be reward for you for the rest of the days. He said: I am capable of doing more than this. Thereupon he said: Then observe fast (which is the) best in the eye of Allah, the fast of David (peace be upon him) ; he used to observe fast one day and break on the other day}}
\hadithdefcmd{muslim}{2743}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ حَاتِمٍ، جَمِيعًا عَنِ ابْنِ مَهْدِيٍّ، - قَالَ زُهَيْرٌ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، - حَدَّثَنَا سَلِيمُ بْنُ حَيَّانَ، حَدَّثَنَا سَعِيدُ بْنُ مِينَاءَ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ عَمْرٍو قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا عَبْدَ اللَّهِ بْنَ عَمْرٍو بَلَغَنِي أَنَّكَ تَصُومُ النَّهَارَ وَتَقُومُ اللَّيْلَ فَلاَ تَفْعَلْ فَإِنَّ لِجَسَدِكَ عَلَيْكَ حَظًّا وَلِعَيْنِكَ عَلَيْكَ حَظًّا وَإِنَّ لِزَوْجِكَ عَلَيْكَ حَظًّا صُمْ وَأَفْطِرْ صُمْ مِنْ كُلِّ شَهْرٍ ثَلاَثَةَ أَيَّامٍ فَذَلِكَ صَوْمُ الدَّهْرِ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ بِي قُوَّةً ‏.‏ قَالَ ‏"‏ فَصُمْ صَوْمَ دَاوُدَ - عَلَيْهِ السَّلاَمُ - صُمْ يَوْمًا وَأَفْطِرْ يَوْمًا ‏"‏ ‏.‏ فَكَانَ يَقُولُ يَا لَيْتَنِي أَخَذْتُ بِالرُّخْصَةِ ‏.‏\hadithno{2743}\hadithtrans{Abdullah b. 'Amr (Allah be pleased with them) reported that the Messenger of Allah (ﷺ) said to me! 'Abdullah b. 'Amr, it has been conveyed to me that you observe fast during the day and stand in prayer during the whole night. Don't do that, for your body has a share of its own in you, your eye has a share of its own in you, your wife has a share of her own in you. Observe fast and break it too. Fast for three days in every month and that is a prepetual fasting. I said! Messenger of Allah, I have got strength enough (to do more than this), whereupon he said:Then observe the fast of David (peace be upon him). Observe fast one day and break it (on the other) day. And he ('Abdullah b. 'Amr) used to say: Would that I had availed myself of this concession}}
\hadithdefcmd{muslim}{2744}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ يَزِيدَ الرِّشْكِ، قَالَ حَدَّثَتْنِي مُعَاذَةُ، الْعَدَوِيَّةُ أَنَّهَا سَأَلَتْ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ مِنْ كُلِّ شَهْرٍ ثَلاَثَةَ أَيَّامٍ قَالَتْ نَعَمْ ‏.‏ فَقُلْتُ لَهَا مِنْ أَىِّ أَيَّامِ الشَّهْرِ كَانَ يَصُومُ قَالَتْ لَمْ يَكُنْ يُبَالِي مِنْ أَىِّ أَيَّامِ الشَّهْرِ يَصُومُ ‏.‏\hadithno{2744}\hadithtrans{Mu'adha al-'Adawiyya reported that she asked 'A'isha, the wife of the Messenger of Allah (ﷺ), whether the Messenger of Allah (ﷺ) observed fasts for three days during every month. She said:Yes I said to her: Which were (the particular) days of the month on which he observed fast? She said: He was not particular about the days of the month on which to observe fast}}
\hadithdefcmd{muslim}{2745}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ الضُّبَعِيُّ، حَدَّثَنَا مَهْدِيٌّ، - وَهُوَ ابْنُ مَيْمُونٍ - حَدَّثَنَا غَيْلاَنُ بْنُ جَرِيرٍ، عَنْ مُطَرِّفٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، - رضى الله عنهما - أَنَّصلى الله عليه وسلم قَالَ لَهُ أَوْ قَالَ لِرَجُلٍ وَهُوَ يَسْمَعُ ‏"‏ يَا فُلاَنُ أَصُمْتَ مِنْ سُرَّةِ هَذَا الشَّهْرِ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَإِذَا أَفْطَرْتَ فَصُمْ يَوْمَيْنِ ‏"‏ ‏.‏\hadithno{2745}\hadithtrans{Imran b. Husain (Allah be pleased with them) reported that the Messenger of Allah (ﷺ) said to him (or he said to another person and he was listening to it):O, so and so, did you observe fast in the middle of the month? He said: No. Thereupon he (the Messenger of Allah) said: When you break it, then observe fast for two days}}
\hadithdefcmd{muslim}{2746}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، جَمِيعًا عَنْ حَمَّادٍ، - قَالَ يَحْيَى أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، - عَنْ غَيْلاَنَ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْبَدٍ الزِّمَّانِيِّ، عَنْ أَبِي قَتَادَةَ، رَجُلٌ أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ كَيْفَ تَصُومُ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَأَى عُمَرُ - رضى الله عنه - غَضَبَهُ قَالَ رَضِينَا بِاللَّهِ رَبًّا وَبِالإِسْلاَمِ دِينًا وَبِمُحَمَّدٍ نَبِيًّا نَعُوذُ بِاللَّهِ مِنْ غَضَبِ اللَّهِ وَغَضَبِ رَسُولِهِ ‏.‏ فَجَعَلَ عُمَرُ - رضى الله عنه - يُرَدِّدُ هَذَا الْكَلاَمَ حَتَّى سَكَنَ غَضَبُهُ فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ كَيْفَ بِمَنْ يَصُومُ الدَّهْرَ كُلَّهُ قَالَ ‏"‏ لاَ صَامَ وَلاَ أَفْطَرَ - أَوْ قَالَ - لَمْ يَصُمْ وَلَمْ يُفْطِرْ ‏"‏ ‏.‏ قَالَ كَيْفَ مَنْ يَصُومُ يَوْمَيْنِ وَيُفْطِرُ يَوْمًا قَالَ ‏"‏ وَيُطِيقُ ذَلِكَ أَحَدٌ ‏"‏ ‏.‏ قَالَ كَيْفَ مَنْ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا قَالَ ‏"‏ ذَاكَ صَوْمُ دَاوُدَ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏ قَالَ كَيْفَ مَنْ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمَيْنِ قَالَ ‏"‏ وَدِدْتُ أَنِّي طُوِّقْتُ ذَلِكَ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ثَلاَثٌ مِنْ كُلِّ شَهْرٍ وَرَمَضَانُ إِلَى رَمَضَانَ فَهَذَا صِيَامُ الدَّهْرِ كُلِّهِ صِيَامُ يَوْمِ عَرَفَةَ أَحْتَسِبُ عَلَى اللَّهِ أَنْ يُكَفِّرَ السَّنَةَ الَّتِي قَبْلَهُ وَالسَّنَةَ الَّتِي بَعْدَهُ وَصِيَامُ يَوْمِ عَاشُورَاءَ أَحْتَسِبُ عَلَى اللَّهِ أَنْ يُكَفِّرَ السَّنَةَ الَّتِي قَبْلَهُ ‏"‏ ‏.‏\hadithno{2746}\hadithtrans{Abu Qatada reported that a person came to the Messenger of Allah (ﷺ) and said:How do you fast? The Messenger of Allah (ﷺ) felt annoyed. When 'Umar (Allah be pleased with him) noticed his annoyance, he said: We are well pleased with Allah as our Lord, with Islam as our code of life, and with Muhammad as our Prophet. We seek refuge with Allah from the anger of Allah and that of His Messenger. 'Umar kept on repeating these words till his (the Prophet's) anger calmed down. Then Umar said: Messenger of Allah, what is the position of one who fasts perpetually? He (ﷺ) said: He neither fasted nor broke it, or he said: He did not fast and he did not break it. 'Umar said: What about him who fasts for two days and does not fast one day? He (ﷺ) said: Is anyone capable of doing that? He ('Umar) said: What is the position of him who fasts for a day and doesn't fast on the other day? Thereupon he (the Holy Prophet) said: That is the fast of David (peace be upon him). He ('Umar) said: What about him who fasts one day and doesn't fast for two days. Thereupon he (the Messenger of Allah) said: I wish I were given the strength to do that. Thereafter he (ﷺ) said: Fasting three days every month and that of Ramadan every year is a perpetual fasting. I seek from Allah that fasting on the day of 'Arafa may atone for the sins of the preceding and the coming years, and I seek from Allah that fasting on the day of Ashura may atone for the sins of the preceding year}}
\hadithdefcmd{muslim}{2747}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، سَمِعَ عَبْدَ اللَّهِ بْنَ مَعْبَدٍ الزِّمَّانِيَّ، عَنْ أَبِي قَتَادَةَ الأَنْصَارِيِّ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنْ صَوْمِهِ قَالَ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ عُمَرُ رضى الله عنه رَضِينَا بِاللَّهِ رَبًّا وَبِالإِسْلاَمِ دِينًا وَبِمُحَمَّدٍ رَسُولاً وَبِبَيْعَتِنَا بَيْعَةً ‏.‏ قَالَ فَسُئِلَ عَنْ صِيَامِ الدَّهْرِ فَقَالَ ‏"‏ لاَ صَامَ وَلاَ أَفْطَرَ ‏"‏ ‏.‏ أَوْ ‏"‏ مَا صَامَ وَمَا أَفْطَرَ ‏"‏ ‏.‏ قَالَ فَسُئِلَ عَنْ صَوْمِ يَوْمَيْنِ وَإِفْطَارِ يَوْمٍ قَالَ ‏"‏ وَمَنْ يُطِيقُ ذَلِكَ ‏"‏ ‏.‏ قَالَ وَسُئِلَ عَنْ صَوْمِ يَوْمٍ وَإِفْطَارِ يَوْمَيْنِ قَالَ ‏"‏ لَيْتَ أَنَّ اللَّهَ قَوَّانَا لِذَلِكَ ‏"‏ ‏.‏ قَالَ وَسُئِلَ عَنْ صَوْمِ يَوْمٍ وَإِفْطَارِ يَوْمٍ قَالَ ‏"‏ ذَاكَ صَوْمُ أَخِي دَاوُدَ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏ قَالَ وَسُئِلَ عَنْ صَوْمِ يَوْمِ الاِثْنَيْنِ قَالَ ‏"‏ ذَاكَ يَوْمٌ وُلِدْتُ فِيهِ وَيَوْمٌ بُعِثْتُ أَوْ أُنْزِلَ عَلَىَّ فِيهِ ‏"‏ ‏.‏ قَالَ فَقَالَ ‏"‏ صَوْمُ ثَلاَثَةٍ مِنْ كُلِّ شَهْرٍ وَرَمَضَانَ إِلَى رَمَضَانَ صَوْمُ الدَّهْرِ ‏"‏ ‏.‏ قَالَ وَسُئِلَ عَنْ صَوْمِ يَوْمِ عَرَفَةَ فَقَالَ ‏"‏ يُكَفِّرُ السَّنَةَ الْمَاضِيَةَ وَالْبَاقِيَةَ ‏"‏ ‏.‏ قَالَ وَسُئِلَ عَنْ صَوْمِ يَوْمِ عَاشُورَاءَ فَقَالَ ‏"‏ يُكَفِّرُ السَّنَةَ الْمَاضِيَةَ ‏"‏ ‏.‏ وَفِي هَذَا الْحَدِيثِ مِنْ رِوَايَةِ شُعْبَةَ قَالَ وَسُئِلَ عَنْ صَوْمِ يَوْمِ الاِثْنَيْنِ وَالْخَمِيسِ فَسَكَتْنَا عَنْ ذِكْرِ الْخَمِيسِ لَمَّا نَرَاهُ وَهْمًا ‏.‏\hadithno{2747}\hadithtrans{Abu Qatada al-Ansari (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) was asked about his fasting. The Messenger of Allah (ﷺ) felt annoyed. Thereupon 'Umar (Allah be pleased with him) said:We are pleased with Allah as the Lord, with Islam as our Code of Life, with Muhammad as the Messenger and with our pledge (to you for willing and cheerful submission) as a (sacred) commitment. He was then asked about perpetual fasting, whereupon he said: He neither fasted nor did he break it, or he did not fast and he did not break it. He was then asked about fasting for two days and breaking one day. He (the Holy Prophet) said: And who has strength enough to do it? He was asked about fasting for a day and breaking for two days, whereupon he said: May Allah bestow upon us strength to do it. He was then asked about fasting for a day and breaking on the other, whereupon he said: That is the fasting of my brother David (peace be upon him). He was then asked about fasting on Monday, whereupon he said: It was the day on which I was born. on which I was commissioned with prophethood or revelation was sent to me, (and he further) said: Three days' fasting every month and of the whole of Ramadan every year is a perpetual fast. He was asked about fasting on the day of 'Arafa (9th of Dhu'I-Hijja), whereupon he said: It expiates the sins of the preceding year and the coming year. He was asked about fasting on the day of 'Ashura (10th of Muharram), whereupon be said: It expiates the sins of the preceding year. (Imam Muslim said that in this hadith there is a) narration of Imam Shu'ba that he was asked about fasting on Monday and Thursday, but we (Imam Muslim) did not mention Thursday for we found it as an error (in reporting)}}
\hadithdefcmd{muslim}{2748}{وَحَدَّثَنَاهُ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، كُلُّهُمْ عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ‏.‏\hadithno{2748}\hadithtrans{This hadith has been narrated by Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{2749}{وَحَدَّثَنِي أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا أَبَانُ الْعَطَّارُ، حَدَّثَنَا غَيْلاَنُ بْنُ جَرِيرٍ، فِي هَذَا الإِسْنَادِ بِمِثْلِ حَدِيثِ شُعْبَةَ غَيْرَ أَنَّهُ ذَكَرَ فِيهِ الاِثْنَيْنِ وَلَمْ يَذْكُرِ الْخَمِيسَ ‏.‏\hadithno{2749}\hadithtrans{This hadith has been narrated by Ghailan b. Jarir with the same chain of transmitters, but with one variation, that there has been made mention of Monday and not of Thursday}}
\hadithdefcmd{muslim}{2750}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، عَنْ غَيْلاَنَ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْبَدٍ الزِّمَّانِيِّ، عَنْ أَبِي قَتَادَةَ الأَنْصَارِيِّ، رضى الله عنه أَنَّرَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنْ صَوْمِ الاِثْنَيْنِ فَقَالَ ‏ "‏ فِيهِ وُلِدْتُ وَفِيهِ أُنْزِلَ عَلَىَّ ‏"‏ ‏.‏\hadithno{2750}\hadithtrans{Abu Qatada Ansari (Allah be pleased with him) reported that Allah's Massenger (ﷺ) was asked about fasting on Monday, whereupon he said:It is (the day) when I was born and revelation was sent down to me}}
\hadithdefcmd{muslim}{2751}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ مُطَرِّفٍ، - وَلَمْ أَفْهَمْ مُطَرِّفًا مِنْ هَدَّابٍ - عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، - رضى الله عنهما - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُ أَوْ لآخَرَ ‏"‏ أَصُمْتَ مِنْ سَرَرِ شَعْبَانَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَإِذَا أَفْطَرْتَ فَصُمْ يَوْمَيْنِ ‏"‏ ‏.‏\hadithno{2751}\hadithtrans{Imran b. Husain (Allah be pleased with them) reported Allah's Messenger (may peace he upon him) having said to him or to someone else:Did you fast in the middle of Sha'ban? He said: No. Thereupon he (the Holy Prophet) said: If you did not observe fast, then you should observe fast for two days}}
\hadithdefcmd{muslim}{2752}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي، الْعَلاَءِ عَنْ مُطَرِّفٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، - رضى الله عنهما - أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِرَجُلٍ ‏"‏ هَلْ صُمْتَ مِنْ سُرَرِ هَذَا الشَّهْرِ شَيْئًا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِذَا أَفْطَرْتَ مِنْ رَمَضَانَ فَصُمْ يَوْمَيْنِ مَكَانَهُ ‏"‏ ‏.‏\hadithno{2752}\hadithtrans{Imran b. Husain (Allah be pleased with them) reported that Allah's Apostle (ﷺ) said to a person:Did you observe any fast in the middle of this month (Sha'ban)? He said: No. Thereupon the Messenger of Allah (ﷺ) said: Fast for two days instead of (one fast) when you have completed (fasts of) Ramadan}}
\hadithdefcmd{muslim}{2753}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ ابْنِ أَخِي، مُطَرِّفِ بْنِ الشِّخِّيرِ قَالَ سَمِعْتُ مُطَرِّفًا، يُحَدِّثُ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، - رضى الله عنهما - أَنَّصلى الله عليه وسلم قَالَ لِرَجُلٍ ‏"‏ هَلْ صُمْتَ مِنْ سِرَرِ هَذَا الشَّهْرِ شَيْئًا ‏"‏ ‏.‏ يَعْنِي شَعْبَانَ ‏.‏ قَالَ لاَ ‏.‏ قَالَ فَقَالَ لَهُ ‏"‏ إِذَا أَفْطَرْتَ رَمَضَانَ فَصُمْ يَوْمًا أَوْ يَوْمَيْنِ ‏"‏ ‏.‏ شُعْبَةُ الَّذِي شَكَّ فِيهِ قَالَ وَأَظُنُّهُ قَالَ يَوْمَيْنِ ‏.‏\hadithno{2753}\hadithtrans{Imran b. Husain (Allah be pleased with them) reported that the Messenger of Allah (ﷺ) said to a person:Did you observe fast in the middle of this month. i. e. Sha'ban? He said: No. Thereupon he said to him: When it is the end of Ramadan, then observe fast for one day or two (Shu'ba had some doubt about it) but he said: I think that he has said: two days}}
\hadithdefcmd{muslim}{2754}{وَحَدَّثَنِي مُحَمَّدُ بْنُ قُدَامَةَ، وَيَحْيَى اللُّؤْلُؤِيُّ، قَالاَ أَخْبَرَنَا النَّضْرُ، أَخْبَرَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ هَانِئِ ابْنِ أَخِي، مُطَرِّفٍ فِي هَذَا الإِسْنَادِ ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{2754}\hadithtrans{This hadith is narrated by 'Abdullah b. Hani b. Akhi Mutarrif with the same chain of transmitters}}
\hadithdefcmd{muslim}{2755}{حَدَّثَنِي قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، الْحِمْيَرِيِّ عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَفْضَلُ الصِّيَامِ بَعْدَ رَمَضَانَ شَهْرُ اللَّهِ الْمُحَرَّمُ وَأَفْضَلُ الصَّلاَةِ بَعْدَ الْفَرِيضَةِ صَلاَةُ اللَّيْلِ ‏"‏ ‏.‏\hadithno{2755}\hadithtrans{Abu Haraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:The most excellent fast after Ramadan is God's month. al-Muharram, and the most excellent prayer after what is prescribed is prayer during the night}}
\hadithdefcmd{muslim}{2756}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ مُحَمَّدِ بْنِ، الْمُنْتَشِرِ عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - يَرْفَعُهُ قَالَ سُئِلَ أَىُّ الصَّلاَةِ أَفْضَلُ بَعْدَ الْمَكْتُوبَةِ وَأَىُّ الصِّيَامِ أَفْضَلُ بَعْدَ شَهْرِ رَمَضَانَ فَقَالَ ‏ "‏ أَفْضَلُ الصَّلاَةِ بَعْدَ الصَّلاَةِ الْمَكْتُوبَةِ الصَّلاَةُ فِي جَوْفِ اللَّيْلِ وَأَفْضَلُ الصِّيَامِ بَعْدَ شَهْرِ رَمَضَانَ صِيَامُ شَهْرِ اللَّهِ الْمُحَرَّمِ ‏"‏ ‏.‏\hadithno{2756}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that he (the Messenger of Allah) was asked as to which prayer was most excellent after the prescribed prayer, and which fast was most excellent after the month of Ramadan. He said:Prayer offered in the middle of the night and the most excellent fast after (fasting) in the month of Ramadan is the fast in God's month al-Muharram}}
\hadithdefcmd{muslim}{2757}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ عَبْدِ الْمَلِكِ، بْنِ عُمَيْرٍ بِهَذَا الإِسْنَادِ فِي ذِكْرِ الصِّيَامِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{2757}\hadithtrans{A hadith like this has been reported from the Messenger of Allah (ﷺ) by 'Abd al-Malik with the same chain of transmitters in connection with fast}}
\hadithdefcmd{muslim}{2758}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ، جَمِيعًا عَنْ إِسْمَاعِيلَ، - قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، - أَخْبَرَنِي سَعْدُ بْنُ سَعِيدِ بْنِ قَيْسٍ، عَنْ عُمَرَ، بْنِ ثَابِتِ بْنِ الْحَارِثِ الْخَزْرَجِيِّ عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، - رضى الله عنه - أَنَّهُ حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَامَ رَمَضَانَ ثُمَّ أَتْبَعَهُ سِتًّا مِنْ شَوَّالٍ كَانَ كَصِيَامِ الدَّهْرِ ‏"‏ ‏.‏\hadithno{2758}\hadithtrans{Abu Ayyub al-Ansari (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:He who observed the fast of Ramadan and then followed it with six (fasts) of Shawwal. it would be as if he fasted perpetually}}
\hadithdefcmd{muslim}{2759}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سَعْدُ بْنُ سَعِيدٍ، أَخُو يَحْيَى بْنِ سَعِيدٍ أَخْبَرَنَا عُمَرُ بْنُ ثَابِتٍ، أَخْبَرَنَا أَبُو أَيُّوبَ الأَنْصَارِيُّ، - رضى الله عنه - قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{2759}\hadithtrans{Abu Ayyub al-Ansari reported (through another chain of transmitters):I heard Allah's Messenger (ﷺ) saying like this}}
\hadithdefcmd{muslim}{2760}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ سَعْدِ بْنِ سَعِيدٍ، قَالَ سَمِعْتُ عُمَرَ بْنَ ثَابِتٍ، قَالَ سَمِعْتُ أَبَا أَيُّوبَ، - رضى الله عنه - يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{2760}\hadithtrans{Abu Ayyub reported a hadith like this (through another chain of transmitters)}}
\hadithdefcmd{muslim}{2761}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - أَنَّ رِجَالاً، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أُرُوا لَيْلَةَ الْقَدْرِ فِي الْمَنَامِ فِي السَّبْعِ الأَوَاخِرِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَرَى رُؤْيَاكُمْ قَدْ تَوَاطَأَتْ فِي السَّبْعِ الأَوَاخِرِ فَمَنْ كَانَ مُتَحَرِّيَهَا فَلْيَتَحَرَّهَا فِي السَّبْعِ الأَوَاخِرِ ‏"‏ ‏.‏\hadithno{2761}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported that some persons among the Companions of the Messenger of Allah (ﷺ) were shown Lailat- ul-Qadr while sleeping in the last week (of Ramadan). Thereupon Allah's Messenger (ﷺ) said:I see that your dreams agree regarding the last week; so he who wants to seek it should seek it in the last week (during the night)}}
\hadithdefcmd{muslim}{2762}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ، عُمَرَ - رضى الله عنهما - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تَحَرَّوْا لَيْلَةَ الْقَدْرِ فِي السَّبْعِ الأَوَاخِرِ ‏"‏ ‏.‏\hadithno{2762}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Apostle (ﷺ) as saying:Seek Lailat-ul-Qadr in the last week (of Ramadan)}}
\hadithdefcmd{muslim}{2763}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، - رضى الله عنه - قَالَ رَأَى رَجُلٌ أَنَّ لَيْلَةَ الْقَدْرِ لَيْلَةُ سَبْعٍ وَعِشْرِينَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَرَى رُؤْيَاكُمْ فِي الْعَشْرِ الأَوَاخِرِ فَاطْلُبُوهَا فِي الْوِتْرِ مِنْهَا ‏"‏ ‏.‏\hadithno{2763}\hadithtrans{Salim reported on the authority of his father that a person saw Lailat-ul- Qadr on the 27th (of Ramadan). Thereupon Allah's Apostle (ﷺ) said:I see that your dreams agree regarding the last ten (nights of Ramadan). So seek it on an odd number (of these ten nights)}}
\hadithdefcmd{muslim}{2764}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ أَبَاهُ، - رضى الله عنه - قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ لِلَيْلَةِ الْقَدْرِ ‏ "‏ إِنَّ نَاسًا مِنْكُمْ قَدْ أُرُوا أَنَّهَا فِي السَّبْعِ الأُوَلِ وَأُرِيَ نَاسٌ مِنْكُمْ أَنَّهَا فِي السَّبْعِ الْغَوَابِرِ فَالْتَمِسُوهَا فِي الْعَشْرِ الْغَوَابِرِ ‏"‏ ‏.‏\hadithno{2764}\hadithtrans{Salim b. 'Abdullah b. 'Umar reported that his father said:I heard Allah's Messenger (ﷺ) as saying: So far as Lailat-ul-Qadr is concerned. some persons among you have seen it (in a dream) in the first week and some persons among you have been shown that it is in the last week; so seek it in the last ten (nights)}}
\hadithdefcmd{muslim}{2765}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عُقْبَةَ، - وَهُوَ ابْنُ حُرَيْثٍ - قَالَ سَمِعْتُ ابْنَ عُمَرَ، - رضى الله عنهما - يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْتَمِسُوهَا فِي الْعَشْرِ الأَوَاخِرِ - يَعْنِي لَيْلَةَ الْقَدْرِ - فَإِنْ ضَعُفَ أَحَدُكُمْ أَوْ عَجَزَ فَلاَ يُغْلَبَنَّ عَلَى السَّبْعِ الْبَوَاقِي ‏"‏ ‏.‏\hadithno{2765}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:Seek it (Lailat-ul-Qadr) in the last (ten nights). If one among you shows slackness and weakness (in the earlier part of Ramadan), it should not be allowed to prevail upon him in the last week}}
\hadithdefcmd{muslim}{2766}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ جَبَلَةَ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، - رضى الله عنهما - يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ كَانَ مُلْتَمِسَهَا فَلْيَلْتَمِسْهَا فِي الْعَشْرِ الأَوَاخِرِ ‏"‏ ‏.‏\hadithno{2766}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:He who is anxious to seek it (Lailat-ul-Qadr) should seek it in the last ten (nights of Ramadan)}}
\hadithdefcmd{muslim}{2767}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الشَّيْبَانِيِّ، عَنْ جَبَلَةَ، وَمُحَارِبٍ عَنِ ابْنِ عُمَرَ، - رضى الله عنهما - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَحَيَّنُوا لَيْلَةَ الْقَدْرِ فِي الْعَشْرِ الأَوَاخِرِ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ فِي التِّسْعِ الأَوَاخِرِ ‏"‏ ‏.‏\hadithno{2767}\hadithtrans{Ibn 'Umar (Allah be pleased with both of them) reported Allah's Messenger (ﷺ) as saying:Seek the time of Lailat-ul-Qadr in the last (ten nights), or he said: in the last nine (nights)}}
\hadithdefcmd{muslim}{2768}{حَدَّثَنَا أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - أَنَّاللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أُرِيتُ لَيْلَةَ الْقَدْرِ ثُمَّ أَيْقَظَنِي بَعْضُ أَهْلِي فَنُسِّيتُهَا فَالْتَمِسُوهَا فِي الْعَشْرِ الْغَوَابِرِ ‏"‏ ‏.‏ وَقَالَ حَرْمَلَةُ ‏"‏ فَنَسِيتُهَا ‏"‏ ‏.‏\hadithno{2768}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:I was shown Lailat-ul-Qadr; then some members of my family awoke me up, then I was caused to forget it. So seek it in the last week. Harmala said: (The Prophet did not say:" I was made to forget," but he stated):" But I forgot it}}
\hadithdefcmd{muslim}{2769}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا بَكْرٌ، - وَهُوَ ابْنُ مُضَرَ - عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ، بْنِ إِبْرَاهِيمَ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، - رضى الله عنه - قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُجَاوِرُ فِي الْعَشْرِ الَّتِي فِي وَسَطِ الشَّهْرِ فَإِذَا كَانَ مِنْ حِينِ تَمْضِي عِشْرُونَ لَيْلَةً وَيَسْتَقْبِلُ إِحْدَى وَعِشْرِينَ يَرْجِعُ إِلَى مَسْكَنِهِ وَرَجَعَ مَنْ كَانَ يُجَاوِرُ مَعَهُ ثُمَّ إِنَّهُ أَقَامَ فِي شَهْرٍ جَاوَرَ فِيهِ تِلْكَ اللَّيْلَةَ الَّتِي كَانَ يَرْجِعُ فِيهَا فَخَطَبَ النَّاسَ فَأَمَرَهُمْ بِمَا شَاءَ اللَّهُ ثُمَّ قَالَ ‏ "‏ إِنِّي كُنْتُ أُجَاوِرُ هَذِهِ الْعَشْرَ ثُمَّ بَدَا لِي أَنْ أُجَاوِرَ هَذِهِ الْعَشْرَ الأَوَاخِرَ فَمَنْ كَانَ اعْتَكَفَ مَعِي فَلْيَبِتْ فِي مُعْتَكَفِهِ وَقَدْ رَأَيْتُ هَذِهِ اللَّيْلَةَ فَأُنْسِيتُهَا فَالْتَمِسُوهَا فِي الْعَشْرِ الأَوَاخِرِ فِي كُلِّ وِتْرٍ وَقَدْ رَأَيْتُنِي أَسْجُدُ فِي مَاءٍ وَطِينٍ ‏"‏ ‏.‏ قَالَ أَبُو سَعِيدٍ الْخُدْرِيُّ مُطِرْنَا لَيْلَةَ إِحْدَى وَعِشْرِينَ فَوَكَفَ الْمَسْجِدُ فِي مُصَلَّى رَسُولِ اللَّهِ صلى الله عليه وسلم فَنَظَرْتُ إِلَيْهِ وَقَدِ انْصَرَفَ مِنْ صَلاَةِ الصُّبْحِ وَوَجْهُهُ مُبْتَلٌّ طِينًا وَمَاءً ‏.‏\hadithno{2769}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported that Allah's Messenger (ﷺ) spent in devotion (in i'tikaf) the middle ten nights of the month of Ramadan, and when twenty nights were over and it was the twenty-first night, he went back to his residence and those who were along with him also returned (to their respective residences). He spent one month in devotion. Then he addressed the people on the night he came back (to his residence) and commanded them as Allah desired (him to command) and then said:I used to devote myself (observe i'tikaf) during these ten (nights). Then I started devoting myself in the last ten (nights). And he who desires to observe i'tikaf along with me should spend the night) at his place of i'tikaf. And I saw this night (Lailat-ul-Qadr) but I forgot it (the exact night) ; so seek it;In the last ten nights on odd numbers. I saw (the glimpses of that dream) that I was prostrating in water and mud. Abu Sa'id al-Khudri said: It rained on the twenty-first night and the water dripped (from the roof) of the mosque at the place where the Messenger of Allah (ﷺ) observed prayer. I looked at him and as he completed the dawn prayer, (I found) his face was wet with mud and water}}
\hadithdefcmd{muslim}{2770}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنْ يَزِيدَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، - رضى الله عنه - أَنَّهُ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُجَاوِرُ فِي رَمَضَانَ الْعَشْرَ الَّتِي فِي وَسَطِ الشَّهْرِ ‏.‏ وَسَاقَ الْحَدِيثَ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ فَلْيَثْبُتْ فِي مُعْتَكَفِهِ ‏"‏ ‏.‏ وَقَالَ وَجَبِينُهُ مُمْتَلِئًا طِينًا وَمَاءً ‏.‏\hadithno{2770}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) devoted (himself to prayer) in the middle (ten nights) of Ramadan. The rest of the hadith is the same except for these words:" That he adhered to his place of i'tikaf and his forehead was besmeared with mud and water}}
\hadithdefcmd{muslim}{2771}{وَحَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا الْمُعْتَمِرُ، حَدَّثَنَا عُمَارَةُ بْنُ غَزِيَّةَ الأَنْصَارِيُّ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ إِبْرَاهِيمَ، يُحَدِّثُ عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، - رضى الله عنه - قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اعْتَكَفَ الْعَشْرَ الأَوَّلَ مِنْ رَمَضَانَ ثُمَّ اعْتَكَفَ الْعَشْرَ الأَوْسَطَ فِي قُبَّةٍ تُرْكِيَّةٍ عَلَى سُدَّتِهَا حَصِيرٌ - قَالَ - فَأَخَذَ الْحَصِيرَ بِيَدِهِ فَنَحَّاهَا فِي نَاحِيَةِ الْقُبَّةِ ثُمَّ أَطْلَعَ رَأْسَهُ فَكَلَّمَ النَّاسَ فَدَنَوْا مِنْهُ فَقَالَ ‏"‏ إِنِّي اعْتَكَفْتُ الْعَشْرَ الأَوَّلَ أَلْتَمِسُ هَذِهِ اللَّيْلَةَ ثُمَّ اعْتَكَفْتُ الْعَشْرَ الأَوْسَطَ ثُمَّ أُتِيتُ فَقِيلَ لِي إِنَّهَا فِي الْعَشْرِ الأَوَاخِرِ فَمَنْ أَحَبَّ مِنْكُمْ أَنْ يَعْتَكِفَ فَلْيَعْتَكِفْ ‏"‏ ‏.‏ فَاعْتَكَفَ النَّاسُ مَعَهُ قَالَ ‏"‏ وَإِنِّي أُرِيتُهَا لَيْلَةَ وِتْرٍ وَأَنِّي أَسْجُدُ صَبِيحَتَهَا فِي طِينٍ وَمَاءٍ ‏"‏ ‏.‏ فَأَصْبَحَ مِنْ لَيْلَةِ إِحْدَى وَعِشْرِينَ وَقَدْ قَامَ إِلَى الصُّبْحِ فَمَطَرَتِ السَّمَاءُ فَوَكَفَ الْمَسْجِدُ فَأَبْصَرْتُ الطِّينَ وَالْمَاءَ فَخَرَجَ حِينَ فَرَغَ مِنْ صَلاَةِ الصُّبْحِ وَجَبِينُهُ وَرَوْثَةُ أَنْفِهِ فِيهِمَا الطِّينُ وَالْمَاءُ وَإِذَا هِيَ لَيْلَةُ إِحْدَى وَعِشْرِينَ مِنَ الْعَشْرِ الأَوَاخِرِ ‏.‏\hadithno{2771}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) observed i'tikaf (confined himself for devotion and prayer) in the first ten (days) of Ramadan; he then observed i'tikaf in the middle ten (days) in a Turkish tent with a mat hanging at its door. He (the Holy Prophet) took hold of that mat and placed it in the nook of the tent. He then put his head out and talked with people and they came near him, and he (the Holy Prophet) said:I observed i'tikaf in the first ten (nights and days) in order to seek that night (Lailat-ul-Qadr). I then observed i'tikaf in the middle ten days. Then (an angel) was sent to me and I was told that this (night) is among the last ten (nights). He who among you likes to observe i'tikaf should do so; and the people observed it along with him, and he (the Holy Prophet) said: That (Lailat-ul-Qadr) was shown to me on an odd (night) and I (saw in the dream) that I was prostrating in the morning in clay and water. So in the morning of the twenty-first night when he (the Holy Prophet) got up for dawn (prayer). there was a rainfall and the mosque dripped, and I saw clay and water. When he came out after completing the morning prayer (I saw) that his forehead and the tip of his nose had (traces) of clay and water, and that was the twenty-first night among the last ten (nights)}}
\hadithdefcmd{muslim}{2772}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، قَالَ تَذَاكَرْنَا لَيْلَةَ الْقَدْرِ فَأَتَيْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ - رضى الله عنه - وَكَانَ لِي صَدِيقًا فَقُلْتُ أَلاَ تَخْرُجُ بِنَا إِلَى النَّخْلِ فَخَرَجَ وَعَلَيْهِ خَمِيصَةٌ فَقُلْتُ لَهُ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَذْكُرُ لَيْلَةَ الْقَدْرِ فَقَالَ نَعَمْ اعْتَكَفْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْعَشْرَ الْوُسْطَى مِنْ رَمَضَانَ فَخَرَجْنَا صَبِيحَةَ عِشْرِينَ فَخَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنِّي أُرِيتُ لَيْلَةَ الْقَدْرِ وَإِنِّي نَسِيتُهَا - أَوْ أُنْسِيتُهَا - فَالْتَمِسُوهَا فِي الْعَشْرِ الأَوَاخِرِ مِنْ كُلِّ وِتْرٍ وَإِنِّي أُرِيتُ أَنِّي أَسْجُدُ فِي مَاءٍ وَطِينٍ فَمَنْ كَانَ اعْتَكَفَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلْيَرْجِعْ ‏"‏ ‏.‏ قَالَ فَرَجَعْنَا وَمَا نَرَى فِي السَّمَاءِ قَزَعَةً قَالَ وَجَاءَتْ سَحَابَةٌ فَمُطِرْنَا حَتَّى سَالَ سَقْفُ الْمَسْجِدِ وَكَانَ مِنْ جَرِيدِ النَّخْلِ وَأُقِيمَتِ الصَّلاَةُ فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْجُدُ فِي الْمَاءِ وَالطِّينِ قَالَ حَتَّى رَأَيْتُ أَثَرَ الطِّينِ فِي جَبْهَتِهِ ‏.‏\hadithno{2772}\hadithtrans{Abu Salama reported:'We discussed amongst ourselves Lailat-ul-Qadr. I came to Abu Sa'id al-Khudri (Allah be pleased with him) who was a friend of mine and said to him: Would you not go with us to the garden of date trees? He went out with a cloak over him. I said to him: Did you hear the Messenger of Allah (ﷺ) making mention of Lailat-ul-Qadr? He said: Yes, (and added) we were observing i'tikaf with the Messenger of Allah (ﷺ) in the middle ten days of Ramadan, and came out on the morning of the twentieth and the Messenger of Allah (ﷺ) addressed us and said: I was shown Lailat-ul-Qadr, but I forgot (the exact night) or I was caused to forget it, so seek it in the last ten odd (nights), and I was shown that I was prostrating in water and clay. So he who wanted to observe i'tikaf with the Messenger of Allah (ﷺ) should return (to the place of i'tikaf). He (Abu Sa'id al-Khudri) said: And we returned and did not find any patch of cloud in the sky. Then the cloud gathered and there was (so heavy) a downpour that the roof of the mosque which was made of the branches of date-palms began to drip. Then there was prayer and I saw the Messenger of Allah (ﷺ) prostrating in water and clay till I saw the traces of clay on his forehead}}
\hadithdefcmd{muslim}{2773}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ، بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ أَخْبَرَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنَا الأَوْزَاعِيُّ، كِلاَهُمَا عَنْ يَحْيَى بْنِ أَبِي، كَثِيرٍ بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ وَفِي حَدِيثِهِمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ انْصَرَفَ وَعَلَى جَبْهَتِهِ وَأَرْنَبَتِهِ أَثَرُ الطِّينِ ‏.‏\hadithno{2773}\hadithtrans{This hadith has been reported on the authority of Yahya b. Abu Kathir with the same chain of transmitters (with a slight variation of these words):I saw the Messenger of Allah (ﷺ) after he had completed (the prayer) and there was a trace of clay on his forehead and tip (of the nose)}}
\hadithdefcmd{muslim}{2774}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ قَالاَ حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، - رضى الله عنه - قَالَ اعْتَكَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْعَشْرَ الأَوْسَطَ مِنْ رَمَضَانَ يَلْتَمِسُ لَيْلَةَ الْقَدْرِ قَبْلَ أَنْ تُبَانَ لَهُ فَلَمَّا انْقَضَيْنَ أَمَرَ بِالْبِنَاءِ فَقُوِّضَ ثُمَّ أُبِينَتْ لَهُ أَنَّهَا فِي الْعَشْرِ الأَوَاخِرِ فَأَمَرَ بِالْبِنَاءِ فَأُعِيدَ ثُمَّ خَرَجَ عَلَى النَّاسِ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ إِنَّهَا كَانَتْ أُبِينَتْ لِي لَيْلَةُ الْقَدْرِ وَإِنِّي خَرَجْتُ لأُخْبِرَكُمْ بِهَا فَجَاءَ رَجُلاَنِ يَحْتَقَّانِ مَعَهُمَا الشَّيْطَانُ فَنُسِّيتُهَا فَالْتَمِسُوهَا فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ الْتَمِسُوهَا فِي التَّاسِعَةِ وَالسَّابِعَةِ وَالْخَامِسَةِ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا أَبَا سَعِيدٍ إِنَّكُمْ أَعْلَمُ بِالْعَدَدِ مِنَّا ‏.‏ قَالَ أَجَلْ ‏.‏ نَحْنُ أَحَقُّ بِذَلِكَ مِنْكُمْ ‏.‏ قَالَ قُلْتُ مَا التَّاسِعَةُ وَالسَّابِعَةُ وَالْخَامِسَةُ قَالَ إِذَا مَضَتْ وَاحِدَةٌ وَعِشْرُونَ فَالَّتِي تَلِيهَا ثِنْتَيْنِ وَعِشْرِينَ وَهْىَ التَّاسِعَةُ فَإِذَا مَضَتْ ثَلاَثٌ وَعِشْرُونَ فَالَّتِي تَلِيهَا السَّابِعَةُ فَإِذَا مَضَى خَمْسٌ وَعِشْرُونَ فَالَّتِي تَلِيهَا الْخَامِسَةُ .‏ وَقَالَ ابْنُ خَلاَّدٍ مَكَانَ يَحْتَقَّانِ يَخْتَصِمَانِ ‏.‏\hadithno{2774}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported:The Messenger of Allah (ﷺ) observed i'tikaf in the middle ten days of Ramadan to seek Lailat-ul-Qadr before it was made manifest to him. When (these nights) were over, he commanded to strike the tent. Then it was made manifest to him that (Lailat-ul-Qadr) was in the last ten nights (of Ramadan), and commanded to pitch the tent (again). He then came to the people and said: O people, Lailat-ul-Qadr was made manifest to me and I came out to inform you about it that two persons came contending with each other and there was a devil along with them and I forgot it. So seek it in the last ten nights of Ramadan. Seek it on the ninth, on the seventh and on the fifth. I (one of the narrators) said: Abu Sa'id, you know more than us about numbers. He said: Yes, indeed we have better right than you. I said: What is this ninth, seventh, and fifth? He said: When twenty-one (nights are over) and the twenty-second begins, it is the ninth, and when twenty-three (nights) are over, that which follows (the last night) is the seventh, and when twenty-five nights are over, what follows it is fifth. Ibn Khallad said: Instead of the word Yahliqan (contending), he said Yakhtasiman, (they are disputing)}}
\hadithdefcmd{muslim}{2775}{وَحَدَّثَنَا سَعِيدُ بْنُ عَمْرِو بْنِ سَهْلِ بْنِ إِسْحَاقَ بْنِ مُحَمَّدِ بْنِ الأَشْعَثِ بْنِ قَيْسٍ، الْكِنْدِيُّ وَعَلِيُّ بْنُ خَشْرَمٍ قَالاَ حَدَّثَنَا أَبُو ضَمْرَةَ، حَدَّثَنِي الضَّحَّاكُ بْنُ عُثْمَانَ، - وَقَالَ ابْنُ خَشْرَمٍ عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، - عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ بُسْرِ بْنِ، سَعِيدٍ عَنْ عَبْدِ اللَّهِ بْنِ أُنَيْسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أُرِيتُ لَيْلَةَ الْقَدْرِ ثُمَّ أُنْسِيتُهَا وَأَرَانِي صُبْحَهَا أَسْجُدُ فِي مَاءٍ وَطِينٍ ‏"‏ ‏.‏ قَالَ فَمُطِرْنَا لَيْلَةَ ثَلاَثٍ وَعِشْرِينَ فَصَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَانْصَرَفَ وَإِنَّ أَثَرَ الْمَاءِ وَالطِّينِ عَلَى جَبْهَتِهِ وَأَنْفِهِ ‏.‏ قَالَ وَكَانَ عَبْدُ اللَّهِ بْنُ أُنَيْسٍ يَقُولُ ثَلاَثٍ وَعِشْرِينَ ‏.‏\hadithno{2775}\hadithtrans{Abdullah b. Unais reported Allah's Messenger (ﷺ) as saying:I was shown Lailat-ul-Qadr; then I was made to forget it, and saw that I was prostrating in water and clay in the morning of that (night). He (the narrator) said: There was a downpour on the twenty-third night and the Messenger of Allah (ﷺ) led us in prayer, and as he went back, there was a trace of water and clay on his forehead and on his nose. He (the narrator) said: 'Abdullah b. Unais used to say that it was the twenty-third (night)}}
\hadithdefcmd{muslim}{2776}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، وَوَكِيعٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ابْنُ نُمَيْرٍ ‏ "‏ الْتَمِسُوا - وَقَالَ وَكِيعٌ - تَحَرَّوْا لَيْلَةَ الْقَدْرِ فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ ‏"‏ ‏.‏\hadithno{2776}\hadithtrans{A'isha (Allah be pleased with her) and Ibn Numair reported Allah's Messenger (ﷺ) as saying:Look for (and in the words of Waki, seek) Lailat-ul-Qadr in the last ten nights of Ramadan}}
\hadithdefcmd{muslim}{2777}{وَحَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ، وَابْنُ أَبِي عُمَرَ، كِلاَهُمَا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ ابْنُ حَاتِمٍ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنْ عَبْدَةَ، وَعَاصِمِ بْنِ أَبِي النَّجُودِ، سَمِعَا زِرَّ بْنَ حُبَيْشٍ، يَقُولُ سَأَلْتُ أُبَىَّ بْنَ كَعْبٍ - رضى الله عنه - فَقُلْتُ إِنَّ أَخَاكَ ابْنَ مَسْعُودٍ يَقُولُ مَنْ يَقُمِ الْحَوْلَ يُصِبْ لَيْلَةَ الْقَدْرِ ‏.‏ فَقَالَ رَحِمَهُ اللَّهُ أَرَادَ أَنْ لاَ يَتَّكِلَ النَّاسُ أَمَا إِنَّهُ قَدْ عَلِمَ أَنَّهَا فِي رَمَضَانَ وَأَنَّهَا فِي الْعَشْرِ الأَوَاخِرِ وَأَنَّهَا لَيْلَةُ سَبْعٍ وَعِشْرِينَ ‏.‏ ثُمَّ حَلَفَ لاَ يَسْتَثْنِي أَنَّهَا لَيْلَةُ سَبْعٍ وَعِشْرِينَ فَقُلْتُ بِأَىِّ شَىْءٍ تَقُولُ ذَلِكَ يَا أَبَا الْمُنْذِرِ قَالَ بِالْعَلاَمَةِ أَوْ بِالآيَةِ الَّتِي أَخْبَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّهَا تَطْلُعُ يَوْمَئِذٍ لاَ شُعَاعَ لَهَا ‏.‏\hadithno{2777}\hadithtrans{Zirr b. Habaish reported:I thu asked Ubayy b. Ka'b (Allah be pleased with him): Your brother (in faith) Ibn Mas'ud says: He who stands (for the night prayer) throughout the year would find Lailat-ul-Qadr, whereupon he said: May Allah have mercy upon him; (he said these words) with the intention that people might not rely only (on one night), whereas he knew that it (Lailat-ul-Qadr) is in the month of Ramadan and it is the twenty-seventh night. He then took oath (without making any exception, i. e. without saying In sha Allah) that it was the twenty-seventh night. I said to him: Abu Mundhir, on what ground do you say that? Thereupon he said: By the indication or by the sign which the Messenger of Allah (ﷺ) gave us, and that is that on that day (the sun) would rise without having any ray in it}}
\hadithdefcmd{muslim}{2778}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ عَبْدَةَ، بْنَ أَبِي لُبَابَةَ يُحَدِّثُ عَنْ زِرِّ بْنِ حُبَيْشٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، - رضى الله عنه - قَالَ قَالَ أُبَىٌّ فِي لَيْلَةِ الْقَدْرِ وَاللَّهِ إِنِّي لأَعْلَمُهَا - قَالَ شُعْبَةُ وَأَكْبَرُ عِلْمِي - هِيَ اللَّيْلَةُ الَّتِي أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِقِيَامِهَا هِيَ لَيْلَةُ سَبْعٍ وَعِشْرِينَ ‏.‏ وَإِنَّمَا شَكَّ شُعْبَةُ فِي هَذَا الْحَرْفِ هِيَ اللَّيْلَةُ الَّتِي أَمَرَنَا بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ وَحَدَّثَنِي بِهَا صَاحِبٌ لِي عَنْهُ ‏.‏\hadithno{2778}\hadithtrans{Zirr b. Hubaish reported that Ubayy b. Ka'b (Allah be pleased with him) said about Lailat-ul-Qadr:By Allah, I know well about it. Shu'ba said: To the best of my knowledge it was the twenty-seventh night for which the Messenger of Allah (ﷺ) commanded us to stand for prayer. Shu'ba doubted these words: That it was the night for which the Messenger of Allah (ﷺ) commanded us to stand for prayer. And (he further) said: This was narrated to me by a friend of mine from him (the Holy Prophet)}}
\hadithdefcmd{muslim}{2779}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا مَرْوَانُ، - وَهُوَ الْفَزَارِيُّ - عَنْ يَزِيدَ، - وَهُوَ ابْنُ كَيْسَانَ - عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، - رضى الله عنه - قَالَ تَذَاكَرْنَا لَيْلَةَ الْقَدْرِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَيُّكُمْ يَذْكُرُ حِينَ طَلَعَ الْقَمَرُ وَهُوَ مِثْلُ شِقِّ جَفْنَةٍ ‏"‏ ‏.‏\hadithno{2779}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:We were talking about Lailat-ul-Qadr in the presence of the Messenger of Allah (ﷺ) and he said: He who amongst you remembers (the night) when the moon arose and it was like a piece of plate (at the fag end of the month in a state of waning)}}
