% Auto-generated chapter 9 for tirmidhi
% Hadiths in this chapter: 157

\hadithdefcmd{tirmidhi}{809}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي شُرَيْحٍ الْعَدَوِيِّ، أَنَّهُ قَالَ لِعَمْرِو بْنِ سَعِيدٍ وَهُوَ يَبْعَثُ الْبُعُوثَ إِلَى مَكَّةَ ائْذَنْ لِي أَيُّهَا الأَمِيرُ أُحَدِّثْكَ قَوْلاً قَامَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم الْغَدَ مِنْ يَوْمِ الْفَتْحِ سَمِعَتْهُ أُذُنَاىَ وَوَعَاهُ قَلْبِي وَأَبْصَرَتْهُ عَيْنَاىَ حِينَ تَكَلَّمَ بِهِ أَنَّهُ حَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ إِنَّ مَكَّةَ حَرَّمَهَا اللَّهُ وَلَمْ يُحَرِّمْهَا النَّاسُ وَلاَ يَحِلُّ لاِمْرِئٍ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ يَسْفِكَ فِيهَا دَمًا أَوْ يَعْضِدَ بِهَا شَجَرَةً فَإِنْ أَحَدٌ تَرَخَّصَ بِقِتَالِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِيهَا فَقُولُوا لَهُ إِنَّ اللَّهَ أَذِنَ لِرَسُولِهِ صلى الله عليه وسلم وَلَمْ يَأْذَنْ لَكَ وَإِنَّمَا أَذِنَ لِي فِيهِ سَاعَةً مِنَ النَّهَارِ وَقَدْ عَادَتْ حُرْمَتُهَا الْيَوْمَ كَحُرْمَتِهَا بِالأَمْسِ وَلْيُبَلِّغِ الشَّاهِدُ الْغَائِبَ ‏"‏ ‏.‏ فَقِيلَ لأَبِي شُرَيْحٍ مَا قَالَ لَكَ عَمْرُو بْنُ سَعِيدٍ قَالَ أَنَا أَعْلَمُ مِنْكَ بِذَلِكَ يَا أَبَا شُرَيْحٍ إِنَّ الْحَرَمَ لاَ يُعِيذُ عَاصِيًا وَلاَ فَارًّا بِدَمٍ وَلاَ فَارًّا بِخَرْبَةٍ ‏.‏ قَالَ أَبُو عِيسَى وَيُرْوَى وَلاَ فَارًّا بِخِزْيَةٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي شُرَيْحٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو شُرَيْحٍ الْخُزَاعِيُّ اسْمُهُ خُوَيْلِدُ بْنُ عَمْرٍو وَهُوَ الْعَدَوِيُّ وَهُوَ الْكَعْبِيُّ ‏.‏ وَمَعْنَى قَوْلِهِ ‏"‏ وَلاَ فَارًّا بِخَرْبَةٍ ‏"‏ يَعْنِي الْجِنَايَةَ يَقُولُ مَنْ جَنَى جِنَايَةً أَوْ أَصَابَ دَمًا ثُمَّ لَجَأَ إِلَى الْحَرَمِ فَإِنَّهُ يُقَامُ عَلَيْهِ الْحَدُّ ‏.‏\hadithno{809}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sa'eed bin Abi Sa'eed Al Maqbury narrated:"Abu Shuraih Al-Adawi said tat when Amr bin Sa'eed was sending troops to Makkah he said to him: 'O Amr! Allow me to tell you what the Messenger of Allah said on the day following the Conquest of Makkah. My ears heard it, my heard understood it thoroughly, and with my own eyes, I saw the Prophet when he - after glorifying and praising Allah - said: "Indeed Allah, the Most High, made Makkah a sanctuary, it was not made a sanctuary by the people. So it is not lawful for a man who believes in Allah and the Last Day to shed blood it, nor to cut down its trees. If anybody tries to use the Messenger of Allah to make an excuse for fighting in it, then say to him: 'Indeed Allah permitted His Messenger and He did not permit you.' Allah only allowed it for me for a few hours of one day, and today its sanctity has returned as it was before. So let the one who is present convey to the one who is absent." Abu Shuraih was asked: "What was Amr bin Sa'eeds reply to you?" He said: "I am more knowledgeable about that than you Abu Shuraih! The Haram does not give protection to a disobedient person, nor a person fleeing for murder, nor fleeing for (Kharbah) lawlessness}}
\hadithdefcmd{tirmidhi}{810}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ عَمْرِو بْنِ قَيْسٍ، عَنْ عَاصِمٍ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَابِعُوا بَيْنَ الْحَجِّ وَالْعُمْرَةِ فَإِنَّهُمَا يَنْفِيَانِ الْفَقْرَ وَالذُّنُوبَ كَمَا يَنْفِي الْكِيرُ خَبَثَ الْحَدِيدِ وَالذَّهَبِ وَالْفِضَّةِ وَلَيْسَ لِلْحَجَّةِ الْمَبْرُورَةِ ثَوَابٌ إِلاَّ الْجَنَّةُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَعَامِرِ بْنِ رَبِيعَةَ وَأَبِي هُرَيْرَةَ وَعَبْدِ اللَّهِ بْنِ حُبْشِيٍّ وَأُمِّ سَلَمَةَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ مَسْعُودٍ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ‏.‏\hadithno{810}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah (bin Mas'ud) narrated that:The Messenger of Allah said: "Alternate between Hajj and Umrah; for those two remove poverty and sins just as the bellows removes filth from iron, gold, and silver - and there is no reward for Al-Hajj Al-Mabrur except for Paradise}}
\hadithdefcmd{tirmidhi}{811}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مَنْصُورٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حَجَّ فَلَمْ يَرْفُثْ وَلَمْ يَفْسُقْ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو حَازِمٍ كُوفِيٌّ وَهُوَ الأَشْجَعِيُّ وَاسْمُهُ سَلْمَانُ مَوْلَى عَزَّةَ الأَشْجَعِيَّةِ ‏.‏\hadithno{811}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :The Messenger of Allah said: "Whoever performs Hajj for Allah, and he does not have sexual relations nor commit any sin, then his previous sins will be forgiven}}
\hadithdefcmd{tirmidhi}{812}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الْقُطَعِيُّ الْبَصْرِيُّ، حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِلاَلُ بْنُ عَبْدِ اللَّهِ، مَوْلَى رَبِيعَةَ بْنِ عَمْرِو بْنِ مُسْلِمٍ الْبَاهِلِيِّ حَدَّثَنَا أَبُو إِسْحَاقَ الْهَمْدَانِيُّ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ مَلَكَ زَادًا وَرَاحِلَةً تُبَلِّغُهُ إِلَى بَيْتِ اللَّهِ وَلَمْ يَحُجَّ فَلاَ عَلَيْهِ أَنْ يَمُوتَ يَهُودِيًّا أَوْ نَصْرَانِيًّا وَذَلِكَ أَنَّ اللَّهَ يَقُولُ فِي كِتَابِهِ ‏:‏ ‏(‏وَلِلَّهِ عَلَى النَّاسِ حِجُّ الْبَيْتِ مَنِ اسْتَطَاعَ إِلَيْهِ سَبِيلاً ‏)‏ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَفِي إِسْنَادِهِ مَقَالٌ ‏.‏ وَهِلاَلُ بْنُ عَبْدِ اللَّهِ مَجْهُولٌ وَالْحَارِثُ يُضَعَّفُ فِي الْحَدِيثِ ‏.‏\hadithno{812}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ali narrated that :The Messenger of Allah said: "Whoever has the provisions and the means to convey him to Allah's House and he does not perform Hajj, then it does not matter if he dies as a Jew or a Christian. That is because Allah said in His Book: 'And Hajj to the House is a duty that mankind owes to Allah, for whomever is able to bear the journey}}
\hadithdefcmd{tirmidhi}{813}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَزِيدَ، عَنْ مُحَمَّدِ بْنِ عَبَّادِ بْنِ جَعْفَرٍ، عَنِ ابْنِ عُمَرَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ مَا يُوجِبُ الْحَجَّ قَالَ ‏ "‏ الزَّادُ وَالرَّاحِلَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ أَنَّ الرَّجُلَ إِذَا مَلَكَ زَادًا وَرَاحِلَةً وَجَبَ عَلَيْهِ الْحَجُّ ‏.‏ وَإِبْرَاهِيمُ بْنُ يَزِيدَ هُوَ الْخُوزِيُّ الْمَكِّيُّ وَقَدْ تَكَلَّمَ فِيهِ بَعْضُ أَهْلِ الْعِلْمِ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{813}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated:"A man came to the Prophet and said: 'O Messenger of Allah! What is it that makes Hajj obligatory?' He said: "The provisions and a means of conveyance}}
\hadithdefcmd{tirmidhi}{814}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا مَنْصُورُ بْنُ وَرْدَانَ، عَنْ عَلِيِّ بْنِ عَبْدِ الأَعْلَى، عَنْ أَبِيهِ، عَنْ أَبِي الْبَخْتَرِيِّ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ لَمَّا نَزَلَتْ ‏(‏ وَلِلَّهِ عَلَى النَّاسِ حِجُّ الْبَيْتِ مَنِ اسْتَطَاعَ إِلَيْهِ سَبِيلاً ‏)‏ قَالُوا يَا رَسُولَ اللَّهِ أَفِي كُلِّ عَامٍ فَسَكَتَ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ أَفِي كُلِّ عَامٍ قَالَ ‏"‏ لاَ وَلَوْ قُلْتُ نَعَمْ لَوَجَبَتْ ‏"‏ ‏.‏ فَأَنْزَلَ اللَّهُ ‏:‏ ‏(‏يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَسْأَلُوا عَنْ أَشْيَاءَ إِنْ تُبْدَ لَكُمْ تَسُؤْكُمْ ‏)‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَاسْمُ أَبِي الْبَخْتَرِيِّ سَعِيدُ بْنُ أَبِي عِمْرَانَ وَهُوَ سَعِيدُ بْنُ فَيْرُوزَ ‏.‏\hadithno{814}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ali bin Abi Talib narrated:"When Allah revealed: And Hajj to the House is a duty that mankind owes to Allah, for whomever is able to bear the journey. They said: 'O Messenger of Allah! Is that every year?' He remained silent. So they said: 'O Messenger of Allah! Is that every year?' He said: 'No. If I had said yes, then it would have been made obligatory.' So Allah revealed: O you who believe! Do not ask about things which, if made plain to you, may cause you trouble}}
\hadithdefcmd{tirmidhi}{815}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ الْكُوفِيُّ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ سُفْيَانَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم حَجَّ ثَلاَثَ حِجَجٍ حَجَّتَيْنِ قَبْلَ أَنْ يُهَاجِرَ وَحَجَّةً بَعْدَ مَا هَاجَرَ وَمَعَهَا عُمْرَةٌ فَسَاقَ ثَلاَثًا وَسِتِّينَ بَدَنَةً وَجَاءَ عَلِيٌّ مِنَ الْيَمَنِ بِبَقِيَّتِهَا فِيهَا جَمَلٌ لأَبِي جَهْلٍ فِي أَنْفِهِ بُرَةٌ مِنْ فِضَّةٍ فَنَحَرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ كُلِّ بَدَنَةٍ بِبَضْعَةٍ فَطُبِخَتْ وَشَرِبَ مِنْ مَرَقِهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ سُفْيَانَ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ زَيْدِ بْنِ حُبَابٍ ‏.‏ وَرَأَيْتُ عَبْدَ اللَّهِ بْنَ عَبْدِ الرَّحْمَنِ رَوَى هَذَا الْحَدِيثَ فِي كُتُبِهِ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي زِيَادٍ ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا فَلَمْ يَعْرِفْهُ مِنْ حَدِيثِ الثَّوْرِيِّ عَنْ جَعْفَرٍ عَنْ أَبِيهِ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرَأَيْتُهُ لاَ يَعُدُّ هَذَا الْحَدِيثَ مَحْفُوظًا ‏.‏ وَقَالَ إِنَّمَا يُرْوَى عَنِ الثَّوْرِيِّ عَنْ أَبِي إِسْحَاقَ عَنْ مُجَاهِدٍ مُرْسَلاً ‏.‏\hadithno{815}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Jabir bin Abdullah narrated:"The Prophet performed Hajj three times. He performed Hajj twice before his emigration, and he performed one Hajj after he emigrated, and these were accompanied by Umrah. So he drove sixty-three sacrificial animals (Budn) and Ali came from Yemen with the rest of them, among them was a camel of Abu Jahl that has a ring made of silver in its nose. So he (the Messenger of Allah) slaughtered the, and the Messenger of Allah ordered that a piece of each of them be cooked, and he drank from its broth}}
\hadithdefcmd{tirmidhi}{815p2}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، قَالَ قُلْتُ لأَنَسِ بْنِ مَالِكٍ كَمْ حَجَّ النَّبِيُّ صلى الله عليه وسلم قَالَ حَجَّةٌ وَاحِدَةٌ وَاعْتَمَرَ أَرْبَعَ عُمَرٍ عُمْرَةٌ فِي ذِي الْقَعْدَةِ وَعُمْرَةُ الْحُدَيْبِيَةِ وَعُمْرَةٌ مَعَ حَجَّتِهِ وَعُمْرَةُ الْجِعِرَّانَةِ إِذْ قَسَّمَ غَنِيمَةَ حُنَيْنٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَحَبَّانُ بْنُ هِلاَلٍ هُوَ أَبُو حَبِيبٍ الْبَصْرِيُّ هُوَ جَلِيلٌ ثِقَةٌ وَثَّقَهُ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ ‏.‏\hadithno{815.2}\hadithtrans{Qatadah narrated:"I said to Anas bin Malik: 'How many times did the Prophet perform Hajj?' He said: 'He performed one Hajj and he performed four Umrah: An Umrah during Dhul-Qa'dah; the Umrah of Al-Hudaibiyah, and Umrah with his Hajj, and an Umrah from Al-Ji'irranah when he divided up the war spoils of Hunain}}
\hadithdefcmd{tirmidhi}{816}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا دَاوُدُ بْنُ عَبْدِ الرَّحْمَنِ الْعَطَّارُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اعْتَمَرَ أَرْبَعَ عُمَرٍ عُمْرَةَ الْحُدَيْبِيَةِ وَعُمْرَةَ الثَّانِيَةِ مِنْ قَابِلٍ وَعُمْرَةَ الْقَضَاءِ فِي ذِي الْقَعْدَةِ وَعُمْرَةَ الثَّالِثَةِ مِنَ الْجِعِرَّانَةِ وَالرَّابِعَةِ الَّتِي مَعَ حَجَّتِهِ.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَرَوَى ابْنُ عُيَيْنَةَ، هَذَا الْحَدِيثَ عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عِكْرِمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اعْتَمَرَ أَرْبَعَ عُمَرٍ ‏.‏ وَلَمْ يَذْكُرْ فِيهِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ حَدَّثَنَا بِذَلِكَ سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ عَنْ عَمْرِو بْنِ دِينَارٍ عَنْ عِكْرِمَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{816}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Abbas narrared:"The Messenger of Allah performed four Umrah: The Umrah of Al-Hudaibiyah, a second Umrah the following (year), (which was) the Umrah of Al-Qisas during Dhul-Qa'dah, a third Umrah from Al-Ji'irranah, and the fourth which accompanied his Hajj}}
\hadithdefcmd{tirmidhi}{817}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ لَمَّا أَرَادَ النَّبِيُّ صلى الله عليه وسلم الْحَجَّ أَذَّنَ فِي النَّاسِ فَاجْتَمَعُوا فَلَمَّا أَتَى الْبَيْدَاءَ أَحْرَمَ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَنَسٍ وَالْمِسْوَرِ بْنِ مَخْرَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{817}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir bin Abdullah narrated:"When the Prophet wanted to Perform Hajj, he announced it to the people, and they gathered (to accompany him). When he reached Al-Baida he assumed Ihram}}
\hadithdefcmd{tirmidhi}{818}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ ابْنِ عُمَرَ، قَالَ الْبَيْدَاءُ الَّتِي يَكْذِبُونَ فِيهَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَاللَّهِ مَا أَهَلَّ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلاَّ مِنْ عِنْدِ الْمَسْجِدِ مِنْ عِنْدِ الشَّجَرَةِ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{818}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated:"Al-Baida the one they lie about regarding the Messenger of Allah. By Allah! The Messenger of Allah did not start the Talbiyah except from near the Masjid, near the tree}}
\hadithdefcmd{tirmidhi}{819}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، عَنْ خُصَيْفٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَهَلَّ فِي دُبُرِ الصَّلاَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُ أَحَدًا رَوَاهُ غَيْرَ عَبْدِ السَّلاَمِ بْنِ حَرْبٍ ‏.‏ وَهُوَ الَّذِي يَسْتَحِبُّهُ أَهْلُ الْعِلْمِ أَنْ يُحْرِمَ الرَّجُلُ فِي دُبُرِ الصَّلاَةِ ‏.‏\hadithno{819}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"The Prophet started the Talbiyah after the Salat}}
\hadithdefcmd{tirmidhi}{820}{حَدَّثَنَا أَبُو مُصْعَبٍ، قِرَاءَةً عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَفْرَدَ الْحَجَّ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ ‏.‏ وَرُوِيَ عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَفْرَدَ الْحَجَّ وَأَفْرَدَ أَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ ‏.‏ حَدَّثَنَا بِذَلِكَ قُتَيْبَةُ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ الصَّائِغُ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ بِهَذَا ‏.‏ قَالَ أَبُو عِيسَى وَقَالَ الثَّوْرِيُّ إِنْ أَفْرَدْتَ الْحَجَّ فَحَسَنٌ وَإِنْ قَرَنْتَ فَحَسَنٌ وَإِنْ تَمَتَّعْتَ فَحَسَنٌ ‏.‏ وَقَالَ الشَّافِعِيُّ مِثْلَهُ ‏.‏ وَقَالَ أَحَبُّ إِلَيْنَا الإِفْرَادُ ثُمَّ التَّمَتُّعُ ثُمَّ الْقِرَانُ ‏.‏\hadithno{820}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Hasan Isnaad; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated:"the Messenger of Allah performed the Ifrad form of Hajj}}
\hadithdefcmd{tirmidhi}{821}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَبَّيْكَ بِعُمْرَةٍ وَحَجَّةٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَعِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا ‏.‏ وَاخْتَارُوهُ مِنْ أَهْلِ الْكُوفَةِ وَغَيْرِهِمْ ‏.‏\hadithno{821}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas narrated:"I heard the Prophet saying: (Labbaika Bi'umratin wa Hajjah) 'Here I am for 'Umrah and Hajj}}
\hadithdefcmd{tirmidhi}{822}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ لَيْثٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ تَمَتَّعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ وَأَوَّلُ مَنْ نَهَى عَنْهَا مُعَاوِيَةُ ‏\hadithno{822}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"The Messenger of Allah performed Tamattu, as did Abu Bakr, Umar and Uthman. And the first to prohibit it was Mu'awiyah}}
\hadithdefcmd{tirmidhi}{823}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ نَوْفَلٍ، أَنَّهُ سَمِعَ سَعْدَ بْنَ أَبِي وَقَّاصٍ، وَالضَّحَّاكَ بْنَ قَيْسٍ، وَهُمَا، يَذْكُرَانِ التَّمَتُّعَ بِالْعُمْرَةِ إِلَى الْحَجِّ فَقَالَ الضَّحَّاكُ بْنُ قَيْسٍ لاَ يَصْنَعُ ذَلِكَ إِلاَّ مَنْ جَهِلَ أَمْرَ اللَّهِ ‏.‏ فَقَالَ سَعْدٌ بِئْسَ مَا قُلْتَ يَا ابْنَ أَخِي ‏.‏ فَقَالَ الضَّحَّاكُ بْنُ قَيْسٍ فَإِنَّ عُمَرَ بْنَ الْخَطَّابِ قَدْ نَهَى عَنْ ذَلِكَ ‏.‏ فَقَالَ سَعْدٌ قَدْ صَنَعَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَصَنَعْنَاهَا مَعَهُ ‏.‏ قَالَ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{823}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Sahih Isnaad; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Muhammad bin Abdullah bin Al-Harith bin Nawfal narrated that:He heard Sa'd bin Abi Waqas, and Ad-Dahhak bin Qais while they were mentioning Tamattu after "Umrah until Hajj. Ad-Dahhak bin Qais said: "No one does that except one who is ignorant of the order of Allah, Most High." Sa'd said: "How horrible is it what you have said O my nephew!" So Ad-Dahhak (bin Qais) said: "Indeed Umar bin Al-Khattab has prohibited that." So Sa'd said: "The Messenger of Allah did it, and we did it with him}}
\hadithdefcmd{tirmidhi}{824}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَالِمَ بْنَ عَبْدِ اللَّهِ، حَدَّثَهُ أَنَّهُ، سَمِعَ رَجُلاً، مِنْ أَهْلِ الشَّامِ وَهُوَ يَسْأَلُ عَبْدَ اللَّهِ بْنَ عُمَرَ عَنِ التَّمَتُّعِ بِالْعُمْرَةِ إِلَى الْحَجِّ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ هِيَ حَلاَلٌ ‏.‏ فَقَالَ الشَّامِيُّ إِنَّ أَبَاكَ قَدْ نَهَى عَنْهَا ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ أَرَأَيْتَ إِنْ كَانَ أَبِي نَهَى عَنْهَا وَصَنَعَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَأَمْرَ أَبِي نَتَّبِعُ أَمْ أَمْرَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ الرَّجُلُ بَلْ أَمْرَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ لَقَدْ صَنَعَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعُثْمَانَ وَجَابِرٍ وَسَعْدٍ وَأَسْمَاءَ بِنْتِ أَبِي بَكْرٍ وَابْنِ عُمَرَ ‏.‏ وَقَدِ اخْتَارَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمُ التَّمَتُّعَ بِالْعُمْرَةِ ‏.‏ وَالتَّمَتُّعُ أَنْ يَدْخُلَ الرَّجُلُ بِعُمْرَةٍ فِي أَشْهُرِ الْحَجِّ ثُمَّ يُقِيمَ حَتَّى يَحُجَّ فَهُوَ مُتَمَتِّعٌ وَعَلَيْهِ دَمٌ مَا اسْتَيْسَرَ مِنَ الْهَدْىِ فَإِنْ لَمْ يَجِدْ صَامَ ثَلاَثَةَ أَيَّامٍ فِي الْحَجِّ وَسَبْعَةً إِذَا رَجَعَ إِلَى أَهْلِهِ وَيُسْتَحَبُّ لِلْمُتَمَتِّعِ إِذَا صَامَ ثَلاَثَةَ أَيَّامٍ فِي الْحَجِّ أَنْ يَصُومَ فِي الْعَشْرِ وَيَكُونَ آخِرُهَا يَوْمَ عَرَفَةَ فَإِنْ لَمْ يَصُمْ فِي الْعَشْرِ صَامَ أَيَّامَ التَّشْرِيقِ فِي قَوْلِ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمُ ابْنُ عُمَرَ وَعَائِشَةُ وَبِهِ يَقُولُ مَالِكٌ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ يَصُومُ أَيَّامَ التَّشْرِيقِ ‏.‏ وَهُوَ قَوْلُ أَهْلِ الْكُوفَةِ ‏.‏ قَالَ أَبُو عِيسَى وَأَهْلُ الْحَدِيثِ يَخْتَارُونَ التَّمَتُّعَ بِالْعُمْرَةِ فِي الْحَجِّ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{824}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Salim bin Abdullah narrated that :he had heard a man from Ash-Sham asking Abdullah bin Umar about Tamattu after Umrah until Hajj, so Abdullah bin Umar said: "It is lawful." The man from Ash-Sham said: "But your father prohibited it." So Abdullah bin Umar said: "Is the order to follow my father or is the order (to follow) for the Messenger of Allah?" The man said: "Rather it is for the Messenger of Allah." So he said: "Indeed the Messenger of Allah did it}}
\hadithdefcmd{tirmidhi}{825}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ تَلْبِيَةَ النَّبِيِّ، صلى الله عليه وسلم كَانَتْ ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَجَابِرٍ وَعَائِشَةَ وَابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَهُوَ قَوْلُ سُفْيَانَ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ قَالَ الشَّافِعِيُّ وَإِنْ زَادَ فِي التَّلْبِيَةِ شَيْئًا مِنْ تَعْظِيمِ اللَّهِ فَلاَ بَأْسَ إِنْ شَاءَ اللَّهُ وَأَحَبُّ إِلَىَّ أَنْ يَقْتَصِرَ عَلَى تَلْبِيَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ الشَّافِعِيُّ وَإِنَّمَا قُلْنَا لاَ بَأْسَ بِزِيَادَةِ تَعْظِيمِ اللَّهِ فِيهَا لِمَا جَاءَ عَنِ ابْنِ عُمَرَ وَهُوَ حَفِظَ التَّلْبِيَةَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ زَادَ ابْنُ عُمَرَ فِي تَلْبِيَتِهِ مِنْ قِبَلِهِ لَبَّيْكَ وَالرَّغْبَاءُ إِلَيْكَ وَالْعَمَلُ ‏.‏\hadithno{825}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Umar narrated:"The Prophet would say the following for the Talbiyah: "Labbaik Allahumma labbaik. Labbaik la sharika laka labbaik. Innal-hamda wan-ni;mata laka wal-mulk, la sharika laka." ('I respond to Your call O Allah! I respond to Your call. You have no partner. I respond to Your call. All praise, thanks and blessings are for You. All sovereignty is for You. And You have no partners with You)}}
\hadithdefcmd{tirmidhi}{826}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ أَهَلَّ فَانْطَلَقَ يُهِلُّ فَيَقُولُ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ لاَ شَرِيكَ لَكَ لَبَّيْكَ إِنَّ الْحَمْدَ وَالنِّعْمَةَ لَكَ وَالْمُلْكَ لاَ شَرِيكَ لَكَ ‏.‏ قَالَ وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ يَقُولُ هَذِهِ تَلْبِيَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ وَكَانَ يَزِيدُ مِنْ عِنْدِهِ فِي أَثَرِ تَلْبِيَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم لَبَّيْكَ لَبَّيْكَ وَسَعْدَيْكَ وَالْخَيْرُ فِي يَدَيْكَ لَبَّيْكَ وَالرَّغْبَاءُ إِلَيْكَ وَالْعَمَلُ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{826}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Nafi` narrated:When Ibn Umar would say the talbiyah he would continue saying: "Labbaik Allahumma labbaik. Labbaik la sharika laka labbaik. Innal-hamda wan-ni`mata laka wal-mulk, la sharika laka" (I respond to Your call O Allah! I respond to Your call, You have no partner, I respond to You call. All praise, thanks and blessings are for You. And You have no partners with You). He said: "Abdullah bin Umar would say: 'This is the Talbiyah of the Messenger of Allah.' He would himself add the following after the Talbiyah of the Messenger of Allah: "Labbaik labbaika wa-sa'daik, wal-khairuu fi yadaik. Labbaika war-raghba'u ilaika wal-amal" ('I respond to Your call, and I am obedient to Your orders, all good is in Your Hands. I respond to Your call and the requests and deeds are for You)}}
\hadithdefcmd{tirmidhi}{827}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَرْبُوعٍ، عَنْ أَبِي بَكْرٍ الصِّدِّيقِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ أَىُّ الْحَجِّ أَفْضَلُ قَالَ ‏ "‏ الْعَجُّ وَالثَّجُّ ‏"‏ ‏.‏\hadithno{827}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Bakr As-Siddiq narrated that:The Messenger of Allah was asked: "Which Hajj is the most virtuous?" He said: "That with raised voices (Al-Ajj) and the flow of blood (of the sacrifice) (Ath-Thajj)}}
\hadithdefcmd{tirmidhi}{828}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ مُسْلِمٍ يُلَبِّي إِلاَّ لَبَّى مَنْ عَنْ يَمِينِهِ أَوْ عَنْ شِمَالِهِ مِنْ حَجَرٍ أَوْ شَجَرٍ أَوْ مَدَرٍ حَتَّى تَنْقَطِعَ الأَرْضُ مِنْ هَا هُنَا وَهَا هُنَا ‏"‏ ‏.‏ حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، وَعَبْدُ الرَّحْمَنِ بْنُ الأَسْوَدِ أَبُو عَمْرٍو الْبَصْرِيُّ، قَالاَ حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ إِسْمَاعِيلَ بْنِ عَيَّاشٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي بَكْرٍ حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ابْنِ أَبِي فُدَيْكٍ عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ ‏.‏ وَمُحَمَّدُ بْنُ الْمُنْكَدِرِ لَمْ يَسْمَعْ مِنْ عَبْدِ الرَّحْمَنِ بْنِ يَرْبُوعٍ وَقَدْ رَوَى مُحَمَّدُ بْنُ الْمُنْكَدِرِ عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَرْبُوعٍ عَنْ أَبِيهِ غَيْرَ هَذَا الْحَدِيثِ ‏.‏ وَرَوَى أَبُو نُعَيْمٍ الطَّحَّانُ ضِرَارُ بْنُ صُرَدٍ هَذَا الْحَدِيثَ عَنِ ابْنِ أَبِي فُدَيْكٍ عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَرْبُوعٍ عَنْ أَبِيهِ عَنْ أَبِي بَكْرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَأَخْطَأَ فِيهِ ضِرَارٌ ‏.‏ قَالَ أَبُو عِيسَى سَمِعْتُ أَحْمَدَ بْنَ الْحَسَنِ يَقُولُ قَالَ أَحْمَدُ بْنُ حَنْبَلٍ مَنْ قَالَ فِي هَذَا الْحَدِيثِ عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ عَنِ ابْنِ عَبْدِ الرَّحْمَنِ بْنِ يَرْبُوعٍ عَنْ أَبِيهِ فَقَدْ أَخْطَأَ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدًا يَقُولُ وَذَكَرْتُ لَهُ حَدِيثَ ضِرَارِ بْنِ صُرَدٍ عَنِ ابْنِ أَبِي فُدَيْكٍ فَقَالَ هُوَ خَطَأٌ ‏.‏ فَقُلْتُ قَدْ رَوَاهُ غَيْرُهُ عَنِ ابْنِ أَبِي فُدَيْكٍ أَيْضًا مِثْلَ رِوَايَتِهِ ‏.‏ فَقَالَ لاَ شَىْءَ إِنَّمَا رَوَوْهُ عَنِ ابْنِ أَبِي فُدَيْكٍ وَلَمْ يَذْكُرُوا فِيهِ عَنْ سَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ ‏.‏ وَرَأَيْتُهُ يُضَعِّفُ ضِرَارَ بْنَ صُرَدٍ ‏.‏ وَالْعَجُّ هُوَ رَفْعُ الصَّوْتِ بِالتَّلْبِيَةِ ‏.‏ وَالثَّجُّ هُوَ نَحْرُ الْبُدْنِ ‏.‏\hadithno{828}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sahl bin Sa'd narrated that :the Messenger of Allah said: "There is no Muslim who says the Talbiyah except that - on his right and left, until the end f the land, from here to there - the rocks, or trees, or mud say the Talbiyah}}
\hadithdefcmd{tirmidhi}{829}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، وَهُوَ ابْنُ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ خَلاَّدِ بْنِ السَّائِبِ بْنِ خَلاَّدٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَتَانِي جِبْرِيلُ فَأَمَرَنِي أَنْ آمُرَ أَصْحَابِي أَنْ يَرْفَعُوا أَصْوَاتَهُمْ بِالإِهْلاَلِ وَالتَّلْبِيَةِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ زَيْدِ بْنِ خَالِدٍ وَأَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ خَلاَّدٍ عَنْ أَبِيهِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ خَلاَّدِ بْنِ السَّائِبِ عَنْ زَيْدِ بْنِ خَالِدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَلاَ يَصِحُّ وَالصَّحِيحُ هُوَ عَنْ خَلاَّدِ بْنِ السَّائِبِ عَنْ أَبِيهِ ‏.‏ وَهُوَ خَلاَّدُ بْنُ السَّائِبِ بْنِ خَلاَّدِ بْنِ سُوَيْدٍ الأَنْصَارِيُّ عَنْ أَبِيهِ\hadithno{829}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Khallad bin As-Sa'ib (bin Khalad) narrated from his father:Who said that the Messenger of Allah said: "Jibril came to me and ordered me to order my Companions to raise their voices with the Ihlal, or; the Talbiyah}}
\hadithdefcmd{tirmidhi}{830}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَعْقُوبَ الْمَدَنِيُّ، عَنِ ابْنِ أَبِي الزِّنَادِ، عَنْ أَبِيهِ، عَنْ خَارِجَةَ بْنِ زَيْدِ بْنِ ثَابِتٍ، عَنْ أَبِيهِ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم تَجَرَّدَ لإِهْلاَلِهِ وَاغْتَسَلَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدِ اسْتَحَبَّ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ الاِغْتِسَالَ عِنْدَ الإِحْرَامِ وَبِهِ يَقُولُ الشَّافِعِيُّ ‏.‏\hadithno{830}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Zaid bin Thabit narrated from his father :who said that he saw the Prophet disrobing for his Ihlal and to perform Ghusl}}
\hadithdefcmd{tirmidhi}{831}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، قَالَ مِنْ أَيْنَ نُهِلُّ يَا رَسُولَ اللَّهِ فَقَالَ ‏ "‏ يُهِلُّ أَهْلُ الْمَدِينَةِ مِنْ ذِي الْحُلَيْفَةِ وَأَهْلُ الشَّامِ مِنَ الْجُحْفَةِ وَأَهْلُ نَجْدٍ مِنْ قَرْنٍ ‏"‏ ‏.‏ قَالَ وَيَقُولُونَ وَأَهْلُ الْيَمَنِ مِنْ يَلَمْلَمَ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَجَابِرِ بْنِ عَبْدِ اللَّهِ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{831}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Umar narrated that:A man said: "Where should we begin our Hil (Ihram) O Messenger of Allah?" He said: "The people of Al-Madinah begin their Hil (Ihram) from Dhul-Hulaifah, the people from Ash-Sham from Al-Juhfah, and the people of Najd from Qarn." And he (Ibn Umar) said: ("And they say:) "And the people of Yemen from Yalamlam}}
\hadithdefcmd{tirmidhi}{832}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ مُحَمَّدِ بْنِ عَلِيٍّ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَقَّتَ لأَهْلِ الْمَشْرِقِ الْعَقِيقَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَمُحَمَّدُ بْنُ عَلِيٍّ هُوَ أَبُو جَعْفَرٍ مُحَمَّدُ بْنُ عَلِيِّ بْنِ حُسَيْنِ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ ‏.‏\hadithno{832}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"The Prophet made Al-Aqiq the Miqat for the people of the west}}
\hadithdefcmd{tirmidhi}{833}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ قَالَ قَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ مَاذَا تَأْمُرُنَا أَنْ نَلْبَسَ مِنَ الثِّيَابِ فِي الْحَرَمِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَلْبَسُوا الْقُمُصَ وَلاَ السَّرَاوِيلاَتِ وَلاَ الْبَرَانِسَ وَلاَ الْعَمَائِمَ وَلاَ الْخِفَافَ إِلاَّ أَنْ يَكُونَ أَحَدٌ لَيْسَتْ لَهُ نَعْلاَنِ فَلْيَلْبَسِ الْخُفَّيْنِ وَلْيَقْطَعْهُمَا مَا أَسْفَلَ مِنَ الْكَعْبَيْنِ وَلاَ تَلْبَسُوا شَيْئًا مِنَ الثِّيَابِ مَسَّهُ الزَّعْفَرَانُ وَلاَ الْوَرْسُ وَلاَ تَنْتَقِبِ الْمَرْأَةُ الْحَرَامُ وَلاَ تَلْبَسِ الْقُفَّازَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{833}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Umar narrated:"A man stood and said 'O Messenger of Allah! What clothing do you command us to wear in Al-Haram?' The Messenger of Allah said: 'Do not wear shirts, nor pants, nor burnooses, nor turbans, nor Khuff - unless one does not have any sandals, then let him wear Khuff, but let him cut them below the ankles. And do not wear any cloth that has been touched by saffron or Wars. And the woman in Ihram is not to cover her face, nor wear gloves}}
\hadithdefcmd{tirmidhi}{834}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ الْبَصْرِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا أَيُّوبُ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ الْمُحْرِمُ إِذَا لَمْ يَجِدِ الإِزَارَ فَلْيَلْبَسِ السَّرَاوِيلَ وَإِذَا لَمْ يَجِدِ النَّعْلَيْنِ فَلْيَلْبَسِ الْخُفَّيْنِ ‏"‏ ‏.‏ حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرٍو، نَحْوَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ، وَجَابِرٍ، ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ قَالُوا إِذَا لَمْ يَجِدِ الْمُحْرِمُ الإِزَارَ لَبِسَ السَّرَاوِيلَ وَإِذَا لَمْ يَجِدِ النَّعْلَيْنِ لَبِسَ الْخُفَّيْنِ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ ‏.‏ وَقَالَ بَعْضُهُمْ عَلَى حَدِيثِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ إِذَا لَمْ يَجِدْ نَعْلَيْنِ فَلْيَلْبَسِ الْخُفَّيْنِ وَلْيَقْطَعْهُمَا أَسْفَلَ مِنَ الْكَعْبَيْنِ ‏"‏ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَبِهِ يَقُولُ مَالِكٌ ‏.‏\hadithno{834}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Abbas narrated that:He heard the Messenger of Allah say: "If the Muhrim cannot find an Izar, then let him wear pants, and if he cannot find sandals, them let him wear Khuff}}
\hadithdefcmd{tirmidhi}{835}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنْ يَعْلَى بْنِ أُمَيَّةَ، قَالَ رَأَى النَّبِيُّ صلى الله عليه وسلم أَعْرَابِيًّا قَدْ أَحْرَمَ وَعَلَيْهِ جُبَّةٌ فَأَمَرَهُ أَنْ يَنْزِعَهَا ‏.‏\hadithno{835}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ya'la bin Umayyah narrated:"The Messenger of Allah saw a Bedouin who was in Ihram wearing a cloak. So he ordered him to remove it}}
\hadithdefcmd{tirmidhi}{836}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءٍ، عَنْ صَفْوَانَ بْنِ يَعْلَى، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِمَعْنَاهُ ‏.‏ وَهَذَا أَصَحُّ وَفِي الْحَدِيثِ قِصَّةٌ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رَوَاهُ قَتَادَةُ وَالْحَجَّاجُ بْنُ أَرْطَاةَ وَغَيْرُ وَاحِدٍ عَنْ عَطَاءٍ عَنْ يَعْلَى بْنِ أُمَيَّةَ ‏.‏ وَالصَّحِيحُ مَا رَوَى عَمْرُو بْنُ دِينَارٍ وَابْنُ جُرَيْجٍ عَنْ عَطَاءٍ عَنْ صَفْوَانَ بْنِ يَعْلَى عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{836}\hadithgrade{Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ya'la bin Umayyah narrated:A Hadith similar to no. 835 with a different chain}}
\hadithdefcmd{tirmidhi}{837}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَمْسُ فَوَاسِقَ يُقْتَلْنَ فِي الْحَرَمِ الْفَأْرَةُ وَالْعَقْرَبُ وَالْغُرَابُ وَالْحُدَيَّا وَالْكَلْبُ الْعَقُورُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَابْنِ عُمَرَ وَأَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{837}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated that :the Messenger of Allah said: "Five are Fawasiq which may be killed in the Haram: the mouse, the scorpion, the crow, the kite, and the barbed dog}}
\hadithdefcmd{tirmidhi}{838}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا يَزِيدُ بْنُ أَبِي زِيَادٍ، عَنِ ابْنِ أَبِي نُعْمٍ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَقْتُلُ الْمُحْرِمُ السَّبُعَ الْعَادِيَ وَالْكَلْبَ الْعَقُورَ وَالْفَأْرَةَ وَالْعَقْرَبَ وَالْحِدَأَةَ وَالْغُرَابَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ قَالُوا الْمُحْرِمُ يَقْتُلُ السَّبُعَ الْعَادِيَ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ ‏.‏ وَقَالَ الشَّافِعِيُّ كُلُّ سَبُعٍ عَدَا عَلَى النَّاسِ أَوْ عَلَى دَوَابِّهِمْ فَلِلْمُحْرِمِ قَتْلُهُ ‏.‏\hadithno{838}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed narrated that:The Prophet said: "The Muhrim may kill the wild beast of prey, the rabid dog, the mouse, the scorpion, the kite, and the crow}}
\hadithdefcmd{tirmidhi}{839}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، وَعَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم احْتَجَمَ وَهُوَ مُحْرِمٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَعَبْدِ اللَّهِ ابْنِ بُحَيْنَةَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَخَّصَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ فِي الْحِجَامَةِ لِلْمُحْرِمِ وَقَالُوا لاَ يَحْلِقُ شَعَرًا ‏.‏ وَقَالَ مَالِكٌ لاَ يَحْتَجِمُ الْمُحْرِمُ إِلاَّ مِنْ ضَرُورَةٍ ‏.‏ وَقَالَ سُفْيَانُ الثَّوْرِيُّ وَالشَّافِعِيُّ لاَ بَأْسَ أَنْ يَحْتَجِمَ الْمُحْرِمُ وَلاَ يَنْزِعُ شَعَرًا ‏.‏\hadithno{839}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated:"The Messenger of Allah was cupped while he was a Muhrim}}
\hadithdefcmd{tirmidhi}{840}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنْ نُبَيْهِ بْنِ وَهْبٍ، قَالَ أَرَادَ ابْنُ مَعْمَرٍ أَنْ يُنْكِحَ، ابْنَهُ فَبَعَثَنِي إِلَى أَبَانَ بْنِ عُثْمَانَ وَهُوَ أَمِيرُ الْمَوْسِمِ بِمَكَّةَ فَأَتَيْتُهُ فَقُلْتُ إِنَّ أَخَاكَ يُرِيدُ أَنْ يُنْكِحَ ابْنَهُ فَأَحَبَّ أَنْ يُشْهِدَكَ ذَلِكَ ‏.‏ قَالَ لاَ أُرَاهُ إِلاَّ أَعْرَابِيًّا جَافِيًا إِنَّ الْمُحْرِمَ لاَ يَنْكِحُ وَلاَ يُنْكِحُ ‏.‏ أَوْ كَمَا قَالَ ثُمَّ حَدَّثَ عَنْ عُثْمَانَ مِثْلَهُ يَرْفَعُهُ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي رَافِعٍ وَمَيْمُونَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُثْمَانَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ عُمَرُ بْنُ الْخَطَّابِ وَعَلِيُّ بْنُ أَبِي طَالِبٍ وَابْنُ عُمَرَ وَهُوَ قَوْلُ بَعْضِ فُقَهَاءِ التَّابِعِينَ وَبِهِ يَقُولُ مَالِكٌ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ لاَ يَرَوْنَ أَنْ يَتَزَوَّجَ الْمُحْرِمُ قَالُوا فَإِنْ نَكَحَ فَنِكَاحُهُ بَاطِلٌ ‏.‏\hadithno{840}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Nubaih bin Wahb narrated:"Ibn Ma'mar wanted to have his son married. S he sent me to Aban bin Uthman who was the Amir of the (Hajj) season. I went to him and said: 'Your brother wants to marry his son and he would like for you to witness that.' He said: 'I think he is but a crude Bedouin; indeed the Muhrim is not to marry nor have someone married'" - or he said similarly - then he narrated from Uthman similar in Marfu form (from the Prophet)}}
\hadithdefcmd{tirmidhi}{841}{حَدَّثَنَا قُتَيْبَةُ، أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ مَطَرٍ الْوَرَّاقِ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ أَبِي رَافِعٍ، قَالَ تَزَوَّجَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَيْمُونَةَ وَهُوَ حَلاَلٌ وَبَنَى بِهَا وَهُوَ حَلاَلٌ وَكُنْتُ أَنَا الرَّسُولَ فِيمَا بَيْنَهُمَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَلاَ نَعْلَمُ أَحَدًا أَسْنَدَهُ غَيْرَ حَمَّادِ بْنِ زَيْدٍ عَنْ مَطَرٍ الْوَرَّاقِ عَنْ رَبِيعَةَ ‏.‏ وَرَوَى مَالِكُ بْنُ أَنَسٍ عَنْ رَبِيعَةَ عَنْ سُلَيْمَانَ بْنِ يَسَارٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم تَزَوَّجَ مَيْمُونَةَ وَهُوَ حَلاَلٌ ‏.‏ رَوَاهُ مَالِكٌ مُرْسَلاً ‏.‏ قَالَ وَرَوَاهُ أَيْضًا سُلَيْمَانُ بْنُ بِلاَلٍ عَنْ رَبِيعَةَ مُرْسَلاً ‏.‏ قَالَ أَبُو عِيسَى وَرُوِيَ عَنْ يَزِيدَ بْنِ الأَصَمِّ عَنْ مَيْمُونَةَ قَالَتْ تَزَوَّجَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ حَلاَلٌ ‏.‏ وَيَزِيدُ بْنُ الأَصَمِّ هُوَ ابْنُ أُخْتِ مَيْمُونَةَ ‏.‏\hadithno{841}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Abu Rafi narrated:"The Messenger of Allah married Maimunah while he was Halal, and he stayed with her while he was Halal, and I was the messenger between the two of them}}
\hadithdefcmd{tirmidhi}{842}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ الْبَصْرِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ حَبِيبٍ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَزَوَّجَ مَيْمُونَةَ وَهُوَ مُحْرِمٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَأَهْلُ الْكُوفَةِ ‏.‏\hadithno{842}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated:"The Prophet married Maimunah while he was a Muhrim}}
\hadithdefcmd{tirmidhi}{843}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَزَوَّجَ مَيْمُونَةَ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{843}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Shadh; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{(Another chain) that Ibn Abbas narrated:"The Prophet married Maimunah while he was a Muhrim}}
\hadithdefcmd{tirmidhi}{844}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا دَاوُدُ بْنُ عَبْدِ الرَّحْمَنِ الْعَطَّارُ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ سَمِعْتُ أَبَا الشَّعْثَاءِ، يُحَدِّثُ عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَزَوَّجَ مَيْمُونَةَ وَهُوَ مُحْرِمٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَأَبُو الشَّعْثَاءِ اسْمُهُ جَابِرُ بْنُ زَيْدٍ ‏.‏ وَاخْتَلَفُوا فِي تَزْوِيجِ النَّبِيِّ صلى الله عليه وسلم مَيْمُونَةَ لأَنَّ النَّبِيَّ صلى الله عليه وسلم تَزَوَّجَهَا فِي طَرِيقِ مَكَّةَ فَقَالَ بَعْضُهُمْ تَزَوَّجَهَا حَلاَلاً وَظَهَرَ أَمْرُ تَزْوِيجِهَا وَهُوَ مُحْرِمٌ ثُمَّ بَنَى بِهَا وَهُوَ حَلاَلٌ بِسَرِفَ فِي طَرِيقِ مَكَّةَ وَمَاتَتْ مَيْمُونَةُ بِسَرِفَ حَيْثُ بَنَى بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَدُفِنَتْ بِسَرِفَ ‏.‏\hadithno{844}\hadithgrade{Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{(Another chain) that Ibn Abbas narrated:"The Prophet married Maimunah while he was a Muhrim}}
\hadithdefcmd{tirmidhi}{845}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ أَبَا فَزَارَةَ، يُحَدِّثُ عَنْ يَزِيدَ بْنِ الأَصَمِّ، عَنْ مَيْمُونَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَزَوَّجَهَا وَهُوَ حَلاَلٌ وَبَنَى بِهَا حَلاَلاً وَمَاتَتْ بِسَرِفَ وَدَفَنَّاهَا فِي الظُّلَّةِ الَّتِي بَنَى بِهَا فِيهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَرَوَى غَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ يَزِيدَ بْنِ الأَصَمِّ مُرْسَلاً أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَزَوَّجَ مَيْمُونَةَ وَهُوَ حَلاَلٌ ‏.‏\hadithno{845}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Yazid bin Al-Asamm narrated about Maimunah:"The Messenger of Allah married he while he was Halal and he stayed with her while he was Halal. She died in Sarif, and we buried her at the (site of the) tent where he had stayed wit her}}
\hadithdefcmd{tirmidhi}{846}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنِ الْمُطَّلِبِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ صَيْدُ الْبَرِّ لَكُمْ حَلاَلٌ وَأَنْتُمْ حُرُمٌ مَا لَمْ تَصِيدُوهُ أَوْ يُصَدْ لَكُمْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي قَتَادَةَ وَطَلْحَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ مُفَسَّرٌ ‏.‏ وَالْمُطَّلِبُ لاَ نَعْرِفُ لَهُ سَمَاعًا مِنْ جَابِرٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ لاَ يَرَوْنَ بِأَكْلِ الصَّيْدِ لِلْمُحْرِمِ بَأْسًا إِذَا لَمْ يَصْطَدْهُ أَوْ لَمْ يُصْطَدْ مِنْ أَجْلِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا أَحْسَنُ حَدِيثٍ رُوِيَ فِي هَذَا الْبَابِ وَأَفْسَرُ وَالَعَمَلُ عَلَى هَذَا وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{846}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Jabir bin Abdullah narrated that:The Prophet said: "The land game is lawful for you while you are in Ihram as long as you did not hunt it - or - it was not hunted for you}}
\hadithdefcmd{tirmidhi}{847}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ أَبِي النَّضْرِ، عَنْ نَافِعٍ، مَوْلَى أَبِي قَتَادَةَ عَنْ أَبِي قَتَادَةَ، أَنَّهُ كَانَ مَعَ النَّبِيِّ صلى الله عليه وسلم حَتَّى إِذَا كَانَ بِبَعْضِ طَرِيقِ مَكَّةَ تَخَلَّفَ مَعَ أَصْحَابٍ لَهُ مُحْرِمِينَ وَهُوَ غَيْرُ مُحْرِمٍ فَرَأَى حِمَارًا وَحْشِيًّا فَاسْتَوَى عَلَى فَرَسِهِ فَسَأَلَ أَصْحَابَهُ أَنْ يُنَاوِلُوهُ سَوْطَهُ فَأَبَوْا فَسَأَلَهُمْ رُمْحَهُ فَأَبَوْا عَلَيْهِ فَأَخَذَهُ ثُمَّ شَدَّ عَلَى الْحِمَارِ فَقَتَلَهُ فَأَكَلَ مِنْهُ بَعْضُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَأَبَى بَعْضُهُمْ فَأَدْرَكُوا النَّبِيَّ صلى الله عليه وسلم فَسَأَلُوهُ عَنْ ذَلِكَ فَقَالَ ‏ "‏ إِنَّمَا هِيَ طُعْمَةٌ أَطْعَمَكُمُوهَا اللَّهُ ‏"‏ ‏.‏\hadithno{847}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Qatadah narrated that:He was with the Prophet and when he got to one of the roads of Makkah some of the companions were Muhrim and he (Abu Qatadah) was not a Muhrim. So he saw a wild donkey, so he mounted his horse, asked his companions to give him his whip but they refused, so he asked them to give him his spear and they refused. So he (himself) took it and struck the donkey killing it. Some of the Companions of the Prophet ate it and some of them refused. When they caught up to the Prophet they asked him about that and he said: "It is only food which Allah fed you}}
\hadithdefcmd{tirmidhi}{848}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي قَتَادَةَ، فِي حِمَارِ الْوَحْشِ مِثْلَ حَدِيثِ أَبِي النَّضْرِ غَيْرَ أَنَّ فِي، حَدِيثِ زَيْدِ بْنِ أَسْلَمَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ هَلْ مَعَكُمْ مِنْ لَحْمِهِ شَيْءٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{848}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{(Another chain that) Abu Qatadah narrated:About the wild donkey, and it is similar to the (previous) narrated of Abu An-Nadr except that in the narration of Zaid bin Aslam he said that the Messenger of Allah said: "Do you have any of its meat left with you?}}
\hadithdefcmd{tirmidhi}{849}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، أَنَّ ابْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّ الصَّعْبَ بْنَ جَثَّامَةَ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِهِ بِالأَبْوَاءِ أَوْ بِوَدَّانَ فَأَهْدَى لَهُ حِمَارًا وَحْشِيًّا فَرَدَّهُ عَلَيْهِ فَلَمَّا رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم مَا فِي وَجْهِهِ مِنَ الْكَرَاهِيَةِ قَالَ ‏ "‏ إِنَّهُ لَيْسَ بِنَا رَدٌّ عَلَيْكَ وَلَكِنَّا حُرُمٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذَهَبَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِلَى هَذَا الْحَدِيثِ وَكَرِهُوا أَكْلَ الصَّيْدِ لِلْمُحْرِمِ ‏.‏ وَقَالَ الشَّافِعِيُّ إِنَّمَا وَجْهُ هَذَا الْحَدِيثِ عِنْدَنَا إِنَّمَا رَدَّهُ عَلَيْهِ لَمَّا ظَنَّ أَنَّهُ صِيدَ مِنْ أَجْلِهِ وَتَرَكَهُ عَلَى التَّنَزُّهِ ‏.‏ وَقَدْ رَوَى بَعْضُ أَصْحَابِ الزُّهْرِيِّ عَنِ الزُّهْرِيِّ هَذَا الْحَدِيثَ وَقَالَ أَهْدَى لَهُ لَحْمَ حِمَارِ وَحْشٍ ‏.‏ وَهُوَ غَيْرُ مَحْفُوظٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَزَيْدِ بْنِ أَرْقَمَ ‏.‏\hadithno{849}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated that:As-S'ab bin Jath-thamah informed him that the Messenger of Allah had passed him at Al-Abwa or Bawaddan. He (As-S'ab) gave him a wild donkey but he refused it. When the Messenger of Allah noticed on his face that he was upset, he said: "We would not refuse you, but we are in Ihram}}
\hadithdefcmd{tirmidhi}{850}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ أَبِي الْمُهَزِّمِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي حَجٍّ أَوْ عُمْرَةٍ فَاسْتَقْبَلَنَا رِجْلٌ مِنْ جَرَادٍ فَجَعَلْنَا نَضْرِبُهُ بِسِيَاطِنَا وَعِصِيِّنَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ كُلُوهُ فَإِنَّهُ مِنْ صَيْدِ الْبَحْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ أَبِي الْمُهَزِّمِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَأَبُو الْمُهَزِّمِ اسْمُهُ يَزِيدُ بْنُ سُفْيَانَ وَقَدْ تَكَلَّمَ فِيهِ شُعْبَةُ ‏.‏ وَقَدْ رَخَّصَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ لِلْمُحْرِمِ أَنْ يَصِيدَ الْجَرَادَ وَيَأْكُلَهُ وَرَأَى بَعْضُهُمْ عَلَيْهِ صَدَقَةً إِذَا اصْطَادَهُ وَأَكَلَهُ ‏.‏\hadithno{850}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated:"We went with the Messenger of Allah during Hajj or Umrah and we encountered a swarm of locusts. We began striking at them with our whips and set our staffs, and the Prophet said: "Eat it, for indeed it is game of the sea}}
\hadithdefcmd{tirmidhi}{851}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عُمَيْرٍ، عَنِ ابْنِ أَبِي عَمَّارٍ، قَالَ قُلْتُ لِجَابِرِ بْنِ عَبْدِ اللَّهِ الضَّبُعُ أَصَيْدٌ هِيَ قَالَ نَعَمْ ‏.‏ قَالَ قُلْتُ آكُلُهَا قَالَ نَعَمْ ‏.‏ قَالَ قُلْتُ أَقَالَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ قَالَ يَحْيَى بْنُ سَعِيدٍ وَرَوَى جَرِيرُ بْنُ حَازِمٍ هَذَا الْحَدِيثَ فَقَالَ عَنْ جَابِرٍ عَنْ عُمَرَ ‏.‏ وَحَدِيثُ ابْنِ جُرَيْجٍ أَصَحُّ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ فِي الْمُحْرِمِ إِذَا أَصَابَ ضَبُعًا أَنَّ عَلَيْهِ الْجَزَاءَ ‏.‏\hadithno{851}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abi Ammar said:"I asked Jabir bin Abdullah: 'Is the hyena game?' He said: 'Yes'" He said: "I said: 'Can it be eaten?' He said: 'Yes.'" He said: "I said: 'Did the Messenger of Allah say that?' He said: 'Yes}}
\hadithdefcmd{tirmidhi}{852}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا هَارُونُ بْنُ صَالِحٍ الطَّلْحِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ اغْتَسَلَ النَّبِيُّ صلى الله عليه وسلم لِدُخُولِهِ مَكَّةَ بِفَخٍّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَيْرُ مَحْفُوظٍ ‏.‏ وَالصَّحِيحُ مَا رَوَى نَافِعٌ عَنِ ابْنِ عُمَرَ أَنَّهُ كَانَ يَغْتَسِلُ لِدُخُولِ مَكَّةَ ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ يُسْتَحَبُّ الاِغْتِسَالُ لِدُخُولِ مَكَّةَ ‏.‏ وَعَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ ضَعِيفٌ فِي الْحَدِيثِ ضَعَّفَهُ أَحْمَدُ بْنُ حَنْبَلٍ وَعَلِيُّ بْنُ الْمَدِينِيِّ وَغَيْرُهُمَا وَلاَ نَعْرِفُ هَذَا الْحَدِيثَ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِهِ ‏.‏\hadithno{852}\hadithgrade{Ahmad Muhammad Shakir: Very Daif Isnaad; Al-Albani: Very Daif Isnaad; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated:"The Prophet performed Ghusl for entered Makkah at Fakhkh}}
\hadithdefcmd{tirmidhi}{853}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا جَاءَ النَّبِيُّ صلى الله عليه وسلم إِلَى مَكَّةَ دَخَلَ مِنْ أَعْلاَهَا وَخَرَجَ مِنْ أَسْفَلِهَا ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ قَاَلَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{853}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"When Prophet came to Makkah he entered it from its higher side, and left from its lower side}}
\hadithdefcmd{tirmidhi}{854}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الْعُمَرِيُّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ مَكَّةَ نَهَارًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{854}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Umar narrated:"The Prophet entered Makkah during the daytime}}
\hadithdefcmd{tirmidhi}{855}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي قَزَعَةَ الْبَاهِلِيِّ، عَنِ الْمُهَاجِرِ الْمَكِّيِّ، قَالَ سُئِلَ جَابِرُ بْنُ عَبْدِ اللَّهِ أَيَرْفَعُ الرَّجُلُ يَدَيْهِ إِذَا رَأَى الْبَيْتَ فَقَالَ حَجَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم أَفَكُنَّا نَفْعَلُهُ ‏.‏ قَالَ أَبُو عِيسَى رَفْعُ الْيَدَيْنِ عِنْدَ رُؤْيَةِ الْبَيْتِ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ شُعْبَةَ عَنْ أَبِي قَزَعَةَ ‏.‏ وَأَبُو قَزَعَةَ اسْمُهُ سُوَيْدُ بْنُ حُجَيْرٍ ‏.‏\hadithno{855}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Al-Muhajir Al-Makki said:Jabir bin Abdulla was asked about a man raising his hands when he sees the House (Ka'bah). So he said: 'We performed Hajj with the Messenger of Allah and we did it}}
\hadithdefcmd{tirmidhi}{856}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، أَخْبَرَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، قَالَ لَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم مَكَّةَ دَخَلَ الْمَسْجِدَ فَاسْتَلَمَ الْحَجَرَ ثُمَّ مَضَى عَلَى يَمِينِهِ فَرَمَلَ ثَلاَثًا وَمَشَى أَرْبَعًا ثُمَّ أَتَى الْمَقَامَ فَقَالَ ‏:‏ ‏(‏وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى ‏)‏ فَصَلَّى رَكْعَتَيْنِ وَالْمَقَامُ بَيْنَهُ وَبَيْنَ الْبَيْتِ ثُمَّ أَتَى الْحَجَرَ بَعْدَ الرَّكْعَتَيْنِ فَاسْتَلَمَهُ ثُمَّ خَرَجَ إِلَى الصَّفَا أَظُنُّهُ قَالََّ ‏:‏‏(‏ إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ ‏)‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{856}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir narrated:"When the Prophet arrived in Makkah, he entered the Masjid and touched the (Black) Stone, then went to his right and performed Raml (walking quickly) for three (circuits) and walking for four. Then he came to the Maqam and said: 'And take you (people) the Maqam (place) of Ibrahim as a place of prayer.' Then he performed two Rak'ah while the Maqam was between him and the House. Then he came to the (Black) Stone after the two Rak'ah to touch it, then he left to As-Safa - I think - he said: Indeed As-Safa and Al-Marwah are among the symbols of Allah}}
\hadithdefcmd{tirmidhi}{857}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَمَلَ مِنَ الْحَجَرِ إِلَى الْحَجَرِ ثَلاَثًا وَمَشَى أَرْبَعًا ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ قَالَ الشَّافِعِيُّ إِذَا تَرَكَ الرَّمَلَ عَمْدًا فَقَدْ أَسَاءَ وَلاَ شَىْءَ عَلَيْهِ وَإِذَا لَمْ يَرْمُلْ فِي الأَشْوَاطِ الثَّلاَثَةِ لَمْ يَرْمُلْ فِيمَا بَقِيَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لَيْسَ عَلَى أَهْلِ مَكَّةَ رَمَلٌ وَلاَ عَلَى مَنْ أَحْرَمَ مِنْهَا ‏.‏\hadithno{857}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir narrated:"The Prophet performed Raml from the (Black) Stone to the (Black) Stone for three (circuits), and he walked four (circuits)}}
\hadithdefcmd{tirmidhi}{858}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا سُفْيَانُ، وَمَعْمَرٌ، عَنِ ابْنِ خُثَيْمٍ، عَنْ أَبِي الطُّفَيْلِ، قَالَ كُنْتُ مَعَ ابْنِ عَبَّاسٍ وَمُعَاوِيَةُ لاَ يَمُرُّ بِرُكْنٍ إِلاَّ اسْتَلَمَهُ فَقَالَ لَهُ ابْنُ عَبَّاسٍ إِنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَكُنْ يَسْتَلِمُ إِلاَّ الْحَجَرَ الأَسْوَدَ وَالرُّكْنَ الْيَمَانِيَ ‏.‏ فَقَالَ مُعَاوِيَةُ لَيْسَ شَيْءٌ مِنَ الْبَيْتِ مَهْجُورًا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ أَنْ لاَ يَسْتَلِمَ إِلاَّ الْحَجَرَ الأَسْوَدَ وَالرُّكْنَ الْيَمَانِيَ ‏.‏\hadithno{858}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Tufail narrated:"I was with Ibn Abbas, and Mu'awiyah would not pass any corner without touching it. So Ibn Abbas said to him: 'the Prophet would not touch any besides the Black Stone and the Yemeni corner.' So Mu'awiyah said: 'There is no part of the House that is untouchable}}
\hadithdefcmd{tirmidhi}{859}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا قَبِيصَةُ، عَنْ سُفْيَانَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَبْدِ الْحَمِيدِ، عَنِ ابْنِ يَعْلَى، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم طَافَ بِالْبَيْتِ مُضْطَبِعًا وَعَلَيْهِ بُرْدٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثُ الثَّوْرِيِّ عَنِ ابْنِ جُرَيْجٍ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِهِ وَهُوَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعَبْدُ الْحَمِيدِ هُوَ ابْنُ جُبَيْرِ بْنِ شَيْبَةَ ‏.‏ عَنِ ابْنِ يَعْلَى عَنْ أَبِيهِ وَهُوَ يَعْلَى بْنُ أُمَيَّةَ ‏.‏\hadithno{859}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn Ya'la narrated from his father:"The Prophet performed Tawaf of the House Mudtabi'an, and he was wearing a Burd}}
\hadithdefcmd{tirmidhi}{860}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَابِسِ بْنِ رَبِيعَةَ، قَالَ رَأَيْتُ عُمَرَ بْنَ الْخَطَّابِ يُقَبِّلُ الْحَجَرَ وَيَقُولُ إِنِّي أُقَبِّلُكَ وَأَعْلَمُ أَنَّكَ حَجَرٌ وَلَوْلاَ أَنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُقَبِّلُكَ لَمْ أُقَبِّلْكَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{860}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abbas bin Rabi'ah said:"I saw Umar bin Al-Khattab kissing the (Black) Stone and saying: 'I am kissing you while I know that you are just a stone, and if I had not seen the Messenger of Allah kissing you, I would not kiss you}}
\hadithdefcmd{tirmidhi}{861}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنِ الزُّبَيْرِ بْنِ عَرَبِيٍّ، أَنَّ رَجُلاً، سَأَلَ ابْنَ عُمَرَ عَنِ اسْتِلاَمِ الْحَجَرِ، فَقَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَسْتَلِمُهُ وَيُقَبِّلُهُ ‏.‏ فَقَالَ الرَّجُلُ أَرَأَيْتَ إِنْ غُلِبْتُ عَلَيْهِ أَرَأَيْتَ إِنْ زُوحِمْتُ فَقَالَ ابْنُ عُمَرَ اجْعَلْ أَرَأَيْتَ بِالْيَمَنِ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَسْتَلِمُهُ وَيُقَبِّلُهُ ‏.‏ قَالَ وَهَذَا هُوَ الزُّبَيْرُ بْنُ عَرَبِيٍّ رَوَى عَنْهُ حَمَّادُ بْنُ زَيْدٍ وَالزُّبَيْرُ بْنُ عَرَبِيٍّ كُوفِيٌّ يُكْنَى أَبَا سَلَمَةَ سَمِعَ مِنْ أَنَسِ بْنِ مَالِكٍ وَغَيْرِ وَاحِدٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم رَوَى عَنْهُ سُفْيَانُ الثَّوْرِيُّ وَغَيْرُ وَاحِدٍ مِنَ الأَئِمَّةِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ عَنْهُ مِنْ غَيْرِ وَجْهٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ يَسْتَحِبُّونَ تَقْبِيلَ الْحَجَرِ فَإِنْ لَمْ يُمْكِنْهُ وَلَمْ يَصِلْ إِلَيْهِ اسْتَلَمَهُ بِيَدِهِ وَقَبَّلَ يَدَهُ وَإِنْ لَمْ يَصِلْ إِلَيْهِ اسْتَقْبَلَهُ إِذَا حَاذَى بِهِ وَكَبَّرَ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏\hadithno{861}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Az-Zubair bin Arabi narrated:That a man asked Ibn Umar about touching the (Black) Stone, so he said: "I saw the Prophet touching it and kissing it." So the man said: "What is your view if there is a throng (around the Ka'bah) and what is your view if the people overpowered me?" Ibn Umar said: "Leave 'What is your view' in Yemen. I saw the Prophet touching it and kissing it}}
\hadithdefcmd{tirmidhi}{862}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم حِينَ قَدِمَ مَكَّةَ طَافَ بِالْبَيْتِ سَبْعًا وَأَتَى الْمَقَامَ فَقَرَأَ ‏:‏‏(‏ وَاتَّخِذُوا مِنْ مَقَامِ إِبْرَاهِيمَ مُصَلًّى ‏)‏ فَصَلَّى خَلْفَ الْمَقَامِ ثُمَّ أَتَى الْحَجَرَ فَاسْتَلَمَهُ ثُمَّ قَالَ ‏"‏ نَبْدَأُ بِمَا بَدَأَ اللَّهُ بِهِ ‏"‏ ‏.‏ فَبَدَأَ بِالصَّفَا وَقَرَأَ ‏:‏ ‏(‏إِنَّ الصَّفَا وَالْمَرْوَةَ مِنْ شَعَائِرِ اللَّهِ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّهُ يَبْدَأُ بِالصَّفَا قَبْلَ الْمَرْوَةِ فَإِنْ بَدَأَ بِالْمَرْوَةِ قَبْلَ الصَّفَا لَمْ يُجْزِهِ وَبَدَأَ بِالصَّفَا ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِيمَنْ طَافَ بِالْبَيْتِ وَلَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ حَتَّى رَجَعَ فَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِنْ لَمْ يَطُفْ بَيْنَ الصَّفَا وَالْمَرْوَةِ حَتَّى خَرَجَ مِنْ مَكَّةَ فَإِنْ ذَكَرَ وَهُوَ قَرِيبٌ مِنْهَا رَجَعَ فَطَافَ بَيْنَ الصَّفَا وَالْمَرْوَةِ وَإِنْ لَمْ يَذْكُرْ حَتَّى أَتَى بِلاَدَهُ أَجْزَأَهُ وَعَلَيْهِ دَمٌ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ ‏.‏ وَقَالَ بَعْضُهُمْ إِنْ تَرَكَ الطَّوَافَ بَيْنَ الصَّفَا وَالْمَرْوَةِ حَتَّى رَجَعَ إِلَى بِلاَدِهِ فَإِنَّهُ لاَ يُجْزِيهِ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏ قَالَ الطَّوَافُ بَيْنَ الصَّفَا وَالْمَرْوَةِ وَاجِبٌ لاَ يَجُوزُ الْحَجُّ إِلاَّ بِهِ ‏.‏\hadithno{862}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir narrated:"When the Prophet arrived in Makkah, he performed seven (circuits) of Tawaf around the House. Then he came to the Maqam and said: And take you (people) the Maqam (place) of Ibrahim as a place of prayer. Then he prayed behind the Maqam. Then he came to the (Black) Stone to touch it. Then he said: 'We begin with what Allah began with.' So he began at As-Safa and recited: Indeed As-Safa and Al-Marwah are among the Symbols of Allah}}
\hadithdefcmd{tirmidhi}{863}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّمَا سَعَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ لِيُرِيَ الْمُشْرِكِينَ قُوَّتَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَابْنِ عُمَرَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ الَّذِي يَسْتَحِبُّهُ أَهْلُ الْعِلْمِ أَنْ يَسْعَى بَيْنَ الصَّفَا وَالْمَرْوَةِ ‏.‏ فَإِنْ لَمْ يَسْعَ وَمَشَى بَيْنَ الصَّفَا وَالْمَرْوَةِ رَأَوْهُ جَائِزًا ‏.‏\hadithno{863}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated:"The Messenger of Allah only performed the Sa'i of the House and of As-Safa and Al-Marwah to show his strength to the idolaters}}
\hadithdefcmd{tirmidhi}{864}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ كَثِيرِ بْنِ جُمْهَانَ، قَالَ رَأَيْتُ ابْنَ عُمَرَ يَمْشِي فِي السَّعْىِ فَقُلْتُ لَهُ أَتَمْشِي فِي السَّعْىِ بَيْنَ الصَّفَا وَالْمَرْوَةِ قَالَ لَئِنْ سَعَيْتُ لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْعَى وَلَئِنْ مَشَيْتُ لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَمْشِي وَأَنَا شَيْخٌ كَبِيرٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرُوِيَ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنِ ابْنِ عُمَرَ نَحْوُهُ ‏.‏\hadithno{864}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Kathir bin Jumhan said:"I saw Ibn Umar walking at the place of Sa'i so I said to him: 'Do you walk at the place of Sa'i between As-Safa and Al-Marwah?' He said: 'If I performed Sa'i, then it is because I saw the Messenger of Allah performing Sa'i there, and if I walked, then it is because I have seen the Messenger of Allah walking. And I am an old man}}
\hadithdefcmd{tirmidhi}{865}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، وَعَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ طَافَ النَّبِيُّ صلى الله عليه وسلم عَلَى رَاحِلَتِهِ فَإِذَا انْتَهَى إِلَى الرُّكْنِ أَشَارَ إِلَيْهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَأَبِي الطُّفَيْلِ وَأُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ كَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ أَنْ يَطُوفَ الرَّجُلُ بِالْبَيْتِ وَبَيْنَ الصَّفَا وَالْمَرْوَةِ رَاكِبًا إِلاَّ مِنْ عُذْرٍ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏\hadithno{865}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Ibn Abbas narrated:"The Prophet performed Tawaf upon his mount, so when he arrived at the (Black Stone) corner, he pointed to it}}
\hadithdefcmd{tirmidhi}{866}{يَحْيَى بْنُ يَمَانٍ، عَنْ شَرِيكٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ طَافَ بِالْبَيْتِ خَمْسِينَ مَرَّةً خَرَجَ مِنْ ذُنُوبِهِ كَيَوْمِ وَلَدَتْهُ أُمُّهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ غَرِيبٌ ‏.‏ سَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَقَالَ إِنَّمَا يُرْوَى هَذَا عَنِ ابْنِ عَبَّاسٍ قَوْلُهُ ‏.‏\hadithno{866}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"Whoever performed Tawaf around the House fifty time, he will be as free of his sins as the day his mother bore him}}
\hadithdefcmd{tirmidhi}{867}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ عَنْ أَيُّوبَ السَّخْتِيَانِيِّ قَالَ كَانُوا يَعُدُّونَ عَبْدَ اللَّهِ بْنَ سَعِيدِ بْنِ جُبَيْرٍ أَفْضَلَ مِنْ أَبِيهِ ‏.‏ وَلِعَبْدِ اللَّهِ أَخٌ يُقَالُ لَهُ عَبْدُ الْمَلِكِ بْنُ سَعِيدِ بْنِ جُبَيْرٍ وَقَدْ رَوَى عَنْهُ أَيْضًا ‏.‏\hadithno{867}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ayyub As-Sakhtiyani said:"We considered Abdullah bin Sa'eed bin Jubair to be better than his father, and he had a brother named Abdul-Malik bin Sa'eed bin Jubair who also reported from him}}
\hadithdefcmd{tirmidhi}{868}{حَدَّثَنَا أَبُو عَمَّارٍ، وَعَلِيُّ بْنُ خَشْرَمٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ بَابَاهْ، عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ يَا بَنِي عَبْدِ مَنَافٍ لاَ تَمْنَعُوا أَحَدًا طَافَ بِهَذَا الْبَيْتِ وَصَلَّى أَيَّةَ سَاعَةٍ شَاءَ مِنْ لَيْلٍ أَوْ نَهَارٍ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَأَبِي ذَرٍّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جُبَيْرِ بْنِ مُطْعِمٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ عَبْدُ اللَّهِ بْنُ أَبِي نَجِيحٍ عَنْ عَبْدِ اللَّهِ بْنِ بَابَاهْ أَيْضًا ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي الصَّلاَةِ بَعْدَ الْعَصْرِ وَبَعْدَ الصُّبْحِ بِمَكَّةَ فَقَالَ بَعْضُهُمْ لاَ بَأْسَ بِالصَّلاَةِ وَالطَّوَافِ بَعْدَ الْعَصْرِ وَبَعْدَ الصُّبْحِ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ وَاحْتَجُّوا بِحَدِيثِ النَّبِيِّ صلى الله عليه وسلم هَذَا ‏.‏ وَقَالَ بَعْضُهُمْ إِذَا طَافَ بَعْدَ الْعَصْرِ لَمْ يُصَلِّ حَتَّى تَغْرُبَ الشَّمْسُ وَكَذَلِكَ إِنْ طَافَ بَعْدَ صَلاَةِ الصُّبْحِ لَمْ يُصَلِّ حَتَّى تَطْلُعَ الشَّمْسُ ‏.‏ وَاحْتَجُّوا بِحَدِيثِ عُمَرَ أَنَّهُ طَافَ بَعْدَ صَلاَةِ الصُّبْحِ فَلَمْ يُصَلِّ وَخَرَجَ مِنْ مَكَّةَ حَتَّى نَزَلَ بِذِي طُوًى فَصَلَّى بَعْدَ مَا طَلَعَتِ الشَّمْسُ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكِ بْنِ أَنَسٍ ‏.‏\hadithno{868}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jubair bin Mut'im narrated that :the Prophet said: "O Banu Abd Manaf! Do not prevent anyone from performing Tawaf around this House, and Salat, whichever hour it is of the night or day}}
\hadithdefcmd{tirmidhi}{869}{أَخْبَرَنَا أَبُو مُصْعَبٍ الْمَدَنِيُّ، قِرَاءَةً عَنْ عَبْدِ الْعَزِيزِ بْنِ عِمْرَانَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ فِي رَكْعَتَىِ الطَّوَافِ بِسُورَتَىِ الإِخْلاَصِْ ‏:‏ ‏(‏ قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏)‏ وَ ‏(‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏‏.‏\hadithno{869}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir bin Abdullah narrated:During the two Rak'ah of Tawaf, the Messenger of Allah recited the two Surat of Ikhlas, "Say: O you disbelievers!" and: "Say: He is Allah, (the) One}}
\hadithdefcmd{tirmidhi}{870}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يَسْتَحِبُّ أَنْ يَقْرَأَ، فِي رَكْعَتَىِ الطَّوَافِ بِـ ‏(‏ قُلْ يَا أَيُّهَا الْكَافِرُونَ ‏)‏ وَ ‏(‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ مِنْ حَدِيثِ عَبْدِ الْعَزِيزِ بْنِ عِمْرَانَ وَحَدِيثُ جَعْفَرِ بْنِ مُحَمَّدٍ عَنْ أَبِيهِ فِي هَذَا أَصَحُّ مِنْ حَدِيثِ جَعْفَرِ بْنِ مُحَمَّدٍ عَنْ أَبِيهِ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَعَبْدُ الْعَزِيزِ بْنُ عِمْرَانَ ضَعِيفٌ فِي الْحَدِيثِ ‏.‏\hadithno{870}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad Maqtu; Al-Albani: Sahih Isnaad Maqtu; Zubair Ali Zai: Sahih}\hadithtrans{Ja'far bin Muhammad narrated from his father:that he considered it recommended for the two Rak'ah of Tawaf to recite: Say: "O you disbelievers!" and: Say: "He is Allah, (the) One}}
\hadithdefcmd{tirmidhi}{871}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ زَيْدِ بْنِ أُثَيْعٍ، قَالَ سَأَلْتُ عَلِيًّا بِأَىِّ شَيْءٍ بُعِثْتَ قَالَ بِأَرْبَعٍ لاَ يَدْخُلُ الْجَنَّةَ إِلاَّ نَفْسٌ مُسْلِمَةٌ وَلاَ يَطُوفُ بِالْبَيْتِ عُرْيَانٌ وَلاَ يَجْتَمِعُ الْمُسْلِمُونَ وَالْمُشْرِكُونَ بَعْدَ عَامِهِمْ هَذَا وَمَنْ كَانَ بَيْنَهُ وَبَيْنَ النَّبِيِّ صلى الله عليه وسلم عَهْدٌ فَعَهْدُهُ إِلَى مُدَّتِهِ وَمَنْ لاَ مُدَّةَ لَهُ فَأَرْبَعَةُ أَشْهُرٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ ‏.‏\hadithno{871}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Zaid bin Uthai said:XI asked Ali: "What is it that you were sent with?" He said: "With four things: None will be admitted into Paradise except for the soul that is a Muslim. None is to perform Tawaf around the House while naked. The Muslims and the idolaters will not be gathering (in Makkah) together after this year. And for whomever there is a covenant between him and the Prophet, then his covenant is (valid) until its term, and for that in which there was no term, then it shall be four months}}
\hadithdefcmd{tirmidhi}{872}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَنَصْرُ بْنُ عَلِيٍّ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي إِسْحَاقَ، نَحْوَهُ وَقَالاَ زَيْدُ بْنُ يُثَيْعٍ ‏.‏ وَهَذَا أَصَحُّ ‏.‏ قَالَ أَبُو عِيسَى وَشُعْبَةُ وَهِمَ فِيهِ فَقَالَ زَيْدُ بْنُ أُثَيْلٍ ‏.‏\hadithno{872}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Zaid bin Uthai said:(Another chain) and they said: "Zaid bin Yuthai" and this is more correct}}
\hadithdefcmd{tirmidhi}{873}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْمَاعِيلَ بْنِ عَبْدِ الْمَلِكِ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ خَرَجَ النَّبِيُّ صلى الله عليه وسلم مِنْ عِنْدِي وَهُوَ قَرِيرُ الْعَيْنِ طَيِّبُ النَّفْسِ فَرَجَعَ إِلَىَّ وَهُوَ حَزِينٌ فَقُلْتُ لَهُ فَقَالَ ‏ "‏ إِنِّي دَخَلْتُ الْكَعْبَةَ وَوَدِدْتُ أَنِّي لَمْ أَكُنْ فَعَلْتُ إِنِّي أَخَافُ أَنْ أَكُونَ أَتْعَبْتُ أُمَّتِي مِنْ بَعْدِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{873}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"The Prophet left me while he had a joyous look of contentment and he returned to me grieving. So I asked him about that and he said: 'I entered the Ka'bah, and I wished that I had not done it. I fear that my Ummah will follow me (in that) after me}}
\hadithdefcmd{tirmidhi}{874}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، عَنْ بِلاَلٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى فِي جَوْفِ الْكَعْبَةِ ‏.‏ قَالَ ابْنُ عَبَّاسٍ لَمْ يُصَلِّ وَلَكِنَّهُ كَبَّرَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُسَامَةَ بْنِ زَيْدٍ وَالْفَضْلِ بْنِ عَبَّاسٍ وَعُثْمَانَ بْنِ طَلْحَةَ وَشَيْبَةَ بْنِ عُثْمَانَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ بِلاَلٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ لاَ يَرَوْنَ بِالصَّلاَةِ فِي الْكَعْبَةِ بَأْسًا ‏.‏ وَقَالَ مَالِكُ بْنُ أَنَسٍ لاَ بَأْسَ بِالصَّلاَةِ النَّافِلَةِ فِي الْكَعْبَةِ ‏.‏ وَكَرِهَ أَنْ تُصَلَّى الْمَكْتُوبَةُ فِي الْكَعْبَةِ ‏.‏ وَقَالَ الشَّافِعِيُّ لاَ بَأْسَ أَنْ تُصَلَّى الْمَكْتُوبَةُ وَالتَّطَوُّعُ فِي الْكَعْبَةِ لأَنَّ حُكْمَ النَّافِلَةِ وَالْمَكْتُوبَةِ فِي الطَّهَارَةِ وَالْقِبْلَةِ سَوَاءٌ ‏.‏\hadithno{874}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Umar narrated from Bilal:"The Prophet performed Salat in the interior of the Ka'bah." And Ibn Abbas said: "He did not perform Salat in it, but he said the Takbir}}
\hadithdefcmd{tirmidhi}{875}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، أَنَّ ابْنَ الزُّبَيْرِ، قَالَ لَهُ حَدِّثْنِي بِمَا، كَانَتْ تُفْضِي إِلَيْكَ أُمُّ الْمُؤْمِنِينَ يَعْنِي عَائِشَةَ فَقَالَ حَدَّثَتْنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهَا ‏ "‏ لَوْلاَ أَنَّ قَوْمَكِ حَدِيثُو عَهْدٍ بِالْجَاهِلِيَّةِ لَهَدَمْتُ الْكَعْبَةَ وَجَعَلْتُ لَهَا بَابَيْنِ ‏"‏ ‏.‏ قَالَ فَلَمَّا مَلَكَ ابْنُ الزُّبَيْرِ هَدَمَهَا وَجَعَلَ لَهَا بَابَيْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{875}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-Aswad bin Yazid narrated that:Ibn Az-Zubair said to him: "Narrated to me from what the Mother of the Believers used to (secretly) inform you about" - meaning Aishah - so he said: "She narrated to me that the Messenger of Allah said: 'Had your people not been still close to the pre-Islamic period of ignorance, then I would demolish the Ka'bah and rebuild it with two doors.'" He said: "So when Ibn Az-Zubair came to power he demolished it and rebuilt it with two doors}}
\hadithdefcmd{tirmidhi}{876}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَلْقَمَةَ بْنِ أَبِي عَلْقَمَةَ، عَنْ أُمِّهِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أُحِبُّ أَنْ أَدْخُلَ، الْبَيْتَ فَأُصَلِّيَ فِيهِ فَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِي فَأَدْخَلَنِي الْحِجْرَ فَقَالَ ‏ "‏ صَلِّي فِي الْحِجْرِ إِنْ أَرَدْتِ دُخُولَ الْبَيْتِ فَإِنَّمَا هُوَ قِطْعَةٌ مِنَ الْبَيْتِ وَلَكِنَّ قَوْمَكِ اسْتَقْصَرُوهُ حِينَ بَنَوُا الْكَعْبَةَ فَأَخْرَجُوهُ مِنَ الْبَيْتِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعَلْقَمَةُ بْنُ أَبِي عَلْقَمَةَ هُوَ عَلْقَمَةُ بْنُ بِلاَلٍ ‏.‏\hadithno{876}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah narrated:"I wanted to enter the House to perform Salat in it, so the Messenger of Allah took me by the hand and put me in the Hijr, and he said: 'Perform Salat in the Hijri if you want to enter the House. For indeed it is part of the House, but your people considered it insignificant when they built the Ka'bah, so they put it outside the House}}
\hadithdefcmd{tirmidhi}{877}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَزَلَ الْحَجَرُ الأَسْوَدُ مِنَ الْجَنَّةِ وَهُوَ أَشَدُّ بَيَاضًا مِنَ اللَّبَنِ فَسَوَّدَتْهُ خَطَايَا بَنِي آدَمَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{877}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Abbas narrated that:The Messenger of Allah said: "The Black Stone descended from the Paradise, and it was more white than milk, then it was blackened by the sins of the children of Adam}}
\hadithdefcmd{tirmidhi}{878}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ رَجَاءٍ أَبِي يَحْيَى، قَالَ سَمِعْتُ مُسَافِعًا الْحَاجِبَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ الرُّكْنَ وَالْمَقَامَ يَاقُوتَتَانِ مِنْ يَاقُوتِ الْجَنَّةِ طَمَسَ اللَّهُ نُورَهُمَا وَلَوْ لَمْ يَطْمِسْ نُورَهُمَا لأَضَاءَتَا مَا بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا يُرْوَى عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو مَوْقُوفًا قَوْلُهُ ‏.‏ وَفِيهِ عَنْ أَنَسٍ أَيْضًا وَهُوَ حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{878}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Amr narrated that :He heard the Messenger of Allah saying: "Indeed the Corner and the Maqam are two corundums from the corundum of Paradise. Allah removed their lights, and if their lights had not been removed then they would illuminate what is between east and the west}}
\hadithdefcmd{tirmidhi}{879}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الأَجْلَحِ، عَنْ إِسْمَاعِيلَ بْنِ مُسْلِمٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِنًى الظُّهْرَ وَالْعَصْرَ وَالْمَغْرِبَ وَالْعِشَاءَ وَالْفَجْرَ ثُمَّ غَدَا إِلَى عَرَفَاتٍ ‏.‏ قَالَ أَبُو عِيسَى وَإِسْمَاعِيلُ بْنُ مُسْلِمٍ قَدْ تَكَلَّمُوا فِيهِ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{879}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ata reported that Ibn Abbas narrated:"The Messenger of Allah led us in Salat at Mina for Zuhr, Asr, Maghrib, Isha, and Fajr, then he left in the morning to Arafat}}
\hadithdefcmd{tirmidhi}{880}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الأَجْلَحِ، عَنِ الأَعْمَشِ، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى بِمِنًى الظُّهْرَ وَالْفَجْرَ ثُمَّ غَدَا إِلَى عَرَفَاتٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ مِقْسَمٍ عَنِ ابْنِ عَبَّاسٍ قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ قَالَ يَحْيَى قَالَ شُعْبَةُ لَمْ يَسْمَعِ الْحَكَمُ مِنْ مِقْسَمٍ إِلاَّ خَمْسَةَ أَشْيَاءَ ‏.‏ وَعَدَّهَا وَلَيْسَ هَذَا الْحَدِيثُ فِيمَا عَدَّ شُعْبَةُ ‏.‏\hadithno{880}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Al-Hakam reported from Miqsam, that Ibn Abbas narrated:That the Prophet prayed Zuhr and Fajr in Mina, then he left in the morning to Arafat}}
\hadithdefcmd{tirmidhi}{881}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، وَمُحَمَّدُ بْنُ أَبَانَ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ أُمِّهِ، مُسَيْكَةَ عَنْ عَائِشَةَ، قَالَتْ قُلْنَا يَا رَسُولَ اللَّهِ أَلاَ نَبْنِي لَكَ بَيْتًا يُظِلُّكَ بِمِنًى قَالَ ‏ "‏ لاَ مِنًى مُنَاخُ مَنْ سَبَقَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{881}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Aishah said:"We said: 'O Messenger of Allah! Shall we build a structure to shade you at Mina? He said: 'No., Mina is a resting place for whoever arrives}}
\hadithdefcmd{tirmidhi}{882}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ حَارِثَةَ بْنِ وَهْبٍ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم بِمِنًى آمَنَ مَا كَانَ النَّاسُ وَأَكْثَرَهُ رَكْعَتَيْنِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَابْنِ عُمَرَ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ حَارِثَةَ بْنِ وَهْبٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرُوِيَ عَنِ ابْنِ مَسْعُودٍ أَنَّهُ قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم بِمِنًى رَكْعَتَيْنِ وَمَعَ أَبِي بَكْرٍ وَمَعَ عُمَرَ وَمَعَ عُثْمَانَ رَكْعَتَيْنِ صَدْرًا مِنْ إِمَارَتِهِ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي تَقْصِيرِ الصَّلاَةِ بِمِنًى لأَهْلِ مَكَّةَ فَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لَيْسَ لأَهْلِ مَكَّةَ أَنْ يَقْصُرُوا الصَّلاَةَ بِمِنًى إِلاَّ مَنْ كَانَ بِمِنًى مُسَافِرًا ‏.‏ وَهُوَ قَوْلُ ابْنِ جُرَيْجٍ وَسُفْيَانَ الثَّوْرِيِّ وَيَحْيَى بْنِ سَعِيدٍ الْقَطَّانِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ بَأْسَ لأَهْلِ مَكَّةَ أَنْ يَقْصُرُوا الصَّلاَةَ بِمِنًى ‏.‏ وَهُوَ قَوْلُ الأَوْزَاعِيِّ وَمَالِكٍ وَسُفْيَانَ بْنِ عُيَيْنَةَ وَعَبْدِ الرَّحْمَنِ بْنِ مَهْدِيٍّ ‏.‏\hadithno{882}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Harithah bin Wahb said:"I prayed two Rak'ah with the Prophet at Mina, and the people were as secure as they ever were, and even more so}}
\hadithdefcmd{tirmidhi}{883}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَمْرِو بْنِ عَبْدِ اللَّهِ بْنِ صَفْوَانَ، عَنْ يَزِيدَ بْنِ شَيْبَانَ، قَالَ أَتَانَا ابْنُ مِرْبَعٍ الأَنْصَارِيُّ وَنَحْنُ وُقُوفٌ بِالْمَوْقِفِ مَكَانًا يُبَاعِدُهُ عَمْرٌو - فَقَالَ إِنِّي رَسُولُ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَيْكُمْ يَقُولُ ‏ "‏ كُونُوا عَلَى مَشَاعِرِكُمْ فَإِنَّكُمْ عَلَى إِرْثٍ مِنْ إِرْثِ إِبْرَاهِيمَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَائِشَةَ وَجُبَيْرِ بْنِ مُطْعِمٍ وَالشَّرِيدِ بْنِ سُوَيْدٍ الثَّقَفِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ مِرْبَعٍ الأَنْصَارِيِّ حَدِيثٌ حَسَنٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ابْنِ عُيَيْنَةَ عَنْ عَمْرِو بْنِ دِينَارٍ ‏.‏ وَابْنُ مِرْبَعٍ اسْمُهُ يَزِيدُ بْنُ مِرْبَعٍ الأَنْصَارِيُّ وَإِنَّمَا يُعْرَفُ لَهُ هَذَا الْحَدِيثُ الْوَاحِدُ ‏.‏\hadithno{883}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Amr bin Dinar narrated from Amr bin Abdulah bin Safwan, that Yazid bin Shaiban said:"Ibn Mirba Al-Ansari came to us while we were standing at our places" (Amr bin Sinar said:) a place that Amr (bin Abdullah) indicated was far - "and he said: 'I am a messenger whom the Messenger of Allah sent to you to say: 'Stay with your (Hajj) rites, for indeed you are following a legacy left by Ibrahim}}
\hadithdefcmd{tirmidhi}{884}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ الْبَصْرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ الطُّفَاوِيُّ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَتْ قُرَيْشٌ وَمَنْ كَانَ عَلَى دِينِهَا وَهُمُ الْحُمْسُ يَقِفُونَ بِالْمُزْدَلِفَةِ يَقُولُونَ نَحْنُ قَطِينُ اللَّهِ ‏.‏ وَكَانَ مَنْ سِوَاهُمْ يَقِفُونَ بِعَرَفَةَ فَأَنْزَلَ اللَّهُ تَعَالَى ‏:‏ ‏(‏ثُمَّ أَفِيضُوا مِنْ حَيْثُ أَفَاضَ النَّاسُ ‏)‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَمَعْنَى هَذَا الْحَدِيثِ أَنَّ أَهْلَ مَكَّةَ كَانُوا لاَ يَخْرُجُونَ مِنَ الْحَرَمِ وَعَرَفَةُ خَارِجٌ مِنَ الْحَرَمِ وَأَهْلُ مَكَّةَ كَانُوا يَقِفُونَ بِالْمُزْدَلِفَةِ وَيَقُولُونَ نَحْنُ قَطِينُ اللَّهِ يَعْنِي سُكَّانَ اللَّهِ وَمَنْ سِوَى أَهْلِ مَكَّةَ كَانُوا يَقِفُونَ بِعَرَفَاتٍ ‏.‏ فَأَنْزَلَ اللَّهُ تَعَالَى‏:‏ ‏(‏ثُمَّ أَفِيضُوا مِنْ حَيْثُ أَفَاضَ النَّاسُ ‏)‏ ‏.‏ وَالْحُمْسُ هُمْ أَهْلُ الْحَرَمِ ‏.‏\hadithno{884}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"The Quraish and those who followed their religion - and they were called Al-Hums - would stand at Al-Muzdalifah, and they would say: 'We are the people of Allah.' The others would stand at Arafat, so Allah the Mighty and Sublime revealed: Then depart from where the people depart}}
\hadithdefcmd{tirmidhi}{885}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ عَيَّاشِ بْنِ أَبِي رَبِيعَةَ، عَنْ زَيْدِ بْنِ عَلِيٍّ، عَنْ أَبِيهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، رضى الله عنه قَالَ وَقَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِعَرَفَةَ فَقَالَ ‏"‏ هَذِهِ عَرَفَةُ وَهَذَا هُوَ الْمَوْقِفُ وَعَرَفَةُ كُلُّهَا مَوْقِفٌ ‏"‏ ‏.‏ ثُمَّ أَفَاضَ حِينَ غَرَبَتِ الشَّمْسُ وَأَرْدَفَ أُسَامَةَ بْنَ زَيْدٍ وَجَعَلَ يُشِيرُ بِيَدِهِ عَلَى هَيْئَتِهِ وَالنَّاسُ يَضْرِبُونَ يَمِينًا وَشِمَالاً يَلْتَفِتُ إِلَيْهِمْ وَيَقُولُ ‏"‏ يَا أَيُّهَا النَّاسُ عَلَيْكُمُ السَّكِينَةَ ‏"‏ ‏.‏ ثُمَّ أَتَى جَمْعًا فَصَلَّى بِهِمُ الصَّلاَتَيْنِ جَمِيعًا فَلَمَّا أَصْبَحَ أَتَى قُزَحَ فَوَقَفَ عَلَيْهِ وَقَالَ ‏"‏ هَذَا قُزَحُ وَهُوَ الْمَوْقِفُ وَجَمْعٌ كُلُّهَا مَوْقِفٌ ‏"‏ ‏.‏ ثُمَّ أَفَاضَ حَتَّى انْتَهَى إِلَى وَادِي مُحَسِّرٍ فَقَرَعَ نَاقَتَهُ فَخَبَّتْ حَتَّى جَاوَزَ الْوَادِيَ فَوَقَفَ وَأَرْدَفَ الْفَضْلَ ثُمَّ أَتَى الْجَمْرَةَ فَرَمَاهَا ثُمَّ أَتَى الْمَنْحَرَ فَقَالَ ‏"‏ هَذَا الْمَنْحَرُ وَمِنًى كُلُّهَا مَنْحَرٌ ‏"‏ ‏.‏ وَاسْتَفْتَتْهُ جَارِيَةٌ شَابَّةٌ مِنْ خَثْعَمٍ فَقَالَتْ إِنَّ أَبِي شَيْخٌ كَبِيرٌ قَدْ أَدْرَكَتْهُ فَرِيضَةُ اللَّهِ فِي الْحَجِّ أَفَيُجْزِئُ أَنْ أَحُجَّ عَنْهُ قَالَ ‏"‏ حُجِّي عَنْ أَبِيكِ ‏"‏ ‏.‏ قَالَ وَلَوَى عُنُقَ الْفَضْلِ فَقَالَ الْعَبَّاسُ يَا رَسُولَ اللَّهِ لِمَ لَوَيْتَ عُنُقَ ابْنِ عَمِّكَ قَالَ ‏"‏ رَأَيْتُ شَابًّا وَشَابَّةً فَلَمْ آمَنِ الشَّيْطَانَ عَلَيْهِمَا ‏"‏ ‏.‏ ثُمَّ أَتَاهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَفَضْتُ قَبْلَ أَنْ أَحْلِقَ ‏.‏ قَالَ ‏"‏ احْلِقْ أَوْ قَصِّرْ وَلاَ حَرَجَ ‏"‏ ‏.‏ قَالَ وَجَاءَ آخَرُ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي ذَبَحْتُ قَبْلَ أَنْ أَرْمِيَ ‏.‏ قَالَ ‏"‏ ارْمِ وَلاَ حَرَجَ ‏"‏ ‏.‏ قَالَ ثُمَّ أَتَى الْبَيْتَ فَطَافَ بِهِ ثُمَّ أَتَى زَمْزَمَ فَقَالَ ‏"‏ يَا بَنِي عَبْدِ الْمُطَّلِبِ لَوْلاَ أَنْ يَغْلِبَكُمُ النَّاسُ عَنْهُ لَنَزَعْتُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ حَدِيثٌ حَسَنٌ صَحِيحٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ عَلِيٍّ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ عَيَّاشٍ ‏.‏ وَقَدْ رَوَاهُ غَيْرُ وَاحِدٍ عَنِ الثَّوْرِيِّ مِثْلَ هَذَا ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ رَأَوْا أَنْ يُجْمَعَ بَيْنَ الظُّهْرِ وَالْعَصْرِ بِعَرَفَةَ فِي وَقْتِ الظُّهْرِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا صَلَّى الرَّجُلُ فِي رَحْلِهِ وَلَمْ يَشْهَدِ الصَّلاَةَ مَعَ الإِمَامِ إِنْ شَاءَ جَمَعَ هُوَ بَيْنَ الصَّلاَتَيْنِ مِثْلَ مَا صَنَعَ الإِمَامُ ‏.‏ قَالَ وَزَيْدُ بْنُ عَلِيٍّ هُوَ ابْنُ حُسَيْنِ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ عَلَيْهِ السَّلاَمُ ‏.‏\hadithno{885}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ali bin Abi Talib, may Allah be pleased with him, narrated:"The Messenger of Allah stopped at Arafat and said: 'This is Arafah and it is a place of standing. And all of Arafat is a place for standing.' Then he departed when the sun had set and took Usamah bin Zaid as a companion rider, and he was motioning with his hand as was his custom, and the people were striking (their camels) on the right and the left to try and catch them, so he said: 'O you people! Be calmm.' Then he came to Jama and performed the two Salat there combined. When the morning came, he went to Quzah and stood there and said: 'This is Quzah, and it is a place of standing, and all of Jama is a place for standing.' Then he departed until he arrived at Wadi Muhassir. Then he stuck his she-camel and she trotted until he passed the valley. Then he stopped and took Al-Fadl as a companion rider and went to the Jamrah to stone it. Then he went to Al-Manhar and said: 'This is Al-Manhar, and all of Mina is a place for sacrifice.' A young girl from Khath'am came to ask him for a verdict, she said: 'Indeed my father is an elderly man who has lived until Allah has made Hajj obligatory, so would he be rewarded if I perform Hajj for him? He said: 'Perform Hajj for your father.'" He said: "And he turned the neck of Al Fadl. So Al-Abbas said: 'O Messenger of Allah! Why did you turn the neck of your cousin?' He said: 'I saw a young man and a young woman, and they were not safe from Shaitan.' A man came to him and said, 'O Messenger of Allah! I performed (Tawaf) Al-Ifadah before shaving.' He said: 'Shave, and there is no harm'" - or: 'Clip and there is no harm'" He said: "Someone else came and said: 'O Messenger of Allah! I did the sacrifice before stoning.' So he said: 'Stone, and there is no harm.'" He said: "Then he went to the House (Ka'bah) to perform Tawaf around it, then he went to Zamzam and said: 'O tribe of Abdul-Muttalib! If it were not that the people would rush upon you then I would remove it}}
\hadithdefcmd{tirmidhi}{886}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، وَبِشْرُ بْنُ السَّرِيِّ، وَأَبُو نُعَيْمٍ قَالُوا حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَوْضَعَ فِي وَادِي مُحَسِّرٍ ‏.‏ وَزَادَ فِيهِ بِشْرٌ وَأَفَاضَ مِنْ جَمْعٍ وَعَلَيْهِ السَّكِينَةُ وَأَمَرَهُمْ بِالسَّكِينَةِ ‏.‏ وَزَادَ فِيهِ أَبُو نُعَيْمٍ وَأَمَرَهُمْ أَنْ يَرْمُوا بِمِثْلِ حَصَى الْخَذْفِ وَقَالَ ‏ "‏ لَعَلِّي لاَ أَرَاكُمْ بَعْدَ عَامِي هَذَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُسَامَةَ بْنِ زَيْدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{886}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir narrated:"The Prophet hurried through Wadi Muhassir." Bishr (one of the narrators) added: "He departed from Jam calmly and he ordered them (the people) to be calm." And Abu Nu'aim (one of the narrators) added: "And he ordered them to do the stoning with what was similar to pebbles for Al-Khadhf' And he said: "Perhaps I will not see you after this year}}
\hadithdefcmd{tirmidhi}{887}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ مَالِكٍ، أَنَّ ابْنَ عُمَرَ، صَلَّى بِجَمْعٍ فَجَمَعَ بَيْنَ الصَّلاَتَيْنِ بِإِقَامَةٍ وَقَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَعَلَ مِثْلَ هَذَا فِي هَذَا الْمَكَانِ ‏.‏\hadithno{887}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Malik narrated:"Ibn Umar prayed at Jam (Muzdalifah), so he combined two prayers with the Iqamah, and he said: 'I saw the Messenger of Allah doing the same as this at the place}}
\hadithdefcmd{tirmidhi}{888}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏ قَالَ مُحَمَّدُ بْنُ بَشَّارٍ قَالَ يَحْيَى وَالصَّوَابُ حَدِيثُ سُفْيَانَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي أَيُّوبَ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَجَابِرٍ وَأُسَامَةَ بْنِ زَيْدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ فِي رِوَايَةِ سُفْيَانَ أَصَحُّ مِنْ رِوَايَةِ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ وَحَدِيثُ سُفْيَانَ حَدِيثٌ صَحِيحٌ حَسَنٌ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى إِسْرَائِيلُ هَذَا الْحَدِيثَ عَنْ أَبِي إِسْحَاقَ عَنْ عَبْدِ اللَّهِ وَخَالِدٍ ابْنَىْ مَالِكٍ عَنِ ابْنِ عُمَرَ ‏.‏ وَحَدِيثُ سَعِيدِ بْنِ جُبَيْرٍ عَنِ ابْنِ عُمَرَ هُوَ حَدِيثٌ حَسَنٌ صَحِيحٌ أَيْضًا رَوَاهُ سَلَمَةُ بْنُ كُهَيْلٍ عَنْ سَعِيدِ بْنِ جُبَيْرٍ ‏.‏ وَأَمَّا أَبُو إِسْحَاقَ فَرَوَاهُ عَنْ عَبْدِ اللَّهِ وَخَالِدٍ ابْنَىْ مَالِكٍ عَنِ ابْنِ عُمَرَ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ لأَنَّهُ لاَ تُصَلَّى صَلاَةُ الْمَغْرِبِ دُونَ جَمْعٍ فَإِذَا أَتَى جَمْعًا وَهُوَ الْمُزْدَلِفَةُ جَمَعَ بَيْنَ الصَّلاَتَيْنِ بِإِقَامَةٍ وَاحِدَةٍ وَلَمْ يَتَطَوَّعْ فِيمَا بَيْنَهُمَا وَهُوَ الَّذِي اخْتَارَهُ بَعْضُ أَهْلِ الْعِلْمِ وَذَهَبَ إِلَيْهِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ ‏.‏ قَالَ سُفْيَانُ وَإِنْ شَاءَ صَلَّى الْمَغْرِبَ ثُمَّ تَعَشَّى وَوَضَعَ ثِيَابَهُ ثُمَّ أَقَامَ فَصَلَّى الْعِشَاءَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ يَجْمَعُ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ بِالْمُزْدَلِفَةِ بِأَذَانٍ وَإِقَامَتَيْنِ يُؤَذِّنُ لِصَلاَةِ الْمَغْرِبِ وَيُقِيمُ وَيُصَلِّي الْمَغْرِبَ ثُمَّ يُقِيمُ وَيُصَلِّي الْعِشَاءَ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى إِسْرَائِيلُ هَذَا الْحَدِيثَ عَنْ أَبِي إِسْحَقَ عَنْ عَبْدِ اللَّهِ وَخَالِدٍ ابْنَيْ مَالِكٍ عَنْ ابْنِ عُمَرَ وَحَدِيثُ سَعِيدِ بْنِ جُبَيْرٍ عَنْ ابْنِ عُمَرَ هُوَ حَدِيثٌ حَسَنٌ صَحِيحٌ أَيْضًا رَوَاهُ سَلَمَةُ بْنُ كُهَيْلٍ عَنْ سَعِيدِ بْنِ جُبَيْرٍ وَأَمَّا أَبُو إِسْحَقَ فَرَوَاهُ عَنْ عَبْدِ اللَّهِ وَخَالِدٍ ابْنَيْ مَالِكٍ عَنْ ابْنِ عُمَرَ\hadithno{888}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{(Another chain) that Sa'eed bin Jubair narrated :Similarly from Ibn Umar, from the Prophet}}
\hadithdefcmd{tirmidhi}{889}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ بُكَيْرِ بْنِ عَطَاءٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَعْمَرَ، أَنَّ نَاسًا، مِنْ أَهْلِ نَجْدٍ أَتَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ بِعَرَفَةَ فَسَأَلُوهُ فَأَمَرَ مُنَادِيًا فَنَادَى ‏ "‏ الْحَجُّ عَرَفَةُ مَنْ جَاءَ لَيْلَةَ جَمْعٍ قَبْلَ طُلُوعِ الْفَجْرِ فَقَدْ أَدْرَكَ الْحَجَّ أَيَّامُ مِنًى ثَلاَثَةٌ فَمَنْ تَعَجَّلَ فِي يَوْمَيْنِ فَلاَ إِثْمَ عَلَيْهِ وَمَنْ تَأَخَّرَ فَلاَ إِثْمَ عَلَيْهِ ‏"‏ ‏.‏ قَالَ مُحَمَّدٌ وَزَادَ يَحْيَى وَأَرْدَفَ رَجُلاً فَنَادَى\hadithno{889}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdur-Rahman bin Ya'mar narrated that:Some people among the residents of Najd came to the Messenger of Allah while he was at Arafat. They were questioning him, so he ordered a caller to proclaim: "The Hajj is Arafah. Whoever came to Jam during the night, before the time of Fajr, then he has attended the Hajj. The days of Mina are three, so whoever hastens (leaving after) two days, then there is no sin upon him, and whoever delays, then there is no sin upon him." Muhammad said: "Yahya added: 'And he took a companion rider to proclaim it}}
\hadithdefcmd{tirmidhi}{890}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ بُكَيْرِ بْنِ عَطَاءٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَعْمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِمَعْنَاهُ ‏.‏ وَقَالَ ابْنُ أَبِي عُمَرَ قَالَ سُفْيَانُ بْنُ عُيَيْنَةَ وَهَذَا أَجْوَدُ حَدِيثٍ رَوَاهُ سُفْيَانُ الثَّوْرِيُّ ‏.‏ قَالَ أَبُو عِيسَى وَالْعَمَلُ عَلَى حَدِيثِ عَبْدِ الرَّحْمَنِ بْنِ يَعْمَرَ عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّهُ مَنْ لَمْ يَقِفْ بِعَرَفَاتٍ قَبْلَ طُلُوعِ الْفَجْرِ فَقَدْ فَاتَهُ الْحَجُّ وَلاَ يُجْزِئُ عَنْهُ إِنْ جَاءَ بَعْدَ طُلُوعِ الْفَجْرِ وَيَجْعَلُهَا عُمْرَةً وَعَلَيْهِ الْحَجُّ مِنْ قَابِلٍ ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى شُعْبَةُ عَنْ بُكَيْرِ بْنِ عَطَاءٍ نَحْوَ حَدِيثِ الثَّوْرِيِّ ‏.‏ قَالَ وَسَمِعْتُ الْجَارُودَ يَقُولُ سَمِعْتُ وَكِيعًا أَنَّهُ ذَكَرَ هَذَا الْحَدِيثَ فَقَالَ هَذَا الْحَدِيثُ أُمُّ الْمَنَاسِكِ ‏.‏\hadithno{890}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{Abdur-Rahman bin Ya'mar narrated:(Another chain) with a similar narration (as no)}}
\hadithdefcmd{tirmidhi}{891}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، وَإِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، وَزَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنِ الشَّعْبِيِّ، عَنْ عُرْوَةَ بْنِ مُضَرِّسِ بْنِ أَوْسِ بْنِ حَارِثَةَ بْنِ لاَمٍ الطَّائِيِّ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِالْمُزْدَلِفَةِ حِينَ خَرَجَ إِلَى الصَّلاَةِ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي جِئْتُ مِنْ جَبَلَىْ طَيِّئٍ أَكْلَلْتُ رَاحِلَتِي وَأَتْعَبْتُ نَفْسِي وَاللَّهِ مَا تَرَكْتُ مِنْ حَبْلٍ إِلاَّ وَقَفْتُ عَلَيْهِ فَهَلْ لِي مِنْ حَجٍّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ شَهِدَ صَلاَتَنَا هَذِهِ وَوَقَفَ مَعَنَا حَتَّى نَدْفَعَ وَقَدْ وَقَفَ بِعَرَفَةَ قَبْلَ ذَلِكَ لَيْلاً أَوْ نَهَارًا فَقَدْ أَتَمَّ حَجَّهُ وَقَضَى تَفَثَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ قَوْلُهُ ‏"‏ تَفَثَهُ ‏"‏ ‏.‏ يَعْنِي نُسُكَهُ ‏.‏ قَوْلُهُ ‏"‏ مَا تَرَكْتُ مِنْ حَبْلٍ إِلاَّ وَقَفْتُ عَلَيْهِ ‏"‏ ‏.‏ إِذَا كَانَ مِنْ رَمْلٍ يُقَالُ لَهُ حَبْلٌ وَإِذَا كَانَ مِنْ حِجَارَةٍ يُقَالُ لَهُ جَبَلٌ ‏.‏\hadithno{891}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Urwah bin Mudarris bin Aws bin Harithah bin Lam At-Ta'i narrated:"I came to the Messenger of Allah at Al-Muzdalifah when he left for the Salat. I said: 'O Messenger of Allah! I came from the two mountains of (the tribe of) Tai, wearing out my mount and exhausting myself. By Allah! I did not leave a Habl (sand dune) without stopping on it. So is there Hajj for me?' The Messenger of Allah said: 'Whoever attends this Salat of ours, and stays here with us until departing, while he has stood during the night or the day before that at Arafat, then he has completed his Hajj and fulfilled his Tafath}}
\hadithdefcmd{tirmidhi}{892}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ثَقَلٍ مِنْ جَمْعٍ بِلَيْلٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأُمِّ حَبِيبَةَ وَأَسْمَاءَ بِنْتِ أَبِي بَكْرٍ وَالْفَضْلِ بْنِ عَبَّاسٍ\hadithno{892}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{Ibn Abbas narrated:"The Messenger of Allah sent me with the Thaqal (load of baggage) during the night from Jam}}
\hadithdefcmd{tirmidhi}{893}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الْمَسْعُودِيِّ، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَدَّمَ ضَعَفَةَ أَهْلِهِ وَقَالَ ‏ "‏ لاَ تَرْمُوا الْجَمْرَةَ حَتَّى تَطْلُعَ الشَّمْسُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ لَمْ يَرَوْا بَأْسًا أَنْ يَتَقَدَّمَ الضَّعَفَةُ مِنَ الْمُزْدَلِفَةِ بِلَيْلٍ يَصِيرُونَ إِلَى مِنًى ‏.‏ وَقَالَ أَكْثَرُ أَهْلِ الْعِلْمِ بِحَدِيثِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُمْ لاَ يَرْمُونَ حَتَّى تَطْلُعَ الشَّمْسُ ‏.‏ وَرَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ فِي أَنْ يَرْمُوا بِلَيْلٍ ‏.‏ وَالْعَمَلُ عَلَى حَدِيثِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُمْ لاَ يَرْمُونَ ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ وَالشَّافِعِيِّ ‏.‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ثَقَلٍ حَدِيثٌ صَحِيحٌ رُوِيَ عَنْهُ مِنْ غَيْرِ وَجْهٍ ‏.‏ وَرَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ مُشَاشٍ عَنْ عَطَاءٍ عَنِ ابْنِ عَبَّاسٍ عَنِ الْفَضْلِ بْنِ عَبَّاسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَدَّمَ ضَعَفَةَ أَهْلِهِ مِنْ جَمْعٍ بِلَيْلٍ ‏.‏ وَهَذَا حَدِيثٌ خَطَأٌ أَخْطَأَ فِيهِ مُشَاشٌ وَزَادَ فِيهِ عَنِ الْفَضْلِ بْنِ عَبَّاسٍ ‏.‏ وَرَوَى ابْنُ جُرَيْجٍ وَغَيْرُهُ هَذَا الْحَدِيثَ عَنْ عَطَاءٍ عَنِ ابْنِ عَبَّاسٍ ‏.‏ وَلَمْ يَذْكُرُوا فِيهِ عَنِ الْفَضْلِ بْنِ عَبَّاسٍ ‏.‏ وَمُشَاشٌ بَصْرِيٌّ رَوَى عَنْهُ شُعْبَةُ ‏.‏\hadithno{893}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated:"The Prophet advanced the weak among his family and he said: 'Do not stone the Jamrah until the sun has risen}}
\hadithdefcmd{tirmidhi}{894}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَرْمِي يَوْمَ النَّحْرِ ضُحًى وَأَمَّا بَعْدَ ذَلِكَ فَبَعْدَ زَوَالِ الشَّمْسِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ أَنَّهُ لاَ يَرْمِي بَعْدَ يَوْمِ النَّحْرِ إِلاَّ بَعْدَ الزَّوَالِ ‏.‏\hadithno{894}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir narrated:"The Prophet would stone on the Day of An-Nahr during the morning light, as for (the days) afterwards, then (he would do it) after the Zenith of the sun}}
\hadithdefcmd{tirmidhi}{895}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ الأَعْمَشِ، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَفَاضَ قَبْلَ طُلُوعِ الشَّمْسِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَإِنَّمَا كَانَ أَهْلُ الْجَاهِلِيَّةِ يَنْتَظِرُونَ حَتَّى تَطْلُعَ الشَّمْسُ ثُمَّ يُفِيضُونَ ‏.‏\hadithno{895}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated:"The Prophet departed before the rising of the sun}}
\hadithdefcmd{tirmidhi}{896}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ عَمْرَو بْنَ مَيْمُونٍ، يُحَدِّثُ يَقُولُ كُنَّا وُقُوفًا بِجَمْعٍ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ إِنَّ الْمُشْرِكِينَ كَانُوا لاَ يُفِيضُونَ حَتَّى تَطْلُعَ الشَّمْسُ وَكَانُوا يَقُولُونَ أَشْرِقْ ثَبِيرُ ‏.‏ وَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَالَفَهُمْ ‏.‏ فَأَفَاضَ عُمَرُ قَبْلَ طُلُوعِ الشَّمْسِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{896}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Amr bin Maimun narrated:"We were halted at Jama when Umar bin Al-Khattab said: 'The idolaters would not depart until the sun had risen and they would say: "Let the sun shine on Thabir" and indeed the Messenger of Allah contradicted them.' So Umar departed before the rising of the sun}}
\hadithdefcmd{tirmidhi}{897}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَرْمِي الْجِمَارَ بِمِثْلِ حَصَى الْخَذْفِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سُلَيْمَانَ بْنِ عَمْرِو بْنِ الأَحْوَصِ عَنْ أُمِّهِ وَهِيَ أُمُّ جُنْدُبٍ الأَزْدِيَّةُ وَابْنِ عَبَّاسٍ وَالْفَضْلِ بْنِ عَبَّاسٍ وَعَبْدِ الرَّحْمَنِ بْنِ عُثْمَانَ التَّيْمِيِّ وَعَبْدِ الرَّحْمَنِ بْنِ مُعَاذٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ الَّذِي اخْتَارَهُ أَهْلُ الْعِلْمِ أَنْ تَكُونَ الْجِمَارُ الَّتِي يُرْمَى بِهَا مِثْلَ حَصَى الْخَذْفِ ‏.‏\hadithno{897}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir narrated:"I saw the Messenger of Allah stoning the Jimar with what was similar to pebbles for Al-Khadhaf}}
\hadithdefcmd{tirmidhi}{898}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ الْبَصْرِيُّ، حَدَّثَنَا زِيَادُ بْنُ عَبْدِ اللَّهِ، عَنِ الْحَجَّاجِ، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَرْمِي الْجِمَارَ إِذَا زَالَتِ الشَّمْسُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{898}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated:"The Messenger of Allah stoned the Jimar when the sun had passed the zenith}}
\hadithdefcmd{tirmidhi}{899}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، أَخْبَرَنَا الْحَجَّاجُ، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَمَى الْجَمْرَةَ يَوْمَ النَّحْرِ رَاكِبًا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَقُدَامَةَ بْنِ عَبْدِ اللَّهِ وَأُمِّ سُلَيْمَانَ بْنِ عَمْرِو بْنِ الأَحْوَصِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَاخْتَارَ بَعْضُهُمْ أَنْ يَمْشِيَ إِلَى الْجِمَارِ ‏.‏ وَقَدْ رُوِيَ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَمْشِي إِلَى الْجِمَارِ ‏.‏ وَوَجْهُ هَذَا الْحَدِيثِ عِنْدَنَا أَنَّهُ رَكِبَ فِي بَعْضِ الأَيَّامِ لِيُقْتَدَى بِهِ فِي فِعْلِهِ وَكِلاَ الْحَدِيثَيْنِ مُسْتَعْمَلٌ عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{899}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Abbas narrated:"The Prophet stoned the Jamrah on the Day of An-Nahr while riding}}
\hadithdefcmd{tirmidhi}{900}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا رَمَى الْجِمَارَ مَشَى إِلَيْهَا ذَاهِبًا وَرَاجِعًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ بَعْضُهُمْ عَنْ عُبَيْدِ اللَّهِ وَلَمْ يَرْفَعْهُ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ وَقَالَ بَعْضُهُمْ يَرْكَبُ يَوْمَ النَّحْرِ وَيَمْشِي فِي الأَيَّامِ الَّتِي بَعْدَ يَوْمَ النَّحْرِ ‏.‏ قَالَ أَبُو عِيسَى وَكَأَنَّ مَنْ قَالَ هَذَا إِنَّمَا أَرَادَ اتِّبَاعَ النَّبِيِّ صلى الله عليه وسلم فِي فِعْلِهِ لأَنَّهُ إِنَّمَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ رَكِبَ يَوْمَ النَّحْرِ حَيْثُ ذَهَبَ يَرْمِي الْجِمَارَ وَلاَ يَرْمِي يَوْمَ النَّحْرِ إِلاَّ جَمْرَةَ الْعَقَبَةِ ‏.‏\hadithno{900}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Umar narrated:"The Prophet would walk when stoning the Jimar, both going and returning}}
\hadithdefcmd{tirmidhi}{901}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الْمَسْعُودِيُّ، عَنْ جَامِعِ بْنِ شَدَّادٍ أَبِي صَخْرَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ لَمَّا أَتَى عَبْدُ اللَّهِ جَمْرَةَ الْعَقَبَةِ اسْتَبْطَنَ الْوَادِيَ وَاسْتَقْبَلَ الْقِبْلَةَ وَجَعَلَ يَرْمِي الْجَمْرَةَ عَلَى حَاجِبِهِ الأَيْمَنِ ثُمَّ رَمَى بِسَبْعِ حَصَيَاتٍ يُكَبِّرُ مَعَ كُلِّ حَصَاةٍ ثُمَّ قَالَ وَاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ مِنْ هَا هُنَا رَمَى الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ ‏.‏ حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنِ الْمَسْعُودِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ الْفَضْلِ بْنِ عَبَّاسٍ وَابْنِ عَبَّاسٍ وَابْنِ عُمَرَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ مَسْعُودٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ يَخْتَارُونَ أَنْ يَرْمِيَ الرَّجُلُ مِنْ بَطْنِ الْوَادِي بِسَبْعِ حَصَيَاتٍ يُكَبِّرُ مَعَ كُلِّ حَصَاةٍ ‏.‏ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ إِنْ لَمْ يُمْكِنْهُ أَنْ يَرْمِيَ مِنْ بَطْنِ الْوَادِي رَمَى مِنْ حَيْثُ قَدَرَ عَلَيْهِ وَإِنْ لَمْ يَكُنْ فِي بَطْنِ الْوَادِي ‏.‏\hadithno{901}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdur-Rahman bin Yazid narrated:"When Abdullah went to stone Jamrat Al-Aqabah, he went to the middle of the valley, faced the Ka'bah, and proceeded to stone the Jamrah at its southern wall. Then he stoned with seven pebbles, saying: "Allahu Akbar" with each pebble. Then he said: 'By Allah except Whom none is worthy of worship. This is where the one stoned to whom Surat Al-Baqarah was revealed}}
\hadithdefcmd{tirmidhi}{902}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَعَلِيُّ بْنُ خَشْرَمٍ، قَالاَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي زِيَادٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا جُعِلَ رَمْىُ الْجِمَارِ وَالسَّعْىُ بَيْنَ الصَّفَا وَالْمَرْوَةِ لإِقَامَةِ ذِكْرِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{902}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Aishah narrated that:The Prophet said: "Stoning the Jimari and Sa'i between As-Safa and Al-Marwah are only done for the establishment of Allah's remembrance}}
\hadithdefcmd{tirmidhi}{903}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنْ أَيْمَنَ بْنِ نَابِلٍ، عَنْ قُدَامَةَ بْنِ عَبْدِ اللَّهِ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَرْمِي الْجِمَارَ عَلَى نَاقَةٍ لَيْسَ ضَرْبٌ وَلاَ طَرْدٌ وَلاَ إِلَيْكَ إِلَيْكَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ حَنْظَلَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ قُدَامَةَ بْنِ عَبْدِ اللَّهِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَإِنَّمَا يُعْرَفُ هَذَا الْحَدِيثُ مِنْ هَذَا الْوَجْهِ وَهُوَ حَدِيثُ أَيْمَنَ بْنِ نَابِلٍ وَهُوَ ثِقَةٌ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏\hadithno{903}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Qudamah bin Abdullah said:"I saw the Prophet stoning the Jimar upon his she-camel; there was no hitting, nor crowding, nor: 'Look out! Look out}}
\hadithdefcmd{tirmidhi}{904}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَحَرْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم عَامَ الْحُدَيْبِيَةِ الْبَقَرَةَ عَنْ سَبْعَةٍ وَالْبَدَنَةَ عَنْ سَبْعَةٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَبِي هُرَيْرَةَ وَعَائِشَةَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ يَرَوْنَ الْجَزُورَ عَنْ سَبْعَةٍ وَالْبَقَرَةَ عَنْ سَبْعَةٍ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ ‏.‏ وَرُوِيَ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّ الْبَقَرَةَ عَنْ سَبْعَةٍ وَالْجَزُورَ عَنْ عَشَرَةٍ ‏.‏ وَهُوَ قَوْلُ إِسْحَاقَ وَاحْتَجَّ بِهَذَا الْحَدِيثِ ‏.‏ وَحَدِيثُ ابْنِ عَبَّاسٍ إِنَّمَا نَعْرِفُهُ مِنْ وَجْهٍ وَاحِدٍ ‏.‏\hadithno{904}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir narrated:"We slaughtered with the Messenger of Allah during the year of Al-Hudaibiyah: a cow for seven, and a Badanah for seven}}
\hadithdefcmd{tirmidhi}{905}{حَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ حُسَيْنِ بْنِ وَاقِدٍ، عَنْ عِلْبَاءَ بْنِ أَحْمَرَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ ‏.‏ فَحَضَرَ الأَضْحَى فَاشْتَرَكْنَا فِي الْبَقَرَةِ سَبْعَةً وَفِي الْجَزُورِ عَشَرَةً ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَهُوَ حَدِيثُ حُسَيْنِ بْنِ وَاقِدٍ ‏.‏\hadithno{905}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Abbas narrated:"We were with the Prophet on a journey (on the Day of) Adha, so seven of us shared in a cow, and ten for a camel}}
\hadithdefcmd{tirmidhi}{906}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ قَتَادَةَ، عَنْ أَبِي حَسَّانَ الأَعْرَجِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَلَّدَ نَعْلَيْنِ وَأَشْعَرَ الْهَدْىَ فِي الشِّقِّ الأَيْمَنِ بِذِي الْحُلَيْفَةِ وَأَمَاطَ عَنْهُ الدَّمَ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو حَسَّانَ الأَعْرَجُ اسْمُهُ مُسْلِمٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ يَرَوْنَ الإِشْعَارَ ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ قَالَ أَبُو عِيسَى سَمِعْتُ يُوسُفَ بْنَ عِيسَى يَقُولُ سَمِعْتُ وَكِيعًا يَقُولُ حِينَ رَوَى هَذَا الْحَدِيثَ قَالَ لاَ تَنْظُرُوا إِلَى قَوْلِ أَهْلِ الرَّأْىِ فِي هَذَا فَإِنَّ الإِشْعَارَ سُنَّةٌ وَقَوْلَهُمْ بِدْعَةٌ ‏.‏ قَالَ وَسَمِعْتُ أَبَا السَّائِبِ يَقُولُ كُنَّا عِنْدَ وَكِيعٍ فَقَالَ لِرَجُلٍ عِنْدَهُ مِمَّنْ يَنْظُرُ فِي الرَّأْىِ أَشْعَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَيَقُولُ أَبُو حَنِيفَةَ هُوَ مُثْلَةٌ ‏.‏ قَالَ الرَّجُلُ فَإِنَّهُ قَدْ رُوِيَ عَنْ إِبْرَاهِيمَ النَّخَعِيِّ أَنَّهُ قَالَ الإِشْعَارُ مُثْلَةٌ ‏.‏ قَالَ فَرَأَيْتُ وَكِيعًا غَضِبَ غَضَبًا شَدِيدًا وَقَالَ أَقُولُ لَكَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَتَقُولُ قَالَ إِبْرَاهِيمُ مَا أَحَقَّكَ بِأَنْ تُحْبَسَ ثُمَّ لاَ تَخْرُجَ حَتَّى تَنْزِعَ عَنْ قَوْلِكَ هَذَا ‏.‏\hadithno{906}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Ibn Abbas narrated:"The Prophet garlanded two sandals and marked the Hadi on the right side at Dhul-Hulaifah, and removed the blood from it}}
\hadithdefcmd{tirmidhi}{907}{حَدَّثَنَا قُتَيْبَةُ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا يَحْيَى بْنُ الْيَمَانِ، عَنْ سُفْيَانَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اشْتَرَى هَدْيَهُ مِنْ قُدَيْدٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ الثَّوْرِيِّ إِلاَّ مِنْ حَدِيثِ يَحْيَى بْنِ الْيَمَانِ ‏.‏ وَرُوِيَ عَنْ نَافِعٍ أَنَّ ابْنَ عُمَرَ اشْتَرَى هَدْيَهُ مِنْ قُدَيْدٍ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ ‏.‏\hadithno{907}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated:"The Prophet purchased his Hadi in Qudaid}}
\hadithdefcmd{tirmidhi}{908}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ فَتَلْتُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ لَمْ يُحْرِمْ وَلَمْ يَتْرُكْ شَيْئًا مِنَ الثِّيَابِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ قَالُوا إِذَا قَلَّدَ الرَّجُلُ الْهَدْىَ وَهُوَ يُرِيدُ الْحَجَّ لَمْ يَحْرُمْ عَلَيْهِ شَيْءٌ مِنَ الثِّيَابِ وَالطِّيبِ حَتَّى يُحْرِمَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا قَلَّدَ الرَّجُلُ هَدْيَهُ فَقَدْ وَجَبَ عَلَيْهِ مَا وَجَبَ عَلَى الْمُحْرِمِ ‏.‏\hadithno{908}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"I twisted the garlands for the Hadi of the Prophet, then he did not assume Ihram, nor did he avoid any clothing}}
\hadithdefcmd{tirmidhi}{909}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَفْتِلُ قَلاَئِدَ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم كُلَّهَا غَنَمًا ثُمَّ لاَ يُحْرِمُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ يَرَوْنَ تَقْلِيدَ الْغَنَمِ ‏.‏\hadithno{909}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"I twisted the garlands for all of the Hadi of the Messenger of Allah, which were sheep, then he did not assume Ihram}}
\hadithdefcmd{tirmidhi}{910}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ نَاجِيَةَ الْخُزَاعِيِّ، صَاحِبِ بُدْنِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ قُلْتُ يَا رَسُولَ اللَّهِ كَيْفَ أَصْنَعُ بِمَا عَطِبَ مِنَ الْبُدْنِ قَالَ ‏ "‏ انْحَرْهَا ثُمَّ اغْمِسْ نَعْلَهَا فِي دَمِهَا ثُمَّ خَلِّ بَيْنَ النَّاسِ وَبَيْنَهَا فَيَأْكُلُوهَا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ ذُؤَيْبٍ أَبِي قَبِيصَةَ الْخُزَاعِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ نَاجِيَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ قَالُوا فِي هَدْىِ التَّطَوُّعِ إِذَا عَطِبَ لاَ يَأْكُلُ هُوَ وَلاَ أَحَدٌ مِنْ أَهْلِ رُفْقَتِهِ وَيُخَلَّى بَيْنَهُ وَبَيْنَ النَّاسِ يَأْكُلُونَهُ وَقَدْ أَجْزَأَ عَنْهُ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالُوا إِنْ أَكَلَ مِنْهُ شَيْئًا غَرِمَ بِقَدْرِ مَا أَكَلَ مِنْهُ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا أَكَلَ مِنْ هَدْىِ التَّطَوُّعِ شَيْئًا فَقَدْ ضَمِنَ الَّذِي أَكَلَ ‏.‏\hadithno{910}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Najiyah Al-Khuza'i (the Companion of the Messenger of Allah) said:"I said: 'O Messenger of Allah! What should be done with the afflicted among the Hadi?' He said: 'Slaughter them, then dip their sandals in their blood, then leave them so that the people can eat them}}
\hadithdefcmd{tirmidhi}{911}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى رَجُلاً يَسُوقُ بَدَنَةً فَقَالَ لَهُ ‏"‏ ارْكَبْهَا ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّهَا بَدَنَةٌ ‏.‏ قَالَ لَهُ فِي الثَّالِثَةِ أَوْ فِي الرَّابِعَةِ ‏"‏ ارْكَبْهَا وَيْحَكَ ‏"‏ ‏.‏ أَوْ ‏"‏ وَيْلَكَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي هُرَيْرَةَ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَخَّصَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ فِي رُكُوبِ الْبَدَنَةِ إِذَا احْتَاجَ إِلَى ظَهْرِهَا ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ يَرْكَبُ مَا لَمْ يُضْطَرَّ إِلَيْهَا ‏.‏\hadithno{911}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated:That the Prophet saw a man driving his Badanah so he said to him: "Ride it." He said: "O Messenger of Allah! It is a Badanah." So on the third or fourth time he said to him: "Ride it. And woe to you}}
\hadithdefcmd{tirmidhi}{912}{حَدَّثَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا رَمَى النَّبِيُّ صلى الله عليه وسلم الْجَمْرَةَ نَحَرَ نُسُكَهُ ثُمَّ نَاوَلَ الْحَالِقَ شِقَّهُ الأَيْمَنَ فَحَلَقَهُ فَأَعْطَاهُ أَبَا طَلْحَةَ ثُمَّ نَاوَلَهُ شِقَّهُ الأَيْسَرَ فَحَلَقَهُ فَقَالَ ‏ "‏ اقْسِمْهُ بَيْنَ النَّاسِ ‏"‏ ‏.‏ حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ هِشَامٍ، نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{912}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Anas bin Malik narrted:"When the Messenger of Allah stoned the Jamrah, he slaughtered his sacrifice, then he presented the barber the right side (of his head) and he shaved it, then he gave (the hair) to Abu Talhah. Then he presented the left side to him and he shaved it. Then he said: 'Divide it (the hair) among the people}}
\hadithdefcmd{tirmidhi}{913}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ حَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَحَلَقَ طَائِفَةٌ مِنْ أَصْحَابِهِ وَقَصَّرَ بَعْضُهُمْ ‏.‏ قَالَ ابْنُ عُمَرَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ رَحِمَ اللَّهُ الْمُحَلِّقِينَ ‏"‏ ‏.‏ مَرَّةً أَوْ مَرَّتَيْنِ ثُمَّ قَالَ ‏"‏ وَالْمُقَصِّرِينَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَابْنِ أُمِّ الْحُصَيْنِ وَمَارِبَ وَأَبِي سَعِيدٍ وَأَبِي مَرْيَمَ وَحُبْشِيِّ بْنِ جُنَادَةَ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ يَخْتَارُونَ لِلرَّجُلِ أَنْ يَحْلِقَ رَأْسَهُ وَإِنْ قَصَّرَ يَرَوْنَ أَنَّ ذَلِكَ يُجْزِئُ عَنْهُ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{913}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar narrated that:The Messenger of Allah said: "May Allah have mercy upon those who shaved" saying it one or two times, then he said: "And those who shortened}}
\hadithdefcmd{tirmidhi}{914}{حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى الْجُرَشِيُّ الْبَصْرِيُّ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ خِلاَسِ بْنِ عَمْرٍو، عَنْ عَلِيٍّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تَحْلِقَ الْمَرْأَةُ رَأْسَهَا ‏.‏\hadithno{914}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Ali narrated:"The Messenger of Allah prohibited that a woman should shave her head}}
\hadithdefcmd{tirmidhi}{915}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، عَنْ هَمَّامٍ، عَنْ خِلاَسٍ، نَحْوَهُ ‏.‏ وَلَمْ يَذْكُرْ فِيهِ عَنْ عَلِيٍّ، ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَلِيٍّ فِيهِ اضْطِرَابٌ ‏.‏ وَرُوِيَ هَذَا الْحَدِيثُ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ قَتَادَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ تَحْلِقَ الْمَرْأَةُ رَأْسَهَا ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ لاَ يَرَوْنَ عَلَى الْمَرْأَةِ حَلْقًا وَيَرَوْنَ أَنَّ عَلَيْهَا التَّقْصِيرَ ‏.‏\hadithno{915}\hadithgrade{Zubair Ali Zai: Hasan}\hadithtrans{(Another chain) with similar (as no. 914) from Khilas:But he did not mention "from Ali}}
\hadithdefcmd{tirmidhi}{916}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ حَلَقْتُ قَبْلَ أَنْ أَذْبَحَ فَقَالَ ‏"‏ اذْبَحْ وَلاَ حَرَجَ ‏"‏ ‏.‏ وَسَأَلَهُ آخَرُ فَقَالَ نَحَرْتُ قَبْلَ أَنْ أَرْمِيَ قَالَ ‏"‏ ارْمِ وَلاَ حَرَجَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَجَابِرٍ وَابْنِ عَبَّاسٍ وَابْنِ عُمَرَ وَأُسَامَةَ بْنِ شَرِيكٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ بْنِ عَمْرٍو حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا قَدَّمَ نُسُكًا قَبْلَ نُسُكٍ فَعَلَيْهِ دَمٌ ‏.‏\hadithno{916}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin Amr narrated:"A man asked the Messenger of Allah: 'I shaved before slaughtering.' So he said: 'Slaughter, and there is no harm.' Another man asked him: 'I performed the sacrifice before stoning.' He said: 'Stone, and there is no harm}}
\hadithdefcmd{tirmidhi}{917}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا مَنْصُورٌ يَعْنِي ابْنَ زَاذَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ طَيَّبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَبْلَ أَنْ يُحْرِمَ وَيَوْمَ النَّحْرِ قَبْلَ أَنْ يَطُوفَ بِالْبَيْتِ بِطِيبٍ فِيهِ مِسْكٌ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ يَرَوْنَ أَنَّ الْمُحْرِمَ إِذَا رَمَى جَمْرَةَ الْعَقَبَةِ يَوْمَ النَّحْرِ وَذَبَحَ وَحَلَقَ أَوْ قَصَّرَ فَقَدْ حَلَّ لَهُ كُلُّ شَيْءٍ حَرُمَ عَلَيْهِ إِلاَّ النِّسَاءَ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَدْ رُوِيَ عَنْ عُمَرَ بْنِ الْخَطَّابِ أَنَّهُ قَالَ حَلَّ لَهُ كُلُّ شَيْءٍ إِلاَّ النِّسَاءَ وَالطِّيبَ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَهُوَ قَوْلُ أَهْلِ الْكُوفَةِ ‏.‏\hadithno{917}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"I put perfume with musk in it on the Messenger of Allah before he assumed Ihram, and on the Day of An-Nahr before he performed Tawaf around the House}}
\hadithdefcmd{tirmidhi}{918}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الْفَضْلِ بْنِ عَبَّاسٍ، قَالَ أَرْدَفَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ جَمْعٍ إِلَى مِنًى فَلَمْ يَزَلْ يُلَبِّي حَتَّى رَمَى الْجَمْرَةَ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَابْنِ مَسْعُودٍ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْفَضْلِ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ الْحَاجَّ لاَ يَقْطَعُ التَّلْبِيَةَ حَتَّى يَرْمِيَ الْجَمْرَةَ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{918}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Al-Fadl bin Abbas narrated:"I was a companion rider with the Messenger of Allah from Jam to Mina. He did not cease saying the Talbiyah until stoning Jamrat Al-Aqabah}}
\hadithdefcmd{tirmidhi}{919}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا هُشَيْمٌ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، يَرْفَعُ الْحَدِيثَ أَنَّهُ كَانَ يُمْسِكُ عَنِ التَّلْبِيَةِ، فِي الْعُمْرَةِ إِذَا اسْتَلَمَ الْحَجَرَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ قَالُوا لاَ يَقْطَعُ الْمُعْتَمِرُ التَّلْبِيَةَ حَتَّى يَسْتَلِمَ الْحَجَرَ ‏.‏ وَقَالَ بَعْضُهُمْ إِذَا انْتَهَى إِلَى بُيُوتِ مَكَّةَ قَطَعَ التَّلْبِيَةَ ‏.‏ وَالْعَمَلُ عَلَى حَدِيثِ النَّبِيِّ صلى الله عليه وسلم وَبِهِ يَقُولُ سُفْيَانُ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{919}\hadithgrade{Ahmad Muhammad Shakir: Sahih Muquf; Al-Albani: Sahih Muquf; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:(that the Prophet): "Would stop saying the Talbiyah during "Umrah when he touched the (Black) Stone}}
\hadithdefcmd{tirmidhi}{920}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنِ ابْنِ عَبَّاسٍ، وَعَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَخَّرَ طَوَافَ الزِّيَارَةِ إِلَى اللَّيْلِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ فِي أَنْ يُؤَخَّرَ طَوَافُ الزِّيَارَةِ إِلَى اللَّيْلِ وَاسْتَحَبَّ بَعْضُهُمْ أَنْ يَزُورَ يَوْمَ النَّحْرِ وَوَسَّعَ بَعْضُهُمْ أَنْ يُؤَخَّرَ وَلَوْ إِلَى آخِرِ أَيَّامِ مِنًى ‏.‏\hadithno{920}\hadithgrade{Ahmad Muhammad Shakir: Shadh; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"The Prophet delayed the visiting Tawaf until the night}}
\hadithdefcmd{tirmidhi}{921}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ يَنْزِلُونَ الأَبْطَحَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَبِي رَافِعٍ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ صَحِيحٌ حَسَنٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ عَبْدِ الرَّزَّاقِ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ ‏.‏ وَقَدِ اسْتَحَبَّ بَعْضُ أَهْلِ الْعِلْمِ نُزُولَ الأَبْطَحِ مِنْ غَيْرِ أَنْ يَرَوْا ذَلِكَ وَاجِبًا إِلاَّ مَنْ أَحَبَّ ذَلِكَ ‏.‏ قَالَ الشَّافِعِيُّ وَنُزُولُ الأَبْطَحِ لَيْسَ مِنَ النُّسُكِ فِي شَيْءٍ إِنَّمَا هُوَ مَنْزِلٌ نَزَلَهُ النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{921}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Umar narrated:"The Prophet, Abu Bakr, Umar, and Uthman would camp at Al-Abtah}}
\hadithdefcmd{tirmidhi}{922}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَيْسَ التَّحْصِيبُ بِشَيْءٍ إِنَّمَا هُوَ مَنْزِلٌ نَزَلَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى التَّحْصِيبُ نُزُولُ الأَبْطَحِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{922}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated:"At-Tahsib is nothing, it is only a place that the Messenger of Allah camped at}}
\hadithdefcmd{tirmidhi}{923}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا حَبِيبٌ الْمُعَلِّمُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ إِنَّمَا نَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الأَبْطَحَ لأَنَّهُ كَانَ أَسْمَحَ لِخُرُوجِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، نَحْوَهُ ‏.‏\hadithno{923}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"The Messenger of Allah only camped at Al-Abtah because it was easier for his departure}}
\hadithdefcmd{tirmidhi}{924}{حَدَّثَنَا مُحَمَّدُ بْنُ طَرِيفٍ الْكُوفِيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ مُحَمَّدِ بْنِ سُوقَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ رَفَعَتِ امْرَأَةٌ صَبِيًّا لَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ أَلِهَذَا حَجٌّ قَالَ ‏ "‏ نَعَمْ وَلَكِ أَجْرٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ حَدِيثُ جَابِرٍ حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{924}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir bin Abdullah narrated:"A woman held a boy of hers up for the Messenger of Allah and said: 'O Messenger of Allah! Is there Hajj for this one' He said: 'Yes, and you will be rewarded}}
\hadithdefcmd{tirmidhi}{925}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ مُحَمَّدِ بْنِ يُوسُفَ، عَنِ السَّائِبِ بْنِ يَزِيدَ، قَالَ حَجَّ بِي أَبِي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ وَأَنَا ابْنُ سَبْعِ سِنِينَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{925}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{As-Sa'ib bin Yazid narrated:"My father took me for Hajj with the Messenger of Allah during the Farewell Hajj, and I was seven years old}}
\hadithdefcmd{tirmidhi}{926}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا قَزَعَةُ بْنُ سُوَيْدٍ الْبَاهِلِيُّ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ يَعْنِي حَدِيثَ مُحَمَّدِ بْنِ طَرِيفٍ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ وَقَدْ أَجْمَعَ أَهْلُ الْعِلْمِ أَنَّ الصَّبِيَّ إِذَا حَجَّ قَبْلَ أَنْ يُدْرِكَ فَعَلَيْهِ الْحَجُّ إِذَا أَدْرَكَ لاَ تُجْزِئُ عَنْهُ تِلْكَ الْحَجَّةُ عَنْ حَجَّةِ الإِسْلاَمِ وَكَذَلِكَ الْمَمْلُوكُ إِذَا حَجَّ فِي رِقِّهِ ثُمَّ أُعْتِقَ فَعَلَيْهِ الْحَجُّ إِذَا وَجَدَ إِلَى ذَلِكَ سَبِيلاً وَلاَ يُجْزِئُ عَنْهُ مَا حَجَّ فِي حَالِ رِقِّهِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{926}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{(Another chain) from Jabir bin Abdullah:From the Prophet, with similar (Hadith of Muhammad bin Tarif no)}}
\hadithdefcmd{tirmidhi}{927}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ الْوَاسِطِيُّ، قَالَ سَمِعْتُ ابْنَ نُمَيْرٍ، عَنْ أَشْعَثَ بْنِ سَوَّارٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ كُنَّا إِذَا حَجَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم فَكُنَّا نُلَبِّي عَنِ النِّسَاءِ وَنَرْمِي عَنِ الصِّبْيَانِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ أَجْمَعَ أَهْلُ الْعِلْمِ عَلَى أَنَّ الْمَرْأَةَ لاَ يُلَبِّي عَنْهَا غَيْرُهَا بَلْ هِيَ تُلَبِّي عَنْ نَفْسِهَا وَيُكْرَهُ لَهَا رَفْعُ الصَّوْتِ بِالتَّلْبِيَةِ ‏.‏\hadithno{927}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Jabir narrated:"When we performed our Hajj with the Prophet we would say the Talbiyah for the women and we would stone for the boys}}
\hadithdefcmd{tirmidhi}{928}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي ابْنُ شِهَابٍ، قَالَ حَدَّثَنِي سُلَيْمَانُ بْنُ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنِ الْفَضْلِ بْنِ عَبَّاسٍ، أَنَّ امْرَأَةً، مِنْ خَثْعَمٍ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ أَبِي أَدْرَكَتْهُ فَرِيضَةُ اللَّهِ فِي الْحَجِّ وَهُوَ شَيْخٌ كَبِيرٌ لاَ يَسْتَطِيعُ أَنْ يَسْتَوِيَ عَلَى ظَهْرِ الْبَعِيرِ ‏.‏ قَالَ ‏ "‏ حُجِّي عَنْهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَبُرَيْدَةَ وَحُصَيْنِ بْنِ عَوْفٍ وَأَبِي رَزِينٍ الْعُقَيْلِيِّ وَسَوْدَةَ بِنْتِ زَمْعَةَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْفَضْلِ بْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرُوِيَ عَنِ ابْنِ عَبَّاسٍ عَنْ حُصَيْنِ بْنِ عَوْفٍ الْمُزَنِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرُوِيَ عَنِ ابْنِ عَبَّاسٍ أَيْضًا عَنْ سِنَانِ بْنِ عَبْدِ اللَّهِ الْجُهَنِيِّ عَنْ عَمَّتِهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَرُوِيَ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذِهِ الرِّوَايَاتِ فَقَالَ أَصَحُّ شَيْءٍ فِي هَذَا الْبَابِ مَا رَوَى ابْنُ عَبَّاسٍ عَنِ الْفَضْلِ بْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ مُحَمَّدٌ وَيَحْتَمِلُ أَنْ يَكُونَ ابْنُ عَبَّاسٍ سَمِعَهُ مِنَ الْفَضْلِ وَغَيْرِهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ثُمَّ رَوَى هَذَا عَنِ النَّبِيِّ صلى الله عليه وسلم وَأَرْسَلَهُ وَلَمْ يَذْكُرِ الَّذِي سَمِعَهُ مِنْهُ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ صَحَّ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا الْبَابِ غَيْرُ حَدِيثٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَبِهِ يَقُولُ الثَّوْرِيُّ وَابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ يَرَوْنَ أَنْ يُحَجَّ عَنِ الْمَيِّتِ ‏.‏ وَقَالَ مَالِكٌ إِذَا أَوْصَى أَنْ يُحَجَّ عَنْهُ حُجَّ عَنْهُ ‏.‏ وَقَدْ رَخَّصَ بَعْضُهُمْ أَنْ يُحَجَّ عَنِ الْحَىِّ إِذَا كَانَ كَبِيرًا أَوْ بِحَالٍ لاَ يَقْدِرُ أَنْ يَحُجَّ ‏.‏ وَهُوَ قَوْلُ ابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ ‏.‏\hadithno{928}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Al-Fadl bin Abbas narrated:"A woman from Khath'am said: 'O Messenger of Allah! My father has lived until Allah has made Hajj obligatory, and he is an elderly man who is not able to sit on the back of a camel.' So he (pbuh) said: 'Perform Hajj for him}}
\hadithdefcmd{tirmidhi}{929}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَطَاءٍ، ‏.‏ قَالَ وَحَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَطَاءٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ إِنَّ أُمِّي مَاتَتْ وَلَمْ تَحُجَّ أَفَأَحُجُّ عَنْهَا قَالَ ‏ "‏ نَعَمْ حُجِّي عَنْهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{929}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin Buraidah narrated from his father who said:"A woman came to the Prophet and said: 'My mother died and she did not perform Hajj should I perform Hajj on her behalf?' He said: 'Yes, perform Hajj on her behalf}}
\hadithdefcmd{tirmidhi}{930}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنِ النُّعْمَانِ بْنِ سَالِمٍ، عَنْ عَمْرِو بْنِ أَوْسٍ، عَنْ أَبِي رَزِينٍ الْعُقَيْلِيِّ، أَنَّهُ أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أَبِي شَيْخٌ كَبِيرٌ لاَ يَسْتَطِيعُ الْحَجَّ وَلاَ الْعُمْرَةَ وَلاَ الظَّعْنَ ‏.‏ قَالَ ‏ "‏ حُجَّ عَنْ أَبِيكَ وَاعْتَمِرْ ‏"‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَإِنَّمَا ذُكِرَتِ الْعُمْرَةُ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا الْحَدِيثِ أَنْ يَعْتَمِرَ الرَّجُلُ عَنْ غَيْرِهِ ‏.‏ وَأَبُو رَزِينٍ الْعُقَيْلِيُّ اسْمُهُ لَقِيطُ بْنُ عَامِرٍ ‏.‏\hadithno{930}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Razin Al-Uqaili narrated:That he went to the Prophet and said: "O Messenger of Allah! My father is an elderly man who is not able to perform Hajj nor Umrah nor undertake a journey.' He said: 'Perform Hajj on behalf of your father and perform Umrah}}
\hadithdefcmd{tirmidhi}{931}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ، عَنِ الْحَجَّاجِ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سُئِلَ عَنِ الْعُمْرَةِ أَوَاجِبَةٌ هِيَ قَالَ ‏ "‏ لاَ وَأَنْ تَعْتَمِرُوا هُوَ أَفْضَلُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ قَوْلُ بَعْضِ أَهْلِ الْعِلْمِ قَالُوا الْعُمْرَةُ لَيْسَتْ بِوَاجِبَةٍ ‏.‏ وَكَانَ يُقَالُ هُمَا حَجَّانِ الْحَجُّ الأَكْبَرُ يَوْمَ النَّحْرِ وَالْحَجُّ الأَصْغَرُ الْعُمْرَةُ ‏.‏ وَقَالَ الشَّافِعِيُّ الْعُمْرَةُ سُنَّةٌ لاَ نَعْلَمُ أَحَدًا رَخَّصَ فِي تَرْكِهَا وَلَيْسَ فِيهَا شَيْءٌ ثَابِتٌ بِأَنَّهَا تَطَوُّعٌ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِإِسْنَادٍ وَهُوَ ضَعِيفٌ لاَ تَقُومُ بِمِثْلِهِ الْحُجَّةُ وَقَدْ بَلَغَنَا عَنِ ابْنِ عَبَّاسٍ أَنَّهُ كَانَ يُوجِبُهَا ‏.‏ قَالَ أَبُو عِيسَى كُلُّهُ كَلاَمُ الشَّافِعِيِّ ‏.‏\hadithno{931}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Jabir narrated that:The Prophet was asked about whether Umrah was obligatory? He said: "No. But if you perform Umrah it is more virtuous}}
\hadithdefcmd{tirmidhi}{932}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا زِيَادُ بْنُ عَبْدِ اللَّهِ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ دَخَلَتِ الْعُمْرَةُ فِي الْحَجِّ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سُرَاقَةَ بْنِ مَالِكِ بْنِ جُعْشُمٍ وَجَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ ‏.‏ وَمَعْنَى هَذَا الْحَدِيثِ أَنْ لاَ بَأْسَ بِالْعُمْرَةِ فِي أَشْهُرِ الْحَجِّ ‏.‏ وَهَكَذَا قَالَ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَمَعْنَى هَذَا الْحَدِيثِ أَنَّ أَهْلَ الْجَاهِلِيَّةِ كَانُوا لاَ يَعْتَمِرُونَ فِي أَشْهُرِ الْحَجِّ فَلَمَّا جَاءَ الإِسْلاَمُ رَخَّصَ النَّبِيُّ صلى الله عليه وسلم فِي ذَلِكَ فَقَالَ ‏"‏ دَخَلَتِ الْعُمْرَةُ فِي الْحَجِّ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏ يَعْنِي لاَ بَأْسَ بِالْعُمْرَةِ فِي أَشْهُرِ الْحَجِّ ‏.‏ وَأَشْهُرُ الْحَجِّ شَوَّالٌ وَذُو الْقَعْدَةِ وَعَشْرٌ مِنْ ذِي الْحِجَّةِ لاَ يَنْبَغِي لِلرَّجُلِ أَنْ يُهِلَّ بِالْحَجِّ إِلاَّ فِي أَشْهُرِ الْحَجِّ ‏.‏ وَأَشْهُرُ الْحُرُمِ رَجَبٌ وَذُو الْقَعْدَةِ وَذُو الْحِجَّةِ وَالْمُحَرَّمُ ‏.‏ هَكَذَا قَالَ غَيْرُ وَاحِدٍ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ ‏.‏\hadithno{932}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated:That the Prophet said: "Umrah has been entered into Hajj until the Day of Resurrection}}
\hadithdefcmd{tirmidhi}{933}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعُمْرَةُ إِلَى الْعُمْرَةِ تُكَفِّرُ مَا بَيْنَهُمَا وَالْحَجُّ الْمَبْرُورُ لَيْسَ لَهُ جَزَاءٌ إِلاَّ الْجَنَّةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{933}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"Umrah to 'Umrah atones for the sins between them, and for A1-Hajj Al-Mabrur there is no reward except Paradise}}
\hadithdefcmd{tirmidhi}{934}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَمْرِو بْنِ أَوْسٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرٍ أَنْ يُعْمِرَ عَائِشَةَ مِنَ التَّنْعِيمِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{934}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Amr bin Aws narrated from Abdur-Rahman bin Abi Bakr:"The Prophet ordered Abdur-RAhman bin Abi Bakr to (accompany) Aishah to perform Umrah from At-Tan'im}}
\hadithdefcmd{tirmidhi}{935}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ مُزَاحِمِ بْنِ أَبِي مُزَاحِمٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ عَبْدِ اللَّهِ، عَنْ مُحَرِّشٍ الْكَعْبِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ مِنَ الْجِعْرَانَةِ لَيْلاً مُعْتَمِرًا فَدَخَلَ مَكَّةَ لَيْلاً فَقَضَى عُمْرَتَهُ ثُمَّ خَرَجَ مِنْ لَيْلَتِهِ فَأَصْبَحَ بِالْجِعْرَانَةِ كَبَائِتٍ فَلَمَّا زَالَتِ الشَّمْسُ مِنَ الْغَدِ خَرَجَ مِنْ بَطْنِ سَرِفَ حَتَّى جَاءَ مَعَ الطَّرِيقِ طَرِيقِ جَمْعٍ بِبَطْنِ سَرِفَ فَمِنْ أَجْلِ ذَلِكَ خَفِيَتْ عُمْرَتُهُ عَلَى النَّاسِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَلاَ نَعْرِفُ لِمُحَرِّشٍ الْكَعْبِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم غَيْرَ هَذَا الْحَدِيثِ ‏.‏\hadithno{935}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Muharrish Al-Kabi narrated:"The Messenger of Allah left Al-Ji'irranah during the night for Umrah, then he entered Makkah during he night and performed his Umrah. Then he left there during the night, then he was in Al-Ji'irranah by the morning, as if he had spent the night. When the sun passed the zenith in the morning he left from the midst of Sarif until he came on a road from amidst Sarif. It is because of this that his Umrah was concealed from the people}}
\hadithdefcmd{tirmidhi}{936}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ أَبِي بَكْرِ بْنِ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عُرْوَةَ، قَالَ سُئِلَ ابْنُ عُمَرَ فِي أَىِّ شَهْرٍ اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ فِي رَجَبٍ ‏.‏ قَالَ فَقَالَتْ عَائِشَةُ مَا اعْتَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلاَّ وَهُوَ مَعَهُ تَعْنِي ابْنَ عُمَرَ وَمَا اعْتَمَرَ فِي شَهْرِ رَجَبٍ قَطُّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ سَمِعْتُ مُحَمَّدًا يَقُولُ حَبِيبُ بْنُ أَبِي ثَابِتٍ لَمْ يَسْمَعْ مِنْ عُرْوَةَ بْنِ الزُّبَيْرِ ‏.‏\hadithno{936}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Urwah said:Ibn Umar was asked: In which month did the Messenger of Allah perform Umrah? He said: 'During Rajab.' So Aishah said: 'The Messenger of Allah did not perform Umrah except that he was with him - meaning Ibn Umar - and he did not ever perform Umrah in the month of Rajab}}
\hadithdefcmd{tirmidhi}{937}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا شَيْبَانُ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اعْتَمَرَ أَرْبَعًا إِحْدَاهُنَّ فِي رَجَبٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{937}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ibn Umar narrated:"The Prophet performed Umrah four times, one of them was during Rajab}}
\hadithdefcmd{tirmidhi}{938}{حَدَّثَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، هُوَ السَّلُولِيُّ الْكُوفِيُّ عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اعْتَمَرَ فِي ذِي الْقَعْدَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{938}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Al-Bara narrated:"The Prophet performed Umrah during Dhul-Qa'dah}}
\hadithdefcmd{tirmidhi}{939}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ بْنِ يَزِيدَ، عَنِ ابْنِ أُمِّ مَعْقِلٍ، عَنْ أُمِّ مَعْقِلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ عُمْرَةٌ فِي رَمَضَانَ تَعْدِلُ حَجَّةً ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَجَابِرٍ وَأَبِي هُرَيْرَةَ وَأَنَسٍ وَوَهْبِ بْنِ خَنْبَشٍ ‏.‏ قَالَ أَبُو عِيسَى وَيُقَالُ هَرَمُ بْنُ خَنْبَشٍ ‏.‏ قَالَ بَيَانٌ وَجَابِرٌ عَنِ الشَّعْبِيِّ عَنْ وَهْبِ بْنِ خَنْبَشٍ ‏.‏ وَقَالَ دَاوُدُ الأَوْدِيُّ عَنِ الشَّعْبِيِّ عَنْ هَرَمِ بْنِ خَنْبَشٍ ‏.‏ وَوَهْبٌ أَصَحُّ ‏.‏ وَحَدِيثُ أُمِّ مَعْقِلٍ حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ قَدْ ثَبَتَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّ عُمْرَةً فِي رَمَضَانَ تَعْدِلُ حَجَّةً ‏.‏ قَالَ إِسْحَاقُ مَعْنَى هَذَا الْحَدِيثِ مِثْلُ مَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ مَنْ قَرَأَْ ‏:‏ ‏(‏ قُلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ فَقَدْ قَرَأَ ثُلُثَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{939}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umm Ma'qil narrated that:The Prophet said: "Umrah during Ramadan is equal to Hajj}}
\hadithdefcmd{tirmidhi}{940}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا حَجَّاجٌ الصَّوَّافُ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ عِكْرِمَةَ، قَالَ حَدَّثَنِي الْحَجَّاجُ بْنُ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كُسِرَ أَوْ عَرِجَ فَقَدْ حَلَّ وَعَلَيْهِ حَجَّةٌ أُخْرَى ‏"‏ ‏.‏ فَذَكَرْتُ ذَلِكَ لأَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ فَقَالاَ صَدَقَ ‏.‏ حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، عَنِ الْحَجَّاجِ، مِثْلَهُ ‏.‏ قَالَ وَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ هَكَذَا رَوَاهُ غَيْرُ وَاحِدٍ عَنِ الْحَجَّاجِ الصَّوَّافِ نَحْوَ هَذَا الْحَدِيثِ ‏.‏ وَرَوَى مَعْمَرٌ وَمُعَاوِيَةُ بْنُ سَلاَّمٍ هَذَا الْحَدِيثَ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ عَنْ عِكْرِمَةَ عَنْ عَبْدِ اللَّهِ بْنِ رَافِعٍ عَنِ الْحَجَّاجِ بْنِ عَمْرٍو عَنِ النَّبِيِّ صلى الله عليه وسلم هَذَا الْحَدِيثَ ‏.‏ وَحَجَّاجٌ الصَّوَّافُ لَمْ يَذْكُرْ فِي حَدِيثِهِ عَبْدَ اللَّهِ بْنَ رَافِعٍ ‏.‏ وَحَجَّاجٌ ثِقَةٌ حَافِظٌ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏ وَسَمِعْتُ مُحَمَّدًا يَقُولُ رِوَايَةُ مَعْمَرٍ وَمُعَاوِيَةَ بْنِ سَلاَّمٍ أَصَحُّ ‏.‏ حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عِكْرِمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ رَافِعٍ، عَنِ الْحَجَّاجِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{940}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ikrimah narrated from Al-Hajjaj bin Amr who narrated that:The Messenger of Allah said: "Whoever suffers a fracture or becomes lame them he (leaves the state of Ihram) and is required to perform another Hajj." I (Ikrimah) mentioned that to Abu Hurairah and Ibn Abbas and they said: "He told the truth}}
\hadithdefcmd{tirmidhi}{941}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ الْبَغْدَادِيُّ، حَدَّثَنَا عَبَّادُ بْنُ عَوَّامٍ، عَنْ هِلاَلِ بْنِ خَبَّابٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ ضُبَاعَةَ بِنْتَ الزُّبَيْرِ، أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي أُرِيدُ الْحَجَّ أَفَأَشْتَرِطُ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَتْ كَيْفَ أَقُولُ قَالَ ‏"‏ قُولِي لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ لَبَّيْكَ مَحِلِّي مِنَ الأَرْضِ حَيْثُ تَحْبِسُنِي ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَأَسْمَاءَ بِنْتِ أَبِي بَكْرٍ وَعَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ يَرَوْنَ الاِشْتِرَاطَ فِي الْحَجِّ وَيَقُولُونَ إِنِ اشْتَرَطَ فَعَرَضَ لَهُ مَرَضٌ أَوْ عُذْرٌ فَلَهُ أَنْ يَحِلَّ وَيَخْرُجَ مِنْ إِحْرَامِهِ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَلَمْ يَرَ بَعْضُ أَهْلِ الْعِلْمِ الاِشْتِرَاطَ فِي الْحَجِّ وَقَالُوا إِنِ اشْتَرَطَ فَلَيْسَ لَهُ أَنْ يَخْرُجَ مِنْ إِحْرَامِهِ ‏.‏ وَيَرَوْنَهُ كَمَنْ لَمْ يَشْتَرِطْ ‏.‏\hadithno{941}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Abbas narrated:"Duba'ah bint Az-Zubair came to the prophet and said: 'O Messenger of Allah! I want to perform Hajj so should I state a condition?' He said: 'Yes.' She asked: 'So how should I say it?' He said: 'Say; "Labbaik Allahumma labbaika mahilli minal Ard haithu tahbisuni (I respond to Your call O Allah, I respond to Your call, I will exit Ihram any where on the earth where You prevent me)}}
\hadithdefcmd{tirmidhi}{942}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنِي مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّهُ كَانَ يُنْكِرُ الاِشْتِرَاطَ فِي الْحَجِّ وَيَقُولُ أَلَيْسَ حَسْبُكُمْ سُنَّةَ نَبِيِّكُمْ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{942}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Salim narrated that :His father disliked making a condition during Hajj and he said: 'Is not the Sunnah of your Prophet enough for you?}}
\hadithdefcmd{tirmidhi}{943}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ ذَكَرْتُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ صَفِيَّةَ بِنْتَ حُيَىٍّ حَاضَتْ فِي أَيَّامِ مِنًى ‏.‏ فَقَالَ ‏"‏ أَحَابِسَتُنَا هِيَ ‏"‏ ‏.‏ قَالُوا إِنَّهَا قَدْ أَفَاضَتْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَلاَ إِذًا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّ الْمَرْأَةَ إِذَا طَافَتْ طَوَافَ الزِّيَارَةِ ثُمَّ حَاضَتْ فَإِنَّهَا تَنْفِرُ وَلَيْسَ عَلَيْهَا شَيْءٌ ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{943}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"It was mentioned to the Messenger of Allah that Safiyyah bint Huyai got her menses during the days of Mina, so he said: "Will she prevent us (from departing)?" They said: "She has done (Tawaf) Al-Ifadah/" So the Messenger of Allah said: "In that case there is no harm}}
\hadithdefcmd{tirmidhi}{944}{حَدَّثَنَا أَبُو عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ مَنْ حَجَّ الْبَيْتَ فَلْيَكُنْ آخِرُ عَهْدِهِ بِالْبَيْتِ إِلاَّ الْحُيَّضَ وَرَخَّصَ لَهُنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏\hadithno{944}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Umar said:"Whoever performs Hajj to the House, then let the last of their acts be at the House, except for menstruating women. The Messenger of Allah gave them permission (to leave)." (Sahih Mawquf)}}
\hadithdefcmd{tirmidhi}{945}{\hadithno{945}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{946}{حَدَّثَنَا نَصْرُ بْنُ عَبْدِ الرَّحْمَنِ الْكُوفِيُّ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنِ الْحَجَّاجِ بْنِ أَرْطَاةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ الْمُغِيرَةِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْبَيْلَمَانِيِّ، عَنْ عَمْرِو بْنِ أَوْسٍ، عَنِ الْحَارِثِ بْنِ عَبْدِ اللَّهِ بْنِ أَوْسٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ حَجَّ هَذَا الْبَيْتَ أَوِ اعْتَمَرَ فَلْيَكُنْ آخِرُ عَهْدِهِ بِالْبَيْتِ ‏"‏ ‏.‏ فَقَالَ لَهُ عُمَرُ خَرَرْتَ مِنْ يَدَيْكَ سَمِعْتَ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَمْ تُخْبِرْنَا بِهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ الْحَارِثِ بْنِ عَبْدِ اللَّهِ بْنِ أَوْسٍ حَدِيثٌ غَرِيبٌ ‏.‏ وَهَكَذَا رَوَى غَيْرُ وَاحِدٍ عَنِ الْحَجَّاجِ بْنِ أَرْطَاةَ مِثْلَ هَذَا وَقَدْ خُولِفَ الْحَجَّاجُ فِي بَعْضِ هَذَا الإِسْنَادِ ‏.‏\hadithno{946}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Al-Harith bin Abdullah bin Aws said:"I heard the Prophet saying: 'Whoever performs Hajj to this House, or Umrah, then let the last of his acts be at the House'" So Umar said: "May your hand be humiliated! You heard this from the Messenger of Allah but did not inform us of it?}}
\hadithdefcmd{tirmidhi}{947}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الْحَجَّاجِ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَنَ الْحَجَّ وَالْعُمْرَةَ فَطَافَ لَهُمَا طَوَافًا وَاحِدًا ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ قَالُوا الْقَارِنُ يَطُوفُ طَوَافًا وَاحِدًا ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ يَطُوفُ طَوَافَيْنِ وَيَسْعَى سَعْيَيْنِ ‏.‏ وَهُوَ قَوْلُ الثَّوْرِيِّ وَأَهْلِ الْكُوفَةِ ‏.‏\hadithno{947}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir narrated:"The Messenger of Allah performed Qaran for Hajj and Umrah, so he performed one Tawaf for both of them}}
\hadithdefcmd{tirmidhi}{948}{حَدَّثَنَا خَلاَّدُ بْنُ أَسْلَمَ الْبَغْدَادِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَحْرَمَ بِالْحَجِّ وَالْعُمْرَةِ أَجْزَأَهُ طَوَافٌ وَاحِدٌ وَسَعْىٌ وَاحِدٌ عَنْهُمَا حَتَّى يَحِلَّ مِنْهُمَا جَمِيعًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ تَفَرَّدَ بِهِ الدَّرَاوَرْدِيُّ عَلَى ذَلِكَ اللَّفْظِ ‏.‏ وَقَدْ رَوَاهُ غَيْرُ وَاحِدٍ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ وَلَمْ يَرْفَعُوهُ ‏.‏ وَهُوَ أَصَحُّ ‏.‏\hadithno{948}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Umar narrated that:The Messenger of Allah said: "Whoever assumes Ihram for Hajj and Umrah, then it is acceptable for him to perform one Tawaf and one Sa'I for them both, until he exits Ihram for both of them together}}
\hadithdefcmd{tirmidhi}{949}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حُمَيْدٍ، سَمِعَ السَّائِبَ بْنَ يَزِيدَ، عَنِ الْعَلاَءِ بْنِ الْحَضْرَمِيِّ يَعْنِي مَرْفُوعًا، قَالَ ‏ "‏ يَمْكُثُ الْمُهَاجِرُ بَعْدَ قَضَاءِ نُسُكِهِ بِمَكَّةَ ثَلاَثًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ هَذَا الْوَجْهِ بِهَذَا الإِسْنَادِ مَرْفُوعًا ‏.‏\hadithno{949}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Al-Ala bin Al-Hadrami narrated :(that the Prophet said): "The Muhajir may stay for three (days) in Makkah after carrying out his rites}}
\hadithdefcmd{tirmidhi}{950}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا قَفَلَ مِنْ غَزْوَةٍ أَوْ حَجٍّ أَوْ عُمْرَةٍ فَعَلاَ فَدْفَدًا مِنَ الأَرْضِ أَوْ شَرَفًا كَبَّرَ ثَلاَثًا ثُمَّ قَالَ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَيْءٍ قَدِيرٌ آيِبُونَ تَائِبُونَ عَابِدُونَ سَائِحُونَ لِرَبِّنَا حَامِدُونَ صَدَقَ اللَّهُ وَعْدَهُ وَنَصَرَ عَبْدَهُ وَهَزَمَ الأَحْزَابَ وَحْدَهُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ الْبَرَاءِ وَأَنَسٍ وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{950}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Umar said:"When the Prophet would come home from a battle, or Hajj, or Umrah, when he was it a tract of land or raised area he would say 'Allahu Akbar (Allah is Most Great)' three times, then say: 'La Ilaha illallah Wahdahu la sharika lahu, lahul-mulku wa lahul-Hamdu wa Huwa ala kulli shai'in qadir. A'ibuna ta'ibun abidun saa'ihuna li Rabbina Hamiduna, Sadaqallahu wa'dahu wa nasara abdahu wa hazamal-ahzab Wahdah. (None has the right to be worshiped but Allah Alone without partners. To Him belongs the sovereignty and to Him belongs the praise, and He has power over all things. We are returning, repenting, worshipping, traveling for our Lord, and we are praising. Allah has told the truth, and kept His promise and helped His worshipper, and routed the confederates, Alone)}}
\hadithdefcmd{tirmidhi}{951}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَرَأَى رَجُلاً قَدْ سَقَطَ عَنْ بَعِيرِهِ فَوُقِصَ فَمَاتَ وَهُوَ مُحْرِمٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَكَفِّنُوهُ فِي ثَوْبَيْهِ وَلاَ تُخَمِّرُوا رَأْسَهُ فَإِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ يُهِلُّ أَوْ يُلَبِّي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا مَاتَ الْمُحْرِمُ انْقَطَعَ إِحْرَامُهُ وَيُصْنَعُ بِهِ كَمَا يُصْنَعُ بِغَيْرِ الْمُحْرِمِ ‏.‏\hadithno{951}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated:"We were with the Messenger of Allah on a journey when he saw a man fall from his camel, his neck was broken and he died, and he was a Muhrim. So the Messenger of Allah said: 'Wash him with water and Sidr, and shroud him in his garments, and do not cover his head. For indeed he will be resurrected on the Day of Judgment saying the Talbiyah}}
\hadithdefcmd{tirmidhi}{952}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ نُبَيْهِ بْنِ وَهْبٍ، أَنَّ عُمَرَ بْنَ عُبَيْدِ اللَّهِ بْنِ مَعْمَرٍ، اشْتَكَى عَيْنَيْهِ وَهُوَ مُحْرِمٌ فَسَأَلَ أَبَانَ بْنَ عُثْمَانَ فَقَالَ اضْمِدْهُمَا بِالصَّبِرِ فَإِنِّي سَمِعْتُ عُثْمَانَ بْنَ عَفَّانَ، يَذْكُرُهَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اضْمِدْهُمَا بِالصَّبِرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ لاَ يَرَوْنَ بَأْسًا أَنْ يَتَدَاوَى الْمُحْرِمُ بِدَوَاءٍ مَا لَمْ يَكُنْ فِيهِ طِيبٌ ‏.‏\hadithno{952}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Nubaih bin Wahb narrated that :Umar bin Ubaidullah bin Ma'mar was complaining about his eyes while he was a Muhrim. He asked Aban bin Uthman about it and he said: "Bandage it with some aloes, for I heard Uthman bin Affan mentioning that the Messenger of Allah said: 'Bandage it with aloes}}
\hadithdefcmd{tirmidhi}{953}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، وَابْنِ أَبِي نَجِيحٍ، وَحُمَيْدٍ الأَعْرَجِ، وَعَبْدِ الْكَرِيمِ، عَنْ مُجَاهِدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ بِهِ وَهُوَ بِالْحُدَيْبِيَةِ قَبْلَ أَنْ يَدْخُلَ مَكَّةَ وَهُوَ مُحْرِمٌ وَهُوَ يُوقِدُ تَحْتَ قِدْرٍ وَالْقَمْلُ يَتَهَافَتُ عَلَى وَجْهِهِ فَقَالَ ‏"‏ أَتُؤْذِيكَ هَوَامُّكَ هَذِهِ ‏"‏ ‏.‏ فَقَالَ نَعَمْ ‏.‏ فَقَالَ ‏"‏ احْلِقْ وَأَطْعِمْ فَرَقًا بَيْنَ سِتَّةِ مَسَاكِينَ ‏"‏ ‏.‏ وَالْفَرَقُ ثَلاَثَةُ آصُعٍ ‏"‏ أَوْ صُمْ ثَلاَثَةَ أَيَّامٍ أَوِ انْسُكْ نَسِيكَةً ‏"‏ ‏.‏ قَالَ ابْنُ أَبِي نَجِيحٍ ‏"‏ أَوِ اذْبَحْ شَاةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ الْمُحْرِمَ إِذَا حَلَقَ رَأْسَهُ أَوْ لَبِسَ مِنَ الثِّيَابِ مَا لاَ يَنْبَغِي لَهُ أَنْ يَلْبَسَ فِي إِحْرَامِهِ أَوْ تَطَيَّبَ فَعَلَيْهِ الْكَفَّارَةُ بِمِثْلِ مَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{953}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abdur-Rahman bin Abu Laila narrated from Ka'b bin Ujrah that:The Prophet passed by him while he was at Al-Hudaibiyah, before entering Makkah, and he was a Muhrim. He had lit a fire under a cooking pot and lice were falling all over his face. So he (the Prophet) said: "Have these lice of yours troubled you?" He said: "Yes." He said: "Shave and feed six of the poor with a Faraq" and a Faraq is three Sa - "or fast three days, or slaughter a sacrifice." Ibn Abi Najih (one of the narrators) said: "Or slaughter a sheep}}
\hadithdefcmd{tirmidhi}{954}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ أَبِيهِ، عَنْ أَبِي الْبَدَّاحِ بْنِ عَدِيٍّ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَرْخَصَ لِلرِّعَاءِ أَنْ يَرْمُوا يَوْمًا وَيَدَعُوا يَوْمًا ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رَوَى ابْنُ عُيَيْنَةَ ‏.‏ وَرَوَى مَالِكُ بْنُ أَنَسٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ عَنْ أَبِيهِ عَنْ أَبِي الْبَدَّاحِ بْنِ عَاصِمِ بْنِ عَدِيٍّ عَنْ أَبِيهِ ‏.‏ وَرِوَايَةُ مَالِكٍ أَصَحُّ ‏.‏ وَقَدْ رَخَّصَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ لِلرِّعَاءِ أَنْ يَرْمُوا يَوْمًا وَيَدَعُوا يَوْمًا وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏\hadithno{954}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abi Al-Baddah bin Adi narrated from his father:"The Prophet permitted the shepherds to stone a day and leave a day}}
\hadithdefcmd{tirmidhi}{955}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَالِكُ بْنُ أَنَسٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ أَبِي الْبَدَّاحِ بْنِ عَاصِمِ بْنِ عَدِيٍّ، عَنْ أَبِيهِ، قَالَ رَخَّصَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِرِعَاءِ الإِبِلِ فِي الْبَيْتُوتَةِ أَنْ يَرْمُوا يَوْمَ النَّحْرِ ثُمَّ يَجْمَعُوا رَمْىَ يَوْمَيْنِ بَعْدَ يَوْمِ النَّحْرِ فَيَرْمُونَهُ فِي أَحَدِهِمَا ‏.‏ قَالَ مَالِكٌ ظَنَنْتُ أَنَّهُ قَالَ فِي الأَوَّلِ مِنْهُمَا ثُمَّ يَرْمُونَ يَوْمَ النَّفْرِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَهُوَ أَصَحُّ مِنْ حَدِيثِ ابْنِ عُيَيْنَةَ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ ‏.‏\hadithno{955}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abi Al-Baddah bin Asim bin Adi narrated from his father:"The Messenger of Allah permitted the camel herders who were in the camp (at Mina) to stone on the Day of An-Nahr then to gather the stoning of two days after the Day of An-Nahr, so that they stoned them during one of them." Malik said: "I think that he said about the first of them: 'They they should stone on the day of departure}}
\hadithdefcmd{tirmidhi}{956}{حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ بْنِ عَبْدِ الْوَارِثِ، حَدَّثَنِي أَبِي، حَدَّثَنَا سَلِيمُ بْنُ حَيَّانَ، قَالَ سَمِعْتُ مَرْوَانَ الأَصْفَرَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ عَلِيًّا، قَدِمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْيَمَنِ فَقَالَ ‏"‏ بِمَ أَهْلَلْتَ ‏"‏ ‏.‏ قَالَ أَهْلَلْتُ بِمَا أَهَلَّ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ ‏"‏ لَوْلاَ أَنَّ مَعِي هَدْيًا لأَحْلَلْتُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{956}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated:"When Ali returned to the Messenger of Allah from Yemen he said: 'For what did you intended the Talbiyah?' He replied: 'I intended the Talbiyah for what the Messenger of Allah announced it.' So he (pbuh) said: 'If I did not have the Hadi with me then I would exit Ihram}}
\hadithdefcmd{tirmidhi}{957}{حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ بْنِ عَبْدِ الْوَارِثِ، حَدَّثَنَا أَبِي، عَنْ أَبِيهِ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ يَوْمِ الْحَجِّ الأَكْبَرِ فَقَالَ ‏ "‏ يَوْمُ النَّحْرِ ‏"‏ ‏.‏\hadithno{957}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ali narrated:"I asked the Messenger of Allah about the day of Al-Hajj Al-Akbar and he said: 'They Day of An-Nahr}}
\hadithdefcmd{tirmidhi}{958}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ يَوْمُ الْحَجِّ الأَكْبَرِ يَوْمُ النَّحْرِ ‏.‏ قَالَ أَبُو عِيسَى وَلَمْ يَرْفَعْهُ وَهَذَا أَصَحُّ مِنَ الْحَدِيثِ الأَوَّلِ وَرِوَايَةُ ابْنِ عُيَيْنَةَ مَوْقُوفًا أَصَحُّ مِنْ رِوَايَةِ مُحَمَّدِ بْنِ إِسْحَاقَ مَرْفُوعًا ‏.‏ هَكَذَا رَوَى غَيْرُ وَاحِدٍ مِنَ الْحُفَّاظِ عَنْ أَبِي إِسْحَاقَ عَنِ الْحَارِثِ عَنْ عَلِيٍّ مَوْقُوفًا ‏.‏ وَقَدْ رَوَى شُعْبَةُ عَنْ أَبِي إِسْحَاقَ قَالَ عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ عَنِ الْحَارِثِ عَنْ عَلِيٍّ مَوْقُوفًا ‏.‏\hadithno{958}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ali narrated:"They day of Al-Hajj Al-Akbar is the Day of An-Nahr}}
\hadithdefcmd{tirmidhi}{959}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنِ ابْنِ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ أَبِيهِ، أَنَّ ابْنَ عُمَرَ، كَانَ يُزَاحِمُ عَلَى الرُّكْنَيْنِ زِحَامًا مَا رَأَيْتُ أَحَدًا مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم يَفْعَلُهُ ‏.‏ فَقُلْتُ يَا أَبَا عَبْدِ الرَّحْمَنِ إِنَّكَ تُزَاحِمُ عَلَى الرُّكْنَيْنِ زِحَامًا مَا رَأَيْتُ أَحَدًا مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم يُزَاحِمُ عَلَيْهِ ‏.‏ فَقَالَ إِنْ أَفْعَلْ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ مَسْحَهُمَا كَفَّارَةٌ لِلْخَطَايَا ‏"‏ ‏.‏ وَسَمِعْتُهُ يَقُولُ ‏"‏ مَنْ طَافَ بِهَذَا الْبَيْتِ أُسْبُوعًا فَأَحْصَاهُ كَانَ كَعِتْقِ رَقَبَةٍ ‏"‏ ‏.‏ وَسَمِعْتُهُ يَقُولُ ‏"‏ لاَ يَضَعُ قَدَمًا وَلاَ يَرْفَعُ أُخْرَى إِلاَّ حَطَّ اللَّهُ عَنْهُ بِهَا خَطِيئَةً وَكَتَبَ لَهُ بِهَا حَسَنَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى حَمَّادُ بْنُ زَيْدٍ عَنْ عَطَاءِ بْنِ السَّائِبِ عَنِ ابْنِ عُبَيْدِ بْنِ عُمَيْرٍ عَنِ ابْنِ عُمَرَ نَحْوَهُ ‏.‏ وَلَمْ يَذْكُرْ فِيهِ عَنْ أَبِيهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{959}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Ubaid bin Umair narrated from his father:"Ibn Umar was clinging on the two corners (in a manner that I had not seen any of the Companions of the Prophet doing) so I said: 'O Abu Abdur-Rahman! You are clinging on the two corners in a manner that I have not seen any of the Companions of the Prophet clining.' So he said: 'I do it because I heard the Messenger of Allah saying: "Touching them atones for sins." And I heard him saying: "Whoever performs Tawaf around this House seven times and he keeps track of it, then it is as if he freed a slave." And I heard him saying: "One foot is not put down, nor another raised except that Allah removes a sin from him and records a good merit for him}}
\hadithdefcmd{tirmidhi}{960}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَرِيرٌ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الطَّوَافُ حَوْلَ الْبَيْتِ مِثْلُ الصَّلاَةِ إِلاَّ أَنَّكُمْ تَتَكَلَّمُونَ فِيهِ فَمَنْ تَكَلَّمَ فِيهِ فَلاَ يَتَكَلَّمَنَّ إِلاَّ بِخَيْرٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِي هَذَا الْحَدِيثُ عَنِ ابْنِ طَاوُسٍ وَغَيْرِهِ عَنْ طَاوُسٍ عَنِ ابْنِ عَبَّاسٍ مَوْقُوفًا ‏.‏ وَلاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ عَطَاءِ بْنِ السَّائِبِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ يَسْتَحِبُّونَ أَنْ لاَ يَتَكَلَّمَ الرَّجُلُ فِي الطَّوَافِ إِلاَّ لَحَاجَةٍ أَوْ بِذِكْرِ اللَّهِ تَعَالَى أَوْ مِنَ الْعِلْمِ ‏.‏\hadithno{960}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Abbas narrated that :the Prophet said: "Tawaf around the House is similar to Salat except that you talk during it. So whoever talks in it, then let him not say but good}}
\hadithdefcmd{tirmidhi}{961}{حَدَّثَنَا قُتَيْبَةُ، عَنْ جَرِيرٍ، عَنِ ابْنِ خُثَيْمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْحَجَرِ ‏ "‏ وَاللَّهِ لَيَبْعَثَنَّهُ اللَّهُ يَوْمَ الْقِيَامَةِ لَهُ عَيْنَانِ يُبْصِرُ بِهِمَا وَلِسَانٌ يَنْطِقُ بِهِ يَشْهَدُ عَلَى مَنِ اسْتَلَمَهُ بِحَقٍّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{961}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Abbas narrated that:The Messenger of Allah said about the (Black) Stone: "By Allah! Allah will raise it on the Day of Resurrection with two eyes by which it sees and a tongue that it speaks with, testifying to whoever touched it in truth}}
\hadithdefcmd{tirmidhi}{962}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ فَرْقَدٍ السَّبَخِيِّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَدَّهِنُ بِالزَّيْتِ وَهُوَ مُحْرِمٌ غَيْرَ الْمُقَتَّتِ ‏.‏ قَالَ أَبُو عِيسَى الْمُقَتَّتُ الْمُطَيَّبُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ فَرْقَدٍ السَّبَخِيِّ عَنْ سَعِيدِ بْنِ جُبَيْرٍ ‏.‏ وَقَدْ تَكَلَّمَ يَحْيَى بْنُ سَعِيدٍ فِي فَرْقَدٍ السَّبَخِيِّ وَرَوَى عَنْهُ النَّاسُ ‏.‏\hadithno{962}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated:"The Prophet would apply oil that is not scented (Ghair Muqattat) while he was a Muhrim}}
\hadithdefcmd{tirmidhi}{963}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا خَلاَّدُ بْنُ يَزِيدَ الْجُعْفِيُّ، حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّهَا كَانَتْ تَحْمِلُ مِنْ مَاءِ زَمْزَمَ وَتُخْبِرُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَحْمِلُهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{963}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Hisham bin Urwah narrated :from his father about Aishah, that she would carry some Zamzam water, and she would say: "Indeed the Messenger of Allah would carry it}}
\hadithdefcmd{tirmidhi}{964}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَمُحَمَّدُ بْنُ الْوَزِيرِ الْوَاسِطِيُّ الْمَعْنَى، وَاحِدٌ، قَالاَ حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، قَالَ قُلْتُ لأَنَسِ بْنِ مَالِكٍ حَدِّثْنِي بِشَيْءٍ، عَقَلْتَهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَيْنَ صَلَّى الظُّهْرَ يَوْمَ التَّرْوِيَةِ قَالَ بِمِنًى ‏.‏ قَالَ قُلْتُ فَأَيْنَ صَلَّى الْعَصْرَ يَوْمَ النَّفْرِ قَالَ بِالأَبْطَحِ ‏.‏ ثُمَّ قَالَ افْعَلْ كَمَا يَفْعَلُ أُمَرَاؤُكَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ يُسْتَغْرَبُ مِنْ حَدِيثِ إِسْحَاقَ بْنِ يُوسُفَ الأَزْرَقِ عَنِ الثَّوْرِيِّ ‏.‏\hadithno{964}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdul-Aziz bin Rufai narrated:"I said to Anas bin Malik: 'Narrated something to me that you understand about where the Messenger of Allah performed Zuhr on the Day of Tarwiyah.' He said: 'In Mina.'" "I said: 'So where did he pray Asr on the day of departure?' He said: 'In Al-Abtab.' Then he said: 'Do what your leaders do}}
