% Auto-generated chapter 37 for nasai
% Hadiths in this chapter: 167

\hadithdefcmd{nasai}{3966}{أَخْبَرَنَا هَارُونُ بْنُ مُحَمَّدِ بْنِ بَكَّارِ بْنِ بِلاَلٍ، عَنْ مُحَمَّدِ بْنِ عِيسَى، - وَهُوَ ابْنُ سُمَيْعٍ - قَالَ حَدَّثَنَا حُمَيْدٌ الطَّوِيلُ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ الْمُشْرِكِينَ حَتَّى يَشْهَدُوا أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ فَإِذَا شَهِدُوا أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ وَصَلَّوْا صَلاَتَنَا وَاسْتَقْبَلُوا قِبْلَتَنَا وَأَكَلُوا ذَبَائِحَنَا فَقَدْ حَرُمَتْ عَلَيْنَا دِمَاؤُهُمْ وَأَمْوَالُهُمْ إِلاَّ بِحَقِّهَا ‏"‏ ‏.‏\hadithno{3966}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik that:The Prophet [SAW] said: "I have been commanded to fight the idolators until they bear witness to La ilaha illallah (there is none worthy of worship except Allah) and that Muhammad is His slave and Messenger. If they bear witness to La ilaha illallah and that Muhammad is His slave and Messenger, and they pray as we pray and face our Qiblah, and eat our slaughtered animals, then their blood and wealth becomes forbidden to us except for a right that is due}}
\hadithdefcmd{nasai}{3967}{أَخْبَرَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ نُعَيْمٍ، قَالَ أَنْبَأَنَا حِبَّانُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَشْهَدُوا أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ فَإِذَا شَهِدُوا أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ وَاسْتَقْبَلُوا قِبْلَتَنَا وَأَكَلُوا ذَبِيحَتَنَا وَصَلَّوْا صَلاَتَنَا فَقَدْ حَرُمَتْ عَلَيْنَا دِمَاؤُهُمْ وَأَمْوَالُهُمْ إِلاَّ بِحَقِّهَا لَهُمْ مَا لِلْمُسْلِمِينَ وَعَلَيْهِمْ مَا عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{3967}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih}\hadithtrans{It was narrated from Anas bin Malik that :The Messenger of Allah [SAW] said: "I have been commanded to fight the idolators until they bear witness to La ilaha illallah (there is none worthy of worship except Allah) and that Muhammad is the Messenger of Allah [SAW]. If they bear witness to La ilaha illallah and that Muhammad is the Messenger of Allah [SAW], and they face our Qiblah, eat our slaughtered animals, and pray as we do, then their blood and wealth become forbidden except for a right that is due, and they will have the same rights and obligations as the Muslims}}
\hadithdefcmd{nasai}{3968}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، قَالَ أَنْبَأَنَا حُمَيْدٌ، قَالَ سَأَلَ مَيْمُونُ بْنُ سِيَاهٍ أَنَسَ بْنَ مَالِكٍ قَالَ يَا أَبَا حَمْزَةَ مَا يُحَرِّمُ دَمَ الْمُسْلِمِ وَمَالَهُ فَقَالَ مَنْ شَهِدَ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ وَاسْتَقْبَلَ قِبْلَتَنَا وَصَلَّى صَلاَتَنَا وَأَكَلَ ذَبِيحَتَنَا فَهُوَ مُسْلِمٌ لَهُ مَا لِلْمُسْلِمِينَ وَعَلَيْهِ مَا عَلَى الْمُسْلِمِينَ ‏.‏\hadithno{3968}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Maimun bin Siyah asked Anas bin Malik:"O Abu Hamzah, what makes the blood and wealth of a Muslim forbidden?" He said: "Whoever bears witness to La ilaha illallah (there is none worthy of worship except Allah) and that Muhammad is the Messenger of Allah [SAW], faces our Qiblah, prays as we pray, and eats our slaughtered animals, he is a Muslim, and has the same rights and obligations as the Muslims}}
\hadithdefcmd{nasai}{3969}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، قَالَ حَدَّثَنَا عِمْرَانُ أَبُو الْعَوَّامِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم ارْتَدَّتِ الْعَرَبُ فَقَالَ عُمَرُ يَا أَبَا بَكْرٍ كَيْفَ تُقَاتِلُ الْعَرَبَ فَقَالَ أَبُو بَكْرٍ إِنَّمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَشْهَدُوا أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ وَيُقِيمُوا الصَّلاَةَ وَيُؤْتُوا الزَّكَاةَ ‏"‏ ‏.‏ وَاللَّهِ لَوْ مَنَعُونِي عَنَاقًا مِمَّا كَانُوا يُعْطُونَ رَسُولَ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَيْهِ ‏.‏ قَالَ عُمَرُ فَلَمَّا رَأَيْتُ رَأْىَ أَبِي بَكْرٍ قَدْ شُرِحَ عَلِمْتُ أَنَّهُ الْحَقُّ ‏.‏\hadithno{3969}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas bin Malik said:"When the Messenger of Allah [SAW] died, the 'Arabs apostatized, so 'Umar said: 'O Abu Bakr, how can you fight the 'Arabs?' Abu Bakr said: 'The Messenger of Allah [SAW] said: "I have been commanded to fight the people until they bear witness to La ilaha illallah (there is none worthy of worship except Allah) and that I am the Messenger of Allah, and they establish Salah and pay Zakah." By Allah, if they withhold from me a young goat that they used to give to the Messenger of Allah [SAW], I will fight them for it.' 'Umar said: 'By Allah, as soon as I realized how certain Abu Bakr was, I knew that it was the truth}}
\hadithdefcmd{nasai}{3970}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ لَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَاسْتُخْلِفَ أَبُو بَكْرٍ وَكَفَرَ مَنْ كَفَرَ مِنَ الْعَرَبِ قَالَ عُمَرُ لأَبِي بَكْرٍ كَيْفَ تُقَاتِلُ النَّاسَ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَمَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ عَصَمَ مِنِّي مَالَهُ وَنَفْسَهُ إِلاَّ بِحَقِّهِ وَحِسَابُهُ عَلَى اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ وَاللَّهِ لأُقَاتِلَنَّ مَنْ فَرَّقَ بَيْنَ الصَّلاَةِ وَالزَّكَاةِ فَإِنَّ الزَّكَاةَ حَقُّ الْمَالِ وَاللَّهِ لَوْ مَنَعُونِي عِقَالاً كَانُوا يُؤَدُّونَهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهِ قَالَ عُمَرُ فَوَاللَّهِ مَا هُوَ إِلاَّ أَنِّي رَأَيْتُ اللَّهَ شَرَحَ صَدْرَ أَبِي بَكْرٍ لِلْقِتَالِ فَعَرَفْتُ أَنَّهُ الْحَقُّ ‏.‏\hadithno{3970}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"When the Messenger of Allah [SAW] died and Abu Bakr became the Khalifah after him, and some of the 'Arabs reverted to Kufr, 'Umar said to Abu Bakr: 'How can you fight the people when the Messenger of Allah [SAW] said: I have been commanded to fight the people until they say La ilaha illallah (there is none worthy of worship but Allah). Whoever says La ilaha illallah, his wealth and his life are safe from me except for a right that is due, and his reckoning will be with Allah.?' Abu Bakr said: 'By Allah, I will fight whoever separates Salah and Zakah, for Zakah is the compulsory right to be taken from wealth. By Allah, if they withhold from me a rope that they used to give to the Messenger of Allah [SAW], I will fight them for withholding it.' 'Umar, may Allah be pleased with him, said: 'By Allah, as soon as I realized that Allah has expanded the chest of Abu Bakr for fighting, I knew that it was the truth}}
\hadithdefcmd{nasai}{3971}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَإِذَا قَالُوهَا فَقَدْ عَصَمُوا مِنِّي دِمَاءَهُمْ وَأَمْوَالَهُمْ إِلاَّ بِحَقِّهَا وَحِسَابُهُمْ عَلَى اللَّهِ ‏"‏ ‏.‏ فَلَمَّا كَانَتِ الرِّدَّةُ قَالَ عُمَرُ لأَبِي بَكْرٍ أَتُقَاتِلُهُمْ وَقَدْ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ كَذَا وَكَذَا ‏.‏ فَقَالَ وَاللَّهِ لاَ أُفَرِّقُ بَيْنَ الصَّلاَةِ وَالزَّكَاةِ ‏.‏ وَلأُقَاتِلَنَّ مَنْ فَرَّقَ بَيْنَهُمَا ‏.‏ فَقَاتَلْنَا مَعَهُ فَرَأَيْنَا ذَلِكَ رُشْدًا ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ سُفْيَانُ فِي الزُّهْرِيِّ لَيْسَ بِالْقَوِيِّ وَهُوَ سُفْيَانُ بْنُ حُسَيْنٍ ‏.‏\hadithno{3971}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'I have been commanded to fight the people until they say La ilaha illallah. If they say it then their blood and their wealth are safe from me, except for a right that is due, and their reckoning will be with Allah.' When the people apostatized, 'Umar said to Abu Bakr: 'Will you fight them when you heard the Messenger of Allah [SAW] say such and such?' He said: 'By Allah, I do not separate Salah and Zakah, and I will fight whoever separates them.' So we fought alongside him, and we realized that that was the right thing}}
\hadithdefcmd{nasai}{3972}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَمَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ عَصَمَ مِنِّي مَالَهُ وَنَفْسَهُ إِلاَّ بِحَقِّهِ وَحِسَابُهُ عَلَى اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏ جَمَعَ شُعَيْبُ بْنُ أَبِي حَمْزَةَ الْحَدِيثَيْنِ جَمِيعًا ‏.‏\hadithno{3972}\hadithgrade{Abu Ghuddah: Sahih Mutawatir; Al-Albani: Sahih Mutawatir; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that :The Messenger of Allah [SAW] said: "I have been commanded to fight the people until they say La ilaha illallah (there is none worthy of worship but Allah). Whoever says La ilaha illallah, his wealth and his life are safe from me except for a right that is due, and his reckoning will be with Allah}}
\hadithdefcmd{nasai}{3973}{أَخْبَرَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ الْمُغِيرَةِ، قَالَ حَدَّثَنَا عُثْمَانُ، عَنْ شُعَيْبٍ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ لَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَانَ أَبُو بَكْرٍ بَعْدَهُ وَكَفَرَ مَنْ كَفَرَ مِنَ الْعَرَبِ قَالَ عُمَرُ يَا أَبَا بَكْرٍ كَيْفَ تُقَاتِلُ النَّاسَ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَمَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ فَقَدْ عَصَمَ مِنِّي مَالَهُ وَنَفْسَهُ إِلاَّ بِحَقِّهِ وَحِسَابُهُ عَلَى اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ لأُقَاتِلَنَّ مَنْ فَرَّقَ بَيْنَ الصَّلاَةِ وَالزَّكَاةِ فَإِنَّ الزَّكَاةَ حَقُّ الْمَالِ فَوَاللَّهِ لَوْ مَنَعُونِي عَنَاقًا كَانُوا يُؤَدُّونَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهَا ‏.‏ قَالَ عُمَرُ فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ رَأَيْتُ اللَّهَ شَرَحَ صَدْرَ أَبِي بَكْرٍ لِلْقِتَالِ فَعَرَفْتُ أَنَّهُ الْحَقُّ ‏.‏\hadithno{3973}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"When the Messenger of Allah [SAW] died, and Abu Bakr (became Khalifah) after him, and the 'Arabs reverted to Kufr, 'Umar said: 'O Abu Bakr, how can you fight the people when the Messenger of Allah [SAW] said: I have been commanded to fight the people until they say La ilaha illallah, and whoever says La ilaha illallah, his wealth and his life are safe from me, except for a right that is due, and his reckoning will be with Allah, the Mighty and Sublime?' Abu Bakr said: 'I will fight whoever separates Salah and Zakah, for Zakah is the compulsory right to be taken from wealth. By Allah, if they withhold from me a young goat that they used to give to the Messenger of Allah [SAW], I will fight them for withholding it.' 'Umar said: 'By Allah, as soon as I saw that Allah has expanded the chest of Abu Bakr to fighting, I knew that it was the truth}}
\hadithdefcmd{nasai}{3974}{أَخْبَرَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ الْمُغِيرَةِ، قَالَ حَدَّثَنَا عُثْمَانُ، عَنْ شُعَيْبٍ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَمَنْ قَالَهَا فَقَدْ عَصَمَ مِنِّي نَفْسَهُ وَمَالَهُ إِلاَّ بِحَقِّهِ وَحِسَابُهُ عَلَى اللَّهِ ‏"‏ ‏.‏ خَالَفَهُ الْوَلِيدُ بْنُ مُسْلِمٍ ‏.‏\hadithno{3974}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrated that :The Messenger of Allah [SAW] said: "I have been commanded to fight the people until they say La ilaha illallah, and whoever says it, his life and his wealth are safe from me, except for a right that is due, and his reckoning will be with Allah}}
\hadithdefcmd{nasai}{3975}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنِي شُعَيْبُ بْنُ أَبِي حَمْزَةَ، وَسُفْيَانُ بْنُ عُيَيْنَةَ، وَذَكَرَ، آخَرَ عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ فَأَجْمَعَ أَبُو بَكْرٍ لِقِتَالِهِمْ فَقَالَ عُمَرُ يَا أَبَا بَكْرٍ كَيْفَ تُقَاتِلُ النَّاسَ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَإِذَا قَالُوهَا عَصَمُوا مِنِّي دِمَاءَهُمْ وَأَمْوَالَهُمْ إِلاَّ بِحَقِّهَا ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ لأُقَاتِلَنَّ مَنْ فَرَّقَ بَيْنَ الصَّلاَةِ وَالزَّكَاةِ وَاللَّهِ لَوْ مَنَعُونِي عَنَاقًا كَانُوا يُؤَدُّونَهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَقَاتَلْتُهُمْ عَلَى مَنْعِهَا ‏.‏ قَالَ عُمَرُ فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ رَأَيْتُ اللَّهَ قَدْ شَرَحَ صَدْرَ أَبِي بَكْرٍ لِقِتَالِهِمْ فَعَرَفْتُ أَنَّهُ الْحَقُّ ‏.‏\hadithno{3975}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"So Abu Bakr decided to fight them, then 'Umar said: 'O Abu Bakr, how can you fight the people when the Messenger of Allah [SAW] said: "I have been commanded to fight the people until they say La ilaha illallah, and if they say it, their blood and their wealth will be safe from me except for a right that is due.?' Abu Bakr said: 'I will fight whoever separates prayer and Zakah. By Allah, if they withhold from me a young goat that they used to give to the Messenger of Allah [SAW], I will fight them for withholding it.' 'Umar said: 'By Allah, as soon as I realized that Allah has expanded the chest of Abu Bakr to fight them, I knew that it was the truth}}
\hadithdefcmd{nasai}{3976}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَأَنْبَأَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَإِذَا قَالُوهَا مَنَعُوا مِنِّي دِمَاءَهُمْ وَأَمْوَالَهُمْ إِلاَّ بِحَقِّهَا وَحِسَابُهُمْ عَلَى اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{3976}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'I have been commanded to fight the people until they say La ilaha illallah. If they say it, then their blood and wealth are prohibited for me, except for a right that is due, and their reckoning will be with Allah, the Mighty and Sublime}}
\hadithdefcmd{nasai}{3977}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا يَعْلَى بْنُ عُبَيْدٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، وَعَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالاَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَإِذَا قَالُوهَا مَنَعُوا مِنِّي دِمَاءَهُمْ وَأَمْوَالَهُمْ إِلاَّ بِحَقِّهَا وَحِسَابُهُمْ عَلَى اللَّهِ ‏"‏ ‏.‏\hadithno{3977}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'I have been commanded to fight the people until they say La ilaha illallah. If they say it, then their blood and wealth are prohibited for me, except for a right that is due, and their reckoning will be with Allah}}
\hadithdefcmd{nasai}{3978}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا بْنِ دِينَارٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ عَاصِمٍ، عَنْ زِيَادِ بْنِ قَيْسٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ نُقَاتِلُ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَإِذَا قَالُوا لاَ إِلَهَ إِلاَّ اللَّهُ حَرُمَتْ عَلَيْنَا دِمَاؤُهُمْ وَأَمْوَالُهُمْ إِلاَّ بِحَقِّهَا وَحِسَابُهُمْ عَلَى اللَّهِ ‏"‏ ‏.‏\hadithno{3978}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that :The Messenger of Allah [SAW] said: "We will fight the people until they say La ilaha illallah. If they say La ilaha illallah then their blood and their wealth become forbidden to us, except for a right that is due, and their reckoning will be with Allah}}
\hadithdefcmd{nasai}{3979}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، قَالَ حَدَّثَنَا إِسْرَائِيلُ، عَنْ سِمَاكٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فَجَاءَ رَجُلٌ فَسَارَّهُ فَقَالَ ‏"‏ اقْتُلُوهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَيَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏ قَالَ نَعَمْ وَلَكِنَّمَا يَقُولُهَا تَعَوُّذًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَقْتُلُوهُ فَإِنَّمَا أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَإِذَا قَالُوهَا عَصَمُوا مِنِّي دِمَاءَهُمْ وَأَمْوَالَهُمْ إِلاَّ بِحَقِّهَا وَحِسَابُهُمْ عَلَى اللَّهِ ‏"‏ ‏.‏\hadithno{3979}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that An-Nu'man bin Bashir said:"We were with the Messenger of Allah [SAW] and a man came and whispered to him. He said: 'Kill him.' Then he said: 'Does he bear witness to La ilaha illallah (there is none worthy of worship except Allah)?' He said: 'Yes, but he is only saying it to protect himself.' The Messenger of Allah [SAW] said: 'Do not kill him, for I have been commanded to fight the people until they say La ilaha illallah, and if they say it, their blood and their wealth are safe from me, except for a right that is due, and their reckoning will be with Allah}}
\hadithdefcmd{nasai}{3980}{‏\{‏ أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، ‏\}‏ قَالَ عُبَيْدُ اللَّهِ حَدَّثَنَا إِسْرَائِيلُ، عَنْ سِمَاكٍ، عَنِ النُّعْمَانِ بْنِ سَالِمٍ، عَنْ رَجُلٍ، حَدَّثَهُ قَالَ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ فِي قُبَّةٍ فِي مَسْجِدِ الْمَدِينَةِ وَقَالَ فِيهِ ‏ "‏ إِنَّهُ أُوحِيَ إِلَىَّ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏ نَحْوَهُ ‏.‏\hadithno{3980}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from An-Nu'man bin Salim that:A man said to him: "The Messenger of Allah [SAW] came to us while we were in a tent inside the Masjid of Al-Al-Madinah, and he said to us: 'It has been revealed to me that I should fight the people until they say La ilaha illallah.'" A similar narration}}
\hadithdefcmd{nasai}{3981}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ أَعْيَنَ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا سِمَاكٌ، عَنِ النُّعْمَانِ بْنِ سَالِمٍ، قَالَ سَمِعْتُ أَوْسًا، يَقُولُ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ فِي قُبَّةٍ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{3981}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that An-Nu'man bin Salim said:"I heard Aws say: 'The Messenger of Allah [SAW] came to us when we were in a tent.'" And he quoted the same Hadith}}
\hadithdefcmd{nasai}{3982}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ النُّعْمَانِ بْنِ سَالِمٍ، قَالَ سَمِعْتُ أَوْسًا، يَقُولُ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي وَفْدِ ثَقِيفٍ فَكُنْتُ مَعَهُ فِي قُبَّةٍ فَنَامَ مَنْ كَانَ فِي الْقُبَّةِ غَيْرِي وَغَيْرُهُ فَجَاءَ رَجُلٌ فَسَارَّهُ فَقَالَ ‏"‏ اذْهَبْ فَاقْتُلْهُ ‏"‏ ‏.‏ فَقَالَ ‏"‏ أَلَيْسَ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ ‏"‏ ‏.‏ قَالَ يَشْهَدُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ذَرْهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَإِذَا قَالُوهَا حَرُمَتْ دِمَاؤُهُمْ وَأَمْوَالُهُمْ إِلاَّ بِحَقِّهَا ‏"‏ ‏.‏ قَالَ مُحَمَّدٌ فَقُلْتُ لِشُعْبَةَ أَلَيْسَ فِي الْحَدِيثِ ‏"‏ أَلَيْسَ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ ‏"‏ ‏.‏ قَالَ أَظُنُّهَا مَعَهَا وَلاَ أَدْرِي ‏.‏\hadithno{3982}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that An-Nu'man bin Salim said:"I heard Aws say: 'I came to the Messenger of Allah [SAW] among the delegation of Thaqif and I was with him in a tent. Everyone in the tent had gone to sleep except him and I. A man came and whispered to him, and he said: Go and kill him. Then he said: Does he not bear witness to La ilaha illallah (there is none worthy of worship except Allah) and that I am the Messenger of Allah? He said: He does bear witness to that. The Messenger of Allah [SAW] said: Leave him alone. Then he said: I have been commanded to fight the people until they say La ilaha illallah. If they say it, then their blood and their wealth become forbidden to me, except for a right that is due. (One of the narrators) Muhammad said: I said to Shu'bah: 'Doesn't the Hadith contain: Does he not testify to La ilaha illallah (there is none worthy of worship except Allah) and that I am the Messenger of Allah?' He said: 'I think it is both, but I do not know}}
\hadithdefcmd{nasai}{3983}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَكْرٍ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ أَبِي صَغِيرَةَ، عَنِ النُّعْمَانِ بْنِ سَالِمٍ، أَنَّ عَمْرَو بْنَ أَوْسٍ، أَخْبَرَهُ أَنَّ أَبَاهُ أَوْسًا قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَشْهَدُوا أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ ثُمَّ تَحْرُمُ دِمَاؤُهُمْ وَأَمْوَالُهُمْ إِلاَّ بِحَقِّهَا ‏"‏ ‏.‏\hadithno{3983}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from An-Nu'man bin Salim that:'Amr bin Aws told him that his father Aws said: "The Messenger of Allah [SAW] said: 'I have been commanded to fight the people until they bear witness to La ilaha illallah (there is none worthy of worship except Allah), then their blood and their wealth become forbidden to me, except for a right that is due}}
\hadithdefcmd{nasai}{3984}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، عَنْ ثَوْرٍ، عَنْ أَبِي عَوْنٍ، عَنْ أَبِي إِدْرِيسَ، قَالَ سَمِعْتُ مُعَاوِيَةَ، يَخْطُبُ - وَكَانَ قَلِيلَ الْحَدِيثِ - عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ سَمِعْتُهُ يَخْطُبُ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ كُلُّ ذَنْبٍ عَسَى اللَّهُ أَنْ يَغْفِرَهُ إِلاَّ الرَّجُلُ يَقْتُلُ الْمُؤْمِنَ مُتَعَمِّدًا أَوِ الرَّجُلُ يَمُوتُ كَافِرًا ‏"‏ ‏.‏\hadithno{3984}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Idris said:"I heard Mu'awiyah delivering the Khutbah, and he narrated a few Hadiths from the Messenger of Allah [SAW]." He said: "I heard him delivering a Khutbah and he said: 'I heard the Messenger of Allah [SAW] say: Every sin may be forgiven by Allah except a man who kills a believer deliberately, or a man who dies as a disbeliever}}
\hadithdefcmd{nasai}{3985}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تُقْتَلُ نَفْسٌ ظُلْمًا إِلاَّ كَانَ عَلَى ابْنِ آدَمَ الأَوَّلِ كِفْلٌ مِنْ دَمِهَا وَذَلِكَ أَنَّهُ أَوَّلُ مَنْ سَنَّ الْقَتْلَ ‏"‏ ‏.‏\hadithno{3985}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from 'Abdullah that:The Prophet [SAW] said: "No person is killed wrongfully, but a share of responsibility for his blood will be upon the first son of Adam, because he was the first one to set the precedence, of killing}}
\hadithdefcmd{nasai}{3986}{أَخْبَرَنَا مُحَمَّدُ بْنُ مُعَاوِيَةَ بْنِ مَالَجَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْحَرَّانِيُّ، عَنِ ابْنِ إِسْحَاقَ، عَنْ إِبْرَاهِيمَ بْنِ مُهَاجِرٍ، عَنْ إِسْمَاعِيلَ، مَوْلَى عَبْدِ اللَّهِ بْنِ عَمْرٍو عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَقَتْلُ مُؤْمِنٍ أَعْظَمُ عِنْدَ اللَّهِ مِنْ زَوَالِ الدُّنْيَا ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ إِبْرَاهِيمُ بْنُ الْمُهَاجِرِ لَيْسَ بِالْقَوِيِّ ‏.‏\hadithno{3986}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Amr bin Al-'As said:"The Messenger of Allah [SAW] said: 'By the One in Whose Hand is my soul, killing a believer is more grievous before Allah than the extinction of the whole world}}
\hadithdefcmd{nasai}{3987}{أَخْبَرَنَا يَحْيَى بْنُ حَكِيمٍ الْبَصْرِيُّ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَزَوَالُ الدُّنْيَا أَهْوَنُ عِنْدَ اللَّهِ مِنْ قَتْلِ رَجُلٍ مُسْلِمٍ ‏"‏ ‏.‏\hadithno{3987}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that:The Prophet [SAW] said: "The extinction of the whole world is less significant before Allah than killing a Muslim man}}
\hadithdefcmd{nasai}{3988}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، عَنْ شُعْبَةَ، عَنْ يَعْلَى، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَتْلُ الْمُؤْمِنِ أَعْظَمُ عِنْدَ اللَّهِ مِنْ زَوَالِ الدُّنْيَا ‏.‏\hadithno{3988}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"Killing a believer is more grievous before Allah than the extinction of the whole world}}
\hadithdefcmd{nasai}{3989}{أَخْبَرَنَا عَمْرُو بْنُ هِشَامٍ، قَالَ حَدَّثَنَا مَخْلَدُ بْنُ يَزِيدَ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَتْلُ الْمُؤْمِنِ أَعْظَمُ عِنْدَ اللَّهِ مِنْ زَوَالِ الدُّنْيَا ‏.‏\hadithno{3989}\hadithgrade{Abu Ghuddah: -; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"Killing a believer is more grievous before Allah than the extinction of the whole world}}
\hadithdefcmd{nasai}{3990}{أَخْبَرَنَا الْحَسَنُ بْنُ إِسْحَاقَ الْمَرْوَزِيُّ، - ثِقَةٌ - حَدَّثَنِي خَالِدُ بْنُ خِدَاشٍ، قَالَ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ بَشِيرِ بْنِ الْمُهَاجِرِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَتْلُ الْمُؤْمِنِ أَعْظَمُ عِنْدَ اللَّهِ مِنْ زَوَالِ الدُّنْيَا ‏"‏ ‏.‏\hadithno{3990}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Abdullah bin Buraidah that his father said:"The Messenger of Allah [SAW] said: 'Killing a believer is more grievous before Allah than the extinction of the whole world}}
\hadithdefcmd{nasai}{3991}{أَخْبَرَنَا سَرِيعُ بْنُ عَبْدِ اللَّهِ الْوَاسِطِيُّ الْخَصِيُّ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ الأَزْرَقُ، عَنْ شَرِيكٍ، عَنْ عَاصِمٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوَّلُ مَا يُحَاسَبُ بِهِ الْعَبْدُ الصَّلاَةُ وَأَوَّلُ مَا يُقْضَى بَيْنَ النَّاسِ فِي الدِّمَاءِ ‏"‏ ‏.‏\hadithno{3991}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah [SAW] said: 'The first thing concerning which a person will be brought to account will be the Salah, and the first thing concerning which scores will be settled among the people, will be bloodshed}}
\hadithdefcmd{nasai}{3992}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، عَنْ خَالِدٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَوَّلُ مَا يُحْكَمُ بَيْنَ النَّاسِ فِي الدِّمَاءِ ‏"‏ ‏.‏\hadithno{3992}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah [SAW] said: 'The first matter concerning which judgment will be passed among the people will be bloodshed}}
\hadithdefcmd{nasai}{3993}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، عَنْ سُفْيَانَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ عَبْدُ اللَّهِ أَوَّلُ مَا يُقْضَى بَيْنَ النَّاسِ يَوْمَ الْقِيَامَةِ فِي الدِّمَاءِ ‏.‏\hadithno{3993}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah that:The Messenger of Allah [SAW] said: "The first matter concerning which scores will be settled among the people on the Day of Resurrection will be bloodshed}}
\hadithdefcmd{nasai}{3994}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، ثُمَّ ذَكَرَ كَلِمَةً مَعْنَاهَا عَنْ عَمْرِو بْنِ شُرَحْبِيلَ، عَنْ عَبْدِ اللَّهِ، قَالَ أَوَّلُ مَا يُقْضَى بَيْنَ النَّاسِ يَوْمَ الْقِيَامَةِ فِي الدِّمَاءِ ‏.‏\hadithno{3994}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah said:"The first matter concerning which scores will be settled among the people on the Day of Resurrection will be bloodshed}}
\hadithdefcmd{nasai}{3995}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَمْرِو بْنِ شُرَحْبِيلَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوَّلُ مَا يُقْضَى فِيهِ بَيْنَ النَّاسِ يَوْمَ الْقِيَامَةِ فِي الدِّمَاءِ ‏"‏ ‏.‏\hadithno{3995}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Amr bin Shurahbil said:"The Messenger of Allah [SAW] said: 'The first matter concerning which scores will be settled among the people on the Day of Resurrection will be bloodshed}}
\hadithdefcmd{nasai}{3996}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ أَوَّلُ مَا يُقْضَى بَيْنَ النَّاسِ فِي الدِّمَاءِ ‏.‏\hadithno{3996}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah said:"The first matter concerning which scores will be settled among the people will be bloodshed}}
\hadithdefcmd{nasai}{3997}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْمُسْتَمِرِّ، قَالَ حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، قَالَ حَدَّثَنَا مُعْتَمِرٌ، عَنْ أَبِيهِ، عَنِ الأَعْمَشِ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، عَنْ عَمْرِو بْنِ شُرَحْبِيلَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَجِيءُ الرَّجُلُ آخِذًا بِيَدِ الرَّجُلِ فَيَقُولُ يَا رَبِّ هَذَا قَتَلَنِي ‏.‏ فَيَقُولُ اللَّهُ لَهُ لِمَ قَتَلْتَهُ فَيَقُولُ قَتَلْتُهُ لِتَكُونَ الْعِزَّةُ لَكَ ‏.‏ فَيَقُولُ فَإِنَّهَا لِي ‏.‏ وَيَجِيءُ الرَّجُلُ آخِذًا بِيَدِ الرَّجُلِ فَيَقُولُ إِنَّ هَذَا قَتَلَنِي ‏.‏ فَيَقُولُ اللَّهُ لَهُ لِمَ قَتَلْتَهُ فَيَقُولُ لِتَكُونَ الْعِزَّةُ لِفُلاَنٍ فَيَقُولُ إِنَّهَا لَيْسَتْ لِفُلاَنٍ فَيَبُوءُ بِإِثْمِهِ ‏"‏ ‏.‏\hadithno{3997}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdullah bin Mas'ud that:The Prophet [SAW] said: "A man will come, holding another man's hand, and will say: 'O Lord, this man killed me.' Allah will say to him: 'Why did you kill him?' He will say: 'I killed him so that the glory would be to you.' He will say: 'It is to Me.' Then (another) man will come holding another man's hand, and will say: 'This man killed me.' Allah will say to him: 'Why did you kill him?' He will say: 'So that the glory would be to so and so.' He will say: 'It is not to so and so,' and the burden of sin will be upon him}}
\hadithdefcmd{nasai}{3998}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ تَمِيمٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ أَخْبَرَنِي شُعْبَةُ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، قَالَ قَالَ جُنْدَبٌ حَدَّثَنِي فُلاَنٌ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَجِيءُ الْمَقْتُولُ بِقَاتِلِهِ يَوْمَ الْقِيَامَةِ فَيَقُولُ سَلْ هَذَا فِيمَ قَتَلَنِي فَيَقُولُ قَتَلْتُهُ عَلَى مُلْكِ فُلاَنٍ ‏"‏ ‏.‏ قَالَ جُنْدَبٌ فَاتَّقِهَا ‏.‏\hadithno{3998}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu 'Imran Al-Jawni said:"Jundab said: 'So and so told me that the Messenger of Allah [SAW] said: The slain will bring his killer on the Day of Resurrection and will say: Ask him why he killed me. He will say: I killed him defending the kingdom of so and so.'" Jundab said: "So be careful}}
\hadithdefcmd{nasai}{3999}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمَّارٍ الدُّهْنِيِّ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، أَنَّ ابْنَ عَبَّاسٍ، سُئِلَ عَمَّنْ قَتَلَ مُؤْمِنًا مُتَعَمِّدًا ثُمَّ تَابَ وَآمَنَ وَعَمِلَ صَالِحًا ثُمَّ اهْتَدَى فَقَالَ ابْنُ عَبَّاسٍ وَأَنَّى لَهُ التَّوْبَةُ سَمِعْتُ نَبِيَّكُمْ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَجِيءُ مُتَعَلِّقًا بِالْقَاتِلِ تَشْخُبُ أَوْدَاجُهُ دَمًا فَيَقُولُ أَىْ رَبِّ سَلْ هَذَا فِيمَ قَتَلَنِي ‏"‏ ‏.‏ ثُمَّ قَالَ وَاللَّهِ لَقَدْ أَنْزَلَهَا اللَّهُ ثُمَّ مَا نَسَخَهَا ‏.‏\hadithno{3999}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Salim bin Abi Ja'd that:Ibn 'Abbas was asked about someone who killed a believer deliberately, then he repented, believed and did righteous deeds, and followed true guidance. Ibn 'Abbas said: "There is no way the repentance could avail him! I heard the Prophet [SAW] say: 'He (the victim) will come hanging onto his killer, with his jugular veins flowing with blood and saying: O Lord, ask him why he killed me. Then he said: By Allah, Allah revealed it and never abrogated anything of it}}
\hadithdefcmd{nasai}{4000}{قَالَ وَأَخْبَرَنِي أَزْهَرُ بْنُ جَمِيلٍ الْبَصْرِيُّ، قَالَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْمُغِيرَةِ بْنِ النُّعْمَانِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ اخْتَلَفَ أَهْلُ الْكُوفَةِ فِي هَذِهِ الآيَةِ ‏\{‏ وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا ‏\}‏ فَرَحَلْتُ إِلَى ابْنِ عَبَّاسٍ فَسَأَلْتُهُ فَقَالَ لَقَدْ أُنْزِلَتْ فِي آخِرِ مَا أُنْزِلَ ثُمَّ مَا نَسَخَهَا شَىْءٌ ‏.‏\hadithno{4000}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Sa'eed bin Jubair said:"The people of Al-Kufah differed concerning this Verse: "And whoever kills a believer intentionally." So I went to Ibn 'Abbas and asked him, and he said: 'It was revealed among the last of what was revealed, and nothing of it was abrogated after that}}
\hadithdefcmd{nasai}{4001}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ حَدَّثَنِي الْقَاسِمُ بْنُ أَبِي بَزَّةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ هَلْ لِمَنْ قَتَلَ مُؤْمِنًا مُتَعَمِّدًا مِنْ تَوْبَةٍ قَالَ لاَ ‏.‏ وَقَرَأْتُ عَلَيْهِ الآيَةَ الَّتِي فِي الْفُرْقَانِ ‏\{‏ وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ وَلاَ يَقْتُلُونَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ ‏\}‏ قَالَ هَذِهِ آيَةٌ مَكِّيَّةٌ نَسَخَتْهَا آيَةٌ مَدَنِيَّةٌ ‏\{‏ وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا فَجَزَاؤُهُ جَهَنَّمُ ‏\}‏ ‏.‏\hadithno{4001}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Sa'eed bin Jubair said:"I said to Ibn 'Abbas: 'Can a person, who killed a believer intentionally, repent?' He said: 'No.' I recited the Verse from Al-Furqan to him: 'And those who invoke not any other ilah (god) along with Allah, or kill such person as Allah has forbidden, except by right,' he said: 'This Verse was revealed in Makkah and was abrogated by a Verse that was revealed in Al-Madinah: 'And whoever kills a believer intentionally, his recompense is Hell}}
\hadithdefcmd{nasai}{4002}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ أَمَرَنِي عَبْدُ الرَّحْمَنِ بْنُ أَبِي لَيْلَى أَنْ أَسْأَلَ ابْنَ عَبَّاسٍ، عَنْ هَاتَيْنِ الآيَتَيْنِ، ‏\{‏ وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا فَجَزَاؤُهُ جَهَنَّمُ ‏\}‏ فَسَأَلْتُهُ فَقَالَ لَمْ يَنْسَخْهَا شَىْءٌ ‏.‏ وَعَنْ هَذِهِ الآيَةِ ‏\{‏ وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ وَلاَ يَقْتُلُونَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ ‏\}‏ قَالَ نَزَلَتْ فِي أَهْلِ الشِّرْكِ ‏.‏\hadithno{4002}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Sa'eed bin Jubair said:"Abdur-Rahman bin Abi Laila told me to ask Ibn 'Abbas about two Verses: 'And whoever kills a believer intentionally, his recompense is Hell.' I asked him and he said: 'Nothing of this has been abrogated.' (And I asked him about the Verse): 'And those who invoke not any other ilah (god) along with Allah, or kill such person as Allah has forbidden, except by right,' he said: 'This was revealed concerning the people of Shirk}}
\hadithdefcmd{nasai}{4003}{أَخْبَرَنَا حَاجِبُ بْنُ سُلَيْمَانَ الْمَنْبِجِيُّ، قَالَ حَدَّثَنَا ابْنُ أَبِي رَوَّادٍ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَبْدِ الأَعْلَى الثَّعْلَبِيِّ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ قَوْمًا، كَانُوا قَتَلُوا فَأَكْثَرُوا وَزَنَوْا فَأَكْثَرُوا وَانْتَهَكُوا فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم قَالُوا يَا مُحَمَّدُ إِنَّ الَّذِي تَقُولُ وَتَدْعُو إِلَيْهِ لَحَسَنٌ لَوْ تُخْبِرُنَا أَنَّ لِمَا عَمِلْنَا كَفَّارَةً ‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ ‏\}‏ إِلَى ‏\{‏ فَأُولَئِكَ يُبَدِّلُ اللَّهُ سَيِّئَاتِهِمْ حَسَنَاتٍ ‏\}‏ قَالَ يُبَدِّلُ اللَّهُ شِرْكَهُمْ إِيمَانًا وَزِنَاهُمْ إِحْصَانًا وَنَزَلَتْ ‏\{‏ قُلْ يَا عِبَادِيَ الَّذِينَ أَسْرَفُوا عَلَى أَنْفُسِهِمْ ‏\}‏ الآيَةَ ‏.‏\hadithno{4003}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Abbas that :Some people used to kill, and they did a great deal of it, and they used to commit adultery and they did a great deal of it, and they committed violations. They came to the Prophet [SAW] and said: "O Muhammad, what you say and call people to is good, if only you could tell us that there is any expiation for what we have done." Then Allah, the Mighty and Sublime, revealed: "And those who invoke not any other ilah (god) along with Allah up to for those, Allah will change their sins into good deeds," he said: "So Allah will change their Shirk into faith, and their adultery into chastity. And the Verse: "Say: O 'Ibadi (My slaves) who have transgressed against themselves (by committing evil deeds and sins)" was revealed}}
\hadithdefcmd{nasai}{4004}{أَخْبَرَنَا الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ، قَالَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي يَعْلَى، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ نَاسًا، مِنْ أَهْلِ الشِّرْكِ أَتَوْا مُحَمَّدًا فَقَالُوا إِنَّ الَّذِي تَقُولُ وَتَدْعُو إِلَيْهِ لَحَسَنٌ لَوْ تُخْبِرُنَا أَنَّ لِمَا عَمِلْنَا كَفَّارَةً ‏.‏ فَنَزَلَتْ ‏\{‏ وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ ‏\}‏ وَنَزَلَتْ ‏\{‏ قُلْ يَا عِبَادِيَ الَّذِينَ أَسْرَفُوا عَلَى أَنْفُسِهِمْ ‏\}‏ ‏.‏\hadithno{4004}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Abbas that :Some of the people of Shirk came to Muhammad [SAW] and said: "What you say and call people to is good, if only you could tell us that there is any expiation for what we have done." Then the Verses: "And those who invoke not any other ilah (god) along with Allah, or kill such a person as Allah has forbidden, except by right." And "Say: O 'Ibadi (My slaves) who have transgressed against themselves (by committing evil deeds and sins)" were revealed}}
\hadithdefcmd{nasai}{4005}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، قَالَ حَدَّثَنِي وَرْقَاءُ، عَنْ عَمْرٍو، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يَجِيءُ الْمَقْتُولُ بِالْقَاتِلِ يَوْمَ الْقِيَامَةِ نَاصِيَتُهُ وَرَأْسُهُ فِي يَدِهِ وَأَوْدَاجُهُ تَشْخُبُ دَمًا يَقُولُ يَا رَبِّ قَتَلَنِي حَتَّى يُدْنِيَهُ مِنَ الْعَرْشِ ‏"‏ ‏.‏ قَالَ فَذَكَرُوا لاِبْنِ عَبَّاسٍ التَّوْبَةَ فَتَلاَ هَذِهِ الآيَةَ ‏\{‏ وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا ‏\}‏ قَالَ مَا نُسِخَتْ مُنْذُ نَزَلَتْ وَأَنَّى لَهُ التَّوْبَةُ\hadithno{4005}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that:The Prophet [SAW] said: "The slain will bring his killer on the Day of Resurrection with his forelock and his head in his hand, and with his jugular veins flowing with blood, and will say: 'O Lord, he killed me,' until he draws near to the Throne." They mentioned repentance to Ibn 'Abbas and he recited this Verse: "And whoever kills a believer intentionally, his recompense is Hell" He said: "It has not been abrogated since it was revealed; there is no way he could repent}}
\hadithdefcmd{nasai}{4006}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا الأَنْصَارِيُّ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي الزِّنَادِ، عَنْ خَارِجَةَ بْنِ زَيْدٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا فَجَزَاؤُهُ جَهَنَّمُ خَالِدًا فِيهَا ‏\}‏ الآيَةُ كُلُّهَا بَعْدَ الآيَةِ الَّتِي نَزَلَتْ فِي الْفُرْقَانِ بِسِتَّةِ أَشْهُرٍ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ مُحَمَّدُ بْنُ عَمْرٍو لَمْ يَسْمَعْهُ مِنْ أَبِي الزِّنَادِ ‏.‏\hadithno{4006}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Zaid bin Thabit said:"This Verse - 'And whoever kills a believer intentionally, his recompense is Hell' - was revealed six months after the Verse which was revealed in Surat Al-Furqan}}
\hadithdefcmd{nasai}{4007}{أَخْبَرَنِي مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ عَبْدِ الْوَهَّابِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ أَبِي الزِّنَادِ، عَنْ خَارِجَةَ بْنِ زَيْدٍ، عَنْ زَيْدٍ، فِي قَوْلِهِ ‏\{‏ وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا فَجَزَاؤُهُ جَهَنَّمُ ‏\}‏ قَالَ نَزَلَتْ هَذِهِ الآيَةُ بَعْدَ الَّتِي فِي ‏\{‏ تَبَارَكَ ‏\}‏ الْفُرْقَانِ بِثَمَانِيَةِ أَشْهُرٍ ‏\{‏ وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ وَلاَ يَقْتُلُونَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ ‏\}‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ أَدْخَلَ أَبُو الزِّنَادِ بَيْنَهُ وَبَيْنَ خَارِجَةَ مُجَالِدَ بْنَ عَوْفٍ ‏.‏\hadithno{4007}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zaid with regard Allah's saying:"And whoever kills a believer intentionally, his recompense is Hell" that he said: "This Verse was revealed eight months after the Verse that is in Tabark Al-Furqan: "And those who invoke not any other ilah (god) along with Allah, or kill such person as Allah has forbidden, except by right}}
\hadithdefcmd{nasai}{4008}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، عَنْ مُسْلِمِ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنْ أَبِي الزِّنَادِ، عَنْ مُجَالِدِ بْنِ عَوْفٍ، قَالَ سَمِعْتُ خَارِجَةَ بْنَ زَيْدِ بْنِ ثَابِتٍ، يُحَدِّثُ عَنْ أَبِيهِ، أَنَّهُ قَالَ نَزَلَتْ ‏\{‏ وَمَنْ يَقْتُلْ مُؤْمِنًا مُتَعَمِّدًا فَجَزَاؤُهُ جَهَنَّمُ خَالِدًا فِيهَا ‏\}‏ أَشْفَقْنَا مِنْهَا فَنَزَلَتِ الآيَةُ الَّتِي فِي الْفُرْقَانِ ‏\{‏ وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ وَلاَ يَقْتُلُونَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ ‏\}‏ ‏.‏\hadithno{4008}\hadithgrade{Abu Ghuddah: Munkar; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Mujalid bin 'Awf said:"I heard Kharijah bin Zaid bin Thabit narrate that his father said: (The Verse) 'And whoever kills a believer intentionally, his recompense is Hell' was revealed and we became worried about it. Then the Verse in Al-Furqan 'And those who invoke not any other ilah (god) along with Allah, or kill such person as Allah has forbidden, except by right.' was revealed}}
\hadithdefcmd{nasai}{4009}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا بَقِيَّةُ، قَالَ حَدَّثَنِي بَحِيرُ بْنُ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، أَنَّ أَبَا رُهْمٍ السَّمَعِيَّ، حَدَّثَهُمْ أَنَّ أَبَا أَيُّوبَ الأَنْصَارِيَّ حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ جَاءَ يَعْبُدُ اللَّهَ وَلاَ يُشْرِكُ بِهِ شَيْئًا وَيُقِيمُ الصَّلاَةَ وَيُؤْتِي الزَّكَاةَ وَيَجْتَنِبُ الْكَبَائِرَ كَانَ لَهُ الْجَنَّةُ ‏"‏ ‏.‏ فَسَأَلُوهُ عَنِ الْكَبَائِرِ فَقَالَ ‏"‏ الإِشْرَاكُ بِاللَّهِ وَقَتْلُ النَّفْسِ الْمُسْلِمَةِ وَالْفِرَارُ يَوْمَ الزَّحْفِ ‏"‏ ‏.‏\hadithno{4009}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Ayyub Al-Ansari narrated that:The Messenger of Allah [SAW] said: "Whoever comes worshipping Allah and not associating anything with Him, establishing Salah, paying Zakah and avoiding major sins, Paradise will be his." They asked him about major sins and he said: "Associating others with Allah, killing a Muslim soul, and fleeing (from the battlefield) on the day of the march}}
\hadithdefcmd{nasai}{4010}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَأَنْبَأَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا النَّضْرُ بْنُ شُمَيْلٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْكَبَائِرُ الشِّرْكُ بِاللَّهِ وَعُقُوقُ الْوَالِدَيْنِ وَقَتْلُ النَّفْسِ وَقَوْلُ الزُّورِ ‏"‏ ‏.‏\hadithno{4010}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Ubaidullah bin Abi Bakr said:"I heard Anas say: 'The Messenger of Allah [SAW] said: The major sins are: Associating others with Allah (Shirk), disobeying one's parents, killing a soul (murder) and speaking falsely}}
\hadithdefcmd{nasai}{4011}{أَخْبَرَنِي عَبْدَةُ بْنُ عَبْدِ الرَّحِيمِ، قَالَ أَنْبَأَنَا ابْنُ شُمَيْلٍ، قَالَ أَنْبَأَنَا شُعْبَةُ، قَالَ حَدَّثَنَا فِرَاسٌ، قَالَ سَمِعْتُ الشَّعْبِيَّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْكَبَائِرُ الإِشْرَاكُ بِاللَّهِ وَعُقُوقُ الْوَالِدَيْنِ وَقَتْلُ النَّفْسِ وَالْيَمِينُ الْغَمُوسُ ‏"‏ ‏.‏\hadithno{4011}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Abdullah bin 'Amr that:The Prophet [SAW] said: "The major sins are: Associating others with Allah, disobeying parents, killing a soul (murder) and swearing a false oath knowingly}}
\hadithdefcmd{nasai}{4012}{أَخْبَرَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هَانِئٍ، قَالَ حَدَّثَنَا حَرْبُ بْنُ شَدَّادٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ عَبْدِ الْحَمِيدِ بْنِ سِنَانٍ، عَنْ حَدِيثِ، عُبَيْدِ بْنِ عُمَيْرٍ أَنَّهُ حَدَّثَهُ أَبُوهُ، وَكَانَ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم - أَنَّ رَجُلاً قَالَ يَا رَسُولَ اللَّهِ مَا الْكَبَائِرُ قَالَ ‏ "‏ هُنَّ سَبْعٌ أَعْظَمُهُنَّ إِشْرَاكٌ بِاللَّهِ وَقَتْلُ النَّفْسِ بِغَيْرِ حَقٍّ وَفِرَارٌ يَوْمَ الزَّحْفِ ‏"‏ ‏.‏ مُخْتَصَرٌ ‏.‏\hadithno{4012}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Ubaid bin 'Umair that :His father - who was one of the Companions of the Prophet [SAW] - told him: "A man said: 'O Messenger of Allah, what are the major sins?' He said: 'They are seven; the most grievous of which are associating others with Allah, killing a soul unlawfully and fleeing (from the battlefield) on the day of the march.'" It is abridged}}
\hadithdefcmd{nasai}{4013}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ وَاصِلٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَمْرِو بْنِ شُرَحْبِيلَ، عَنْ عَبْدِ اللَّهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَىُّ الذَّنْبِ أَعْظَمُ قَالَ ‏"‏ أَنْ تَجْعَلَ لِلَّهِ نِدًّا وَهُوَ خَلَقَكَ ‏"‏ ‏.‏ قُلْتُ ثُمَّ مَاذَا قَالَ ‏"‏ أَنْ تَقْتُلَ وَلَدَكَ خَشْيَةَ أَنْ يَطْعَمَ مَعَكَ ‏"‏ ‏.‏ قُلْتُ ثُمَّ مَاذَا قَالَ ‏"‏ أَنْ تُزَانِيَ بِحَلِيلَةِ جَارِكَ ‏"‏ ‏.‏\hadithno{4013}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah said:"I said: 'O Messenger of Allah, which sin is the most grievous?' He said: 'Setting up a rival to Allah while it is He that has created you.' I said: 'Then what?' He said: 'Killing your child for fear that he may eat with you.' I said: 'Then what?' He said: 'Committing adultery with your neighbor's wife}}
\hadithdefcmd{nasai}{4014}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي وَاصِلٌ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَىُّ الذَّنْبِ أَعْظَمُ قَالَ ‏"‏ أَنْ تَجْعَلَ لِلَّهِ نِدًّا وَهُوَ خَلَقَكَ ‏"‏ ‏.‏ قُلْتُ ثُمَّ أَىٌّ قَالَ ‏"‏ أَنْ تَقْتُلَ وَلَدَكَ مِنْ أَجْلِ أَنْ يَطْعَمَ مَعَكَ ‏"‏ ‏.‏ قُلْتُ ثُمَّ أَىٌّ قَالَ ‏"‏ ثُمَّ أَنْ تُزَانِيَ بِحَلِيلَةِ جَارِكَ ‏"‏ ‏.‏\hadithno{4014}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Abdullah said:"I said: 'O Messenger of Allah, which sin is most grievous?' He said: 'Setting up a rival to Allah while it is He that created you.' I said: 'Then what?' He said: 'Killing your child so that he will not eat with you.' I said: 'Then what?' He said: 'Committing adultery with your neighbor's wife}}
\hadithdefcmd{nasai}{4015}{أَخْبَرَنَا عَبْدَةُ، قَالَ أَنْبَأَنَا يَزِيدُ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ عَاصِمٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَىُّ الذَّنْبِ أَعْظَمُ قَالَ ‏"‏ الشِّرْكُ أَنْ تَجْعَلَ لِلَّهِ نِدًّا وَأَنْ تُزَانِيَ بِحَلِيلَةِ جَارِكَ وَأَنْ تَقْتُلَ وَلَدَكَ مَخَافَةَ الْفَقْرِ أَنْ يَأْكُلَ مَعَكَ ‏"‏ ‏.‏ ثُمَّ قَرَأَ عَبْدُ اللَّهِ ‏\{‏ وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ ‏\}‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ وَالصَّوَابُ الَّذِي قَبْلَهُ وَحَدِيثُ يَزِيدَ هَذَا خَطَأٌ إِنَّمَا هُوَ وَاصِلٌ وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{4015}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Abdullah said:"I asked the Messenger of Allah [SAW], which sin is most grievous?" He said: "Shirk, setting up a rival to Allah, committing adultery with your neighbor's wife, and killing your child for fear of poverty, and that he may eat with you." Then 'Abdullah recited the Verse: "And those who invoke not any other Ilah (god) along with Allah}}
\hadithdefcmd{nasai}{4016}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَالَّذِي لاَ إِلَهَ غَيْرُهُ لاَ يَحِلُّ دَمُ امْرِئٍ مُسْلِمٍ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ إِلاَّ ثَلاَثَةُ نَفَرٍ التَّارِكُ لِلإِسْلاَمِ مُفَارِقُ الْجَمَاعَةِ وَالثَّيِّبُ الزَّانِي وَالنَّفْسُ بِالنَّفْسِ ‏"‏ ‏.‏ قَالَ الأَعْمَشُ فَحَدَّثْتُ بِهِ إِبْرَاهِيمَ فَحَدَّثَنِي عَنِ الأَسْوَدِ عَنْ عَائِشَةَ بِمِثْلِهِ ‏.‏\hadithno{4016}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah [SAW] said: 'By the One besides Whom there is no other god, it is not permissible to shed the blood of a Muslim who bears witness to La ilaha illalla (there is none worthy of worship except Allah) and that I am the Messenger of Allah, except in three cases: One who leaves Islam and splits away from the Jama'ah, a person who has been married and then commits adultery, and a life for a life}}
\hadithdefcmd{nasai}{4017}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ عَمْرِو بْنِ غَالِبٍ، قَالَ قَالَتْ عَائِشَةُ أَمَا عَلِمْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ دَمُ امْرِئٍ مُسْلِمٍ إِلاَّ رَجُلٌ زَنَى بَعْدَ إِحْصَانِهِ أَوْ كَفَرَ بَعْدَ إِسْلاَمِهِ أَوِ النَّفْسُ بِالنَّفْسِ ‏"‏ ‏.‏ وَقَّفَهُ زُهَيْرٌ ‏.‏\hadithno{4017}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Amr bin Ghalib said:"Aishah said: 'Do you not know that the Messenger of Allah [SAW] said: It is not permissible to shed the blood of a Muslim, except a man who committed adultery after being married, or one who reverted to Kufr after becoming Muslim, or a life for a life}}
\hadithdefcmd{nasai}{4018}{أَخْبَرَنَا هِلاَلُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا حُسَيْنٌ، قَالَ حَدَّثَنَا زُهَيْرٌ، قَالَ حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ عَمْرِو بْنِ غَالِبٍ، قَالَ قَالَتْ عَائِشَةُ يَا عَمَّارُ أَمَا إِنَّكَ تَعْلَمُ أَنَّهُ لاَ يَحِلُّ دَمُ امْرِئٍ إِلاَّ ثَلاَثَةٌ النَّفْسُ بِالنَّفْسِ أَوْ رَجُلٌ زَنَى بَعْدَ مَا أُحْصِنَ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{4018}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Amr bin Ghalib said:"Aishah said: 'O 'Ammar! Do you not know that it is not permissible to shed the blood of a Muslim except in three cases: a life for a life, a man who commits adultery after being married}}
\hadithdefcmd{nasai}{4019}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، قَالَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنِي أَبُو أُمَامَةَ بْنُ سَهْلٍ، وَعَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ رَبِيعَةَ، قَالاَ كُنَّا مَعَ عُثْمَانَ وَهُوَ مَحْصُورٌ - وَكُنَّا إِذَا دَخَلْنَا مَدْخَلاً نَسْمَعُ كَلاَمَ مَنْ بِالْبَلاَطِ - فَدَخَلَ عُثْمَانُ يَوْمًا ثُمَّ خَرَجَ فَقَالَ إِنَّهُمْ لَيَتَوَاعَدُونِي بِالْقَتْلِ ‏.‏ قُلْنَا يَكْفِيكَهُمُ اللَّهُ ‏.‏ قَالَ فَلِمَ يَقْتُلُونِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ دَمُ امْرِئٍ مُسْلِمٍ إِلاَّ بِإِحْدَى ثَلاَثٍ رَجُلٌ كَفَرَ بَعْدَ إِسْلاَمِهِ أَوْ زَنَى بَعْدَ إِحْصَانِهِ أَوْ قَتَلَ نَفْسًا بِغَيْرِ نَفْسٍ ‏"‏ ‏.‏ فَوَاللَّهِ مَا زَنَيْتُ فِي جَاهِلِيَّةٍ وَلاَ إِسْلاَمٍ وَلاَ تَمَنَّيْتُ أَنَّ لِي بِدِينِي بَدَلاً مُنْذُ هَدَانِي اللَّهُ وَلاَ قَتَلْتُ نَفْسًا فَلِمَ يَقْتُلُونَنِي\hadithno{4019}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Umamah bin Sahl and 'Abdullah bin 'Amir bin Rabi'ah said:"We were with 'Uthman when he was under siege and we could hear what was said from Al-Balat. 'Uthman came in one day, then he came out, and said: 'They are threatening to kill me.' We said: 'Allah will suffice you against them.' He said: 'Why would they kill me? I heard the Messenger of Allah [SAW] say: It is not permissible to shed the blood of a Muslim except in one of three cases: A man who reverts to Kufr after becoming Muslim, or commits adultery after being married, or one who kills a soul unlawfully. By Allah, I did not commit adultery during Jahiliyyah or in Islam, I never wished to follow any other religion since Allah guided me, and I have never killed anyone, so why do they want to kill me?}}
\hadithdefcmd{nasai}{4020}{أَخْبَرَنِي أَحْمَدُ بْنُ يَحْيَى الصُّوفِيُّ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ مَرْدَانْبَهْ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ عَرْفَجَةَ بْنِ شُرَيْحٍ الأَشْجَعِيِّ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم عَلَى الْمِنْبَرِ يَخْطُبُ النَّاسَ فَقَالَ ‏ "‏ إِنَّهُ سَيَكُونُ بَعْدِي هَنَاتٌ وَهَنَاتٌ فَمَنْ رَأَيْتُمُوهُ فَارَقَ الْجَمَاعَةَ أَوْ يُرِيدُ تَفْرِيقَ أَمْرِ أُمَّةِ مُحَمَّدٍ صلى الله عليه وسلم كَائِنًا مَنْ كَانَ فَاقْتُلُوهُ فَإِنَّ يَدَ اللَّهِ عَلَى الْجَمَاعَةِ فَإِنَّ الشَّيْطَانَ مَعَ مَنْ فَارَقَ الْجَمَاعَةَ يَرْكُضُ ‏"‏ ‏.‏\hadithno{4020}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Arfajah bin Shuraih Al-Ashja'I said:"I saw the Prophet [SAW] on the Minbar addressing the people. He said: 'After me there will be many calamities and much evil behavior. Whoever you see splitting away from the Jama'ah or trying to create division among the Ummah of Muhammad [SAW], then kill him, for the Hand of Allah is with the Jama'ah, and the Shaitan is with the one who splits away from the Ummah, running with him}}
\hadithdefcmd{nasai}{4021}{أَخْبَرَنَا أَبُو عَلِيٍّ، مُحَمَّدُ بْنُ عَلِيٍّ الْمَرْوَزِيُّ قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنِ عُثْمَانَ، عَنْ أَبِي حَمْزَةَ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ عَرْفَجَةَ بْنِ شُرَيْحٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّهَا سَتَكُونُ بَعْدِي هَنَاتٌ وَهَنَاتٌ وَهَنَاتٌ - وَرَفَعَ يَدَيْهِ - فَمَنْ رَأَيْتُمُوهُ يُرِيدُ تَفْرِيقَ أَمْرِ أُمَّةِ مُحَمَّدٍ صلى الله عليه وسلم وَهُمْ جَمِيعٌ فَاقْتُلُوهُ كَائِنًا مَنْ كَانَ مِنَ النَّاسِ ‏"‏ ‏.‏\hadithno{4021}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Arfajah bin Shuraih said:"The Prophet [SAW] said: 'After me there will be many calamities and much evil behavior.' He raised his hands (and said): 'Whomever you see trying to create division among the Ummah of Muhammad [SAW] when they are all united, kill him, no matter who he is among the people}}
\hadithdefcmd{nasai}{4022}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا زِيَادُ بْنُ عِلاَقَةَ، عَنْ عَرْفَجَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ سَتَكُونُ بَعْدِي هَنَاتٌ وَهَنَاتٌ فَمَنْ أَرَادَ أَنْ يُفَرِّقَ أَمْرَ أُمَّةِ مُحَمَّدٍ صلى الله عليه وسلم وَهُمْ جَمْعٌ فَاضْرِبُوهُ بِالسَّيْفِ ‏"‏ ‏.‏\hadithno{4022}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Arfajah said:"I heard the Messenger of Allah [SAW] say: 'After me there will be many calamities and much evil behavior. Whoever wants to create division among the Ummah (of Muhammad [SAW]) when they are all united, strike him with the sword}}
\hadithdefcmd{nasai}{4023}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ زَيْدِ بْنِ عَطَاءِ بْنِ السَّائِبِ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ أُسَامَةَ بْنِ شَرِيكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا رَجُلٍ خَرَجَ يُفَرِّقُ بَيْنَ أُمَّتِي فَاضْرِبُوا عُنُقَهُ ‏"‏ ‏.‏\hadithno{4023}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Usamah bin Sharik said:"The Messenger of Allah [SAW] said: 'Any man who goes out and tries to create division among my Ummah, strike his neck (kill him)}}
\hadithdefcmd{nasai}{4024}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ حَجَّاجٍ الصَّوَّافِ، قَالَ حَدَّثَنَا أَبُو رَجَاءٍ، مَوْلَى أَبِي قِلاَبَةَ قَالَ حَدَّثَنَا أَبُو قِلاَبَةَ، قَالَ حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ نَفَرًا، مِنْ عُكْلٍ ثَمَانِيَةً قَدِمُوا عَلَى النَّبِيِّ صلى الله عليه وسلم فَاسْتَوْخَمُوا الْمَدِينَةَ وَسَقِمَتْ أَجْسَامُهُمْ فَشَكَوْا ذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَلاَ تَخْرُجُونَ مَعَ رَاعِينَا فِي إِبِلِهِ فَتُصِيبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ فَخَرَجُوا فَشَرِبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا فَصَحُّوا فَقَتَلُوا رَاعِيَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَعَثَ فَأَخَذُوهُمْ فَأُتِيَ بِهِمْ فَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَّرَ أَعْيُنَهُمْ وَنَبَذَهُمْ فِي الشَّمْسِ حَتَّى مَاتُوا ‏.‏\hadithno{4024}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Anas bin Malik narrated that:A group of eighty people from 'Ukl came to the Prophet [SAW], but the climate of Al-Madinah did not suit them and they fell sick. They complained about that to the Messenger of Allah [SAW] and he said: "Why don't you go out with our herdsmen and drink the milk and urine of the camels?" They said: "Yes (we will do that)." They went out and drank some of the (camels') milk and urine, and they recovered. Then they killed the herdsman of the Messenger of Allah [SAW], so he sent (men after them) and they caught them and brought them back. He had their hands and feet cut off and branded their eyes, and left them in the sun to die}}
\hadithdefcmd{nasai}{4025}{أَخْبَرَنِي عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ، عَنِ الْوَلِيدِ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، أَنَّ نَفَرًا، مِنْ عُكْلٍ قَدِمُوا عَلَى النَّبِيِّ صلى الله عليه وسلم فَاجْتَوَوُا الْمَدِينَةَ فَأَمَرَهُمُ النَّبِيُّ صلى الله عليه وسلم أَنْ يَأْتُوا إِبِلَ الصَّدَقَةِ فَيَشْرَبُوا مِنْ أَبْوَالِهَا وَأَلْبَانِهَا فَفَعَلُوا فَقَتَلُوا رَاعِيَهَا وَاسْتَاقُوهَا فَبَعَثَ النَّبِيُّ صلى الله عليه وسلم فِي طَلَبِهِمْ - قَالَ - فَأُتِيَ بِهِمْ فَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَّرَ أَعْيُنَهُمْ وَلَمْ يَحْسِمْهُمْ وَتَرَكَهُمْ حَتَّى مَاتُوا فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ إِنَّمَا جَزَاءُ الَّذِينَ يُحَارِبُونَ اللَّهَ وَرَسُولَهُ ‏\}‏ الآيَةَ ‏.‏\hadithno{4025}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas that :Some people from 'Ukl came to the Prophet [SAW] but the climate of Al-Madinah did not suit them. The Prophet [SAW] told them to go to the camels that had been given in Sadaqah and drink some of their milk and urine. They did that, then they killed their herdsman and drove off the camels. The Prophet [SAW] sent (men) after them, and they were brought to him. He had their hands and feet cut off, and their eyes gouged out, and he did not have (their wounds) cauterized, and he left them to die. Then Allah, the Mighty and Sublime, revealed: "The recompense of those who wage war against Allah and His Messenger}}
\hadithdefcmd{nasai}{4026}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو قِلاَبَةَ، عَنْ أَنَسٍ، قَالَ قَدِمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ثَمَانِيَةُ نَفَرٍ مِنْ عُكْلٍ فَذَكَرَ نَحْوَهُ إِلَى قَوْلِهِ لَمْ يَحْسِمْهُمْ وَقَالَ قَتَلُوا الرَّاعِيَ ‏.‏\hadithno{4026}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas said:"Eighty men from 'Ukl came to the Messenger of Allah [SAW]" and he (the narrator) mentioned a similar report up to the words: "And he did not have (their wounds) cauterized." And he said: "They killed the herdsman}}
\hadithdefcmd{nasai}{4027}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، قَالَ أَتَى النَّبِيَّ صلى الله عليه وسلم نَفَرٌ مِنْ عُكْلٍ أَوْ عُرَيْنَةَ فَأَمَرَ لَهُمْ - وَاجْتَوَوُا الْمَدِينَةَ - بِذَوْدٍ أَوْ لِقَاحٍ يَشْرَبُونَ أَلْبَانَهَا وَأَبْوَالَهَا فَقَتَلُوا الرَّاعِيَ وَاسْتَاقُوا الإِبِلَ فَبَعَثَ فِي طَلَبِهِمْ فَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَلَ أَعْيُنَهُمْ ‏.‏\hadithno{4027}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas said:"A group of men from 'Ukl, or 'Uraynah, came to the Prophet [SAW], and when the climate of Al-Madinah did not suit them, he told them to go to some camels and drink their milk and urine. Then they killed the herdsman and stole the camels. He sent (men) after them, and had their hands and feet cut off, and their eyes gouged out}}
\hadithdefcmd{nasai}{4028}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ أَخْبَرَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عُمَرَ، وَغَيْرُهُ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ نَاسًا، مِنْ عُرَيْنَةَ قَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَاجْتَوَوُا الْمَدِينَةَ فَبَعَثَهُمُ النَّبِيُّ صلى الله عليه وسلم إِلَى ذَوْدٍ لَهُ فَشَرِبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا فَلَمَّا صَحُّوا ارْتَدُّوا عَنِ الإِسْلاَمِ وَقَتَلُوا رَاعِيَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُؤْمِنًا وَاسْتَاقُوا الإِبِلَ فَبَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي آثَارِهِمْ فَأُخِذُوا فَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَلَ أَعْيُنَهُمْ وَصَلَبَهُمْ ‏.‏\hadithno{4028}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that:Some people from 'Uraynah came to the Messenger of Allah [SAW], but the climate of Al-Madinah did not suit them. The Prophet [SAW] sent them to some camels of his, and he drank some of their milk and urine. When they recovered, they apostatized from Islam and killed the herdsman of the Messenger of Allah [SAW], who was a believer, and drove the camels off. The Messenger of Allah [SAW] sent (men) after them, and they were caught. He had their hands and feet cut off, their eyes gouged out, and had them crucified}}
\hadithdefcmd{nasai}{4029}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ قَدِمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أُنَاسٌ مِنْ عُرَيْنَةَ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ خَرَجْتُمْ إِلَى ذَوْدِنَا فَكُنْتُمْ فِيهَا فَشَرِبْتُمْ مِنْ أَلْبَانِهَا وَأَبْوَالِهَا ‏"‏ ‏.‏ فَفَعَلُوا فَلَمَّا صَحُّوا قَامُوا إِلَى رَاعِي رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَتَلُوهُ وَرَجَعُوا كُفَّارًا وَاسْتَاقُوا ذَوْدَ النَّبِيِّ صلى الله عليه وسلم فَأَرْسَلَ فِي طَلَبِهِمْ فَأُتِيَ بِهِمْ فَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَلَ أَعْيُنَهُمْ ‏.‏\hadithno{4029}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"Some people from 'Uraynah came to the Messenger of Allah [SAW] and the Messenger of Allah [SAW] said to them: 'Why don't you go out to our camels and stay with them and drink their milk and urine?' So they did that, and when they recovered, they went to the herdsman of the Messenger of Allah [SAW] and killed him, reverted to being disbelievers, and drove off the camels of the Prophet [SAW]. He sent (men) after them, and they were brought to him. He had their hands and feet cut off, and their eyes gouged out}}
\hadithdefcmd{nasai}{4030}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ قَدِمَ نَاسٌ مِنْ عُرَيْنَةَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَاجْتَوَوُا الْمَدِينَةَ فَقَالَ لَهُمُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْ خَرَجْتُمْ إِلَى ذَوْدِنَا فَشَرِبْتُمْ مِنْ أَلْبَانِهَا ‏"‏ ‏.‏ قَالَ وَقَالَ قَتَادَةُ ‏"‏ وَأَبْوَالِهَا ‏"‏ ‏.‏ فَخَرَجُوا إِلَى ذَوْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا صَحُّوا كَفَرُوا بَعْدَ إِسْلاَمِهِمْ وَقَتَلُوا رَاعِيَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُؤْمِنًا وَاسْتَاقُوا ذَوْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَانْطَلَقُوا مُحَارِبِينَ فَأَرْسَلَ فِي طَلَبِهِمْ فَأُخِذُوا فَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَّرَ أَعْيُنَهُمْ ‏.‏\hadithno{4030}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas said:"Some people from 'Uraynah came to the Messenger of Allah [SAW], but the climate of Al-Madinah did not suit them. The Messenger of Allah [SAW] said to them: 'Why don't you go out to our camels and drink their milk?'" - (one of the narrators) Qatadah said: 'And their urine.' - "So they went out to the camels of the Messenger of Allah [SAW], but when they recovered they killed the herdsman of the Messenger of Allah [SAW], who was a believer, and drove off the camels of the Messenger of Allah [SAW], and left as those at war. He sent (men) after them and they were caught. Then he had their hands and feet cut off, and branded their eyes}}
\hadithdefcmd{nasai}{4031}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عَدِيٍّ، قَالَ حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ، قَالَ أَسْلَمَ أُنَاسٌ مِنْ عُرَيْنَةَ فَاجْتَوَوُا الْمَدِينَةَ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ خَرَجْتُمْ إِلَى ذَوْدٍ لَنَا فَشَرِبْتُمْ مِنْ أَلْبَانِهَا ‏"‏ ‏.‏ قَالَ حُمَيْدٌ وَقَالَ قَتَادَةُ عَنْ أَنَسٍ ‏"‏ وَأَبْوَالِهَا ‏"‏ ‏.‏ فَفَعَلُوا فَلَمَّا صَحُّوا كَفَرُوا بَعْدَ إِسْلاَمِهِمْ وَقَتَلُوا رَاعِيَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُؤْمِنًا وَاسْتَاقُوا ذَوْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهَرَبُوا مُحَارِبِينَ فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَنْ أَتَى بِهِمْ فَأُخِذُوا فَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَّرَ أَعْيُنَهُمْ وَتَرَكَهُمْ فِي الْحَرَّةِ حَتَّى مَاتُوا ‏.‏\hadithno{4031}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas said:"Some people from 'Uraynah became Muslim, but the climate of Al-Madinah did not suit them. The Messenger of Allah [SAW] said to them: 'Why don't you go out to some camels of ours and drink their milk?'" - (one of the narrators) Humaid said: "And Qatadah said, narrating from Anas: 'And their urine.'" - "So they did that, and when they recovered they reverted to disbelief after their Islam, killed the herdsman of the Messenger of Allah [SAW], who was a believer, drove off the camels of the Messenger of Allah [SAW], and fled as those at war. The Messenger of Allah [SAW] sent someone to bring them and they were caught. He had their hands and feet cut off and their eyes branded, then he left them in Al-Harrah until they died}}
\hadithdefcmd{nasai}{4032}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا قَتَادَةُ، أَنَّ أَنَسَ بْنَ مَالِكٍ، حَدَّثَهُمْ أَنَّ نَاسًا أَوْ رِجَالاً مِنْ عُكْلٍ أَوْ عُرَيْنَةَ قَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّا أَهْلُ ضَرْعٍ وَلَمْ نَكُنْ أَهْلَ رِيفٍ ‏.‏ فَاسْتَوْخَمُوا الْمَدِينَةَ فَأَمَرَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم بِذَوْدٍ وَرَاعٍ وَأَمَرَهُمْ أَنْ يَخْرُجُوا فِيهَا فَيَشْرَبُوا مِنْ لَبَنِهَا وَأَبْوَالِهَا فَلَمَّا صَحُّوا - وَكَانُوا بِنَاحِيَةِ الْحَرَّةِ - كَفَرُوا بَعْدَ إِسْلاَمِهِمْ وَقَتَلُوا رَاعِيَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاسْتَاقُوا الذَّوْدَ فَبَعَثَ الطَّلَبَ فِي آثَارِهِمْ فَأُتِيَ بِهِمْ فَسَمَّرَ أَعْيُنَهُمْ وَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ ثُمَّ تَرَكَهُمْ فِي الْحَرَّةِ عَلَى حَالِهِمْ حَتَّى مَاتُوا ‏.‏\hadithno{4032}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Anas bin Malik narrated that:Some people or some men from 'Ukl, or 'Uraynah came to the Messenger of Allah [SAW] and said: "O Messenger of Allah, we are herdsmen, not tillers," the climate of Al-Madinah did not suit them. So the Messenger of Allah [SAW] ordered that they be allocated some camels and a herdsman, and he told them to go out with them and drink their milk and urine. When they recovered and they were in the vicinity of Al-Harrah, they reverted to disbelief after their Islam, killed the herdsman of the Messenger of Allah [SAW] and drove off the camels. He sent (men) after them and they were brought, and he had their eyes gouged out, and their hands and feet cut off. Then he left them in Al-Harrah in that state until they died}}
\hadithdefcmd{nasai}{4033}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ عَبْدِ الأَعْلَى، نَحْوَهُ ‏.‏\hadithno{4033}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated from 'Abdul-A'la:A similar report was narrated from 'Abdul-A'la}}
\hadithdefcmd{nasai}{4034}{أَخْبَرَنَا مُحَمَّدُ بْنُ نَافِعٍ أَبُو بَكْرٍ، قَالَ حَدَّثَنَا بَهْزٌ، قَالَ حَدَّثَنَا حَمَّادٌ، قَالَ حَدَّثَنَا قَتَادَةُ، وَثَابِتٌ، عَنْ أَنَسٍ، أَنَّ نَفَرًا، مِنْ عُرَيْنَةَ نَزَلُوا فِي الْحَرَّةِ فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم فَاجْتَوَوُا الْمَدِينَةَ فَأَمَرَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَكُونُوا فِي إِبِلِ الصَّدَقَةِ وَأَنْ يَشْرَبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا فَقَتَلُوا الرَّاعِيَ وَارْتَدُّوا عَنِ الإِسْلاَمِ وَاسْتَاقُوا الإِبِلَ فَبَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي آثَارِهِمْ فَجِيءَ بِهِمْ فَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَّرَ أَعْيُنَهُمْ وَأَلْقَاهُمْ فِي الْحَرَّةِ ‏.‏ قَالَ أَنَسٌ فَلَقَدْ رَأَيْتُ أَحَدَهُمْ يَكْدُمُ الأَرْضَ بِفِيهِ عَطَشًا حَتَّى مَاتُوا ‏.‏\hadithno{4034}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas that :Some people from 'Uraynah camped in Al-Harrah and came to the Messenger of Allah [SAW]. The climate of Al-Madinah did not suit them, so the Messenger of Allah [SAW] told them to go and stay near the camels that had been given in Sadaqah, and to drink their milk and urine. Then they killed the herdsman and apostatized from Islam, and drove off the camels. The Messenger of Allah [SAW] sent (men) after them, who brought them, then he had their hands and feet cut off, and their eyes gouged out, and left them in Al-Harrah. Anas said: "I saw one of them biting at the ground from thirst, until they died}}
\hadithdefcmd{nasai}{4035}{أَخْبَرَنِي مُحَمَّدُ بْنُ وَهْبٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ حَدَّثَنِي أَبُو عَبْدِ الرَّحِيمِ، قَالَ حَدَّثَنِي زَيْدُ بْنُ أَبِي أُنَيْسَةَ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَدِمَ أَعْرَابٌ مِنْ عُرَيْنَةَ إِلَى نَبِيِّ اللَّهِ صلى الله عليه وسلم فَأَسْلَمُوا فَاجْتَوَوُا الْمَدِينَةَ حَتَّى اصْفَرَّتْ أَلْوَانُهُمْ وَعَظُمَتْ بُطُونُهُمْ فَبَعَثَ بِهِمْ نَبِيُّ اللَّهِ صلى الله عليه وسلم إِلَى لِقَاحٍ لَهُ فَأَمَرَهُمْ أَنْ يَشْرَبُوا مِنْ أَلْبَانِهَا وَأَبْوَالِهَا حَتَّى صَحُّوا فَقَتَلُوا رُعَاتِهَا وَاسْتَاقُوا الإِبِلَ فَبَعَثَ نَبِيُّ اللَّهِ صلى الله عليه وسلم فِي طَلَبِهِمْ فَأُتِيَ بِهِمْ فَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَّرَ أَعْيُنَهُمْ ‏.‏ قَالَ أَمِيرُ الْمُؤْمِنِينَ عَبْدُ الْمَلِكِ لأَنَسٍ وَهُوَ يُحَدِّثُهُ هَذَا الْحَدِيثَ بِكُفْرٍ أَوْ بِذَنْبٍ قَالَ بِكُفْرٍ ‏.‏\hadithno{4035}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"Some Bedouin from 'Uraynah came to the Prophet of Allah [SAW] and accepted Islam, but the climate of Al-Madinah did not suit them; their skin turned yellow and their bellies became swollen. The Prophet of Allah sent them to some milk camels of his and told them to drink their milk and urine until they recovered. Then they killed their herdsmen and drove off the camels. The Prophet of Allah sent (men) after them and they were brought back, then he had their hands and feet cut off, and their eyes were branded." The Commander of the Believers, 'Abdul-Malik, said to Anas, when he was narrating this Hadith: "Was that (punishment) for Kufr or for sin?" He said: "For Kufr}}
\hadithdefcmd{nasai}{4036}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ وَأَخْبَرَنِي يَحْيَى بْنُ أَيُّوبَ، وَمُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ قَدِمَ نَاسٌ مِنَ الْعَرَبِ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَسْلَمُوا ثُمَّ مَرِضُوا فَبَعَثَ بِهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى لِقَاحٍ لِيَشْرَبُوا مِنْ أَلْبَانِهَا فَكَانُوا فِيهَا ثُمَّ عَمَدُوا إِلَى الرَّاعِي غُلاَمِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَتَلُوهُ وَاسْتَاقُوا اللِّقَاحَ فَزَعَمُوا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ عَطِّشَ مَنْ عَطَّشَ آلَ مُحَمَّدٍ اللَّيْلَةَ ‏"‏ ‏.‏ فَبَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي طَلَبِهِمْ فَأُخِذُوا فَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَلَ أَعْيُنَهُمْ ‏.‏ وَبَعْضُهُمْ يَزِيدُ عَلَى بَعْضٍ إِلاَّ أَنَّ مُعَاوِيَةَ قَالَ فِي هَذَا الْحَدِيثِ اسْتَاقُوا إِلَى أَرْضِ الشِّرْكِ ‏.‏\hadithno{4036}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sa'eed bin Al-Musayyab said:"Some 'Arab people came to the Messenger of Allah [SAW] and accepted Islam, then they became sick. The Messenger of Allah [SAW] sent them to some milk camels to drink their milk. While they were with them, they attacked the herdsman, who was a slave of the Messenger of Allah [SAW], and killed him. They drove off the camels, and claimed that the Messenger of Allah [SAW] had said: 'O Allah, make thirsty the one who makes the family of Muhammad thirsty tonight.' The Messenger of Allah [SAW] sent (men) after them, and they were caught. Then he had their hands and feet cut off, and their eyes gouged out." Some of them (the narrators) added more than others, except that in his narration of this Hadith, Mu'awiyah said: "They drove them off to the land of Shirk}}
\hadithdefcmd{nasai}{4037}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الْخَلَنْجِيُّ، قَالَ حَدَّثَنَا مَالِكُ بْنُ سُعَيْرٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ أَغَارَ قَوْمٌ عَلَى لِقَاحِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخَذَهُمْ فَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَلَ أَعْيُنَهُمْ ‏.‏\hadithno{4037}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"Some people raided the milk camels of the Messenger of Allah [SAW]. He caught them and had their hands and feet cut off and their eyes gouged out}}
\hadithdefcmd{nasai}{4038}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ إِبْرَاهِيمَ بْنِ أَبِي الْوَزِيرِ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ أَبِي الْوَزِيرِ، قَالَ حَدَّثَنَا الدَّرَاوَرْدِيُّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ قَوْمًا، أَغَارُوا عَلَى لِقَاحِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأُتِيَ بِهِمُ النَّبِيُّ صلى الله عليه وسلم فَقَطَّعَ النَّبِيُّ صلى الله عليه وسلم أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَلَ أَعْيُنَهُمْ ‏.‏ اللَّفْظُ لاِبْنِ الْمُثَنَّى ‏.‏\hadithno{4038}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah:"Some people raided the milk camels of the Messenger of Allah [SAW]. They were brought to the Prophet [SAW], and the Prophet [SAW] had their hands and feet cut off and their eyes gouged out." This is the wording of Ibn Al-Muthanna}}
\hadithdefcmd{nasai}{4039}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، أَنَّ قَوْمًا، أَغَارُوا عَلَى إِبِلِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَلَ أَعْيُنَهُمْ ‏.‏\hadithno{4039}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Hisham, from his father, that:Some people raided the camels of the Messenger of Allah [SAW]. He had their hands and feet cut off and their eyes gouged out}}
\hadithdefcmd{nasai}{4040}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ وَأَخْبَرَنِي يَحْيَى بْنُ عَبْدِ اللَّهِ بْنِ سَالِمٍ، وَسَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ، وَذَكَرَ، آخَرَ عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّهُ قَالَ أَغَارَ نَاسٌ مِنْ عُرَيْنَةَ عَلَى لِقَاحِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاسْتَاقُوهَا وَقَتَلُوا غُلاَمًا لَهُ فَبَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي آثَارِهِمْ فَأُخِذُوا فَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَلَ أَعْيُنَهُمْ ‏.‏\hadithno{4040}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Urwah bin Az-Zubair said:"Some people from 'Uraynah raided the milk camels of the Messenger of Allah [SAW] and drove them off, and killed a slave of his. The Messenger of Allah [SAW] sent (men) after them, and they were caught, and he had their hands and feet cut off, and their eyes gouged out}}
\hadithdefcmd{nasai}{4041}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ أَخْبَرَنِي ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ أَبِي الزِّنَادِ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَنَزَلَتْ فِيهِمْ آيَةُ الْمُحَارَبَةِ ‏.‏\hadithno{4041}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin 'Umar:From the Messenger of Allah [SAW]: "The Verse about Al-Muharabah was revealed concerning them}}
\hadithdefcmd{nasai}{4042}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِي الزِّنَادِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا قَطَّعَ الَّذِينَ سَرَقُوا لِقَاحَهُ وَسَمَلَ أَعْيُنَهُمْ بِالنَّارِ عَاتَبَهُ اللَّهُ فِي ذَلِكَ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏ إِنَّمَا جَزَاءُ الَّذِينَ يُحَارِبُونَ اللَّهَ وَرَسُولَهُ ‏\}‏ الآيَةَ كُلَّهَا ‏.‏\hadithno{4042}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Az-Zinad that:The Messenger of Allah [SAW] had the (hands and feet) of those who drove off his camels cut off, and their eyes gouged out with fire. Allah rebuked him for that, and Allah, Most High, revealed the entire verse: "The recompense of those who wage war against Allah and His Messenger}}
\hadithdefcmd{nasai}{4043}{أَخْبَرَنَا الْفَضْلُ بْنُ سَهْلٍ الأَعْرَجُ، قَالَ حَدَّثَنَا يَحْيَى بْنُ غَيْلاَنَ، - ثِقَةٌ مَأْمُونٌ - قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَنَسٍ، قَالَ إِنَّمَا سَمَلَ النَّبِيُّ صلى الله عليه وسلم أَعْيُنَ أُولَئِكَ لأَنَّهُمْ سَمَلُوا أَعْيُنَ الرُّعَاةِ ‏.‏\hadithno{4043}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas said:"The Prophet [SAW] only had the eyes of those people gouged out, because they had gouged out the eyes of the herdsmen}}
\hadithdefcmd{nasai}{4044}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ عَمْرٍو، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، مِنَ الْيَهُودِ قَتَلَ جَارِيَةً مِنَ الأَنْصَارِ عَلَى حُلِيٍّ لَهَا وَأَلْقَاهَا فِي قَلِيبٍ وَرَضَخَ رَأْسَهَا بِالْحِجَارَةِ فَأُخِذَ فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُرْجَمَ حَتَّى يَمُوتَ ‏.‏\hadithno{4044}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas bin Malik that:A Jewish man killed an Ansari girl for her jewelry, and threw her in an empty well, and crushed her head with a rock. He was caught and the Messenger of Allah [SAW] ordered that he be stoned to death}}
\hadithdefcmd{nasai}{4045}{أَخْبَرَنَا يُوسُفُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، أَنَّ رَجُلاً، قَتَلَ جَارِيَةً مِنَ الأَنْصَارِ عَلَى حُلِيٍّ لَهَا ثُمَّ أَلْقَاهَا فِي قَلِيبٍ وَرَضَخَ رَأْسَهَا بِالْحِجَارَةِ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يُرْجَمَ حَتَّى يَمُوتَ ‏.‏\hadithno{4045}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas that:A man killed an Ansari girl for her jewelry, then he threw her in an empty well, and crushed her head with a rock. The Prophet [SAW] ordered that he be stoned to death}}
\hadithdefcmd{nasai}{4046}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنِي عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنَا يَزِيدُ النَّحْوِيُّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ تَعَالَى ‏\{‏ إِنَّمَا جَزَاءُ الَّذِينَ يُحَارِبُونَ اللَّهَ وَرَسُولَهُ ‏\}‏ الآيَةَ قَالَ نَزَلَتْ هَذِهِ الآيَةُ فِي الْمُشْرِكِينَ فَمَنْ تَابَ مِنْهُمْ قَبْلَ أَنْ يُقْدَرَ عَلَيْهِ لَمْ يَكُنْ عَلَيْهِ سَبِيلٌ وَلَيْسَتْ هَذِهِ الآيَةُ لِلرَّجُلِ الْمُسْلِمِ فَمَنْ قَتَلَ وَأَفْسَدَ فِي الأَرْضِ وَحَارَبَ اللَّهَ وَرَسُولَهُ ثُمَّ لَحِقَ بِالْكُفَّارِ قَبْلَ أَنْ يُقْدَرَ عَلَيْهِ لَمْ يَمْنَعْهُ ذَلِكَ أَنْ يُقَامَ فِيهِ الْحَدُّ الَّذِي أَصَابَ ‏.‏\hadithno{4046}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said, :Concerning the statement of Allah, the Most High: The recompense of those who wage war against Allah and His Messenger. "This Verse was revealed concerning the idolators. Whoever among them repents before he is captured, you have no way against him. This Verse does not apply to the Muslims. Whoever kills, spreads mischief in the land, and wages war against Allah and His Messenger, then joins the disbelievers before he can be caught, there is nothing to prevent the Hadd punishment being carried out on him because of what he did}}
\hadithdefcmd{nasai}{4047}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَحُثُّ فِي خُطْبَتِهِ عَلَى الصَّدَقَةِ وَيَنْهَى عَنِ الْمُثْلَةِ ‏.‏\hadithno{4047}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas who said:"The Messenger of Allah [SAW] used to stress charity in his sermons, and prohibit mutilation}}
\hadithdefcmd{nasai}{4048}{أَخْبَرَنَا الْعَبَّاسُ بْنُ مُحَمَّدٍ الدُّورِيُّ، قَالَ حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، عَنْ إِبْرَاهِيمَ بْنِ طَهْمَانَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ دَمُ امْرِئٍ مُسْلِمٍ إِلاَّ بِإِحْدَى ثَلاَثِ خِصَالٍ زَانٍ مُحْصَنٌ يُرْجَمُ أَوْ رَجُلٌ قَتَلَ رَجُلاً مُتَعَمِّدًا فَيُقْتَلُ أَوْ رَجُلٌ يَخْرُجُ مِنَ الإِسْلاَمِ يُحَارِبُ اللَّهَ عَزَّ وَجَلَّ وَرَسُولَهُ فَيُقْتَلُ أَوْ يُصْلَبُ أَوْ يُنْفَى مِنَ الأَرْضِ ‏"‏ ‏.‏\hadithno{4048}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Aishah that:The Messenger of Allah [SAW] said: "It is not permissible to shed the blood of a Muslim except in three cases: An adulterer who had been married, who should be stoned to death; a man who killed another man intentionally, who should be killed; and a man who left Islam and waged war against Allah, the Might and Sublime, and His Messenger, who should be killed, or crucified, or banished from the land}}
\hadithdefcmd{nasai}{4049}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنِ الشَّعْبِيِّ، عَنْ جَرِيرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَبَقَ الْعَبْدُ لَمْ تُقْبَلْ لَهُ صَلاَةٌ حَتَّى يَرْجِعَ إِلَى مَوَالِيهِ ‏"‏ ‏.‏\hadithno{4049}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jarir said:"The Messenger of Allah [SAW] said: 'If a slave runs away, no Salah will be accepted from him until he goes back to his masters}}
\hadithdefcmd{nasai}{4050}{أَخْبَرَنَا مُحَمَّدُ بْنُ قُدَامَةَ، عَنْ جَرِيرٍ، عَنْ مُغِيرَةَ، عَنِ الشَّعْبِيِّ، قَالَ كَانَ جَرِيرٌ يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ إِذَا أَبَقَ الْعَبْدُ لَمْ تُقْبَلْ لَهُ صَلاَةٌ وَإِنْ مَاتَ مَاتَ كَافِرًا ‏"‏ ‏.‏ وَأَبَقَ غُلاَمٌ لِجَرِيرٍ فَأَخَذَهُ فَضَرَبَ عُنُقَهُ ‏.‏\hadithno{4050}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Daif}\hadithtrans{Jarir used to narrate from the Prophet [SAW]:"If a slave runs away, no Salah will be accepted from him, and if he dies he will die a disbeliever." A slave of Jarir's ran away, and he caught him and struck his neck (killing him)}}
\hadithdefcmd{nasai}{4051}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، قَالَ أَنْبَأَنَا إِسْرَائِيلُ، عَنْ مُغِيرَةَ، عَنِ الشَّعْبِيِّ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ إِذَا أَبَقَ الْعَبْدُ إِلَى أَرْضِ الشِّرْكِ فَلاَ ذِمَّةَ لَهُ ‏.‏\hadithno{4051}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jarir bin 'Abdullah said:"If a slave runs away to the land of Shirk, there is no protection (or immunity) for him}}
\hadithdefcmd{nasai}{4052}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الشَّعْبِيِّ، عَنْ جَرِيرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَبَقَ الْعَبْدُ إِلَى أَرْضِ الشِّرْكِ فَقَدْ حَلَّ دَمُهُ ‏"‏ ‏.‏\hadithno{4052}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jarir said:"The Messenger of Allah [SAW] said: 'If a slave runs away to the land of Shirk, it becomes permissible to shed his blood}}
\hadithdefcmd{nasai}{4053}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا قَاسِمٌ، قَالَ حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، ‏\{‏ عَنِ الشَّعْبِيِّ، ‏\}‏ عَنْ جَرِيرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَبَقَ الْعَبْدُ إِلَى أَرْضِ الشِّرْكِ فَقَدْ حَلَّ دَمُهُ ‏"‏ ‏.‏\hadithno{4053}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jarir that:The Prophet [SAW] said: "If a slave runs away to the land of Shirk, it becomes permissible to shed his blood}}
\hadithdefcmd{nasai}{4054}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا خَالِدُ بْنُ عَبْدِ الرَّحْمَنِ، ‏\{‏ عَنْ إِسْرَائِيلَ، ‏\}‏ عَنْ أَبِي إِسْحَاقَ، عَنِ الشَّعْبِيِّ، عَنْ جَرِيرٍ، قَالَ أَيُّمَا عَبْدٍ أَبَقَ إِلَى أَرْضِ الشِّرْكِ فَقَدْ حَلَّ دَمُهُ ‏.‏\hadithno{4054}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jarir said:"Any slave who runs away to the land of Shirk, it becomes permissible to shed his blood}}
\hadithdefcmd{nasai}{4055}{أَخْبَرَنِي صَفْوَانُ بْنُ عَمْرٍو، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الشَّعْبِيِّ، عَنْ جَرِيرٍ، قَالَ أَيُّمَا عَبْدٍ أَبَقَ إِلَى أَرْضِ الشِّرْكِ فَقَدْ حَلَّ دَمُهُ ‏.‏\hadithno{4055}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jarir said:"Any slave who runs away to the land of Shirk, it becomes permissible to shed his blood}}
\hadithdefcmd{nasai}{4056}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَامِرٍ، عَنْ جَرِيرٍ، قَالَ أَيُّمَا عَبْدٍ أَبَقَ مِنْ مَوَالِيهِ وَلَحِقَ بِالْعَدُوِّ فَقَدْ أَحَلَّ بِنَفْسِهِ ‏.‏\hadithno{4056}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jarir said:"Any slave who runs away from his masters and joins the enemy, he has made it permissible to shed his blood}}
\hadithdefcmd{nasai}{4057}{أَخْبَرَنَا أَبُو الأَزْهَرِ، أَحْمَدُ بْنُ الأَزْهَرِ النَّيْسَابُورِيُّ قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ الرَّازِيُّ، قَالَ أَنْبَأَنَا الْمُغِيرَةُ بْنُ مُسْلِمٍ، عَنْ مَطَرٍ الْوَرَّاقِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُثْمَانَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ دَمُ امْرِئٍ مُسْلِمٍ إِلاَّ بِإِحْدَى ثَلاَثٍ رَجُلٌ زَنَى بَعْدَ إِحْصَانِهِ فَعَلَيْهِ الرَّجْمُ أَوْ قَتَلَ عَمْدًا فَعَلَيْهِ الْقَوَدُ أَوِ ارْتَدَّ بَعْدَ إِسْلاَمِهِ فَعَلَيْهِ الْقَتْلُ ‏"‏ ‏.‏\hadithno{4057}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn 'Umar that:'Uthman said: "I heard the Messenger of Allah [SAW] say: 'It is not permissible to shed the blood of a Muslim except in three cases: A man who commits adultery after having married; or one who kills intentionally, in which case he deserves retaliation; or one who apostatizes after having become Muslim, in which case he deserves to be killed}}
\hadithdefcmd{nasai}{4058}{أَخْبَرَنَا مُؤَمَّلُ بْنُ إِهَابٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنِي ابْنُ جُرَيْجٍ، عَنْ أَبِي النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَحِلُّ دَمُ امْرِئٍ مُسْلِمٍ إِلاَّ بِثَلاَثٍ أَنْ يَزْنِيَ بَعْدَ مَا أُحْصِنَ أَوْ يَقْتُلَ إِنْسَانًا فَيُقْتَلُ أَوْ يَكْفُرَ بَعْدَ إِسْلاَمِهِ فَيُقْتَلُ ‏"‏ ‏.‏\hadithno{4058}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Uthman bin 'Affan said:"I heard the Messenger of Allah [SAW] say: 'It is not permissible to shed the blood of a Muslim except in three cases: A man who commits adultery after having married; or one who kills another person, who is to be killed; or who reverts to Kufr after having accepted Islam, who is to be killed}}
\hadithdefcmd{nasai}{4059}{أَخْبَرَنَا عِمْرَانُ بْنُ مُوسَى، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، قَالَ قَالَ ابْنُ عَبَّاسٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ بَدَّلَ دِينَهُ فَاقْتُلُوهُ ‏"‏ ‏.‏\hadithno{4059}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ibn 'Abbas said:"The Messenger of Allah [SAW] said: 'Whoever changes his religion, kill him}}
\hadithdefcmd{nasai}{4060}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، قَالَ حَدَّثَنَا أَبُو هِشَامٍ، قَالَ حَدَّثَنَا وُهَيْبٌ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، أَنَّ نَاسًا، ارْتَدُّوا عَنِ الإِسْلاَمِ، فَحَرَّقَهُمْ عَلِيٌّ بِالنَّارِ قَالَ ابْنُ عَبَّاسٍ لَوْ كُنْتُ أَنَا لَمْ، أُحَرِّقْهُمْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تُعَذِّبُوا بِعَذَابِ اللَّهِ أَحَدًا ‏"‏ ‏.‏ وَلَوْ كُنْتُ أَنَا لَقَتَلْتُهُمْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ بَدَّلَ دِينَهُ فَاقْتُلُوهُ ‏"‏ ‏.‏\hadithno{4060}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Ikrimah:"Some people apostatized after accepting Islam, and 'Ali burned them with fire. Ibn 'Abbas said: 'If it had been me, I would not have burned them; the Messenger of Allah [SAW] said: 'No one should be punished with the punishment of Allah.' If it had been me, I would have killed them; the Messenger of Allah [SAW] said: 'Whoever changes his religion, kill him}}
\hadithdefcmd{nasai}{4061}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ مَعْمَرٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ بَدَّلَ دِينَهُ فَاقْتُلُوهُ ‏"‏ ‏.‏\hadithno{4061}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah [SAW] said: 'Whoever changes his religion, kill him}}
\hadithdefcmd{nasai}{4062}{أَخْبَرَنِي هِلاَلُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ بْنِ زُرَارَةَ، قَالَ حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ بَدَّلَ دِينَهُ فَاقْتُلُوهُ ‏"‏ ‏.‏\hadithno{4062}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah [SAW] said: 'Whoever changes his religion, kill him}}
\hadithdefcmd{nasai}{4063}{أَخْبَرَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ بَدَّلَ دِينَهُ فَاقْتُلُوهُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ وَهَذَا أَوْلَى بِالصَّوَابِ مِنْ حَدِيثِ عَبَّادٍ ‏.‏\hadithno{4063}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Al-Hasan said:"The Messenger of Allah [SAW] said: 'Whoever changes his religion, kill him}}
\hadithdefcmd{nasai}{4064}{أَخْبَرَنَا الْحُسَيْنُ بْنُ عِيسَى، عَنْ عَبْدِ الصَّمَدِ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ ابْنَ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ بَدَّلَ دِينَهُ فَاقْتُلُوهُ ‏"‏ ‏.‏\hadithno{4064}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that :Ibn 'Abbas said: "The Messenger of Allah [SAW] said: 'Whoever changes his religion, kill him}}
\hadithdefcmd{nasai}{4065}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ الصَّمَدِ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ عَلِيًّا، أُتِيَ بِنَاسٍ مِنَ الزُّطِّ يَعْبُدُونَ وَثَنًا فَأَحْرَقَهُمْ، قَالَ ابْنُ عَبَّاسٍ إِنَّمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ بَدَّلَ دِينَهُ فَاقْتُلُوهُ ‏"‏ ‏.‏\hadithno{4065}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas that :'Ali came to some people of Az-Zutt, who worshipped idols, and burned them. Ibn 'Abbas said: "But the Messenger of Allah [SAW] said: 'Whoever changes his religion, kill him}}
\hadithdefcmd{nasai}{4066}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنِي حَمَّادُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَبِي بُرْدَةَ بْنِ أَبِي مُوسَى الأَشْعَرِيِّ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَهُ إِلَى الْيَمَنِ ثُمَّ أَرْسَلَ مُعَاذَ بْنَ جَبَلٍ بَعْدَ ذَلِكَ فَلَمَّا قَدِمَ قَالَ أَيُّهَا النَّاسُ إِنِّي رَسُولُ رَسُولِ اللَّهِ إِلَيْكُمْ ‏.‏ فَأَلْقَى لَهُ أَبُو مُوسَى وِسَادَةً لِيَجْلِسَ عَلَيْهَا فَأُتِيَ بِرَجُلٍ كَانَ يَهُودِيًّا فَأَسْلَمَ ثُمَّ كَفَرَ فَقَالَ مُعَاذٌ لاَ أَجْلِسُ حَتَّى يُقْتَلَ قَضَاءُ اللَّهِ وَرَسُولِهِ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏.‏ فَلَمَّا قُتِلَ قَعَدَ ‏.‏\hadithno{4066}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Burdah bin Abi Musa Al-Ash'ari, from his father:"That the Prophet [SAW] sent him to Yemen, then he sent Mu'adh bin Jabal after that. When he arrived he said: 'O people, I am the envoy of the Messenger of Allah [SAW] to you.' Abu Musa gave him a cushion to sit down, then a man was brought who had been a Jew, then he became a Muslim, then he reverted to Kufr. Mu'adh said: 'I will not sit down until he is killed; this is the decree of Allah and His Messenger,' (saying it) three times. When he was killed, he sat down}}
\hadithdefcmd{nasai}{4067}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا بْنِ دِينَارٍ، قَالَ حَدَّثَنِي أَحْمَدُ بْنُ مُفَضَّلٍ، قَالَ حَدَّثَنَا أَسْبَاطُ، قَالَ زَعَمَ السُّدِّيُّ عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ لَمَّا كَانَ يَوْمُ فَتْحِ مَكَّةَ أَمَّنَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّاسَ إِلاَّ أَرْبَعَةَ نَفَرٍ وَامْرَأَتَيْنِ وَقَالَ ‏"‏ اقْتُلُوهُمْ وَإِنْ وَجَدْتُمُوهُمْ مُتَعَلِّقِينَ بِأَسْتَارِ الْكَعْبَةِ ‏"‏ ‏.‏ عِكْرِمَةُ بْنُ أَبِي جَهْلٍ وَعَبْدُ اللَّهِ بْنُ خَطَلٍ وَمِقْيَسُ بْنُ صُبَابَةَ وَعَبْدُ اللَّهِ بْنُ سَعْدِ بْنِ أَبِي السَّرْحِ فَأَمَّا عَبْدُ اللَّهِ بْنُ خَطَلٍ فَأُدْرِكَ وَهُوَ مُتَعَلِّقٌ بِأَسْتَارِ الْكَعْبَةِ فَاسْتَبَقَ إِلَيْهِ سَعِيدُ بْنُ حُرَيْثٍ وَعَمَّارُ بْنُ يَاسِرٍ فَسَبَقَ سَعِيدٌ عَمَّارًا - وَكَانَ أَشَبَّ الرَّجُلَيْنِ - فَقَتَلَهُ وَأَمَّا مِقْيَسُ بْنُ صُبَابَةَ فَأَدْرَكَهُ النَّاسُ فِي السُّوقِ فَقَتَلُوهُ وَأَمَّا عِكْرِمَةُ فَرَكِبَ الْبَحْرَ فَأَصَابَتْهُمْ عَاصِفٌ فَقَالَ أَصْحَابُ السَّفِينَةِ أَخْلِصُوا فَإِنَّ آلِهَتَكُمْ لاَ تُغْنِي عَنْكُمْ شَيْئًا هَا هُنَا ‏.‏ فَقَالَ عِكْرِمَةُ وَاللَّهِ لَئِنْ لَمْ يُنَجِّنِي مِنَ الْبَحْرِ إِلاَّ الإِخْلاَصُ لاَ يُنَجِّينِي فِي الْبَرِّ غَيْرُهُ اللَّهُمَّ إِنَّ لَكَ عَلَىَّ عَهْدًا إِنْ أَنْتَ عَافَيْتَنِي مِمَّا أَنَا فِيهِ أَنْ آتِيَ مُحَمَّدًا صلى الله عليه وسلم حَتَّى أَضَعَ يَدِي فِي يَدِهِ فَلأَجِدَنَّهُ عَفُوًّا كَرِيمًا ‏.‏ فَجَاءَ فَأَسْلَمَ وَأَمَّا عَبْدُ اللَّهِ بْنُ سَعْدِ بْنِ أَبِي السَّرْحِ فَإِنَّهُ اخْتَبَأَ عِنْدَ عُثْمَانَ بْنِ عَفَّانَ فَلَمَّا دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم النَّاسَ إِلَى الْبَيْعَةِ جَاءَ بِهِ حَتَّى أَوْقَفَهُ عَلَى النَّبِيِّ صلى الله عليه وسلم قَالَ يَا رَسُولَ اللَّهِ بَايِعْ عَبْدَ اللَّهِ ‏.‏ قَالَ فَرَفَعَ رَأْسَهُ فَنَظَرَ إِلَيْهِ ثَلاَثًا كُلَّ ذَلِكَ يَأْبَى فَبَايَعَهُ بَعْدَ ثَلاَثٍ ثُمَّ أَقْبَلَ عَلَى أَصْحَابِهِ فَقَالَ ‏"‏ أَمَا كَانَ فِيكُمْ رَجُلٌ رَشِيدٌ يَقُومُ إِلَى هَذَا حَيْثُ رَآنِي كَفَفْتُ يَدِي عَنْ بَيْعَتِهِ فَيَقْتُلَهُ ‏"‏ ‏.‏ فَقَالُوا وَمَا يُدْرِينَا يَا رَسُولَ اللَّهِ مَا فِي نَفْسِكَ هَلاَّ أَوْمَأْتَ إِلَيْنَا بِعَيْنِكَ ‏.‏ قَالَ ‏"‏ إِنَّهُ لاَ يَنْبَغِي لِنَبِيٍّ أَنْ يَكُونَ لَهُ خَائِنَةُ أَعْيُنٍ ‏"‏ ‏.‏\hadithno{4067}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Mus'ab bin Sa'd that his father said:"On the day of the Conquest of Makkah, the Messenger of Allah [SAW] granted amnesty to the people, except four men and two women. He said: 'Kill them, even if you find them clinging to the covers of Ka'bah.' (They were) 'Ikrimah bin Abi Jahl, 'Abdullah bin Khatal, Miqyas bin Subabah and 'Abdullah bin Sa'd bin Abi As-Sarh. 'Abdullah bin Khatl was caught while he was clinging to the covers of Ka'bah. Sa'eed bin Huraith and 'Ammar bin Yasir both rushed toward him, but Sa'eed, who was the younger of the two, got there before 'Ammar, and he killed him. Miqyas bin Subabah was caught by the people in the marketplace, and they killed him. 'Ikrimah traveled by sea, and he was caught in a storm. The crew of the ship said: 'Turn sincerely toward Allah, for your (false) gods cannot help you at all in this situation.' 'Ikrimah said: 'By Allah, if nothing came to save me at sea except sincerity toward Allah then nothing else will save me on land. O Allah, I promise You that if You save me from this predicament I will go to Muhammad [SAW] and put my hand in his, and I am sure that I will find him generous and forgiving.' So he came, and accepted Islam. 'Abdullah (bin Sa'd) bin Abi Sarh hid in the house of 'Uthman bin 'Affan, and when the Messenger of Allah [SAW] called the people to give their Oath of Allegiance, he brought him, and made him stand before the Prophet [SAW]. He ('Uthman) said: 'O Messenger of Allah! Accept the allegiance of 'Abdullah.' He raised his head and looked at him three times, refusing his allegiance each time, then he accepted his allegiance after three times. Then he turned to his Companions and said: 'Was there not any sensible man among you who would get up when he saw me refusing to give him my hand and kill him?' They said: 'We did not know, O Messenger of Allah, what was in your heart. Why did you not gesture to us with your eyes?' He said: 'It is not befitting for a Prophet that his eyes be deceitful}}
\hadithdefcmd{nasai}{4068}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ أَنْبَأَنَا دَاوُدُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَجُلٌ مِنَ الأَنْصَارِ أَسْلَمَ ثُمَّ ارْتَدَّ وَلَحِقَ بِالشِّرْكِ ثُمَّ تَنَدَّمَ فَأَرْسَلَ إِلَى قَوْمِهِ سَلُوا لِي رَسُولَ اللَّهِ صلى الله عليه وسلم هَلْ لِي مِنْ تَوْبَةٍ فَجَاءَ قَوْمُهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا إِنَّ فُلاَنًا قَدْ نَدِمَ وَإِنَّهُ أَمَرَنَا أَنْ نَسْأَلَكَ هَلْ لَهُ مِنْ تَوْبَةٍ فَنَزَلَتْ ‏\{‏ كَيْفَ يَهْدِي اللَّهُ قَوْمًا كَفَرُوا بَعْدَ إِيمَانِهِمْ ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ غَفُورٌ رَحِيمٌ ‏\}‏ ‏"‏ ‏.‏ فَأَرْسَلَ إِلَيْهِ فَأَسْلَمَ ‏.‏\hadithno{4068}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"A man from among the Ansar accepted Islam, then he apostatized and went back to Shirk. Then he regretted that, and sent word to his people (saying): 'Ask the Messenger of Allah [SAW], is there any repentance for me?' His people came to the Messenger of Allah [SAW] and said: 'So and so regrets (what he did), and he has told us to ask you if there is any repentance for him?' Then the Verses: 'How shall Allah guide a people who disbelieved after their Belief up to His saying: Verily, Allah is Oft-Forgiving, Most Merciful' was revealed. So he sent word to him, and he accepted Islam}}
\hadithdefcmd{nasai}{4069}{أَخْبَرَنَا زَكَرِيَّا بْنُ يَحْيَى، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، قَالَ أَخْبَرَنِي أَبِي، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ فِي سُورَةِ النَّحْلِ ‏\{‏ مَنْ كَفَرَ بِاللَّهِ مِنْ بَعْدِ إِيمَانِهِ إِلاَّ مَنْ أُكْرِهَ ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ لَهُمْ عَذَابٌ عَظِيمٌ ‏\}‏ فَنُسِخَ وَاسْتَثْنَى مِنْ ذَلِكَ فَقَالَ ‏\{‏ ثُمَّ إِنَّ رَبَّكَ لِلَّذِينَ هَاجَرُوا مِنْ بَعْدِ مَا فُتِنُوا ثُمَّ جَاهَدُوا وَصَبَرُوا إِنَّ رَبَّكَ مِنْ بَعْدِهَا لَغَفُورٌ رَحِيمٌ ‏\}‏ وَهُوَ عَبْدُ اللَّهِ بْنُ سَعْدِ بْنِ أَبِي سَرْحٍ الَّذِي كَانَ عَلَى مِصْرَ كَانَ يَكْتُبُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَأَزَلَّهُ الشَّيْطَانُ فَلَحِقَ بِالْكُفَّارِ فَأَمَرَ بِهِ أَنْ يُقْتَلَ يَوْمَ الْفَتْحِ فَاسْتَجَارَ لَهُ عُثْمَانُ بْنُ عَفَّانَ فَأَجَارَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4069}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said concerning Surat An-Nahl - :"Whoever disbelieved in Allah after his belief, except him who is forced thereto and whose heart is at rest with Faith; but such as open their breasts to disbelief, on them is wrath from Allah, and theirs will be a great torment." "This was abrogated, and an exception was made, as Allah said: "Then, verily, your Lord for those who emigrated after they had been put to trials and thereafter strove hard and fought (for the Cause of Allah) and were patient, verily, your Lord afterward is, Oft-Forgiving, Most Merciful." This was 'Abdullah bin Sa'd bin Abi As-Sarh who was the governor of Egypt and used to write to the Messenger of Allah [SAW]. The Shaitan misled him and he went and joined the unbelievers. So he (the Prophet [SAW]) commanded that he be killed on the day of the Conquest of Makkah. Then, 'Uthman bin 'Afan sought protection for him, and the Messenger of Allah [SAW] granted him protection}}
\hadithdefcmd{nasai}{4070}{أَخْبَرَنَا عُثْمَانُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا عَبَّادُ بْنُ مُوسَى، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنِي إِسْرَائِيلُ، عَنْ عُثْمَانَ الشَّحَّامِ، قَالَ كُنْتُ أَقُودُ رَجُلاً أَعْمَى فَانْتَهَيْتُ إِلَى عِكْرِمَةَ فَأَنْشَأَ يُحَدِّثُنَا قَالَ حَدَّثَنِي ابْنُ عَبَّاسٍ أَنَّ أَعْمَى كَانَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَتْ لَهُ أُمُّ وَلَدٍ وَكَانَ لَهُ مِنْهَا ابْنَانِ وَكَانَتْ تُكْثِرُ الْوَقِيعَةَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم وَتَسُبُّهُ فَيَزْجُرُهَا فَلاَ تَنْزَجِرُ وَيَنْهَاهَا فَلاَ تَنْتَهِي فَلَمَّا كَانَ ذَاتَ لَيْلَةٍ ذَكَرْتُ النَّبِيَّ صلى الله عليه وسلم فَوَقَعَتْ فِيهِ فَلَمْ أَصْبِرْ أَنْ قُمْتُ إِلَى الْمِغْوَلِ فَوَضَعْتُهُ فِي بَطْنِهَا فَاتَّكَأْتُ عَلَيْهِ فَقَتَلْتُهَا فَأَصْبَحَتْ قَتِيلاً فَذُكِرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَجَمَعَ النَّاسَ وَقَالَ ‏"‏ أَنْشُدُ اللَّهَ رَجُلاً لِي عَلَيْهِ حَقٌّ فَعَلَ مَا فَعَلَ إِلاَّ قَامَ ‏"‏ ‏.‏ فَأَقْبَلَ الأَعْمَى يَتَدَلْدَلُ فَقَالَ يَا رَسُولَ اللَّهِ أَنَا صَاحِبُهَا كَانَتْ أُمَّ وَلَدِي وَكَانَتْ بِي لَطِيفَةً رَفِيقَةً وَلِي مِنْهَا ابْنَانِ مِثْلُ اللُّؤْلُؤَتَيْنِ وَلَكِنَّهَا كَانَتْ تُكْثِرُ الْوَقِيعَةَ فِيكَ وَتَشْتُمُكَ فَأَنْهَاهَا فَلاَ تَنْتَهِي وَأَزْجُرُهَا فَلاَ تَنْزَجِرُ فَلَمَّا كَانَتِ الْبَارِحَةَ ذَكَرْتُكَ فَوَقَعَتْ فِيكَ فَقُمْتُ إِلَى الْمِغْوَلِ فَوَضَعْتُهُ فِي بَطْنِهَا فَاتَّكَأْتُ عَلَيْهَا حَتَّى قَتَلْتُهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ اشْهَدُوا أَنَّ دَمَهَا هَدَرٌ ‏"‏ ‏.‏\hadithno{4070}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn 'Abbas narrated that :There was a blind man during the time of the Messenger of Allah [SAW] who had an Umm Walad by whom he had two sons. She used to slander and defame the Messenger of Allah [SAW] a great deal, and he would rebuke her, but she would not pay heed, and he would forbid her to do that, but she ignored him. (The blind man said) One night I mentioned the Prophet [SAW], and she slandered him. I could not bear it so I went and got a dagger which I thrust into her stomach and leaned upon it, and killed her. In the morning she was found slain. Mention of that was made to the Prophet [SAW] and he gathered the people and said: "I adjure by Allah; a man over whom I have the right, that he should obey me, and he did what he did, to stand up." The blind man started to tremble and said: "O Messenger of Allah [SAW], I am the one who killed her. She was my Umm Walad and she was kind and gentle toward me, and I have two sons like pearls from her, but she used to slander and defame you a great deal. I forbade her, but she did not stop, and I rebuked her, but she did not pay heed. Finally, I mentioned your name and she slandered you, so I went and got a dagger which I thrust into her stomach, and leaned on it until I killed her. The Messenger of Allah [SAW] said: "I bear witness that her blood is permissible}}
\hadithdefcmd{nasai}{4071}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ تَوْبَةَ الْعَنْبَرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ قُدَامَةَ بْنِ عَنَزَةَ، عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ، قَالَ أَغْلَظَ رَجُلٌ لأَبِي بَكْرٍ الصِّدِّيقِ فَقُلْتُ أَقْتُلُهُ فَانْتَهَرَنِي وَقَالَ لَيْسَ هَذَا لأَحَدٍ بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4071}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Barzah Al-Aslami said:"A man spoke harshly to Abu Bakr As-Siddiq, and I said: 'Shall I kill him?' He told me off, and said: 'That is not for anyone after the Messenger of Allah [SAW]}}
\hadithdefcmd{nasai}{4072}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ أَبِي بَرْزَةَ، قَالَ تَغَيَّظَ أَبُو بَكْرٍ عَلَى رَجُلٍ فَقُلْتُ مَنْ هُوَ يَا خَلِيفَةَ رَسُولِ اللَّهِ قَالَ لِمَ قُلْتُ لأَضْرِبَ عُنُقَهُ إِنْ أَمَرْتَنِي بِذَلِكَ ‏.‏ قَالَ أَفَكُنْتَ فَاعِلاً قُلْتُ نَعَمْ ‏.‏ قَالَ فَوَاللَّهِ لأَذْهَبَ عِظَمُ كَلِمَتِي الَّتِي قُلْتُ غَضَبَهُ ثُمَّ قَالَ مَا كَانَ لأَحَدٍ بَعْدَ مُحَمَّدٍ صلى الله عليه وسلم ‏.‏\hadithno{4072}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Barzah said:"Abu Bakr got infuriated with a man, and I said: 'Who is he, O Khalifah of the Messenger of Allah?' He said: 'Why?' I said: 'So that I might strike his neck (killing him) if you tell me to.' He said: 'Would you really do that?' I said: 'Yes. By Allah,' the seriousness of what I said took away his anger. Then he said: 'That is not for anyone after Muhammad [SAW]}}
\hadithdefcmd{nasai}{4073}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَعْلَى، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي الْبَخْتَرِيِّ، عَنْ أَبِي بَرْزَةَ، قَالَ مَرَرْتُ عَلَى أَبِي بَكْرٍ وَهُوَ مُتَغَيِّظٌ عَلَى رَجُلٍ مِنْ أَصْحَابِهِ فَقُلْتُ يَا خَلِيفَةَ رَسُولِ اللَّهِ مَنْ هَذَا الَّذِي تَغَيَّظُ عَلَيْهِ قَالَ وَلِمَ تَسْأَلُ قُلْتُ أَضْرِبُ عُنُقَهُ ‏.‏ قَالَ فَوَاللَّهِ لأَذْهَبَ عِظَمُ كَلِمَتِي غَضَبَهُ ثُمَّ قَالَ مَا كَانَتْ لأَحَدٍ بَعْدَ مُحَمَّدٍ صلى الله عليه وسلم ‏.‏\hadithno{4073}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Barzah said:"I passed by Abu Bakr and he was furious with one of his companions. I said: 'O Khalifah of the Messenger of Allah, who is the one with whom you are furious?' He said: 'Why are you asking about him?' I said: 'I will strike his neck (kill him).' By Allah, the seriousness of what I said took away his anger. Then he said: 'That is not for anyone after Muhammad [SAW]}}
\hadithdefcmd{nasai}{4074}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ يَحْيَى بْنِ حَمَّادٍ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سُلَيْمَانَ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي الْبَخْتَرِيِّ، عَنْ أَبِي بَرْزَةَ، قَالَ تَغَيَّظَ أَبُو بَكْرٍ عَلَى رَجُلٍ فَقَالَ لَوْ أَمَرْتَنِي لَفَعَلْتُ ‏.‏ قَالَ أَمَا وَاللَّهِ مَا كَانَتْ لِبَشَرٍ بَعْدَ مُحَمَّدٍ صلى الله عليه وسلم ‏.‏\hadithno{4074}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Barzah said:"Abu Bakr became infuriated with a man." He said: "If you tell me to, I will do it." He said: "By Allah, that is not for any human being after Muhammad [SAW]}}
\hadithdefcmd{nasai}{4075}{أَخْبَرَنَا مُعَاوِيَةُ بْنُ صَالِحٍ الأَشْعَرِيُّ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ زَيْدٍ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنِ أَبِي نَضْرَةَ، عَنْ أَبِي بَرْزَةَ، قَالَ غَضِبَ أَبُو بَكْرٍ عَلَى رَجُلٍ غَضَبًا شَدِيدًا حَتَّى تَغَيَّرَ لَوْنُهُ قُلْتُ يَا خَلِيفَةَ رَسُولِ اللَّهِ وَاللَّهِ لَئِنْ أَمَرْتَنِي لأَضْرِبَنَّ عُنُقَهُ فَكَأَنَّمَا صُبَّ عَلَيْهِ مَاءٌ بَارِدٌ فَذَهَبَ غَضَبُهُ عَنِ الرَّجُلِ ‏.‏ قَالَ ثَكِلَتْكَ أُمُّكَ أَبَا بَرْزَةَ وَإِنَّهَا لَمْ تَكُنْ لأَحَدٍ بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ وَالصَّوَابُ أَبُو نَصْرٍ وَاسْمُهُ حُمَيْدُ بْنُ هِلاَلٍ خَالَفَهُ شُعْبَةُ ‏.‏\hadithno{4075}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Nadrah, that Abu Barzah said:"Abu Bakr got very angry with a man, so much so that his color changed. I said: 'O Khalifah of the Messenger of Allah, if you tell me to, I will strike his neck (kill him).' It was as if cold water had been poured on him and he became calm. He said: 'May your mother be bereft of you, Abu Barzah! That is not for anyone after the Messenger of Allah [SAW]}}
\hadithdefcmd{nasai}{4076}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ أَبِي دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ أَبَا نَصْرٍ، يُحَدِّثُ عَنْ أَبِي بَرْزَةَ، قَالَ أَتَيْتُ عَلَى أَبِي بَكْرٍ وَقَدْ أَغْلَظَ لِرَجُلٍ فَرَدَّ عَلَيْهِ فَقُلْتُ أَلاَ أَضْرِبُ عُنُقَهُ فَانْتَهَرَنِي ‏.‏ فَقَالَ إِنَّهَا لَيْسَتْ لأَحَدٍ بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ أَبُو نَصْرٍ حُمَيْدُ بْنُ هِلاَلٍ ‏.‏ وَرَوَاهُ عَنْهُ يُونُسُ بْنُ عُبَيْدٍ فَأَسْنَدَهُ ‏.‏\hadithno{4076}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Nasr narrated from Abu Barzah, that he said:"I came to Abu Bakr when he had spoken harshly to a man who had answered back. I said: 'Shall I not strike his neck (kill him)?' He rebuked me, and said: 'That is not for anyone after the Messenger of Allah [SAW]}}
\hadithdefcmd{nasai}{4077}{أَخْبَرَنِي أَبُو دَاوُدَ، قَالَ حَدَّثَنَا عَفَّانُ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا يُونُسُ بْنُ عُبَيْدٍ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُطَرِّفِ بْنِ الشِّخِّيرِ، عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ، أَنَّهُ قَالَ كُنَّا عِنْدَ أَبِي بَكْرٍ الصِّدِّيقِ فَغَضِبَ عَلَى رَجُلٍ مِنَ الْمُسْلِمِينَ فَاشْتَدَّ غَضَبُهُ عَلَيْهِ جِدًّا فَلَمَّا رَأَيْتُ ذَلِكَ قُلْتُ يَا خَلِيفَةَ رَسُولِ اللَّهِ أَضْرِبُ عُنُقَهُ فَلَمَّا ذَكَرْتُ الْقَتْلَ أَضْرَبَ عَنْ ذَلِكَ الْحَدِيثِ أَجْمَعَ إِلَى غَيْرِ ذَلِكَ مِنَ النَّحْوِ فَلَمَّا تَفَرَّقْنَا أَرْسَلَ إِلَىَّ فَقَالَ يَا أَبَا بَرْزَةَ مَا قُلْتَ وَنَسِيتُ الَّذِي قُلْتُ قُلْتُ ذَكِّرْنِيهِ ‏.‏ قَالَ أَمَا تَذْكُرُ مَا قُلْتَ قُلْتُ لاَ وَاللَّهِ ‏.‏ قَالَ أَرَأَيْتَ حِينَ رَأَيْتَنِي غَضِبْتُ عَلَى رَجُلٍ فَقُلْتَ أَضْرِبُ عُنُقَهُ يَا خَلِيفَةَ رَسُولِ اللَّهِ أَمَا تَذْكُرُ ذَلِكَ أَوَكُنْتَ فَاعِلاً ذَلِكَ قُلْتُ نَعَمْ وَاللَّهِ وَالآنَ إِنْ أَمَرْتَنِي فَعَلْتُ ‏.‏ قَالَ وَاللَّهِ مَا هِيَ لأَحَدٍ بَعْدَ مُحَمَّدٍ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا الْحَدِيثُ أَحْسَنُ الأَحَادِيثِ وَأَجْوَدُهَا وَاللَّهُ تَعَالَى أَعْلَمُ ‏.‏\hadithno{4077}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Yunus bin 'Ubaid, from Humaid bin Hilal, from 'Abdullah bin Mutarrif bin Ash-Shikhkhir, from Abu Barzah Al-Aslami, that he said:"We were with Abu Bakr As-Siddiq, and he got angry with a man from among the Muslims, and became very angry indeed. When I saw that, I said: 'O Khalifah of the Messenger of Allah, shall I strike his neck?' When I mentioned killing him, he stopped being angry with him and changed the subject. When we parted, he sent for me and said: 'O Abu Barzah, what did you say?' I said: 'I have forgotten what I said; remind me.' He said: 'Do you not remember what you said?' I said: 'No, by Allah.' He said: 'Don't you remember, when you saw me angry with a man, and said, 'I will strike his neck O Khalifah of the Messenger of Allah?' Don't you remember that? Would you really have done that?' I said: 'Yes, by Allah, and if you tell me to do it now, I will do it.' He said: 'By Allah, that is not for anyone after Muhammad [SAW]}}
\hadithdefcmd{nasai}{4078}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، عَنِ ابْنِ إِدْرِيسَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ سَلِمَةَ، عَنْ صَفْوَانَ بْنِ عَسَّالٍ، قَالَ قَالَ يَهُودِيٌّ لِصَاحِبِهِ اذْهَبْ بِنَا إِلَى هَذَا النَّبِيِّ ‏.‏ قَالَ لَهُ صَاحِبُهُ لاَ تَقُلْ نَبِيٌّ لَوْ سَمِعَكَ كَانَ لَهُ أَرْبَعَةُ أَعْيُنٍ ‏.‏ فَأَتَيَا رَسُولَ اللَّهِ صلى الله عليه وسلم وَسَأَلاَهُ عَنْ تِسْعِ آيَاتٍ بَيِّنَاتٍ فَقَالَ لَهُمْ ‏"‏ لاَ تُشْرِكُوا بِاللَّهِ شَيْئًا وَلاَ تَسْرِقُوا وَلاَ تَزْنُوا وَلاَ تَقْتُلُوا النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ وَلاَ تَمْشُوا بِبَرِيءٍ إِلَى ذِي سُلْطَانٍ وَلاَ تَسْحَرُوا وَلاَ تَأْكُلُوا الرِّبَا وَلاَ تَقْذِفُوا الْمُحْصَنَةَ وَلاَ تَوَلَّوْا يَوْمَ الزَّحْفِ وَعَلَيْكُمْ خَاصَّةً يَهُودُ أَنْ لاَ تَعْدُوا فِي السَّبْتِ ‏"‏ ‏.‏ فَقَبَّلُوا يَدَيْهِ وَرِجْلَيْهِ وَقَالُوا نَشْهَدُ أَنَّكَ نَبِيٌّ ‏.‏ قَالَ ‏"‏ فَمَا يَمْنَعُكُمْ أَنْ تَتَّبِعُونِي ‏"‏ ‏.‏ قَالُوا إِنَّ دَاوُدَ دَعَا بِأَنْ لاَ يَزَالَ مِنْ ذُرِّيَّتِهِ نَبِيٌّ وَإِنَّا نَخَافُ إِنِ اتَّبَعْنَاكَ أَنْ تَقْتُلَنَا يَهُودُ ‏.‏\hadithno{4078}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Safwan bin 'Assal said:"A Jew said to his companion: 'Let us go to this Prophet.' His companion said to him: 'Do not say Prophet; if he hears you, he will become big-headed.' So they came to the Messenger of Allah [SAW] and asked him about nine clear signs. He said to them: 'Do not associate anything with Allah, do not steal, do not commit adultery, do not kill any soul whom Allah has forbidden you to kill, except by right, do not speak falsely about an innocent man before a ruler, do not engage in magic, do not consume Riba (usury), do not slander chaste women, and do not flee on the day of the march (to battle). And for you Jews especially, do not break the Sabbath.' They kissed his hands and feet and said: 'We bear witness that you are a Prophet.' He said: 'What is keeping you from following me?' They said: 'Dawud prayed that there would always be a Prophet among his descendants, and we are afraid that if we follow you, the Jews will kill us}}
\hadithdefcmd{nasai}{4079}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا عَبَّادُ بْنُ مَيْسَرَةَ الْمِنْقَرِيُّ، عَنِ الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ عَقَدَ عُقْدَةً ثُمَّ نَفَثَ فِيهَا فَقَدْ سَحَرَ وَمَنْ سَحَرَ فَقَدْ أَشْرَكَ وَمَنْ تَعَلَّقَ شَيْئًا وُكِّلَ إِلَيْهِ ‏"‏ ‏.‏\hadithno{4079}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'Whoever ties a know and blows on it, he has practiced magic; and whoever practices magic, he has committed Shirk; and whoever hangs up something (as an amulet) will be entrusted to it}}
\hadithdefcmd{nasai}{4080}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنِ ابْنِ حَيَّانَ، - يَعْنِي يَزِيدَ - عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ سَحَرَ النَّبِيَّ صلى الله عليه وسلم رَجُلٌ مِنَ الْيَهُودِ فَاشْتَكَى لِذَلِكَ أَيَّامًا فَأَتَاهُ جِبْرِيلُ عَلَيْهِ السَّلاَمُ فَقَالَ إِنَّ رَجُلاً مِنَ الْيَهُودِ سَحَرَكَ عَقَدَ لَكَ عُقَدًا فِي بِئْرِ كَذَا وَكَذَا فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاسْتَخْرَجُوهَا فَجِيءَ بِهَا فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم كَأَنَّمَا نُشِطَ مِنْ عِقَالٍ فَمَا ذَكَرَ ذَلِكَ لِذَلِكَ الْيَهُودِيِّ وَلاَ رَآهُ فِي وَجْهِهِ قَطُّ ‏.‏\hadithno{4080}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Zaid bin Arqam said:"A Jewish man cast a spell on the Prophet [SAW], and he fell ill as a result of it, for several days. Then Jibra'il, peace be upon him, came to him and said: 'A Jewish man has put a spell on you. In such and such a well there is a knot that he tied for you.' The Messenger of Allah [SAW] sent them to take it out and bring it to him. Then the Messenger of Allah [SAW] got up as if he had been released from some bonds. No mention of that was made to that Jew, and he did not see that in his face at all}}
\hadithdefcmd{nasai}{4081}{أَخْبَرَنَا هَنَّادُ بْنُ السَّرِيِّ، فِي حَدِيثِهِ عَنْ أَبِي الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ قَابُوسَ، عَنْ أَبِيهِ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ح وَأَخْبَرَنِي عَلِيُّ بْنُ مُحَمَّدِ بْنِ عَلِيٍّ قَالَ حَدَّثَنَا خَلَفُ بْنُ تَمِيمٍ قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ قَالَ حَدَّثَنَا سِمَاكُ بْنُ حَرْبٍ عَنْ قَابُوسَ بْنِ مُخَارِقٍ عَنْ أَبِيهِ قَالَ وَسَمِعْتُ سُفْيَانَ الثَّوْرِيَّ يُحَدِّثُ بِهَذَا الْحَدِيثِ قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ الرَّجُلُ يَأْتِينِي فَيُرِيدُ مَالِي ‏.‏ قَالَ ‏"‏ ذَكِّرْهُ بِاللَّهِ ‏"‏ ‏.‏ قَالَ فَإِنْ لَمْ يَذَّكَّرْ قَالَ ‏"‏ فَاسْتَعِنْ عَلَيْهِ مَنْ حَوْلَكَ مِنَ الْمُسْلِمِينَ ‏"‏ ‏.‏ قَالَ فَإِنْ لَمْ يَكُنْ حَوْلِي أَحَدٌ مِنَ الْمُسْلِمِينَ قَالَ ‏"‏ فَاسْتَعِنْ عَلَيْهِ بِالسُّلْطَانِ ‏"‏ ‏.‏ قَالَ فَإِنْ نَأَى السُّلْطَانُ عَنِّي قَالَ ‏"‏ قَاتِلْ دُونَ مَالِكَ حَتَّى تَكُونَ مِنْ شُهَدَاءِ الآخِرَةِ أَوْ تَمْنَعَ مَالَكَ ‏"‏ ‏.‏\hadithno{4081}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Qabus bin Mukhariq that his father said:"I heard Sufyan Ath-Thawri narrating this Hadith. He said: 'A man came to the Prophet [SAW] and said: "What if a man comes to me and wants to take my wealth?" He said: "Remind him of Allah." He said: "What if he pays no heed?" He said: "Seek the help of the Muslims around you against him." He said: "What if there are no Muslims around me?" He said: "Seek the help of the ruler against him." He said: "What if the ruler is far away from me?" He said: "Fight to defend your wealth until you either become one of the martyrs of the Hereafter, or you protect your wealth (successfully)}}
\hadithdefcmd{nasai}{4082}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ الْهَادِ، عَنْ عَمْرِو بْنِ قُهَيْدٍ الْغِفَارِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ عُدِيَ عَلَى مَالِي قَالَ ‏"‏ فَانْشُدْ بِاللَّهِ ‏"‏ ‏.‏ قَالَ فَإِنْ أَبَوْا عَلَىَّ ‏.‏ قَالَ ‏"‏ فَانْشُدْ بِاللَّهِ ‏"‏ ‏.‏ قَالَ فَإِنْ أَبَوْا عَلَىَّ ‏.‏ قَالَ ‏"‏ فَانْشُدْ بِاللَّهِ ‏"‏ ‏.‏ قَالَ فَإِنْ أَبَوْا عَلَىَّ قَالَ ‏"‏ فَقَاتِلْ فَإِنْ قُتِلْتَ فَفِي الْجَنَّةِ وَإِنْ قَتَلْتَ فَفِي النَّارِ ‏"‏ ‏.‏\hadithno{4082}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"A man came to the Messenger of Allah [SAW] and said: 'O Messenger of Allah, what do you think if someone comes to steal my wealth?' He said: 'Urge him by Allah.' He said: 'What if he persists?' He said: 'Urge him by Allah.' He said: 'What if he persists?' He said: 'Urge him by Allah.' He said: 'What if he persists?' He said: 'Then fight. If you are killed you will be in Paradise, and if you kill him, he will be in the Fire}}
\hadithdefcmd{nasai}{4083}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبِ بْنِ اللَّيْثِ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنِ ابْنِ الْهَادِ، عَنْ قُهَيْدِ بْنِ مُطَرِّفٍ الْغِفَارِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ عُدِيَ عَلَى مَالِي قَالَ ‏"‏ فَانْشُدْ بِاللَّهِ ‏"‏ ‏.‏ قَالَ فَإِنْ أَبَوْا عَلَىَّ قَالَ ‏"‏ فَانْشُدْ بِاللَّهِ ‏"‏ ‏.‏ قَالَ فَإِنْ أَبَوْا عَلَىَّ قَالَ ‏"‏ فَانْشُدْ بِاللَّهِ ‏"‏ ‏.‏ قَالَ فَإِنْ أَبَوْا عَلَىَّ قَالَ ‏"‏ فَقَاتِلْ فَإِنْ قُتِلْتَ فَفِي الْجَنَّةِ وَإِنْ قَتَلْتَ فَفِي النَّارِ ‏"‏ ‏.‏\hadithno{4083}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that:A man came to the Messenger of Allah [SAW] and said: "O Messenger of Allah, what do you think if someone comes to steal my wealth?" He said: "Urge him by Allah." He said: "What if he persists?" He said: "Urge him by Allah." He said: "What if he persists?" He said: "Urge him by Allah." He said: "What if he persists?" He said: "Then fight. If you are killed you will be in Paradise and if you kill him, he will be in the Fire}}
\hadithdefcmd{nasai}{4084}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا حَاتِمٌ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ قَاتَلَ دُونَ مَالِهِ فَقُتِلَ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{4084}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"I heard the Messenger of Allah [SAW] say: 'Whoever fights to protect his wealth and is killed, he is a martyr}}
\hadithdefcmd{nasai}{4085}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ أَبِي يُونُسَ الْقُشَيْرِيِّ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ صَفْوَانَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ قَاتَلَ دُونَ مَالِهِ فَقُتِلَ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{4085}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"I heard the Messenger of Allah [SAW] say: 'Whoever fights to protect his wealth and is killed, he is a martyr}}
\hadithdefcmd{nasai}{4086}{أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ فَضَالَةَ بْنِ إِبْرَاهِيمَ النَّيْسَابُورِيُّ، قَالَ أَنْبَأَنَا عَبْدُ اللَّهِ، قَالَ حَدَّثَنَا سَعِيدٌ، قَالَ أَنْبَأَنَا أَبُو الأَسْوَدِ، مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ عَنْ عِكْرِمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قُتِلَ دُونَ مَالِهِ مَظْلُومًا فَلَهُ الْجَنَّةُ ‏"‏ ‏.‏\hadithno{4086}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from 'Abdullah bin 'Amr bin Al-'As that:The Messenger of Allah [SAW] said: "Whoever is killed defending his wealth and is killed unjustly, Paradise will be his}}
\hadithdefcmd{nasai}{4087}{أَخْبَرَنَا جَعْفَرُ بْنُ مُحَمَّدِ بْنِ الْهُذَيْلِ، قَالَ حَدَّثَنَا عَاصِمُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا سُعَيْرُ بْنُ الْخِمْسِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَسَنِ، عَنْ عِكْرِمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قُتِلَ دُونَ مَالِهِ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{4087}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abudllah bin 'Amr said:"The Messenger of Allah [SAW] said: 'Whoever is killed defending his wealth, he is a martyr}}
\hadithdefcmd{nasai}{4088}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ حَسَنٍ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ طَلْحَةَ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرٍو، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أُرِيدَ مَالُهُ بِغَيْرِ حَقٍّ فَقَاتَلَ فَقُتِلَ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏ هَذَا خَطَأٌ وَالصَّوَابُ حَدِيثُ سُعَيْرِ بْنِ الْخِمْسِ ‏.‏\hadithno{4088}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibrahim bin Muhammad bin Talhah that he heard 'Abdullah bin 'Amr narrating:From the Prophet [SAW], that he said: "If a person's wealth is sought without right, and he fights (to protect it) and is killed, he is a martyr}}
\hadithdefcmd{nasai}{4089}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَسَنِ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ طَلْحَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قُتِلَ دُونَ مَالِهِ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{4089}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah bin 'Amr said:"The Messenger of Allah [SAW] said: 'Whoever is killed defending his wealth, he is a martyr}}
\hadithdefcmd{nasai}{4090}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَقُتَيْبَةُ، - وَاللَّفْظُ لإِسْحَاقَ - قَالاَ أَنْبَأَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ بْنِ عَوْفٍ، عَنْ سَعِيدِ بْنِ زَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قُتِلَ دُونَ مَالِهِ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{4090}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Sa'eed bin Zaid that:The Prophet [SAW] said: "Whoever is killed defending his wealth, he is a martyr." This is an abridgement of it}}
\hadithdefcmd{nasai}{4091}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدَةُ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ بْنِ عَوْفٍ، عَنْ سَعِيدِ بْنِ زَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَاتَلَ دُونَ مَالِهِ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{4091}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Sa'eed bin Zaid that:The Prophet [SAW] said: "Whoever is killed defending his wealth, he is a martyr}}
\hadithdefcmd{nasai}{4092}{أَخْبَرَنَا أَحْمَدُ بْنُ نَصْرٍ، قَالَ حَدَّثَنَا الْمُؤَمَّلُ، عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قُتِلَ دُونَ مَالِهِ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{4092}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Sulaiman bin Buraidah that his father said:"The Messenger of Allah [SAW] said: 'Whoever is killed defending his wealth, he is a martyr}}
\hadithdefcmd{nasai}{4093}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَلْقَمَةَ، عَنْ أَبِي جَعْفَرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قُتِلَ دُونَ مَظْلَمَتِهِ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ حَدِيثُ الْمُؤَمَّلِ خَطَأٌ وَالصَّوَابُ حَدِيثُ عَبْدِ الرَّحْمَنِ ‏.‏\hadithno{4093}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Ja'far said:"The Messenger of Allah [SAW] said: 'Whoever is killed defending his wealth and is killed unjustly, he is a martyr}}
\hadithdefcmd{nasai}{4094}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ أَبِي عُبَيْدَةَ بْنِ مُحَمَّدٍ، عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ بْنِ عَوْفٍ، عَنْ سَعِيدِ بْنِ زَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَاتَلَ دُونَ مَالِهِ فَقُتِلَ فَهُوَ شَهِيدٌ وَمَنْ قَاتَلَ دُونَ دَمِهِ فَهُوَ شَهِيدٌ وَمَنْ قَاتَلَ دُونَ أَهْلِهِ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{4094}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Sa'eed bin Zaid that:The Prophet [SAW] said: "Whoever fights to protect his wealth and is killed, he is a martyr. Whoever fights to protect himself, he is a martyr. Whoever fights to protect his family is a martyr}}
\hadithdefcmd{nasai}{4095}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ دَاوُدَ - الْهَاشِمِيُّ قَالَ حَدَّثَنَا إِبْرَاهِيمُ، عَنْ أَبِيهِ، عَنْ أَبِي عُبَيْدَةَ بْنِ مُحَمَّدِ بْنِ عَمَّارِ بْنِ يَاسِرٍ، عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ بْنِ عَوْفٍ، عَنْ سَعِيدِ بْنِ زَيْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قُتِلَ دُونَ مَالِهِ فَهُوَ شَهِيدٌ وَمَنْ قُتِلَ دُونَ أَهْلِهِ فَهُوَ شَهِيدٌ وَمَنْ قُتِلَ دُونَ دِينِهِ فَهُوَ شَهِيدٌ وَمَنْ قُتِلَ دُونَ دَمِهِ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{4095}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Sa'eed bin Zaid said:"The Messenger of Allah [SAW] said: 'Whoever is killed protecting his wealth, he is a martyr. Whoever is killed protecting his family, he is a martyr. Whoever is killed protecting his religion, he is a martyr. Whoever is killed protecting himself, he is a martyr}}
\hadithdefcmd{nasai}{4096}{أَخْبَرَنَا الْقَاسِمُ بْنُ زَكَرِيَّا بْنِ دِينَارٍ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، قَالَ حَدَّثَنَا عَبْثَرٌ، عَنْ مُطَرِّفٍ، عَنْ سَوَادَةَ بْنِ أَبِي الْجَعْدِ، عَنْ أَبِي جَعْفَرٍ، قَالَ كُنْتُ جَالِسًا عِنْدَ سُوَيْدِ بْنِ مُقَرِّنٍ فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قُتِلَ دُونَ مَظْلَمَتِهِ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{4096}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Ja'far said:"I was sitting with Suwaid bin Muqarrin, and he said: The Messenger of Allah [SAW] said: "Whoever is killed defending himself against injustice, he is a martyr}}
\hadithdefcmd{nasai}{4097}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ الزُّبَيْرِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ شَهَرَ سَيْفَهُ ثُمَّ وَضَعَهُ فَدَمُهُ هَدَرٌ ‏"‏ ‏.‏\hadithno{4097}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn Az-Zubair that:The Messenger of Allah [SAW] said: "Whoever unsheathes his sword and starts to strike the people with it, it is permissible to shed his blood}}
\hadithdefcmd{nasai}{4098}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، بِهَذَا الإِسْنَادِ مِثْلَهُ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{4098}\hadithgrade{Al-Albani: Sahih Muquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdur-Razzaq narrated:'Abdur-Razzaq narrated a similar report with the same chain, but he did not attribute it to the Prophet [SAW]}}
\hadithdefcmd{nasai}{4099}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ الزُّبَيْرِ، قَالَ مَنْ رَفَعَ السِّلاَحَ ثُمَّ وَضَعَهُ فَدَمُهُ هَدَرٌ ‏.‏\hadithno{4099}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn Az-Zubair said:"Whoever wields a weapon and starts to strike (the people) with it, it is permissible to shed his blood}}
\hadithdefcmd{nasai}{4100}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي مَالِكٌ، وَعَبْدُ اللَّهِ بْنُ عُمَرَ، وَأُسَامَةُ بْنُ زَيْدٍ، وَيُونُسُ بْنُ يَزِيدَ، أَنَّ نَافِعًا، أَخْبَرَهُمْ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَمَلَ عَلَيْنَا السِّلاَحَ فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{4100}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that :The Prophet [SAW] said: "Whoever bears weapons against us, he is not one of us}}
\hadithdefcmd{nasai}{4101}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا الثَّوْرِيُّ، عَنْ أَبِيهِ، عَنِ ابْنِ أَبِي نُعْمٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ بَعَثَ عَلِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ بِالْيَمَنِ بِذُهَيْبَةٍ فِي تُرْبَتِهَا فَقَسَمَهَا بَيْنَ الأَقْرَعِ بْنِ حَابِسٍ الْحَنْظَلِيِّ ثُمَّ أَحَدِ بَنِي مُجَاشِعٍ وَبَيْنَ عُيَيْنَةَ بْنِ بَدْرٍ الْفَزَارِيِّ وَبَيْنَ عَلْقَمَةَ بْنِ عُلاَثَةَ الْعَامِرِيِّ ثُمَّ أَحَدِ بَنِي كِلاَبٍ وَبَيْنَ زَيْدِ الْخَيْلِ الطَّائِيِّ ثُمَّ أَحَدَ بَنِي نَبْهَانَ - قَالَ - فَغَضِبَتْ قُرَيْشٌ وَالأَنْصَارُ وَقَالُوا يُعْطِي صَنَادِيدَ أَهْلِ نَجْدٍ وَيَدَعُنَا فَقَالَ ‏"‏ إِنَّمَا أَتَأَلَّفُهُمْ ‏"‏ ‏.‏ فَأَقْبَلَ رَجُلٌ غَائِرَ الْعَيْنَيْنِ نَاتِئَ الْوَجْنَتَيْنِ كَثَّ اللِّحْيَةِ مَحْلُوقَ الرَّأْسِ فَقَالَ يَا مُحَمَّدُ اتَّقِ اللَّهَ قَالَ ‏"‏ مَنْ يُطِعِ اللَّهَ إِذَا عَصَيْتُهُ أَيَأْمَنُنِي عَلَى أَهْلِ الأَرْضِ وَلاَ تَأْمَنُونِي ‏"‏ ‏.‏ فَسَأَلَ رَجُلٌ مِنَ الْقَوْمِ قَتْلَهُ فَمَنَعَهُ فَلَمَّا وَلَّى قَالَ ‏"‏ إِنَّ مِنْ ضِئْضِئِ هَذَا قَوْمًا يَخْرُجُونَ يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ حَنَاجِرَهُمْ يَمْرُقُونَ مِنَ الدِّينِ مُرُوقَ السَّهْمِ مِنَ الرَّمِيَّةِ يَقْتُلُونَ أَهْلَ الإِسْلاَمِ وَيَدَعُونَ أَهْلَ الأَوْثَانِ لَئِنْ أَنَا أَدْرَكْتُهُمْ لأَقْتُلَنَّهُمْ قَتْلَ عَادٍ ‏"‏ ‏.‏\hadithno{4101}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"When 'Ali was in Yemen, he sent some gold that was still enclosed in rock to the Prophet [SAW], who distributed it among Al-Aqra' bin Habis Al-Hanzali, who belonged to Banu Mujashi', 'Uyaynah bin Badr Al-Fazari, 'Alqamah bin 'Ulathah Al-'Amiri, who belonged to Banu Kilab and Zaid Al-Khail At-Ta'I, who belonged to Banu Nabhan. The Quraish and the Ansar became angry and said: 'He gives to the chiefs of Najd and ignores us!' He said: 'I am seeking to win them over (firmly to Islam).' Then a man with sunken eyes, a bulging forehead, a thick beard and a shaven head came and said: 'O Muhammad, fear Allah!' He said: 'Who will obey Allah if I do not? He trusts me with the people of this Earth but you do not trust me.' A man among the people asked for permission to kill him, but he did not let him do that. When (the man) went away, he (the Prophet [SAW]) said: 'Among the offspring of this man there will be people who will recite the Qur'an but it will not go beyond their throats, and they will go out of Islam as an arrow goes through the target. They will kill the Muslims and leave the idol-worshippers alone. If I live to see them, I will kill them as the killing of 'Ad}}
\hadithdefcmd{nasai}{4102}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ خَيْثَمَةَ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، عَنْ عَلِيٍّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَخْرُجُ قَوْمٌ فِي آخِرِ الزَّمَانِ أَحْدَاثُ الأَسْنَانِ سُفَهَاءُ الأَحْلاَمِ يَقُولُونَ مِنْ خَيْرِ قَوْلِ الْبَرِيَّةِ لاَ يُجَاوِزُ إِيمَانُهُمْ حَنَاجِرَهُمْ يَمْرُقُونَ مِنَ الدِّينِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ فَإِذَا لَقِيتُمُوهُمْ فَاقْتُلُوهُمْ فَإِنَّ قَتْلَهُمْ أَجْرٌ لِمَنْ قَتَلَهُمْ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4102}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Ali said:"I heard the Messenger of Allah [SAW] say: 'At the end of time there will appear young people with foolish minds. Their faith will not pass through their throats, and they will go out of Islam as an arrow goes through the target. If you meet them, then kill them, for killing them will bring reward to the one who killed them on the Day of Resurrection}}
\hadithdefcmd{nasai}{4103}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَعْمَرٍ الْبَصْرِيُّ الْحَرَّانِيُّ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنِ الأَزْرَقِ بْنِ قَيْسٍ، عَنْ شَرِيكِ بْنِ شِهَابٍ، قَالَ كُنْتُ أَتَمَنَّى أَنْ أَلْقَى، رَجُلاً مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَسْأَلُهُ عَنِ الْخَوَارِجِ فَلَقِيتُ أَبَا بَرْزَةَ فِي يَوْمِ عِيدٍ فِي نَفَرٍ مِنْ أَصْحَابِهِ فَقُلْتُ لَهُ هَلْ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَذْكُرُ الْخَوَارِجَ فَقَالَ نَعَمْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِأُذُنِي وَرَأَيْتُهُ بِعَيْنِي أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَالٍ فَقَسَمَهُ فَأَعْطَى مَنْ عَنْ يَمِينِهِ وَمَنْ عَنْ شِمَالِهِ وَلَمْ يُعْطِ مَنْ وَرَاءَهُ شَيْئًا فَقَامَ رَجُلٌ مِنْ وَرَائِهِ فَقَالَ يَا مُحَمَّدُ مَا عَدَلْتَ فِي الْقِسْمَةِ ‏.‏ رَجُلٌ أَسْوَدُ مَطْمُومُ الشَّعْرِ عَلَيْهِ ثَوْبَانِ أَبْيَضَانِ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم غَضَبًا شَدِيدًا وَقَالَ ‏"‏ وَاللَّهِ لاَ تَجِدُونَ بَعْدِي رَجُلاً هُوَ أَعْدَلُ مِنِّي ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ يَخْرُجُ فِي آخِرِ الزَّمَانِ قَوْمٌ كَأَنَّ هَذَا مِنْهُمْ يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ تَرَاقِيَهُمْ يَمْرُقُونَ مِنَ الإِسْلاَمِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ سِيمَاهُمُ التَّحْلِيقُ لاَ يَزَالُونَ يَخْرُجُونَ حَتَّى يَخْرُجَ آخِرُهُمْ مَعَ الْمَسِيحِ الدَّجَّالِ فَإِذَا لَقِيتُمُوهُمْ فَاقْتُلُوهُمْ هُمْ شَرُّ الْخَلْقِ وَالْخَلِيقَةِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ رَحِمَهُ اللَّهُ شَرِيكُ بْنُ شِهَابٍ لَيْسَ بِذَلِكَ الْمَشْهُورِ ‏.‏\hadithno{4103}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{it was narrated that Sharik bin Shihab said:"I used to wish that I could meet a man among the Companions of the Prophet [SAW] and ask him about the Khawarij. Then I met Abu Barzah on the day of 'Id, with a number of his companions. I said to him: 'Did you hear the Messenger of Allah [SAW] mention the Khawarij?' He said: 'Yes. I heard the Messenger of Allah [SAW] with my own ears, and saw him with my own eyes. Some wealth was brought to the Messenger of Allah [SAW] and he distributed it to those on his right and on his left, but he did not give anything to those who were behind him. Then a man stood behind him and said: "O Muhammad! You have not been just in your division!" He was a man with black patchy (shaved) hair, wearing two white garments. So Allah's Messenger [SAW] became very angry and said: "By Allah! You will not find a man after me who is more just than me." Then he said: "A people will come at the end of time; as if he is one of them, reciting the Qur'an without it passing beyond their throats. They will go through Islam just as the arrow goes through the target. Their distinction will be shaving. They will not cease to appear until the last of them comes with Al-Masih Ad-Dajjal. So when you meet them, then kill them, they are the worst of created beings}}
\hadithdefcmd{nasai}{4104}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ عُمَرَ بْنِ سَعْدٍ، قَالَ حَدَّثَنَا سَعْدُ بْنُ أَبِي وَقَّاصٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قِتَالُ الْمُسْلِمِ كُفْرٌ وَسِبَابُهُ فُسُوقٌ ‏"‏ ‏.‏\hadithno{4104}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Sa'd bin Abi Waqas told us that:The Messenger of Allah [SAW] said: "Fighting a Muslim is Kufr and defaming him is evildoing}}
\hadithdefcmd{nasai}{4105}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ أَبَا الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ سِبَابُ الْمُسْلِمِ فُسُوقٌ وَقِتَالُهُ كُفْرٌ ‏.‏\hadithno{4105}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah said:"Defaming a Muslim is evildoing and fighting him is Kufr." (Sahih Mawquf)}}
\hadithdefcmd{nasai}{4106}{أَخْبَرَنَا يَحْيَى بْنُ حَكِيمٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ سِبَابُ الْمُسْلِمِ فِسْقٌ وَقِتَالُهُ كُفْرٌ ‏.‏ فَقَالَ لَهُ أَبَانُ يَا أَبَا إِسْحَاقَ أَمَا سَمِعْتَهُ إِلاَّ مِنْ أَبِي الأَحْوَصِ قَالَ بَلْ سَمِعْتُهُ مِنَ الأَسْوَدِ وَهُبَيْرَةَ ‏.‏\hadithno{4106}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Shu'bah, from Abu Ishaq who said:"I heard Abu Al-Ahwas (narrate) that 'Abdullah said: 'Defaming a Muslim is evildoing and fighting him is Kufr.'" So Aban said to him: "O Abu Ishaq! You heard it only from Abu Al-Ahwas?" He said: "Rather, I heard it from Al-Aswad and Hubairah}}
\hadithdefcmd{nasai}{4107}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزَّعْرَاءِ، عَنْ عَمِّهِ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ سِبَابُ الْمُسْلِمِ فُسُوقٌ وَقِتَالُهُ كُفْرٌ ‏.‏\hadithno{4107}\hadithgrade{Abu Ghuddah: Sahih Isnaad Mauquf; Al-Albani: Sahih Isnaad Mauquf; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Abdullah said:"Defaming a Muslim is evildoing and fighting him is Kufr." (Sahih Mawquf)}}
\hadithdefcmd{nasai}{4108}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ عَبْدَ الْمَلِكِ بْنَ عُمَيْرٍ، يُحَدِّثُهُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ سِبَابُ الْمُسْلِمِ فُسُوقٌ وَقِتَالُهُ كُفْرٌ ‏"‏ ‏.‏\hadithno{4108}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Abdur-Rahman bin 'Abdullah, from his father, that:The Messenger of Allah [SAW] said: "Defaming a Muslim is evildoing and fighting him is Kufr}}
\hadithdefcmd{nasai}{4109}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ قُلْتُ لِحَمَّادٍ سَمِعْتُ مَنْصُورًا، وَسُلَيْمَانَ، وَزُبَيْدًا، يُحَدِّثُونَ عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ سِبَابُ الْمُسْلِمِ فُسُوقٌ وَقِتَالُهُ كُفْرٌ ‏"‏ ‏.‏ مَنْ تَتَّهِمُ أَتَتَّهِمُ مَنْصُورًا أَتَتَّهِمُ زُبَيْدًا أَتَتَّهِمُ سُلَيْمَانَ قَالَ لاَ وَلَكِنِّي أَتَّهِمُ أَبَا وَائِلٍ ‏.‏\hadithno{4109}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Shu'bah who said:"I said to Hammad: 'I heard Mansur, and Sulaiman, and Zubaid narrating from Abu Wa'il, from 'Abdullah, that the Messenger of Allah [SAW] said: "Defaming a Muslim is evildoing and fighting him is Kufr." - Who are you worried about? Are you worried about Mansur? Are you worried about Zubaid? Are you worried about Sulaiman?' He said: 'No, but I am worried about Abu Wa'il}}
\hadithdefcmd{nasai}{4110}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ زُبَيْدٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سِبَابُ الْمُسْلِمِ فُسُوقٌ وَقِتَالُهُ كُفْرٌ ‏"‏ ‏.‏ قُلْتُ لأَبِي وَائِلٍ سَمِعْتَهُ مِنْ عَبْدِ اللَّهِ قَالَ نَعَمْ ‏.‏\hadithno{4110}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Sufyan bin Zubaid, from Abu Wa'il, from 'Abdullah:"The Messenger of Allah [SAW] said: 'Defaming a Muslim is evildoing and fighting him is Kufr.'" I said to Abu Wa'il: "Did you hear it from 'Abdullah?" He said: "Yes}}
\hadithdefcmd{nasai}{4111}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا مُعَاوِيَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سِبَابُ الْمُسْلِمِ فُسُوقٌ وَقِتَالُهُ كُفْرٌ ‏"‏ ‏.‏\hadithno{4111}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah [SAW] said: 'Defaming a Muslim is evildoing and fighting him is Kufr}}
\hadithdefcmd{nasai}{4112}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ عَبْدُ اللَّهِ سِبَابُ الْمُسْلِمِ فُسُوقٌ وَقِتَالُهُ كُفْرٌ ‏.‏\hadithno{4112}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Wa'il said:"'Abdullah said: 'Defaming a Muslim is evildoing and fighting him is Kufr}}
\hadithdefcmd{nasai}{4113}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قِتَالُ الْمُؤْمِنِ كُفْرٌ وَسِبَابُهُ فُسُوقٌ ‏.‏\hadithno{4113}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah said:"Fighting a believer is Kufr and defaming him is evildoing}}
\hadithdefcmd{nasai}{4114}{أَخْبَرَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ زِيَادِ بْنِ رَبَاحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ خَرَجَ مِنَ الطَّاعَةِ وَفَارَقَ الْجَمَاعَةَ فَمَاتَ مَاتَ مِيتَةً جَاهِلِيَّةً وَمَنْ خَرَجَ عَلَى أُمَّتِي يَضْرِبُ بَرَّهَا وَفَاجِرَهَا لاَ يَتَحَاشَى مِنْ مُؤْمِنِهَا وَلاَ يَفِي لِذِي عَهْدِهَا فَلَيْسَ مِنِّي وَمَنْ قَاتَلَ تَحْتَ رَايَةٍ عُمِّيَّةٍ يَدْعُو إِلَى عَصَبِيَّةٍ أَوْ يَغْضَبُ لِعَصَبِيَّةٍ فَقُتِلَ فَقِتْلَةٌ جَاهِلِيَّةٌ ‏"‏ ‏.‏\hadithno{4114}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah [SAW] said: 'Whoever parts from obedience, and splits away from the Jama'ah and dies, then he has died a death of Jahiliyyah. Whoever rebels against my Ummah, killing good and evil people alike, and does not try to avoid killing the believers, and does not pay attention to those who are under a covenant, then he is not of me. Whoever fights for a cause that is not clear, advocating tribalism, getting angry for the sake of tribalism, and he is killed, then he has died a death of Jahiliyyah}}
\hadithdefcmd{nasai}{4115}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا عِمْرَانُ الْقَطَّانُ، عَنْ قَتَادَةَ، عَنْ أَبِي مِجْلَزٍ، عَنْ جُنْدُبِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَاتَلَ تَحْتَ رَايَةٍ عُمِّيَّةٍ يُقَاتِلُ عَصَبِيَّةً وَيَغْضَبُ لِعَصَبِيَّةٍ فَقِتْلَتُهُ جَاهِلِيَّةٌ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ عِمْرَانُ الْقَطَّانُ لَيْسَ بِالْقَوِيِّ ‏.‏\hadithno{4115}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jundab bin 'Abdullah said:"The Messenger of Allah [SAW] said: 'Whoever fights for a cause that is not clear, advocating tribalism, getting angry for the sake of tribalism, then he has died a death of Jahiliyyah}}
\hadithdefcmd{nasai}{4116}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، عَنْ شُعْبَةَ، قَالَ أَخْبَرَنِي مَنْصُورٌ، قَالَ سَمِعْتُ رِبْعِيًّا، يُحَدِّثُ عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَشَارَ الْمُسْلِمُ عَلَى أَخِيهِ الْمُسْلِمِ بِالسِّلاَحِ فَهُمَا عَلَى جُرُفِ جَهَنَّمَ فَإِذَا قَتَلَهُ خَرَّا جَمِيعًا فِيهَا ‏"‏ ‏.‏\hadithno{4116}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Bakrah said:"The Messenger of Allah [SAW] said: 'If a Muslim points a weapon at his fellow Muslim, then they are on the brink of Hell, and if he kills him, then they will both fall into it}}
\hadithdefcmd{nasai}{4117}{أَخْبَرَنَا أَحْمَدُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا يَعْلَى، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيٍّ، عَنْ أَبِي بَكْرَةَ، قَالَ إِذَا حَمَلَ الرَّجُلاَنِ الْمُسْلِمَانِ السِّلاَحَ أَحَدُهُمَا عَلَى الآخَرِ فَهُمَا عَلَى جُرُفِ جَهَنَّمَ فَإِذَا قَتَلَ أَحَدُهُمَا الآخَرَ فَهُمَا فِي النَّارِ ‏.‏\hadithno{4117}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Bakrah said:"If two Muslim men bear weapons against each other, then they are both on the brink of Hell. And if one of them kills the other, they will both be in Hell}}
\hadithdefcmd{nasai}{4118}{أَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، عَنْ يَزِيدَ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنِ الْحَسَنِ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا تَوَاجَهَ الْمُسْلِمَانِ بِسَيْفَيْهِمَا فَقَتَلَ أَحَدُهُمَا صَاحِبَهُ فَهُمَا فِي النَّارِ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ هَذَا الْقَاتِلُ فَمَا بَالُ الْمَقْتُولِ قَالَ ‏"‏ أَرَادَ قَتْلَ صَاحِبِهِ ‏"‏ ‏.‏\hadithno{4118}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Musa that:The Prophet [SAW] said: "If two Muslims confront each other with swords, and one kills the other, they will both be in Hell." It was said: "O Messenger of Allah, (we understand about) the killer, but what about the one who is killed?" He said: "He wanted to kill his companion}}
\hadithdefcmd{nasai}{4119}{أَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ هَارُونَ - قَالَ أَنْبَأَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا تَوَاجَهَ الْمُسْلِمَانِ بِسَيْفَيْهِمَا فَقَتَلَ أَحَدُهُمَا صَاحِبَهُ فَهُمَا فِي النَّارِ مِثْلَهُ سَوَاءً ‏"‏ ‏.‏\hadithno{4119}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Musa Al-Ash'ari that:The Prophet [SAW] said: "If two Muslims confront each other with swords and one of them kills the other, they will both be in Hell}}
\hadithdefcmd{nasai}{4120}{أَخْبَرَنَا عَلِيُّ بْنُ مُحَمَّدِ بْنِ عَلِيٍّ الْمِصِّيصِيُّ، قَالَ حَدَّثَنَا خَلَفٌ، عَنْ زَائِدَةَ، عَنْ هِشَامٍ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا تَوَاجَهَ الْمُسْلِمَانِ بِسَيْفَيْهِمَا كُلُّ وَاحِدٍ مِنْهُمَا يُرِيدُ قَتْلَ صَاحِبِهِ فَهُمَا فِي النَّارِ ‏"‏ ‏.‏ قِيلَ لَهُ يَا رَسُولَ اللَّهِ هَذَا الْقَاتِلُ فَمَا بَالُ الْمَقْتُولِ قَالَ ‏"‏ إِنَّهُ كَانَ حَرِيصًا عَلَى قَتْلِ صَاحِبِهِ ‏"‏ ‏.‏\hadithno{4120}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Bakrah that :The Prophet [SAW] said: "If two Muslims confront each other with swords, each of them wanting to kill the other, they will both be in Hell." It was said to him: "O Messenger of Allah, (we understand about) the killer, but what about the one who is killed?" He said: "He was determined to kill his companion}}
\hadithdefcmd{nasai}{4121}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا الْخَلِيلُ بْنُ عُمَرَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي قَتَادَةُ، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا الْتَقَى الْمُسْلِمَانِ بِسَيْفَيْهِمَا فَقَتَلَ أَحَدُهُمَا صَاحِبَهُ فَالْقَاتِلُ وَالْمَقْتُولُ فِي النَّارِ ‏"‏ ‏.‏\hadithno{4121}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Bakrah said:"The Messenger [SAW] said: 'If two Muslims meet (and fight) with their swords and one of them kills the other, the killer and the slain will both be in Hell}}
\hadithdefcmd{nasai}{4122}{أَخْبَرَنَا أَحْمَدُ بْنُ فَضَالَةَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنِ الْحَسَنِ، عَنِ الأَحْنَفِ بْنِ قَيْسٍ، عَنْ أَبِي بَكْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِذَا تَوَاجَهَ الْمُسْلِمَانِ بِسَيْفَيْهِمَا فَقَتَلَ أَحَدُهُمَا صَاحِبَهُ فَالْقَاتِلُ وَالْمَقْتُولُ فِي النَّارِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ هَذَا الْقَاتِلُ فَمَا بَالُ الْمَقْتُولِ قَالَ ‏"‏ إِنَّهُ أَرَادَ قَتْلَ صَاحِبِهِ ‏"‏ ‏.‏\hadithno{4122}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Bakrah said:"I heard the Messenger of Allah [SAW] say: 'If two Muslims confront each other with their swords and one of them kills the other, both the killer and the slain will be in Hell.'" They said: "O Messenger of Allah, (we understand about) the killer, but what about the one who is killed?" He said: "He wanted to kill his companion}}
\hadithdefcmd{nasai}{4123}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدَةَ، عَنْ حَمَّادٍ، عَنْ أَيُّوبَ، وَيُونُسَ، وَالْعَلاَءِ بْنِ زِيَادٍ، عَنِ الْحَسَنِ، عَنِ الأَحْنَفِ بْنِ قَيْسٍ، عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا الْتَقَى الْمُسْلِمَانِ بِسَيْفَيْهِمَا فَقَتَلَ أَحَدُهُمَا صَاحِبَهُ فَالْقَاتِلُ وَالْمَقْتُولُ فِي النَّارِ ‏"‏ ‏.‏\hadithno{4123}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Bakrah said:"The Messenger of Allah [SAW] said: 'If two Muslims fight with swords, and one of them kills the other, then the killer and the slain will both be in Hell}}
\hadithdefcmd{nasai}{4124}{أَخْبَرَنَا مُجَاهِدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ عُلَيَّةَ - عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا تَوَاجَهَ الْمُسْلِمَانِ بِسَيْفَيْهِمَا فَقَتَلَ أَحَدُهُمَا صَاحِبَهُ فَالْقَاتِلُ وَالْمَقْتُولُ فِي النَّارِ ‏"‏ ‏.‏ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ هَذَا الْقَاتِلُ فَمَا بَالُ الْمَقْتُولِ قَالَ ‏"‏ إِنَّهُ أَرَادَ قَتْلَ صَاحِبِهِ ‏"‏ ‏.‏\hadithno{4124}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Musa Al-Ash'ari that :The Messenger of Allah [SAW] said: "If two Muslims confront each other with swords and one of them kills the other, then the killer and the slain will both be in Hell." A man said: "O Messenger of Allah, (we understand about) the killer, but what about the one who is killed?" He said: "He wanted to kill his companion}}
\hadithdefcmd{nasai}{4125}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ وَاقِدِ بْنِ مُحَمَّدِ بْنِ زَيْدٍ، أَنَّهُ سَمِعَ أَبَاهُ، يُحَدِّثُ عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَرْجِعُوا بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏ ‏.‏\hadithno{4125}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that :The Prophet [SAW] said: "Do not revert to disbelievers after I am gone, striking the necks of one another (killing one another)}}
\hadithdefcmd{nasai}{4126}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، قَالَ حَدَّثَنَا شَرِيكٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَرْجِعُوا بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ لاَ يُؤْخَذُ الرَّجُلُ بِجِنَايَةِ أَبِيهِ وَلاَ جِنَايَةِ أَخِيهِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا خَطَأٌ وَالصَّوَابُ مُرْسَلٌ ‏.‏\hadithno{4126}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah [SAW] said: 'Do not revert to disbelievers after I am gone, striking the necks of one another (killing one another). No man is to be punished for the sins of his father, or for the sins of his brother}}
\hadithdefcmd{nasai}{4127}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، قَالَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَرْجِعُوا بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ وَلاَ يُؤْخَذُ الرَّجُلُ بِجَرِيرَةِ أَبِيهِ وَلاَ بِجَرِيرَةِ أَخِيهِ ‏"‏ ‏.‏\hadithno{4127}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdullah said:"The Messenger of Allah [SAW] said: 'Do not revert to disbelievers after I am gone, striking the necks of one another (killing one another). No man is to be punished for the sins of his father, or the sins of his brother}}
\hadithdefcmd{nasai}{4128}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ أُلْفِيَنَّكُمْ تَرْجِعُونَ بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ لاَ يُؤْخَذُ الرَّجُلُ بِجَرِيرَةِ أَبِيهِ وَلاَ بِجَرِيرَةِ أَخِيهِ ‏"‏ ‏.‏ هَذَا الصَّوَابُ ‏.‏\hadithno{4128}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Masruq said:"The Messenger of Allah [SAW] said: 'I do not want to see you after I am gone reverting to disbelievers, striking the necks of one another (killing one another). No man is punished for the crime of his father, or the crime of his brother.'" This is correct}}
\hadithdefcmd{nasai}{4129}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ يَعْقُوبَ، قَالَ حَدَّثَنَا يَعْلَى، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَرْجِعُوا بَعْدِي كُفَّارًا ‏"‏ ‏.‏ مُرْسَلٌ ‏.‏\hadithno{4129}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Masruq that:The Messenger of Allah [SAW] said: "Do not revert to disbelievers after I am gone." It is Mursal}}
\hadithdefcmd{nasai}{4130}{أَخْبَرَنَا عَمْرُو بْنُ زُرَارَةَ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي بَكْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَرْجِعُوا بَعْدِي ضُلاَّلاً يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏ ‏.‏\hadithno{4130}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Bakrah that:The Prophet [SAW] said: "Do not revert to misguidance after I am gone, striking the necks of one another (killing one another)}}
\hadithdefcmd{nasai}{4131}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، وَعَبْدُ الرَّحْمَنِ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ عَلِيِّ بْنِ مُدْرِكٍ، قَالَ سَمِعْتُ أَبَا زُرْعَةَ بْنَ عَمْرِو بْنِ جَرِيرٍ، عَنْ جَرِيرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ اسْتَنْصَتَ النَّاسَ قَالَ ‏ "‏ لاَ تَرْجِعُوا بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏ ‏.‏\hadithno{4131}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Jarir that :During the Farewell Pilgrimage, the Messenger of Allah [SAW] asked the people to be quiet and listen, and said: "Do not revert to disbelievers after I am gone, striking the necks of one another (killing one another)}}
\hadithdefcmd{nasai}{4132}{أَخْبَرَنَا أَبُو عُبَيْدَةَ بْنُ أَبِي السَّفَرِ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ قَيْسٍ، قَالَ بَلَغَنِي أَنَّ جَرِيرَ بْنَ عَبْدِ اللَّهِ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اسْتَنْصِتِ النَّاسَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ لاَ أُلْفِيَنَّكُمْ بَعْدَ مَا أَرَى تَرْجِعُونَ بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏ ‏.‏\hadithno{4132}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jarir bin 'Abdullah said:"The Messenger of Allah [SAW] said to me: 'Ask the people to be quiet and listen.' Then he said: 'I do not want to see you after I am gone reverting to disbelievers, striking the necks of one another (killing one another)}}
