% Auto-generated chapter 43 for muslim
% Hadiths in this chapter: 217

\hadithdefcmd{muslim}{384}{\hadithno{384}\hadithtrans{}}
\hadithdefcmd{muslim}{5938}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، وَمُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ سَهْمٍ، جَمِيعًا عَنِ الْوَلِيدِ، - قَالَ ابْنُ مِهْرَانَ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، - حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ أَبِي عَمَّارٍ، شَدَّادٍ أَنَّهُ سَمِعَ وَاثِلَةَ بْنَ الأَسْقَعِ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ اصْطَفَى كِنَانَةَ مِنْ وَلَدِ إِسْمَاعِيلَ وَاصْطَفَى قُرَيْشًا مِنْ كِنَانَةَ وَاصْطَفَى مِنْ قُرَيْشٍ بَنِي هَاشِمٍ وَاصْطَفَانِي مِنْ بَنِي هَاشِمٍ ‏"‏ ‏.‏\hadithno{5938}\hadithtrans{Wathila b. al-Asqa' reported:I heard Allah's Messenger (ﷺ) as saying: Verily Allah granted eminence to Kinana from amongst the descendants of Isma'il, and he granted eminence to the Quraish amongst Kinana, and he granted eminence to Banu Hashim amonsgst the Quraish, and he granted me eminence from the tribe of Banu Hashim}}
\hadithdefcmd{muslim}{5939}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، عَنْ إِبْرَاهِيمَ بْنِ طَهْمَانَ، حَدَّثَنِي سِمَاكُ بْنُ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي لأَعْرِفُ حَجَرًا بِمَكَّةَ كَانَ يُسَلِّمُ عَلَىَّ قَبْلَ أَنْ أُبْعَثَ إِنِّي لأَعْرِفُهُ الآنَ ‏"‏ ‏.‏\hadithno{5939}\hadithtrans{Jabir b. Samura reported Allah's Messenger (ﷺ) as saying:I recognise the stone in Mecca which used to pay me salutations before my advent as a Prophet and I recognise that even now}}
\hadithdefcmd{muslim}{5940}{حَدَّثَنِي الْحَكَمُ بْنُ مُوسَى أَبُو صَالِحٍ، حَدَّثَنَا هِقْلٌ، - يَعْنِي ابْنَ زِيَادٍ - عَنِ الأَوْزَاعِيِّ، حَدَّثَنِي أَبُو عَمَّارٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ فَرُّوخَ، حَدَّثَنِي أَبُو هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا سَيِّدُ وَلَدِ آدَمَ يَوْمَ الْقِيَامَةِ وَأَوَّلُ مَنْ يَنْشَقُّ عَنْهُ الْقَبْرُ وَأَوَّلُ شَافِعٍ وَأَوَّلُ مُشَفَّعٍ ‏"‏ ‏.‏\hadithno{5940}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:I shall be pre-eminent amongst the descendants of Adam on the Day of Resurrection and I will be the first intercessor and the first whose intercession will be accepted (by Allah)}}
\hadithdefcmd{muslim}{5941}{وَحَدَّثَنِي أَبُو الرَّبِيعِ، سُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَعَا بِمَاءٍ فَأُتِيَ بِقَدَحٍ رَحْرَاحٍ فَجَعَلَ الْقَوْمُ يَتَوَضَّئُونَ فَحَزَرْتُ مَا بَيْنَ السِّتِّينَ إِلَى الثَّمَانِينَ - قَالَ - فَجَعَلْتُ أَنْظُرُ إِلَى الْمَاءِ يَنْبُعُ مِنْ بَيْنِ أَصَابِعِهِ ‏.‏\hadithno{5941}\hadithtrans{Anas reported that Allah's Apostle (ﷺ) called for water and he was given a vessel and the people began to perform ablution in that and I counted (the persons) and they were between sixty and eighty and I saw water which was spouting from his fingers}}
\hadithdefcmd{muslim}{5942}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَحَانَتْ صَلاَةُ الْعَصْرِ فَالْتَمَسَ النَّاسُ الْوَضُوءَ فَلَمْ يَجِدُوهُ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِوَضُوءٍ فَوَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي ذَلِكَ الإِنَاءِ يَدَهُ وَأَمَرَ النَّاسَ أَنْ يَتَوَضَّئُوا مِنْهُ - قَالَ - فَرَأَيْتُ الْمَاءَ يَنْبُعُ مِنْ تَحْتِ أَصَابِعِهِ فَتَوَضَّأَ النَّاسُ حَتَّى تَوَضَّئُوا مِنْ عِنْدِ آخِرِهِمْ ‏.‏\hadithno{5942}\hadithtrans{Anas b. Malik reported:I saw Allah's Messenger (ﷺ) during the time of the afternoon prayer and the people asking for water for performing ablution which they did not find. (A small quantity) of water was brought to Allah's Messenger (ﷺ) and he placed his hand in that vessel and commanded people to perform ablution. I saw water spouting from his fingers and the people performing ablution until the last amongst them performed it}}
\hadithdefcmd{muslim}{5943}{حَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا مُعَاذٌ، - يَعْنِي ابْنَ هِشَامٍ - حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم وَأَصْحَابَهُ بِالزَّوْرَاءِ - قَالَ وَالزَّوْرَاءُ بِالْمَدِينَةِ عِنْدَ السُّوقِ وَالْمَسْجِدِ فِيمَا ثَمَّهْ - دَعَا بِقَدَحٍ فِيهِ مَاءٌ فَوَضَعَ كَفَّهُ فِيهِ فَجَعَلَ يَنْبُعُ مِنْ بَيْنِ أَصَابِعِهِ فَتَوَضَّأَ جَمِيعُ أَصْحَابِهِ ‏.‏ قَالَ قُلْتُ كَمْ كَانُوا يَا أَبَا حَمْزَةَ قَالَ كَانُوا زُهَاءَ الثَّلاَثِمِائَةِ ‏.‏\hadithno{5943}\hadithtrans{Anas b. Malik reported that Allah's Apostle (ﷺ) and his Companions were at a place known as az-Zaura' (az-Zaurd' is a place in the bazar of Medina near the mosque) that he called for a vessel containing water. He put his hand in that. And there began to spout (water) between his fingers and all the Companions performed ablution. Qatada, one of the narrators in the chain of narrators, said:Abu Hamza (the kunya of Hadrat Anas b. Malik), how many people were they? He said: They were about three hundred}}
\hadithdefcmd{muslim}{5944}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ بِالزَّوْرَاءِ فَأُتِيَ بِإِنَاءِ مَاءٍ لاَ يَغْمُرُ أَصَابِعَهُ أَوْ قَدْرَ مَا يُوَارِي أَصَابِعَهُ ‏.‏ ثُمَّ ذَكَرَ نَحْوَ حَدِيثِ هِشَامٍ ‏.‏\hadithno{5944}\hadithtrans{Anas reported Allah's Apostle (ﷺ) was at az-Zaura' and a vessel containing water was brought to him in which his finger could not be completely dipped or completely covered; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{5945}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ أُمَّ مَالِكٍ، كَانَتْ تُهْدِي لِلنَّبِيِّ صلى الله عليه وسلم فِي عُكَّةٍ لَهَا سَمْنًا فَيَأْتِيهَا بَنُوهَا فَيَسْأَلُونَ الأُدْمَ وَلَيْسَ عِنْدَهُمْ شَىْءٌ فَتَعْمِدُ إِلَى الَّذِي كَانَتْ تُهْدِي فِيهِ لِلنَّبِيِّ صلى الله عليه وسلم فَتَجِدُ فِيهِ سَمْنًا فَمَا زَالَ يُقِيمُ لَهَا أُدْمَ بَيْتِهَا حَتَّى عَصَرَتْهُ فَأَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ عَصَرْتِيهَا ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ لَوْ تَرَكْتِيهَا مَا زَالَ قَائِمًا ‏"‏ ‏.‏\hadithno{5945}\hadithtrans{Jabir reported that Umm Malik used to send clarified butter in a small skin to the Messenger of Allah (ﷺ). Her sons would come to her and ask for seasoning when they had nothing with them (in the form of condiments) and she would go to that (skin) in which she offered (clarified butter) to Allah's Apostle (ﷺ), and she would find in that clarified butter and it kept providing her with seasoning for her household until she had (completely) squeezed it. She came to Allah's Apostle (ﷺ) and (informed him about it). Thereupon, he (the Holy Prophet) said:Did you squeeze it? She said: Yes. Thereupon he said: If you had left it in that very state, it would have kept on provid- ing you (the clarified butter) on end}}
\hadithdefcmd{muslim}{5946}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم يَسْتَطْعِمُهُ فَأَطْعَمَهُ شَطْرَ وَسْقِ شَعِيرٍ فَمَا زَالَ الرَّجُلُ يَأْكُلُ مِنْهُ وَامْرَأَتُهُ وَضَيْفُهُمَا حَتَّى كَالَهُ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لَوْ لَمْ تَكِلْهُ لأَكَلْتُمْ مِنْهُ وَلَقَامَ لَكُمْ ‏"‏ ‏.‏\hadithno{5946}\hadithtrans{Jabir reported that a person came to Allah's Apostle (ﷺ) and asked for food. And he gave him half a wasq of barley, and the person and his wife and their guests kept on making use of it (as a food) until he weighed it (in order to find out the actual quantity, and it was no more). He came to Allah's Apostle (ﷺ) (and informed him about it). He said:Had you not weighed it, you would be eating out of it and it would have remained intact for you}}
\hadithdefcmd{muslim}{5947}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، حَدَّثَنَا أَبُو عَلِيٍّ الْحَنَفِيُّ، حَدَّثَنَا مَالِكٌ، - وَهُوَ ابْنُ أَنَسٍ - عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، أَنَّ أَبَا الطُّفَيْلِ، عَامِرَ بْنَ وَاثِلَةَ أَخْبَرَهُ أَنَّ مُعَاذَ بْنَ جَبَلٍ أَخْبَرَهُ قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ غَزْوَةِ تَبُوكَ فَكَانَ يَجْمَعُ الصَّلاَةَ فَصَلَّى الظُّهْرَ وَالْعَصْرَ جَمِيعًا وَالْمَغْرِبَ وَالْعِشَاءَ جَمِيعًا حَتَّى إِذَا كَانَ يَوْمًا أَخَّرَ الصَّلاَةَ ثُمَّ خَرَجَ فَصَلَّى الظُّهْرَ وَالْعَصْرَ جَمِيعًا ثُمَّ دَخَلَ ثُمَّ خَرَجَ بَعْدَ ذَلِكَ فَصَلَّى الْمَغْرِبَ وَالْعِشَاءَ جَمِيعًا ثُمَّ قَالَ ‏"‏ إِنَّكُمْ سَتَأْتُونَ غَدًا إِنْ شَاءَ اللَّهُ عَيْنَ تَبُوكَ وَإِنَّكُمْ لَنْ تَأْتُوهَا حَتَّى يُضْحِيَ النَّهَارُ فَمَنْ جَاءَهَا مِنْكُمْ فَلاَ يَمَسَّ مِنْ مَائِهَا شَيْئًا حَتَّى آتِيَ ‏"‏ ‏.‏ فَجِئْنَاهَا وَقَدْ سَبَقَنَا إِلَيْهَا رَجُلاَنِ وَالْعَيْنُ مِثْلُ الشِّرَاكِ تَبِضُّ بِشَىْءٍ مِنْ مَاءٍ - قَالَ - فَسَأَلَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ مَسَسْتُمَا مِنْ مَائِهَا شَيْئًا ‏"‏ ‏.‏ قَالاَ نَعَمْ ‏.‏ فَسَبَّهُمَا النَّبِيُّ صلى الله عليه وسلم وَقَالَ لَهُمَا مَا شَاءَ اللَّهُ أَنْ يَقُولَ - قَالَ - ثُمَّ غَرَفُوا بِأَيْدِيهِمْ مِنَ الْعَيْنِ قَلِيلاً قَلِيلاً حَتَّى اجْتَمَعَ فِي شَىْءٍ - قَالَ - وَغَسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِيهِ يَدَيْهِ وَوَجْهَهُ ثُمَّ أَعَادَهُ فِيهَا فَجَرَتِ الْعَيْنُ بِمَاءٍ مُنْهَمِرٍ أَوْ قَالَ غَزِيرٍ - شَكَّ أَبُو عَلِيٍّ أَيُّهُمَا قَالَ - حَتَّى اسْتَقَى النَّاسُ ثُمَّ قَالَ ‏"‏ يُوشِكُ يَا مُعَاذُ إِنْ طَالَتْ بِكَ حَيَاةٌ أَنْ تَرَى مَا هَا هُنَا قَدْ مُلِئَ جِنَانًا ‏"‏ ‏.‏\hadithno{5947}\hadithtrans{Mu'adh b. Jabal reported that he went along with Allah's Apostle (ﷺ) in the expedition of Tabuk and he (the Holy Prophet) combined the prayers. He offered the noon and afternoon prayers together and the sunset and night prayers together and on the other day he deferred the prayers; he then came out and offered the noon and afternoon prayers together. He then went in and (later on) came out and then after that offered the sunset and night prayers together and then said:God willing, you would reach by tomorrow the fountain of Tabuk and you should not come to that until it is dawn, and he who amongst you happens to go there should not touch its water until I come. We came to that and two persons (amongst) us reached that fountain ahead of us. It was a thin flow of water like the shoelace. Allah's Messenger (ﷺ) asked them whether they had touched the water. They said: Yes. Allah's Apostle (ﷺ) scolded them, and he said to them what he had to say by the will of God. The people then took water of the fountain in their palms until it became somewhat significant and Allah's Messenger (ﷺ) washed his hands and his face too in it, and then, took it again in that (fountain) and there gushed forth abundant water from that fountain, until all the people drank to their fill. He then said: Mu'adh, it is likely that if you live long that you see what is here filled with gardens}}
\hadithdefcmd{muslim}{5948}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ عَبَّاسِ بْنِ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، عَنْ أَبِي حُمَيْدٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم غَزْوَةَ تَبُوكَ فَأَتَيْنَا وَادِيَ الْقُرَى عَلَى حَدِيقَةٍ لاِمْرَأَةٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اخْرُصُوهَا ‏"‏ ‏.‏ فَخَرَصْنَاهَا وَخَرَصَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَشْرَةَ أَوْسُقٍ وَقَالَ ‏"‏ أَحْصِيهَا حَتَّى نَرْجِعَ إِلَيْكِ إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏ وَانْطَلَقْنَا حَتَّى قَدِمْنَا تَبُوكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَتَهُبُّ عَلَيْكُمُ اللَّيْلَةَ رِيحٌ شَدِيدَةٌ فَلاَ يَقُمْ فِيهَا أَحَدٌ مِنْكُمْ فَمَنْ كَانَ لَهُ بَعِيرٌ فَلْيَشُدَّ عِقَالَهُ ‏"‏ ‏.‏ فَهَبَّتْ رِيحٌ شَدِيدَةٌ فَقَامَ رَجُلٌ فَحَمَلَتْهُ الرِّيحُ حَتَّى أَلْقَتْهُ بِجَبَلَىْ طَيِّئٍ وَجَاءَ رَسُولُ ابْنِ الْعَلْمَاءِ صَاحِبِ أَيْلَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِكِتَابٍ وَأَهْدَى لَهُ بَغْلَةً بَيْضَاءَ فَكَتَبَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَهْدَى لَهُ بُرْدًا ثُمَّ أَقْبَلْنَا حَتَّى قَدِمْنَا وَادِيَ الْقُرَى فَسَأَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَرْأَةَ عَنْ حَدِيقَتِهَا ‏"‏ كَمْ بَلَغَ ثَمَرُهَا ‏"‏ ‏.‏ فَقَالَتْ عَشَرَةَ أَوْسُقٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي مُسْرِعٌ فَمَنْ شَاءَ مِنْكُمْ فَلْيُسْرِعْ مَعِيَ وَمَنْ شَاءَ فَلْيَمْكُثْ ‏"‏ ‏.‏ فَخَرَجْنَا حَتَّى أَشْرَفْنَا عَلَى الْمَدِينَةِ فَقَالَ ‏"‏ هَذِهِ طَابَةُ وَهَذَا أُحُدٌ وَهُوَ جَبَلٌ يُحِبُّنَا وَنُحِبُّهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ خَيْرَ دُورِ الأَنْصَارِ دَارُ بَنِي النَّجَّارِ ثُمَّ دَارُ بَنِي عَبْدِ الأَشْهَلِ ثُمَّ دَارُ بَنِي عَبْدِ الْحَارِثِ بْنِ الْخَزْرَجِ ثُمَّ دَارُ بَنِي سَاعِدَةَ وَفِي كُلِّ دُورِ الأَنْصَارِ خَيْرٌ ‏"‏ ‏.‏ فَلَحِقَنَا سَعْدُ بْنُ عُبَادَةَ فَقَالَ أَبُو أُسَيْدٍ أَلَمْ تَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَيَّرَ دُورَ الأَنْصَارِ فَجَعَلَنَا آخِرًا ‏.‏ فَأَدْرَكَ سَعْدٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ خَيَّرْتَ دُورَ الأَنْصَارِ فَجَعَلْتَنَا آخِرًا ‏.‏ فَقَالَ ‏"‏ أَوَلَيْسَ بِحَسْبِكُمْ أَنْ تَكُونُوا مِنَ الْخِيَارِ ‏"‏ ‏.‏\hadithno{5948}\hadithtrans{Abu Humaid as-Sa'idi reported:We went out with Allah's Messenger (ﷺ) on the expedition to Tabuk and we came to a wadi where there was a garden belonging to a woman. Allah's Apostle (ﷺ) said. Make an assessment (of the price of its fruit). And Allah's Messenger (ﷺ) also made an assessment and it was ten wasqs. He asked that lady (to calculate the amount) until they would, God willing, come back to her. So we proceeded on until we came to Tabuk and Allah's Messenger (ﷺ) said: The violent storm will overtake you during the night, so none amongst you should stand up and he who has a camel with him should hobble it firmly. A violent storm blew and a person who had stood up was carried away by the storm and thrown between the mountains of Tayy. Then the messenger of the son of al 'Alma', the ruler of Aila, came to Allah's Messenger (ﷺ) with a letter and a gift of a white mule. Allah's Messenger (ﷺ) wrote him (the reply) and presented him a cloak. We came back until we halted in the Wadi al-Qura. Allah's Messenger (ﷺ) asked that lady about her garden and the price of the fruits in that. She said: Ten wasqs. Thereupon Allah's Messenger (ﷺ) said: I am going to depart, and he who amongst you wishes may depart with me but he who wants to stay may stay. We resumed the journey until we came to the outskirts of Medina. (It was at this time) that Allah's Messenger (ﷺ) said: This is Taba, this is Uhud, that is a mountain which loves us and we love it, and then said: The best amongst the houses of the Ansar is the house of Bani Najjar. Then the house of Bani Abd al-Ashhal, then the house of Bani Abd al-Harith b. Khazraj, then the house of Bani Sa'ida, and there is goodness in all the houses of the Ansar. Said b. Ubada came to us and Abu Usaid said to him: Did you not see that Allah's Messenger (ﷺ) has declared the houses of the Ansar good and he has kept us at the end. Said met Allah's Messenger (ﷺ) and said: Allah's Messenger, you have declared the house of the Ansar as good and have kept us at the end, whereupon he said: Is it not enough for you that you have been counted amongst the good}}
\hadithdefcmd{muslim}{5949}{حَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْمُغِيرَةُ بْنُ سَلَمَةَ الْمَخْزُومِيُّ، قَالاَ حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، بِهَذَا الإِسْنَادِ إِلَى قَوْلِهِ ‏ "‏ وَفِي كُلِّ دُورِ الأَنْصَارِ خَيْرٌ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ مَا بَعْدَهُ مِنْ قِصَّةِ سَعْدِ بْنِ عُبَادَةَ وَزَادَ فِي حَدِيثِ وُهَيْبٍ فَكَتَبَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِبَحْرِهِمْ ‏.‏ وَلَمْ يَذْكُرْ فِي حَدِيثِ وُهَيْبٍ فَكَتَبَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5949}\hadithtrans{This hadith has been narrated on the authority of 'Amr b. Yahya with the same chain of transmitters up to the words:There is good in all the houses of the Ansar, and there is no mention of the subsequent event pertaining to Sa'd b. 'Ubada}}
\hadithdefcmd{muslim}{5950}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي، سَلَمَةَ عَنْ جَابِرٍ، ح وَحَدَّثَنِي أَبُو عِمْرَانَ، مُحَمَّدُ بْنُ جَعْفَرِ بْنِ زِيَادٍ - وَاللَّفْظُ لَهُ - أَخْبَرَنَا إِبْرَاهِيمُ، - يَعْنِي ابْنَ سَعْدٍ - عَنِ الزُّهْرِيِّ، عَنْ سِنَانِ بْنِ أَبِي سِنَانٍ الدُّؤَلِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ غَزَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم غَزْوَةً قِبَلَ نَجْدٍ فَأَدْرَكَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي وَادٍ كَثِيرِ الْعِضَاهِ فَنَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم تَحْتَ شَجَرَةٍ فَعَلَّقَ سَيْفَهُ بِغُصْنٍ مِنْ أَغْصَانِهَا - قَالَ - وَتَفَرَّقَ النَّاسُ فِي الْوَادِي يَسْتَظِلُّونَ بِالشَّجَرِ - قَالَ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ رَجُلاً أَتَانِي وَأَنَا نَائِمٌ فَأَخَذَ السَّيْفَ فَاسْتَيْقَظْتُ وَهُوَ قَائِمٌ عَلَى رَأْسِي فَلَمْ أَشْعُرْ إِلاَّ وَالسَّيْفُ صَلْتًا فِي يَدِهِ فَقَالَ لِي مَنْ يَمْنَعُكَ مِنِّي قَالَ قُلْتُ اللَّهُ ‏.‏ ثُمَّ قَالَ فِي الثَّانِيَةِ مَنْ يَمْنَعُكَ مِنِّي قَالَ قُلْتُ اللَّهُ ‏.‏ قَالَ فَشَامَ السَّيْفَ فَهَا هُوَ ذَا جَالِسٌ ‏"‏ ‏.‏ ثُمَّ لَمْ يَعْرِضْ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5950}\hadithtrans{Jabir b. Abdullah reported:We went along with Allah's Messenger (ﷺ) on an expedition towards Najd and Allah's Messenger (ﷺ) found us in a valley abounding in thorny trees. Allah's Messenger (ﷺ) stayed for rest under a tree and he suspended his sword by one of its branches under which he was taking rest. The persons scattered in the valley and they also began to take rest under the shade of trees, and Allah's Messenger (ﷺ) said: A person came to me while I was asleep and he took hold of the sword. I woke up and found him standing upon my head and I had hardly become alert (and saw) that the sword was in his hand. And he said: Who can protect you from me? I said: Allah. He again said: Who can protect you from me? I said: Allah. He put his sword in the sheath (and you can see) this man sitting here. Allah's Messenger (ﷺ) did not in any way touch him}}
\hadithdefcmd{muslim}{5951}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، وَأَبُو بَكْرِ بْنُ إِسْحَاقَ قَالاَ أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي سِنَانُ بْنُ أَبِي سِنَانٍ الدُّؤَلِيُّ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ جَابِرَ بْنَ عَبْدِ اللَّهِ الأَنْصَارِيَّ، وَكَانَ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَهُمَا أَنَّهُ غَزَا مَعَ النَّبِيِّ صلى الله عليه وسلم غَزْوَةً قِبَلَ نَجْدٍ فَلَمَّا قَفَلَ النَّبِيُّ صلى الله عليه وسلم قَفَلَ مَعَهُ فَأَدْرَكَتْهُمُ الْقَائِلَةُ يَوْمًا ثُمَّ ذَكَرَ نَحْوَ حَدِيثِ إِبْرَاهِيمَ بْنِ سَعْدٍ وَمَعْمَرٍ ‏.‏\hadithno{5951}\hadithtrans{Jabir b. 'Abdullah al-Ansiri, who was one amongst the Companions of Allah's Apostle (ﷺ), reported that he went on an expedition along with Allah's Messenger (ﷺ) towards Najd and Allah's Messenger (ﷺ) stayed there, and when Allah's Messenger (ﷺ) came back he also came back along with him. They, for one day, stayed for rest; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{5952}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا أَبَانُ بْنُ يَزِيدَ، حَدَّثَنَا يَحْيَى، بْنُ أَبِي كَثِيرٍ عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ، قَالَ أَقْبَلْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا كُنَّا بِذَاتِ الرِّقَاعِ ‏.‏ بِمَعْنَى حَدِيثِ الزُّهْرِيِّ وَلَمْ يَذْكُرْ ثُمَّ لَمْ يَعْرِضْ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{5952}\hadithtrans{Jabir b. 'Abdullah reported:We went along with Allah's Messenger (ﷺ) and as we reached the place Dhat-ur-Riqa'; the rest of the hadith is the same, but there is no mention of the word that Allah's Messenger (ﷺ) did not harm him}}
\hadithdefcmd{muslim}{5953}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو عَامِرٍ الأَشْعَرِيُّ وَمُحَمَّدُ بْنُ الْعَلاَءِ - وَاللَّفْظُ لأَبِي عَامِرٍ - قَالُوا حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ مَثَلَ مَا بَعَثَنِي اللَّهُ بِهِ عَزَّ وَجَلَّ مِنَ الْهُدَى وَالْعِلْمِ كَمَثَلِ غَيْثٍ أَصَابَ أَرْضًا فَكَانَتْ مِنْهَا طَائِفَةٌ طَيِّبَةٌ قَبِلَتِ الْمَاءَ فَأَنْبَتَتِ الْكَلأَ وَالْعُشْبَ الْكَثِيرَ وَكَانَ مِنْهَا أَجَادِبُ أَمْسَكَتِ الْمَاءَ فَنَفَعَ اللَّهُ بِهَا النَّاسَ فَشَرِبُوا مِنْهَا وَسَقَوْا وَرَعَوْا وَأَصَابَ طَائِفَةً مِنْهَا أُخْرَى إِنَّمَا هِيَ قِيعَانٌ لاَ تُمْسِكُ مَاءً وَلاَ تُنْبِتُ كَلأً فَذَلِكَ مَثَلُ مَنْ فَقُهَ فِي دِينِ اللَّهِ وَنَفَعَهُ بِمَا بَعَثَنِي اللَّهُ بِهِ فَعَلِمَ وَعَلَّمَ وَمَثَلُ مَنْ لَمْ يَرْفَعْ بِذَلِكَ رَأْسًا وَلَمْ يَقْبَلْ هُدَى اللَّهِ الَّذِي أُرْسِلْتُ بِهِ ‏"‏ ‏.‏\hadithno{5953}\hadithtrans{Abu Musa reported Allah's Apostle (ﷺ) as saying:The similitude of that guidance and knowledge with which Allah, the Exalted and Glorious, has sent me is that of rain falling upon the earth. There is a good piece of land which receives the rainfall (eagerly) and as a result of it there is grown in it herbage and grass abundantly. Then there is a land hard and barren which retains water and the people derive benefit from it and they drink it and make the animals drink. Then there is another land which is barren. Neither water is retained in it, nor is the grass grown in it. And that is the similitude of the first one who develops the understanding of the religion of Allah and it becomes a source of benefit to him with which Allah sent me. (The second one is that) who acquires the knowledge of religion and imparts it to others. (Then the other type is) one who does not pay attention to (the revealed knowledge) and thus does not accept guidance of Allah with which I have been sent}}
\hadithdefcmd{muslim}{5954}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَرَّادٍ الأَشْعَرِيُّ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لأَبِي كُرَيْبٍ - قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ مَثَلِي وَمَثَلَ مَا بَعَثَنِيَ اللَّهُ بِهِ كَمَثَلِ رَجُلٍ أَتَى قَوْمَهُ فَقَالَ يَا قَوْمِ إِنِّي رَأَيْتُ الْجَيْشَ بِعَيْنَىَّ وَإِنِّي أَنَا النَّذِيرُ الْعُرْيَانُ فَالنَّجَاءَ ‏.‏ فَأَطَاعَهُ طَائِفَةٌ مِنْ قَوْمِهِ فَأَدْلَجُوا فَانْطَلَقُوا عَلَى مُهْلَتِهِمْ وَكَذَّبَتْ طَائِفَةٌ مِنْهُمْ فَأَصْبَحُوا مَكَانَهُمْ فَصَبَّحَهُمُ الْجَيْشُ فَأَهْلَكَهُمْ وَاجْتَاحَهُمْ فَذَلِكَ مَثَلُ مَنْ أَطَاعَنِي وَاتَّبَعَ مَا جِئْتُ بِهِ وَمَثَلُ مَنْ عَصَانِي وَكَذَّبَ مَا جِئْتُ بِهِ مِنَ الْحَقِّ ‏"‏ ‏.‏\hadithno{5954}\hadithtrans{Abu Musa reported Allah's Messenger (ﷺ) as saying:The similitude of mine and of that with which Allah sent me is that of a person who came to us and said: O people, I have seen an army with my eyes and I am a plain warner (and issue you warning) that you should immediately manage to find an escape. A group of people from amongst them paying heed (to his warning) fled to a place of protection and a group amongst them belied him and the morning overtook them in their houses and the army attacked them and killed them and they were routed. And that is the similitude of the one who obeyed me, followed with which I had been sent and the similitude of the other is of one who disobeyed and belied me and the Truth with which I have been sent}}
\hadithdefcmd{muslim}{5955}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ الْقُرَشِيُّ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا مَثَلِي وَمَثَلُ أُمَّتِي كَمَثَلِ رَجُلٍ اسْتَوْقَدَ نَارًا فَجَعَلَتِ الدَّوَابُّ وَالْفَرَاشُ يَقَعْنَ فِيهِ فَأَنَا آخِذٌ بِحُجَزِكُمْ وَأَنْتُمْ تَقَحَّمُونَ فِيهِ ‏"‏ ‏.‏\hadithno{5955}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The similitude of mine and that of my Umma is that of a person who lit fire and there began to fall into it insects and moths. And I am there to hold you back, but you plunge into it}}
\hadithdefcmd{muslim}{5956}{وَحَدَّثَنَاهُ عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{5956}\hadithtrans{The above hadith was likewise narrated with another chain of transmitters}}
\hadithdefcmd{muslim}{5957}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلِي كَمَثَلِ رَجُلٍ اسْتَوْقَدَ نَارًا فَلَمَّا أَضَاءَتْ مَا حَوْلَهَا جَعَلَ الْفَرَاشُ وَهَذِهِ الدَّوَابُّ الَّتِي فِي النَّارِ يَقَعْنَ فِيهَا وَجَعَلَ يَحْجُزُهُنَّ وَيَغْلِبْنَهُ فَيَتَقَحَّمْنَ فِيهَا قَالَ فَذَلِكُمْ مَثَلِي وَمَثَلُكُمْ أَنَا آخِذٌ بِحُجَزِكُمْ عَنِ النَّارِ هَلُمَّ عَنِ النَّارِ هَلُمَّ عَنِ النَّارِ فَتَغْلِبُونِي تَقَحَّمُونَ فِيهَا ‏"‏ ‏.‏\hadithno{5957}\hadithtrans{Hammam b. Munabbih reported:Abu Huraira reported us some ahadith from Allah's Messenger (ﷺ) amongst many, (and) one is this that Allah's Messenger (ﷺ) said: A person lit fire and when the atmosphere was aglow, moths and insects began to fall into the fire, but I am there to hold them back, but they are plunging into it despite my efforts, and he further added: That is your example and mine. I am there to hold you back from fire and to save you from it, but you are plunging into it despite my efforts}}
\hadithdefcmd{muslim}{5958}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، حَدَّثَنَا سَلِيمٌ، عَنْ سَعِيدِ بْنِ مِينَاءَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلِي وَمَثَلُكُمْ كَمَثَلِ رَجُلٍ أَوْقَدَ نَارًا فَجَعَلَ الْجَنَادِبُ وَالْفَرَاشُ يَقَعْنَ فِيهَا وَهُوَ يَذُبُّهُنَّ عَنْهَا وَأَنَا آخِذٌ بِحُجَزِكُمْ عَنِ النَّارِ وَأَنْتُمْ تَفَلَّتُونَ مِنْ يَدِي ‏"‏ ‏.‏\hadithno{5958}\hadithtrans{Jabir b. Abdullah reported Allah's Messenger (ﷺ) as saying. My example and your example is that of a person who lit the fire and insects and moths began to fall in it and he would be making efforts to take them out, and I am going to hold you back from fire, but you are slipping from my hand}}
\hadithdefcmd{muslim}{5959}{حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلِي وَمَثَلُ الأَنْبِيَاءِ كَمَثَلِ رَجُلٍ بَنَى بُنْيَانًا فَأَحْسَنَهُ وَأَجْمَلَهُ فَجَعَلَ النَّاسُ يُطِيفُونَ بِهِ يَقُولُونَ مَا رَأَيْنَا بُنْيَانًا أَحْسَنَ مِنْ هَذَا إِلاَّ هَذِهِ اللَّبِنَةَ ‏.‏ فَكُنْتُ أَنَا تِلْكَ اللَّبِنَةَ ‏"‏ ‏.‏\hadithno{5959}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The similitude of mine and that of the Apostles (before me) is that of a person who constructed a building and he built it fine and well and the people went round it saying: Never have we seen a building more imposing than this. but for one brick, and I am that brick (with which you give the finishing touch to the building)}}
\hadithdefcmd{muslim}{5960}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏"‏ مَثَلِي وَمَثَلُ الأَنْبِيَاءِ مِنْ قَبْلِي كَمَثَلِ رَجُلٍ ابْتَنَى بُيُوتًا فَأَحْسَنَهَا وَأَجْمَلَهَا وَأَكْمَلَهَا إِلاَّ مَوْضِعَ لَبِنَةٍ مِنْ زَاوِيَةٍ مِنْ زَوَايَاهَا فَجَعَلَ النَّاسُ يَطُوفُونَ وَيُعْجِبُهُمُ الْبُنْيَانُ فَيَقُولُونَ أَلاَّ وَضَعْتَ هَا هُنَا لَبِنَةً فَيَتِمَّ بُنْيَانُكَ ‏"‏ ‏.‏ فَقَالَ مُحَمَّدٌ صلى الله عليه وسلم ‏"‏ فَكُنْتُ أَنَا اللَّبِنَةَ ‏"‏ ‏.‏\hadithno{5960}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The similitude of mine and that of the Apostles before me is that of a person who built a house quite imposing and beautiful and he made it complete but for one brick in one of its corners. People began to walk round it, and the building pleased them and they would say: But for this brick your building would have been perfect. Muhammad (ﷺ) said: And I am that final brick}}
\hadithdefcmd{muslim}{5961}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلِي وَمَثَلُ الأَنْبِيَاءِ مِنْ قَبْلِي كَمَثَلِ رَجُلٍ بَنَى بُنْيَانًا فَأَحْسَنَهُ وَأَجْمَلَهُ إِلاَّ مَوْضِعَ لَبِنَةٍ مِنْ زَاوِيَةٍ مِنْ زَوَايَاهُ فَجَعَلَ النَّاسُ يَطُوفُونَ بِهِ وَيَعْجَبُونَ لَهُ وَيَقُولُونَ هَلاَّ وُضِعَتْ هَذِهِ اللَّبِنَةُ - قَالَ - فَأَنَا اللَّبِنَةُ وَأَنَا خَاتَمُ النَّبِيِّينَ ‏"‏ ‏.‏\hadithno{5961}\hadithtrans{Abu Hurairh reported Allah's Messenger (ﷺ) as saying:The similitude of mine and that of the Apostles before me is that of a person who built a house quite imposing and beautiful, but for one brick in one of its corners. People would go round it, appreciating the building, but saying: Why has the brick not been fixed here? He said: I am that brick and I am the last of the Apostles}}
\hadithdefcmd{muslim}{5962}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلِي وَمَثَلُ النَّبِيِّينَ ‏"‏ ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{5962}\hadithtrans{Abu Sa'id reported Allah's Messenger (ﷺ) as saying:The similitude of mine and that of the Apostles; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{5963}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا سَلِيمُ بْنُ حَيَّانَ، حَدَّثَنَا سَعِيدُ، بْنُ مِينَاءَ عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَثَلِي وَمَثَلُ الأَنْبِيَاءِ كَمَثَلِ رَجُلٍ بَنَى دَارًا فَأَتَمَّهَا وَأَكْمَلَهَا إِلاَّ مَوْضِعَ لَبِنَةٍ فَجَعَلَ النَّاسُ يَدْخُلُونَهَا وَيَتَعَجَّبُونَ مِنْهَا وَيَقُولُونَ لَوْلاَ مَوْضِعُ اللَّبِنَةِ ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَأَنَا مَوْضِعُ اللَّبِنَةِ جِئْتُ فَخَتَمْتُ الأَنْبِيَاءَ ‏"‏ ‏.‏\hadithno{5963}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) as saying:The similitude of mine and that of the Apostles is like that of a person who built a house and he completed it and made it perfect but for the space of a brick. People entered therein and they were surprised at it and said: Had there been a brick (it would have been complete in all respects). Allah's Messenger (ﷺ) said: I am that place where the brick (completing the building is to be placed), and I have come to finalise the chain of Apostles}}
\hadithdefcmd{muslim}{5964}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، حَدَّثَنَا سَلِيمٌ، بِهَذَا الإِسْنَادِ مِثْلَهُ وَقَالَ بَدَلَ أَتَمَّهَا أَحْسَنَهَا ‏.‏\hadithno{5964}\hadithtrans{This hadith has been narrated through another chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5965}{قَالَ مُسْلِمٌ وَحُدِّثْتُ عَنْ أَبِي أُسَامَةَ، وَمِمَّنْ، رَوَى ذَلِكَ، عَنْهُ إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنِي بُرَيْدُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ إِذَا أَرَادَ رَحْمَةَ أُمَّةٍ مِنْ عِبَادِهِ قَبَضَ نَبِيَّهَا قَبْلَهَا فَجَعَلَهُ لَهَا فَرَطًا وَسَلَفًا بَيْنَ يَدَيْهَا وَإِذَا أَرَادَ هَلَكَةَ أُمَّةٍ عَذَّبَهَا وَنَبِيُّهَا حَىٌّ فَأَهْلَكَهَا وَهُوَ يَنْظُرُ فَأَقَرَّ عَيْنَهُ بِهَلَكَتِهَا حِينَ كَذَّبُوهُ وَعَصَوْا أَمْرَهُ ‏"‏ ‏.‏\hadithno{5965}\hadithtrans{Abu Musa reported Allah's Messenger (ﷺ) as saying:When Allah, the Exalted and Glorious, intends to show mercy to an Umma from amongst His servants He calls back His Apostle to his eternal home and makes him a harbinger and recompense in the world to come; and when He intends to cause destruction to an Umma, He punishes it while its Apostle is alive and He destroys it as he (the Apostle) witnesses it and he cools his eyes by destruction as they had belied him and disobeyed his command}}
\hadithdefcmd{muslim}{5966}{حَدَّثَنِي أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زَائِدَةُ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ، قَالَ سَمِعْتُ جُنْدَبًا، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَنَا فَرَطُكُمْ، عَلَى الْحَوْضِ ‏"‏ ‏.‏\hadithno{5966}\hadithtrans{Jundab reported:I heard Allah's Messenger (ﷺ) as saying: I shall be there at the Cistern before you}}
\hadithdefcmd{muslim}{5967}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ بِشْرٍ، جَمِيعًا عَنْ مِسْعَرٍ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، كِلاَهُمَا عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ جُنْدَبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{5967}\hadithtrans{This hadith has been narrated on the authority of Jundab through another chain of transmitters}}
\hadithdefcmd{muslim}{5969}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنْ أَبِي حَازِمٍ، قَالَ سَمِعْتُ سَهْلاً، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ أَنَا فَرَطُكُمْ، عَلَى الْحَوْضِ مَنْ وَرَدَ شَرِبَ وَمَنْ شَرِبَ لَمْ يَظْمَأْ أَبَدًا وَلَيَرِدَنَّ عَلَىَّ أَقْوَامٌ أَعْرِفُهُمْ وَيَعْرِفُونِي ثُمَّ يُحَالُ بَيْنِي وَبَيْنَهُمْ ‏"‏ ‏.‏ قَالَ أَبُو حَازِمٍ فَسَمِعَ النُّعْمَانُ بْنُ أَبِي عَيَّاشٍ وَأَنَا أُحَدِّثُهُمْ هَذَا الْحَدِيثَ فَقَالَ هَكَذَا سَمِعْتَ سَهْلاً يَقُولُ قَالَ فَقُلْتُ نَعَمْ ‏.‏ قَالَ وَأَنَا أَشْهَدُ، عَلَى أَبِي سَعِيدٍ الْخُدْرِيِّ لَسَمِعْتُهُ يَزِيدُ فَيَقُولُ ‏"‏ إِنَّهُمْ مِنِّي ‏.‏ فَيُقَالُ إِنَّكَ لاَ تَدْرِي مَا عَمِلُوا بَعْدَكَ ‏.‏ فَأَقُولُ سُحْقًا سُحْقًا لِمَنْ بَدَّلَ بَعْدِي ‏"‏ ‏.‏\hadithno{5969}\hadithtrans{Sahl (b. Sa'd) reported:I heard Allah's Apostle (ﷺ) as saying: I shall go to the Cistern before you and he who comes would drink and he who drinks would never feel thirsty, and there would come to me people whom I would know and who would know me. Then there would be intervention between me and them. Abu Hazim said that Nu'man b. Abu 'Ayyash heard it and I narrated to them this hadith, and said: Is it this that you heard Sahl saying? He said: Yes, and I bear witness to the fact that I heard it from Abu Sa'id Khudri also, but he made this addition that he (the Holy Prophet) would say: They are my followers, and it would be said to him: You do not know what they did after you and I will say to them: Woe to him who changes (his religion) after me}}
\hadithdefcmd{muslim}{5970}{وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي أُسَامَةُ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم وَعَنِ النُّعْمَانِ بْنِ أَبِي عَيَّاشٍ، عَنْ أَبِي سَعِيدٍ، الْخُدْرِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ يَعْقُوبَ ‏.‏\hadithno{5970}\hadithtrans{This hadith has been narrated on the authority of Abu Sa'id Khudri through another chain of transmitters}}
\hadithdefcmd{muslim}{5972}{وَحَدَّثَنَا دَاوُدُ بْنُ عَمْرٍو الضَّبِّيُّ، حَدَّثَنَا نَافِعُ بْنُ عُمَرَ الْجُمَحِيُّ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ الْعَاصِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ حَوْضِي مَسِيرَةُ شَهْرٍ وَزَوَايَاهُ سَوَاءٌ وَمَاؤُهُ أَبْيَضُ مِنَ الْوَرِقِ وَرِيحُهُ أَطْيَبُ مِنَ الْمِسْكِ وَكِيزَانُهُ كَنُجُومِ السَّمَاءِ فَمَنْ شَرِبَ مِنْهُ فَلاَ يَظْمَأُ بَعْدَهُ أَبَدًا ‏"‏ ‏.‏ قَالَ وَقَالَتْ أَسْمَاءُ بِنْتُ أَبِي بَكْرٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي عَلَى الْحَوْضِ حَتَّى أَنْظُرَ مَنْ يَرِدُ عَلَىَّ مِنْكُمْ وَسَيُؤْخَذُ أُنَاسٌ دُونِي فَأَقُولُ يَا رَبِّ مِنِّي وَمِنْ أُمَّتِي ‏.‏ فَيُقَالُ أَمَا شَعَرْتَ مَا عَمِلُوا بَعْدَكَ وَاللَّهِ مَا بَرِحُوا بَعْدَكَ يَرْجِعُونَ عَلَى أَعْقَابِهِمْ ‏"‏ ‏.‏ قَالَ فَكَانَ ابْنُ أَبِي مُلَيْكَةَ يَقُولُ اللَّهُمَّ إِنَّا نَعُوذُ بِكَ أَنْ نَرْجِعَ عَلَى أَعْقَابِنَا أَوْ أَنْ نُفْتَنَ عَنْ دِينِنَا\hadithno{5972}\hadithtrans{Abdullah b. `Amr al-`As, reported Allah's Messenger (ﷺ) as saying:My Cistern (is as wide and broad that it requires) a month's journey (to go round it) all, and its sides are equal and its water is whiter than silver, and its odour is more fragrant than the fragrance of musk, and its jugs (placed around it) are like stars in the sky; and he who would drink from it would never feel thirsty after that. Asma', daughter of Abu Bakr said: Allah's Messenger (ﷺ) said: I would be on the Cistern so that I would be seeing those who would be coming to me from you, but some people would be detained (before reaching me). I would say: My Lord, they are my followers and belong to my Ummah, and it would be said to me: Do you know what they did after you? By Allah, they did not do good after you, and they turned back upon their heels. He (the narrator) said: lbn Abu Mulaika used to say (in supplication): O Allah, I seek refuge with Thee that we should turn back upon our heels or put to any trial about our religion}}
\hadithdefcmd{muslim}{5973}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنِ ابْنِ خُثَيْمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ، اللَّهِ بْنِ أَبِي مُلَيْكَةَ أَنَّهُ سَمِعَ عَائِشَةَ، تَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ وَهُوَ بَيْنَ ظَهْرَانَىْ أَصْحَابِهِ ‏ "‏ إِنِّي عَلَى الْحَوْضِ أَنْتَظِرُ مَنْ يَرِدُ عَلَىَّ مِنْكُمْ فَوَاللَّهِ لَيُقْتَطَعَنَّ دُونِي رِجَالٌ فَلأَقُولَنَّ أَىْ رَبِّ مِنِّي وَمِنْ أُمَّتِي ‏.‏ فَيَقُولُ إِنَّكَ لاَ تَدْرِي مَا عَمِلُوا بَعْدَكَ مَا زَالُوا يَرْجِعُونَ عَلَى أَعْقَابِهِمْ ‏"‏ ‏.‏\hadithno{5973}\hadithtrans{A'isha reported:I heard Allah's Messenger (ﷺ) say in the company of his Companions: I would be on the Cistern waiting for those who would be coming to me from amongst you. By Allah, some persons would be prevented from coming to me, and I would say: My Lord, they are my followers and people of my Umma. And He would say,: You don't know what they did after you; they had been constantly turning back on their heels (from their religion)}}
\hadithdefcmd{muslim}{5974}{وَحَدَّثَنِي يُونُسُ بْنُ عَبْدِ الأَعْلَى الصَّدَفِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، - وَهُوَ ابْنُ الْحَارِثِ - أَنَّ بُكَيْرًا، حَدَّثَهُ عَنِ الْقَاسِمِ بْنِ عَبَّاسٍ الْهَاشِمِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ، رَافِعٍ مَوْلَى أُمِّ سَلَمَةَ عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كُنْتُ أَسْمَعُ النَّاسَ يَذْكُرُونَ الْحَوْضَ وَلَمْ أَسْمَعْ ذَلِكَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا كَانَ يَوْمًا مِنْ ذَلِكَ وَالْجَارِيَةُ تَمْشُطُنِي فَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ أَيُّهَا النَّاسُ ‏"‏ ‏.‏ فَقُلْتُ لِلْجَارِيَةِ اسْتَأْخِرِي عَنِّي ‏.‏ قَالَتْ إِنَّمَا دَعَا الرِّجَالَ وَلَمْ يَدْعُ النِّسَاءَ ‏.‏ فَقُلْتُ إِنِّي مِنَ النَّاسِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي لَكُمْ فَرَطٌ عَلَى الْحَوْضِ فَإِيَّاىَ لاَ يَأْتِيَنَّ أَحَدُكُمْ فَيُذَبُّ عَنِّي كَمَا يُذَبُّ الْبَعِيرُ الضَّالُّ فَأَقُولُ فِيمَ هَذَا فَيُقَالُ إِنَّكَ لاَ تَدْرِي مَا أَحْدَثُوا بَعْدَكَ ‏.‏ فَأَقُولُ سُحْقًا ‏"‏ ‏.‏\hadithno{5974}\hadithtrans{Umm Salama, the wife of Allah's Apostle (ﷺ), said I used to hear from people making a mention of the Cistern, but I did not hear about it from Allah's Messenger (ﷺ). One day while a girl was combing me I heard Allah's Messenger (ﷺ) say:" O people." I said to that girl: Keep away from me. She said: He (the Holy Prophet) has addressed the men only and he has not invited the attention of the women. I said: I am amongst the people also (and have thus every right to listen to the things pertaining to religion). Allah's Messenger (ﷺ) said: I shall be your harbinger on the Cistern; therefore, be cautious lest one of you should come (to me) and may be driven away like a stray camel. I would ask the reasons, and it would be said to me: You don't know what innovations they made after you. And I would then also say: Be away}}
\hadithdefcmd{muslim}{5975}{وَحَدَّثَنِي أَبُو مَعْنٍ الرَّقَاشِيُّ، وَأَبُو بَكْرِ بْنُ نَافِعٍ وَعَبْدُ بْنُ حُمَيْدٍ قَالُوا حَدَّثَنَا أَبُو عَامِرٍ - وَهُوَ عَبْدُ الْمَلِكِ بْنُ عَمْرٍو - حَدَّثَنَا أَفْلَحُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَافِعٍ، قَالَ كَانَتْ أُمُّ سَلَمَةَ تُحَدِّثُ أَنَّهَا سَمِعَتِ النَّبِيَّ صلى الله عليه وسلم يَقُولُ عَلَى الْمِنْبَرِ وَهِيَ تَمْتَشِطُ ‏ "‏ أَيُّهَا النَّاسُ ‏"‏ ‏.‏ فَقَالَتْ لِمَاشِطَتِهَا كُفِّي رَأْسِي ‏.‏ بِنَحْوِ حَدِيثِ بُكَيْرٍ عَنِ الْقَاسِمِ بْنِ عَبَّاسٍ ‏.‏\hadithno{5975}\hadithtrans{Umm Salama reported that she heard Allah's Apostle (ﷺ) saying this as he was sitting on the pulpit and she was getting her hair combed. (He uttered these words):" O people." And she said to one who was combing: Leave my head; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{5976}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ يَوْمًا فَصَلَّى عَلَى أَهْلِ أُحُدٍ صَلاَتَهُ عَلَى الْمَيِّتِ ثُمَّ انْصَرَفَ إِلَى الْمِنْبَرِ فَقَالَ ‏ "‏ إِنِّي فَرَطٌ لَكُمْ وَأَنَا شَهِيدٌ عَلَيْكُمْ وَإِنِّي وَاللَّهِ لأَنْظُرُ إِلَى حَوْضِيَ الآنَ وَإِنِّي قَدْ أُعْطِيتُ مَفَاتِيحَ خَزَائِنِ الأَرْضِ أَوْ مَفَاتِيحَ الأَرْضِ وَإِنِّي وَاللَّهِ مَا أَخَافُ عَلَيْكُمْ أَنْ تُشْرِكُوا بَعْدِي وَلَكِنْ أَخَافُ عَلَيْكُمْ أَنْ تَتَنَافَسُوا فِيهَا ‏"‏ ‏.‏\hadithno{5976}\hadithtrans{Uqba b. 'Amir reported that Allah's Messenger (ﷺ) one day went out and he offered prayer over the martyrs of Uhud just as prayer is offered over the dead. He then came back and sat on pulpit and said:I shall be present there (at the Cistern) before you. I shall be your witness and, by Allah, I perceive as if I am seeing with my own eyes my Cistern at this very state and I have been given the keys of the treasures of the earth or the keys of the earth and, by Allah, I am not afraid concerning you that you would associate anything (with Allah after me), but I am afraid that you would be vying with one another (for the possession of) the treasures of the earth}}
\hadithdefcmd{muslim}{5977}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا وَهْبٌ، - يَعْنِي ابْنَ جَرِيرٍ - حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ يَحْيَى بْنَ أَيُّوبَ، يُحَدِّثُ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مَرْثَدٍ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى قَتْلَى أُحُدٍ ثُمَّ صَعِدَ الْمِنْبَرَ كَالْمُوَدِّعِ لِلأَحْيَاءِ وَالأَمْوَاتِ فَقَالَ ‏ "‏ إِنِّي فَرَطُكُمْ عَلَى الْحَوْضِ وَإِنَّ عَرْضَهُ كَمَا بَيْنَ أَيْلَةَ إِلَى الْجُحْفَةِ إِنِّي لَسْتُ أَخْشَى عَلَيْكُمْ أَنْ تُشْرِكُوا بَعْدِي وَلَكِنِّي أَخْشَى عَلَيْكُمُ الدُّنْيَا أَنْ تَنَافَسُوا فِيهَا وَتَقْتَتِلُوا فَتَهْلِكُوا كَمَا هَلَكَ مَنْ كَانَ قَبْلَكُمْ ‏"‏ ‏.‏ قَالَ عُقْبَةُ فَكَانَتْ آخِرَ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ ‏.‏\hadithno{5977}\hadithtrans{Uqba b. 'Amir reported Allah's Messenger (ﷺ) as saying:Allah's Messenger offered prayer over those who had fallen matyrs at Uhud. He then climbed the pulpit as if someone is saying good-bye to the living and the dead, and then said: I shall be there as your predecesor on the Cistern before you, and it is as wide as the distance between Aila and Juhfa (Aila is at the top of the gulf of 'Aqaba). I am not afraid that you would associate anything with Allah after me, but I am afraid that you may be (allured) by the world and (vie) with one another (in possessing material wealth) and begin killing one another, and you would be destroyed as were destroyed those who had gone before you. 'Uqba said that that was the last occasion that he saw Allah's Massenger on the pulpit}}
\hadithdefcmd{muslim}{5978}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَابْنُ نُمَيْرٍ قَالُوا حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا فَرَطُكُمْ عَلَى الْحَوْضِ وَلأُنَازِعَنَّ أَقْوَامًا ثُمَّ لأُغْلَبَنَّ عَلَيْهِمْ فَأَقُولُ يَا رَبِّ أَصْحَابِي أَصْحَابِي ‏.‏ فَيُقَالُ إِنَّكَ لاَ تَدْرِي مَا أَحْدَثُوا بَعْدَكَ ‏"‏ ‏.‏\hadithno{5978}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying; I shall be there at the Cistern before you, and I shall have to contend for some people, but I shall have to yield. I would be saying:My Lord, they are my friends, they are my friends, and it would be said: You don't know what innovations they made after you}}
\hadithdefcmd{muslim}{5979}{وَحَدَّثَنَاهُ عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنْ جَرِيرٍ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ وَلَمْ يَذْكُرْ ‏ "‏ أَصْحَابِي أَصْحَابِي ‏"‏ ‏.‏\hadithno{5979}\hadithtrans{The hadith has been narrated on the authority ot al-A'mash with the same chain of transmitters but no mention is made of:" They are my companions; they are my companions}}
\hadithdefcmd{muslim}{5980}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، كِلاَهُمَا عَنْ جَرِيرٍ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، جَمِيعًا عَنْ مُغِيرَةَ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ، اللَّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِنَحْوِ حَدِيثِ الأَعْمَشِ وَفِي حَدِيثِ شُعْبَةَ عَنْ مُغِيرَةَ، سَمِعْتُ أَبَا وَائِلٍ، ‏.‏\hadithno{5980}\hadithtrans{This hadith has been narrated on the authority of 'Abdullah through another chain of transmitters}}
\hadithdefcmd{muslim}{5981}{وَحَدَّثَنَاهُ سَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، أَخْبَرَنَا عَبْثَرٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي، شَيْبَةَ حَدَّثَنَا ابْنُ فُضَيْلٍ، كِلاَهُمَا عَنْ حُصَيْنٍ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ الأَعْمَشِ وَمُغِيرَةَ ‏.‏\hadithno{5981}\hadithtrans{This hadith has been narrated on the authority of Hudhaifa through another chain of transmitters}}
\hadithdefcmd{muslim}{5982}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ مَعْبَدِ، بْنِ خَالِدٍ عَنْ حَارِثَةَ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ حَوْضُهُ مَا بَيْنَ صَنْعَاءَ وَالْمَدِينَةِ ‏"‏ ‏.‏ فَقَالَ لَهُ الْمُسْتَوْرِدُ أَلَمْ تَسْمَعْهُ قَالَ ‏"‏ الأَوَانِي ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ فَقَالَ الْمُسْتَوْرِدُ ‏"‏ تُرَى فِيهِ الآنِيَةُ مِثْلَ الْكَوَاكِبِ ‏"‏ ‏.‏\hadithno{5982}\hadithtrans{Haritha reported that he heard Allah's Messenger (ﷺ) as saying:His Cistern would be as extensive as the distance between San'a' and Medina. Mustaurid (one of the narrators) said: Did you not hear anything about the utensils? Thereupon he said. No. Mustaurid said: You would find that the utensils would be like stars}}
\hadithdefcmd{muslim}{5983}{وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ عَرْعَرَةَ، حَدَّثَنَا حَرَمِيُّ بْنُ عُمَارَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ مَعْبَدِ بْنِ خَالِدٍ، أَنَّهُ سَمِعَ حَارِثَةَ بْنَ وَهْبٍ الْخُزَاعِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏ وَذَكَرَ الْحَوْضَ بِمِثْلِهِ وَلَمْ يَذْكُرْ قَوْلَ الْمُسْتَوْرِدِ وَقَوْلَهُ ‏.‏\hadithno{5983}\hadithtrans{Haritha b. Wahb al-Khuza'i reported Allah's Messeiiger's (ﷺ) words concerning the Cistern like it, but he made no mention of the words of Mustaurid}}
\hadithdefcmd{muslim}{5984}{حَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ قَالاَ حَدَّثَنَا حَمَّادٌ، - وَهُوَ ابْنُ زَيْدٍ - حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَمَامَكُمْ حَوْضًا مَا بَيْنَ نَاحِيَتَيْهِ كَمَا بَيْنَ جَرْبَا وَأَذْرُحَ ‏"‏ ‏.‏\hadithno{5984}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:There is before you a Cistern and the distance between its two sides is as it is between Jarba' and Adhruh}}
\hadithdefcmd{muslim}{5985}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالُوا حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ أَمَامَكُمْ حَوْضًا كَمَا بَيْنَ جَرْبَا وَأَذْرُحَ ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ الْمُثَنَّى ‏"‏ حَوْضِي ‏"‏ ‏.‏\hadithno{5985}\hadithtrans{This hadith has been transmitted on the authority of Ibn 'Umar and the words are:That he said there would be before you a Cistern extending from jarba' and Adhruh and the same has been transmitted on the authority of Ibn Muthanna and the wording is:" My Cistern}}
\hadithdefcmd{muslim}{5986}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ، بِشْرٍ قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ وَزَادَ قَالَ عُبَيْدُ اللَّهِ فَسَأَلْتُهُ فَقَالَ قَرْيَتَيْنِ بِالشَّامِ بَيْنَهُمَا مَسِيرَةُ ثَلاَثِ لَيَالٍ ‏.‏ وَفِي حَدِيثِ ابْنِ بِشْرٍ ‏.‏ ثَلاَثَةِ أَيَّامٍ ‏.‏\hadithno{5986}\hadithtrans{A hadith like this has been transmitted on the authority, of 'Ubaidullah with this addition:Ubaidullah was asked (about these two names, i. e. Jarba' and Adhruh). He said: These are the two towns of Syria and there is between them the distance which can be covered in three nights, and the hadith transmitted on the authority of Ibn Bishr (the words are)." Three days}}
\hadithdefcmd{muslim}{5987}{وَحَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ مَيْسَرَةَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ عُبَيْدِ اللَّهِ ‏.‏\hadithno{5987}\hadithtrans{A hadith like this has been narrated on the authority of Ibn Umar through another chain of transmitters}}
\hadithdefcmd{muslim}{5988}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي عُمَرُ بْنُ مُحَمَّدٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَمَامَكُمْ حَوْضًا كَمَا بَيْنَ جَرْبَا وَأَذْرُحَ فِيهِ أَبَارِيقُ كَنُجُومِ السَّمَاءِ مَنْ وَرَدَهُ فَشَرِبَ مِنْهُ لَمْ يَظْمَأْ بَعْدَهَا أَبَدًا ‏"‏ ‏.‏\hadithno{5988}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying:There would be before you a Cistern (as extensive) as there is the distance between Jarba' and Adhruh and there would be jugs like stars in the sky; he who would come to that and drink from it would never feel thirsty after that}}
\hadithdefcmd{muslim}{5989}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ الْمَكِّيُّ، - وَاللَّفْظُ لاِبْنِ أَبِي شَيْبَةَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ، الصَّمَدِ الْعَمِّيُّ عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَا آنِيَةُ الْحَوْضِ قَالَ ‏ "‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لآنِيَتُهُ أَكْثَرُ مِنْ عَدَدِ نُجُومِ السَّمَاءِ وَكَوَاكِبِهَا أَلاَ فِي اللَّيْلَةِ الْمُظْلِمَةِ الْمُصْحِيَةِ آنِيَةُ الْجَنَّةِ مَنْ شَرِبَ مِنْهَا لَمْ يَظْمَأْ آخِرَ مَا عَلَيْهِ يَشْخُبُ فِيهِ مِيزَابَانِ مِنَ الْجَنَّةِ مَنْ شَرِبَ مِنْهُ لَمْ يَظْمَأْ عَرْضُهُ مِثْلُ طُولِهِ مَا بَيْنَ عَمَّانَ إِلَى أَيْلَةَ مَاؤُهُ أَشَدُّ بَيَاضًا مِنَ اللَّبَنِ وَأَحْلَى مِنَ الْعَسَلِ ‏"‏ ‏.‏\hadithno{5989}\hadithtrans{Abu Dharr said:Allah's Messenger, what about the vessels of that Cistern? He said: By Him in Whose Hand is the life of Muhammad, the vessels would outnumber the stars in the sky and its planets shining on a dark cloudless night. These would be the vessels of Paradise. He who drinks out of it (the Cistern) would never feel thirsty. There would flow in it two spouts from Paradise and he who would drink out of it would not feel thirsty; and the distance between its (two corners) is that between 'Amman and Aila, and its water is whiter than milk and sweeter than honey}}
\hadithdefcmd{muslim}{5992}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمَّادٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ سَالِمِ، بْنِ أَبِي الْجَعْدِ عَنْ مَعْدَانَ، عَنْ ثَوْبَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم حَدِيثَ الْحَوْضِ فَقُلْتُ لِيَحْيَى بْنِ حَمَّادٍ هَذَا حَدِيثٌ سَمِعْتَهُ مِنْ أَبِي عَوَانَةَ فَقَالَ وَسَمِعْتُهُ أَيْضًا مِنْ شُعْبَةَ فَقُلْتُ انْظُرْ لِي فِيهِ فَنَظَرَ لِي فِيهِ فَحَدَّثَنِي بِهِ ‏.‏\hadithno{5992}\hadithtrans{Thaubin reported this hadith pertaining to the Cistern. Muhammad b. Bashshar said:I said to Yahya b. Hammad: This is the hadith that I heard from Abu 'Awana and he said: I also heard it from Shu'ba. I said: Narrate that to me and he narrated that to me}}
\hadithdefcmd{muslim}{5993}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَلاَّمٍ الْجُمَحِيُّ، حَدَّثَنَا الرَّبِيعُ، - يَعْنِي ابْنَ مُسْلِمٍ - عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لأَذُودَنَّ عَنْ حَوْضِي رِجَالاً كَمَا تُذَادُ الْغَرِيبَةُ مِنَ الإِبِلِ ‏"‏ ‏.‏\hadithno{5993}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:I will drive away from my Cistern people just as the stray camels are driven away}}
\hadithdefcmd{muslim}{5994}{وَحَدَّثَنِيهِ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{5994}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain ot transmitters}}
\hadithdefcmd{muslim}{6004}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، وَأَبُو أُسَامَةَ عَنْ مِسْعَرٍ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِيهِ، عَنْ سَعْدٍ، قَالَ رَأَيْتُ عَنْ يَمِينِ، رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَنْ شِمَالِهِ يَوْمَ أُحُدٍ رَجُلَيْنِ عَلَيْهِمَا ثِيَابُ بَيَاضٍ مَا رَأَيْتُهُمَا قَبْلُ وَلاَ بَعْدُ ‏.‏ يَعْنِي جِبْرِيلَ وَمِيكَائِيلَ عَلَيْهِمَا السَّلاَمُ ‏.‏\hadithno{6004}\hadithtrans{Sa`d reported that on the Day of Uhud I saw on the right side of Allah's Messenger (ﷺ) and on his left side two persons dressed in white clothes and whom I did not see before nor after that, and they were Gabriel and Michael (Allah be pleased with both of them)}}
\hadithdefcmd{muslim}{6005}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا إِبْرَاهِيمُ، بْنُ سَعْدٍ حَدَّثَنَا سَعْدٌ، عَنْ أَبِيهِ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ لَقَدْ رَأَيْتُ يَوْمَ أُحُدٍ عَنْ يَمِينِ، رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَنْ يَسَارِهِ رَجُلَيْنِ عَلَيْهِمَا ثِيَابٌ بِيضٌ يُقَاتِلاَنِ عَنْهُ كَأَشَدِّ الْقِتَالِ مَا رَأَيْتُهُمَا قَبْلُ وَلاَ بَعْدُ ‏.‏\hadithno{6005}\hadithtrans{Sa'd b. Abu Waqqas reported:I saw on the right side of Allah's Messenger (ﷺ) and on his left side two persons with white clothes on the Day of Uhtid fighting a desperate fight, and I saw them neither before nor after that}}
\hadithdefcmd{muslim}{6006}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَسَعِيدُ بْنُ مَنْصُورٍ، وَأَبُو الرَّبِيعِ الْعَتَكِيُّ، وَأَبُو كَامِلٍ - وَاللَّفْظُ لِيَحْيَى - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا - حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَحْسَنَ النَّاسِ وَكَانَ أَجْوَدَ النَّاسِ وَكَانَ أَشْجَعَ النَّاسِ وَلَقَدْ فَزِعَ أَهْلُ الْمَدِينَةِ ذَاتَ لَيْلَةٍ فَانْطَلَقَ نَاسٌ قِبَلَ الصَّوْتِ فَتَلَقَّاهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم رَاجِعًا وَقَدْ سَبَقَهُمْ إِلَى الصَّوْتِ وَهُوَ عَلَى فَرَسٍ لأَبِي طَلْحَةَ عُرْىٍ فِي عُنُقِهِ السَّيْفُ وَهُوَ يَقُولُ ‏"‏ لَمْ تُرَاعُوا لَمْ تُرَاعُوا ‏"‏ ‏.‏ قَالَ ‏"‏ وَجَدْنَاهُ بَحْرًا أَوْ إِنَّهُ لَبَحْرٌ ‏"‏ ‏.‏ قَالَ وَكَانَ فَرَسًا يُبَطَّأُ ‏.‏\hadithno{6006}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) was the sublimest among people (in character) and the most generous amongst them and he was the bravest of men. One night the people of Medina felt disturbed and set forth in the direction of a sound when Allah's Messenger (ﷺ) met them on his way back as he had gone towards that sound ahead of them. He was on the horse of Abu Talha which had no saddle over it, and a sword was slung round his neck, and he was saying:There was nothing to be afraid of, and he also said: We found it (this horse) like a torrent of water (indicating its swift-footedness), whereas the horse had been slow before that time}}
\hadithdefcmd{muslim}{6007}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَانَ بِالْمَدِينَةِ فَزَعٌ فَاسْتَعَارَ النَّبِيُّ صلى الله عليه وسلم فَرَسًا لأَبِي طَلْحَةَ يُقَالُ لَهُ مَنْدُوبٌ فَرَكِبَهُ فَقَالَ ‏ "‏ مَا رَأَيْنَا مِنْ فَزَعٍ وَإِنْ وَجَدْنَاهُ لَبَحْرًا ‏"‏ ‏.‏\hadithno{6007}\hadithtrans{Anas reported that there was consternation in Medina. The Messenger of Allah (ﷺ) borrowed the horse from Abu Talha which was called Mandub. He rode it and said:We have found no reason for consternation, and we have found it to be (as quick as a torrent) of water}}
\hadithdefcmd{muslim}{6008}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - قَالاَ حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِ ابْنِ جَعْفَرٍ قَالَ فَرَسًا لَنَا ‏.‏ وَلَمْ يَقُلْ لأَبِي طَلْحَةَ ‏.‏ وَفِي حَدِيثِ خَالِدٍ عَنْ قَتَادَةَ سَمِعْتُ أَنَسًا ‏.‏\hadithno{6008}\hadithtrans{This hadith has been transmitted on the authority of Anas with a slight variation of wording}}
\hadithdefcmd{muslim}{6009}{حَدَّثَنَا مَنْصُورُ بْنُ أَبِي مُزَاحِمٍ، حَدَّثَنَا إِبْرَاهِيمُ، - يَعْنِي ابْنَ سَعْدٍ - عَنِ الزُّهْرِيِّ، ح وَحَدَّثَنِي أَبُو عِمْرَانَ، مُحَمَّدُ بْنُ جَعْفَرِ بْنِ زِيَادٍ - وَاللَّفْظُ لَهُ - أَخْبَرَنَا إِبْرَاهِيمُ، عَنِ ابْنِ، شِهَابٍ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَجْوَدَ النَّاسِ بِالْخَيْرِ وَكَانَ أَجْوَدَ مَا يَكُونُ فِي شَهْرِ رَمَضَانَ إِنَّ جِبْرِيلَ عَلَيْهِ السَّلاَمُ كَانَ يَلْقَاهُ فِي كُلِّ سَنَةٍ فِي رَمَضَانَ حَتَّى يَنْسَلِخَ فَيَعْرِضُ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم الْقُرْآنَ فَإِذَا لَقِيَهُ جِبْرِيلُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَجْوَدَ بِالْخَيْرِ مِنَ الرِّيحِ الْمُرْسَلَةِ ‏.‏\hadithno{6009}\hadithtrans{Ibn 'Abbas reported that Allah's Messenger (ﷺ) was the most generous of people in charity, but he was generous to the utmost in the month of Ramadan. Gabriel (peace be upon him) would meet him every year during the month of Ramadin until it ended, and Allah's Messenger (ﷺ) recited to him the Qur'an; and when Gabriel met him Allah's Messenger (ﷺ) was most generous in giving charity like the blowing wind}}
\hadithdefcmd{muslim}{6010}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ مُبَارَكٍ، عَنْ يُونُسَ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{6010}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{6011}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَأَبُو الرَّبِيعِ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ خَدَمْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَشْرَ سِنِينَ وَاللَّهِ مَا قَالَ لِي أُفًّا ‏.‏ قَطُّ وَلاَ قَالَ لِي لِشَىْءٍ لِمَ فَعَلْتَ كَذَا وَهَلاَّ فَعَلْتَ كَذَا زَادَ أَبُو الرَّبِيعِ لَيْسَ مِمَّا يَصْنَعُهُ الْخَادِمُ ‏.‏ وَلَمْ يَذْكُرْ قَوْلَهُ وَاللَّهِ ‏.‏\hadithno{6011}\hadithtrans{Anas b. Malik reported:I served the Messenger of Allah (ﷺ) for ten years, and, by Allah, he never said to me any harsh word, and he never said to me about a thing as to why I had done that and as to why I had not done that. Abu Rabi' has made this addition (in this narration):" The work which a servant should do." There is no mention of his words" By Allah}}
\hadithdefcmd{muslim}{6012}{وَحَدَّثَنَاهُ شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا سَلاَّمُ بْنُ مِسْكِينٍ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ أَنَسٍ، بِمِثْلِهِ ‏.‏\hadithno{6012}\hadithtrans{This hadith has been narrated on the authority of Anas through another chain of transmitters}}
\hadithdefcmd{muslim}{6013}{وَحَدَّثَنَاهُ أَحْمَدُ بْنُ حَنْبَلٍ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنْ إِسْمَاعِيلَ، - وَاللَّفْظُ لأَحْمَدَ - قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ لَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ أَخَذَ أَبُو طَلْحَةَ بِيَدِي فَانْطَلَقَ بِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أَنَسًا غُلاَمٌ كَيِّسٌ فَلْيَخْدُمْكَ ‏.‏ قَالَ فَخَدَمْتُهُ فِي السَّفَرِ وَالْحَضَرِ وَاللَّهِ مَا قَالَ لِي لِشَىْءٍ صَنَعْتُهُ لِمَ صَنَعْتَ هَذَا هَكَذَا وَلاَ لِشَىْءٍ لَمْ أَصْنَعْهُ لِمَ لَمْ تَصْنَعْ هَذَا هَكَذَا\hadithno{6013}\hadithtrans{Anas reported:When Allah's Messenger (ﷺ) came to Medina, Abla Talha took hold of my hand and brought me to Allah's Messenger (ﷺ) and said: Allah's Messenger, Anas is a prudent young boy, and he will serve you. He (Anas) said: I served him in journey and at home, but, by Allah, he never asked me about a thing which I did as to why I did so, nor about a thing which I did not do as to why I had not done that}}
\hadithdefcmd{muslim}{6014}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا زَكَرِيَّاءُ، حَدَّثَنِي سَعِيدٌ، - وَهُوَ ابْنُ أَبِي بُرْدَةَ - عَنْ أَنَسٍ، قَالَ خَدَمْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم تِسْعَ سِنِينَ فَمَا أَعْلَمُهُ قَالَ لِي قَطُّ لِمَ فَعَلْتَ كَذَا وَكَذَا وَلاَ عَابَ عَلَىَّ شَيْئًا قَطُّ ‏.‏\hadithno{6014}\hadithtrans{Anas reported Allah's Messenger (ﷺ) as saying:I served the Messenger of Allah (ﷺ) for nine years, and I do not know (of any instance) when he said to me: Why you have done this and that, and he never found fault with me in anything}}
\hadithdefcmd{muslim}{6016}{حَدَّثَنِي أَبُو مَعْنٍ الرَّقَاشِيُّ، زَيْدُ بْنُ يَزِيدَ أَخْبَرَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ، - وَهُوَ ابْنُ عَمَّارٍ - قَالَ قَالَ إِسْحَاقُ قَالَ أَنَسٌ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ أَحْسَنِ النَّاسِ خُلُقًا فَأَرْسَلَنِي يَوْمًا لِحَاجَةٍ فَقُلْتُ وَاللَّهِ لاَ أَذْهَبُ ‏.‏ وَفِي نَفْسِي أَنْ أَذْهَبَ لِمَا أَمَرَنِي بِهِ نَبِيُّ اللَّهِ صلى الله عليه وسلم فَخَرَجْتُ حَتَّى أَمُرَّ عَلَى صِبْيَانٍ وَهُمْ يَلْعَبُونَ فِي السُّوقِ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَدْ قَبَضَ بِقَفَاىَ مِنْ وَرَائِي - قَالَ - فَنَظَرْتُ إِلَيْهِ وَهُوَ يَضْحَكُ فَقَالَ ‏ "‏ يَا أُنَيْسُ أَذَهَبْتَ حَيْثُ أَمَرْتُكَ ‏"‏ ‏.‏ قَالَ قُلْتُ نَعَمْ أَنَا أَذْهَبُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ أَنَسٌ وَاللَّهِ لَقَدْ خَدَمْتُهُ تِسْعَ سِنِينَ مَا عَلِمْتُهُ قَالَ لِشَىْءٍ صَنَعْتُهُ لِمَ فَعَلْتَ كَذَا وَكَذَا أَوْ لِشَىْءٍ تَرَكْتُهُ هَلاَّ فَعَلْتَ كَذَا وَكَذَا ‏.‏\hadithno{6016}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) had the best disposition amongst people. He sent me on an errand one day, and I said:By Allah, I would not go. I had, however, this idea in my mind that I would do as Allah's Apostle (ﷺ) had commanded me to do. I went out until I happened to come across children who had been playing in the street. In the meanwhile, Allah's Messenger (ﷺ) came there and he caught me by the back of my neck from behind me. As I looked towards him I found him smiling and he said: Unais, did you go where I commanded you to go? I said: Allah's Messenger, yes, I am going. Anas further said: I served him for nine years but I know not that he ever said to me about a thing which I had done why I did that, or about a thing I had left as to why I had not done that}}
\hadithdefcmd{muslim}{6017}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، وَأَبُو الرَّبِيعِ، قَالاَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَحْسَنَ النَّاسِ خُلُقًا ‏.‏\hadithno{6017}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) was the best amongst people in disposition and behaviour}}
\hadithdefcmd{muslim}{6018}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ الْمُنْكَدِرِ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ مَا سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَيْئًا قَطُّ فَقَالَ لاَ ‏.‏\hadithno{6018}\hadithtrans{Jabir b. 'Abdullah reported:It never happened that Allah's Messenger (ﷺ) was asked for anything and he said: No}}
\hadithdefcmd{muslim}{6019}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا الأَشْجَعِيُّ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - كِلاَهُمَا عَنْ سُفْيَانَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ، اللَّهِ يَقُولُ مِثْلَهُ سَوَاءً ‏.‏\hadithno{6019}\hadithtrans{This hadith has been narrated on the authority of Jabir b. 'Abdullah through another chain of transmitters}}
\hadithdefcmd{muslim}{6020}{وَحَدَّثَنَا عَاصِمُ بْنُ النَّضْرِ التَّيْمِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا حُمَيْدٌ، عَنْ مُوسَى بْنِ أَنَسٍ، عَنْ أَبِيهِ، قَالَ مَا سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الإِسْلاَمِ شَيْئًا إِلاَّ أَعْطَاهُ - قَالَ - فَجَاءَهُ رَجُلٌ فَأَعْطَاهُ غَنَمًا بَيْنَ جَبَلَيْنِ فَرَجَعَ إِلَى قَوْمِهِ فَقَالَ يَا قَوْمِ أَسْلِمُوا فَإِنَّ مُحَمَّدًا يُعْطِي عَطَاءً لاَ يَخْشَى الْفَاقَةَ ‏.‏\hadithno{6020}\hadithtrans{Musa b. Anas reported on the authority of his father:It never happened that Allah's Messenger (ﷺ) was asked anything for the sake of Islam and he did not give that. There came to him a person and he gave him a large flock (of sheep and goats) and he went back to his people and said: My people, embrace Islam, for Muhammad gives so much charity as if he has no fear of want}}
\hadithdefcmd{muslim}{6021}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَجُلاً، سَأَلَ النَّبِيَّ صلى الله عليه وسلم غَنَمًا بَيْنَ جَبَلَيْنِ فَأَعْطَاهُ إِيَّاهُ فَأَتَى قَوْمَهُ فَقَالَ أَىْ قَوْمِ أَسْلِمُوا فَوَاللَّهِ إِنَّ مُحَمَّدًا لَيُعْطِي عَطَاءً مَا يَخَافُ الْفَقْرَ ‏.‏ فَقَالَ أَنَسٌ إِنْ كَانَ الرَّجُلُ لَيُسْلِمُ مَا يُرِيدُ إِلاَّ الدُّنْيَا فَمَا يُسْلِمُ حَتَّى يَكُونَ الإِسْلاَمُ أَحَبَّ إِلَيْهِ مِنَ الدُّنْيَا وَمَا عَلَيْهَا ‏.‏\hadithno{6021}\hadithtrans{Anas 'b. Malik reported that a person requested Allah's Apostle (ﷺ) to give him a very large flock and he gave that to him. He came to his tribe and said:O people, embrace Islam. By Allah, Muhammad donates so much as if he did not fear want. Anas said that the person embraced Islam for the sake of the world but later he became Muslim until Islam became dearer to him than the world and what it contains}}
\hadithdefcmd{muslim}{6022}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ غَزَا رَسُولُ اللَّهِ صلى الله عليه وسلم غَزْوَةَ الْفَتْحِ فَتْحِ مَكَّةَ ثُمَّ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَنْ مَعَهُ مِنَ الْمُسْلِمِينَ فَاقْتَتَلُوا بِحُنَيْنٍ فَنَصَرَ اللَّهُ دِينَهُ وَالْمُسْلِمِينَ وَأَعْطَى رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَئِذٍ صَفْوَانَ بْنَ أُمَيَّةَ مِائَةً مِنَ النَّعَمِ ثُمَّ مِائَةً ثُمَّ مِائَةً ‏.‏ قَالَ ابْنُ شِهَابٍ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ أَنَّ صَفْوَانَ قَالَ وَاللَّهِ لَقَدْ أَعْطَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم مَا أَعْطَانِي وَإِنَّهُ لأَبْغَضُ النَّاسِ إِلَىَّ فَمَا بَرِحَ يُعْطِينِي حَتَّى إِنَّهُ لأَحَبُّ النَّاسِ إِلَىَّ ‏.‏\hadithno{6022}\hadithtrans{Ibn Shihab reported that Allah's Messenger (ﷺ) went on the expedition of Victory, i. e. the Victory of Mecca, and then he went out along with the Muslims and they fought at Hunain, and Allah granted victory to his religion and to the Muslims, and Allah's Messenger (ﷺ) gave one hundred camels to Safwan b. Umayya. He again gave him one hundred camels, and then again gave him one hundred camels. Sa'id b. Musayyib said that Safwan told him:(By Allah) Allah's Messenger (ﷺ) gave me what he gave me (and my state of mind at that time was) that he was the most detested person amongst people in my eyes. But he continued giving to me until now he is the dearest of people to me}}
\hadithdefcmd{muslim}{6023}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ الْمُنْكَدِرِ، أَنَّهُ سَمِعَ جَابِرَ، بْنَ عَبْدِ اللَّهِ ح وَحَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا سُفْيَانُ، عَنِ ابْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، وَعَنْ عَمْرٍو، عَنْ مُحَمَّدِ، بْنِ عَلِيٍّ عَنْ جَابِرٍ، أَحَدُهُمَا يَزِيدُ عَلَى الآخَرِ ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لَهُ - قَالَ قَالَ سُفْيَانُ سَمِعْتُ مُحَمَّدَ بْنَ الْمُنْكَدِرِ، يَقُولُ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، قَالَ سُفْيَانُ وَسَمِعْتُ أَيْضًا، عَمْرَو بْنَ دِينَارٍ يُحَدِّثُ عَنْ مُحَمَّدِ بْنِ عَلِيٍّ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، وَزَادَ، أَحَدُهُمَا عَلَى الآخَرِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ قَدْ جَاءَنَا مَالُ الْبَحْرَيْنِ لَقَدْ أَعْطَيْتُكَ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ وَقَالَ بِيَدَيْهِ جَمِيعًا فَقُبِضَ النَّبِيُّ صلى الله عليه وسلم قَبْلَ أَنْ يَجِيءَ مَالُ الْبَحْرَيْنِ فَقَدِمَ عَلَى أَبِي بَكْرٍ بَعْدَهُ فَأَمَرَ مُنَادِيًا فَنَادَى مَنْ كَانَتْ لَهُ عَلَى النَّبِيِّ صلى الله عليه وسلم عِدَةٌ أَوْ دَيْنٌ فَلْيَأْتِ ‏.‏ فَقُمْتُ فَقُلْتُ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لَوْ قَدْ جَاءَنَا مَالُ الْبَحْرَيْنِ أَعْطَيْتُكَ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ فَحَثَى أَبُو بَكْرٍ مَرَّةً ثُمَّ قَالَ لِي عُدَّهَا ‏.‏ فَعَدَدْتُهَا فَإِذَا هِيَ خَمْسُمِائَةٍ فَقَالَ خُذْ مِثْلَيْهَا ‏.‏\hadithno{6023}\hadithtrans{Jabir b. 'Abdullah reported Allah's Messenger (ﷺ) as saying:In case we get wealth from Bahrain, I would give you so much and so much; he made an indication of it with both his hands. Allah's Apostle (ﷺ) died before wealth from Bahrain came, and it fell to the lot of Abu Bakr after him. He commanded the announcer to make announcement to the effect that he to whom Allah's Apostle (ﷺ) had held out promise or owed any debt should come (to him). I came and said: Allah's Apostle (ﷺ) had said to me: In case there comes to us the wealth of Bahrain I shall give you so much, and so much. Abu Bakr took a handful (of the coins) and gave that to me once and asked me to count them I counted them as five hundred dinars and he said: Here is double of this for you}}
\hadithdefcmd{muslim}{6024}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، عَنْ مُحَمَّدِ بْنِ عَلِيٍّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ وَأَخْبَرَنِي مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ لَمَّا مَاتَ النَّبِيُّ صلى الله عليه وسلم جَاءَ أَبَا بَكْرٍ مَالٌ مِنْ قِبَلِ الْعَلاَءِ بْنِ الْحَضْرَمِيِّ فَقَالَ أَبُو بَكْرٍ مَنْ كَانَ لَهُ عَلَى النَّبِيِّ صلى الله عليه وسلم دَيْنٌ أَوْ كَانَتْ لَهُ قِبَلَهُ عِدَةٌ فَلْيَأْتِنَا ‏.‏ بِنَحْوِ حَدِيثِ ابْنِ عُيَيْنَةَ ‏.‏\hadithno{6024}\hadithtrans{Jabir b. 'Abdullah reported:When Allah's Apostle (ﷺ) died, there came to Abfi Bakr wealth from al-'Ala' b. al-Hadrami. Abu Bakr said: He to whom Allah's Apostle (ﷺ) owed any debt or held out any promise should come to us; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{6025}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، وَشَيْبَانُ بْنُ فَرُّوخَ، كِلاَهُمَا عَنْ سُلَيْمَانَ، - وَاللَّفْظُ لِشَيْبَانَ - حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وُلِدَ لِيَ اللَّيْلَةَ غُلاَمٌ فَسَمَّيْتُهُ بِاسْمِ أَبِي إِبْرَاهِيمَ ‏"‏ ‏.‏ ثُمَّ دَفَعَهُ إِلَى أُمِّ سَيْفٍ امْرَأَةِ قَيْنٍ يُقَالُ لَهُ أَبُو سَيْفٍ فَانْطَلَقَ يَأْتِيهِ وَاتَّبَعْتُهُ فَانْتَهَيْنَا إِلَى أَبِي سَيْفٍ وَهُوَ يَنْفُخُ بِكِيرِهِ قَدِ امْتَلأَ الْبَيْتُ دُخَانًا فَأَسْرَعْتُ الْمَشْىَ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا أَبَا سَيْفٍ أَمْسِكْ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَأَمْسَكَ فَدَعَا النَّبِيُّ صلى الله عليه وسلم بِالصَّبِيِّ فَضَمَّهُ إِلَيْهِ وَقَالَ مَا شَاءَ اللَّهُ أَنْ يَقُولَ ‏.‏ فَقَالَ أَنَسٌ لَقَدْ رَأَيْتُهُ وَهُوَ يَكِيدُ بِنَفْسِهِ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَدَمَعَتْ عَيْنَا رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ تَدْمَعُ الْعَيْنُ وَيَحْزَنُ الْقَلْبُ وَلاَ نَقُولُ إِلاَّ مَا يَرْضَى رَبُّنَا وَاللَّهِ يَا إِبْرَاهِيمُ إِنَّا بِكَ لَمَحْزُونُونَ ‏"‏ ‏.‏\hadithno{6025}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said:A child was born into me this night and I named him after the name of my father Ibrihim. He then sent him to Umm Saif, the wife of a blacksmith who was called Abu Saif. He (the Holy Prophet) went to him and I followed him until we reached Abu Saif and he was blowing fire with the help of blacksmith's bellows and the house was filled with smoke. I hastened my step and went ahead of Allah's Messenger (ﷺ) and said: Abu Saif, stop it, as there comes Allah's Messenger (may peace he upon him). He stopped and Allah's Apostle (ﷺ) called for the child. He embraced him and said what Allah had desired. Anas said: I saw that the boy breathed his last in the presence of Allah's Messenger (ﷺ). The eyes of Allah's Messenger (ﷺ) shed tears and he said: Ibrahim, our eyes shed tears and our hearts are filled with grief, but we do not say anything except that by which Allah is pleased. O Ibrahim, we are grieved for you}}
\hadithdefcmd{muslim}{6026}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ عُلَيَّةَ - عَنْ أَيُّوبَ، عَنْ عَمْرِو بْنِ سَعِيدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مَا رَأَيْتُ أَحَدًا كَانَ أَرْحَمَ بِالْعِيَالِ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ - كَانَ إِبْرَاهِيمُ مُسْتَرْضِعًا لَهُ فِي عَوَالِي الْمَدِينَةِ فَكَانَ يَنْطَلِقُ وَنَحْنُ مَعَهُ فَيَدْخُلُ الْبَيْتَ وَإِنَّهُ لَيُدَّخَنُ وَكَانَ ظِئْرُهُ قَيْنًا فَيَأْخُذُهُ فَيُقَبِّلُهُ ثُمَّ يَرْجِعُ ‏.‏ قَالَ عَمْرٌو فَلَمَّا تُوُفِّيَ إِبْرَاهِيمُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ إِبْرَاهِيمَ ابْنِي وَإِنَّهُ مَاتَ فِي الثَّدْىِ وَإِنَّ لَهُ لَظِئْرَيْنِ تُكَمِّلاَنِ رَضَاعَهُ فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{6026}\hadithtrans{Anas b. Malik reported:I have never seen anyone more kind to one's family than Allah's Messenger (ﷺ), and Ibrahim was sent to the suburb of Medina for suckling. He used to go there and we accompanied him. He entered the house, and it was filled with smoke as his foster-father was a bricksmith. He took him (his son Ibrihim) and kissed him and then came back. 'Amr said that when Ibrihim died. Allah's LMessenger (ﷺ) said: Ibrihim is my son and he dies as a suckling babe. He has now two foster-mothers who would complete his suckling period in Paradise}}
\hadithdefcmd{muslim}{6027}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، وَابْنُ، نُمَيْرٍ عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَدِمَ نَاسٌ مِنَ الأَعْرَابِ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا أَتُقَبِّلُونَ صِبْيَانَكُمْ فَقَالُوا نَعَمْ ‏.‏ فَقَالُوا لَكِنَّا وَاللَّهِ مَا نُقَبِّلُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَأَمْلِكُ إِنْ كَانَ اللَّهُ نَزَعَ مِنْكُمُ الرَّحْمَةَ ‏"‏ ‏.‏ وَقَالَ ابْنُ نُمَيْرٍ ‏"‏ مِنْ قَلْبِكَ الرَّحْمَةَ ‏"‏ ‏.‏\hadithno{6027}\hadithtrans{A'isha (Allah be pleased with her) reported that there came a few desert Arabs to Allah's Messenger (ﷺ) and said:Do you kiss your children? He said: Yes. Thereupon they said: By Allah but we do not kiss our children. Thereupon Allah's Messenger (ﷺ) said: Then what can I do if Allah has deprived you of mercy? Ibn Numair said: (We has deprived) your heart of mercy}}
\hadithdefcmd{muslim}{6028}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنْ سُفْيَانَ، قَالَ عَمْرٌو حَدَّثَنَا سُفْيَانُ، بْنُ عُيَيْنَةَ عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ الأَقْرَعَ بْنَ حَابِسٍ، أَبْصَرَ النَّبِيَّ صلى الله عليه وسلم يُقَبِّلُ الْحَسَنَ فَقَالَ إِنَّ لِي عَشَرَةً مِنَ الْوَلَدِ مَا قَبَّلْتُ وَاحِدًا مِنْهُمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّهُ مَنْ لاَ يَرْحَمْ لاَ يُرْحَمْ ‏"‏ ‏.‏\hadithno{6028}\hadithtrans{Abu Huraira reported that al-Aqra' b. Habis saw Allah's Apostle (ﷺ) kissing Hasan. He said:I have ten children, but I have never kissed any one of them, whereupon Allah's Messenger (ﷺ) said: He who does not show mercy (towards his children), no mercy would be shown to him}}
\hadithdefcmd{muslim}{6029}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي أَبُو سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{6029}\hadithtrans{The above hadith has likewise been narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{6030}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، كِلاَهُمَا عَنْ جَرِيرٍ، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ وَعَلِيُّ بْنُ خَشْرَمٍ قَالاَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا حَفْصٌ، - يَعْنِي ابْنَ غِيَاثٍ - كُلُّهُمْ عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، وَأَبِي، ظِبْيَانَ عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لاَ يَرْحَمِ النَّاسَ لاَ يَرْحَمْهُ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{6030}\hadithtrans{This hadith has been narrated on the authority of Jarir b. 'Abdullah through different chains of transmitters and the words are:" That the Messenger of Allah (ﷺ) said: He who shows no mercy to the people, Allah, the Exalted and Glorious, does not show mercy to him}}
\hadithdefcmd{muslim}{6031}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ جَرِيرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ أَبِي عُمَرَ، وَأَحْمَدُ بْنُ عَبْدَةَ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنْ جَرِيرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ الأَعْمَشِ ‏.‏\hadithno{6031}\hadithtrans{This hadith has been narrated on the authority of Jarir through other chains of transmitters}}
\hadithdefcmd{muslim}{6032}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، سَمِعَ عَبْدَ اللَّهِ، بْنَ أَبِي عُتْبَةَ يُحَدِّثُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَأَحْمَدُ بْنُ سِنَانٍ، قَالَ زُهَيْرٌ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي عُتْبَةَ، يَقُولُ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَشَدَّ حَيَاءً مِنَ الْعَذْرَاءِ فِي خِدْرِهَا وَكَانَ إِذَا كَرِهَ شَيْئًا عَرَفْنَاهُ فِي وَجْهِهِ ‏.‏\hadithno{6032}\hadithtrans{Abu Sa'id Khudri reported that Allah's Messenger (ﷺ) was more modest than the virgin behind the curtain (or in the apartment), and when he disliked anything, we recognised that from his face}}
\hadithdefcmd{muslim}{6033}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالاَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، قَالَ دَخَلْنَا عَلَى عَبْدِ اللَّهِ بْنِ عَمْرٍو حِينَ قَدِمَ مُعَاوِيَةُ إِلَى الْكُوفَةِ فَذَكَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ لَمْ يَكُنْ فَاحِشًا وَلاَ مُتَفَحِّشًا ‏.‏ وَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنْ خِيَارِكُمْ أَحَاسِنَكُمْ أَخْلاَقًا ‏"‏ ‏.‏ قَالَ عُثْمَانُ حِينَ قَدِمَ مَعَ مُعَاوِيَةَ إِلَى الْكُوفَةِ ‏.‏\hadithno{6033}\hadithtrans{Masruq reported:We went to Abdullah b. 'Amr when Mu'dwiya came to Kufa, and he made a mention of Allah's Messenger (ﷺ) and said: He was never immoderate in his talk and he never reviled others. Allah's Messenger (ﷺ) also said: The best amongst you are those who are best in morals. Uthman said: When he came to Kufa along with Mu'awiya... (The rest of the hadith is the same)}}
\hadithdefcmd{muslim}{6034}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا أَبُو خَالِدٍ، - يَعْنِي الأَحْمَرَ - كُلُّهُمْ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6034}\hadithtrans{This hadith had been narrated on the authority of al-A'mash through another chain of transmitters also}}
\hadithdefcmd{muslim}{6035}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ قُلْتُ لِجَابِرِ بْنِ سَمُرَةَ أَكُنْتَ تُجَالِسُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ كَثِيرًا كَانَ لاَ يَقُومُ مِنْ مُصَلاَّهُ الَّذِي يُصَلِّي فِيهِ الصُّبْحَ حَتَّى تَطْلُعَ الشَّمْسُ فَإِذَا طَلَعَتْ قَامَ وَكَانُوا يَتَحَدَّثُونَ فَيَأْخُذُونَ فِي أَمْرِ الْجَاهِلِيَّةِ فَيَضْحَكُونَ وَيَتَبَسَّمُ صلى الله عليه وسلم ‏.‏\hadithno{6035}\hadithtrans{Simak b. Harb reported:I said to Jabir b. Samura: Did you have the privilege of sitting in the company of Allah's Messenger (ﷺ)? He said: Yes, very frequently, and added: He did not stand up (and go) from the place where he offered the dawn prayer until the sun rose, and after the rising of the sun he stood up, and they (his Companions) entered into conversation with one another and they talked of the things (that they did during the Days of Ignorance), and they laughed (on their unreasonable and ridiculous acts). Allah's Messenger (ﷺ) smiled only}}
\hadithdefcmd{muslim}{6036}{حَدَّثَنَا أَبُو الرَّبِيعِ الْعَتَكِيُّ، وَحَامِدُ بْنُ عُمَرَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو كَامِلٍ جَمِيعًا عَنْ حَمَّادِ بْنِ زَيْدٍ، قَالَ أَبُو الرَّبِيعِ حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ وَغُلاَمٌ أَسْوَدُ يُقَالُ لَهُ أَنْجَشَةُ يَحْدُو فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا أَنْجَشَةُ رُوَيْدَكَ سَوْقًا بِالْقَوَارِيرِ ‏"‏ ‏.‏\hadithno{6036}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) had in one of his journeys his black slave who was called Anjasha along with him. He goaded by singing the songs of camel-driver. Thereupon Allah's Messenger (ﷺ) said:Anjasha, drive slowly as you are driving (the mounts who are carrying) glass vessels}}
\hadithdefcmd{muslim}{6037}{وَحَدَّثَنَا أَبُو الرَّبِيعِ الْعَتَكِيُّ، وَحَامِدُ بْنُ عُمَرَ، وَأَبُو كَامِلٍ قَالُوا حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، بِنَحْوِهِ ‏.‏\hadithno{6037}\hadithtrans{This hadith has been narrated on the authority of Anas through another chain of transmitters}}
\hadithdefcmd{muslim}{6038}{وَحَدَّثَنَاهُ ابْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَذْكُرْ حَادٍ حَسَنُ الصَّوْتِ ‏.‏\hadithno{6038}\hadithtrans{Anas reported this hadith through another chain of transmitters, but he made no mention of a camel-driver having a melodious voice}}
\hadithdefcmd{muslim}{6039}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، كِلاَهُمَا عَنِ ابْنِ عُلَيَّةَ، قَالَ زُهَيْرٌ حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَتَى عَلَى أَزْوَاجِهِ وَسَوَّاقٌ يَسُوقُ بِهِنَّ يُقَالُ لَهُ أَنْجَشَةُ فَقَالَ ‏ "‏ وَيْحَكَ يَا أَنْجَشَةُ رُوَيْدًا سَوْقَكَ بِالْقَوَارِيرِ ‏"‏ ‏.‏ قَالَ قَالَ أَبُو قِلاَبَةَ تَكَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِكَلِمَةٍ لَوْ تَكَلَّمَ بِهَا بَعْضُكُمْ لَعِبْتُمُوهَا عَلَيْهِ ‏.‏\hadithno{6039}\hadithtrans{Anas reported that Allah's Apostle (ﷺ) came to his wives as the camel-driver who was called Anjasha had been, driving (the camels) on which (they were riding). Thereupon he said:Anjasha, be careful, drive slowly for you are driving the mounts who carry vessels of glass. Abu Qilaba said that Allah's Messenger (ﷺ) uttered words which if someone had uttered amongst you, you would have found fault with him}}
\hadithdefcmd{muslim}{6040}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَنَسِ، بْنِ مَالِكٍ ح وَحَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا يَزِيدُ، حَدَّثَنَا التَّيْمِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَتْ أُمُّ سُلَيْمٍ مَعَ نِسَاءِ النَّبِيِّ صلى الله عليه وسلم وَهُنَّ يَسُوقُ بِهِنَّ سَوَّاقٌ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَىْ أَنْجَشَةُ رُوَيْدًا سَوْقَكَ بِالْقَوَارِيرِ ‏"‏ ‏.‏\hadithno{6040}\hadithtrans{Anas b. Malik reported that Umm Sulaim was with the wives of Allah's Apostle (ﷺ) and a camel-driver had been driving (the camels) oil which they were riding. Thereupon Allah's Apostle (ﷺ) said:Anjasha, drive slowly, for you are carrying (on the camels) vessels of glass}}
\hadithdefcmd{muslim}{6041}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنِي هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، قَالَ كَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم حَادٍ حَسَنُ الصَّوْتِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رُوَيْدًا يَا أَنْجَشَةُ لاَ تَكْسِرِ الْقَوَارِيرَ ‏"‏ ‏.‏ يَعْنِي ضَعَفَةَ النِّسَاءِ ‏.‏\hadithno{6041}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) had a camel-driver who had a very melodious voice. Allah's Messenger (ﷺ) said to him:Anjasha, drive slowly; do not break the vessels of glass, meaning the weak women}}
\hadithdefcmd{muslim}{6042}{حَدَّثَنَا مُجَاهِدُ بْنُ مُوسَى، وَأَبُو بَكْرِ بْنُ النَّضْرِ بْنِ أَبِي النَّضْرِ وَهَارُونُ بْنُ عَبْدِ اللَّهِ جَمِيعًا عَنْ أَبِي النَّضْرِ، قَالَ أَبُو بَكْرٍ حَدَّثَنَا أَبُو النَّضْرِ، - يَعْنِي هَاشِمَ بْنَ الْقَاسِمِ - حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا صَلَّى الْغَدَاةَ جَاءَ خَدَمُ الْمَدِينَةِ بِآنِيَتِهِمْ فِيهَا الْمَاءُ فَمَا يُؤْتَى بِإِنَاءٍ إِلاَّ غَمَسَ يَدَهُ فِيهَا فَرُبَّمَا جَاءُوهُ فِي الْغَدَاةِ الْبَارِدَةِ فَيَغْمِسُ يَدَهُ فِيهَا ‏.‏\hadithno{6042}\hadithtrans{Anas b. Malik reported that when Allah's Messenger (ﷺ) had completed his dawn prayer, the servants of Medina came to him with utensils containing water, and no utensil was brought in which he did not dip his hand; and sometime they came in the cold dawn (and he did not feel reluctant in acceding to their request even in the cold weather) and dipped his hand in them}}
\hadithdefcmd{muslim}{6043}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو النَّضْرِ، حَدَّثَنَا سُلَيْمَانُ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَالْحَلاَّقُ يَحْلِقُهُ وَأَطَافَ بِهِ أَصْحَابُهُ فَمَا يُرِيدُونَ أَنْ تَقَعَ شَعْرَةٌ إِلاَّ فِي يَدِ رَجُلٍ ‏.‏\hadithno{6043}\hadithtrans{Anas reported:I saw when the Messenger of Allah (ﷺ) got his hair cut by the barber, his Companions came round him and they eagerly wanted that no hair should fall but in the hand of a person}}
\hadithdefcmd{muslim}{6044}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ امْرَأَةً، كَانَ فِي عَقْلِهَا شَىْءٌ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ لِي إِلَيْكَ حَاجَةً فَقَالَ ‏ "‏ يَا أُمَّ فُلاَنٍ انْظُرِي أَىَّ السِّكَكِ شِئْتِ حَتَّى أَقْضِيَ لَكِ حَاجَتَكِ ‏"‏ ‏.‏ فَخَلاَ مَعَهَا فِي بَعْضِ الطُّرُقِ حَتَّى فَرَغَتْ مِنْ حَاجَتِهَا ‏.‏\hadithno{6044}\hadithtrans{Anas reported that a woman had a partial derangement in her mind, so she said. Allah's Messenger, I want something from you. He said:Mother of so and so, see on which side of the road you would like (to stand and talk) so that I may do the needful for you. He stood aside with her on the roadside until she got what she needed}}
\hadithdefcmd{muslim}{6045}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ ح وَحَدَّثَنَا يَحْيَى بْنُ، يَحْيَى قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ مَا خُيِّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَمْرَيْنِ إِلاَّ أَخَذَ أَيْسَرَهُمَا مَا لَمْ يَكُنْ إِثْمًا فَإِنْ كَانَ إِثْمًا كَانَ أَبْعَدَ النَّاسِ مِنْهُ وَمَا انْتَقَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِنَفْسِهِ إِلاَّ أَنْ تُنْتَهَكَ حُرْمَةُ اللَّهِ عَزَّ وَجَلَّ ‏.‏\hadithno{6045}\hadithtrans{A'isha, the wife of Allah's Apostle (ﷺ), said that whenever he had to choose between two things he adopted the easier one, provided it was nor sin, but if it was any sin he was the one wio was the farthest from it of the people; and Allah's Messenger (ﷺ) never took revenge from anyone because of his personal grievance, unless what Allah, the Exalted and Glorious, had made inviolable had been violated}}
\hadithdefcmd{muslim}{6046}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنْ جَرِيرٍ، ح وَحَدَّثَنَا أَحْمَدُ، بْنُ عَبْدَةَ حَدَّثَنَا فُضَيْلُ بْنُ عِيَاضٍ، كِلاَهُمَا عَنْ مَنْصُورٍ، عَنْ مُحَمَّدٍ، فِي رِوَايَةِ فُضَيْلِ بْنِ شِهَابٍ وَفِي رِوَايَةِ جَرِيرٍ مُحَمَّدٍ الزُّهْرِيِّ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، ‏.‏\hadithno{6046}\hadithtrans{The above hadith has been narrated through several other chains of transmitters}}
\hadithdefcmd{muslim}{6047}{وَحَدَّثَنِيهِ حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ مَالِكٍ ‏.‏\hadithno{6047}\hadithtrans{This hadith has been narrated on the authority of Ibn Shibab through another chain of transmitters}}
\hadithdefcmd{muslim}{6048}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَا خُيِّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَمْرَيْنِ أَحَدُهُمَا أَيْسَرُ مِنَ الآخَرِ إِلاَّ اخْتَارَ أَيْسَرَهُمَا مَا لَمْ يَكُنْ إِثْمًا فَإِنْ كَانَ إِثْمًا كَانَ أَبْعَدَ النَّاسِ مِنْهُ ‏.‏\hadithno{6048}\hadithtrans{A'isha reported:Never did Allah's Messenger (ﷺ) make a choice between two things but adopting the easier one as compared to the difficult one, but his choice for the easier one was only in case it did not involve any sin, but if it involved sin he was the one who was the farthest from it amongst the people}}
\hadithdefcmd{muslim}{6049}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، وَابْنُ، نُمَيْرٍ جَمِيعًا عَنْ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ إِلَى قَوْلِهِ أَيْسَرَهُمَا ‏.‏ وَلَمْ يَذْكُرَا مَا بَعْدَهُ ‏.‏\hadithno{6049}\hadithtrans{This hadith has been narrated on the authority of Hisham through another chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{6050}{حَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَا ضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَيْئًا قَطُّ بِيَدِهِ وَلاَ امْرَأَةً وَلاَ خَادِمًا إِلاَّ أَنْ يُجَاهِدَ فِي سَبِيلِ اللَّهِ وَمَا نِيلَ مِنْهُ شَىْءٌ قَطُّ فَيَنْتَقِمَ مِنْ صَاحِبِهِ إِلاَّ أَنْ يُنْتَهَكَ شَىْءٌ مِنْ مَحَارِمِ اللَّهِ فَيَنْتَقِمَ لِلَّهِ عَزَّ وَجَلَّ ‏.‏\hadithno{6050}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) never beat anyone with his hand, neither a woman nor a servant, but only, in the case when he had been fighting in the cause of Allah and he never took revenge for anything unless the things made inviolable by Allah were made violable; he then took revenge for Allah, the Exalted and Glorious}}
\hadithdefcmd{muslim}{6051}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا عَبْدَةُ، وَوَكِيعٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، كُلُّهُمْ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ يَزِيدُ بَعْضُهُمْ عَلَى بَعْضٍ ‏.‏\hadithno{6051}\hadithtrans{This hadith has been narrated on the authority of Hisham through another chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{6052}{حَدَّثَنَا عَمْرُو بْنُ حَمَّادِ بْنِ طَلْحَةَ الْقَنَّادُ، حَدَّثَنَا أَسْبَاطٌ، - وَهُوَ ابْنُ نَصْرٍ الْهَمْدَانِيُّ - عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَةَ الأُولَى ثُمَّ خَرَجَ إِلَى أَهْلِهِ وَخَرَجْتُ مَعَهُ فَاسْتَقْبَلَهُ وِلْدَانٌ فَجَعَلَ يَمْسَحُ خَدَّىْ أَحَدِهِمْ وَاحِدًا وَاحِدًا - قَالَ - وَأَمَّا أَنَا فَمَسَحَ خَدِّي - قَالَ - فَوَجَدْتُ لِيَدِهِ بَرْدًا أَوْ رِيحًا كَأَنَّمَا أَخْرَجَهَا مِنْ جُؤْنَةِ عَطَّارٍ ‏.‏\hadithno{6052}\hadithtrans{Jabir b. Samura reported:I prayed along with Allah's Messenger (ﷺ) the first prayer. He then went to his family and I also went along with him when he met some children (on the way). He began to pat the cheeks of each one of them. He also patted my cheek and I experienced a coolness or a fragrance of his hand as if it had been brought out from the scent bag of a perfumer}}
\hadithdefcmd{muslim}{6053}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا هَاشِمٌ، - يَعْنِي ابْنَ الْقَاسِمِ - حَدَّثَنَا سُلَيْمَانُ، - وَهُوَ ابْنُ الْمُغِيرَةِ - عَنْ ثَابِتٍ، قَالَ أَنَسٌ مَا شَمِمْتُ عَنْبَرًا قَطُّ وَلاَ مِسْكًا وَلاَ شَيْئًا أَطْيَبَ مِنْ رِيحِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ مَسِسْتُ شَيْئًا قَطُّ دِيبَاجًا وَلاَ حَرِيرًا أَلْيَنَ مَسًّا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{6053}\hadithtrans{Anas reported:I never smelt ambergris or musk as fragrant as the fragrance of the body of Allah's Messenger (ﷺ) and I never touched brocade or silk and found it as soft as the body of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{6054}{وَحَدَّثَنِي أَحْمَدُ بْنُ سَعِيدِ بْنِ صَخْرٍ الدَّارِمِيُّ، حَدَّثَنَا حَبَّانٌ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَزْهَرَ اللَّوْنِ كَأَنَّ عَرَقَهُ اللُّؤْلُؤُ إِذَا مَشَى تَكَفَّأَ وَلاَ مَسِسْتُ دِيبَاجَةً وَلاَ حَرِيرَةً أَلْيَنَ مِنْ كَفِّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ شَمَمْتُ مِسْكَةً وَلاَ عَنْبَرَةً أَطْيَبَ مِنْ رَائِحَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{6054}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) had a very fair complexion and (the drops) of his perspiration shone like pearls, and when he walked he walked inclining forward, and I never touched brocade and silk (and found it) as soft as the softness of the palm of Allah's Messenger (ﷺ) and I never smelt musk or ambergris and found its fragrance as sweet as the fragrance of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{6055}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا هَاشِمٌ، - يَعْنِي ابْنَ الْقَاسِمِ - عَنْ سُلَيْمَانَ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ دَخَلَ عَلَيْنَا النَّبِيُّ صلى الله عليه وسلم فَقَالَ عِنْدَنَا فَعَرِقَ وَجَاءَتْ أُمِّي بِقَارُورَةٍ فَجَعَلَتْ تَسْلُتُ الْعَرَقَ فِيهَا فَاسْتَيْقَظَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ يَا أُمَّ سُلَيْمٍ مَا هَذَا الَّذِي تَصْنَعِينَ ‏"‏ ‏.‏ قَالَتْ هَذَا عَرَقُكَ نَجْعَلُهُ فِي طِيبِنَا وَهُوَ مِنْ أَطْيَبِ الطِّيبِ ‏.‏\hadithno{6055}\hadithtrans{Anas b. Malik reported that Allah's Apostle (ﷺ) used to come to our house and there was perspiration upon his body. My mother brought a bottle and began to pour the sweat in that. When Allah's Apostle (ﷺ) got up he said:Umm Sulaim, what is this that you are doing? Thereupon she said: That is your sweat which we mix in our perfume and it becomes the most fragrant perfume}}
\hadithdefcmd{muslim}{6056}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا حُجَيْنُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - وَهُوَ ابْنُ أَبِي سَلَمَةَ - عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَدْخُلُ بَيْتَ أُمِّ سُلَيْمٍ فَيَنَامُ عَلَى فِرَاشِهَا وَلَيْسَتْ فِيهِ - قَالَ - فَجَاءَ ذَاتَ يَوْمٍ فَنَامَ عَلَى فِرَاشِهَا فَأُتِيَتْ فَقِيلَ لَهَا هَذَا النَّبِيُّ صلى الله عليه وسلم نَامَ فِي بَيْتِكِ عَلَى فِرَاشِكِ - قَالَ - فَجَاءَتْ وَقَدْ عَرِقَ وَاسْتَنْقَعَ عَرَقُهُ عَلَى قِطْعَةِ أَدِيمٍ عَلَى الْفِرَاشِ فَفَتَحَتْ عَتِيدَتَهَا فَجَعَلَتْ تُنَشِّفُ ذَلِكَ الْعَرَقَ فَتَعْصِرُهُ فِي قَوَارِيرِهَا فَفَزِعَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا تَصْنَعِينَ يَا أُمَّ سُلَيْمٍ ‏"‏ ‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ نَرْجُو بَرَكَتَهُ لِصِبْيَانِنَا قَالَ ‏"‏ أَصَبْتِ ‏"‏ ‏.‏\hadithno{6056}\hadithtrans{Anas b. Malik reported that Allah's Apostle (ﷺ) came to the house of Umm Sulaim and slept in her bed while she was away from her house. On the other day too he slept in her bed. She came and it was said to her:It is Allah's Apostle (ﷺ) who is having siesta in your house, lying in your bed. She came and found him sweating and his sweat falling on the leather cloth spread on her bed. She opened her scent-bag and began to fill the bottles with it. Allah's Apostle (ﷺ) was startled and woke up and said: Umm Sulaim, what are you doing? She said: Allah's Messenger, we seek blessings for our children through it. Thereupon he said: You have done something right}}
\hadithdefcmd{muslim}{6057}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، عَنْ أُمِّ سُلَيْمٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَأْتِيهَا فَيَقِيلُ عِنْدَهَا فَتَبْسُطُ لَهُ نَطْعًا فَيَقِيلُ عَلَيْهِ وَكَانَ كَثِيرَ الْعَرَقِ فَكَانَتْ تَجْمَعُ عَرَقَهُ فَتَجْعَلُهُ فِي الطِّيبِ وَالْقَوَارِيرِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَا أُمَّ سُلَيْمٍ مَا هَذَا ‏"‏ ‏.‏ قَالَتْ عَرَقُكَ أَدُوفُ بِهِ طِيبِي ‏.‏\hadithno{6057}\hadithtrans{Umm Sulaim reported that Allah's Apostle (ﷺ) visited her house and (took rest) and she spread a piece of cloth for him and he had had a siesta on it. And he sweated profusely and she collected his sweat and put it in a perfume and in bottles. Allah's Apostle (ﷺ) said:Umm Sulaim, what is this? She said: It is your sweat, which I put in my perfume. Allah's Apostle (ﷺ) sweated in cold weather when revelation descended upon him}}
\hadithdefcmd{muslim}{6058}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ إِنْ كَانَ لَيُنْزَلُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْغَدَاةِ الْبَارِدَةِ ثُمَّ تَفِيضُ جَبْهَتُهُ عَرَقًا ‏.‏\hadithno{6058}\hadithtrans{A'isha reported:When revelation descended upon Allah's Messenger (ﷺ) even during the cold days, his forehead perspired}}
\hadithdefcmd{muslim}{6059}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، وَابْنُ، بِشْرٍ جَمِيعًا عَنْ هِشَامٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ الْحَارِثَ بْنَ هِشَامٍ، سَأَلَ النَّبِيَّ صلى الله عليه وسلم كَيْفَ يَأْتِيكَ الْوَحْىُ فَقَالَ ‏ "‏ أَحْيَانًا يَأْتِينِي فِي مِثْلِ صَلْصَلَةِ الْجَرَسِ وَهُوَ أَشَدُّهُ عَلَىَّ ثُمَّ يَفْصِمُ عَنِّي وَقَدْ وَعَيْتُهُ وَأَحْيَانًا مَلَكٌ فِي مِثْلِ صُورَةِ الرَّجُلِ فَأَعِي مَا يَقُولُ ‏"‏ ‏.‏\hadithno{6059}\hadithtrans{A'isha reported that Harith b. Hisham asked Allah's Apostle (ﷺ):How does the the wahi (inspiration) come to you? He said: At times it comes to me like the ringing of a bell and that is most severe for me and when it is over I retain that (what I had received in the form of wahi), and at times an Angel in the form of a human being comes to me (and speaks) and I retain whatever he speaks}}
\hadithdefcmd{muslim}{6060}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ حِطَّانَ بْنِ عَبْدِ اللَّهِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ كَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم إِذَا أُنْزِلَ عَلَيْهِ الْوَحْىُ كُرِبَ لِذَلِكَ وَتَرَبَّدَ وَجْهُهُ ‏.‏\hadithno{6060}\hadithtrans{Ubida b. Samit reported that when wahi (inspiration) descended upon Allah's Messenger (ﷺ), he felt a burden on that account and the colour of his face underwent a change}}
\hadithdefcmd{muslim}{6061}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنَا أَبِي، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ حِطَّانَ بْنِ عَبْدِ اللَّهِ الرَّقَاشِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أُنْزِلَ عَلَيْهِ الْوَحْىُ نَكَسَ رَأْسَهُ وَنَكَسَ أَصْحَابُهُ رُءُوسَهُمْ فَلَمَّا أُتْلِيَ عَنْهُ رَفَعَ رَأْسَهُ ‏.‏\hadithno{6061}\hadithtrans{Ubida b. Samit reported that when wahi descended upon Allah's Apostle (ﷺ), he lowered his head and so lowered his Companions their heads, and when (this state) was over, he raised his head}}
\hadithdefcmd{muslim}{6062}{حَدَّثَنَا مَنْصُورُ بْنُ أَبِي مُزَاحِمٍ، وَمُحَمَّدُ بْنُ جَعْفَرِ بْنِ زِيَادٍ، قَالَ مَنْصُورٌ حَدَّثَنَا وَقَالَ، ابْنُ جَعْفَرٍ أَخْبَرَنَا إِبْرَاهِيمُ، - يَعْنِيَانِ ابْنَ سَعْدٍ - عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ، اللَّهِ عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ أَهْلُ الْكِتَابِ يَسْدُلُونَ أَشْعَارَهُمْ وَكَانَ الْمُشْرِكُونَ يَفْرُقُونَ رُءُوسَهُمْ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُحِبُّ مُوَافَقَةَ أَهْلِ الْكِتَابِ فِيمَا لَمْ يُؤْمَرْ بِهِ فَسَدَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَاصِيَتَهُ ثُمَّ فَرَقَ بَعْدُ ‏.‏\hadithno{6062}\hadithtrans{Ibn Abbas reported that the People of the Book used to let their hair fall (on their foreheads) and the polytheists used to part them on their heads, and Allah's Messenger (ﷺ) liked to conform his behaviour to the People of the Book in matters in which he received no command (from God) ; so Allah's Messenger (ﷺ) let fall his hair upon his forehead, and then he began to part it after this}}
\hadithdefcmd{muslim}{6063}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{6063}\hadithtrans{This hadith has been narrated on the authority of Ibn Shihab with the same chain of transmitters}}
\hadithdefcmd{muslim}{6064}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ أَبَا إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً مَرْبُوعًا بَعِيدَ مَا بَيْنَ الْمَنْكِبَيْنِ عَظِيمَ الْجُمَّةِ إِلَى شَحْمَةِ أُذُنَيْهِ عَلَيْهِ حُلَّةٌ حَمْرَاءُ مَا رَأَيْتُ شَيْئًا قَطُّ أَحْسَنَ مِنْهُ صلى الله عليه وسلم ‏.‏\hadithno{6064}\hadithtrans{Al-Bara' reported that Allah's Messenger (ﷺ) was of medium height, having broad shoulders, with his hair hanging down on the lobes of his ears. He put on a red mantle over him, and never have I seen anyone more handsome than Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{6065}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ مَا رَأَيْتُ مِنْ ذِي لِمَّةٍ أَحْسَنَ فِي حُلَّةٍ حَمْرَاءَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم شَعْرُهُ يَضْرِبُ مَنْكِبَيْهِ بَعِيدَ مَا بَيْنَ الْمَنْكِبَيْنِ لَيْسَ بِالطَّوِيلِ وَلاَ بِالْقَصِيرِ ‏.‏ قَالَ أَبُو كُرَيْبٍ لَهُ شَعَرٌ ‏.‏\hadithno{6065}\hadithtrans{Al-Bara' reported:Never did I see anyone more handsome than Allah's Apostle (ﷺ) in the red mantle. His hair had been hanging down on the shoulders and his shoulders were very broad, and he was neither very tall nor short-statured. Ibn Kuraib said he had hair}}
\hadithdefcmd{muslim}{6066}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ بْنِ، يُوسُفَ عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَحْسَنَ النَّاسِ وَجْهًا وَأَحْسَنَهُمْ خَلْقًا لَيْسَ بِالطَّوِيلِ الذَّاهِبِ وَلاَ بِالْقَصِيرِ ‏.‏\hadithno{6066}\hadithtrans{Al-Bara' reported that Allah's Messenger (ﷺ) had the most handsome face amongst men and he had the best disposition and he was neither very tall nor short-statured}}
\hadithdefcmd{muslim}{6067}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنَا قَتَادَةُ، قَالَ قُلْتُ لأَنَسِ بْنِ مَالِكٍ كَيْفَ كَانَ شَعَرُ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ كَانَ شَعَرًا رَجِلاً لَيْسَ بِالْجَعْدِ وَلاَ السَّبِطِ بَيْنَ أُذُنَيْهِ وَعَاتِقِهِ ‏.‏\hadithno{6067}\hadithtrans{Qatada reported:I asked Anas b. Malik: How was the hair of Allah's Messenger (ﷺ)? Thereupon he said: His hair was neither very curly nor very straight, and they hung over his shoulders and earlobes}}
\hadithdefcmd{muslim}{6068}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الصَّمَدِ، قَالاَ حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَضْرِبُ شَعَرُهُ مَنْكِبَيْهِ ‏.‏\hadithno{6068}\hadithtrans{Anas reported that the hair of Allah's Messenger (may. peace be upon him) came upon his shoulders}}
\hadithdefcmd{muslim}{6069}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ كَانَ شَعَرُ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى أَنْصَافِ أُذُنَيْهِ ‏.‏\hadithno{6069}\hadithtrans{Anas reported that the hair of Allah's Apostle (ﷺ) reached half of the earlobe}}
\hadithdefcmd{muslim}{6070}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ سَمُرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم ضَلِيعَ الْفَمِ أَشْكَلَ الْعَيْنِ مَنْهُوسَ الْعَقِبَيْنِ ‏.‏ قَالَ قُلْتُ لِسِمَاكٍ مَا ضَلِيعُ الْفَمِ قَالَ عَظِيمُ الْفَمِ ‏.‏ قَالَ قُلْتُ مَا أَشْكَلُ الْعَيْنِ قَالَ طَوِيلُ شَقِّ الْعَيْنِ ‏.‏ قَالَ قُلْتُ مَا مَنْهُوسُ الْعَقِبِ قَالَ قَلِيلُ لَحْمِ الْعَقِبِ ‏.‏\hadithno{6070}\hadithtrans{Jabir b. Samura reported that Allah's Messenger (ﷺ) had a broad face with reddish (wide) eyes, and lean heels. Shu'ba reported:I said to Simak: What does this dali-ul-fam mean? And he said: This means broad face. I said: What does this ashkal mean? He said: Long in the slit of the eye. I said: What is this manhus-ul-aqibain? He said: It implies little flesh at the heels}}
\hadithdefcmd{muslim}{6071}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي الطُّفَيْلِ، قَالَ قُلْتُ لَهُ أَرَأَيْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ كَانَ أَبْيَضَ مَلِيحَ الْوَجْهِ ‏.‏ قَالَ مُسْلِمُ بْنُ الْحَجَّاجِ مَاتَ أَبُو الطُّفَيْلِ سَنَةَ مِائَةٍ وَكَانَ آخِرَ مَنْ مَاتَ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{6071}\hadithtrans{Jurairi reported:I said to Abu Tufail: Did you see Allah's Messenger (ﷺ)? He said: Yes, he had a white handsome face. Muslim b. Hajjaj said: Abu Tufail who died in 100 Hijra was the last of the Companions of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{6072}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي الطُّفَيْلِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَمَا عَلَى وَجْهِ الأَرْضِ رَجُلٌ رَآهُ غَيْرِي ‏.‏ قَالَ فَقُلْتُ لَهُ فَكَيْفَ رَأَيْتَهُ قَالَ كَانَ أَبْيَضَ مَلِيحًا مُقَصَّدًا ‏.‏\hadithno{6072}\hadithtrans{Abu Tufail reported:I saw Allah's Messenger (ﷺ) and there is one amongst the people of the earth who (are living at the present time and) had seen him except me. I said to him: How did you find him? He said: He had an elegant white color, and he was of an average height}}
\hadithdefcmd{muslim}{6073}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ وَعَمْرٌو النَّاقِدُ جَمِيعًا عَنِ ابْنِ إِدْرِيسَ، - قَالَ عَمْرٌو حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ الأَوْدِيُّ، - عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، قَالَ سُئِلَ أَنَسُ بْنُ مَالِكٍ هَلْ خَضَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ إِنَّهُ لَمْ يَكُنْ رَأَى مِنَ الشَّيْبِ إِلاَّ - قَالَ ابْنُ إِدْرِيسَ كَأَنَّهُ يُقَلِّلُهُ - وَقَدْ خَضَبَ أَبُو بَكْرٍ وَعُمَرُ بِالْحِنَّاءِ وَالْكَتَمِ ‏.‏\hadithno{6073}\hadithtrans{Ibn Sirin reported:Anas b. Malik was asked whether Allah's Messenger (ﷺ) dyed his hair. He said: He had not become old enough to have white hair. Ibn Idris said that he had a few white hair. Abu Bakr and Umar, however, dyed hair with hina' (henna)}}
\hadithdefcmd{muslim}{6074}{حَدَّثَنَا مُحَمَّدُ بْنُ بَكَّارِ بْنِ الرَّيَّانِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنِ ابْنِ سِيرِينَ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ هَلْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَضَبَ فَقَالَ لَمْ يَبْلُغِ الْخِضَابَ كَانَ فِي لِحْيَتِهِ شَعَرَاتٌ بِيضٌ ‏.‏ قَالَ قُلْتُ لَهُ أَكَانَ أَبُو بَكْرٍ يَخْضِبُ قَالَ فَقَالَ نَعَمْ بِالْحِنَّاءِ وَالْكَتَمِ ‏.‏\hadithno{6074}\hadithtrans{Ibn Sirin reported:I asked Anas b. Malik whether Allah's Messenger (ﷺ) dyed his hair. He said: He had not reached the stage when (he needed) dyeing (of his white hair). He had a few white hair in his beard. I said to him: Did Abu Bakr dye his hair? He said: Yes, with hina' (henna)}}
\hadithdefcmd{muslim}{6075}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبُ بْنُ خَالِدٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ أَخَضَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ إِنَّهُ لَمْ يَرَ مِنَ الشَّيْبِ إِلاَّ قَلِيلاً ‏.‏\hadithno{6075}\hadithtrans{Muhammad b. Sirin reported:I asked Anas b. Malik whether Allah's Messenger (ﷺ) dyed his hair. He said: He had but little white hair}}
\hadithdefcmd{muslim}{6076}{حَدَّثَنِي أَبُو الرَّبِيعِ الْعَتَكِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا ثَابِتٌ، قَالَ سُئِلَ أَنَسُ بْنُ مَالِكٍ عَنْ خِضَابِ النَّبِيِّ، صلى الله عليه وسلم فَقَالَ لَوْ شِئْتُ أَنْ أَعُدَّ شَمَطَاتٍ كُنَّ فِي رَأْسِهِ فَعَلْتُ ‏.‏ وَقَالَ لَمْ يَخْتَضِبْ وَقَدِ اخْتَضَبَ أَبُو بَكْرٍ بِالْحِنَّاءِ وَالْكَتَمِ وَاخْتَضَبَ عُمَرُ بِالْحِنَّاءِ بَحْتًا ‏.‏\hadithno{6076}\hadithtrans{Thabit reported that Anas b. Malik was asked about the dyeing (of the hair of) Allah's Apostle (ﷺ). Thereupon he said.:(They were so few) that if I so liked I could count their number in his head, and he further said: (That is) he did not dye. Abu Bakr, however, dyed them and so did 'Umar dye them with pure henna}}
\hadithdefcmd{muslim}{6077}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا الْمُثَنَّى بْنُ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ يُكْرَهُ أَنْ يَنْتِفَ الرَّجُلُ، الشَّعْرَةَ الْبَيْضَاءَ مِنْ رَأْسِهِ وَلِحْيَتِهِ - قَالَ - وَلَمْ يَخْتَضِبْ رَسُولُ اللَّهِ صلى الله عليه وسلم إِنَّمَا كَانَ الْبَيَاضُ فِي عَنْفَقَتِهِ وَفِي الصُّدْغَيْنِ وَفِي الرَّأْسِ نَبْذٌ ‏.‏\hadithno{6077}\hadithtrans{Anas b. Malik did not like that a person should pick out his white hair from his head or beard, and Allah's Messenger (ﷺ) did not dye, and there was some whiteness in his hair at his chin, on his temples and very little on his head}}
\hadithdefcmd{muslim}{6078}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا الْمُثَنَّى، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6078}\hadithtrans{This hadith has been narrated on the authority of Muthanna through the same chain of transmitters}}
\hadithdefcmd{muslim}{6079}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ وَأَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ وَهَارُونُ بْنُ عَبْدِ اللَّهِ جَمِيعًا عَنْ أَبِي دَاوُدَ، قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ، حَدَّثَنَا شُعْبَةُ، عَنْ خُلَيْدِ بْنِ جَعْفَرٍ، سَمِعَ أَبَا إِيَاسٍ، عَنْ أَنَسٍ، أَنَّهُ سُئِلَ عَنْ شَيْبِ النَّبِيِّ، صلى الله عليه وسلم فَقَالَ مَا شَانَهُ اللَّهُ بِبَيْضَاءَ ‏.‏\hadithno{6079}\hadithtrans{Anas (b. Malik) was asked about the old age of Allah's Apostle (ﷺ). He said:Allah did not blemish him with white hair}}
\hadithdefcmd{muslim}{6080}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، ح وَحَدَّثَنَا يَحْيَى بْنُ، يَحْيَى أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي جُحَيْفَةَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم هَذِهِ مِنْهُ بَيْضَاءَ وَوَضَعَ زُهَيْرٌ بَعْضَ أَصَابِعِهِ عَلَى عَنْفَقَتِهِ قِيلَ لَهُ مِثْلُ مَنْ أَنْتَ يَوْمَئِذٍ قَالَ أَبْرِي النَّبْلَ وَأَرِيشُهَا ‏.‏\hadithno{6080}\hadithtrans{Abu Juhaifa reported:I saw Allah's Messenger (ﷺ) having some whiteness (in hair) at this place, and Zuhair placed one of his fingers at his chin. Juhaifa was asked how old he had been at that time. He said: I made arrows and put feathers to them (i. e. I had passed my childhood)}}
\hadithdefcmd{muslim}{6081}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ أَبِي جُحَيْفَةَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَبْيَضَ قَدْ شَابَ كَانَ الْحَسَنُ بْنُ عَلِيٍّ يُشْبِهُهُ ‏.‏\hadithno{6081}\hadithtrans{Abu Juhaifa reported:I saw Allah's Messenger (ﷺ) that he had white complexion and had some white hair, and Hasan b. 'Ali resembled him}}
\hadithdefcmd{muslim}{6082}{وَحَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا سُفْيَانُ، وَخَالِدُ بْنُ عَبْدِ اللَّهِ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، كُلُّهُمْ عَنْ إِسْمَاعِيلَ، عَنْ أَبِي جُحَيْفَةَ، بِهَذَا وَلَمْ يَقُولُوا أَبْيَضَ قَدْ شَابَ ‏.‏\hadithno{6082}\hadithtrans{This hadith has been transmitted on the authority of Abu Juhaifa with a slight variation of wording}}
\hadithdefcmd{muslim}{6083}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ دَاوُدَ حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ، بْنِ حَرْبٍ قَالَ سَمِعْتُ جَابِرَ بْنَ سَمُرَةَ، سُئِلَ عَنْ شَيْبِ النَّبِيِّ، صلى الله عليه وسلم فَقَالَ كَانَ إِذَا دَهَنَ رَأْسَهُ لَمْ يُرَ مِنْهُ شَىْءٌ وَإِذَا لَمْ يَدْهُنْ رُئِيَ مِنْهُ ‏.‏\hadithno{6083}\hadithtrans{Jabir b. Samura was asked about the old age of Allah's Apostle (ﷺ). He said:When he oiled his head nothing was seen (as a mark of old age) and when he did not apply oil something (of the old age) became visible}}
\hadithdefcmd{muslim}{6084}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ إِسْرَائِيلَ، عَنْ سِمَاكٍ، أَنَّهُ سَمِعَ جَابِرَ بْنَ سَمُرَةَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَدْ شَمِطَ مُقَدَّمُ رَأْسِهِ وَلِحْيَتِهِ وَكَانَ إِذَا ادَّهَنَ لَمْ يَتَبَيَّنْ وَإِذَا شَعِثَ رَأْسُهُ تَبَيَّنَ وَكَانَ كَثِيرَ شَعْرِ اللِّحْيَةِ فَقَالَ رَجُلٌ وَجْهُهُ مِثْلُ السَّيْفِ قَالَ لاَ بَلْ كَانَ مِثْلَ الشَّمْسِ وَالْقَمَرِ وَكَانَ مُسْتَدِيرًا وَرَأَيْتُ الْخَاتَمَ عِنْدَ كَتِفِهِ مِثْلَ بَيْضَةِ الْحَمَامَةِ يُشْبِهُ جَسَدَهُ ‏.‏\hadithno{6084}\hadithtrans{Jabir b. Samura reported that there had appeared some whiteness on the front part of the head and beard of Allah's Messenger (ﷺ). When he applied oil, it did not become visible, but when he did not (apply) oil, it became apparent. And he had a thick beard. A person said:His face was as (bright) as the sword. Thereupon he (Jabir) said: No, it was round and like the sun and the moon. And I saw the seal near his shoulder of the size of a pigeon's egg and its color was the same as that of his body}}
\hadithdefcmd{muslim}{6085}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ سَمُرَةَ، قَالَ رَأَيْتُ خَاتِمًا فِي ظَهْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم كَأَنَّهُ بَيْضَةُ حَمَامٍ ‏.‏\hadithno{6085}\hadithtrans{Jabir. Samura reported:I saw the seal on his back as if it were a pigeon's egg}}
\hadithdefcmd{muslim}{6086}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَخْبَرَنَا حَسَنُ بْنُ صَالِحٍ، عَنْ سِمَاكٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6086}\hadithtrans{This hadith has been narrated on the authority of Simak with the same chain of transmitters}}
\hadithdefcmd{muslim}{6087}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ عَبَّادٍ، قَالاَ حَدَّثَنَا حَاتِمٌ، - وَهُوَ ابْنُ إِسْمَاعِيلَ - عَنِ الْجَعْدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ السَّائِبَ بْنَ يَزِيدَ، يَقُولُ ذَهَبَتْ بِي خَالَتِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَ أُخْتِي وَجِعٌ ‏.‏ فَمَسَحَ رَأْسِي وَدَعَا لِي بِالْبَرَكَةِ ثُمَّ تَوَضَّأَ فَشَرِبْتُ مِنْ وَضُوئِهِ ثُمَّ قُمْتُ خَلْفَ ظَهْرِهِ فَنَظَرْتُ إِلَى خَاتِمِهِ بَيْنَ كَتِفَيْهِ مِثْلَ زِرِّ الْحَجَلَةِ ‏.‏\hadithno{6087}\hadithtrans{As-Sa'ib b. Yazid reported:My mother's sister took me to Allah's Messenger (ﷺ) and said: Allah's Messenger, here is the son of my sister and he is ailing. He touched my head and invoked blessings upon me. He then performed ablution and I drank the water left from his ablution; then I stood behind him and I saw the seal between his shoulders}}
\hadithdefcmd{muslim}{6088}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا حَمَّادٌ يَعْنِي ابْنَ زَيْدٍ، ح وَحَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، كِلاَهُمَا عَنْ عَاصِمٍ الأَحْوَلِ، ح وَحَدَّثَنِي حَامِدُ بْنُ عُمَرَ الْبَكْرَاوِيُّ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدُ الْوَاحِدِ، - يَعْنِي ابْنَ زِيَادٍ - حَدَّثَنَا عَاصِمٌ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَأَكَلْتُ مَعَهُ خُبْزًا وَلَحْمًا - أَوْ قَالَ ثَرِيدًا - قَالَ فَقُلْتُ لَهُ أَسْتَغْفَرَ لَكَ النَّبِيُّ صلى الله عليه وسلم قَالَ نَعَمْ وَلَكَ ثُمَّ تَلاَ هَذِهِ الآيَةَ ‏\{‏ وَاسْتَغْفِرْ لِذَنْبِكَ وَلِلْمُؤْمِنِينَ وَالْمُؤْمِنَاتِ‏\}‏ قَالَ ثُمَّ دُرْتُ خَلْفَهُ فَنَظَرْتُ إِلَى خَاتَمِ النُّبُوَّةِ بَيْنَ كَتِفَيْهِ عِنْدَ نَاغِضِ كَتِفِهِ الْيُسْرَى جُمْعًا عَلَيْهِ خِيلاَنٌ كَأَمْثَالِ الثَّآلِيلِ ‏.‏\hadithno{6088}\hadithtrans{Abdullah b. Sarjis reported:I saw Allah's Apostle (ﷺ) and ate with him bread and meat, or he said Tharid (bread soaked in soup). I said to him: Did Allah's Apostle (ﷺ) seek forgiveness for you? He said: Yes, and for you, and he then recited this verse:" Ask forgiveness for thy sin and for the believing men and believing women" (xlvii. 19). I then went after him and saw the Seal of Prophethood between his shoulders on the left side of his shoulder having spots on it like moles}}
\hadithdefcmd{muslim}{6089}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ سَمِعَهُ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْسَ بِالطَّوِيلِ الْبَائِنِ وَلاَ بِالْقَصِيرِ وَلَيْسَ بِالأَبْيَضِ الأَمْهَقِ وَلاَ بِالآدَمِ وَلاَ بِالْجَعْدِ الْقَطَطِ وَلاَ بِالسَّبِطِ بَعَثَهُ اللَّهُ عَلَى رَأْسِ أَرْبَعِينَ سَنَةً فَأَقَامَ بِمَكَّةَ عَشْرَ سِنِينَ وَبِالْمَدِينَةِ عَشْرَ سِنِينَ وَتَوَفَّاهُ اللَّهُ عَلَى رَأْسِ سِتِّينَ سَنَةً وَلَيْسَ فِي رَأْسِهِ وَلِحْيَتِهِ عِشْرُونَ شَعْرَةً بَيْضَاءَ ‏.‏\hadithno{6089}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) was neither very conspicuously tall nor short-statured, and his color was neither glaringly white nor brown; his hair was neither very curly nor very straight; Allah commissioned him (as a Prophet) when he had reached the age of forty years, and he stayed in Mecca for ten years and for ten years in Medina; Allah took him away when he had just reached the age of sixty, and there had not been twenty white hair in his head and beard}}
\hadithdefcmd{muslim}{6090}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، يَعْنُونَ ابْنَ جَعْفَرٍ ح وَحَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنِي سُلَيْمَانُ بْنُ، بِلاَلٍ كِلاَهُمَا عَنْ رَبِيعَةَ، - يَعْنِي ابْنَ أَبِي عَبْدِ الرَّحْمَنِ - عَنْ أَنَسِ بْنِ مَالِكٍ، ‏.‏ بِمِثْلِ حَدِيثِ مَالِكِ بْنِ أَنَسٍ وَزَادَ فِي حَدِيثِهِمَا كَانَ أَزْهَرَ ‏.‏\hadithno{6090}\hadithtrans{This hadith has been transmitted on the authority of Anas b. Malik with this addition that instead of the word al-Amhaq there is the word Azhar}}
\hadithdefcmd{muslim}{6091}{حَدَّثَنِي أَبُو غَسَّانَ الرَّازِيُّ، مُحَمَّدُ بْنُ عَمْرٍو حَدَّثَنَا حَكَّامُ بْنُ سَلْمٍ، حَدَّثَنَا عُثْمَانُ، بْنُ زَائِدَةَ عَنِ الزُّبَيْرِ بْنِ عَدِيٍّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قُبِضَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ وَأَبُو بَكْرٍ وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ وَعُمَرُ وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ ‏.‏\hadithno{6091}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) died when he was sixty-three years old, and so was the case with Abu Bakr, and so was the case with Umar who was also sixty-three (when he died)}}
\hadithdefcmd{muslim}{6092}{وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ حَدَّثَنِي عُقَيْلُ، بْنُ خَالِدٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تُوُفِّيَ وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ سَنَةً ‏.‏ وَقَالَ ابْنُ شِهَابٍ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ بِمِثْلِ ذَلِكَ ‏.‏\hadithno{6092}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) died when he had attained the age of sixty-three. And a hadith like this had been transmitted on the authority of Sa'id b. Musayyib}}
\hadithdefcmd{muslim}{6093}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَعَبَّادُ بْنُ مُوسَى، قَالاَ حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، بِالإِسْنَادَيْنِ جَمِيعًا مِثْلَ حَدِيثِ عُقَيْلٍ ‏.‏\hadithno{6093}\hadithtrans{This hadith has been narrated on the authority of Ibn Shihab through the same chain of transmitters}}
\hadithdefcmd{muslim}{6094}{حَدَّثَنَا أَبُو مَعْمَرٍ، إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ الْهُذَلِيُّ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ قُلْتُ لِعُرْوَةَ كَمْ كَانَ النَّبِيُّ صلى الله عليه وسلم بِمَكَّةَ قَالَ عَشْرًا ‏.‏ قَالَ قُلْتُ فَإِنَّ ابْنَ عَبَّاسٍ يَقُولُ ثَلاَثَ عَشْرَةَ ‏.‏\hadithno{6094}\hadithtrans{Amr reported:I said to 'Urwa: How long did Allah's Apostle - (ﷺ) stay in Mecca? He said: For ten years. I said: Ibn 'Abbas says (that he stayed in Mecca) for thirteen years}}
\hadithdefcmd{muslim}{6095}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، قَالَ قُلْتُ لِعُرْوَةَ كَمْ لَبِثَ النَّبِيُّ صلى الله عليه وسلم بِمَكَّةَ قَالَ عَشْرًا ‏.‏ قُلْتُ فَإِنَّ ابْنَ عَبَّاسٍ يَقُولُ بِضْعَ عَشْرَةَ ‏.‏ قَالَ فَغَفَّرَهُ وَقَالَ إِنَّمَا أَخَذَهُ مِنْ قَوْلِ الشَّاعِرِ ‏.‏\hadithno{6095}\hadithtrans{Amr reported:I said to 'Urwa: How long did Allah's Apostle (ﷺ) stay in Mecca? He said: For ten years. I said: Ibn Abbas says it is some years above ten. He ('Urwa) sought forgiveness for him and said: His statement is based on the verse of a poet}}
\hadithdefcmd{muslim}{6096}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، عَنْ رَوْحِ بْنِ عُبَادَةَ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَكَثَ بِمَكَّةَ ثَلاَثَ عَشْرَةَ وَتُوُفِّيَ وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ ‏.‏\hadithno{6096}\hadithtrans{Ibn 'Abbas reported that Allah's Messenger (ﷺ) stayed in Mecca for thirteen years and he died when he had attained the age of sixty three years}}
\hadithdefcmd{muslim}{6097}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، حَدَّثَنَا حَمَّادٌ، عَنْ أَبِي جَمْرَةَ الضُّبَعِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَكَّةَ ثَلاَثَ عَشْرَةَ سَنَةً يُوحَى إِلَيْهِ وَبِالْمَدِينَةِ عَشْرًا وَمَاتَ وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ سَنَةً ‏.‏\hadithno{6097}\hadithtrans{Ibn 'Abbas reported that Allah's Messenger (ﷺ) stayed in Mecca for thirteen years (after he had received revelation) and stayed in Medina for ten years, and he was sixty-three when he died}}
\hadithdefcmd{muslim}{6098}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ بْنِ مُحَمَّدِ بْنِ أَبَانَ الْجُعْفِيُّ، حَدَّثَنَا سَلاَّمٌ أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، قَالَ كُنْتُ جَالِسًا مَعَ عَبْدِ اللَّهِ بْنِ عُتْبَةَ فَذَكَرُوا سِنِي رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ بَعْضُ الْقَوْمِ كَانَ أَبُو بَكْرٍ أَكْبَرَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ عَبْدُ اللَّهِ قُبِضَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ وَمَاتَ أَبُو بَكْرٍ وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ وَقُتِلَ عُمَرُ وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ ‏.‏ قَالَ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ يُقَالُ لَهُ عَامِرُ بْنُ سَعْدٍ حَدَّثَنَا جَرِيرٌ قَالَ كُنَّا قُعُودًا عِنْدَ مُعَاوِيَةَ فَذَكَرُوا سِنِي رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ مُعَاوِيَةُ قُبِضَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ سَنَةً وَمَاتَ أَبُو بَكْرٍ وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ وَقُتِلَ عُمَرُ وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ ‏.‏\hadithno{6098}\hadithtrans{Abu Ishaq reported:I was sitting with 'Abdullah b. 'Utba and there was a discussion about the age of the Messenger of Allah (ﷺ). Some of the persons said: Abu Bakr was older than Allah's Messenger (ﷺ). 'Abdullah said: Allah's Messenger (ﷺ) died when he was sixty-three, and Abu Bakr died when he was sixty-three and so 'Umar fell as a martyr when he was sixty-three. A person from the people who was called 'Amir b. Sa'd reported that Jabir had said: We were sitting with Mu'awiya that there was a discussion about the age of Allah's Messenger (ﷺ). Thereupon Mu'awiya said: Allah's Messenger (ﷺ) died when he had attained the age of sixty-three, and Abu Bakr died when he had attained the age of sixty-three, and Umar fell as a martyr when he had attained the age of sixty-three}}
\hadithdefcmd{muslim}{6099}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ، جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، سَمِعْتُ أَبَا إِسْحَاقَ، يُحَدِّثُ عَنْ عَامِرِ بْنِ سَعْدٍ الْبَجَلِيِّ، عَنْ جَرِيرٍ، أَنَّهُ سَمِعَ مُعَاوِيَةَ، يَخْطُبُ فَقَالَ مَاتَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ ابْنُ ثَلاَثٍ وَسِتِّينَ وَأَبُو بَكْرٍ وَعُمَرُ وَأَنَا ابْنُ ثَلاَثٍ وَسِتِّينَ ‏.‏\hadithno{6099}\hadithtrans{Jabir reported that he heard Mu'awiya say in his address that Allah's Messenger (ﷺ) died at the age of sixty-three, so was the case with Abu Bakr and 'Umar, and I (am now) sixty-three}}
\hadithdefcmd{muslim}{6100}{وَحَدَّثَنِي ابْنُ مِنْهَالٍ الضَّرِيرُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا يُونُسُ بْنُ عُبَيْدٍ، عَنْ عَمَّارٍ، مَوْلَى بَنِي هَاشِمٍ قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ كَمْ أَتَى لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ مَاتَ فَقَالَ مَا كُنْتُ أَحْسِبُ مِثْلَكَ مِنْ قَوْمِهِ يَخْفَى عَلَيْهِ ذَاكَ - قَالَ - قُلْتُ إِنِّي قَدْ سَأَلْتُ النَّاسَ فَاخْتَلَفُوا عَلَىَّ فَأَحْبَبْتُ أَنْ أَعْلَمَ قَوْلَكَ فِيهِ ‏.‏ قَالَ أَتَحْسُبُ قَالَ قُلْتُ نَعَمْ ‏.‏ قَالَ أَمْسِكْ أَرْبَعِينَ بُعِثَ لَهَا خَمْسَ عَشْرَةَ بِمَكَّةَ يَأْمَنُ وَيَخَافُ وَعَشْرَ مِنْ مُهَاجَرِهِ إِلَى الْمَدِينَةِ ‏.‏\hadithno{6100}\hadithtrans{Ammar, the freed slave of Banu Hashim, reported:I asked Ibn 'Abbas how old was he when death overtook the Messenger of Allah (ﷺ). He said: I little know that such a thing is not known to a man like you who belong to his people. He said: I asked people about it but they differed with me, and I liked to know your opinion about it. He said: Do you know counting? He said: Yes. He then said: Bear this in mind very well that he was commissioned (as a Prophet) at the age of forty, and he stayed in Mecca for fifteen years; sometime in peace and sometime in dread, and (lived) for ten years after his migration to Medina}}
\hadithdefcmd{muslim}{6101}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ، حَدَّثَنَا شُعْبَةُ، عَنْ يُونُسَ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ يَزِيدَ بْنِ زُرَيْعٍ ‏.‏\hadithno{6101}\hadithtrans{This hadith has been narrated on the authority of Yunus with the same chain of transmitters}}
\hadithdefcmd{muslim}{6102}{وَحَدَّثَنِي نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ مُفَضَّلٍ - حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، حَدَّثَنَا عَمَّارٌ، مَوْلَى بَنِي هَاشِمٍ حَدَّثَنَا ابْنُ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تُوُفِّيَ وَهُوَ ابْنُ خَمْسٍ وَسِتِّينَ ‏.‏\hadithno{6102}\hadithtrans{Ammar, the freed slave of Banu Hashim, reported that Ibn 'Abbas said that Allah's Messenger (ﷺ) died when he had attained the age of sixty-five}}
\hadithdefcmd{muslim}{6103}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ خَالِدٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6103}\hadithtrans{This hadith has been narrated on the authority of Khalid with the same chain of transmitters}}
\hadithdefcmd{muslim}{6104}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا رَوْحٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَمَّارِ بْنِ أَبِي عَمَّارٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَكَّةَ خَمْسَ عَشْرَةَ سَنَةً يَسْمَعُ الصَّوْتَ وَيَرَى الضَّوْءَ سَبْعَ سِنِينَ وَلاَ يَرَى شَيْئًا وَثَمَانَ سِنِينَ يُوحَى إِلَيْهِ وَأَقَامَ بِالْمَدِينَةِ عَشْرًا ‏.‏\hadithno{6104}\hadithtrans{Ibn 'Abbas reported that Allah's Messenger (ﷺ) stayed in Mecca for fifteen years (after his advent as a Prophet) and he heard the voice of Gabriel and saw his radiance for seven years but did not see any visible form, and then received revelation for ten years, and he stayed in Medina for ten years}}
\hadithdefcmd{muslim}{6105}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، سَمِعَ مُحَمَّدَ، بْنَ جُبَيْرِ بْنِ مُطْعِمٍ عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَنَا مُحَمَّدٌ وَأَنَا أَحْمَدُ وَأَنَا الْمَاحِي الَّذِي يُمْحَى بِيَ الْكُفْرُ وَأَنَا الْحَاشِرُ الَّذِي يُحْشَرُ النَّاسُ عَلَى عَقِبِي وَأَنَا الْعَاقِبُ ‏"‏ ‏.‏ وَالْعَاقِبُ الَّذِي لَيْسَ بَعْدَهُ نَبِيُّ ‏.‏\hadithno{6105}\hadithtrans{Jubair b. Mut'im reported on the authority of his father that he heard Allah's Messenger (ﷺ) as saying:I am Muhammad and I am Ahmad, and I am al-Mahi (the obliterator) by whom unbelief would be obliterated, and I am Hashir (the gatherer) at whose feet mankind will be gathered, and I am 'Aqib (the last to come) after whom there will be no Prophet}}
\hadithdefcmd{muslim}{6106}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ لِي أَسْمَاءً أَنَا مُحَمَّدٌ وَأَنَا أَحْمَدُ وَأَنَا الْمَاحِي الَّذِي يَمْحُو اللَّهُ بِيَ الْكُفْرَ وَأَنَا الْحَاشِرُ الَّذِي يُحْشَرُ النَّاسُ عَلَى قَدَمَىَّ وَأَنَا الْعَاقِبُ الَّذِي لَيْسَ بَعْدَهُ أَحَدٌ ‏"‏ ‏.‏ وَقَدْ سَمَّاهُ اللَّهُ رَءُوفًا رَحِيمًا ‏.‏\hadithno{6106}\hadithtrans{Jubair b. Mut'im reported on the authority of his father that he heard Allah's Messenger (ﷺ) as saying:I have many names: I am Muhammad, I am Ahmad, I am al-Mahi through whom Allah obliterates unbelief, and I am Hashir (the gatherer) at whose feet people will be gathered, and I am 'Aqib (after whom there would be none), and Allah has named him as compassionate and merciful}}
\hadithdefcmd{muslim}{6107}{وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، قَالَ حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلٌ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ، الرَّحْمَنِ الدَّارِمِيُّ أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِ شُعَيْبٍ وَمَعْمَرٍ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ وَفِي حَدِيثِ عُقَيْلٍ قَالَ قُلْتُ لِلزُّهْرِيِّ وَمَا الْعَاقِبُ قَالَ الَّذِي لَيْسَ بَعْدَهُ نَبِيٌّ ‏.‏ وَفِي حَدِيثِ مَعْمَرٍ وَعُقَيْلٍ الْكَفَرَةَ ‏.‏ وَفِي حَدِيثِ شُعَيْبٍ الْكُفْرَ ‏.‏\hadithno{6107}\hadithtrans{This hadith has been transmitted on the authority of Ma'mar (and the words are):I said to Zuhri: What does (the word) al-'Aqib imply? He said: One after whom there is no Prophet, and in the hadith transmitted on the authority of Ma'mar and 'Uqail there is a slight variation of wording}}
\hadithdefcmd{muslim}{6108}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو، بْنِ مُرَّةَ عَنْ أَبِي عُبَيْدَةَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُسَمِّي لَنَا نَفْسَهُ أَسْمَاءً فَقَالَ ‏ "‏ أَنَا مُحَمَّدٌ وَأَحْمَدُ وَالْمُقَفِّي وَالْحَاشِرُ وَنَبِيُّ التَّوْبَةِ وَنَبِيُّ الرَّحْمَةِ ‏"‏ ‏.‏\hadithno{6108}\hadithtrans{Abu Musa Ash'ari reported that Allah's Messenger (ﷺ) mentioned many names of his and said:I am Muhammad, Ahmad. Muqaffi (the last in succession), Hashir, the Prophet of repentance, and the Prophet of Mercy}}
\hadithdefcmd{muslim}{6109}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَمْرًا فَتَرَخَّصَ فِيهِ فَبَلَغَ ذَلِكَ نَاسًا مِنْ أَصْحَابِهِ فَكَأَنَّهُمْ كَرِهُوهُ وَتَنَزَّهُوا عَنْهُ فَبَلَغَهُ ذَلِكَ فَقَامَ خَطِيبًا فَقَالَ ‏ "‏ مَا بَالُ رِجَالٍ بَلَغَهُمْ عَنِّي أَمْرٌ تَرَخَّصْتُ فِيهِ فَكَرِهُوهُ وَتَنَزَّهُوا عَنْهُ فَوَاللَّهِ لأَنَا أَعْلَمُهُمْ بِاللَّهِ وَأَشَدُّهُمْ لَهُ خَشْيَةً ‏"‏ ‏.‏\hadithno{6109}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) did an act, and held it to be valid. This news reached some persons amongst his Companions (and it was felt) that they did not approve of it and avoided (it). This reaction of theirs was conveyed to him. He stood to deliver an address; and said:What has happened to the people to whom there was conveyed on my behalf a matter for which I granted permission and they disapproved it and avoided it? By Allah, I have the best knowledge of Allah amongst them, and I fear Him most amongst them}}
\hadithdefcmd{muslim}{6110}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا حَفْصٌ يَعْنِي ابْنَ غِيَاثٍ، ح وَحَدَّثَنَاهُ إِسْحَاقُ، بْنُ إِبْرَاهِيمَ وَعَلِيُّ بْنُ خَشْرَمٍ قَالاَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِإِسْنَادِ جَرِيرٍ نَحْوَ حَدِيثِهِ ‏.‏\hadithno{6110}\hadithtrans{This hadith has been narrated on the authority of A'mash through a different chain of transmitters}}
\hadithdefcmd{muslim}{6111}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ رَخَّصَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي أَمْرٍ فَتَنَزَّهَ عَنْهُ نَاسٌ مِنَ النَّاسِ فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم فَغَضِبَ حَتَّى بَانَ الْغَضَبُ فِي وَجْهِهِ ثُمَّ قَالَ ‏ "‏ مَا بَالُ أَقْوَامٍ يَرْغَبُونَ عَمَّا رُخِّصَ لِي فِيهِ فَوَاللَّهِ لأَنَا أَعْلَمُهُمْ بِاللَّهِ وَأَشَدُّهُمْ لَهُ خَشْيَةً ‏"‏ ‏.‏\hadithno{6111}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) granted permission for doing a thing, but some persons amongst the people avoided it. This was conveyed to Allah's Apostle (ﷺ), and he was so much annoyed that the sign of his anger appeared on his face. He then said:What has happened to the people that they avoid that for which permission has been granted to me? By Allah, I have the best knowledge of Allah amongst them, and fear Him most amongst them}}
\hadithdefcmd{muslim}{6112}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، حَدَّثَهُ أَنَّ رَجُلاً مِنَ الأَنْصَارِ خَاصَمَ الزُّبَيْرَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي شِرَاجِ الْحَرَّةِ الَّتِي يَسْقُونَ بِهَا النَّخْلَ فَقَالَ الأَنْصَارِيُّ سَرِّحِ الْمَاءَ ‏.‏ يَمُرُّ فَأَبَى عَلَيْهِمْ فَاخْتَصَمُوا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلزُّبَيْرِ ‏"‏ اسْقِ يَا زُبَيْرُ ثُمَّ أَرْسِلِ الْمَاءَ إِلَى جَارِكَ ‏"‏ ‏.‏ فَغَضِبَ الأَنْصَارِيُّ فَقَالَ يَا رَسُولَ اللَّهِ أَنْ كَانَ ابْنَ عَمَّتِكَ فَتَلَوَّنَ وَجْهُ نَبِيِّ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ يَا زُبَيْرُ اسْقِ ثُمَّ احْبِسِ الْمَاءَ حَتَّى يَرْجِعَ إِلَى الْجَدْرِ ‏"‏ ‏.‏ فَقَالَ الزُّبَيْرُ وَاللَّهِ إِنِّي لأَحْسِبُ هَذِهِ الآيَةَ نَزَلَتْ فِي ذَلِكَ ‏\{‏ فَلاَ وَرَبِّكَ لاَ يُؤْمِنُونَ حَتَّى يُحَكِّمُوكَ فِيمَا شَجَرَ بَيْنَهُمْ ثُمَّ لاَ يَجِدُوا فِي أَنْفُسِهِمْ حَرَجًا‏\}‏\hadithno{6112}\hadithtrans{Urwa b. Zubair reported that 'Abdullah b. Zubair had narrated to him that a person from the Ansar disputed with Zubair in the presence of Allah's Messenger (ﷺ) in regard to the watering places of Harra from which they watered the date-palms. The Ansari said:Let the water flow, but he (Zubair) refused to do this and the dispute was brought to Allah's Messenger (ﷺ) and he said to Zubair: Zubair, water (your date-palms), then let the water flow to your neighbor. The Ansari was enraged and said: Allah's Messenger, (you have given this decision) for he is the son of your father's sister. The face of Allah's Apostle (ﷺ) underwent a change, and then said: Zubair, water (your date-palms), then hold it until it rises up to the walls. Zubair said: I think, by Allah, that this verse:" Nay, by the Lord, they will not (really) (believe) until they make thee a judge of what is in dispute among them, and find in this no dislike of what thou decidest and submit with full submission" (iv)}}
\hadithdefcmd{muslim}{6113}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، وَسَعِيدُ بْنُ الْمُسَيَّبِ، قَالاَ كَانَ أَبُو هُرَيْرَةَ يُحَدِّثُ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا نَهَيْتُكُمْ عَنْهُ فَاجْتَنِبُوهُ وَمَا أَمَرْتُكُمْ بِهِ فَافْعَلُوا مِنْهُ مَا اسْتَطَعْتُمْ فَإِنَّمَا أَهْلَكَ الَّذِينَ مِنْ قَبْلِكُمْ كَثْرَةُ مَسَائِلِهِمْ وَاخْتِلاَفُهُمْ عَلَى أَنْبِيَائِهِمْ ‏"‏ ‏.‏\hadithno{6113}\hadithtrans{Abu Huraira reported that he heard Allah's Messenger (ﷺ) as saying:Avoid that which I forbid you to do and do that which I command you to do to the best of your capacity. Verily the people before you went to their doom because they had put too many questions to their Prophets and then disagreed with their teachings}}
\hadithdefcmd{muslim}{6114}{وَحَدَّثَنِي مُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ، حَدَّثَنَا أَبُو سَلَمَةَ، - وَهُوَ مَنْصُورُ بْنُ سَلَمَةَ الْخُزَاعِيُّ - أَخْبَرَنَا لَيْثٌ، عَنْ يَزِيدَ بْنِ الْهَادِ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ سَوَاءً ‏.‏\hadithno{6114}\hadithtrans{This hadith has been narrated on the authority of Ibn Shihab with the same chain of transmitters}}
\hadithdefcmd{muslim}{6115}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا ابْنُ، نُمَيْرٍ حَدَّثَنَا أَبِي كِلاَهُمَا، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ يَعْنِي الْحِزَامِيَّ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، كِلاَهُمَا عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، ح وَحَدَّثَنَاهُ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، سَمِعَ أَبَا هُرَيْرَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، كُلُّهُمْ قَالَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ ذَرُونِي مَا تَرَكْتُكُمْ ‏"‏ ‏.‏ وَفِي حَدِيثِ هَمَّامٍ ‏"‏ مَا تُرِكْتُمْ فَإِنَّمَا هَلَكَ مَنْ كَانَ قَبْلَكُمْ ‏"‏ ‏.‏ ثُمَّ ذَكَرُوا نَحْوَ حَدِيثِ الزُّهْرِيِّ عَنْ سَعِيدٍ وَأَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{6115}\hadithtrans{This hadith has been narrated by Abu Huraira through a different chain of transmitters (and the words are) that he reported Allah's Messenger (ﷺ) having said:Abandon that which I have asked you to abandon, for the people before you went to their doom (for asking too many questions)}}
\hadithdefcmd{muslim}{6116}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَامِرِ بْنِ، سَعْدٍ عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَعْظَمَ الْمُسْلِمِينَ فِي الْمُسْلِمِينَ جُرْمًا مَنْ سَأَلَ عَنْ شَىْءٍ لَمْ يُحَرَّمْ عَلَى الْمُسْلِمِينَ فَحُرِّمَ عَلَيْهِمْ مِنْ أَجْلِ مَسْأَلَتِهِ ‏"‏ ‏.‏\hadithno{6116}\hadithtrans{Amir b. Sa'd reported on the authority of his father that Allah's Messenger (ﷺ) said:The greatest sinner amongst the Muslims is one who asked about a thing (from Allah's Apostle) which had not been forbidden for the Muslims and it was forbidden for them because of his persistently asking about it}}
\hadithdefcmd{muslim}{6117}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا سُفْيَانُ، قَالَ - أَحْفَظُهُ كَمَا أَحْفَظُ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ - الزُّهْرِيُّ عَنْ عَامِرِ بْنِ سَعْدٍ عَنْ أَبِيهِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَعْظَمُ الْمُسْلِمِينَ فِي الْمُسْلِمِينَ جُرْمًا مَنْ سَأَلَ عَنْ أَمْرٍ لَمْ يُحَرَّمْ فَحُرِّمَ عَلَى النَّاسِ مِنْ أَجْلِ مَسْأَلَتِهِ ‏"‏ ‏.‏\hadithno{6117}\hadithtrans{This hadith has been transmitted on the authority of 'Amir b. Sa'd and the words are. Allah's Messenger (ﷺ) said:The greatest sinner of the Muslims amongst Muslims is one who asked about a certain thing which had not been prohibited and it was prohibited because of his asking about it}}
\hadithdefcmd{muslim}{6118}{وَحَدَّثَنِيهِ حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا عَبْدُ بْنُ، حُمَيْدٍ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ وَزَادَ فِي حَدِيثِ مَعْمَرٍ ‏ "‏ رَجُلٌ سَأَلَ عَنْ شَىْءٍ وَنَقَّرَ عَنْهُ ‏"‏ ‏.‏ وَقَالَ فِي حَدِيثِ يُونُسَ عَامِرِ بْنِ سَعْدٍ أَنَّهُ سَمِعَ سَعْدًا ‏.‏\hadithno{6118}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters and with this addition:" A person asked about a thing from Allah's Apostle (ﷺ) and he indulged in hair-splitting}}
\hadithdefcmd{muslim}{6119}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، وَمُحَمَّدُ بْنُ قُدَامَةَ السُّلَمِيُّ، وَيَحْيَى بْنُ مُحَمَّدٍ اللُّؤْلُؤِيُّ، - وَأَلْفَاظُهُمْ مُتَقَارِبَةٌ قَالَ مَحْمُودٌ حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، وَقَالَ الآخَرَانِ، أَخْبَرَنَا النَّضْرُ، - أَخْبَرَنَا شُعْبَةُ، حَدَّثَنَا مُوسَى بْنُ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ بَلَغَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ أَصْحَابِهِ شَىْءٌ فَخَطَبَ فَقَالَ ‏"‏ عُرِضَتْ عَلَىَّ الْجَنَّةُ وَالنَّارُ فَلَمْ أَرَ كَالْيَوْمِ فِي الْخَيْرِ وَالشَّرِّ وَلَوْ تَعْلَمُونَ مَا أَعْلَمُ لَضَحِكْتُمْ قَلِيلاً وَلَبَكَيْتُمْ كَثِيرًا ‏"‏ ‏.‏ قَالَ فَمَا أَتَى عَلَى أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمٌ أَشَدُّ مِنْهُ - قَالَ - غَطَّوْا رُءُوسَهُمْ وَلَهُمْ خَنِينٌ - قَالَ - فَقَامَ عُمَرُ فَقَالَ رَضِينَا بِاللَّهِ رَبًّا وَبِالإِسْلاَمِ دِينًا وَبِمُحَمَّدٍ نَبِيًّا - قَالَ - فَقَامَ ذَاكَ الرَّجُلُ فَقَالَ مَنْ أَبِي قَالَ ‏"‏ أَبُوكَ فُلاَنٌ ‏"‏ ‏.‏ فَنَزَلَتْ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَسْأَلُوا عَنْ أَشْيَاءَ إِنْ تُبْدَ لَكُمْ تَسُؤْكُمْ‏\}‏\hadithno{6119}\hadithtrans{Anas b. Malik reported that something was conveyed to him (the Holy prophet) about his Companions, so he addressed them and said:Paradise and Hell were presented to me and I have never seen the good and evil as (I did) today. And if you were to know you would have wept more and laughed less. He (the narrator) said: There was nothing more burdensome for the Companions of Allah's Messenger (ﷺ) than this. They covered their heads and the sound of weeping was heard from them. Then there stood up 'Umar and he said: We are well pleased with Allah as our Lord, with Islam as our code of life and with Muhammad as our Apostle, and it was at that time that a person stood up and he said: Who is my father? Thereupon he (the Holy Prophet) said: Your father is so and so; and there was revealed the verse:" O you who believe, do not ask about matters which, if they were to be made manifest to you (in terms of law), might cause to you harm" (v)}}
\hadithdefcmd{muslim}{6120}{وَحَدَّثَنَا مُحَمَّدُ بْنُ مَعْمَرِ بْنِ رِبْعِيٍّ الْقَيْسِيُّ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي مُوسَى بْنُ أَنَسٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ مَنْ أَبِي قَالَ ‏"‏ أَبُوكَ فُلاَنٌ ‏"‏ ‏.‏ وَنَزَلَتْ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَسْأَلُوا عَنْ أَشْيَاءَ إِنْ تُبْدَ لَكُمْ تَسُؤْكُمْ‏\}‏ تَمَامَ الآيَةِ ‏.‏\hadithno{6120}\hadithtrans{Anas b. Malik reported that a person said:Allah's Messenger, who is my father? And he said: Your father is so and so, and there was revealed this verse:" Do not ask about matters which, if they were to be made manifest to you, might cause you harm" (v)}}
\hadithdefcmd{muslim}{6121}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ حَرْمَلَةَ بْنِ عِمْرَانَ التُّجِيبِيُّ، أَخْبَرَنَا ابْنُ، وَهْبٍ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ حِينَ زَاغَتِ الشَّمْسُ فَصَلَّى لَهُمْ صَلاَةَ الظُّهْرِ فَلَمَّا سَلَّمَ قَامَ عَلَى الْمِنْبَرِ فَذَكَرَ السَّاعَةَ وَذَكَرَ أَنَّ قَبْلَهَا أُمُورًا عِظَامًا ثُمَّ قَالَ ‏"‏ مَنْ أَحَبَّ أَنْ يَسْأَلَنِي عَنْ شَىْءٍ فَلْيَسْأَلْنِي عَنْهُ فَوَاللَّهِ لاَ تَسْأَلُونَنِي عَنْ شَىْءٍ إِلاَّ أَخْبَرْتُكُمْ بِهِ مَا دُمْتُ فِي مَقَامِي هَذَا ‏"‏ ‏.‏ قَالَ أَنَسُ بْنُ مَالِكٍ فَأَكْثَرَ النَّاسُ الْبُكَاءَ حِينَ سَمِعُوا ذَلِكَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَكْثَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَقُولَ ‏"‏ سَلُونِي ‏"‏ ‏.‏ فَقَامَ عَبْدُ اللَّهِ بْنُ حُذَافَةَ فَقَالَ مَنْ أَبِي يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أَبُوكَ حُذَافَةُ ‏"‏ ‏.‏ فَلَمَّا أَكْثَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ أَنْ يَقُولَ ‏"‏ سَلُونِي ‏"‏ ‏.‏ بَرَكَ عُمَرُ فَقَالَ رَضِينَا بِاللَّهِ رَبًّا وَبِالإِسْلاَمِ دِينًا وَبِمُحَمَّدٍ رَسُولاً - قَالَ - فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ قَالَ عُمَرُ ذَلِكَ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَوْلَى وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَقَدْ عُرِضَتْ عَلَىَّ الْجَنَّةُ وَالنَّارُ آنِفًا فِي عُرْضِ هَذَا الْحَائِطِ فَلَمْ أَرَ كَالْيَوْمِ فِي الْخَيْرِ وَالشَّرِّ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ قَالَ قَالَتْ أُمُّ عَبْدِ اللَّهِ بْنِ حُذَافَةَ لِعَبْدِ اللَّهِ بْنِ حُذَافَةَ مَا سَمِعْتُ بِابْنٍ قَطُّ أَعَقَّ مِنْكَ أَأَمِنْتَ أَنْ تَكُونَ أُمُّكَ قَدْ قَارَفَتْ بَعْضَ مَا تُقَارِفُ نِسَاءُ أَهْلِ الْجَاهِلِيَّةِ فَتَفْضَحَهَا عَلَى أَعْيُنِ النَّاسِ قَالَ عَبْدُ اللَّهِ بْنُ حُذَافَةَ وَاللَّهِ لَوْ أَلْحَقَنِي بِعَبْدٍ أَسْوَدَ لَلَحِقْتُهُ ‏.‏\hadithno{6121}\hadithtrans{Anas b. Malik reported that Allah's Messenger (may peace be upon him stood when the sun had passed the meridian and he led them noon prayer and after observing salutations (completing the prayer) he stood upon the pulpit and talked about the Last Hour and made a mention of the important facts prior to it and then said:He who desires to ask anything from me let him ask me about it. By Allah, I shall not move from this place so long as I do not inform you about that which you ask. Anas b. Malik said: People began to shed tears profusely when they heard this from Allah's Messenger (ﷺ) and Allah's Messenger (ﷺ) said it repeatedly: You ask me. Thereupon 'Abdullah b. Hudhafa stood up and said: Allah's Messenger, who is my father? He said: Your father is Hudhafa, and Allah's Messenger (ﷺ) said repeatedly: Ask me, and (it was at this juncture that 'Umar knelt down and said): We are well pleased with Allah as our Lord, with Islam as our code of life and with Muhammad as the Messenger (of Allah). Allah's Messenger (ﷺ) kept quiet so long as 'Umar spoke. Then Allah's Messenger (ﷺ) said: (The Doom) is near; by Him, in Whose Hand is the life of Muhammad, there was presented to me the Paradise and Hell in the nook of this enclosure, and I did not see good and evil like that of the present day. Ibn Shihab reported: Ubaidullah b. 'Abdullah b. 'Utba told me that the mother of 'Abdullah b. Hudhafa told 'Abdullah b. Hudhafa: I have never heard of a son more disobedient than you. Do you feel yourself immune from the fact that your mother committed a sin which the women in the pre-Islamic period committed and then you disgrace her in the eyes of the people? 'Abdullah b. Hudhafa said: If my fatherhood were to be attributed to a black slave I would have connected myself with him}}
\hadithdefcmd{muslim}{6122}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ، عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ وَحَدِيثِ عُبَيْدِ اللَّهِ مَعَهُ غَيْرَ أَنَّ شُعَيْبًا قَالَ عَنِ الزُّهْرِيِّ قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ قَالَ حَدَّثَنِي رَجُلٌ مِنْ أَهْلِ الْعِلْمِ أَنَّ أُمَّ عَبْدِ اللَّهِ بْنِ حُذَافَةَ قَالَتْ بِمِثْلِ حَدِيثِ يُونُسَ ‏.‏\hadithno{6122}\hadithtrans{This hadith has been transmitted on the authority of Zuhri with a slight variation of wording}}
\hadithdefcmd{muslim}{6123}{حَدَّثَنَا يُوسُفُ بْنُ حَمَّادٍ الْمَعْنِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّاسَ، سَأَلُوا نَبِيَّ اللَّهِ صلى الله عليه وسلم حَتَّى أَحْفَوْهُ بِالْمَسْأَلَةِ فَخَرَجَ ذَاتَ يَوْمٍ فَصَعِدَ الْمِنْبَرَ فَقَالَ ‏"‏ سَلُونِي لاَ تَسْأَلُونِي عَنْ شَىْءٍ إِلاَّ بَيَّنْتُهُ لَكُمْ ‏"‏ ‏.‏ فَلَمَّا سَمِعَ ذَلِكَ الْقَوْمُ أَرَمُّوا وَرَهِبُوا أَنْ يَكُونَ بَيْنَ يَدَىْ أَمْرٍ قَدْ حَضَرَ ‏.‏ قَالَ أَنَسٌ فَجَعَلْتُ أَلْتَفِتُ يَمِينًا وَشِمَالاً فَإِذَا كُلُّ رَجُلٍ لاَفٌّ رَأْسَهُ فِي ثَوْبِهِ يَبْكِي فَأَنْشَأَ رَجُلٌ مِنَ الْمَسْجِدِ كَانَ يُلاَحَى فَيُدْعَى لِغَيْرِ أَبِيهِ فَقَالَ يَا نَبِيَّ اللَّهِ مَنْ أَبِي قَالَ ‏"‏ أَبُوكَ حُذَافَةُ ‏"‏ ‏.‏ ثُمَّ أَنْشَأَ عُمَرُ بْنُ الْخَطَّابِ رضى الله عنه فَقَالَ رَضِينَا بِاللَّهِ رَبًّا وَبِالإِسْلاَمِ دِينًا وَبِمُحَمَّدٍ رَسُولاً عَائِذًا بِاللَّهِ مِنْ سُوءِ الْفِتَنِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَمْ أَرَ كَالْيَوْمِ قَطُّ فِي الْخَيْرِ وَالشَّرِّ إِنِّي صُوِّرَتْ لِيَ الْجَنَّةُ وَالنَّارُ فَرَأَيْتُهُمَا دُونَ هَذَا الْحَائِطِ ‏"‏ ‏.‏\hadithno{6123}\hadithtrans{Anas b. Malik reported that the people asked Allah's Apostle (ﷺ) until he was hard pressed. He went out one day and he occupied the pulpit and said:Ask me and I shall leave no question of yours unanswered for you, and when the people heard about it they were overawed, as if (something tragic) was going to happen. Anas said: I began to look towards the right and the left and (found) that every person was weeping wrapping his head with the cloth. Then a person in the mosque broke the ice and they used to dispute with him by attributing his fatherhood to another man than his own father. He said: Allah's Apostle, who is my father? He said: Your father is Hudhafa. Then 'Umar b. Khattab (Allah be pleased with him) dared say something and said: We are well pleased with Allah as our Lord, with Islam as our code of life and with Muhammad as our Messenger, seeking refuge with Allah from the evil of Turmoil. Thereupon Allah's Messenger (ﷺ) said: Never did I see the good and evil as today. Paradise and Hell were given a visible shape before me (in this worldly life) and I saw both of them near this well}}
\hadithdefcmd{muslim}{6124}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ يَعْنِي ابْنَ الْحَارِثِ، ح وَحَدَّثَنَا مُحَمَّدُ، بْنُ بَشَّارٍ حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عَدِيٍّ، كِلاَهُمَا عَنْ هِشَامٍ، ح وَحَدَّثَنَا عَاصِمُ بْنُ النَّضْرِ التَّيْمِيُّ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي قَالاَ، جَمِيعًا حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، بِهَذِهِ الْقِصَّةِ ‏.‏\hadithno{6124}\hadithtrans{This hadith has been transmitted on the authority of Qatada}}
\hadithdefcmd{muslim}{6125}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَرَّادٍ الأَشْعَرِيُّ، وَمُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنْ أَشْيَاءَ كَرِهَهَا فَلَمَّا أُكْثِرَ عَلَيْهِ غَضِبَ ثُمَّ قَالَ لِلنَّاسِ ‏"‏ سَلُونِي عَمَّ شِئْتُمْ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مَنْ أَبِي قَالَ ‏"‏ أَبُوكَ حُذَافَةُ ‏"‏ ‏.‏ فَقَامَ آخَرُ فَقَالَ مَنْ أَبِي يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أَبُوكَ سَالِمٌ مَوْلَى شَيْبَةَ ‏"‏ ‏.‏ فَلَمَّا رَأَى عُمَرُ مَا فِي وَجْهِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْغَضَبِ قَالَ يَا رَسُولَ اللَّهِ إِنَّا نَتُوبُ إِلَى اللَّهِ ‏.‏ وَفِي رِوَايَةِ أَبِي كُرَيْبٍ قَالَ مَنْ أَبِي يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أَبُوكَ سَالِمٌ مَوْلَى شَيْبَةَ ‏"‏ ‏.‏\hadithno{6125}\hadithtrans{Abu Musa reported that Allah's Apostle (ﷺ) was asked such things which he disapproved and when they persisted on asking him he felt enraged and then said to the people:Ask me what you wish to ask. Thereupon a person said: Who is my father? He said: Your father is Hudhafa. Then another person stood up and said: Allah's Messenger, who is my father? He said: Your father is Salim, the freed slave of Shaiba. When 'Umar saw the signs of anger upon the face of Allah's Apostle (ﷺ), he said: Allah's Messenger, we ask repentance from Allah. And in the hadith transmitted on the authority of Abu Kuraib (the words are):" Allah's Messenger, who is my father? He said: Your father is Salim, the freed slave of Shaiba}}
\hadithdefcmd{muslim}{6126}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ الثَّقَفِيُّ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ - وَتَقَارَبَا فِي اللَّفْظِ وَهَذَا حَدِيثُ قُتَيْبَةَ - قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ عَنْ سِمَاكٍ عَنْ مُوسَى بْنِ طَلْحَةَ عَنْ أَبِيهِ قَالَ مَرَرْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِقَوْمٍ عَلَى رُءُوسِ النَّخْلِ فَقَالَ ‏"‏ مَا يَصْنَعُ هَؤُلاَءِ ‏"‏ ‏.‏ فَقَالُوا يُلَقِّحُونَهُ يَجْعَلُونَ الذَّكَرَ فِي الأُنْثَى فَيَلْقَحُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا أَظُنُّ يُغْنِي ذَلِكَ شَيْئًا ‏"‏ ‏.‏ قَالَ فَأُخْبِرُوا بِذَلِكَ فَتَرَكُوهُ فَأُخْبِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِذَلِكَ فَقَالَ ‏"‏ إِنْ كَانَ يَنْفَعُهُمْ ذَلِكَ فَلْيَصْنَعُوهُ فَإِنِّي إِنَّمَا ظَنَنْتُ ظَنًّا فَلاَ تُؤَاخِذُونِي بِالظَّنِّ وَلَكِنْ إِذَا حَدَّثْتُكُمْ عَنِ اللَّهِ شَيْئًا فَخُذُوا بِهِ فَإِنِّي لَنْ أَكْذِبَ عَلَى اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{6126}\hadithtrans{Musa b. Talha reported:I and Allah's Messenger (ﷺ) happened to pass by people near the date-palm trees. He (the Holy Prophet) said: What are these people doing? They said: They are grafting, i. e. they combine the male with the female (tree) and thus they yield more fruit. Thereupon Allah's Messenger (ﷺ) said: I do not find it to be of any use. The people were informed about it and they abandoned this practice. Allah's Messenger (ﷺ) (was later) on informed (that the yield had dwindled), whereupon he said: If there is any use of it, then they should do it, for it was just a personal opinion of mine, and do not go after my personal opinion; but when I say to you anything on behalf of Allah, then do accept it, for I do not attribute lie to Allah, the Exalted and Glorious}}
\hadithdefcmd{muslim}{6127}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الرُّومِيِّ الْيَمَامِيُّ، وَعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، وَأَحْمَدُ بْنُ، جَعْفَرٍ الْمَعْقِرِيُّ قَالُوا حَدَّثَنَا النَّضْرُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عِكْرِمَةُ، - وَهُوَ ابْنُ عَمَّارٍ - حَدَّثَنَا أَبُو النَّجَاشِيِّ، حَدَّثَنِي رَافِعُ بْنُ خَدِيجٍ، قَالَ قَدِمَ نَبِيُّ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ وَهُمْ يَأْبُرُونَ النَّخْلَ يَقُولُونَ يُلَقِّحُونَ النَّخْلَ فَقَالَ ‏"‏ مَا تَصْنَعُونَ ‏"‏ ‏.‏ قَالُوا كُنَّا نَصْنَعُهُ قَالَ ‏"‏ لَعَلَّكُمْ لَوْ لَمْ تَفْعَلُوا كَانَ خَيْرًا ‏"‏ ‏.‏ فَتَرَكُوهُ فَنَفَضَتْ أَوْ فَنَقَصَتْ - قَالَ - فَذَكَرُوا ذَلِكَ لَهُ فَقَالَ ‏"‏ إِنَّمَا أَنَا بَشَرٌ إِذَا أَمَرْتُكُمْ بِشَىْءٍ مِنْ دِينِكُمْ فَخُذُوا بِهِ وَإِذَا أَمَرْتُكُمْ بِشَىْءٍ مِنْ رَأْىٍ فَإِنَّمَا أَنَا بَشَرٌ ‏"‏ ‏.‏ قَالَ عِكْرِمَةُ أَوْ نَحْوَ هَذَا ‏.‏ قَالَ الْمَعْقِرِيُّ فَنَفَضَتْ ‏.‏ وَلَمْ يَشُكَّ ‏.‏\hadithno{6127}\hadithtrans{Rafi' b. Khadij reported that Allah's Messenger (ﷺ) came to Medina and the people had been grafting the trees. He said:What are you doing? They said: We are grafting them, whereupon he said: It may perhaps be good for you if you do not do that, so they abandoned this practice (and the date-palms) began to yield less fruit. They made a mention of it (to the Holy Prophet), whereupon he said: I am a human being, so when I command you about a thing pertaining to religion, do accept it, and when I command you about a thing out of my personal opinion, keep it in mind that I am a human being. 'Ikrima reported that he said something like this}}
\hadithdefcmd{muslim}{6128}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، كِلاَهُمَا عَنِ الأَسْوَدِ بْنِ عَامِرٍ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا أَسْوَدُ بْنُ عَامِرٍ، - حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، وَعَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ بِقَوْمٍ يُلَقِّحُونَ فَقَالَ ‏"‏ لَوْ لَمْ تَفْعَلُوا لَصَلُحَ ‏"‏ ‏.‏ قَالَ فَخَرَجَ شِيصًا فَمَرَّ بِهِمْ فَقَالَ ‏"‏ مَا لِنَخْلِكُمْ ‏"‏ ‏.‏ قَالُوا قُلْتَ كَذَا وَكَذَا قَالَ ‏"‏ أَنْتُمْ أَعْلَمُ بِأَمْرِ دُنْيَاكُمْ ‏"‏ ‏.‏\hadithno{6128}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) happened to pass by the people who had been busy in grafting the trees. Thereupon he said:If you were not to do it, it might be good for you. (So they abandoned this practice) and there was a decline in the yield. He (the Holy Prophet) happened to pass by them (and said): What has gone wrong with your trees? They said: You said so and so. Thereupon he said: You have better knowledge (of a technical skill) in the affairs of the world}}
\hadithdefcmd{muslim}{6129}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسُ مُحَمَّدٍ فِي يَدِهِ لَيَأْتِيَنَّ عَلَى أَحَدِكُمْ يَوْمٌ وَلاَ يَرَانِي ثُمَّ لأَنْ يَرَانِي أَحَبُّ إِلَيْهِ مِنْ أَهْلِهِ وَمَالِهِ مَعَهُمْ ‏"‏ ‏.‏ قَالَ أَبُو إِسْحَاقَ الْمَعْنَى فِيهِ عِنْدِي لأَنْ يَرَانِي مَعَهُمْ أَحَبُّ إِلَيْهِ مِنْ أَهْلِهِ وَمَالِهِ وَهُوَ عِنْدِي مُقَدَّمٌ وَمُؤَخَّرٌ ‏.‏\hadithno{6129}\hadithtrans{Abu Huraira reported so many 'ahadith from Allah's Messenger (ﷺ) and one among them was that Allah's Messenger (ﷺ) is reported to have said:By Him in Whose Hand is the life of Muhammad, a day would come to you when you would not be able to see me, and the glimpse of my face would be dearer to one than one's own family, one's property and in fact everything. This hadith has been transmitted on the authority of Ishaq with a slight variation of wording}}
\hadithdefcmd{muslim}{6130}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّأَخْبَرَهُ أَنَّ أَبَا هُرَيْرَةَ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَنَا أَوْلَى النَّاسِ بِابْنِ مَرْيَمَ الأَنْبِيَاءُ أَوْلاَدُ عَلاَّتٍ وَلَيْسَ بَيْنِي وَبَيْنَهُ نَبِيٌّ ‏"‏ ‏.‏\hadithno{6130}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:I am most akin to the son of Mary among the whole of mankind and the Prophets are of different mothers, but of one religion, and no Prophet was raised between me and him (Jesus Christ)}}
\hadithdefcmd{muslim}{6131}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو دَاوُدَ، عُمَرُ بْنُ سَعْدٍ عَنْ سُفْيَانَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَا أَوْلَى النَّاسِ بِعِيسَى الأَنْبِيَاءُ أَبْنَاءُ عَلاَّتٍ وَلَيْسَ بَيْنِي وَبَيْنَ عِيسَى نَبِيٌّ ‏"‏ ‏.‏\hadithno{6131}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:I am most akin to Jesus Christ among the whole of mankind, and all the Prophets are of different mothers but belong to one religion and no Prophet was raised between me and Jesus}}
\hadithdefcmd{muslim}{6132}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَنَا أَوْلَى النَّاسِ بِعِيسَى ابْنِ مَرْيَمَ فِي الأُولَى وَالآخِرَةِ ‏"‏ ‏.‏ قَالُوا كَيْفَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الأَنْبِيَاءُ إِخْوَةٌ مِنْ عَلاَّتٍ وَأُمَّهَاتُهُمْ شَتَّى وَدِينُهُمْ وَاحِدٌ فَلَيْسَ بَيْنَنَا نَبِيٌّ ‏"‏ ‏.‏\hadithno{6132}\hadithtrans{Abu Huraira reported many ahadith from Allah's Messenger (ﷺ) and one is that Allah's Messenger (ﷺ) said:I am most close to Jesus, son of Mary, among the whole of mankind in this worldly life and the next life. They said: Allah's Messenger how is it? Thereupon he said: Prophets are brothers in faith, having different mothers. Their religion is, however, one and there is no Apostle between us (between I and Jesus Christ)}}
\hadithdefcmd{muslim}{6133}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا مِنْ مَوْلُودٍ يُولَدُ إِلاَّ نَخَسَهُ الشَّيْطَانُ فَيَسْتَهِلُّ صَارِخًا مِنْ نَخْسَةِ الشَّيْطَانِ إِلاَّ ابْنَ مَرْيَمَ وَأُمَّهُ ‏"‏ ‏.‏ ثُمَّ قَالَ أَبُو هُرَيْرَةَ اقْرَءُوا إِنْ شِئْتُمْ ‏\{‏ وَإِنِّي أُعِيذُهَا بِكَ وَذُرِّيَّتَهَا مِنَ الشَّيْطَانِ الرَّجِيمِ‏\}‏\hadithno{6133}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:No child is born but he is pricked by the satan and he begins to weep because of the pricking of the satan except the son of Mary and his mother. Abu Huraira then said: You may recite if you so like (the verse):" I seek Thy protection for her and her offspring against satan the accursed" (iii)}}
\hadithdefcmd{muslim}{6134}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنِي عَبْدُ اللَّهِ، بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، جَمِيعًا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ وَقَالاَ ‏"‏ يَمَسُّهُ حِينَ يُولَدُ فَيَسْتَهِلُّ صَارِخًا مِنْ مَسَّةِ الشَّيْطَانِ إِيَّاهُ ‏"‏ ‏.‏ وَفِي حَدِيثِ شُعَيْبٍ ‏"‏ مِنْ مَسِّ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{6134}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters (and the words are):" The newborn child is touched by the satan (when he comes in the world) and he starts crying because of the touch of satan." In the hadith transmitted on the authority of Shu'aib there is a slight variation of wording}}
\hadithdefcmd{muslim}{6135}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ أَبَا يُونُسَ، سُلَيْمًا مَوْلَى أَبِي هُرَيْرَةَ حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ كُلُّ بَنِي آدَمَ يَمَسُّهُ الشَّيْطَانُ يَوْمَ وَلَدَتْهُ أُمُّهُ إِلاَّ مَرْيَمَ وَابْنَهَا ‏"‏ ‏.‏\hadithno{6135}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The satan touches every son of Adam on the day when his mother gives birth to him with the exception of Mary and her son}}
\hadithdefcmd{muslim}{6136}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صِيَاحُ الْمَوْلُودِ حِينَ يَقَعُ نَزْغَةٌ مِنَ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{6136}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The crying of the child (starts) when the satan begins to prick him}}
\hadithdefcmd{muslim}{6137}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَأَى عِيسَى ابْنُ مَرْيَمَ رَجُلاً يَسْرِقُ فَقَالَ لَهُ عِيسَى سَرَقْتَ قَالَ كَلاَّ وَالَّذِي لاَ إِلَهَ إِلاَّ هُوَ ‏.‏ فَقَالَ عِيسَى آمَنْتُ بِاللَّهِ وَكَذَّبْتُ نَفْسِي ‏"‏ ‏.‏\hadithno{6137}\hadithtrans{Abu Huraira reported ahadith from the Messenger of Allah (ﷺ) (and one of them was) that Allah's Messenger (ﷺ) said Jesus son of Mary saw a person committing theft; thereupon Jesus said to him:You committed theft. He said: Nay. By Him besides Whom there is no god (I have not committed theft). Thereupon Jesus said: I affirm my faith in Allah It is my ownself that deceived me}}
\hadithdefcmd{muslim}{6138}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، وَابْنُ، فُضَيْلٍ عَنِ الْمُخْتَارِ، ح وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، أَخْبَرَنَا الْمُخْتَارُ، بْنُ فُلْفُلٍ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا خَيْرَ الْبَرِيَّةِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ذَاكَ إِبْرَاهِيمُ عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏\hadithno{6138}\hadithtrans{Anas b. Malik reported that a person came to Allah's Messenger (ﷺ) and said:O, the best of creation; thereupon Allah's Messenger (ﷺ) said: He is Ibrahim (peace be upon him)}}
\hadithdefcmd{muslim}{6139}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ إِدْرِيسَ، قَالَ سَمِعْتُ مُخْتَارَ بْنَ فُلْفُلٍ، مَوْلَى عَمْرِو بْنِ حُرَيْثٍ قَالَ سَمِعْتُ أَنَسًا، يَقُولُ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{6139}\hadithtrans{This hadith has been narrated on the authority of Anas through a different chain of transmitters}}
\hadithdefcmd{muslim}{6140}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنِ الْمُخْتَارِ، قَالَ سَمِعْتُ أَنَسًا، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{6140}\hadithtrans{Anas reported a hadith like this from Allah's Apostle (ﷺ) through another chain of transmitters}}
\hadithdefcmd{muslim}{6141}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اخْتَتَنَ إِبْرَاهِيمُ النَّبِيُّ عَلَيْهِ السَّلاَمُ وَهُوَ ابْنُ ثَمَانِينَ سَنَةً بِالْقَدُومِ ‏"‏ ‏.‏\hadithno{6141}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as having said that Ibrahim (as) circumcised himself with the help of an adze when he was eighty years old}}
\hadithdefcmd{muslim}{6142}{وَحَدَّثَنَاهُ إِنْ، شَاءَ اللَّهُ عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ حَدَّثَنَا جُوَيْرِيَةُ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، وَأَبَا، عُبَيْدٍ أَخْبَرَاهُ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ يُونُسَ عَنِ الزُّهْرِيِّ ‏.‏\hadithno{6142}\hadithtrans{This hadith has been narrated on the authority of Zuhri through another chain of transmitters}}
\hadithdefcmd{muslim}{6143}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا وَرْقَاءُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَغْفِرُ اللَّهُ لِلُوطٍ إِنَّهُ أَوَى إِلَى رُكْنٍ شَدِيدٍ ‏"‏ ‏.‏\hadithno{6143}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{6145}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي جَرِيرُ بْنُ حَازِمٍ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَمْ يَكْذِبْ إِبْرَاهِيمُ النَّبِيُّ عَلَيْهِ السَّلاَمُ قَطُّ إِلاَّ ثَلاَثَ كَذَبَاتٍ ثِنْتَيْنِ فِي ذَاتِ اللَّهِ قَوْلُهُ ‏\{‏ إِنِّي سَقِيمٌ‏\}‏ ‏.‏ وَقَوْلُهُ ‏\{‏ بَلْ فَعَلَهُ كَبِيرُهُمْ هَذَا‏\}‏ وَوَاحِدَةً فِي شَأْنِ سَارَةَ فَإِنَّهُ قَدِمَ أَرْضَ جَبَّارٍ وَمَعَهُ سَارَةُ وَكَانَتْ أَحْسَنَ النَّاسِ فَقَالَ لَهَا إِنَّ هَذَا الْجَبَّارَ إِنْ يَعْلَمْ أَنَّكِ امْرَأَتِي يَغْلِبْنِي عَلَيْكِ فَإِنْ سَأَلَكِ فَأَخْبِرِيهِ أَنَّكِ أُخْتِي فَإِنَّكِ أُخْتِي فِي الإِسْلاَمِ فَإِنِّي لاَ أَعْلَمُ فِي الأَرْضِ مُسْلِمًا غَيْرِي وَغَيْرَكِ فَلَمَّا دَخَلَ أَرْضَهُ رَآهَا بَعْضُ أَهْلِ الْجَبَّارِ أَتَاهُ فَقَالَ لَهُ لَقَدْ قَدِمَ أَرْضَكَ امْرَأَةٌ لاَ يَنْبَغِي لَهَا أَنْ تَكُونَ إِلاَّ لَكَ ‏.‏ فَأَرْسَلَ إِلَيْهَا فَأُتِيَ بِهَا فَقَامَ إِبْرَاهِيمُ عَلَيْهِ السَّلاَمُ إِلَى الصَّلاَةِ فَلَمَّا دَخَلَتْ عَلَيْهِ لَمْ يَتَمَالَكْ أَنْ بَسَطَ يَدَهُ إِلَيْهَا فَقُبِضَتْ يَدُهُ قَبْضَةً شَدِيدَةً فَقَالَ لَهَا ادْعِي اللَّهَ أَنْ يُطْلِقَ يَدِي وَلاَ أَضُرُّكِ ‏.‏ فَفَعَلَتْ فَعَادَ فَقُبِضَتْ أَشَدَّ مِنَ الْقَبْضَةِ الأُولَى فَقَالَ لَهَا مِثْلَ ذَلِكَ فَفَعَلَتْ فَعَادَ فَقُبِضَتْ أَشَدَّ مِنَ الْقَبْضَتَيْنِ الأُولَيَيْنِ فَقَالَ ادْعِي اللَّهَ أَنْ يُطْلِقَ يَدِي فَلَكِ اللَّهَ أَنْ لاَ أَضُرَّكِ ‏.‏ فَفَعَلَتْ وَأُطْلِقَتْ يَدُهُ وَدَعَا الَّذِي جَاءَ بِهَا فَقَالَ لَهُ إِنَّكَ إِنَّمَا أَتَيْتَنِي بِشَيْطَانٍ وَلَمْ تَأْتِنِي بِإِنْسَانٍ فَأَخْرِجْهَا مِنْ أَرْضِي وَأَعْطِهَا هَاجَرَ ‏.‏ قَالَ فَأَقْبَلَتْ تَمْشِي فَلَمَّا رَآهَا إِبْرَاهِيمُ عَلَيْهِ السَّلاَمُ انْصَرَفَ فَقَالَ لَهَا مَهْيَمْ قَالَتْ خَيْرًا كَفَّ اللَّهُ يَدَ الْفَاجِرِ وَأَخْدَمَ خَادِمًا ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَتِلْكَ أُمُّكُمْ يَا بَنِي مَاءِ السَّمَاءِ ‏.‏\hadithno{6145}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Prophet Ibrahim (peace be upon him) never told a lie but only thrice: two times for the sake of Allah (for example, his words): "I am sick," and his words: "But it was the big one amongst them which has done that" and because of Sara (his wife). He had come in a land inhabited by haughty and cruel men along with Sara. She was very good-looking amongst the people, so he said to her: If these people were to know that you are my wife they would snatch you away from me, so if they ask you tell them that you are my sister and in fact you are my sister in Islam, and I do not know of any other Muslim in this land besides I and you. And when they entered that land the tyrants came to see her and said to him (the king): 'There comes to your land a woman, whom you alone deserve to possess', so he (the king) sent someone (towards her) and she was brought to him, and Ibrahim (peace be upon him) stood in prayer. When she visited him (the tyrant king came) he could help but stretch his hand towards her and his hand was tied up. He said: 'Supplicate to Allah so that He may release my hand and I will do no harm to you.' She did that and the man repeated (the same highhandedness) and his hand was again tied up more tightly than on the first occasion. He said the same thing to her again, and she again did that (supplicated), but he repeated (the same highhandedness and his hands were tied up more tightly than on the previous occasion). He then again said: 'Supplicate your Lord so that He may set my hand free; by Allah I shall do no harm to you.' She did and his hand was freed. Then he called the person who had brought her and said to him: 'You have brought to me the satan and you have not brought to me a human being, so turn them out from my land,' and he gave Hajar as a gift to her. She returned (along with Hajar) and when Ibrahim (peace be upon him) saw her, he said: 'How have you returned?' She said: 'With full safety (have I returned). Allah held the hand of that debauch and he gave me a maid-servant.' Abu Huraira said: 'O sons of the rain of the sky, she is your mother}}
\hadithdefcmd{muslim}{6146}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَانَتْ بَنُو إِسْرَائِيلَ يَغْتَسِلُونَ عُرَاةً يَنْظُرُ بَعْضُهُمْ إِلَى سَوْأَةِ بَعْضٍ وَكَانَ مُوسَى عَلَيْهِ السَّلاَمُ يَغْتَسِلُ وَحْدَهُ فَقَالُوا وَاللَّهِ مَا يَمْنَعُ مُوسَى أَنْ يَغْتَسِلَ مَعَنَا إِلاَّ أَنَّهُ آدَرُ ‏.‏ قَالَ فَذَهَبَ مَرَّةً يَغْتَسِلُ فَوَضَعَ ثَوْبَهُ عَلَى حَجَرٍ فَفَرَّ الْحَجَرُ بِثَوْبِهِ - قَالَ - فَجَمَحَ مُوسَى بِأَثَرِهِ يَقُولُ ثَوْبِي حَجَرُ ثَوْبِي حَجَرُ ‏.‏ حَتَّى نَظَرَتْ بَنُو إِسْرَائِيلَ إِلَى سَوْأَةِ مُوسَى فَقَالُوا وَاللَّهِ مَا بِمُوسَى مِنْ بَأْسٍ ‏.‏ فَقَامَ الْحَجَرُ بَعْدُ حَتَّى نُظِرَ إِلَيْهِ - قَالَ - فَأَخَذَ ثَوْبَهُ فَطَفِقَ بِالْحَجَرِ ضَرْبًا ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ وَاللَّهِ إِنَّهُ بِالْحَجَرِ نَدَبٌ سِتَّةٌ أَوْ سَبْعَةٌ ضَرْبُ مُوسَى عَلَيْهِ السَّلاَمُ بِالْحَجَرِ ‏.‏\hadithno{6146}\hadithtrans{Hammam b. Munabbih reported that Abu Huraira reported many ahadith from Allah's Messenger (ﷺ) and one, of them speaks that Allah's Messenger (ﷺ) is reported to have said:Banu Isra'il used to take bath (together) naked and thus saw private parts of one another, but Moses (peace be upon him) used to take bath alone (in privacy), and they said: By Allah, nothing prevents Moses to take bath along with us; but scrotal hernia. One day when he (Moses) was taking bath (alone) he placed his clothes upon a stone, but the stone began to move along with his clothes. Moses raced after it saying: My garment, stone; until (some of the people) of Banu Isra'il looked at the private parts of Moses, and they said: By Allah, there is no trouble with Moses. The stone stopped after he (Moses) had been seen. He took hold of his garments and struck the stone. Abu Huraira said: I swear by Allah that there were six or seven scars on the stone because of the striking of stone by Moses (peace be upon him)}}
\hadithdefcmd{muslim}{6147}{وَحَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ أَنْبَأَنَا أَبُو هُرَيْرَةَ، قَالَ كَانَ مُوسَى عَلَيْهِ السَّلاَمُ رَجُلاً حَيِيًّا - قَالَ - فَكَانَ لاَ يُرَى مُتَجَرِّدًا - قَالَ - فَقَالَ بَنُو إِسْرَائِيلَ إِنَّهُ آدَرُ - قَالَ - فَاغْتَسَلَ عِنْدَ مُوَيْهٍ فَوَضَعَ ثَوْبَهُ عَلَى حَجَرٍ فَانْطَلَقَ الْحَجَرُ يَسْعَى وَاتَّبَعَهُ بِعَصَاهُ يَضْرِبُهُ ثَوْبِي حَجَرُ ثَوْبِي حَجَرُ ‏.‏ حَتَّى وَقَفَ عَلَى مَلإٍ مِنْ بَنِي إِسْرَائِيلَ وَنَزَلَتْ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَكُونُوا كَالَّذِينَ آذَوْا مُوسَى فَبَرَّأَهُ اللَّهُ مِمَّا قَالُوا وَكَانَ عِنْدَ اللَّهِ وَجِيهًا‏\}‏\hadithno{6147}\hadithtrans{Abu Huraira reported that Moses was a modest person. He was never seen naked and Banu Isra'iI said:(He was afraid to expose his private part) because he had been suffering from scrotal hernia. He (one day) took bath in water and placed his garments upon a stone. The stone began to move on quickly. He followed that and struck it with the help of a stone (saying): O stone, my garment; O stone, my garments, O stone; until it stopped near the big gathering of Isrii'll, and this verse was revealed (pertaining to the incident):" O you who believe, be not Iike those who maligned Moses, but Allah cleared him of what they said, and he was worthy of regard with Allah" (xxxiii)}}
\hadithdefcmd{muslim}{6148}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أُرْسِلَ مَلَكُ الْمَوْتِ إِلَى مُوسَى عَلَيْهِ السَّلاَمُ فَلَمَّا جَاءَهُ صَكَّهُ فَفَقَأَ عَيْنَهُ فَرَجَعَ إِلَى رَبِّهِ فَقَالَ أَرْسَلْتَنِي إِلَى عَبْدٍ لاَ يُرِيدُ الْمَوْتَ - قَالَ - فَرَدَّ اللَّهُ إِلَيْهِ عَيْنَهُ وَقَالَ ارْجِعْ إِلَيْهِ فَقُلْ لَهُ يَضَعُ يَدَهُ عَلَى مَتْنِ ثَوْرٍ فَلَهُ بِمَا غَطَّتْ يَدُهُ بِكُلِّ شَعْرَةٍ سَنَةٌ قَالَ أَىْ رَبِّ ثُمَّ مَهْ قَالَ ثُمَّ الْمَوْتُ ‏.‏ قَالَ فَالآنَ فَسَأَلَ اللَّهَ أَنْ يُدْنِيَهُ مِنَ الأَرْضِ الْمُقَدَّسَةِ رَمْيَةً بِحَجَرٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَلَوْ كُنْتُ ثَمَّ لأَرَيْتُكُمْ قَبْرَهُ إِلَى جَانِبِ الطَّرِيقِ تَحْتَ الْكَثِيبِ الأَحْمَرِ ‏"‏ ‏.‏\hadithno{6148}\hadithtrans{Abu Huraira reported that the Angel of Death was sent to Moses (peace be upon him) to inform of his Lord's summons. When he came, he (Moses) boxed him and his eye was knocked out. He (the Angel of Death) came back to the Lord and said:You sent me to a servant. who did not want to die. Allah restored his eye to its proper place (and revived his eyesight), and then said: Go back to him and tell him that if he wants life he must place his hand on the back of an ox, and he would be granted as many years of life as the number of hair covered by his hand. He (Moses) said: My Lord what would happen then He said: Then you must court death. He said: Let it be now. And he supplicated Allah to bring him close to the sacred land. Thereupon Allah's Messenger (ﷺ) said: If I were there, I would have shown you his grave beside the road at the red mound}}
\hadithdefcmd{muslim}{6149}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ جَاءَ مَلَكُ الْمَوْتِ إِلَى مُوسَى عَلَيْهِ السَّلاَمُ فَقَالَ لَهُ أَجِبْ رَبَّكَ - قَالَ - فَلَطَمَ مُوسَى عَلَيْهِ السَّلاَمُ عَيْنَ مَلَكِ الْمَوْتِ فَفَقَأَهَا - قَالَ - فَرَجَعَ الْمَلَكُ إِلَى اللَّهِ تَعَالَى فَقَالَ إِنَّكَ أَرْسَلْتَنِي إِلَى عَبْدٍ لَكَ لاَ يُرِيدُ الْمَوْتَ وَقَدْ فَقَأَ عَيْنِي - قَالَ - فَرَدَّ اللَّهُ إِلَيْهِ عَيْنَهُ وَقَالَ ارْجِعْ إِلَى عَبْدِي فَقُلِ الْحَيَاةَ تُرِيدُ فَإِنْ كُنْتَ تُرِيدُ الْحَيَاةَ فَضَعْ يَدَكَ عَلَى مَتْنِ ثَوْرٍ فَمَا تَوَارَتْ يَدُكَ مِنْ شَعْرَةٍ فَإِنَّكَ تَعِيشُ بِهَا سَنَةً قَالَ ثُمَّ مَهْ قَالَ ثُمَّ تَمُوتُ ‏.‏ قَالَ فَالآنَ مِنْ قَرِيبٍ رَبِّ أَمِتْنِي مِنَ الأَرْضِ الْمُقَدَّسَةِ رَمْيَةً بِحَجَرٍ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَاللَّهِ لَوْ أَنِّي عِنْدَهُ لأَرَيْتُكُمْ قَبْرَهُ إِلَى جَانِبِ الطَّرِيقِ عِنْدَ الْكَثِيبِ الأَحْمَرِ ‏"‏ ‏.‏\hadithno{6149}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) having said that the Angel of Death came to Moses and said:Respond (to the call) of Allah (i. e. be prepared for death). Moses (peace be upon him) gave a blow at the eye of the Angel of Death and knocked it out. The Angel went back to Allah (the Exalted) and said: You sent me to your servant who does not like to die and he knocked out my eye. Allah restored his eye to its proper place (and revived his eyesight) and said: Go to My servant and say: Do you want life? And in case you want life, keep your hand on the body of the ox and you would live such number of years as the (number of) hair your hand covers. He (Moses) said: What, then? He said: Then you would die, whereupon he (Moses) said: Then why not now? (He then prayed): Allah, cause me to die close to the sacred land. Allah's Messenger (ﷺ) said: Had I been near that place I would have shown his grave by the side of the path at the red mound}}
\hadithdefcmd{muslim}{6150}{قَالَ أَبُو إِسْحَاقَ حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، بِمِثْلِ هَذَا الْحَدِيثِ ‏.‏\hadithno{6150}\hadithtrans{This hadith has been transmitted on the authority of Ma'mar}}
\hadithdefcmd{muslim}{6151}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا حُجَيْنُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، بْنِ أَبِي سَلَمَةَ عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ الْهَاشِمِيِّ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ بَيْنَمَا يَهُودِيٌّ يَعْرِضُ سِلْعَةً لَهُ أُعْطِيَ بِهَا شَيْئًا كَرِهَهُ أَوْ لَمْ يَرْضَهُ - شَكَّ عَبْدُ الْعَزِيزِ - قَالَ لاَ وَالَّذِي اصْطَفَى مُوسَى عَلَيْهِ السَّلاَمُ عَلَى الْبَشَرِ ‏.‏ قَالَ فَسَمِعَهُ رَجُلٌ مِنَ الأَنْصَارِ فَلَطَمَ وَجْهَهُ - قَالَ - تَقُولُ وَالَّذِي اصْطَفَى مُوسَى عَلَيْهِ السَّلاَمُ عَلَى الْبَشَرِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَظْهُرِنَا قَالَ فَذَهَبَ الْيَهُودِيُّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا أَبَا الْقَاسِمِ إِنَّ لِي ذِمَّةً وَعَهْدًا ‏.‏ وَقَالَ فُلاَنٌ لَطَمَ وَجْهِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لِمَ لَطَمْتَ وَجْهَهُ ‏"‏ ‏.‏ قَالَ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ وَالَّذِي اصْطَفَى مُوسَى عَلَيْهِ السَّلاَمُ عَلَى الْبَشَرِ وَأَنْتَ بَيْنَ أَظْهُرِنَا ‏.‏ قَالَ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى عُرِفَ الْغَضَبُ فِي وَجْهِهِ ثُمَّ قَالَ ‏"‏ لاَ تُفَضِّلُوا بَيْنَ أَنْبِيَاءِ اللَّهِ فَإِنَّهُ يُنْفَخُ فِي الصُّورِ فَيَصْعَقُ مَنْ فِي السَّمَوَاتِ وَمَنْ فِي الأَرْضِ إِلاَّ مَنْ شَاءَ اللَّهُ - قَالَ - ثُمَّ يُنْفَخُ فِيهِ أُخْرَى فَأَكُونُ أَوَّلَ مَنْ بُعِثَ أَوْ فِي أَوَّلِ مَنْ بُعِثَ فَإِذَا مُوسَى عَلَيْهِ السَّلاَمُ آخِذٌ بِالْعَرْشِ فَلاَ أَدْرِي أَحُوسِبَ بِصَعْقَتِهِ يَوْمَ الطُّورِ أَوْ بُعِثَ قَبْلِي وَلاَ أَقُولُ إِنَّ أَحَدًا أَفْضَلُ مِنْ يُونُسَ بْنِ مَتَّى عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏\hadithno{6151}\hadithtrans{Abu Huraira reported:While a Jew was selling goods, he was given something which he did not accept or he did not agree (to accept) that 'Abdul 'Azlz (one of the narrators) is doubtful about it. He (the Jew) said: By Allah, Who chose Moses (peace be upon him) among mankind. A person from the Ansar heard it and gave a blow at his face saying: (You have the audacity) to say: By Him Who chose Moses amongst mankind, whereas Allah's Messenger (ﷺ) is living amongst us. The Jew went to Allah's Messenger (ﷺ) and said: Abu'l-Qasim, I am a Dhimmi and (thus need your protection) by a covenant, and added: Such and such person has given a blow upon my face. Thereupon Allah's Messenger (ﷺ) said: Why did you give a blow on his face? He said: Allah's Messenger, this man said: By Him Who chose Moses (peace be upon him) amongst mankind, whereas you are living amongst us. Allah's Messenger (ﷺ) became angry and signs of anger could be seen on his face, and then said: Don't make distinction amongst the Prophets of Allah. When the horn will be blown and whatever is in the heavens and the earth would swoon but he whom Allah grants exception, then another horn will be blown and I would be the first amongst those who would recover and Moses (peace be upon him) would be catching hold of the Throne and I do not know whether it is a compensation for that when he swooned on the Day of Tur or he would be resurrected before me and I do not say that anyone is more excellent than Yunus son of Matta (peace he upon him)}}
\hadithdefcmd{muslim}{6152}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، بِهَذَا الإِسْنَادِ سَوَاءً ‏.‏\hadithno{6152}\hadithtrans{This hadith has been narrated on the authority of Abu Salama with the same chain of transmitters}}
\hadithdefcmd{muslim}{6153}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَأَبُو بَكْرِ بْنُ النَّضْرِ قَالاَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَعَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ اسْتَبَّ رَجُلاَنِ رَجُلٌ مِنَ الْيَهُودِ وَرَجُلٌ مِنَ الْمُسْلِمِينَ فَقَالَ الْمُسْلِمُ وَالَّذِي اصْطَفَى مُحَمَّدًا صلى الله عليه وسلم عَلَى الْعَالَمِينَ ‏.‏ وَقَالَ الْيَهُودِيُّ وَالَّذِي اصْطَفَى مُوسَى عَلَيْهِ السَّلاَمُ عَلَى الْعَالَمِينَ ‏.‏ قَالَ فَرَفَعَ الْمُسْلِمُ يَدَهُ عِنْدَ ذَلِكَ فَلَطَمَ وَجْهَ الْيَهُودِيِّ فَذَهَبَ الْيَهُودِيُّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ بِمَا كَانَ مِنْ أَمْرِهِ وَأَمْرِ الْمُسْلِمِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُخَيِّرُونِي عَلَى مُوسَى فَإِنَّ النَّاسَ يَصْعَقُونَ فَأَكُونُ أَوَّلَ مَنْ يُفِيقُ فَإِذَا مُوسَى بَاطِشٌ بِجَانِبِ الْعَرْشِ فَلاَ أَدْرِي أَكَانَ فِيمَنْ صَعِقَ فَأَفَاقَ قَبْلِي أَمْ كَانَ مِمَّنِ اسْتَثْنَى اللَّهُ ‏"‏ ‏.‏\hadithno{6153}\hadithtrans{Abu Huraira reported that two persons, one from amongst the Jews and the other from amongst the Muslims, fell into dispute and began to abuse one another. The Muslim said:By Him Who chose Muhammad (ﷺ) in the worlds. And the Jew said: By Him Who chose Moses in the worlds. Thereupon the Muslim lifted his hand and slapped at the face of the Jew. The Jew went to Allah's Messenger (ﷺ) and told him about his affair and the affair of the Muslim. Thereupon Allah's Messenger (ﷺ) said: Don't make me superior to Moses for mankind will swoon and I would be the first to recover from it and Moses would be at that time seizing the side of the Throne and I do not know (whether) he would swoon and would recover before me or Allah would make an exception for him}}
\hadithdefcmd{muslim}{6154}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، وَأَبُو بَكْرِ بْنُ إِسْحَاقَ قَالاَ أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، وَسَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ اسْتَبَّ رَجُلٌ مِنَ الْمُسْلِمِينَ وَرَجُلٌ مِنَ الْيَهُودِ ‏.‏ بِمِثْلِ حَدِيثِ إِبْرَاهِيمَ بْنِ سَعْدٍ عَنِ ابْنِ شِهَابٍ ‏.‏\hadithno{6154}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:A person from amongst the Muslims and a person from amongst the Jews fell into dispute and reviled each other. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{6155}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ، يَحْيَى عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ جَاءَ يَهُودِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم قَدْ لُطِمَ وَجْهُهُ ‏.‏ وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ الزُّهْرِيِّ غَيْرَ أَنَّهُ قَالَ ‏ "‏ فَلاَ أَدْرِي أَكَانَ مِمَّنْ صَعِقَ فَأَفَاقَ قَبْلِي أَوِ اكْتَفَى بِصَعْقَةِ الطُّورِ ‏"‏ ‏.‏\hadithno{6155}\hadithtrans{Abu Sa'id Khudri reported that a Jew who had received a blow at his face came to Allah's Messenger (ﷺ) ; the rest of the hadith is the same, up to the hand (where the words are):That he (the Holy Prophet) said: I do not know whether he would be one who would fall into swoon and would recover before me or he would be compensated for his swooning at Tur (and thus he would not swoon on this occasion) of Resurrection}}
\hadithdefcmd{muslim}{6156}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُخَيِّرُوا بَيْنَ الأَنْبِيَاءِ ‏"‏ ‏.‏ وَفِي حَدِيثِ ابْنِ نُمَيْرٍ عَمْرِو بْنِ يَحْيَى حَدَّثَنِي أَبِي ‏.‏\hadithno{6156}\hadithtrans{Abu Sa'id Kudari reported Allah's Messenger (ﷺ) having, said this:Don't make distinction amongst the Apostles. This hadith has been narrated through another chain of transmitters also}}
\hadithdefcmd{muslim}{6157}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، وَشَيْبَانُ بْنُ فَرُّوخَ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، الْبُنَانِيِّ وَسُلَيْمَانَ التَّيْمِيِّ عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَتَيْتُ - وَفِي رِوَايَةِ هَدَّابٍ مَرَرْتُ - عَلَى مُوسَى لَيْلَةَ أُسْرِيَ بِي عِنْدَ الْكَثِيبِ الأَحْمَرِ وَهُوَ قَائِمٌ يُصَلِّي فِي قَبْرِهِ ‏"‏ ‏.‏\hadithno{6157}\hadithtrans{Anas b. malik reported Allah's Messenger (ﷺ) as saying:I came. And in the narration transmitted on the authority of Haddib (the words are): I happened to pass by Moses on the occasion of the Night journey near the red mound (and found him) saying his prayer in his grave}}
\hadithdefcmd{muslim}{6158}{وَحَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى يَعْنِي ابْنَ يُونُسَ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ، أَبِي شَيْبَةَ حَدَّثَنَا جَرِيرٌ، كِلاَهُمَا عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَنَسٍ، ح وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ سُفْيَانَ، عَنْ سُلَيْمَانَ، التَّيْمِيِّ سَمِعْتُ أَنَسًا، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَرَرْتُ عَلَى مُوسَى وَهُوَ يُصَلِّي فِي قَبْرِهِ ‏"‏ ‏.‏ وَزَادَ فِي حَدِيثِ عِيسَى ‏"‏ مَرَرْتُ لَيْلَةَ أُسْرِيَ بِي ‏"‏ ‏.‏\hadithno{6158}\hadithtrans{Anas reported Allah's Messenger (ﷺ) as saying:I happened to pass by Moses as he was busy in saying prayer in his grave, and in the hadith transmitted on the authority of 'Isa there is an addition of these words:, I happened to pass on the occasion of the Night journey}}
\hadithdefcmd{muslim}{6159}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالُوا حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، - حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ سَمِعْتُ حُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ ‏ "‏ قَالَ - يَعْنِي اللَّهَ تَبَارَكَ وَتَعَالَى - لاَ يَنْبَغِي لِعَبْدٍ لِي - وَقَالَ ابْنُ الْمُثَنَّى لِعَبْدِي - أَنْ يَقُولَ أَنَا خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى عَلَيْهِ السَّلاَمُ ‏"‏ ‏.‏ قَالَ ابْنُ أَبِي شَيْبَةَ مُحَمَّدُ بْنُ جَعْفَرٍ عَنْ شُعْبَةَ ‏.‏\hadithno{6159}\hadithtrans{Abu Huraira reported Allah's Messenger (may prace be upon him) as saying that Allah, the Exalted and Majestic, said:It is not meet for a servant of Mine that he should say: I am better than Yunus b. Matta (peace be upon him)}}
\hadithdefcmd{muslim}{6160}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَبَا الْعَالِيَةِ، يَقُولُ حَدَّثَنِي ابْنُ عَمِّ، نَبِيِّكُمْ صلى الله عليه وسلم - يَعْنِي ابْنَ عَبَّاسٍ - عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا يَنْبَغِي لِعَبْدٍ أَنْ يَقُولَ أَنَا خَيْرٌ مِنْ يُونُسَ بْنِ مَتَّى ‏"‏ ‏.‏ وَنَسَبَهُ إِلَى أَبِيهِ ‏.‏\hadithno{6160}\hadithtrans{Abu al-Aliya said:The son of the uncle of your Prophet (ﷺ), i. e. Ibn Abbas, reported Allah's Messenger (ﷺ) as saying: It is not meet for a servant that he should say: I am better than Yunus b. Matta (and this Matta) is the name of his father}}
\hadithdefcmd{muslim}{6161}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالُوا حَدَّثَنَا يَحْيَى، بْنُ سَعِيدٍ عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ مَنْ أَكْرَمُ النَّاسِ قَالَ ‏"‏ أَتْقَاهُمْ ‏"‏ ‏.‏ قَالُوا لَيْسَ عَنْ هَذَا نَسْأَلُكَ ‏.‏ قَالَ ‏"‏ فَيُوسُفُ نَبِيُّ اللَّهِ ابْنُ نَبِيِّ اللَّهِ ابْنِ نَبِيِّ اللَّهِ ابْنِ خَلِيلِ اللَّهِ ‏"‏ ‏.‏ قَالُوا لَيْسَ عَنْ هَذَا نَسْأَلُكَ ‏.‏ قَالَ ‏"‏ فَعَنْ مَعَادِنِ الْعَرَبِ تَسْأَلُونِي خِيَارُهُمْ فِي الْجَاهِلِيَّةِ خِيَارُهُمْ فِي الإِسْلاَمِ إِذَا فَقِهُوا ‏"‏ ‏.‏\hadithno{6161}\hadithtrans{Abu Huraira reported:It was said to Allah's Messenger (ﷺ) as to who was the most worthy of respect amongst people. He said: The most God-conscious amongst you They said: It is not this that we are asking about, whereupon he said: Then he is Yusuf, the Apostle of Aliah and the son of Allah's Apostle, Ya'qub, who was also the son of Allah's Apostle, the friend of Allah (Ibrahim) They said: This is not what we are asking you. He said: You mean the tribes of Arabia? Those who are good in pre-Islamic days are good in Islam (after embracing Islam) when they get an understanding of it}}
\hadithdefcmd{muslim}{6162}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي، هُرَيْرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كَانَ زَكَرِيَّاءُ نَجَّارًا ‏"‏ ‏.‏\hadithno{6162}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Zakariyya (peace be upon him) was a carpenter}}
\hadithdefcmd{muslim}{6163}{حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ النَّاقِدُ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ أَبِي عُمَرَ الْمَكِّيُّ كُلُّهُمْ عَنِ ابْنِ عُيَيْنَةَ، - وَاللَّفْظُ لاِبْنِ أَبِي عُمَرَ - حَدَّثَنَا سُفْيَانُ، بْنُ عُيَيْنَةَ حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ إِنَّ نَوْفًا الْبِكَالِيَّ يَزْعُمُ أَنَّ مُوسَى عَلَيْهِ السَّلاَمُ صَاحِبَ بَنِي إِسْرَائِيلَ لَيْسَ هُوَ مُوسَى صَاحِبَ الْخَضِرِ عَلَيْهِ السَّلاَمُ ‏.‏ فَقَالَ كَذَبَ عَدُوُّ اللَّهِ سَمِعْتُ أُبَىَّ بْنَ كَعْبٍ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ قَامَ مُوسَى عَلَيْهِ السَّلاَمُ خَطِيبًا فِي بَنِي إِسْرَائِيلَ فَسُئِلَ أَىُّ النَّاسِ أَعْلَمُ فَقَالَ أَنَا أَعْلَمُ ‏.‏ قَالَ فَعَتَبَ اللَّهُ عَلَيْهِ إِذْ لَمْ يَرُدَّ الْعِلْمَ إِلَيْهِ فَأَوْحَى اللَّهُ إِلَيْهِ أَنَّ عَبْدًا مِنْ عِبَادِي بِمَجْمَعِ الْبَحْرَيْنِ هُوَ أَعْلَمُ مِنْكَ قَالَ مُوسَى أَىْ رَبِّ كَيْفَ لِي بِهِ فَقِيلَ لَهُ احْمِلْ حُوتًا فِي مِكْتَلٍ فَحَيْثُ تَفْقِدُ الْحُوتَ فَهُوَ ثَمَّ ‏.‏ فَانْطَلَقَ وَانْطَلَقَ مَعَهُ فَتَاهُ وَهُوَ يُوشَعُ بْنُ نُونٍ فَحَمَلَ مُوسَى عَلَيْهِ السَّلاَمُ حُوتًا فِي مِكْتَلٍ وَانْطَلَقَ هُوَ وَفَتَاهُ يَمْشِيَانِ حَتَّى أَتَيَا الصَّخْرَةَ فَرَقَدَ مُوسَى عَلَيْهِ السَّلاَمُ وَفَتَاهُ فَاضْطَرَبَ الْحُوتُ فِي الْمِكْتَلِ حَتَّى خَرَجَ مِنَ الْمِكْتَلِ فَسَقَطَ فِي الْبَحْرِ - قَالَ - وَأَمْسَكَ اللَّهُ عَنْهُ جِرْيَةَ الْمَاءِ حَتَّى كَانَ مِثْلَ الطَّاقِ فَكَانَ لِلْحُوتِ سَرَبًا وَكَانَ لِمُوسَى وَفَتَاهُ عَجَبًا فَانْطَلَقَا بَقِيَّةَ يَوْمِهِمَا وَلَيْلَتِهِمَا وَنَسِيَ صَاحِبُ مُوسَى أَنْ يُخْبِرَهُ فَلَمَّا أَصْبَحَ مُوسَى عَلَيْهِ السَّلاَمُ قَالَ لِفَتَاهُ آتِنَا غَدَاءَنَا لَقَدْ لَقِينَا مِنْ سَفَرِنَا هَذَا نَصَبًا - قَالَ - وَلَمْ يَنْصَبْ حَتَّى جَاوَزَ الْمَكَانَ الَّذِي أُمِرَ بِهِ ‏.‏ قَالَ أَرَأَيْتَ إِذْ أَوَيْنَا إِلَى الصَّخْرَةِ فَإِنِّي نَسِيتُ الْحُوتَ وَمَا أَنْسَانِيهُ إِلاَّ الشَّيْطَانُ أَنْ أَذْكُرَهُ وَاتَّخَذَ سَبِيلَهُ فِي الْبَحْرِ عَجَبًا ‏.‏ قَالَ مُوسَى ذَلِكَ مَا كُنَّا نَبْغِي فَارْتَدَّا عَلَى آثَارِهِمَا قَصَصًا ‏.‏ قَالَ يَقُصَّانِ آثَارَهُمَا حَتَّى أَتَيَا الصَّخْرَةَ فَرَأَى رَجُلاً مُسَجًّى عَلَيْهِ بِثَوْبٍ فَسَلَّمَ عَلَيْهِ مُوسَى ‏.‏ فَقَالَ لَهُ الْخَضِرُ أَنَّى بِأَرْضِكَ السَّلاَمُ قَالَ أَنَا مُوسَى ‏.‏ قَالَ مُوسَى بَنِي إِسْرَائِيلَ قَالَ نَعَمْ ‏.‏ قَالَ إِنَّكَ عَلَى عِلْمٍ مِنْ عِلْمِ اللَّهِ عَلَّمَكَهُ اللَّهُ لاَ أَعْلَمُهُ وَأَنَا عَلَى عِلْمٍ مِنْ عِلْمِ اللَّهِ عَلَّمَنِيهِ لاَ تَعْلَمُهُ ‏.‏ قَالَ لَهُ مُوسَى عَلَيْهِ السَّلاَمُ هَلْ أَتَّبِعُكَ عَلَى أَنْ تُعَلِّمَنِي مِمَّا عُلِّمْتَ رُشْدًا قَالَ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِيَ صَبْرًا وَكَيْفَ تَصْبِرُ عَلَى مَا لَمْ تُحِطْ بِهِ خُبْرًا قَالَ سَتَجِدُنِي إِنْ شَاءَ اللَّهُ صَابِرًا وَلاَ أَعْصِي لَكَ أَمْرًا ‏.‏ قَالَ لَهُ الْخَضِرُ فَإِنِ اتَّبَعْتَنِي فَلاَ تَسْأَلْنِي عَنْ شَىْءٍ حَتَّى أُحْدِثَ لَكَ مِنْهُ ذِكْرًا ‏.‏ قَالَ نَعَمْ ‏.‏ فَانْطَلَقَ الْخَضِرُ وَمُوسَى يَمْشِيَانِ عَلَى سَاحِلِ الْبَحْرِ فَمَرَّتْ بِهِمَا سَفِينَةٌ فَكَلَّمَاهُمْ أَنْ يَحْمِلُوهُمَا فَعَرَفُوا الْخَضِرَ فَحَمَلُوهُمَا بِغَيْرِ نَوْلٍ فَعَمَدَ الْخَضِرُ إِلَى لَوْحٍ مِنْ أَلْوَاحِ السَّفِينَةِ فَنَزَعَهُ فَقَالَ لَهُ مُوسَى قَوْمٌ حَمَلُونَا بِغَيْرِ نَوْلٍ عَمَدْتَ إِلَى سَفِينَتِهِمْ فَخَرَقْتَهَا لِتُغْرِقَ أَهْلَهَا لَقَدْ جِئْتَ شَيْئًا إِمْرًا ‏.‏ قَالَ أَلَمْ أَقُلْ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِيَ صَبْرًا قَالَ لاَ تُؤَاخِذْنِي بِمَا نَسِيتُ وَلاَ تُرْهِقْنِي مِنْ أَمْرِي عُسْرًا ثُمَّ خَرَجَا مِنَ السَّفِينَةِ فَبَيْنَمَا هُمَا يَمْشِيَانِ عَلَى السَّاحِلِ إِذَا غُلاَمٌ يَلْعَبُ مَعَ الْغِلْمَانِ فَأَخَذَ الْخَضِرُ بِرَأْسِهِ فَاقْتَلَعَهُ بِيَدِهِ فَقَتَلَهُ ‏.‏ فَقَالَ مُوسَى أَقَتَلْتَ نَفْسًا زَاكِيَةً بِغَيْرِ نَفْسٍ لَقَدْ جِئْتَ شَيْئًا نُكْرًا ‏.‏ قَالَ أَلَمْ أَقُلْ لَكَ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِيَ صَبْرًا قَالَ وَهَذِهِ أَشَدُّ مِنَ الأُولَى ‏.‏ قَالَ إِنْ سَأَلْتُكَ عَنْ شَىْءٍ بَعْدَهَا فَلاَ تُصَاحِبْنِي قَدْ بَلَغْتَ مِنْ لَدُنِّي عُذْرًا ‏.‏ فَانْطَلَقَا حَتَّى إِذَا أَتَيَا أَهْلَ قَرْيَةٍ اسْتَطْعَمَا أَهْلَهَا فَأَبَوْا أَنْ يُضَيِّفُوهُمَا فَوَجَدَا فِيهَا جِدَارًا يُرِيدُ أَنْ يَنْقَضَّ فَأَقَامَهُ ‏.‏ يَقُولُ مَائِلٌ ‏.‏ قَالَ الْخَضِرُ بِيَدِهِ هَكَذَا فَأَقَامَهُ ‏.‏ قَالَ لَهُ مُوسَى قَوْمٌ أَتَيْنَاهُمْ فَلَمْ يُضَيِّفُونَا وَلَمْ يُطْعِمُونَا لَوْ شِئْتَ لَتَخِذْتَ عَلَيْهِ أَجْرًا ‏.‏ قَالَ هَذَا فِرَاقُ بَيْنِي وَبَيْنِكَ سَأُنَبِّئُكَ بِتَأْوِيلِ مَا لَمْ تَسْتَطِعْ عَلَيْهِ صَبْرًا ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَرْحَمُ اللَّهُ مُوسَى لَوَدِدْتُ أَنَّهُ كَانَ صَبَرَ حَتَّى يُقَصَّ عَلَيْنَا مِنْ أَخْبَارِهِمَا ‏"‏ ‏.‏ قَالَ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَانَتِ الأُولَى مِنْ مُوسَى نِسْيَانًا ‏"‏ ‏.‏ قَالَ ‏"‏ وَجَاءَ عُصْفُورٌ حَتَّى وَقَعَ عَلَى حَرْفِ السَّفِينَةِ ثُمَّ نَقَرَ فِي الْبَحْرِ ‏.‏ فَقَالَ لَهُ الْخَضِرُ مَا نَقَصَ عِلْمِي وَعِلْمُكَ مِنْ عِلْمِ اللَّهِ إِلاَّ مِثْلَ مَا نَقَصَ هَذَا الْعُصْفُورُ مِنَ الْبَحْرِ ‏"‏ ‏.‏ قَالَ سَعِيدُ بْنُ جُبَيْرٍ وَكَانَ يَقْرَأُ وَكَانَ أَمَامَهُمْ مَلِكٌ يَأْخُذُ كُلَّ سَفِينَةٍ صَالِحَةٍ غَصْبًا ‏.‏ وَكَانَ يَقْرَأُ وَأَمَّا الْغُلاَمُ فَكَانَ كَافِرًا ‏.‏\hadithno{6163}\hadithtrans{Sa'id b. Jubair reported:I said to Ibn Abbas that Nauf al-Bikali was of the opinion that Moses (peace be upon him), the Apostle of Bani Isra'il, was not the same who accompanied Khadir, whereupon he said: The enemy of Allah tells a lie. I heard Ubayy b. Ka'b say: Moses (peace be upon him) stood up to give sermon to the people of Isra'il. He was asked as to who amongst the people has the best knowledge, whereupon he said: I have the best knowledge. Thereupon Allah was annoyed with him that he did not attribute (the best knowledge) to Him. He revealed to him: A servant amongst My servants is at the junction of two rivers who has more knowledge than yours. Moses said: How can I meet him? It was said to him: Carry a fish in the large basket and the place where you find it missing there you will find him. Thereupon Moses proceeded forth along with a young man (Yusha'). Joshua b. Nun and Moses (peace be upon him) put the fish in the basket and there went along with him the young man (Yusha') until they came to a certain rock and Moses and his companion went to sleep and the fish stirred in that basket and fell into the ocean and Allah stopped the current of water like a vault until the way was made for the fish. Moses and his young companion were astonished and they walked for the rest of the day and the night and the friend of Moses forgot to inform him of this incident. When it was morning, Moses (peace be upon him) said to the young man: Bring for us the breakfast for we are dead tired because of this journey, and they did not feel exhausted until they had passed that place where they had been commanded (to stay). He said: Don't you know that when we reached the Sakhra (rock) I forgot the fish and nothing made me forget it but Satan that I could not remember it? How strange is it that the fish found a way in the river? Moses said: That was what we had been aiming at. Then both of them retraced their steps until they reached Sakhra; there they saw a man covered with a cloth. Moses greeted him. Khadir said to him: Where is as-Salam in our country.? He said: I am Moses, whereupon he (Khadir) said: You mean the Moses of Bani Isra'il? He said: Yes. He (Khadir) said: You have a knowledge out of the knowledge of Allah which in fact Allah imparted to you and about that I know nothing and I have knowledge out of Allah's knowledge which He imparted to me and about that you do not know. Moses (peace be upon him) said to him: May I follow you so that you may teach me that with which you have been taught righteousness. He said: You will not be able to bear with me; how you will be able to bear that about which you do not know? Moses said: Thou wilt find me patient, nor shalt I disobey you in aught. Khadir said to him: If you were to follow me, then do not ask me about anything until I myself speak to you about it. He said: Yes. So Khadir and Moses set forth on the bank of the river that there came before them a boat. Both of them talked to them (the owners of the boat) so that they might carry both of them. They had recognised Khadir and they carried them free. Khadir thereupon took hold of a plank in the boat and broke it away. Moses said: These people have carried us without any charge and you attempt to break their boat so that the people sailing in the boat may drown. This is (something) grievous that you have done. He said: Did I not say that you would not bear with me? He said: Blame me not for what I forgot and be not hard upon what I did. Then both of them got down from the boat and began to walk along the coastline that they saw a boy who had been playing with other boys. Khadir pulled up his head and killed him. Moses said: Have you killed an innocent person who is in no way guilty of slaying another? You have done something horrible. Thereupon he said: Did I not say to you that you will not be able to bear with me? He (Moses) said: This (act) is more grievous than the first one. He (Moses) further said. If I ask you about anything after this, keep not company with me, then you would no doubt find (a plausible) excuse for this. Then they both walked on until they reached the inhabitants of a village. They asked its inhabitants for food but they refused to entertain them as their guests. They found in it a wall which had been bent on one side and was about to fall. Khadir set it right with his own hand. Moses, said to him: It is the people to whom we came but they showed us no hospitality and they did not serve us food. If you wish you can get wages for it. He (Khadir) said: This is the parting of ways between me and you. Now I wish to reveal to you the significance of that for which you could not bear with me. Allah's Messenger (ﷺ) said. May Allah have mercy upon Moses! I wish if Moses could show patience and a (fuller) story of both of them could have been told. Allah's Messenger (ﷺ) said that the first thing which Moses said was out of forgetfulness. Then there came a sparrow until it perched on the wall of the boat and took water from the ocean. Thereupon, Khadir said: My knowledge and your knowledge in comparison with the knowledge of Allah is even less than the water taken by the sparrow in its beak in comparison to the water of the ocean, and Sa'id b. Jubair used to recite (verses 79 and 80 of Sura Kahf) in this way: There was before them a king who used to seize every boat by force which was in order, the boy was an unbeliever}}
\hadithdefcmd{muslim}{6164}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الْقَيْسِيُّ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ التَّيْمِيُّ، عَنْ أَبِيهِ، عَنْ رَقَبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قِيلَ لاِبْنِ عَبَّاسٍ إِنَّ نَوْفًا يَزْعُمُ أَنَّ مُوسَى الَّذِي ذَهَبَ يَلْتَمِسُ الْعِلْمَ لَيْسَ بِمُوسَى بَنِي إِسْرَائِيلَ ‏.‏ قَالَ أَسَمِعْتَهُ يَا سَعِيدُ قُلْتُ نَعَمْ ‏.‏ قَالَ كَذَبَ نَوْفٌ ‏.‏\hadithno{6164}\hadithtrans{Sa, id b. jubair reported that it was said to Ibn 'Abbas that Nauf al-Bikali was of the opinion that Moses who went in search of knowledge was not the Moses of Bani Isra'il. He said:Sa'id, did you hear it from him? I said: Yes. Thereupon he said that Nauf had not stated the fact}}
\hadithdefcmd{muslim}{6165}{حَدَّثَنَا أُبَىُّ بْنُ كَعْبٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّهُ بَيْنَمَا مُوسَى عَلَيْهِ السَّلاَمُ فِي قَوْمِهِ يُذَكِّرُهُمْ بِأَيَّامِ اللَّهِ وَأَيَّامُ اللَّهِ نَعْمَاؤُهُ وَبَلاَؤُهُ إِذْ قَالَ مَا أَعْلَمُ فِي الأَرْضِ رَجُلاً خَيْرًا أَوْ أَعْلَمَ مِنِّي ‏.‏ قَالَ فَأَوْحَى اللَّهُ إِلَيْهِ إِنِّي أَعْلَمُ بِالْخَيْرِ مِنْهُ أَوْ عِنْدَ مَنْ هُوَ إِنَّ فِي الأَرْضِ رَجُلاً هُوَ أَعْلَمُ مِنْكَ ‏.‏ قَالَ يَا رَبِّ فَدُلَّنِي عَلَيْهِ ‏.‏ قَالَ فَقِيلَ لَهُ تَزَوَّدْ حُوتًا مَالِحًا فَإِنَّهُ حَيْثُ تَفْقِدُ الْحُوتَ ‏.‏ قَالَ فَانْطَلَقَ هُوَ وَفَتَاهُ حَتَّى انْتَهَيَا إِلَى الصَّخْرَةِ فَعُمِّيَ عَلَيْهِ فَانْطَلَقَ وَتَرَكَ فَتَاهُ فَاضْطَرَبَ الْحُوتُ فِي الْمَاءِ فَجَعَلَ لاَ يَلْتَئِمُ عَلَيْهِ صَارَ مِثْلَ الْكُوَّةِ قَالَ فَقَالَ فَتَاهُ أَلاَ أَلْحَقُ نَبِيَّ اللَّهِ فَأُخْبِرَهُ قَالَ فَنُسِّيَ ‏.‏ فَلَمَّا تَجَاوَزَا قَالَ لِفَتَاهُ آتِنَا غَدَاءَنَا لَقَدْ لَقِينَا مِنْ سَفَرِنَا هَذَا نَصَبًا ‏.‏ قَالَ وَلَمْ يُصِبْهُمْ نَصَبٌ حَتَّى تَجَاوَزَا ‏.‏ قَالَ فَتَذَكَّرَ قَالَ أَرَأَيْتَ إِذْ أَوَيْنَا إِلَى الصَّخْرَةِ فَإِنِّي نَسِيتُ الْحُوتَ وَمَا أَنْسَانِيهُ إِلاَّ الشَّيْطَانُ أَنْ أَذْكُرَهُ وَاتَّخَذَ سَبِيلَهُ فِي الْبَحْرِ عَجَبًا ‏.‏ قَالَ ذَلِكَ مَا كُنَّا نَبْغِي ‏.‏ فَارْتَدَّا عَلَى آثَارِهِمَا قَصَصًا فَأَرَاهُ مَكَانَ الْحُوتِ قَالَ هَا هُنَا وُصِفَ لِي ‏.‏ قَالَ فَذَهَبَ يَلْتَمِسُ فَإِذَا هُوَ بِالْخَضِرِ مُسَجًّى ثَوْبًا مُسْتَلْقِيًا عَلَى الْقَفَا أَوْ قَالَ عَلَى حَلاَوَةِ الْقَفَا قَالَ السَّلاَمُ عَلَيْكُمْ ‏.‏ فَكَشَفَ الثَّوْبَ عَنْ وَجْهِهِ قَالَ وَعَلَيْكُمُ السَّلاَمُ مَنْ أَنْتَ قَالَ أَنَا مُوسَى ‏.‏ قَالَ وَمَنْ مُوسَى قَالَ مُوسَى بَنِي إِسْرَائِيلَ ‏.‏ قَالَ مَجِيءٌ مَا جَاءَ بِكَ قَالَ جِئْتُ لِتُعَلِّمَنِي مِمَّا عُلِّمْتَ رُشْدًا ‏.‏ قَالَ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِيَ صَبْرًا وَكَيْفَ تَصْبِرُ عَلَى مَا لَمْ تُحِطْ بِهِ خُبْرًا ‏.‏ شَىْءٌ أُمِرْتُ بِهِ أَنْ أَفْعَلَهُ إِذَا رَأَيْتَهُ لَمْ تَصْبِرْ ‏.‏ قَالَ سَتَجِدُنِي إِنْ شَاءَ اللَّهُ صَابِرًا وَلاَ أَعْصِي لَكَ أَمْرًا ‏.‏ قَالَ فَإِنِ اتَّبَعْتَنِي فَلاَ تَسْأَلْنِي عَنْ شَىْءٍ حَتَّى أُحْدِثَ لَكَ مِنْهُ ذِكْرًا ‏.‏ فَانْطَلَقَا حَتَّى إِذَا رَكِبَا فِي السَّفِينَةِ خَرَقَهَا ‏.‏ قَالَ انْتَحَى عَلَيْهَا ‏.‏ قَالَ لَهُ مُوسَى عَلَيْهِ السَّلاَمُ أَخَرَقْتَهَا لِتُغْرِقَ أَهْلَهَا لَقَدْ جِئْتَ شَيْئًا إِمْرًا ‏.‏ قَالَ أَلَمْ أَقُلْ إِنَّكَ لَنْ تَسْتَطِيعَ مَعِيَ صَبْرًا قَالَ لاَ تُؤَاخِذْنِي بِمَا نَسِيتُ وَلاَ تُرْهِقْنِي مِنْ أَمْرِي عُسْرًا ‏.‏ فَانْطَلَقَا حَتَّى إِذَا لَقِيَا غِلْمَانًا يَلْعَبُونَ ‏.‏ قَالَ فَانْطَلَقَ إِلَى أَحَدِهِمْ بَادِيَ الرَّأْىِ فَقَتَلَهُ فَذُعِرَ عِنْدَهَا مُوسَى عَلَيْهِ السَّلاَمُ ذَعْرَةً مُنْكَرَةً ‏.‏ قَالَ أَقَتَلْتَ نَفْسًا زَاكِيَةً بِغَيْرِ نَفْسٍ لَقَدْ جِئْتَ شَيْئًا نُكْرًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ هَذَا الْمَكَانِ ‏"‏ رَحْمَةُ اللَّهِ عَلَيْنَا وَعَلَى مُوسَى لَوْلاَ أَنَّهُ عَجَّلَ لَرَأَى الْعَجَبَ وَلَكِنَّهُ أَخَذَتْهُ مِنْ صَاحِبِهِ ذَمَامَةٌ ‏.‏ قَالَ إِنْ سَأَلْتُكَ عَنْ شَىْءٍ بَعْدَهَا فَلاَ تُصَاحِبْنِي قَدْ بَلَغْتَ مِنْ لَدُنِّي عُذْرًا ‏.‏ وَلَوْ صَبَرَ لَرَأَى الْعَجَبَ - قَالَ وَكَانَ إِذَا ذَكَرَ أَحَدًا مِنَ الأَنْبِيَاءِ بَدَأَ بِنَفْسِهِ ‏"‏ رَحْمَةُ اللَّهِ عَلَيْنَا وَ��َلَى أَخِي كَذَا رَحْمَةُ اللَّهِ عَلَيْنَا - ‏"‏ فَانْطَلَقَا حَتَّى إِذَا أَتَيَا أَهْلَ قَرْيَةٍ لِئَامًا فَطَافَا فِي الْمَجَالِسِ فَاسْتَطْعَمَا أَهْلَهَا فَأَبَوْا أَنْ يُضَيِّفُوهُمَا فَوَجَدَا فِيهَا جِدَارًا يُرِيدُ أَنْ يَنْقَضَّ فَأَقَامَهُ ‏.‏ قَالَ لَوْ شِئْتَ لاَتَّخَذْتَ عَلَيْهِ أَجْرًا ‏.‏ قَالَ هَذَا فِرَاقُ بَيْنِي وَبَيْنِكَ وَأَخَذَ بِثَوْبِهِ ‏.‏ قَالَ سَأُنَبِّئُكَ بِتَأْوِيلِ مَا لَمْ تَسْتَطِعْ عَلَيْهِ صَبْرًا أَمَّا السَّفِينَةُ فَكَانَتْ لِمَسَاكِينَ يَعْمَلُونَ فِي الْبَحْرِ إِلَى آخِرِ الآيَةِ ‏.‏ فَإِذَا جَاءَ الَّذِي يُسَخِّرُهَا وَجَدَهَا مُنْخَرِقَةً فَتَجَاوَزَهَا فَأَصْلَحُوهَا بِخَشَبَةٍ وَأَمَّا الْغُلاَمُ فَطُبِعَ يَوْمَ طُبِعَ كَافِرًا وَكَانَ أَبَوَاهُ قَدْ عَطَفَا عَلَيْهِ فَلَوْ أَنَّهُ أَدْرَكَ أَرْهَقَهُمَا طُغْيَانًا وَكُفْرًا فَأَرَدْنَا أَنْ يُبَدِّلَهُمَا رَبُّهُمَا خَيْرًا مِنْهُ زَكَاةً وَأَقْرَبَ رُحْمًا ‏.‏ وَأَمَّا الْجِدَارُ فَكَانَ لِغُلاَمَيْنِ يَتِيمَيْنِ فِي الْمَدِينَةِ وَكَانَ تَحْتَهُ ‏"‏ ‏.‏ إِلَى آخِرِ الآيَةِ ‏.‏\hadithno{6165}\hadithtrans{Ubayy b. Ka'b narrated to us that he had heard Allah's Messenger (ﷺ) as saying:Moses had been delivering sermons to his people. And he made this remark: No person upon the earth has better knowledge than I or nothing better than mine. Thereupon Allah revealed to him: I know one who is better than you (in knowledge) or there is a person on the earth having more knowledge than you. Thereupon he said: My Lord, direct me to him. It was said to him: Keep a salted fish as a provision for journey. The place where that fish would be lost (there you will find that man). So he set forth and a young slave along with him until they came to a place Sakhra. but he did not find any clue. So he proceeded on and left that young man there. The fish began to stir in water and the water assumed the form of an ark over the fish. The young man said: I should meet Allah's Apostle (peace be upon him) and inform him, but he was made to forget and when they had gone beyond that place, he (Moses) said to the young man: Bring breakfast. We have been exhausted because of the journey, and he (Moses) was not exhausted until he had crossed that (particular) place (where he had) to meet Khadir, and the youth was reminded and said: Did you not see that as we reached Sakhra I forgot the fish and it is satan alone who has made me forgetful of it'? It is strange that he has been able to find way in the ocean too. He said: This is what we sought for us. They returned retracing their steps, and he (his companion) pointed to him the location (where) the fish (had been lost). Moses began to search him there. He suddenly saw Khadir wrapped in a cloth and lying on his back. He said to him: As-Salamu-'Alaikum. He removed the cloth from his face and said: Wa 'Alaikum-us-Salam! Who are you? He said: I am Moses. He said: Who Moses? He said: Moses Of Bani Isra'il. He said: What brought you here? He said: I have come so that you may teach me what you have been taught of righteousness. He said: You shall have to bear with me, and how can you have patience about a thing of which you have no comprehensive knowledge? You will not have patience when you see me doing a thing I have been ordered to do. He said: If Allah pleases, you will find me patient, nor shall I disobey you in aught. Khadir said: If you follow me, don't ask me about anything until I explain it to you. So they went on until they embarked upon a boat. He (Khadir) made a hole in that. Thereupon he (Moses) said: You have done this so that you may drown the persons sitting in the boat. You have done something grievous. Thereupon he said: Did I not tell you that you will not be able to bear with me? Thereupon he (Moses) said: Blame me not for what I forgot and be not hard upon me for what I did. (Khadir gave him another chance.) So they went on until they reached a place where boys were playing. He went to one of them and caught hold'of one (apparently) at random and killed him. Moses (peace be upon him) felt agitated and said: You have killed an innocent person not guilty of slaying another. You have done something aboininable. Thereupon Allah's Messenger (ﷺ) said: May Allah have mercy upon us and Moses. Had he shown patience he would have seen wonderful things, but fear of blame, with respect to his companion, seized him and he said: If I ask anything after this, keep not company with me. You will then have a valid excuse in my case, and had he (Moses) shown patience he would have seen many wonderful things. He (the narrator) said: Whenever he (the Holy Prophet) made mention of any Prophet, he always said: May there be mercy of Allah upon us and upon my brother so and so. They, however, proceeded on until they came to the inhabitants of a village who were very miserly. They went to the meeting places and asked for hospitality but they refused to show any hospitality to them. They both found in that village a wall which was about to fall. He (Khadir) set it right. Thereupon he (Moses) said: If you so liked. you could get wages for it. Thereupon he said: This is the partince, of ways between me and you, and, taking hold of his cloth, he said: Now I will explain to you the real significance (of all these acts) for which you could not show patience. As for the boat, it belonged to the poor people working on the river and I intended to damage it for there was ahead of them (a king) who seized boats by force. (When he came) to catch hold of it he found it a damaged boat, so he spared it (and later on) it was set right with wood. So far as the boy is concerned, he has been, by very nature, an unbeliever, whereas his parents loved him very much. Had he grown up he would have involved them in wrongdoing and unbelief, so we wished that their Lord should give them in its place one better in purity and close to mercy. And as for the wall it belonged to two orphan boys in the city and there was beneath it a (treasure) belongin to them,... up to the last verse}}
\hadithdefcmd{muslim}{6166}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا مُحَمَّدُ بْنُ يُوسُفَ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، كِلاَهُمَا عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، بِإِسْنَادِ التَّيْمِيِّ عَنْ أَبِي إِسْحَاقَ، نَحْوَ حَدِيثِهِ ‏.‏\hadithno{6166}\hadithtrans{This hadith has been transmitted on the authority of Abu Ishaq}}
\hadithdefcmd{muslim}{6167}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَرَأَ ‏\{‏ لَتَخِذْتَ عَلَيْهِ أَجْرًا‏\}‏ ‏.‏\hadithno{6167}\hadithtrans{Ibn 'Abbas has reported this hadith on the authority of Ubayy b. ka'b that Allah's Apostle (ﷺ) used to recite this}}
\hadithdefcmd{muslim}{6168}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ تَمَارَى هُوَ وَالْحُرُّ بْنُ قَيْسِ بْنِ حِصْنٍ الْفَزَارِيُّ فِي صَاحِبِ مُوسَى عَلَيْهِ السَّلاَمُ فَقَالَ ابْنُ عَبَّاسٍ هُوَ الْخَضِرُ ‏.‏ فَمَرَّ بِهِمَا أُبَىُّ بْنُ كَعْبٍ الأَنْصَارِيُّ فَدَعَاهُ ابْنُ عَبَّاسٍ فَقَالَ يَا أَبَا الطُّفَيْلِ هَلُمَّ إِلَيْنَا فَإِنِّي قَدْ تَمَارَيْتُ أَنَا وَصَاحِبِي هَذَا فِي صَاحِبِ مُوسَى الَّذِي سَأَلَ السَّبِيلَ إِلَى لُقِيِّهِ فَهَلْ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَذْكُرُ شَأْنَهُ فَقَالَ أُبَىٌّ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ بَيْنَمَا مُوسَى فِي مَلإٍ مِنْ بَنِي إِسْرَائِيلَ إِذْ جَاءَهُ رَجُلٌ فَقَالَ لَهُ هَلْ تَعْلَمُ أَحَدًا أَعْلَمُ مِنْكَ قَالَ مُوسَى لاَ ‏.‏ فَأَوْحَى اللَّهُ إِلَى مُوسَى بَلْ عَبْدُنَا الْخَضِرُ - قَالَ - فَسَأَلَ مُوسَى السَّبِيلَ إِلَى لُقِيِّهِ فَجَعَلَ اللَّهُ لَهُ الْحُوتَ آيَةً وَقِيلَ لَهُ إِذَا افْتَقَدْتَ الْحُوتَ فَارْجِعْ فَإِنَّكَ سَتَلْقَاهُ فَسَارَ مُوسَى مَا شَاءَ اللَّهُ أَنْ يَسِيرَ ثُمَّ قَالَ لِفَتَاهُ آتِنَا غَدَاءَنَا ‏.‏ فَقَالَ فَتَى مُوسَى حِينَ سَأَلَهُ الْغَدَاءَ أَرَأَيْتَ إِذْ أَوَيْنَا إِلَى الصَّخْرَةِ فَإِنِّي نَسِيتُ الْحُوتَ وَمَا أَنْسَانِيهُ إِلاَّ الشَّيْطَانُ أَنْ أَذْكُرَهُ ‏.‏ فَقَالَ مُوسَى لِفَتَاهُ ذَلِكَ مَا كُنَّا نَبْغِي ‏.‏ فَارْتَدَّا عَلَى آثَارِهِمَا قَصَصًا فَوَجَدَا خَضِرًا ‏.‏ فَكَانَ مِنْ شَأْنِهِمَا مَا قَصَّ اللَّهُ فِي كِتَابِهِ ‏"‏ ‏.‏ إِلاَّ أَنَّ يُونُسَ قَالَ فَكَانَ يَتَّبِعُ أَثَرَ الْحُوتِ فِي الْبَحْرِ ‏.‏\hadithno{6168}\hadithtrans{Utba b. Mas, ud reported that 'Abdullah b. 'Abbas contended with Hurr b. Qais b. Hisn al-Fazari aboat the companion of Moses (peace be upon hiin). Ibn 'Abbas said that he was Khadir. There happened to pass Ubayy b. Ka'b Ansari. Ibn Abbas called him and said:Abu Tufail, come to us. There has been a difference of opinion between me and my friend about the companion of Moses whom he wanted to meet on the way. Did hear anything from Allah's meesenger (ﷺ) making a mention of anything? Ubayy said: I heard Allah's Messenger (may Peace be upon him) as saying: As Moses was amongst the group of Bani Isra'il, there came to him a person and he said to him: Do you know anyone having better knowledge than you? Moses said: No. Thereupon Allah revealed to Moses: Of course, there is amongst Our servants Khadir (who has better knowledge) than you. Moses asked the way of meeting him. Allah made the fish a sign and it was said to him: Where you miss the fish return to that (place) and you will soon find him. So Moses moved on as Allah wished him to move on. He then said to his young companion: Bring for us the breakfast. Thereupop that young man said to Moses. when he asked him for the breakfast: Don't you see that as we had reached the Sakhra I forgot the fish and nobody made it forget (in our mind) but the satan that I should remind you of it? Mosed said to that young man: This was what we wanted. So they retraced their steps and met Khadir and the events which followed have been described in His Book except that Yunus (the narrator) said that he followed the traces of fish in the ocean}}
