% Auto-generated chapter 13 for abudawud
% Hadiths in this chapter: 138

\hadithdefcmd{abudawud}{2175}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا عَمَّارُ بْنُ رُزَيْقٍ، عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى، عَنْ عِكْرِمَةَ، عَنْ يَحْيَى بْنِ يَعْمُرَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ مِنَّا مَنْ خَبَّبَ امْرَأَةً عَلَى زَوْجِهَا أَوْ عَبْدًا عَلَى سَيِّدِهِ ‏"‏ ‏.‏\hadithno{2175}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Anyone who incites a woman against her husband or a slave against his master is not one of us}}
\hadithdefcmd{abudawud}{2176}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَسْأَلِ الْمَرْأَةُ طَلاَقَ أُخْتِهَا لِتَسْتَفْرِغَ صَحْفَتَهَا وَلْتَنْكِحْ فَإِنَّمَا لَهَا مَا قُدِّرَ لَهَا ‏"‏ ‏.‏\hadithno{2176}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6601)}\hadithtrans{Abu Hurairah reported the Apostle of Allaah(ﷺ) as saying “A woman should not ask for the divorce of her sister to make her bowl vacant for her and to marry him. She will have what is decreed for her.”}}
\hadithdefcmd{abudawud}{2177}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا مُعَرِّفٌ، عَنْ مُحَارِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أَحَلَّ اللَّهُ شَيْئًا أَبْغَضَ إِلَيْهِ مِنَ الطَّلاَقِ ‏"‏ ‏.‏\hadithno{2177}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Muharib: The Prophet (ﷺ) said: Allah did not make anything lawful more abominable to Him than divorce}}
\hadithdefcmd{abudawud}{2178}{حَدَّثَنَا كَثِيرُ بْنُ عُبَيْدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدٍ، عَنْ مُعَرِّفِ بْنِ وَاصِلٍ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَبْغَضُ الْحَلاَلِ إِلَى اللَّهِ تَعَالَى الطَّلاَقُ ‏"‏ ‏.‏\hadithno{2178}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: Of all the lawful acts the most detestable to Allah is divorce}}
\hadithdefcmd{abudawud}{2179}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَ عُمَرُ بْنُ الْخَطَّابِ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا ثُمَّ لْيُمْسِكْهَا حَتَّى تَطْهُرَ ثُمَّ تَحِيضَ ثُمَّ تَطْهُرَ ثُمَّ إِنْ شَاءَ أَمْسَكَ بَعْدَ ذَلِكَ وَإِنْ شَاءَ طَلَّقَ قَبْلَ أَنْ يَمَسَّ فَتِلْكَ الْعِدَّةُ الَّتِي أَمَرَ اللَّهُ سُبْحَانَهُ أَنْ تُطَلَّقَ لَهَا النِّسَاءُ ‏"‏ ‏.‏\hadithno{2179}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5251) Sahih Muslim (1471)}\hadithtrans{‘Abd Allah bin Umar said that he divorced his wife while she was menstruating during the time of the Apostle of Allaah(ﷺ). So ‘Umar bin Al Khattab asked the Apostle of Allaah(ﷺ) about this matter. The Apostle of Allaah(ﷺ) said “Order him, he must take her back and keep her back till she is purified, then has another menstrual period and is purified. Thereafter if he desires he may divorce her before having intercourse with her, for that is the period of waiting which Allaah the Glorified has commanded for the divorce of women.”}}
\hadithdefcmd{abudawud}{2180}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، طَلَّقَ امْرَأَةً لَهُ وَهِيَ حَائِضٌ تَطْلِيقَةً بِمَعْنَى حَدِيثِ مَالِكٍ ‏.‏\hadithno{2180}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5332) Sahih Muslim (1471)}\hadithtrans{The aforesaid tradition has also been transmitted by Nafi’ through a different chain of narrators. This version says Ibn ‘Umar divorced a wife of his while she was menstruating pronouncing one divorce. He then narrated the rest of the tradition similar to the one narrated by Malik}}
\hadithdefcmd{abudawud}{2181}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، مَوْلَى آلِ طَلْحَةَ عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَذَكَرَ ذَلِكَ عُمَرُ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا ثُمَّ لْيُطَلِّقْهَا إِذَا طَهُرَتْ أَوْ وَهِيَ حَامِلٌ ‏"‏ ‏.‏\hadithno{2181}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1471)}\hadithtrans{Ibn ‘Umar said that he divorced his wife while she was menstruating. ‘Umar mentioned the matter to the Prophet(ﷺ). He (the Prophet) said “Order him, he must take her back and divorce her when she is purified (from menstrual discharge) or she is pregnant.”}}
\hadithdefcmd{abudawud}{2182}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّهُ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ فَذَكَرَ ذَلِكَ عُمَرُ لِرَسُولِ صلى الله عليه وسلم فَتَغَيَّظَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا ثُمَّ لْيُمْسِكْهَا حَتَّى تَطْهُرَ ثُمَّ تَحِيضَ فَتَطْهُرَ ثُمَّ إِنْ شَاءَ طَلَّقَهَا طَاهِرًا قَبْلَ أَنْ يَمَسَّ فَذَلِكَ الطَّلاَقُ لِلْعِدَّةِ كَمَا أَمَرَ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{2182}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (7160) Sahih Muslim (1471)}\hadithtrans{‘Abd Allah (bin Umar) said that he divorced his wife while she was menstruating. ‘Umar mentioned the matter to the Messenger of Allah(ﷺ). The Messenger of Allah(ﷺ) became angry and said “Command him, he must take her back and keep her back till she is purified, then has another menstrual period and is purified. Then if he desires he may divorce her during the period of purity before he has intercourse with her. This is the divorce for waiting period as commanded by Allaah, the Exalted}}
\hadithdefcmd{abudawud}{2183}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، أَخْبَرَنِي يُونُسُ بْنُ جُبَيْرٍ، أَنَّهُ سَأَلَ ابْنَ عُمَرَ فَقَالَ كَمْ طَلَّقْتَ امْرَأَتَكَ فَقَالَ وَاحِدَةً ‏.‏\hadithno{2183}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari (5333) Sahih Muslim (1471)}\hadithtrans{Yunus bin Jubair said that he asked Ibn ‘Umar “How many times did you pronounce divorce to your wife? He replied, once.”}}
\hadithdefcmd{abudawud}{2184}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ إِبْرَاهِيمَ - عَنْ مُحَمَّدِ بْنِ سِيرِينَ، حَدَّثَنِي يُونُسُ بْنُ جُبَيْرٍ، قَالَ سَأَلْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ قَالَ قُلْتُ رَجُلٌ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ ‏.‏ قَالَ تَعْرِفُ عَبْدَ اللَّهِ بْنَ عُمَرَ قُلْتُ نَعَمْ ‏.‏ قَالَ فَإِنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ ‏.‏ فَأَتَى عُمَرُ النَّبِيَّ صلى الله عليه وسلم فَسَأَلَهُ فَقَالَ ‏ "‏ مُرْهُ فَلْيُرَاجِعْهَا ثُمَّ لْيُطَلِّقْهَا فِي قُبُلِ عِدَّتِهَا ‏"‏ ‏.‏ قَالَ قُلْتُ فَيُعْتَدُّ بِهَا قَالَ فَمَهْ أَرَأَيْتَ إِنْ عَجَزَ وَاسْتَحْمَقَ\hadithno{2184}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5333) Sahih Muslim (1471)}\hadithtrans{Yunus bin Jubair said “I asked ‘Abd Allah bin ‘Umar “A man divorced his wife while she was menstruating? He said do you know ‘Abd Allah bin ‘Umar? He said, yes. ‘Abd Allah bin ‘Umar divorced his wife while she was menstruating. So, ‘Umar came to the Prophet (ﷺ) and asked him (about this matter). He said Command him to take her back in marriage he may the divorce her in the beginning of the waiting period. I (Ibn Jubair) asked him “Will this divorce be counted? He said “Why not?” If he was helpless and showed his foolishness (that would have been counted)}}
\hadithdefcmd{abudawud}{2185}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ عَبْدَ الرَّحْمَنِ بْنَ أَيْمَنَ، مَوْلَى عُرْوَةَ يَسْأَلُ ابْنَ عُمَرَ وَأَبُو الزُّبَيْرِ يَسْمَعُ قَالَ كَيْفَ تَرَى فِي رَجُلٍ طَلَّقَ امْرَأَتَهُ حَائِضًا قَالَ طَلَّقَ عَبْدُ اللَّهِ بْنُ عُمَرَ امْرَأَتَهُ وَهِيَ حَائِضٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَ عُمَرُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ طَلَّقَ امْرَأَتَهُ وَهِيَ حَائِضٌ قَالَ عَبْدُ اللَّهِ فَرَدَّهَا عَلَىَّ وَلَمْ يَرَهَا شَيْئًا وَقَالَ ‏"‏ إِذَا طَهُرَتْ فَلْيُطَلِّقْ أَوْ لِيُمْسِكْ ‏"‏ ‏.‏ قَالَ ابْنُ عُمَرَ وَقَرَأَ النَّبِيُّ صلى الله عليه وسلم ‏\{‏ يَا أَيُّهَا النَّبِيُّ إِذَا طَلَّقْتُمُ النِّسَاءَ فَطَلِّقُوهُنَّ ‏\}‏ فِي قُبُلِ عِدَّتِهِنَّ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذَا الْحَدِيثَ عَنِ ابْنِ عُمَرَ يُونُسُ بْنُ جُبَيْرٍ وَأَنَسُ بْنُ سِيرِينَ وَسَعِيدُ بْنُ جُبَيْرٍ وَزَيْدُ بْنُ أَسْلَمَ وَأَبُو الزُّبَيْرِ وَمَنْصُورٌ عَنْ أَبِي وَائِلٍ مَعْنَاهُمْ كُلُّهُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهُ أَنْ يُرَاجِعَهَا حَتَّى تَطْهُرَ ثُمَّ إِنْ شَاءَ طَلَّقَ وَإِنْ شَاءَ أَمْسَكَ وَكَذَلِكَ رَوَاهُ مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ عَنْ سَالِمٍ عَنِ ابْنِ عُمَرَ وَأَمَّا رِوَايَةُ الزُّهْرِيِّ عَنْ سَالِمٍ وَنَافِعٍ عَنِ ابْنِ عُمَرَ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَهُ أَنْ يُرَاجِعَهَا حَتَّى تَطْهُرَ ثُمَّ تَحِيضَ ثُمَّ تَطْهُرَ ثُمَّ إِنْ شَاءَ طَلَّقَ وَإِنْ شَاءَ أَمْسَكَ وَرُوِيَ عَنْ عَطَاءٍ الْخُرَاسَانِيِّ عَنِ الْحَسَنِ عَنِ ابْنِ عُمَرَ نَحْوُ رِوَايَةِ نَافِعٍ وَالزُّهْرِيِّ وَالأَحَادِيثُ كُلُّهَا عَلَى خِلاَفِ مَا قَالَ أَبُو الزُّبَيْرِ ‏.‏\hadithno{2185}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1471)}\hadithtrans{Abdur Rahman ibn Ayman, the client of Urwah, asked Ibn Umar and Abu al-Zubayr was was listening:What do you think if a man divorces his wife while she is menstruating? He said: Abdullah ibn Umar divorced his wife while she was menstruating during the time of the Messenger of Allah (ﷺ).So Umar asked the Messenger of Allah (ﷺ) saying: Abdullah ibn Umar divorced his wife while she was menstruating. Abdullah said: He returned her to me and did not count it (the pronouncement) anything. He said: When she is purified, he may divorce her or keep her with him. Ibn Umar said: The Prophet (ﷺ) recited the Qur'anic verse: O Prophet, when you divorce women, divorce them in the beginning of their waiting period." Abu Dawud said: This tradition has been narrated by Yunus b. Jubair, Anas b. Sirin b. Jubair, Zaid b. Aslam, Abu al-Zubair and Mansur from Abu Wa'il on the authority of Ibn 'Umar. They all agreed on the theme that the Prophet (ﷺ) commanded him to take her back (and keep her) till she was purified. Then if he desired, he might divorce her or keep her with him if he wanted to do so. The version narrated by al-Zuhri from Salim from Nafi' on the authority of Ibn 'Umar has: The Prophet (ﷺ) commanded him to take her back (and keep her) till she is purified, and then has menstrual discharge, and then she is purified. Then if he desires, he may divorce her and if he desires he may keep her. Abu Dawud said: A version like that of Nafi' and al-Zuhri has also been transmitted by 'Ata al-Khurasani from al-Hasan on the authority of Ibn 'Umar. All the versions of this tradition contradict the one narrated by Abu al-Zubair}}
\hadithdefcmd{abudawud}{2186}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ، أَنَّ جَعْفَرَ بْنَ سُلَيْمَانَ، حَدَّثَهُمْ عَنْ يَزِيدَ الرِّشْكِ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ، أَنَّ عِمْرَانَ بْنَ حُصَيْنٍ، سُئِلَ عَنِ الرَّجُلِ، يُطَلِّقُ امْرَأَتَهُ ثُمَّ يَقَعُ بِهَا وَلَمْ يُشْهِدْ عَلَى طَلاَقِهَا وَلاَ عَلَى رَجْعَتِهَا فَقَالَ طَلَّقْتَ لِغَيْرِ سُنَّةٍ ‏.‏ وَرَاجَعْتَ لِغَيْرِ سُنَّةٍ أَشْهِدْ عَلَى طَلاَقِهَا وَعَلَى رَجْعَتِهَا وَلاَ تَعُدْ ‏.‏\hadithno{2186}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Mutarrif ibn Abdullah: Imran ibn Husayn was asked about a person who divorces his wife, and then has intercourse with her, but he does not call any witness to her divorce nor to her restoration. He said: You divorced against the sunnah and took her back against the sunnah. Call someone to bear witness to her divorce, and to her return in marriage, and do not repeat it}}
\hadithdefcmd{abudawud}{2187}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، أَنَّ عُمَرَ بْنَ مُعَتِّبٍ، أَخْبَرَهُ أَنَّ أَبَا حَسَنٍ مَوْلَى بَنِي نَوْفَلٍ أَخْبَرَهُ أَنَّهُ، اسْتَفْتَى ابْنَ عَبَّاسٍ فِي مَمْلُوكٍ كَانَتْ تَحْتَهُ مَمْلُوكَةٌ فَطَلَّقَهَا تَطْلِيقَتَيْنِ ثُمَّ عَتَقَا بَعْدَ ذَلِكَ هَلْ يَصْلُحُ لَهُ أَنْ يَخْطُبَهَا قَالَ نَعَمْ قَضَى بِذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2187}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umar ibn Mu'tab: Abu Hasan, a client of Banu Nawfal asked Ibn Abbas: A slave had a wife who was a slave-girl. He divorced her by two pronouncements. Afterwards both of them were freed. Is it permissible for him to ask her in marriage again? He said: Yes. This is a decision given by the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{2188}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا عَلِيٌّ، بِإِسْنَادِهِ وَمَعْنَاهُ بِلاَ إِخْبَارٍ قَالَ ابْنُ عَبَّاسٍ بَقِيَتْ لَكَ وَاحِدَةٌ قَضَى بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ سَمِعْتُ أَحْمَدَ بْنَ حَنْبَلٍ قَالَ قَالَ عَبْدُ الرَّزَّاقِ قَالَ ابْنُ الْمُبَارَكِ لِمَعْمَرٍ مَنْ أَبُو الْحَسَنِ هَذَا لَقَدْ تَحَمَّلَ صَخْرَةً عَظِيمَةً ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو الْحَسَنِ هَذَا رَوَى عَنْهُ الزُّهْرِيُّ قَالَ الزُّهْرِيُّ وَكَانَ مِنَ الْفُقَهَاءِ رَوَى الزُّهْرِيُّ عَنْ أَبِي الْحَسَنِ أَحَادِيثَ ‏.‏ قَالَ أَبُو دَاوُدَ أَبُو الْحَسَنِ مَعْرُوفٌ وَلَيْسَ الْعَمَلُ عَلَى هَذَا الْحَدِيثِ ‏.‏\hadithno{2188}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The aforesaid tradition (No. 2182) has also been transmitted by Ali (ibn al-Mubarak) through a different chain of narrators to the same effect. This version adds:Ibn Abbas said: There remained one more pronouncement of divorce for you. The Messenger of Allah (ﷺ) took the same decision. Abu Dawud said: I heard Ahmad b. Hanbal say: 'Abd al-Razzaq said that Ibn al-Mubarak said to Ma'mar: Who is this Abu al-Hasan ? He bore a big rock. Abu Dawud said: Al-Zuhri has narrated (traditions) on the authority of this Abu al-Hasan. Al-Zuhri said: He was lawyer, and al-Zuhri narrated many traditions from Abu al-Hasan. Abu Dawud said: Abu al-Hasan is well known narrator. This tradition is not practiced}}
\hadithdefcmd{abudawud}{2189}{حَدَّثَنَا مُحَمَّدُ بْنُ مَسْعُودٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ مُظَاهِرٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ طَلاَقُ الأَمَةِ تَطْلِيقَتَانِ وَقُرْؤُهَا حَيْضَتَانِ ‏"‏ ‏.‏ قَالَ أَبُو عَاصِمٍ حَدَّثَنِي مُظَاهِرٌ حَدَّثَنِي الْقَاسِمُ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ إِلاَّ أَنَّهُ قَالَ ‏"‏ وَعِدَّتُهَا حَيْضَتَانِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ حَدِيثٌ مَجْهُولٌ ‏.‏\hadithno{2189}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) said: The divorce of a slave-woman consists in saying it twice and her waiting period is two menstrual courses (qur') AbuAsim said: A similar tradition has been narrated to me by Muzahir and al-Qasim on the authority of Aisha from the Prophet (ﷺ), except that he said: And her waiting period ('iddah) is two courses. Abu Dawud said: This tradition is obscure}}
\hadithdefcmd{abudawud}{2190}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، ح وَحَدَّثَنَا ابْنُ الصَّبَّاحِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ، قَالاَ حَدَّثَنَا مَطَرٌ الْوَرَّاقُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ طَلاَقَ إِلاَّ فِيمَا تَمْلِكُ وَلاَ عِتْقَ إِلاَّ فِيمَا تَمْلِكُ وَلاَ بَيْعَ إِلاَّ فِيمَا تَمْلِكُ ‏"‏ ‏.‏ زَادَ ابْنُ الصَّبَّاحِ ‏"‏ وَلاَ وَفَاءَ نَذْرٍ إِلاَّ فِيمَا تَمْلِكُ ‏"‏ ‏.‏\hadithno{2190}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr b. Shu'aib on his father's authority said that his grandfather (Abdullah ibn Amr ibn al-'As):The Prophet (ﷺ) said: There is no divorce except in what you possess; there is no possession, there is no sale transaction till you possess. The narrator Ibn as-Sabbah added: There is no fulfilling a vow till you possess}}
\hadithdefcmd{abudawud}{2191}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، أَخْبَرَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ الْحَارِثِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، بِإِسْنَادِهِ وَمَعْنَاهُ زَادَ ‏ "‏ مَنْ حَلَفَ عَلَى مَعْصِيَةٍ فَلاَ يَمِينَ لَهُ وَمَنْ حَلَفَ عَلَى قَطِيعَةِ رَحِمٍ فَلاَ يَمِينَ لَهُ ‏"‏ ‏.‏\hadithno{2191}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{The above tradition has also been transmitted by ‘Amr bin Shu’aib through a different chain of narrators to the same effect. This version adds “If anyone swears an oath to do an act of disobedience to GOD, his oath is not valid, and if anyone swears an oath to sever relationship, his oath is not valid(i.e., he must not fulfill it)}}
\hadithdefcmd{abudawud}{2192}{حَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ سَالِمٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ الْمَخْزُومِيِّ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ فِي هَذَا الْخَبَرِ زَادَ ‏ "‏ وَلاَ نَذْرَ إِلاَّ فِيمَا ابْتُغِيَ بِهِ وَجْهُ اللَّهِ تَعَالَى ذِكْرُهُ ‏"‏ ‏.‏\hadithno{2192}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{The above tradition has also been transmitted by ‘Amr bin Shu’aib through a different chain of narrators. This version adds The Prophet (ﷺ) said “There is no vow except in an act which seeks the pleasure of Allah, the Exalted}}
\hadithdefcmd{abudawud}{2193}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعْدٍ الزُّهْرِيُّ، أَنَّ يَعْقُوبَ بْنَ إِبْرَاهِيمَ، حَدَّثَهُمْ قَالَ حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، عَنْ ثَوْرِ بْنِ يَزِيدَ الْحِمْصِيِّ، عَنْ مُحَمَّدِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَبِي صَالِحٍ الَّذِي، كَانَ يَسْكُنُ إِيلْيَا قَالَ خَرَجْتُ مَعَ عَدِيِّ بْنِ عَدِيٍّ الْكِنْدِيِّ حَتَّى قَدِمْنَا مَكَّةَ فَبَعَثَنِي إِلَى صَفِيَّةَ بِنْتِ شَيْبَةَ وَكَانَتْ قَدْ حَفِظَتْ مِنْ عَائِشَةَ قَالَتْ سَمِعْتُ عَائِشَةَ تَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ طَلاَقَ وَلاَ عَتَاقَ فِي غَلاَقٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الْغِلاَقُ أَظُنُّهُ فِي الْغَضَبِ ‏.‏\hadithno{2193}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Muhammad ibn Ubayd ibn Abu Salih who lived in Ayliya said:I went out with Adi ibn Adi al-Kindi till we came to Mecca. He sent me to Safiyyah daughter of Shaybah who remembered a tradition (that she had heard) from Aisha. She said: I heard Aisha say: I heard the Messenger of Allah (ﷺ) say: There is no divorce or emancipation in case of constraint or duress (ghalaq). Abu Dawud said: I think ghalaq means anger}}
\hadithdefcmd{abudawud}{2194}{حَدَّثَنَا الْقَعْنَبِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ حَبِيبٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنِ ابْنِ مَاهَكَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثٌ جِدُّهُنَّ جِدٌّ وَهَزْلُهُنَّ جِدٌّ النِّكَاحُ وَالطَّلاَقُ وَالرَّجْعَةُ ‏"‏ ‏.‏\hadithno{2194}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: There are three things which, whether undertaken seriously or in jest, are treated as serious: Marriage, divorce and taking back a wife (after a divorce which is not final)}}
\hadithdefcmd{abudawud}{2195}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنِ بْنِ وَاقِدٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏\{‏ وَالْمُطَلَّقَاتُ يَتَرَبَّصْنَ بِأَنْفُسِهِنَّ ثَلاَثَةَ قُرُوءٍ وَلاَ يَحِلُّ لَهُنَّ أَنْ يَكْتُمْنَ مَا خَلَقَ اللَّهُ فِي أَرْحَامِهِنَّ ‏\}‏ الآيَةَ وَذَلِكَ أَنَّ الرَّجُلَ كَانَ إِذَا طَلَّقَ امْرَأَتَهُ فَهُوَ أَحَقُّ بِرَجْعَتِهَا وَإِنْ طَلَّقَهَا ثَلاَثًا فَنُسِخَ ذَلِكَ وَقَالَ ‏\{‏ الطَّلاَقُ مَرَّتَانِ ‏\}‏ ‏.‏\hadithno{2195}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: Divorced women shall wait concerning themselves for three monthly periods. Nor is it lawful for them to hide what Allah hath created in their wombs. This means that if a man divorced his wife he had the right to take her back in marriage though he had divorced her by three pronouncements. This was then repealed (by a Qur'anic verse). Divorce is only permissible twice}}
\hadithdefcmd{abudawud}{2196}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي بَعْضُ بَنِي أَبِي رَافِعٍ، مَوْلَى النَّبِيِّ صلى الله عليه وسلم عَنْ عِكْرِمَةَ مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ قَالَ طَلَّقَ عَبْدُ يَزِيدَ - أَبُو رُكَانَةَ وَإِخْوَتِهِ - أُمَّ رُكَانَةَ وَنَكَحَ امْرَأَةً مِنْ مُزَيْنَةَ فَجَاءَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ مَا يُغْنِي عَنِّي إِلاَّ كَمَا تُغْنِي هَذِهِ الشَّعْرَةُ ‏.‏ لِشَعْرَةٍ أَخَذَتْهَا مِنْ رَأْسِهَا فَفَرِّقْ بَيْنِي وَبَيْنَهُ فَأَخَذَتِ النَّبِيَّ صلى الله عليه وسلم حَمِيَّةٌ فَدَعَا بِرُكَانَةَ وَإِخْوَتِهِ ثُمَّ قَالَ لِجُلَسَائِهِ ‏"‏ أَتَرَوْنَ فُلاَنًا يُشْبِهُ مِنْهُ كَذَا وَكَذَا مِنْ عَبْدِ يَزِيدَ وَفُلاَنًا يُشْبِهُ مِنْهُ - كَذَا وَكَذَا ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم لِعَبْدِ يَزِيدَ ‏"‏ طَلِّقْهَا ‏"‏ ‏.‏ فَفَعَلَ ثُمَّ قَالَ ‏"‏ رَاجِعِ امْرَأَتَكَ أُمَّ رُكَانَةَ وَإِخْوَتِهِ ‏"‏ ‏.‏ فَقَالَ إِنِّي طَلَّقْتُهَا ثَلاَثًا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ قَدْ عَلِمْتُ رَاجِعْهَا ‏"‏ ‏.‏ وَتَلاَ ‏\{‏ يَا أَيُّهَا النَّبِيُّ إِذَا طَلَّقْتُمُ النِّسَاءَ فَطَلِّقُوهُنَّ لِعِدَّتِهِنَّ ‏\}‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدِيثُ نَافِعِ بْنِ عُجَيْرٍ وَعَبْدِ اللَّهِ بْنِ عَلِيِّ بْنِ يَزِيدَ بْنِ رُكَانَةَ عَنْ أَبِيهِ عَنْ جَدِّهِ أَنَّ رُكَانَةَ طَلَّقَ امْرَأَتَهُ الْبَتَّةَ فَرَدَّهَا إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم أَصَحُّ لأَنَّ وَلَدَ الرَّجُلِ وَأَهْلَهُ أَعْلَمُ بِهِ أَنَّ رُكَانَةَ إِنَّمَا طَلَّقَ امْرَأَتَهُ الْبَتَّةَ فَجَعَلَهَا النَّبِيُّ صلى الله عليه وسلم وَاحِدَةً ‏.‏\hadithno{2196}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: Abd Yazid, the father of Rukanah and his brothers, divorced Umm Rukanah and married a woman of the tribe of Muzaynah. She went to the Prophet (ﷺ) and said: He is of no use to me except that he is as useful to me as a hair; and she took a hair from her head. So separate me from him. The Prophet (ﷺ) became furious. He called on Rukanah and his brothers. He then said to those who were sitting beside him. Do you see so-and-so who resembles Abdu Yazid in respect of so-and-so; and so-and-so who resembles him in respect of so-and-so? They replied: Yes. The Prophet (ﷺ) said to Abdu Yazid: Divorce her. Then he did so. He said: Take your wife, the mother of Rukanah and his brothers, back in marriage. He said: I have divorced her by three pronouncements, Messenger of Allah. He said: I know: take her back. He then recited the verse: "O Prophet, when you divorce women, divorce them at their appointed periods." Abu Dawud said: The tradition narrated by Nafi' b. 'Ujair and 'Abd Allah b. Yazid b. Rukanah from his father on the authority of his grandfather reads: Rukanah divorced his wife absolutely (i.e. irrevocable divorce). The Prophet (ﷺ) restored her to him. This version is sounder (than other versions), for they (i.e. these narrators) are the children of his man, and the members of the family are more aware of his case. Rukanah divorced his wife absolutely (i.e. three divorces in one pronouncement) and the Prophet (ﷺ) made it a single divorce}}
\hadithdefcmd{abudawud}{2197}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا إِسْمَاعِيلُ، أَخْبَرَنَا أَيُّوبُ، عَنْ عَبْدِ اللَّهِ بْنِ كَثِيرٍ، عَنْ مُجَاهِدٍ، قَالَ كُنْتُ عِنْدَ ابْنِ عَبَّاسٍ فَجَاءَ رَجُلٌ فَقَالَ إِنَّهُ طَلَّقَ امْرَأَتَهُ ثَلاَثًا ‏.‏ قَالَ فَسَكَتَ حَتَّى ظَنَنْتُ أَنَّهُ رَادُّهَا إِلَيْهِ ‏.‏ ثُمَّ قَالَ يَنْطَلِقُ أَحَدُكُمْ فَيَرْكَبُ الْحَمُوقَةَ ثُمَّ يَقُولُ يَا ابْنَ عَبَّاسٍ يَا ابْنَ عَبَّاسٍ وَإِنَّ اللَّهَ قَالَ ‏\{‏ وَمَنْ يَتَّقِ اللَّهَ يَجْعَلْ لَهُ مَخْرَجًا ‏\}‏ وَإِنَّكَ لَمْ تَتَّقِ اللَّهَ فَلَمْ أَجِدْ لَكَ مَخْرَجًا عَصَيْتَ رَبَّكَ وَبَانَتْ مِنْكَ امْرَأَتُكَ وَإِنَّ اللَّهَ قَالَ ‏\{‏ يَا أَيُّهَا النَّبِيُّ إِذَا طَلَّقْتُمُ النِّسَاءَ فَطَلِّقُوهُنَّ ‏\}‏ فِي قُبُلِ عِدَّتِهِنَّ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذَا الْحَدِيثَ حُمَيْدٌ الأَعْرَجُ وَغَيْرُهُ عَنْ مُجَاهِدٍ عَنِ ابْنِ عَبَّاسٍ وَرَوَاهُ شُعْبَةُ عَنْ عَمْرِو بْنِ مُرَّةَ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ وَأَيُّوبُ وَابْنُ جُرَيْجٍ جَمِيعًا عَنْ عِكْرِمَةَ بْنِ خَالِدٍ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ وَرَوَاهُ ابْنُ جُرَيْجٍ عَنْ عَبْدِ الْحَمِيدِ بْنِ رَافِعٍ عَنْ عَطَاءٍ عَنِ ابْنِ عَبَّاسٍ وَرَوَاهُ الأَعْمَشُ عَنْ مَالِكِ بْنِ الْحَارِثِ عَنِ ابْنِ عَبَّاسٍ وَابْنُ جُرَيْجٍ عَنْ عَمْرِو بْنِ دِينَارٍ عَنِ ابْنِ عَبَّاسٍ كُلُّهُمْ قَالُوا فِي الطَّلاَقِ الثَّلاَثِ إِنَّهُ أَجَازَهَا قَالَ وَبَانَتْ مِنْكَ نَحْوَ حَدِيثِ إِسْمَاعِيلَ عَنْ أَيُّوبَ عَنْ عَبْدِ اللَّهِ بْنِ كَثِيرٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَى حَمَّادُ بْنُ زَيْدٍ عَنْ أَيُّوبَ عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ إِذَا قَالَ ‏"‏ أَنْتِ طَالِقٌ ثَلاَثًا ‏"‏ ‏.‏ بِفَمٍ وَاحِدٍ فَهِيَ وَاحِدَةٌ وَرَوَاهُ إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ عَنْ أَيُّوبَ عَنْ عِكْرِمَةَ هَذَا قَوْلُهُ لَمْ يَذْكُرِ ابْنَ عَبَّاسٍ وَجَعَلَهُ قَوْلَ عِكْرِمَةَ ‏.‏\hadithno{2197}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mujahid said “I was with Ibn ‘Abbas”. A man came to him and said that he divorced his wife by three pronouncements. I kept silence and thought that he was going to restore het to him. He then said “A man goes and commits a foolish act and then says “O, Ibn ‘Abbas! Alaah has said “And for those who fear Allaah, He (ever) prepares a way out.” Since you did not keep duty to Allaah I do not find a way out for you. You disobeyed your Lord and your wife was separated from you. Allaah has said “O Prophet! When you divorce women divorce them in the beginning of their waiting period.” Abu Dawud said “This tradition has been transmitted by Humaid Al A’raj and by others from Mujahid on the authority of Ibn ‘Abbas. Shu’bjh narrated it from ‘Amr bin Murrah from Sa’id bin Jubair on the authority of Ibn ‘Abbas. Ayyub and Ibn ‘Jubair both narrated it from “’Ikrimah bin Khalid from Sa’id bin Jubair on the authority of Ibn ‘Abbas. Ibn Juraij narrated it from ‘Abd Al Hamid bin Rafi’ from ‘Ata from Ibn ‘Abbas. Al A’mash narrated it from Malik bin Al Harith on the authority of Ibn ‘Abbas. They all said about the divorce by three pronouncements. He allowed it and said” (Your wife) has been separated from you similar to the tradition narrated by Isma’il from Ayub from ‘Abd Allaah bin Kathir.” Abu Dawud said “Hammad bin Zaid narrated it from Ayyub from ‘Ikrimah on the authority of Ibn ‘Abbas. This version adds If he said “You are divorced three times saying in one pronouncement, it constitutes a single (divorce). Isma’il bin Ibrahim narrated it from Ayyub from ‘Ikrimah. This is his (‘Ikrimah’s) statement. He did not mention the name of Ibn ‘Abbas. He narrated it as a statement of ‘Ikrimah.”}}
\hadithdefcmd{abudawud}{2198}{وَصَارَ قَوْلُ ابْنِ عَبَّاسٍ فِيمَا حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، وَمُحَمَّدُ بْنُ يَحْيَى، - وَهَذَا حَدِيثُ أَحْمَدَ - قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، وَمُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، عَنْ مُحَمَّدِ بْنِ إِيَاسٍ، أَنَّ ابْنَ عَبَّاسٍ، وَأَبَا، هُرَيْرَةَ وَعَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ سُئِلُوا عَنِ الْبِكْرِ، يُطَلِّقُهَا زَوْجُهَا ثَلاَثًا فَكُلُّهُمْ قَالُوا لاَ تَحِلُّ لَهُ حَتَّى تَنْكِحَ زَوْجًا غَيْرَهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَى مَالِكٌ عَنْ يَحْيَى بْنِ سَعِيدٍ عَنْ بُكَيْرِ بْنِ الأَشَجِّ عَنْ مُعَاوِيَةَ بْنِ أَبِي عَيَّاشٍ أَنَّهُ شَهِدَ هَذِهِ الْقِصَّةَ حِينَ جَاءَ مُحَمَّدُ بْنُ إِيَاسِ بْنِ الْبُكَيْرِ إِلَى ابْنِ الزُّبَيْرِ وَعَاصِمِ بْنِ عُمَرَ فَسَأَلَهُمَا عَنْ ذَلِكَ فَقَالاَ اذْهَبْ إِلَى ابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ فَإِنِّي تَرَكْتُهُمَا عِنْدَ عَائِشَةَ - رضى الله عنها - ثُمَّ سَاقَ هَذَا الْخَبَرَ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَوْلُ ابْنِ عَبَّاسٍ هُوَ أَنَّ الطَّلاَقَ الثَّلاَثَ تَبِينُ مِنْ زَوْجِهَا مَدْخُولاً بِهَا وَغَيْرَ مَدْخُولٍ بِهَا لاَ تَحِلُّ لَهُ حَتَّى تَنْكِحَ زَوْجًا غَيْرَهُ هَذَا مِثْلُ خَبَرِ الصَّرْفِ قَالَ فِيهِ ثُمَّ إِنَّهُ رَجَعَ عَنْهُ يَعْنِي ابْنَ عَبَّاسٍ ‏.‏\hadithno{2198}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Dawud said “The opinion of Ibn ‘Abbas has been mentioned in the following tradition. “Ahmad bin Salih and Muhammad bin Yahya narrated this is the version of Ahmad (bin Salih)” from ‘Abd Ar Razzaq from Ma’mar from Al Zuhri from Abu Salamah din Abd Al Rahman bin ‘Awf and Muhammad bin ‘Abd Al Rahman bin Thawban from Muhammad bin Iyas that Ibn ‘Abbas, Abu Hurairah and ‘Abd Alah bin ‘Amr bin Al ‘As were asked about a virgin who is divorced three times by her husband. They all said “She is not lawful for him until she marries a man other than her former husband.” Abu Dawud said “Malik narrated from Yahya bin Sa’id from Bukair bin Al Ashajj from Mu’awiyah bin Abi ‘Ayyash who was present on this occasion when Muhammad bin Iyas bin Al Bukair came to Ibn Al Zubair and Asim in ‘Umar. He asked them about this matter. They replied “Go to Ibn ‘Abbas and Abu Hurairah, I have left them with A’ishah (may Allaah be pleased with her). He then narrated the rest of the tradition.” Abu Dawud said “The statement of Ibn ‘Abbas goes “The divorce by three pronouncements separates the wife from husband whether the marriage has been consummated or not, the previous husband is not lawful for her until she marries a man other than her husband”. This statement is like the tradition which deals with the exchange of money. In this tradition the narrator said “Ibn ‘Abbas withdrew his opinion.”}}
\hadithdefcmd{abudawud}{2199}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ مَرْوَانَ، حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ غَيْرِ، وَاحِدٍ، عَنْ طَاوُسٍ، أَنَّ رَجُلاً، يُقَالُ لَهُ أَبُو الصَّهْبَاءِ كَانَ كَثِيرَ السُّؤَالِ لاِبْنِ عَبَّاسٍ قَالَ أَمَا عَلِمْتَ أَنَّ الرَّجُلَ كَانَ إِذَا طَلَّقَ امْرَأَتَهُ ثَلاَثًا قَبْلَ أَنْ يَدْخُلَ بِهَا جَعَلُوهَا وَاحِدَةً عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَصَدْرًا مِنْ إِمَارَةِ عُمَرَ قَالَ ابْنُ عَبَّاسٍ بَلَى كَانَ الرَّجُلُ إِذَا طَلَّقَ امْرَأَتَهُ ثَلاَثًا قَبْلَ أَنْ يَدْخُلَ بِهَا جَعَلُوهَا وَاحِدَةً عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَصَدْرًا مِنْ إِمَارَةِ عُمَرَ فَلَمَّا رَأَى النَّاسَ قَدْ تَتَابَعُوا فِيهَا قَالَ أَجِيزُوهُنَّ عَلَيْهِمْ ‏.‏\hadithno{2199}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Tawus said A man called Abu Al Sahba used to ask Ibn ‘Abbas questions frequently. He asked “Do you know that when a man divorced his wife by three pronouncement before sexual intercourse with her, they (the people) made it a single divorce during the time of the Apostle of Allaah(ﷺ), of Abu Bakr and in the early phase of the caliphate of ‘Umar?” Ibn “Abbas said “Yes, when a man divorced his wife by three pronouncement before sexual intercourse they made it a single divorce during the time of the Apostle of Allaah(ﷺ), of Abu Bakr and in the early phase of the caliphate of ‘Umar. When he saw that the people frequently divorced (by three pronouncements) he said “Make them operative on them (i.e., on women)”}}
\hadithdefcmd{abudawud}{2200}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، أَنَّ أَبَا الصَّهْبَاءِ، قَالَ لاِبْنِ عَبَّاسٍ أَتَعْلَمُ إِنَّمَا كَانَتِ الثَّلاَثُ تُجْعَلُ وَاحِدَةً عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَثَلاَثًا مِنْ إِمَارَةِ عُمَرَ قَالَ ابْنُ عَبَّاسٍ نَعَمْ ‏.‏\hadithno{2200}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1472)}\hadithtrans{Tawus said:Abu al-Sahba' said to Ibn Abbas: Do you know that a divorce by three pronouncements was made a single one during the time of the Prophet (ﷺ), and of AbuBakr and in the early days of the caliphate of Umar? He replied: Yes}}
\hadithdefcmd{abudawud}{2201}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ عَلْقَمَةَ بْنِ وَقَّاصٍ اللَّيْثِيِّ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الأَعْمَالُ بِالنِّيَّاتِ وَإِنَّمَا لِكُلِّ امْرِئٍ مَا نَوَى فَمَنْ كَانَتْ هِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ فَهِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ وَمَنْ كَانَتْ هِجْرَتُهُ لِدُنْيَا يُصِيبُهَا أَوِ امْرَأَةٍ يَتَزَوَّجُهَا فَهِجْرَتُهُ إِلَى مَا هَاجَرَ إِلَيْهِ ‏"‏ ‏.‏\hadithno{2201}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1) Sahih Muslim (1907)}\hadithtrans{‘Umar bin Al Khattab reported the Apostle of Allaah(ﷺ) as saying “Actions are to be judged only by intentions and a man will have only what he intended. When one’s emigration is to Allaah and His Apostle, his emigration is to Allaah and His Apostle but his emigration is to a worldly end at which he aims or to a woman whom he marries , his emigration is to that for which he emigrated}}
\hadithdefcmd{abudawud}{2202}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، وَسُلَيْمَانُ بْنُ دَاوُدَ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبٍ، - وَكَانَ قَائِدَ كَعْبٍ مِنْ بَنِيهِ حِينَ عَمِيَ - قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍفَسَاقَ قِصَّتَهُ فِي تَبُوكَ قَالَ حَتَّى إِذَا مَضَتْ أَرْبَعُونَ مِنَ الْخَمْسِينَ إِذَا رَسُولُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَأْتِي فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُكَ أَنْ تَعْتَزِلَ امْرَأَتَكَ ‏.‏ قَالَ فَقُلْتُ أُطَلِّقُهَا أَمْ مَاذَا أَفْعَلُ قَالَ لاَ بَلِ اعْتَزِلْهَا فَلاَ تَقْرَبَنَّهَا ‏.‏ فَقُلْتُ لاِمْرَأَتِي الْحَقِي بِأَهْلِكِ فَكُونِي عِنْدَهُمْ حَتَّى يَقْضِيَ اللَّهُ سُبْحَانَهُ فِي هَذَا الأَمْرِ ‏.‏\hadithno{2202}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2757) Sahih Muslim (2769)}\hadithtrans{‘Abd Allah bin Ka’b reported “I heard Ka’ab bin Malik. He then narrated his story about the battle of Tabuk.(Narrating the story) he added “When forty out of fifty days passed”, the messenger of the Apostle of Allaah(ﷺ) came and said “The Apostle of Allaah(ﷺ) has commanded you to keep away from your wife. He said “So, I (Ka’b bin Malik)” said “Should I divorce her or what should I do? He said “No, but only keep away from her and do not go near her”. So, I said to my wife “Go to your people and live with them until Allaah, the exalted makes a decision in this matter.”}}
\hadithdefcmd{abudawud}{2203}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ خَيَّرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَاخْتَرْنَاهُ فَلَمْ يَعُدَّ ذَلِكَ شَيْئًا ‏.‏\hadithno{2203}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5262) Sahih Muslim (1477)}\hadithtrans{A’ishah said The Apostle of Allaah(ﷺ) gave us our choice and we chose him so that was not reckoned anything (i.e., divorce)}}
\hadithdefcmd{abudawud}{2204}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، عَنْ حَمَّادِ بْنِ زَيْدٍ، قَالَ قُلْتُ لأَيُّوبَ هَلْ تَعْلَمُ أَحَدًا قَالَ بِقَوْلِ الْحَسَنِ فِي أَمْرُكِ بِيَدِكِ ‏.‏ قَالَ لاَ إِلاَّ شَىْءٌ حَدَّثَنَاهُ قَتَادَةُ عَنْ كَثِيرٍ مَوْلَى ابْنِ سَمُرَةَ عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ قَالَ أَيُّوبُ فَقَدِمَ عَلَيْنَا كَثِيرٌ فَسَأَلْتُهُ فَقَالَ مَا حَدَّثْتُ بِهَذَا قَطُّ فَذَكَرْتُهُ لِقَتَادَةَ فَقَالَ بَلَى وَلَكِنَّهُ نَسِيَ ‏.‏\hadithno{2204}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Hammad ibn Zayd said:I asked Ayyub: Do you know anyone who narrates the tradition narrated by Al-Hasan about uttering the words (addressing wife). "Your matter is in your hand"? He replied: No, except something similar transmitted by Qatadah from Kathir, the client of Samurah, from AbuSalamah on the authority of AbuHurayrah from the Prophet (ﷺ). Ayyub said: Kathir then came to us; so I asked him (about this matter). He replied: I never narrated it. I mentioned it to Qatadah who said: Yes (he narrated it) but he forgot}}
\hadithdefcmd{abudawud}{2205}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، فِي أَمْرُكِ بِيَدِكِ ‏.‏ قَالَ ثَلاَثٌ ‏.‏\hadithno{2205}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Qatadah reported on the authority of Al Hasan the uttering of the words “Your matter is in your hand” amounts to three pronouncements of divorce}}
\hadithdefcmd{abudawud}{2206}{حَدَّثَنَا ابْنُ السَّرْحِ، وَإِبْرَاهِيمُ بْنُ خَالِدٍ الْكَلْبِيُّ أَبُو ثَوْرٍ، - فِي آخَرِينَ - قَالُوا حَدَّثَنَا مُحَمَّدُ بْنُ إِدْرِيسَ الشَّافِعِيُّ، حَدَّثَنِي عَمِّي، مُحَمَّدُ بْنُ عَلِيِّ بْنِ شَافِعٍ عَنْ عَبْدِ اللَّهِ بْنِ عَلِيِّ بْنِ السَّائِبِ، عَنْ نَافِعِ بْنِ عُجَيْرِ بْنِ عَبْدِ يَزِيدَ بْنِ رُكَانَةَ، أَنَّ رُكَانَةَ بْنَ عَبْدِ يَزِيدَ، طَلَّقَ امْرَأَتَهُ سُهَيْمَةَ الْبَتَّةَ فَأَخْبَرَ النَّبِيَّ صلى الله عليه وسلم بِذَلِكَ وَقَالَ وَاللَّهِ مَا أَرَدْتُ إِلاَّ وَاحِدَةً ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَاللَّهِ مَا أَرَدْتَ إِلاَّ وَاحِدَةً ‏"‏ ‏.‏ فَقَالَ رُكَانَةُ وَاللَّهِ مَا أَرَدْتُ إِلاَّ وَاحِدَةً ‏.‏ فَرَدَّهَا إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَطَلَّقَهَا الثَّانِيَةَ فِي زَمَانِ عُمَرَ وَالثَّالِثَةَ فِي زَمَانِ عُثْمَانَ ‏.‏ قَالَ أَبُو دَاوُدَ أَوَّلُهُ لَفْظُ إِبْرَاهِيمَ وَآخِرُهُ لَفْظُ ابْنِ السَّرْحِ ‏.‏\hadithno{2206}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Nafi' bun Ujair bin Abd Yazid bin Ruknah reported Ruknah bin ‘Abd Yazid divorced his wife Suhaimah absolutely. The Prophet (ﷺ) was informed about this matter. He said to him (the Prophet) I swear by Allaah that I meant it to be only a single utterance of divorce. The Apostle of Allaah(ﷺ) said “I swear by Allaah that I meant it to be only a single divorce. The Apostle of Allaah(ﷺ) restored her to him, Then he divorced her the second time in the time of ‘Umar and the third time of ‘Uthman. Abu Dawud said “This tradition contains the words of Ibrahim in its beginning and the words of Ibn Al Sarh in the end}}
\hadithdefcmd{abudawud}{2207}{حَدَّثَنَا مُحَمَّدُ بْنُ يُونُسَ النَّسَائِيُّ، أَنَّ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، حَدَّثَهُمْ عَنْ مُحَمَّدِ بْنِ إِدْرِيسَ، حَدَّثَنِي عَمِّي، مُحَمَّدُ بْنُ عَلِيٍّ عَنِ ابْنِ السَّائِبِ، عَنْ نَافِعِ بْنِ عُجَيْرٍ، عَنْ رُكَانَةَ بْنِ عَبْدِ يَزِيدَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏.‏\hadithno{2207}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Rukanah bin Yazid from the Prophet (ﷺ) through a different chain of narrators}}
\hadithdefcmd{abudawud}{2208}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنِ الزُّبَيْرِ بْنِ سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَلِيِّ بْنِ يَزِيدَ بْنِ رُكَانَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّهُ طَلَّقَ امْرَأَتَهُ الْبَتَّةَ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا أَرَدْتَ ‏"‏ ‏.‏ قَالَ وَاحِدَةً ‏.‏ قَالَ ‏"‏ آللَّهِ ‏"‏ ‏.‏ قَالَ آللَّهِ ‏.‏ قَالَ ‏"‏ هُوَ عَلَى مَا أَرَدْتَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا أَصَحُّ مِنْ حَدِيثِ ابْنِ جُرَيْجٍ أَنَّ رُكَانَةَ طَلَّقَ امْرَأَتَهُ ثَلاَثًا لأَنَّهُمْ أَهْلُ بَيْتِهِ وَهُمْ أَعْلَمُ بِهِ وَحَدِيثُ ابْنِ جُرَيْجٍ رَوَاهُ عَنْ بَعْضِ بَنِي أَبِي رَافِعٍ عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{2208}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ali b. Yazid b. Rukanah reported on the authority of his father from his grandfather that he (Rukanah) divorced his wife absolutely; so he came to the Messenger of Allah (ﷺ). He asked (him):What did you intend? He said: A single utterance of divorce. He said: Do you swear by Allah? He replied: I swear by Allah. He said: It stands as you intended. Abu Dawud said: This tradition is sounder than that of Ibn Juraij that Rukanah divorced his wife by three pronouncements, for they are the members of his family and they are more aware for him. The tradition of Ibn Juraij has been narrated by some children of Abu Rafi' from 'Ikrimah on the authority of Ibn 'Abbas}}
\hadithdefcmd{abudawud}{2209}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ تَجَاوَزَ لأُمَّتِي عَمَّا لَمْ تَتَكَلَّمْ بِهِ أَوْ تَعْمَلْ بِهِ وَبِمَا حَدَّثَتْ بِهِ أَنْفُسَهَا ‏"‏ ‏.‏\hadithno{2209}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2528) Sahih Muslim (127)}\hadithtrans{Abu Hurairah reported the Prophet (ﷺ) as saying “Allah has ignored for my community what comes to their mind, so long as they do not act or pronounce words to that effect.”}}
\hadithdefcmd{abudawud}{2210}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، وَخَالِدٌ الطَّحَّانُ، - الْمَعْنَى - كُلُّهُمْ عَنْ خَالِدٍ، عَنْ أَبِي تَمِيمَةَ الْهُجَيْمِيِّ، أَنَّ رَجُلاً، قَالَ لاِمْرَأَتِهِ يَا أُخَيَّةُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُخْتُكَ هِيَ ‏"‏ ‏.‏ فَكَرِهَ ذَلِكَ وَنَهَى عَنْهُ ‏.‏\hadithno{2210}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Tamimah al-Hujayni: A man said to his wife: O my younger sister! The Messenger of Allah (ﷺ)said: Is she your sister? He (the Prophet disliked it and prohibited saying so)}}
\hadithdefcmd{abudawud}{2211}{حَدَّثَنَا مُحَمَّدُ بْنُ إِبْرَاهِيمَ الْبَزَّازُ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ السَّلاَمِ، - يَعْنِي ابْنَ حَرْبٍ - عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي تَمِيمَةَ، عَنْ رَجُلٍ، مِنْ قَوْمِهِ أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم سَمِعَ رَجُلاً، يَقُولُ لاِمْرَأَتِهِ ‏ "‏ يَا أُخَيَّةُ ‏"‏ ‏.‏ فَنَهَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ عَنْ خَالِدٍ عَنْ أَبِي عُثْمَانَ عَنْ أَبِي تَمِيمَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَرَوَاهُ شُعْبَةُ عَنْ خَالِدٍ عَنْ رَجُلٍ عَنْ أَبِي تَمِيمَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2211}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Tamimah reported from a man of his tribe “The Prophet (ﷺ) heard a man say his wife “O my younger sister! So he prohibited him (addressing his wife in this manner) Abu Dawud said “This tradition has also been transmitted by ‘Abd Al Aziz bin Al Mukhtar from Khalid from Abu ‘Uthman from Abu Thamimah from the Prophet (ﷺ). This has also been narrated by Shu’bah from Khalid from a man on the authority of Abu Thamimah from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{2212}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ أَنَّ إِبْرَاهِيمَ صلى الله عليه وسلم لَمْ يَكْذِبْ قَطُّ إِلاَّ ثَلاَثًا ثِنْتَانِ فِي ذَاتِ اللَّهِ تَعَالَى قَوْلُهُ ‏\{‏ إِنِّي سَقِيمٌ ‏\}‏ وَقَوْلُهُ ‏\{‏ بَلْ فَعَلَهُ كَبِيرُهُمْ هَذَا ‏\}‏ وَبَيْنَمَا هُوَ يَسِيرُ فِي أَرْضِ جَبَّارٍ مِنَ الْجَبَابِرَةِ إِذْ نَزَلَ مَنْزِلاً فَأُتِيَ الْجَبَّارُ فَقِيلَ لَهُ إِنَّهُ نَزَلَ هَا هُنَا رَجُلٌ مَعَهُ امْرَأَةٌ هِيَ أَحْسَنُ النَّاسِ قَالَ فَأَرْسَلَ إِلَيْهِ فَسَأَلَهُ عَنْهَا فَقَالَ إِنَّهَا أُخْتِي ‏.‏ فَلَمَّا رَجَعَ إِلَيْهَا قَالَ إِنَّ هَذَا سَأَلَنِي عَنْكِ فَأَنْبَأْتُهُ أَنَّكِ أُخْتِي وَإِنَّهُ لَيْسَ الْيَوْمَ مُسْلِمٌ غَيْرِي وَغَيْرُكِ وَإِنَّكِ أُخْتِي فِي كِتَابِ اللَّهِ فَلاَ تُكَذِّبِينِي عِنْدَهُ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذَا الْخَبَرَ شُعَيْبُ بْنُ أَبِي حَمْزَةَ عَنْ أَبِي الزِّنَادِ عَنِ الأَعْرَجِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{2212}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah reported the Prophet(ﷺ) as saying Abraham(peace be upon him) never told a lie except on three occasions twice for the sake of Allaah. Allaah quoted his words (in the Qur’an) “I am indeed sick” and “Nay, this was done by - this is their biggest one”. Once he was passing through the land of a tyrant (king). He stayed there in a place. People went to the tyrant and informed him saying “A man has come down here; he has a most beautiful woman with him.” So he sent for him (Abraham) and asked about her. He said she is my sister. When he returned to her, he said “he asked me about you and I informed him that you were my sister. Today there is no believer except me and you. You are my sister in the Book of Allaah (i.e., sister in faith). So do not belie me before him. The narrator then narrated the rest of the tradition. Abu Dawud said “A similar tradition has also been narrated by Shu’aib bin Abi Hamza from Abi Al Zinad from Al A’raj on the authority of Abu Hurairah from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{2213}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، - الْمَعْنَى - قَالاَ حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، - قَالَ ابْنُ الْعَلاَءِ ابْنِ عَلْقَمَةَ بْنِ عَيَّاشٍ - عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ سَلَمَةَ بْنِ صَخْرٍ، - قَالَ ابْنُ الْعَلاَءِ الْبَيَاضِيِّ - قَالَ كُنْتُ امْرَأً أُصِيبُ مِنَ النِّسَاءِ مَا لاَ يُصِيبُ غَيْرِي فَلَمَّا دَخَلَ شَهْرُ رَمَضَانَ خِفْتُ أَنْ أُصِيبَ مِنَ امْرَأَتِي شَيْئًا يُتَابَعُ بِي حَتَّى أُصْبِحَ فَظَاهَرْتُ مِنْهَا حَتَّى يَنْسَلِخَ شَهْرُ رَمَضَانَ فَبَيْنَمَا هِيَ تَخْدُمُنِي ذَاتَ لَيْلَةٍ إِذْ تَكَشَّفَ لِي مِنْهَا شَىْءٌ فَلَمْ أَلْبَثْ أَنْ نَزَوْتُ عَلَيْهَا فَلَمَّا أَصْبَحْتُ خَرَجْتُ إِلَى قَوْمِي فَأَخْبَرْتُهُمُ الْخَبَرَ وَقُلْتُ امْشُوا مَعِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالُوا لاَ وَاللَّهِ ‏.‏ فَانْطَلَقْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَخْبَرْتُهُ فَقَالَ ‏"‏ أَنْتَ بِذَاكَ يَا سَلَمَةُ ‏"‏ ‏.‏ قُلْتُ أَنَا بِذَاكَ يَا رَسُولَ اللَّهِ مَرَّتَيْنِ وَأَنَا صَابِرٌ لأَمْرِ اللَّهِ فَاحْكُمْ فِيَّ مَا أَرَاكَ اللَّهُ قَالَ ‏"‏ حَرِّرْ رَقَبَةً ‏"‏ ‏.‏ قُلْتُ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا أَمْلِكُ رَقَبَةً غَيْرَهَا وَضَرَبْتُ صَفْحَةَ رَقَبَتِي قَالَ ‏"‏ فَصُمْ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏"‏ ‏.‏ قَالَ وَهَلْ أُصِبْتُ الَّذِي أُصِبْتُ إِلاَّ مِنَ الصِّيَامِ قَالَ ‏"‏ فَأَطْعِمْ وَسْقًا مِنْ تَمْرٍ بَيْنَ سِتِّينَ مِسْكِينًا ‏"‏ ‏.‏ قُلْتُ وَالَّذِي بَعَثَكَ بِالْحَقِّ لَقَدْ بِتْنَا وَحْشَيْنِ مَا لَنَا طَعَامٌ قَالَ ‏"‏ فَانْطَلِقْ إِلَى صَاحِبِ صَدَقَةِ بَنِي زُرَيْقٍ فَلْيَدْفَعْهَا إِلَيْكَ فَأَطْعِمْ سِتِّينَ مِسْكِينًا وَسْقًا مِنْ تَمْرٍ وَكُلْ أَنْتَ وَعِيَالُكَ بَقِيَّتَهَا ‏"‏ ‏.‏ فَرَجَعْتُ إِلَى قَوْمِي فَقُلْتُ وَجَدْتُ عِنْدَكُمُ الضِّيقَ وَسُوءَ الرَّأْىِ وَوَجَدْتُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم السَّعَةَ وَحُسْنَ الرَّأْىِ وَقَدْ أَمَرَنِي - أَوْ أَمَرَ لِي - بِصَدَقَتِكُمْ زَادَ ابْنُ الْعَلاَءِ قَالَ ابْنُ إِدْرِيسَ بَيَاضَةُ بَطْنٌ مِنْ بَنِي زُرَيْقٍ ‏.‏\hadithno{2213}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salamah ibn Sakhr al-Bayadi: I was a man who was more given than others to sexual intercourse with women. When the month of Ramadan came, I feared lest I should have intercourse with my wife, and this evil should remain with me till the morning. So I made my wife like my mother's back to me till the end of Ramadan. But one night when she was waiting upon me, something of her was revealed. Suddenly I jumped upon her. When the morning came I went to my people and informed them about this matter. I said: Go along with me to the Messenger of Allah (ﷺ). They said: No, by Allah. So I went to the Prophet (peace be upon him and informed him of the matter. He said: Have you really committed it, Salamah? I said: I committed it twice, Messenger of Allah. I am content with the Commandment of Allah, the Exalted; so take a decision about me according to what Allah has shown you. He said: Free a slave. I said: By Him Who sent you with truth, I do not possess a neck other than this: and I struck the surface of my neck. He said: Then fast two consecutive months. I said: Whatever I suffered is due to fasting. He said: Feed sixty poor people with a wasq of dates. I said: By Him Who sent you with truth, we passed the night hungry; there was no food in our house. He said: Then go to the collector of sadaqah of Banu Zurayq; he must give it to you. Then feed sixty poor people with a wasq of dates; and you and your family eat the remaining dates. Then I came back to my people, and said (to them): I found with you poverty and bad opinion; and I found with the Prophet (ﷺ) prosperity and good opinion. He has commanded me to give alms to you. Ibn al-Ala' added: Ibn Idris said: Bayadah is a sub-clan of Banu Zurayq}}
\hadithdefcmd{abudawud}{2214}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مَعْمَرِ بْنِ عَبْدِ اللَّهِ بْنِ حَنْظَلَةَ، عَنْ يُوسُفَ بْنِ عَبْدِ اللَّهِ بْنِ سَلاَمٍ، عَنْ خُوَيْلَةَ بِنْتِ مَالِكِ بْنِ ثَعْلَبَةَ، قَالَتْ ظَاهَرَ مِنِّي زَوْجِي أَوْسُ بْنُ الصَّامِتِ فَجِئْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَشْكُو إِلَيْهِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يُجَادِلُنِي فِيهِ وَيَقُولُ ‏"‏ اتَّقِي اللَّهَ فَإِنَّهُ ابْنُ عَمِّكِ ‏"‏ ‏.‏ فَمَا بَرِحْتُ حَتَّى نَزَلَ الْقُرْآنُ ‏\{‏ قَدْ سَمِعَ اللَّهُ قَوْلَ الَّتِي تُجَادِلُكَ فِي زَوْجِهَا ‏\}‏ إِلَى الْفَرْضِ فَقَالَ ‏"‏ يُعْتِقُ رَقَبَةً ‏"‏ ‏.‏ قَالَتْ لاَ يَجِدُ قَالَ ‏"‏ فَيَصُومُ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏"‏ ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّهُ شَيْخٌ كَبِيرٌ مَا بِهِ مِنْ صِيَامٍ ‏.‏ قَالَ ‏"‏ فَلْيُطْعِمْ سِتِّينَ مِسْكِينًا ‏"‏ ‏.‏ قَالَتْ مَا عِنْدَهُ مِنْ شَىْءٍ يَتَصَدَّقُ بِهِ قَالَتْ فَأُتِيَ سَاعَتَئِذٍ بِعَرَقٍ مِنْ تَمْرٍ قُلْتُ يَا رَسُولَ اللَّهِ فَإِنِّي أُعِينُهُ بِعَرَقٍ آخَرَ ‏.‏ قَالَ ‏"‏ قَدْ أَحْسَنْتِ اذْهَبِي فَأَطْعِمِي بِهَا عَنْهُ سِتِّينَ مِسْكِينًا وَارْجِعِي إِلَى ابْنِ عَمِّكِ ‏"‏ ‏.‏ قَالَ وَالْعَرَقُ سِتُّونَ صَاعًا قَالَ أَبُو دَاوُدَ فِي هَذَا إِنَّهَا كَفَّرَتْ عَنْهُ مِنْ غَيْرِ أَنْ تَسْتَأْمِرَهُ ‏.‏ وَقَالَ أَبُو دَاوُدَ وَهَذَا أَخُو عُبَادَةَ بْنِ الصَّامِتِ ‏.‏\hadithno{2214}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Khuwaylah, daughter of Malik ibn Tha'labah: My husband, Aws ibn as-Samit, pronounced the words: You are like my mother. So I came to the Messenger of Allah (ﷺ), complaining to him about my husband. The Messenger of Allah (ﷺ) disputed with me and said: Remain dutiful to Allah; he is your cousin. I continued (complaining) until the Qur'anic verse came down: "Certainly has Allah heard the speech of the one who argues with you, [O Muhammad], concerning her husband..." [58:1] till the prescription of expiation. He then said: He should set free a slave. She said: He cannot afford it. He said: He should fast for two consecutive months. She said: Messenger of Allah, he is an old man; he cannot keep fasts. He said: He should feed sixty poor people. She said: He has nothing which he may give in alms. At that moment an araq (i.e. date-basket holding fifteen or sixteen sa's) was brought to him. I said: I shall help him with another date-basked ('araq). He said: You have done well. Go and feed sixty poor people on his behalf, and return to your cousin. The narrator said: An araq holds sixty sa's of dates. Abu Dawud said: She atoned on his behalf without seeking his permission. Abu Dawud said: This man (Aws b. al-Samit) is the brother of 'Ubadah b. al-Samit}}
\hadithdefcmd{abudawud}{2215}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى أَبُو الأَصْبَغِ الْحَرَّانِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنِ ابْنِ إِسْحَاقَ، بِهَذَا الإِسْنَادِ نَحْوَهُ إِلاَّ أَنَّهُ قَالَ وَالْعَرَقُ مِكْتَلٌ يَسَعُ ثَلاَثِينَ صَاعًا ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا أَصَحُّ مِنْ حَدِيثِ يَحْيَى بْنِ آدَمَ ‏.‏\hadithno{2215}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{A similar tradition has been transmitted by Ibn Ishaq with a different chain of narrators. But in this version he said ‘Araq is a date-basket holding thirty sa’s. Abu Dawud said “This version is sounder than that of Yahya bin Adam.”}}
\hadithdefcmd{abudawud}{2216}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، حَدَّثَنَا يَحْيَى، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ يَعْنِي بِالْعَرَقِ زَنْبِيلاً يَأْخُذُ خَمْسَةَ عَشَرَ صَاعًا ‏.‏\hadithno{2216}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Another version transmitted by Abu Salamah bin ‘Abd Al Rahman has ‘Araq is a date-basket holding fifteen sa’s}}
\hadithdefcmd{abudawud}{2217}{حَدَّثَنَا ابْنُ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ لَهِيعَةَ، وَعَمْرُو بْنُ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، بِهَذَا الْخَبَرِ قَالَ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِتَمْرٍ فَأَعْطَاهُ إِيَّاهُ وَهُوَ قَرِيبٌ مِنْ خَمْسَةَ عَشَرَ صَاعًا قَالَ ‏"‏ تَصَدَّقْ بِهَذَا ‏"‏ ‏.‏ قَالَ فَقَالَ يَا رَسُولَ اللَّهِ عَلَى أَفْقَرَ مِنِّي وَمِنْ أَهْلِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُلْهُ أَنْتَ وَأَهْلُكَ ‏"‏ ‏.‏\hadithno{2217}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has been transmitted by Sulaiman bin Yasar. This version has “Then some dates were brought to the Apostle of Allaah(ﷺ) and he gave it him. They measured about fifteen sa’s “. He said “Give them in alms”. He said “Is there anyone needier than I and my family. Apostle of Allaah(ﷺ)?” The Apostle of Allaah(ﷺ) said “Eat them, you and your family.”}}
\hadithdefcmd{abudawud}{2218}{قَالَ أَبُو دَاوُدَ قَرَأْتُ عَلَى مُحَمَّدِ بْنِ وَزِيرٍ الْمِصْرِيِّ قُلْتُ لَهُ حَدَّثَكُمْ بِشْرُ بْنُ بَكْرٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا عَطَاءٌ، عَنْ أَوْسٍ، أَخِي عُبَادَةَ بْنِ الصَّامِتِ أَنَّ النَّبِيَّ صلى الله عليه وسلم أَعْطَاهُ خَمْسَةَ عَشَرَ صَاعًا مِنْ شَعِيرٍ إِطْعَامُ سِتِّينَ مِسْكِينًا ‏.‏ قَالَ أَبُو دَاوُدَ وَعَطَاءٌ لَمْ يُدْرِكْ أَوْسًا وَهُوَ مِنْ أَهْلِ بَدْرٍ قَدِيمُ الْمَوْتِ وَالْحَدِيثُ مُرْسَلٌ وَإِنَّمَا رَوَوْهُ عَنِ الأَوْزَاعِيِّ عَنْ عَطَاءٍ أَنَّ أَوْسًا ‏.‏\hadithno{2218}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Dawud said “I recited to Muhammad bin Wazir Al Misri and said to him Bishr bin Bakr narrated it to you and Al Auza’i narrated it to us. And he said “At’a narrated it to us on the authority of Aus brother of ‘Ubadah bin Al Samit. The Prophet (ﷺ) gave him fifteen sa’s of wheat to feed sixty poor people. Abu Dawud said At’a did not meet Aws (bin Al Samit) who was one of the people of Badr and died in the early days of Islam. This version is therefore, mursal (i.e., a successor narrated it directly from the Prophet (ﷺ), the link of the Companions is missing). This has been narrated by Al Auza’i from At’a from Aus}}
\hadithdefcmd{abudawud}{2219}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، أَنَّ جَمِيلَةَ، كَانَتْ تَحْتَ أَوْسِ بْنِ الصَّامِتِ وَكَانَ رَجُلاً بِهِ لَمَمٌ فَكَانَ إِذَا اشْتَدَّ لَمَمُهُ ظَاهَرَ مِنَ امْرَأَتِهِ فَأَنْزَلَ اللَّهُ تَعَالَى فِيهِ كَفَّارَةَ الظِّهَارِ ‏.‏\hadithno{2219}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Hisham b. 'Urwah: Khawlah was the wife of Aws ibn as-Samit; he was a man immensely given to sexual intercourse. When his desire for intercourse was intensified, he made his wife like his mother's back. So Allah, the Exalted, sent down Qur'anic verses relating to expiation for zihar}}
\hadithdefcmd{abudawud}{2220}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ الْفَضْلِ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، مِثْلَهُ ‏.‏\hadithno{2220}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{A similar tradition has been transmitted by A’ishah through a different chain of narrators}}
\hadithdefcmd{abudawud}{2221}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ الطَّالْقَانِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الْحَكَمُ بْنُ أَبَانَ، عَنْ عِكْرِمَةَ، أَنَّ رَجُلاً، ظَاهَرَ مِنَ امْرَأَتِهِ ثُمَّ وَاقَعَهَا قَبْلَ أَنْ يُكَفِّرَ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرَهُ فَقَالَ ‏"‏ مَا حَمَلَكَ عَلَى مَا صَنَعْتَ ‏"‏ ‏.‏ قَالَ رَأَيْتُ بَيَاضَ سَاقَيْهَا فِي الْقَمَرِ ‏.‏ قَالَ ‏"‏ فَاعْتَزِلْهَا حَتَّى تُكَفِّرَ عَنْكَ ‏"‏ ‏.‏\hadithno{2221}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ikrimah: A man made his wife like the back of his mother. He then had intercourse with her before he atoned for it. He came to the Prophet (ﷺ) and informed him of this matter. He asked (him): What moved you to the action you have committed? He replied: I saw the whiteness of her shins in moon light. He said: Keep away from her until you expiate for your deed}}
\hadithdefcmd{abudawud}{2222}{حَدَّثَنَا الزَّعْفَرَانِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الْحَكَمِ بْنِ أَبَانَ، عَنْ عِكْرِمَةَ، أَنَّ رَجُلاً، ظَاهَرَ مِنَ امْرَأَتِهِ فَرَأَى بَرِيقَ سَاقِهَا فِي الْقَمَرِ فَوَقَعَ عَلَيْهَا فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَأَمَرَهُ أَنْ يُكَفِّرَ ‏.‏\hadithno{2222}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{‘Ikrimah said “A man made his wife like the back of his mother. When he saw the illumination of her shin in the moonlight, he had intercourse with her. He came to the Prophet (ﷺ). He ordered him to atone for it}}
\hadithdefcmd{abudawud}{2223}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا الْحَكَمُ بْنُ أَبَانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَلَمْ يَذْكُرِ السَّاقَ ‏.‏\hadithno{2223}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{A similar tradition has been transmitted by Ibn ‘Abbas from the Prophet (ﷺ) through a different chain of narrators. This version does not mention the word “shin”}}
\hadithdefcmd{abudawud}{2224}{حَدَّثَنَا أَبُو كَامِلٍ، أَنَّ عَبْدَ الْعَزِيزِ بْنَ الْمُخْتَارِ، حَدَّثَهُمْ حَدَّثَنَا خَالِدٌ، حَدَّثَنِي مُحَدِّثٌ، عَنْ عِكْرِمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِ حَدِيثِ سُفْيَانَ ‏.‏\hadithno{2224}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{A tradition similar to that of Sufyan has been transmitted by ‘Ikrimah from the Prophet(ﷺ) through a different chain of narrators}}
\hadithdefcmd{abudawud}{2225}{قَالَ أَبُو دَاوُدَ سَمِعْتُ مُحَمَّدَ بْنَ عِيسَى، يُحَدِّثُ بِهِ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ الْحَكَمَ بْنَ أَبَانَ، يُحَدِّثُ بِهَذَا الْحَدِيثِ وَلَمْ يَذْكُرِ ابْنَ عَبَّاسٍ قَالَ عَنْ عِكْرِمَةَقَالَ أَبُو دَاوُدَ كَتَبَ إِلَىَّ الْحُسَيْنُ بْنُ حُرَيْثٍ قَالَ أَخْبَرَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ مَعْمَرٍ، عَنِ الْحَكَمِ بْنِ أَبَانَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، بِمَعْنَاهُ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{2225}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Dawud said “I heard Muhammad bin Isa narrating this tradition who said Mu’tamar narrated it to us. And he (Mu’tamar) said “ I heard Al Hakam bin Aban narrating this tradition. He did not mention the name of Ibn ‘Abbas. Abu Dawud said “Al Hussain bin Huraith wrote to me saying “Al Fadl bin Musa narrated from Ibn ‘Abbas to the same effect from the Prophet(ﷺ)}}
\hadithdefcmd{abudawud}{2226}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا امْرَأَةٍ سَأَلَتْ زَوْجَهَا طَلاَقًا فِي غَيْرِ مَا بَأْسٍ فَحَرَامٌ عَلَيْهَا رَائِحَةُ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{2226}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Thawban: The Prophet (ﷺ) said: If any woman asks her husband for divorce without some strong reason, the odour of Paradise will be forbidden to her}}
\hadithdefcmd{abudawud}{2227}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ بْنِ سَعْدِ بْنِ زُرَارَةَ، أَنَّهَا أَخْبَرَتْهُ عَنْ حَبِيبَةَ بِنْتِ سَهْلٍ الأَنْصَارِيَّةِ، أَنَّهَا كَانَتْ تَحْتَ ثَابِتِ بْنِ قَيْسِ بْنِ شَمَّاسٍ وَأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ إِلَى الصُّبْحِ فَوَجَدَ حَبِيبَةَ بِنْتَ سَهْلٍ عِنْدَ بَابِهِ فِي الْغَلَسِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ هَذِهِ ‏"‏ ‏.‏ فَقَالَتْ أَنَا حَبِيبَةُ بِنْتُ سَهْلٍ ‏.‏ قَالَ ‏"‏ مَا شَأْنُكِ ‏"‏ ‏.‏ قَالَتْ لاَ أَنَا وَلاَ ثَابِتُ بْنُ قَيْسٍ ‏.‏ لِزَوْجِهَا فَلَمَّا جَاءَ ثَابِتُ بْنُ قَيْسٍ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذِهِ حَبِيبَةُ بِنْتُ سَهْلٍ ‏"‏ ‏.‏ وَذَكَرَتْ مَا شَاءَ اللَّهُ أَنْ تَذْكُرَ وَقَالَتْ حَبِيبَةُ يَا رَسُولَ اللَّهِ كُلُّ مَا أَعْطَانِي عِنْدِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِثَابِتِ بْنِ قَيْسٍ ‏"‏ خُذْ مِنْهَا ‏"‏ ‏.‏ فَأَخَذَ مِنْهَا وَجَلَسَتْ هِيَ فِي أَهْلِهَا ‏.‏\hadithno{2227}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Amrah, daughter of 'Abd al-Rahman ibn Sa'd ibn Zurarah, reported on the authority of Habibah, daughter of Sahl al-Ansariyyah:She (Habibah) was the wife of Thabit ibn Qays ibn Shimmas. The Messenger of Allah (ﷺ) came out one morning and found Habibah by his door. The Messenger of Allah (ﷺ) said: Who is this? She replied: I am Habibah, daughter of Sahl. He asked: What is your case? She replied: I and Thabit ibn Qays, referring to her husband, cannot live together. When Thabit ibn Qays came, the Messenger of Allah (ﷺ) said to him: This is Habibah, daughter of Sahl, and she has mentioned (about you) what Allah wished to mention. Habibah said: Messenger of Allah, all that he gave me is with me. The Messenger of Allah (ﷺ) said to Thabit ibn Qays: Take it from her. So he took it from her, and she lived among her people (relatives)}}
\hadithdefcmd{abudawud}{2228}{حَدَّثَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، حَدَّثَنَا أَبُو عَامِرٍ عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو عَمْرٍو السَّدُوسِيُّ الْمَدِينِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، أَنَّ حَبِيبَةَ بِنْتَ سَهْلٍ، كَانَتْ عِنْدَ ثَابِتِ بْنِ قَيْسِ بْنِ شَمَّاسٍ فَضَرَبَهَا فَكَسَرَ بَعْضَهَا فَأَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدَ الصُّبْحِ فَاشْتَكَتْهُ إِلَيْهِ فَدَعَا النَّبِيُّ صلى الله عليه وسلم ثَابِتًا فَقَالَ ‏"‏ خُذْ بَعْضَ مَالِهَا وَفَارِقْهَا ‏"‏ ‏.‏ فَقَالَ وَيَصْلُحُ ذَلِكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَإِنِّي أَصْدَقْتُهَا حَدِيقَتَيْنِ وَهُمَا بِيَدِهَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ خُذْهُمَا فَفَارِقْهَا ‏"‏ ‏.‏ فَفَعَلَ ‏.‏\hadithno{2228}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Habibah daughter of Sahl was the wife of Thabit ibn Qays Shimmas He beat her and broke some of her part. So she came to the Prophet (ﷺ) after morning, and complained to him against her husband. The Prophet (ﷺ) called on Thabit ibn Qays and said (to him): Take a part of her property and separate yourself from her. He asked: Is that right, Messenger of Allah? He said: Yes. He said: I have given her two gardens of mine as a dower, and they are already in her possession. The Prophet (ﷺ) said: Take them and separate yourself from her}}
\hadithdefcmd{abudawud}{2229}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ الْبَزَّازُ، حَدَّثَنَا عَلِيُّ بْنُ بَحْرٍ الْقَطَّانُ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، عَنْ مَعْمَرٍ، عَنْ عَمْرِو بْنِ مُسْلِمٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ امْرَأَةَ، ثَابِتِ بْنِ قَيْسٍ اخْتَلَعَتْ مِنْهُ فَجَعَلَ النَّبِيُّ صلى الله عليه وسلم عِدَّتَهَا حَيْضَةً ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا الْحَدِيثُ رَوَاهُ عَبْدُ الرَّزَّاقِ عَنْ مَعْمَرٍ عَنْ عَمْرِو بْنِ مُسْلِمٍ عَنْ عِكْرِمَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏\hadithno{2229}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The wife of Thabit ibn Qays separated herself from him for a compensation. The Prophet (ﷺ) made her waiting period a menstrual course. Abu Dawud said: This tradition has been transmitted by 'Abd al-Razzaq from Ma'mar from 'Amr b. Muslim from 'Ikrimah from the Prophet (ﷺ) in a mursal form (i.e. missing the link of the Companion)}}
\hadithdefcmd{abudawud}{2230}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ عِدَّةُ الْمُخْتَلِعَةِ حَيْضَةٌ ‏.‏\hadithno{2230}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn ‘Umar said “The waiting period of a woman who separates herself from her husband for compensation is a menstrual period.”}}
\hadithdefcmd{abudawud}{2231}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ مُغِيثًا، كَانَ عَبْدًا فَقَالَ يَا رَسُولَ اللَّهِ اشْفَعْ لِي إِلَيْهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا بَرِيرَةُ اتَّقِي اللَّهَ فَإِنَّهُ زَوْجُكِ وَأَبُو وَلَدِكِ ‏"‏ ‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ أَتَأْمُرُنِي بِذَلِكَ قَالَ ‏"‏ لاَ إِنَّمَا أَنَا شَافِعٌ ‏"‏ ‏.‏ فَكَانَ دُمُوعُهُ تَسِيلُ عَلَى خَدِّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلْعَبَّاسِ ‏"‏ أَلاَ تَعْجَبُ مِنْ حُبِّ مُغِيثٍ بَرِيرَةَ وَبُغْضِهَا إِيَّاهُ ‏"‏ ‏.‏\hadithno{2231}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5283)}\hadithtrans{Ibn ‘Abbas said “Mughith was a slave.” He said “Apostle of Allaah (ﷺ) make intercession for me to her (Barirah)”. The Apostle of Allaah (ﷺ) said “O Barirah fear Allaah. He is your husband and father of your child”. She said “Apostle of Allaah (ﷺ) do you command me for that? He said No, I am only interceding. Then tears were falling down on his (her husband’s) cheeks. The Apostle of Allaah (ﷺ) said to ‘Abbas “Are you not surprised with the love of Mughith for Barirah and her hatred for him.”}}
\hadithdefcmd{abudawud}{2232}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ زَوْجَ، بَرِيرَةَ كَانَ عَبْدًا أَسْوَدَ يُسَمَّى مُغِيثًا فَخَيَّرَهَا - يَعْنِي النَّبِيَّ صلى الله عليه وسلم - وَأَمَرَهَا أَنْ تَعْتَدَّ ‏.‏\hadithno{2232}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (5280)}\hadithtrans{Ibn ‘Abbas said “The husband of Barirah was a black slave called Mughith. The Prophet (ﷺ) gave her choice and commanded her to observe the waiting period.”}}
\hadithdefcmd{abudawud}{2233}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، فِي قِصَّةِ بَرِيرَةَ قَالَتْ كَانَ زَوْجُهَا عَبْدًا فَخَيَّرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَاخْتَارَتْ نَفْسَهَا وَلَوْ كَانَ حُرًّا لَمْ يُخَيِّرْهَا ‏.‏\hadithno{2233}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (2563) Sahih Muslim (1504)}\hadithtrans{While relating the tradition about Barirah A’ishah said “her husband was a slave, so the Prophet(ﷺ) gave her choice. She chose herself. Had he been a free man, he would not given her choice.”}}
\hadithdefcmd{abudawud}{2234}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، وَالْوَلِيدُ بْنُ عُقْبَةَ، عَنْ زَائِدَةَ، عَنْ سِمَاكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ بَرِيرَةَ، خَيَّرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَانَ زَوْجُهَا عَبْدًا ‏.‏\hadithno{2234}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1504)}\hadithtrans{A’ishah said “The Prophet (ﷺ) gave her choice. Her husband was a slave.”}}
\hadithdefcmd{abudawud}{2235}{حَدَّثَنَا ابْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، أَنَّ زَوْجَ، بَرِيرَةَ كَانَ حُرًّا حِينَ أُعْتِقَتْ وَأَنَّهَا خُيِّرَتْ فَقَالَتْ مَا أُحِبُّ أَنْ أَكُونَ مَعَهُ وَإِنَّ لِي كَذَا وَكَذَا ‏.‏\hadithno{2235}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{A’ishah said “Barirah’s husband was a free man when she was emancipated. She was given choice. She said “I do not like to remain with him. I have such and such (grievances)”}}
\hadithdefcmd{abudawud}{2236}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى الْحَرَّانِيُّ، حَدَّثَنِي مُحَمَّدٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ أَبِي جَعْفَرٍ، وَعَنْ أَبَانَ بْنِ صَالِحٍ، عَنْ مُجَاهِدٍ، وَعَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ بَرِيرَةَ، أُعْتِقَتْ وَهِيَ عِنْدَ مُغِيثٍ - عَبْدٍ لآلِ أَبِي أَحْمَدَ - فَخَيَّرَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ لَهَا ‏ "‏ إِنْ قَرِبَكِ فَلاَ خِيَارَ لَكِ ‏"‏ ‏.‏\hadithno{2236}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Barirah was emancipated, and she was the wife of Mughith, a slave of Aal AbuAhmad. The Messenger of Allah (ﷺ) gave her choice, and said to her: If he has intercourse with you, then there is no choice for you}}
\hadithdefcmd{abudawud}{2237}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَنَصْرُ بْنُ عَلِيٍّ، قَالَ زُهَيْرٌ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ مَوْهَبٍ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، أَنَّهَا أَرَادَتْ أَنْ تَعْتِقَ، مَمْلُوكَيْنِ لَهَا زَوْجٌ قَالَ فَسَأَلَتِ النَّبِيَّ صلى الله عليه وسلم عَنْ ذَلِكَ فَأَمَرَهَا أَنْ تَبْدَأَ بِالرَّجُلِ قَبْلَ الْمَرْأَةِ ‏.‏ قَالَ نَصْرٌ أَخْبَرَنِي أَبُو عَلِيٍّ الْحَنَفِيُّ عَنْ عُبَيْدِ اللَّهِ ‏.‏\hadithno{2237}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Al-Qasim said:Aisha intended to set free two slaves of her who were spouses. She, therefore, asked the Prophet (ﷺ) about this matter. He commanded to begin with the man before the woman. The narrator Nasr said: Abu 'Ali al-Hanafi reported it to me on the authority of Ubaydullah}}
\hadithdefcmd{abudawud}{2238}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، جَاءَ مُسْلِمًا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ جَاءَتِ امْرَأَتُهُ مُسْلِمَةً بَعْدَهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّهَا قَدْ كَانَتْ أَسْلَمَتْ مَعِي ‏.‏ فَرَدَّهَا عَلَيْهِ ‏.‏\hadithno{2238}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: A man came after embracing Islam during the time of the Messenger of Allah (ﷺ). Afterwards his wife came after embracing Islam. He said: Messenger of Allah, she embraced Islam along with me; so restore her to me}}
\hadithdefcmd{abudawud}{2239}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنِي أَبُو أَحْمَدَ، عَنْ إِسْرَائِيلَ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَسْلَمَتِ امْرَأَةٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَتَزَوَّجَتْ فَجَاءَ زَوْجُهَا إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي قَدْ كُنْتُ أَسْلَمْتُ وَعَلِمَتْ بِإِسْلاَمِي فَانْتَزَعَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ زَوْجِهَا الآخَرِ وَرَدَّهَا إِلَى زَوْجِهَا الأَوَّلِ ‏.‏\hadithno{2239}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: A woman embraced Islam during the time of the Messenger of Allah (ﷺ); she then married. Her (former) husband then came to the Prophet (ﷺ) and said: Messenger of Allah, I have already embraced Islam, and she had the knowledge about my Islam. The Messenger of Allah (ﷺ) took her away from her latter husband and restored her to her former husband}}
\hadithdefcmd{abudawud}{2240}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو الرَّازِيُّ، حَدَّثَنَا سَلَمَةُ يَعْنِي ابْنَ الْفَضْلِ، ح وَحَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ، - الْمَعْنَى - كُلُّهُمْ عَنِ ابْنِ إِسْحَاقَ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ رَدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم ابْنَتَهُ زَيْنَبَ عَلَى أَبِي الْعَاصِي بِالنِّكَاحِ الأَوَّلِ لَمْ يُحْدِثْ شَيْئًا ‏.‏ قَالَ مُحَمَّدُ بْنُ عَمْرٍو فِي حَدِيثِهِ بَعْدَ سِتِّ سِنِينَ وَقَالَ الْحَسَنُ بْنُ عَلِيٍّ بَعْدَ سَنَتَيْنِ ‏.‏\hadithno{2240}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) restored his daughter Zaynab to Abul'As on the basis of the previous marriage, and he did not do anything afresh. Muhammad b. 'Amr said in his version: After six years. Al-Hasan b. 'Ali said: After two years}}
\hadithdefcmd{abudawud}{2241}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا هُشَيْمٌ، ح وَحَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، أَخْبَرَنَا هُشَيْمٌ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ حُمَيْضَةَ بْنِ الشَّمَرْدَلِ، عَنِ الْحَارِثِ بْنِ قَيْسٍ، - قَالَ مُسَدَّدٌ ابْنِ عُمَيْرَةَ ‏.‏ وَقَالَ وَهْبٌ الأَسَدِيِّ - قَالَ أَسْلَمْتُ وَعِنْدِي ثَمَانُ نِسْوَةٍ فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اخْتَرْ مِنْهُنَّ أَرْبَعًا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَحَدَّثَنَا بِهِ أَحْمَدُ بْنُ إِبْرَاهِيمَ حَدَّثَنَا هُشَيْمٌ بِهَذَا الْحَدِيثِ فَقَالَ قَيْسُ بْنُ الْحَارِثِ مَكَانَ الْحَارِثِ بْنِ قَيْسٍ قَالَ أَحْمَدُ بْنُ إِبْرَاهِيمَ هَذَا الصَّوَابُ ‏.‏ يَعْنِي قَيْسَ بْنَ الْحَارِثِ ‏.‏\hadithno{2241}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Al-Harith ibn Qays al-Asadi: I embraced Islam while I had eight wives. So I mentioned it to the Prophet (ﷺ). The Prophet (said) said: Select four of them. Abu Dawud said: This tradition has also been narrated to us by Ahmad b. Ibrahim from Hushaim. He said: Qais b. al-Harith instead of al-Harith b. Qais. Ahmad b. Ibrahim said: This is correct, i.e. Qais b. al-Harith}}
\hadithdefcmd{abudawud}{2242}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا بَكْرُ بْنُ عَبْدِ الرَّحْمَنِ، قَاضِي الْكُوفَةِ عَنْ عِيسَى بْنِ الْمُخْتَارِ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ حُمَيْضَةَ بْنِ الشَّمَرْدَلِ، عَنْ قَيْسِ بْنِ الْحَارِثِ، بِمَعْنَاهُ ‏.‏\hadithno{2242}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Qais bin Al Harith through a different chain of narrators to the same effect}}
\hadithdefcmd{abudawud}{2243}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ يَحْيَى بْنَ أَيُّوبَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي وَهْبٍ الْجَيْشَانِيِّ، عَنِ الضَّحَّاكِ بْنِ فَيْرُوزَ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أَسْلَمْتُ وَتَحْتِي أُخْتَانِ ‏.‏ قَالَ ‏ "‏ طَلِّقْ أَيَّتَهُمَا شِئْتَ ‏"‏ ‏.‏\hadithno{2243}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Al-Dahhak b. Firuz reported on the authority of his father:I said: Messenger of Allah, I have embraced Islam and two sisters are my wives. He said: Divorce any one of them you wish}}
\hadithdefcmd{abudawud}{2244}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، أَخْبَرَنِي أَبِي، عَنْ جَدِّي، رَافِعِ بْنِ سِنَانٍ أَنَّهُ أَسْلَمَ وَأَبَتِ امْرَأَتُهُ أَنْ تُسْلِمَ فَأَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتِ ابْنَتِي وَهِيَ فَطِيمٌ أَوْ شِبْهُهُ وَقَالَ رَافِعٌ ابْنَتِي ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اقْعُدْ نَاحِيَةً ‏"‏ ‏.‏ وَقَالَ لَهَا ‏"‏ اقْعُدِي نَاحِيَةً ‏"‏ ‏.‏ قَالَ وَأَقْعَدَ الصَّبِيَّةَ بَيْنَهُمَا ثُمَّ قَالَ ‏"‏ ادْعُوَاهَا ‏"‏ ‏.‏ فَمَالَتِ الصَّبِيَّةُ إِلَى أُمِّهَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ اهْدِهَا ‏"‏ ‏.‏ فَمَالَتِ الصَّبِيَّةُ إِلَى أَبِيهَا فَأَخَذَهَا ‏.‏\hadithno{2244}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abd al-Hamid ibn Ja'far reported from his father on the authority of his grandfather Rafi' ibn Sinan that he (Rafi' ibn Sinan) embraced Islam and his wife refused to embrace Islam. She came to the Prophet (ﷺ) and said:My daughter; she is weaned or about to wean. Rafi' said: My daughter. The Prophet (ﷺ) said to him: Be seated on a side. And he said to her: Be seated on a side. He then seated the girl between them, and said to them: Call her. The girl inclined to her mother. The Prophet (ﷺ) said: O Allah! guide her. The daughter then inclined to her father, and he took her}}
\hadithdefcmd{abudawud}{2245}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَهْلَ بْنَ سَعْدٍ السَّاعِدِيَّ، أَخْبَرَهُ أَنَّ عُوَيْمِرَ بْنَ أَشْقَرَ الْعَجْلاَنِيَّ جَاءَ إِلَى عَاصِمِ بْنِ عَدِيٍّ فَقَالَ لَهُ يَا عَاصِمُ أَرَأَيْتَ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً أَيَقْتُلُهُ فَتَقْتُلُونَهُ أَمْ كَيْفَ يَفْعَلُ سَلْ لِي يَا عَاصِمُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ ‏.‏ فَسَأَلَ عَاصِمٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فَكَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسَائِلَ وَعَابَهَا حَتَّى كَبُرَ عَلَى عَاصِمٍ مَا سَمِعَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَجَعَ عَاصِمٌ إِلَى أَهْلِهِ جَاءَهُ عُوَيْمِرٌ فَقَالَ لَهُ يَا عَاصِمُ مَاذَا قَالَ لَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ عَاصِمٌ لَمْ تَأْتِنِي بِخَيْرٍ قَدْ كَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسْأَلَةَ الَّتِي سَأَلْتُهُ عَنْهَا ‏.‏ فَقَالَ عُوَيْمِرٌ وَاللَّهِ لاَ أَنْتَهِي حَتَّى أَسْأَلَهُ عَنْهَا ‏.‏ فَأَقْبَلَ عُوَيْمِرٌ حَتَّى أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ وَسَطَ النَّاسِ فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً أَيَقْتُلُهُ فَتَقْتُلُونَهُ أَمْ كَيْفَ يَفْعَلُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ أُنْزِلَ فِيكَ وَفِي صَاحِبَتِكَ قُرْآنٌ فَاذْهَبْ فَأْتِ بِهَا ‏"‏ ‏.‏ قَالَ سَهْلٌ فَتَلاَعَنَا وَأَنَا مَعَ النَّاسِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا فَرَغَا قَالَ عُوَيْمِرٌ كَذَبْتُ عَلَيْهَا يَا رَسُولَ اللَّهِ إِنْ أَمْسَكْتُهَا ‏.‏ فَطَلَّقَهَا عُوَيْمِرٌ ثَلاَثًا قَبْلَ أَنْ يَأْمُرَهُ النَّبِيُّ صلى الله عليه وسلم ‏.‏ قَالَ ابْنُ شِهَابٍ فَكَانَتْ تِلْكَ سُنَّةَ الْمُتَلاَعِنَيْنِ ‏.‏\hadithno{2245}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5259) Sahih Muslim (1492)}\hadithtrans{Sahl bin Sa’ad Al Sa’idi said that ‘Uwaimir bin Ashqar Al Ajilani came to ‘Asim bin Adl and said to him “Asim tell me about a man who finds a man along with his wife. Should he kill him and then be killed by you, or how should he act? Ask the Apostle of Allaah(ﷺ) ‘Asim, for me about it. ‘Asim then asked the Apostle of Allaah(ﷺ) about it. The Apostle of Allaah(ﷺ) disliked the question and denounced it. What ‘Asim heard from the Apostle of Allaah(ﷺ) fell heavy on him. When ‘Asim returned to his family ‘Uwaimr came to him and asked ‘Asim “What did the Apostle of Allaah(ﷺ) say to you”? Asim replied “You did not do good to me”. The Apostle of Allaah(ﷺ) disliked the question that I asked him. Thereupon ‘Uwaimir said “I swear by Allaah, I shall not leave until I ask him about it. So, ‘Uwaimir came to the Apostle of Allaah(ﷺ) while he was sitting in the midst of the people.” He said “Apostle of Allaah(ﷺ) tell me about a man who finds a man along with his wife. Should he kill him and then be killed by you, or how should he act?” The Apostle of Allaah(ﷺ) said “A revelation has been sent down about you and your wife so go away and bring her. Sahl said “So we cursed one another while I was along with the people who were with the Apostle of Allaah(ﷺ). Then when they finished, ‘Umamir said “I shall have lied against her, Apostle of Allaah(ﷺ) if I keep her. He pronounced her divorce three times before the Apostle of Allaah(ﷺ)commanded him (to do so). Ibn Shihab said “Then this became the method of invoking curses.”}}
\hadithdefcmd{abudawud}{2246}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى، حَدَّثَنِي مُحَمَّدٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي عَبَّاسُ بْنُ سَهْلٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِعَاصِمِ بْنِ عَدِيٍّ ‏ "‏ أَمْسِكِ الْمَرْأَةَ عِنْدَكَ حَتَّى تَلِدَ ‏"‏ ‏.‏\hadithno{2246}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Abbas bin Sahl reported on the authority of his father “The Prophet (ﷺ) said to ‘Asim bin ‘Adl. Keep the woman with you till she begets the child}}
\hadithdefcmd{abudawud}{2247}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ حَضَرْتُ لِعَانَهُمَا عِنْدَ النَّبِيِّ صلى الله عليه وسلم وَأَنَا ابْنُ خَمْسَ عَشْرَةَ سَنَةً ‏.‏ وَسَاقَ الْحَدِيثَ قَالَ فِيهِ ثُمَّ خَرَجَتْ حَامِلاً فَكَانَ الْوَلَدُ يُدْعَى إِلَى أُمِّهِ ‏.‏\hadithno{2247}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1492)}\hadithtrans{Sahl bin Sa’d Al Sa’idi said “I attended the invoking of the curses with the Messenger of Allah (ﷺ) when I was fifteen. He then narrated the rest of the tradition. In this version he said “She then came out pregnant and the child was ascribed to its mother}}
\hadithdefcmd{abudawud}{2248}{حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ الْوَرَكَانِيُّ، أَخْبَرَنَا إِبْرَاهِيمُ، - يَعْنِي ابْنَ سَعْدٍ - عَنِ الزُّهْرِيِّ، عَنْ سَهْلِ بْنِ سَعْدٍ، فِي خَبَرِ الْمُتَلاَعِنَيْنِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَبْصِرُوهَا فَإِنْ جَاءَتْ بِهِ أَدْعَجَ الْعَيْنَيْنِ عَظِيمَ الأَلْيَتَيْنِ فَلاَ أُرَاهُ إِلاَّ قَدْ صَدَقَ وَإِنْ جَاءَتْ بِهِ أُحَيْمِرَ كَأَنَّهُ وَحَرَةٌ فَلاَ أُرَاهُ إِلاَّ كَاذِبًا ‏"‏ ‏.‏ قَالَ فَجَاءَتْ بِهِ عَلَى النَّعْتِ الْمَكْرُوهِ ‏.‏\hadithno{2248}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Sahl bin Sa’ad reported the Apostle of Allaah(ﷺ) as saying - in the tradition of spouses who invoked curses to each other “Look if she bears a child which has very black eyes, large buttocks, I cannot but imagine that he (i.e., ‘Uwaimir) has spoken the truth. But, if she bears a reddish child like the lizard with red spots (waharah), I cannot imagine that ‘Uwaimir has lied against her. She gave birth to a child (like that described the Prophet (ﷺ) ) in a detestable manner}}
\hadithdefcmd{abudawud}{2249}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ الدِّمَشْقِيُّ، حَدَّثَنَا الْفِرْيَابِيُّ، عَنِ الأَوْزَاعِيِّ، عَنِ الزُّهْرِيِّ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، بِهَذَا الْخَبَرِ قَالَ فَكَانَ يُدْعَى - يَعْنِي الْوَلَدَ - لأُمِّهِ ‏.‏\hadithno{2249}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4745)}\hadithtrans{The tradition mentioned above has also been transmitted by Sahl bin Sa’d Al Sa’idi through a different chain of narrators. This version adds the child was attributed to its mother}}
\hadithdefcmd{abudawud}{2250}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ الْفِهْرِيِّ، وَغَيْرِهِ، عَنِ ابْنِ شِهَابٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، فِي هَذَا الْخَبَرِ قَالَ فَطَلَّقَهَا ثَلاَثَ تَطْلِيقَاتٍ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَنْفَذَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَانَ مَا صُنِعَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم سُنَّةً ‏.‏ قَالَ سَهْلٌ حَضَرْتُ هَذَا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَضَتِ السُّنَّةُ بَعْدُ فِي الْمُتَلاَعِنَيْنِ أَنْ يُفَرَّقَ بَيْنَهُمَا ثُمَّ لاَ يَجْتَمِعَانِ أَبَدًا ‏.‏\hadithno{2250}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Sahl bin Sa’d Al Sa’idi through a different chain of narrators. This version has “He divorced her three times before the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) implemented it and what is done before the Prophet (ﷺ) is sunnah(model behavior of the Prophet). Sahl said “I attended this before the Messenger of Allah(ﷺ). Afterwards the sunnah about those who invoked curses on each other was established that they (the spouses) were separated from each other and they would never be united.”}}
\hadithdefcmd{abudawud}{2251}{حَدَّثَنَا مُسَدَّدٌ، وَوَهْبُ بْنُ بَيَانٍ، وَأَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، وَعَمْرُو بْنُ عُثْمَانَ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ مُسَدَّدٌ قَالَ شَهِدْتُ الْمُتَلاَعِنَيْنِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا ابْنُ خَمْسَ عَشْرَةَ فَفَرَّقَ بَيْنَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ تَلاَعَنَا ‏.‏ وَتَمَّ حَدِيثُ مُسَدَّدٍ ‏.‏ وَقَالَ الآخَرُونَ إِنَّهُ شَهِدَ النَّبِيَّ صلى الله عليه وسلم فَرَّقَ بَيْنَ الْمُتَلاَعِنَيْنِ فَقَالَ الرَّجُلُ كَذَبْتُ عَلَيْهَا يَا رَسُولَ اللَّهِ إِنْ أَمْسَكْتُهَا - لَمْ يَقُلْ بَعْضُهُمْ عَلَيْهَا - قَالَ أَبُو دَاوُدَ لَمْ يُتَابِعِ ابْنَ عُيَيْنَةَ أَحَدٌ عَلَى أَنَّهُ فَرَّقَ بَيْنَ الْمُتَلاَعِنَيْنِ ‏.‏\hadithno{2251}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6854)}\hadithtrans{Sahl bin Sa’ad said “The version of Musaddad has “I witnessed the invoking of curses by the two spouses during the life time of the Apostle of Allaah(ﷺ) when I was fifteen years old. When they finished invoking curses, the Apostle of Allaah(ﷺ) separated them from each other. Here ends the version of Musaddad. Others said “He was present when the Prophet (ﷺ) separated the spouses who invoked curses on each other. The man (Sahl) said “I shall have lied against her, Apostle of Allaah(ﷺ) if I keep her. Abu Dawud said “Some narrators did not mention the word ‘alaiha(against her).” Abu Dawud said “No one supported Ibn ‘Uyainah that he separated the spouses who invoked curses.”}}
\hadithdefcmd{abudawud}{2252}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ، حَدَّثَنَا فُلَيْحٌ، عَنِ الزُّهْرِيِّ، عَنْ سَهْلِ بْنِ سَعْدٍ، فِي هَذَا الْحَدِيثِ وَكَانَتْ حَامِلاً فَأَنْكَرَ حَمْلَهَا فَكَانَ ابْنُهَا يُدْعَى إِلَيْهَا ثُمَّ جَرَتِ السُّنَّةُ فِي الْمِيرَاثِ أَنْ يَرِثَهَا وَتَرِثَ مِنْهُ مَا فَرَضَ اللَّهُ عَزَّ وَجَلَّ لَهَا ‏.‏\hadithno{2252}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6746)}\hadithtrans{The tradition mentioned above has also been transmitted by Sahl bin Sa’d through a different chain of narrators. This version has “She was pregnant, he denied pregnancy from him. So her son was attributed to her. In the law of succession the practice (sunnah) was established that the son gets a share in the inheritance of his mother and the mother gets the share in the inheritance of her son according to the shares prescribed by Allaah the Exalted}}
\hadithdefcmd{abudawud}{2253}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ إِنَّا لَلَيْلَةُ جُمْعَةٍ فِي الْمَسْجِدِ إِذْ دَخَلَ رَجُلٌ مِنَ الأَنْصَارِ فِي الْمَسْجِدِ فَقَالَ لَوْ أَنَّ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً فَتَكَلَّمَ بِهِ جَلَدْتُمُوهُ أَوْ قَتَلَ قَتَلْتُمُوهُ فَإِنْ سَكَتَ سَكَتَ عَلَى غَيْظٍ وَاللَّهِ لأَسْأَلَنَّ عَنْهُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَلَمَّا كَانَ مِنَ الْغَدِ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ فَقَالَ لَوْ أَنَّ رَجُلاً وَجَدَ مَعَ امْرَأَتِهِ رَجُلاً فَتَكَلَّمَ بِهِ جَلَدْتُمُوهُ أَوْ قَتَلَ قَتَلْتُمُوهُ أَوْ سَكَتَ سَكَتَ عَلَى غَيْظٍ ‏.‏ فَقَالَ ‏"‏ اللَّهُمَّ افْتَحْ ‏"‏ ‏.‏ وَجَعَلَ يَدْعُو فَنَزَلَتْ آيَةُ اللِّعَانِ ‏\{‏ وَالَّذِينَ يَرْمُونَ أَزْوَاجَهُمْ وَلَمْ يَكُنْ لَهُمْ شُهَدَاءُ إِلاَّ أَنْفُسُهُمْ ‏\}‏ هَذِهِ الآيَةُ فَابْتُلِيَ بِهِ ذَلِكَ الرَّجُلُ مِنْ بَيْنِ النَّاسِ فَجَاءَ هُوَ وَامْرَأَتُهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَتَلاَعَنَا فَشَهِدَ الرَّجُلُ أَرْبَعَ شَهَادَاتٍ بِاللَّهِ إِنَّهُ لَمِنَ الصَّادِقِينَ ثُمَّ لَعَنَ الْخَامِسَةَ عَلَيْهِ إِنْ كَانَ مِنَ الْكَاذِبِينَ قَالَ فَذَهَبَتْ لِتَلْتَعِنَ فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَهْ ‏"‏ ‏.‏ فَأَبَتْ فَفَعَلَتْ فَلَمَّا أَدْبَرَا قَالَ ‏"‏ لَعَلَّهَا أَنْ تَجِيءَ بِهِ أَسْوَدَ جَعْدًا ‏"‏ ‏.‏ فَجَاءَتْ بِهِ أَسْوَدَ جَعْدًا ‏.‏\hadithno{2253}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1495)}\hadithtrans{‘Abd Allah (bin Mas’ud) said “We were in the mosque on the night of a Friday, suddenly a man from the Ansar entered the mosque”. And said “If a man finds a man along with wife and declares (about her adultery) you will flog him. Or if he kills you, you will kill him or if keeps silence he will keep silence in anger. I swear by Allaah, I shall ask the Apostle of Allaah(ﷺ) about it”. On the next day he came to the Apostle of Allaah(ﷺ) and said “If a man finds a man along with wife and declares (about her adultery) you will flog him. Or if he kills you, you will kill him or if keeps silence he will keep silence in anger.” He said “O Allaah, disclose”. He kept on praying until the verses regarding invoking curses (li’an) came down “As for those who accuse their wives but have no witnesses except themselves.” So, the man was first involved in this trial among the people. He and his wife came to the Apostle of Allaah(ﷺ). They invoked curses on each other. The man bore witness before Allaah four times that the thing he said was indeed true. He then invoked curse of Allaah on him for the fifth time if he was a liar. She then wanted to invoke curses of Allaah on him. The Prophet (ﷺ) said “Do not do that. Bust she refused and did so (i.e., invoked curses). When they returned he said “Perhaps she will give birth to a black child with curly hair}}
\hadithdefcmd{abudawud}{2254}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، أَخْبَرَنَا هِشَامُ بْنُ حَسَّانَ، حَدَّثَنِي عِكْرِمَةُ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ هِلاَلَ بْنَ أُمَيَّةَ، قَذَفَ امْرَأَتَهُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِشَرِيكِ بْنِ سَحْمَاءَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الْبَيِّنَةَ أَوْ حَدٌّ فِي ظَهْرِكَ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ إِذَا رَأَى أَحَدُنَا رَجُلاً عَلَى امْرَأَتِهِ يَلْتَمِسُ الْبَيِّنَةَ فَجَعَلَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏"‏ الْبَيِّنَةَ وَإِلاَّ فَحَدٌّ فِي ظَهْرِكَ ‏"‏ ‏.‏ فَقَالَ هِلاَلٌ وَالَّذِي بَعَثَكَ بِالْحَقِّ نَبِيًّا إِنِّي لَصَادِقٌ وَلَيُنْزِلَنَّ اللَّهُ فِي أَمْرِي مَا يُبَرِّئُ ظَهْرِي مِنَ الْحَدِّ فَنَزَلَتْ ‏\{‏ وَالَّذِينَ يَرْمُونَ أَزْوَاجَهُمْ وَلَمْ يَكُنْ لَهُمْ شُهَدَاءُ إِلاَّ أَنْفُسُهُمْ ‏\}‏ فَقَرَأَ حَتَّى بَلَغَ ‏\{‏ مِنَ الصَّادِقِينَ ‏\}‏ فَانْصَرَفَ النَّبِيُّ صلى الله عليه وسلم فَأَرْسَلَ إِلَيْهِمَا فَجَاءَا فَقَامَ هِلاَلُ بْنُ أُمَيَّةَ فَشَهِدَ وَالنَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏"‏ اللَّهُ يَعْلَمُ أَنَّ أَحَدَكُمَا كَاذِبٌ فَهَلْ مِنْكُمَا مِنْ تَائِبٍ ‏"‏ ‏.‏ ثُمَّ قَامَتْ فَشَهِدَتْ فَلَمَّا كَانَ عِنْدَ الْخَامِسَةِ أَنَّ غَضَبَ اللَّهِ عَلَيْهَا إِنْ كَانَ مِنَ الصَّادِقِينَ وَقَالُوا لَهَا إِنَّهَا مُوجِبَةٌ ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَتَلَكَّأَتْ وَنَكَصَتْ حَتَّى ظَنَنَّا أَنَّهَا سَتَرْجِعُ فَقَالَتْ لاَ أَفْضَحُ قَوْمِي سَائِرَ الْيَوْمِ ‏.‏ فَمَضَتْ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَبْصِرُوهَا فَإِنْ جَاءَتْ بِهِ أَكْحَلَ الْعَيْنَيْنِ سَابِغَ الأَلْيَتَيْنِ خَدَلَّجَ السَّاقَيْنِ فَهُوَ لِشَرِيكِ بْنِ سَحْمَاءَ ‏"‏ ‏.‏ فَجَاءَتْ بِهِ كَذَلِكَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَوْلاَ مَا مَضَى مِنْ كِتَابِ اللَّهِ لَكَانَ لِي وَلَهَا شَأْنٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا مِمَّا تَفَرَّدَ بِهِ أَهْلُ الْمَدِينَةِ حَدِيثُ ابْنِ بَشَّارٍ حَدِيثُ هِلاَلٍ ‏.‏\hadithno{2254}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2671)}\hadithtrans{Ibn ‘Abbas said “Hilal bin Umayyah accused his wife in the presence of Prophet (ﷺ) of having committed adultery with Sharik bin Sahma’”. The Prophet (ﷺ) said “Produce evidence or you must receive punishment on your back.” He said “Apostle of Allaah(ﷺ) when one of us sees a man having intercourse with his wife should he go and seek evidence?” But the Prophet (ﷺ) merely said “You must produce evidence or you must receive punishment on your back.” Hilal then said “By Him Who sent you with the Truth, I am speaking Truly. May Allaah send down something which will free my back from punishment. Then the following Qur’anic verses were revealed “And those who make charges against their spouses but have no witnesses except themselves” reciting till he reached “one of those who speak the truth”. The Prophet (ﷺ) then returned and sent for them and they came (to him). Hilal bin Umayyah stood up and testified and the Prophet (ﷺ) was saying “Allaah knows that one of you is lying. Will one of you repent?” Then the woman got up and testified, but when she was about to do it a fifth time saying that Allaah’s anger be upon her if he was one of those who spoke the truth, they said to her “this is the deciding one”. Ibn ‘Abbas said “She then hesitated and drew back so that we thought the she would withdraw(what she said) “Look and see whether she gives birth to a child with eyes looking as if they have antimony in them, wide buttocks and fat legs, if she did. Sharik bin Sahma’ will be its father. She then gave birth to a child of a similar description. The Prophet (ﷺ) thereupon said “If it were not for what has already been stated in Allaah’s book I would have dealt severely with her.” Abu Dawud said “This tradition has been transmitted by the people of Medina alone. They narrated the tradition of Hilal on the authority of Ibn Bashshar.”}}
\hadithdefcmd{abudawud}{2255}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ الشَّعِيرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ كُلَيْبٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَمَرَ رَجُلاً حِينَ أَمَرَ الْمُتَلاَعِنَيْنِ أَنْ يَتَلاَعَنَا أَنْ يَضَعَ يَدَهُ عَلَى فِيهِ عِنْدَ الْخَامِسَةِ يَقُولُ إِنَّهَا مُوجِبَةٌ ‏.‏\hadithno{2255}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: When the Prophet (ﷺ) ordered a man and his wife to invoke curses on each other, he ordered a man to put his hand on his mouth when he came to the fifth utterance, saying that it would be the deciding one}}
\hadithdefcmd{abudawud}{2256}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا عَبَّادُ بْنُ مَنْصُورٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ هِلاَلُ بْنُ أُمَيَّةَ وَهُوَ أَحَدُ الثَّلاَثَةِ الَّذِينَ تَابَ اللَّهُ عَلَيْهِمْ فَجَاءَ مِنْ أَرْضِهِ عَشِيًّا فَوَجَدَ عِنْدَ أَهْلِهِ رَجُلاً فَرَأَى بِعَيْنَيْهِ وَسَمِعَ بِأُذُنَيْهِ فَلَمْ يَهِجْهُ حَتَّى أَصْبَحَ ثُمَّ غَدَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي جِئْتُ أَهْلِي عِشَاءً فَوَجَدْتُ عِنْدَهُمْ رَجُلاً فَرَأَيْتُ بِعَيْنِي وَسَمِعْتُ بِأُذُنِي فَكَرِهَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا جَاءَ بِهِ وَاشْتَدَّ عَلَيْهِ فَنَزَلَتْ ‏\{‏ وَالَّذِينَ يَرْمُونَ أَزْوَاجَهُمْ وَلَمْ يَكُنْ لَهُمْ شُهَدَاءُ إِلاَّ أَنْفُسُهُمْ فَشَهَادَةُ أَحَدِهِمْ ‏\}‏ الآيَتَيْنِ كِلْتَيْهِمَا فَسُرِّيَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَبْشِرْ يَا هِلاَلُ قَدْ جَعَلَ اللَّهُ عَزَّ وَجَلَّ لَكَ فَرَجًا وَمَخْرَجًا ‏"‏ ‏.‏ قَالَ هِلاَلٌ قَدْ كُنْتُ أَرْجُو ذَلِكَ مِنْ رَبِّي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرْسِلُوا إِلَيْهَا ‏"‏ ‏.‏ فَجَاءَتْ فَتَلاَ عَلَيْهِمَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَذَكَّرَهُمَا وَأَخْبَرَهُمَا أَنَّ عَذَابَ الآخِرَةِ أَشَدُّ مِنْ عَذَابِ الدُّنْيَا فَقَالَ هِلاَلٌ وَاللَّهِ لَقَدْ صَدَقْتُ عَلَيْهَا فَقَالَتْ قَدْ كَذَبَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَعِنُوا بَيْنَهُمَا ‏"‏ ‏.‏ فَقِيلَ لِهِلاَلٍ اشْهَدْ ‏.‏ فَشَهِدَ أَرْبَعَ شَهَادَاتٍ بِاللَّهِ إِنَّهُ لَمِنَ الصَّادِقِينَ فَلَمَّا كَانَتِ الْخَامِسَةُ قِيلَ لَهُ يَا هِلاَلُ اتَّقِ اللَّهَ فَإِنَّ عَذَابَ الدُّنْيَا أَهْوَنُ مِنْ عَذَابِ الآخِرَةِ وَإِنَّ هَذِهِ الْمُوجِبَةُ الَّتِي تُوجِبُ عَلَيْكَ الْعَذَابَ ‏.‏ فَقَالَ وَاللَّهِ لاَ يُعَذِّبُنِي اللَّهُ عَلَيْهَا كَمَا لَمْ يَجْلِدْنِي عَلَيْهَا ‏.‏ فَشَهِدَ الْخَامِسَةَ أَنَّ لَعْنَةَ اللَّهِ عَلَيْهِ إِنْ كَانَ مِنَ الْكَاذِبِينَ ثُمَّ قِيلَ لَهَا اشْهَدِي ‏.‏ فَشَهِدَتْ أَرْبَعَ شَهَادَاتٍ بِاللَّهِ إِنَّهُ لَمِنَ الْكَاذِبِينَ فَلَمَّا كَانَتِ الْخَامِسَةُ قِيلَ لَهَا اتَّقِي اللَّهَ فَإِنَّ عَذَابَ الدُّنْيَا أَهْوَنُ مِنْ عَذَابِ الآخِرَةِ وَإِنَّ هَذِهِ الْمُوجِبَةُ الَّتِي تُوجِبُ عَلَيْكِ الْعَذَابَ ‏.‏ فَتَلَكَّأَتْ سَاعَةً ثُمَّ قَالَتْ وَاللَّهِ لاَ أَفْضَحُ قَوْمِي فَشَهِدَتِ الْخَامِسَةَ أَنَّ غَضَبَ اللَّهِ عَلَيْهَا إِنْ كَانَ مِنَ الصَّادِقِينَ فَفَرَّقَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَهُمَا وَقَضَى أَنْ لاَ يُدْعَى وَلَدُهَا لأَبٍ وَلاَ تُرْمَى وَلاَ يُرْمَى وَلَدُهَا وَمَنْ رَمَاهَا أَوْ رَمَى وَلَدَهَا فَعَلَيْهِ الْحَدُّ وَقَضَى أَنْ لاَ بَيْتَ لَهَا عَلَيْهِ وَلاَ قُوتَ مِنْ أَجْلِ أَنَّهُمَا يَتَفَرَّقَانِ مِنْ غَيْرِ طَلاَقٍ وَلاَ مُتَوَفَّى عَنْهَا وَقَالَ ‏"‏ إِنْ جَاءَتْ بِهِ أُصَيْهِبَ أُرَيْصِحَ أُثَيْبِجَ حَمْشَ السَّاقَيْنِ فَهُوَ لِهِلاَلٍ وَإِنْ جَاءَتْ بِهِ أَوْرَقَ جَعْدًا جُمَالِيًّا خَدَلَّجَ السَّاقَيْنِ سَابِغَ الأَلْيَتَيْنِ فَهُوَ لِلَّذِي رُمِيَتْ بِهِ فَجَاءَتْ بِهِ أَوْرَقَ جَعْدًا جُمَالِيًّا خَدَلَّجَ السَّاقَيْنِ سَابِغَ الأَلْيَتَيْنِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْلاَ الأَيْمَانُ لَكَانَ لِي وَلَهَا شَأْنٌ ‏"‏ ‏.‏ قَالَ عِكْرِمَةُ فَكَانَ بَعْدَ ذَلِكَ أَمِيرًا عَلَى مُضَرَ وَمَا يُدْعَى لأَبٍ ‏.‏\hadithno{2256}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn ‘Abbas said “Hilal bin Umayyah was one of the three persons whose repentance was accepted by Allaah. One night he returned from his land and found a man along with his wife. He witnessed with his eyes and heard with his ears. He did not threaten him till the morning.” Next day he went to the Apostle of Allaah(ﷺ) in the morning and said Apostle of Allaah(ﷺ) “I came to my wife in the night and found a man along with her. I saw with my own eyes and heard with my own ears. The Apostle of Allaah(ﷺ) disliked what he described and he took it seriously. There upon the following Qur’anic verse came down “And those who make charges against their spouses but have no witnesses except themselves, let the testimony of one of them ....” When the Apostle of Allaah(ﷺ) came to himself (after the revelation ended) he said “Glad tidings to you Hilal, Allaah the exalted has made ease and a way out for you.” Hilal said “I expected that from my Lord. The Apostle of Allaah(ﷺ) said “Send for her. She then came.” The Apostle of Allaah(ﷺ) recited the verses to them and he reminded them and told them that the punishment in the next world was more severe than that in n this world. Hilal said “I swear by Allah I spoke the truth against her.” She said “He told a lie.” The Apostle of Allaah(ﷺ) said “Apply the method of invoking curses on one another. Hilal was told “Bear witness. So he bore witness before Allaah four times that he spoke the truth.” When he was about to utter the fifth time he was told “Hilal fear Allah, for the punishment in this world is easier than that in the next world and this is the deciding one, that will surely cause punishment to you.” He said “I swear by Allaah. Allah will not punish me for this (act), as He did not cause me to be flogged for this (act).” So he bore witness a fifth time invoking the curse of Allah on him if he was of those who tell a lie. Then the people said to her, Testify. So she gave testimony before Allaah that he was a liar. When she was going to testify the fifth time she was told “Fear Allah, for the punishment in this world is easier than that in the next world. This is the deciding one that will surely cause punishment to you.” She hesitated for a moment. And then said “By Allah, I will not disgrace my people.” So she testified a fifth time invoking the curse of Allah on her if he spoke the truth. Apostle of Allaah(ﷺ) separated them from each other and decided that the child will not be attributed to its father. Neither she nor her child will be accused of adultery. He who accuses her or her child will be liable to punishment. He also decided that there will be no dwelling and maintenance for her (from the husband) as they were separated without divorce and death. He then said “If she gives birth to a child with reddish hair, light buttocks, wide belly and light shins he will be the child of Hilal. If she bears a dusky child with curly hair, fat limbs, fat shins and fat buttocks he will be the child of the one who was accused of adultery. She gave birth to a child with curly hair, fat limbs, fat shins and fat buttocks. The Apostle of Allaah(ﷺ) said “Had there been no oaths, I would have dealt with her severely.” ‘Ikrimah said “Later on he became the chief of the tribe of Mudar. He was not attributed to his father.”}}
\hadithdefcmd{abudawud}{2257}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، قَالَ سَمِعَ عَمْرٌو، سَعِيدَ بْنَ جُبَيْرٍ يَقُولُ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلْمُتَلاَعِنَيْنِ ‏"‏ حِسَابُكُمَا عَلَى اللَّهِ أَحَدُكُمَا كَاذِبٌ لاَ سَبِيلَ لَكَ عَلَيْهَا ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ مَالِي ‏.‏ قَالَ ‏"‏ لاَ مَالَ لَكَ إِنْ كُنْتَ صَدَقْتَ عَلَيْهَا فَهُوَ بِمَا اسْتَحْلَلْتَ مِنْ فَرْجِهَا وَإِنْ كُنْتَ كَذَبْتَ عَلَيْهَا فَذَلِكَ أَبْعَدُ لَكَ ‏"‏ ‏.‏\hadithno{2257}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5312) Sahih Muslim (1493)}\hadithtrans{Ibn ‘Umar said “The Apostle of Allaah(ﷺ) said to the spouses who invoked curses on each other. Your reckoning is in Allaah’s hands for one of you is liar there is no way for you to (remarry) her. He then asked Apostle of Allaah(ﷺ) what about my property? He replied “There is no property for you. If you have spoken the truth, it is the price for your having had the right to intercourse with her and if you have lied against her it is still more remote for you}}
\hadithdefcmd{abudawud}{2258}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنَا أَيُّوبُ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، قَالَ قُلْتُ لاِبْنِ عُمَرَ رَجُلٌ قَذَفَ امْرَأَتَهُ ‏.‏ قَالَ فَرَّقَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَخَوَىْ بَنِي الْعَجْلاَنِ وَقَالَ ‏ "‏ اللَّهُ يَعْلَمُ أَنَّ أَحَدَكُمَا كَاذِبٌ ‏.‏ فَهَلْ مِنْكُمَا تَائِبٌ ‏"‏ ‏.‏ يُرَدِّدُهَا ثَلاَثَ مَرَّاتٍ فَأَبَيَا فَفَرَّقَ بَيْنَهُمَا ‏.‏\hadithno{2258}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5311) Sahih Muslim (1493)}\hadithtrans{Sa’d bin Jubair said I asked Ibn ‘Umar A man accused his wife of adultery? He said “The Apostle of Allaah(ﷺ) separated the brother and the sister of Banu Al ‘Ajilan (i.e., husband and wife). He said Allaah knows that one of you is a liar, will one of you repent? He repeated these words three times, but they refused. So he separated them from each other}}
\hadithdefcmd{abudawud}{2259}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، لاَعَنَ امْرَأَتَهُ فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَانْتَفَى مِنْ وَلَدِهَا فَفَرَّقَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَهُمَا وَأَلْحَقَ الْوَلَدَ بِالْمَرْأَةِ ‏.‏ قَالَ أَبُو دَاوُدَ الَّذِي تَفَرَّدَ بِهِ مَالِكٌ قَوْلُهُ ‏ "‏ وَأَلْحَقَ الْوَلَدَ بِالْمَرْأَةِ ‏"‏ ‏.‏ وَقَالَ يُونُسُ عَنِ الزُّهْرِيِّ عَنْ سَهْلِ بْنِ سَعْدٍ فِي حَدِيثِ اللِّعَانِ وَأَنْكَرَ حَمْلَهَا فَكَانَ ابْنُهَا يُدْعَى إِلَيْهَا ‏.‏\hadithno{2259}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5315) Sahih Muslim (1494)}\hadithtrans{Ibn ‘Umar said A man invoked curses on his wife (charging her of adultery) during the time of Apostle of Allaah(ﷺ) and disowned the child. The Apostle of Allaah(ﷺ) therefore separated them and attributed the child to the woman. Abu Dawud said “The words narrated by Malik alone are “and he attributed the child to the woman.”" Abu Dawud said:The words narrated by Malik alone are: "and he attributed the child to the woman." Yunus narrated from Al Zuhri on the authority of Sahl bin Sa’d in the tradition regarding li’an(invoking curses). He disowned her conception hence her child was attributed to her}}
\hadithdefcmd{abudawud}{2260}{حَدَّثَنَا ابْنُ أَبِي خَلَفٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم مِنْ بَنِي فَزَارَةَ فَقَالَ إِنَّ امْرَأَتِي جَاءَتْ بِوَلَدٍ أَسْوَدَ فَقَالَ ‏"‏ هَلْ لَكَ مِنْ إِبِلٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ مَا أَلْوَانُهَا ‏"‏ ‏.‏ قَالَ حُمْرٌ قَالَ ‏"‏ فَهَلْ فِيهَا مِنْ أَوْرَقَ ‏"‏ ‏.‏ قَالَ إِنَّ فِيهَا لَوُرْقًا ‏.‏ قَالَ ‏"‏ فَأَنَّى تُرَاهُ ‏"‏ ‏.‏ قَالَ عَسَى أَنْ يَكُونَ نَزَعَهُ عِرْقٌ ‏.‏ قَالَ ‏"‏ وَهَذَا عَسَى أَنْ يَكُونَ نَزَعَهُ عِرْقٌ ‏"‏ ‏.‏\hadithno{2260}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1500)}\hadithtrans{Abu Hurairah said A man from Banu Fazarah came to the Prophet (ﷺ) and said “My wife has given birth to a black son”. He said “Have you any camels?” He said “They are red”. He asked “Is there a dusky one among them?” He replied “Some of them are dusky”. He asked “How do you think they have come about?” He replied “This may be a strain to which they reverted”. He said “And this is perhaps a strain to which the child has reverted.”}}
\hadithdefcmd{abudawud}{2261}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِإِسْنَادِهِ وَمَعْنَاهُ قَالَ وَهُوَ حِينَئِذٍ يُعَرِّضُ بِأَنْ يَنْفِيَهُ ‏.‏\hadithno{2261}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1500)}\hadithtrans{The tradition mentioned above has also been narrated by Al Zuhri through a different chain of narrators to the same effect. This version adds “At that time he was hinting at disowning the child.”}}
\hadithdefcmd{abudawud}{2262}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ أَعْرَابِيًّا، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنَّ امْرَأَتِي وَلَدَتْ غُلاَمًا أَسْوَدَ وَإِنِّي أُنْكِرُهُ ‏.‏ فَذَكَرَ مَعْنَاهُ ‏.‏\hadithno{2262}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (7314) Sahih Muslim (1500)}\hadithtrans{Narrated AbuHurayrah: A bedouin came to the Prophet (ﷺ), and said: My wife has given birth to a black son, and I disown him. He then narrated the rest of the tradition to the same effect}}
\hadithdefcmd{abudawud}{2263}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، - يَعْنِي ابْنَ الْحَارِثِ - عَنِ ابْنِ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ يُونُسَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ حِينَ نَزَلَتْ آيَةُ الْمُتَلاَعِنَيْنِ ‏ "‏ أَيُّمَا امْرَأَةٍ أَدْخَلَتْ عَلَى قَوْمٍ مَنْ لَيْسَ مِنْهُمْ فَلَيْسَتْ مِنَ اللَّهِ فِي شَىْءٍ وَلَنْ يُدْخِلَهَا اللَّهُ جَنَّتَهُ وَأَيُّمَا رَجُلٍ جَحَدَ وَلَدَهُ وَهُوَ يَنْظُرُ إِلَيْهِ احْتَجَبَ اللَّهُ مِنْهُ وَفَضَحَهُ عَلَى رُءُوسِ الأَوَّلِينَ وَالآخِرِينَ ‏"‏ ‏.‏\hadithno{2263}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: AbuHurayrah heard the Messenger of Allah (ﷺ) say when the verse about invoking curses came down: Any woman who brings to her family one who does not belong to it has nothing to do with Allah (i.e. expects no mercy from Allah), and Allah will not bring her into His Paradise. Allah, the Exalted, will veil Himself from any man who disowns his child when he looks at him, and disgrace him in the presence of all creatures, first and last}}
\hadithdefcmd{abudawud}{2264}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ سَلْمٍ، - يَعْنِي ابْنَ أَبِي الذَّيَّالِ - حَدَّثَنِي بَعْضُ، أَصْحَابِنَا عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ مُسَاعَاةَ فِي الإِسْلاَمِ مَنْ سَاعَى فِي الْجَاهِلِيَّةِ فَقَدْ لَحِقَ بِعَصَبَتِهِ وَمَنِ ادَّعَى وَلَدًا مِنْ غَيْرِ رِشْدَةٍ فَلاَ يَرِثُ وَلاَ يُورَثُ ‏"‏ ‏.‏\hadithno{2264}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: There is no prostitution in Islam. If anyone practised prostitution in pre-Islamic times, the child will be attributed to the master (of the slave-woman). He who claims his child without a valid marriage or ownership will neither inherit nor be inherited}}
\hadithdefcmd{abudawud}{2265}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا مُحَمَّدُ بْنُ رَاشِدٍ، ح وَحَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا مُحَمَّدُ بْنُ رَاشِدٍ، - وَهُوَ أَشْبَعُ - عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى أَنَّ كُلَّ مُسْتَلْحَقٍ اسْتُلْحِقَ بَعْدَ أَبِيهِ الَّذِي يُدْعَى لَهُ ادَّعَاهُ وَرَثَتُهُ فَقَضَى أَنَّ كُلَّ مَنْ كَانَ مِنْ أَمَةٍ يَمْلِكُهَا يَوْمَ أَصَابَهَا فَقَدْ لَحِقَ بِمَنِ اسْتَلْحَقَهُ وَلَيْسَ لَهُ مِمَّا قُسِمَ قَبْلَهُ مِنَ الْمِيرَاثِ شَىْءٌ وَمَا أَدْرَكَ مِنْ مِيرَاثٍ لَمْ يُقْسَمْ فَلَهُ نَصِيبُهُ وَلاَ يُلْحَقُ إِذَا كَانَ أَبُوهُ الَّذِي يُدْعَى لَهُ أَنْكَرَهُ وَإِنْ كَانَ مِنْ أَمَةٍ لَمْ يَمْلِكْهَا أَوْ مِنْ حُرَّةٍ عَاهَرَ بِهَا فَإِنَّهُ لاَ يُلْحَقُ بِهِ وَلاَ يَرِثُ وَإِنْ كَانَ الَّذِي يُدْعَى لَهُ هُوَ ادَّعَاهُ فَهُوَ وَلَدُ زِنْيَةٍ مِنْ حُرَّةٍ كَانَ أَوْ أَمَةٍ ‏.‏\hadithno{2265}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr b. Shu'aib on his father's authority said that his grandfather reported:The Prophet (ﷺ) decided regarding one who was treated as a member of a family after the death of his father, to whom he was attributed when the heirs said he was one of them, that if he was the child of a slave-woman whom the father owned when he had intercourse with her, he was included among those who sought his inclusion, but received none of the inheritance which was previously divided; he, however, received his portion of the inheritance which had not already been divided; but if the father to whom he was attributed had disowned him, he was not joined to the heirs. If he was a child of a slave-woman whom the father did not possess or of a free woman with whom he had illicit intercourse, he was not joined to the heirs and did not inherit even if the one to whom he was attributed is the one who claimed paternity, since he was a child of fornication whether his mother was free or a slave}}
\hadithdefcmd{abudawud}{2266}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا أَبِي، عَنْ مُحَمَّدِ بْنِ رَاشِدٍ، بِإِسْنَادِهِ وَمَعْنَاهُ زَادَ وَهُوَ وَلَدُ زِنًا لأَهْلِ أُمِّهِ مَنْ كَانُوا حُرَّةً أَوْ أَمَةً وَذَلِكَ فِيمَا اسْتُلْحِقَ فِي أَوَّلِ الإِسْلاَمِ فَمَا اقْتُسِمَ مِنْ مَالٍ قَبْلَ الإِسْلاَمِ فَقَدْ مَضَى ‏.‏\hadithno{2266}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Muhammad bin Rashid through a different chain of narrators to the same effect. This version adds “he is the child of fornication for the people of his mother whether she was free or a slave. This attribution of a child to the parents was practiced in the beginning of Islam. The property divided before Islam will not be taken into account}}
\hadithdefcmd{abudawud}{2267}{حَدَّثَنَا مُسَدَّدٌ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، - الْمَعْنَى - وَابْنُ السَّرْحِ قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ مُسَدَّدٌ وَابْنُ السَّرْحِ يَوْمًا مَسْرُورًا وَقَالَ عُثْمَانُ يُعْرَفُ أَسَارِيرُ وَجْهِهِ فَقَالَ ‏ "‏ أَىْ عَائِشَةُ أَلَمْ تَرَىْ أَنَّ مُجَزِّزًا الْمُدْلِجِيَّ رَأَى زَيْدًا وَأُسَامَةَ قَدْ غَطَّيَا رُءُوسَهُمَا بِقَطِيفَةٍ وَبَدَتْ أَقْدَامُهُمَا فَقَالَ إِنَّ هَذِهِ الأَقْدَامَ بَعْضُهَا مِنْ بَعْضٍ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ كَانَ أُسَامَةُ أَسْوَدَ وَكَانَ زَيْدٌ أَبْيَضَ ‏.‏\hadithno{2267}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6771) Sahih Muslim (1459)}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) entered upon me. The version of Musaddad and Ibn as-Sarh has: one day looking pleased". The version of Uthman has: "The lines of his forehead were realised." He said: O Aisha, are you not surprised to hear that Mujazziz al-Mudlaji saw that Zayd and Usamah had a rug over them concerning their heads and letting their feet appear. He said: These feet are related. Abu Dawud: Usamah was black and Zaid was white}}
\hadithdefcmd{abudawud}{2268}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، بِإِسْنَادِهِ وَمَعْنَاهُ قَالَ قَالَتْ دَخَلَ عَلَىَّ مَسْرُورًا تَبْرُقُ أَسَارِيرُ وَجْهِهِ ‏.‏ قَالَ أَبُو دَاوُدَ وَأَسَارِيرُ وَجْهِهِ ‏.‏ لَمْ يَحْفَظْهُ ابْنُ عُيَيْنَةَ ‏.‏ قَالَ أَبُو دَاوُدَ أَسَارِيرُ وَجْهِهِ هُوَ تَدْلِيسٌ مِنِ ابْنِ عُيَيْنَةَ لَمْ يَسْمَعْهُ مِنَ الزُّهْرِيِّ إِنَّمَا سَمِعَ الأَسَارِيرَ مِنْ غَيْرِ الزُّهْرِيِّ ‏.‏ قَالَ وَالأَسَارِيرُ مِنْ حَدِيثِ اللَّيْثِ وَغَيْرِهِ ‏.‏ قَالَ أَبُو دَاوُدَ وَسَمِعْتُ أَحْمَدَ بْنَ صَالِحٍ يَقُولُ كَانَ أُسَامَةُ أَسْوَدَ شَدِيدَ السَّوَادِ مِثْلَ الْقَارِ وَكَانَ زَيْدٌ أَبْيَضَ مِثْلَ الْقُطْنِ ‏.‏\hadithno{2268}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6771) Sahih Muslim (1459)}\hadithtrans{The tradition mentioned above has also been transmitted by ibn Shihab through a different chain of narrators to the same effect. This version adds “She said “he entered upon me looking pleased with the lines of his face brightened. Abu Dawud said “Ibn ‘Uyainah did not remember the words “the lines of his face”.” Abu Dawud said “The words “the lines of his face” have been narrated by Ibn ‘Uyainah himself. He did not hear Al Zuhri say (these words). He heard some person other than Al Zuhri say these words. The words “the lines of his face” occur in the tradition narrated by Al Laith and others. Abu Dawud said “ I heard Ahmad bin Salih say “Usamah was very black like tar and Zaid was white like cotton.”}}
\hadithdefcmd{abudawud}{2269}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ الأَجْلَحِ، عَنِ الشَّعْبِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الْخَلِيلِ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ كُنْتُ جَالِسًا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَجَاءَ رَجُلٌ مِنَ الْيَمَنِ فَقَالَ إِنَّ ثَلاَثَةَ نَفَرٍ مِنْ أَهْلِ الْيَمَنِ أَتَوْا عَلِيًّا يَخْتَصِمُونَ إِلَيْهِ فِي وَلَدٍ وَقَدْ وَقَعُوا عَلَى امْرَأَةٍ فِي طُهْرٍ وَاحِدٍ فَقَالَ لاِثْنَيْنِ مِنْهُمَا طِيبَا بِالْوَلَدِ لِهَذَا ‏.‏ فَغَلَيَا ثُمَّ قَالَ لاِثْنَيْنِ طِيبَا بِالْوَلَدِ لِهَذَا ‏.‏ فَغَلَبَا ثُمَّ قَالَ لاِثْنَيْنِ طِيبَا بِالْوَلَدِ لِهَذَا ‏.‏ فَغَلَبَا فَقَالَ أَنْتُمْ شُرَكَاءُ مُتَشَاكِسُونَ إِنِّي مُقْرِعٌ بَيْنَكُمْ فَمَنْ قُرِعَ فَلَهُ الْوَلَدُ وَعَلَيْهِ لِصَاحِبَيْهِ ثُلُثَا الدِّيَةِ ‏.‏ فَأَقْرَعَ بَيْنَهُمْ فَجَعَلَهُ لِمَنْ قُرِعَ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى بَدَتْ أَضْرَاسُهُ أَوْ نَوَاجِذُهُ ‏.‏\hadithno{2269}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Zayd ibn Arqam: I was sitting with the Prophet (ﷺ). A man came from the Yemen, and said: Three men from the people of the Yemen came to Ali, quarrelling about a child, asking him to give a decision. They had had sexual intercourse with a woman during a single state of purity. He said to two of them: Give this child to this man (the third person) with pleasure. But they (refused and) cried loudly. Again he said to two of them: Give the child to the man (the third person) willingly. But they (refused and) cried loudly. He then said: You are quarrelsome partners. I shall cast lots among you; he who receives the lot, will acquire the child, and he shall pay two-thirds of the blood-money to both his companions. He then cast lots among them, and gave the child to the one who received the lot. The Messenger of Allah (ﷺ) laughed so much that his canine or molar teeth appeared}}
\hadithdefcmd{abudawud}{2270}{حَدَّثَنَا خُشَيْشُ بْنُ أَصْرَمَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا الثَّوْرِيُّ، عَنْ صَالِحٍ الْهَمْدَانِيِّ، عَنِ الشَّعْبِيِّ، عَنْ عَبْدِ خَيْرٍ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ أُتِيَ عَلِيٌّ - رضى الله عنه - بِثَلاَثَةٍ وَهُوَ بِالْيَمَنِ وَقَعُوا عَلَى امْرَأَةٍ فِي طُهْرٍ وَاحِدٍ فَسَأَلَ اثْنَيْنِ أَتُقِرَّانِ لِهَذَا بِالْوَلَدِ قَالاَ لاَ ‏.‏ حَتَّى سَأَلَهُمْ جَمِيعًا فَجَعَلَ كُلَّمَا سَأَلَ اثْنَيْنِ قَالاَ لاَ ‏.‏ فَأَقْرَعَ بَيْنَهُمْ فَأَلْحَقَ الْوَلَدَ بِالَّذِي صَارَتْ عَلَيْهِ الْقُرْعَةُ وَجَعَلَ عَلَيْهِ ثُلُثَىِ الدِّيَةِ قَالَ فَذُكِرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَضَحِكَ حَتَّى بَدَتْ نَوَاجِذُهُ ‏.‏\hadithno{2270}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Zayd ibn Arqam: Three persons were brought to Ali (Allah be pleased with him) when he was in the Yemen. They and sexual intercourse with a woman during a single state of purity. He asked two of them: Do you acknowledge this child for this (man)? They replied: No. He then put this (question) to all of them. Whenever he asked two of them, they replied in the negative. He, therefore, cast a lot among them, and attributed the child to the one who received the lot. He imposed two-third of the blood-money (i.e. the price of the mother) on him. This was then mentioned to the Prophet (ﷺ) and he laughed so much that his molar teeth appeared}}
\hadithdefcmd{abudawud}{2271}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ، سَمِعَ الشَّعْبِيَّ، عَنِ الْخَلِيلِ، أَوِ ابْنِ الْخَلِيلِ قَالَ أُتِيَ عَلِيُّ بْنُ أَبِي طَالِبٍ - رضى الله عنه - فِي امْرَأَةٍ وَلَدَتْ مِنْ ثَلاَثٍ نَحْوَهُ لَمْ يَذْكُرِ الْيَمَنَ وَلاَ النَّبِيَّ صلى الله عليه وسلم وَلاَ قَوْلَهُ طِيبَا بِالْوَلَدِ ‏.‏\hadithno{2271}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Khalil or Ibn Khalil said “A woman was brought to Ali bin Abi Talib(may Allaah be pleased with him). She bore a child from intercourse of three persons. The narrator transmitted the rest of the tradition similar to the previous one. But in this version he did not mention “Yemen” and the Prophet (ﷺ) and his words “give the child willingly.”}}
\hadithdefcmd{abudawud}{2272}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ بْنُ خَالِدٍ، حَدَّثَنِي يُونُسُ بْنُ يَزِيدَ، قَالَ قَالَ مُحَمَّدُ بْنُ مُسْلِمِ بْنِ شِهَابٍ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، - رضى الله عنها - زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ النِّكَاحَ كَانَ فِي الْجَاهِلِيَّةِ عَلَى أَرْبَعَةِ أَنْحَاءٍ فَنِكَاحٌ مِنْهَا نِكَاحُ النَّاسِ الْيَوْمَ يَخْطُبُ الرَّجُلُ إِلَى الرَّجُلِ وَلِيَّتَهُ فَيُصْدِقُهَا ثُمَّ يَنْكِحُهَا وَنِكَاحٌ آخَرُ كَانَ الرَّجُلُ يَقُولُ لاِمْرَأَتِهِ إِذَا طَهُرَتْ مِنْ طَمْثِهَا أَرْسِلِي إِلَى فُلاَنٍ فَاسْتَبْضِعِي مِنْهُ وَيَعْتَزِلُهَا زَوْجُهَا وَلاَ يَمَسُّهَا أَبَدًا حَتَّى يَتَبَيَّنَ حَمْلُهَا مِنْ ذَلِكَ الرَّجُلِ الَّذِي تَسْتَبْضِعُ مِنْهُ فَإِذَا تَبَيَّنَ حَمْلُهَا أَصَابَهَا زَوْجُهَا إِنْ أَحَبَّ وَإِنَّمَا يَفْعَلُ ذَلِكَ رَغْبَةً فِي نَجَابَةِ الْوَلَدِ فَكَانَ هَذَا النِّكَاحُ يُسَمَّى نِكَاحَ الاِسْتِبْضَاعِ وَنِكَاحٌ آخَرُ يَجْتَمِعُ الرَّهْطُ دُونَ الْعَشَرَةِ فَيَدْخُلُونَ عَلَى الْمَرْأَةِ كُلُّهُمْ يُصِيبُهَا فَإِذَا حَمَلَتْ وَوَضَعَتْ وَمَرَّ لَيَالٍ بَعْدَ أَنْ تَضَعَ حَمْلَهَا أَرْسَلَتْ إِلَيْهِمْ فَلَمْ يَسْتَطِعْ رَجُلٌ مِنْهُمْ أَنْ يَمْتَنِعَ حَتَّى يَجْتَمِعُوا عِنْدَهَا فَتَقُولُ لَهُمْ قَدْ عَرَفْتُمُ الَّذِي كَانَ مِنْ أَمْرِكُمْ وَقَدْ وَلَدْتُ وَهُوَ ابْنُكَ يَا فُلاَنُ فَتُسَمِّي مَنْ أَحَبَّتْ مِنْهُمْ بِاسْمِهِ فَيُلْحَقُ بِهِ وَلَدُهَا وَنِكَاحٌ رَابِعٌ يَجْتَمِعُ النَّاسُ الْكَثِيرُ فَيَدْخُلُونَ عَلَى الْمَرْأَةِ لاَ تَمْتَنِعُ مِمَّنْ جَاءَهَا وَهُنَّ الْبَغَايَا كُنَّ يَنْصِبْنَ عَلَى أَبْوَابِهِنَّ رَايَاتٍ يَكُنَّ عَلَمًا لِمَنْ أَرَادَهُنَّ دَخَلَ عَلَيْهِنَّ فَإِذَا حَمَلَتْ فَوَضَعَتْ حَمْلَهَا جُمِعُوا لَهَا وَدَعَوْا لَهُمُ الْقَافَةَ ثُمَّ أَلْحَقُوا وَلَدَهَا بِالَّذِي يَرَوْنَ فَالْتَاطَهُ وَدُعِيَ ابْنَهُ لاَ يَمْتَنِعُ مِنْ ذَلِكَ فَلَمَّا بَعَثَ اللَّهُ مُحَمَّدًا صلى الله عليه وسلم هَدَمَ نِكَاحَ أَهْلِ الْجَاهِلِيَّةِ كُلَّهُ إِلاَّ نِكَاحَ أَهْلِ الإِسْلاَمِ الْيَوْمَ ‏.‏\hadithno{2272}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5127)}\hadithtrans{A’ishah wife of the Prophet (ﷺ) said “Marriage in pre Islamic times was of four kinds.” One of them was the marriage contracted by the people today. A man asked another man to marry his relative (sister or daughter) to him. He fixed the dower and married her to him. Another kind of marriage was that a man asked his wife when she became pure from menstruation to send fro so and so and have sexual intercourse with him. Her husband kept himself aloof and did not have intercourse with her till It became apparent that she was pregnant from the man who had intercourse with her. When it was manifest that she was pregnant, her husband approached her if he liked. This marriage was called istibda’(to utilize man for intercourse for a noble birth). A third kind of marriage was that a group of people less than ten in number entered upon a woman and had intercourse with her. When she conceived gave birth to a child and a number of days passed after her delivery, she sent for them. No one of them could refuse to attend and they gathered before her. She said to them “You have realized your affair. I have now given birth to a child. And this is your son. O so and so. She called the name of anyone of them she liked and the child was attributed to him. A fourth kind of marriage was that many people gathered together and entered upon a woman who did not prevent anyone who came to her. They were prostitutes. They hoisted flags at their doors which served as a sign for the one who intended to enter upon them. When she became pregnant and delivered the child , they got together before her and called for the experts of tracing relationship from physical features. They attributed the child to whom they considered and it was given to him. The child was called his son and he could not deny. When Allah sent Muhammad (ﷺ) as a Prophet, he abolished all kinds of marriages prevalent among the people of the pre Islamic times except of the Muslims practiced today}}
\hadithdefcmd{abudawud}{2273}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، اخْتَصَمَ سَعْدُ بْنُ أَبِي وَقَّاصٍ وَعَبْدُ بْنُ زَمْعَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ابْنِ أَمَةِ زَمْعَةَ فَقَالَ سَعْدٌ أَوْصَانِي أَخِي عُتْبَةُ إِذَا قَدِمْتُ مَكَّةَ أَنْ أَنْظُرَ إِلَى ابْنِ أَمَةِ زَمْعَةَ فَأَقْبِضَهُ فَإِنَّهُ ابْنُهُ ‏.‏ وَقَالَ عَبْدُ بْنُ زَمْعَةَ أَخِي ابْنُ أَمَةِ أَبِي وُلِدَ عَلَى فِرَاشِ أَبِي ‏.‏ فَرَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم شَبَهًا بَيِّنًا بِعُتْبَةَ فَقَالَ ‏"‏ الْوَلَدُ لِلْفِرَاشِ وَلِلْعَاهِرِ الْحَجَرُ وَاحْتَجِبِي عَنْهُ يَا سَوْدَةُ ‏"‏ ‏.‏ زَادَ مُسَدَّدٌ فِي حَدِيثِهِ وَقَالَ ‏"‏ هُوَ أَخُوكَ يَا عَبْدُ ‏"‏ ‏.‏ ‏.‏\hadithno{2273}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2421) Sahih Muslim (1457)}\hadithtrans{A’ishah said “Sa’d bin Abi Waqqas and ‘Abd bin Zamah disputed amongst themselves about the (relationship of the) son of the slave girl of Zam’ah and brought the case to the Apostle of Allaah(ﷺ). Sa’d said “My brother ‘Utbah enjoined me that when I came to Makkah I should see the son of the slave girl of Zam’ah and take his possession for that is his son”. ‘Abd bin Zam’ah said “He is my brother, the son of my father’s slave girl having been born on my father’s bed”. The Apostle of Allaah(ﷺ) saw his clear resemblance to ‘Utbah. So he said “The child is attributed to the one on whose bed it is born and the fornicator is deprived of any right (lit. the fornicator will have the stone). Veil yourself from him, Saudah. Musaddad added in his version “he is your brother ‘Abd”}}
\hadithdefcmd{abudawud}{2274}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ فُلاَنًا ابْنِي عَاهَرْتُ بِأُمِّهِ فِي الْجَاهِلِيَّةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ دِعْوَةَ فِي الإِسْلاَمِ ذَهَبَ أَمْرُ الْجَاهِلِيَّةِ الْوَلَدُ لِلْفِرَاشِ وَلِلْعَاهِرِ الْحَجَرُ ‏"‏ ‏.‏\hadithno{2274}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr b. Shu'aib on his father's authority said that his grandfather reported:A man got up and said: Messenger of Allah, so-and-so is my son; I had illicit intercourse with his mother in the pre-Islamic period. The Messenger of Allah (ﷺ) said: There is no unlawful claiming of paternity in Islam. What was done in pre-Islamic times has been annulled. The child is attributed to the one on whose bed it is born, and the fornicator is deprived of any right}}
\hadithdefcmd{abudawud}{2275}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ أَبُو يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي يَعْقُوبَ، عَنِ الْحَسَنِ بْنِ سَعْدٍ، مَوْلَى الْحَسَنِ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ - رضى الله عنه - عَنْ رَبَاحٍ، قَالَ زَوَّجَنِي أَهْلِي أَمَةً لَهُمْ رُومِيَّةً فَوَقَعْتُ عَلَيْهَا فَوَلَدَتْ غُلاَمًا أَسْوَدَ مِثْلِي فَسَمَّيْتُهُ عَبْدَ اللَّهِ ثُمَّ وَقَعْتُ عَلَيْهَا فَوَلَدَتْ غُلاَمًا أَسْوَدَ مِثْلِي فَسَمَّيْتُهُ عُبَيْدَ اللَّهِ ثُمَّ طَبَنَ لَهَا غُلاَمٌ لأَهْلِي رُومِيٌّ يُقَالُ لَهُ يُوحَنَّهْ فَرَاطَنَهَا بِلِسَانِهِ فَوَلَدَتْ غُلاَمًا كَأَنَّهُ وَزَغَةٌ مِنَ الْوَزَغَاتِ فَقُلْتُ لَهَا مَا هَذَا فَقَالَتْ هَذَا لِيُوحَنَّهْ ‏.‏ فَرَفَعْنَا إِلَى عُثْمَانَ أَحْسِبُهُ قَالَ مَهْدِيٌّ قَالَ فَسَأَلَهُمَا فَاعْتَرَفَا فَقَالَ لَهُمَا أَتَرْضَيَانِ أَنْ أَقْضِيَ بَيْنَكُمَا بِقَضَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى أَنَّ الْوَلَدَ لِلْفِرَاشِ ‏.‏ وَأَحْسِبُهُ قَالَ فَجَلَدَهَا وَجَلَدَهُ وَكَانَا مَمْلُوكَيْنِ ‏.‏\hadithno{2275}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Rabah said:My people married me to a Roman slave-girl of theirs. I had intercourse with her, and she gave birth to a black (male) child like me. I named it Abdullah. I again had intercourse with her, and she gave birth to a black (male) child like me. I named it Ubaydullah. Then a Roman slave of my people, called Yuhannah, incited her, and spoke to her in his own unintelligible language. She gave birth to a son like a chameleon (red). I asked her: What is this? She replied: This belongs to Yuhannah. We then brought the case to Uthman (for a decision). I think Mahdi said these words. He inquired from both of them, and they acknowledged (the facts). He then said to them: Do you agree that I take the decision about you, which the Messenger of Allah (ﷺ) had taken? The Messenger of Allah (ﷺ) decided that the child was to attributed to the one on whose bed it was born. And I think he said: He flogged her and flogged him, for they were slaves}}
\hadithdefcmd{abudawud}{2276}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ السُّلَمِيُّ، حَدَّثَنَا الْوَلِيدُ، عَنْ أَبِي عَمْرٍو، - يَعْنِي الأَوْزَاعِيَّ - حَدَّثَنِي عَمْرُو بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ امْرَأَةً، قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنِي هَذَا كَانَ بَطْنِي لَهُ وِعَاءً وَثَدْيِي لَهُ سِقَاءً وَحِجْرِي لَهُ حِوَاءً وَإِنَّ أَبَاهُ طَلَّقَنِي وَأَرَادَ أَنْ يَنْتَزِعَهُ مِنِّي فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنْتِ أَحَقُّ بِهِ مَا لَمْ تَنْكِحِي ‏"‏ ‏.‏ ‏.‏\hadithno{2276}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Amr b. Shu'aib on his father's authority said that his grandfather (Abdullah ibn Amr ibn al-'As) reported:A woman said: Messenger of Allah, my womb is a vessel to this son of mine, my breasts, a water-skin for him, and my lap a guard for him, yet his father has divorced me, and wants to take him away from me. The Messenger of Allah (ﷺ) said: You have more right to him as long as you do not marry}}
\hadithdefcmd{abudawud}{2277}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، وَأَبُو عَاصِمٍ عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي زِيَادٌ، عَنْ هِلاَلِ بْنِ أُسَامَةَ، أَنَّ أَبَا مَيْمُونَةَ، سَلْمَى - مَوْلًى مِنْ أَهْلِ الْمَدِينَةِ رَجُلَ صِدْقٍ - قَالَ بَيْنَمَا أَنَا جَالِسٌ مَعَ أَبِي هُرَيْرَةَ جَاءَتْهُ امْرَأَةٌ فَارِسِيَّةٌ مَعَهَا ابْنٌ لَهَا فَادَّعَيَاهُ وَقَدْ طَلَّقَهَا زَوْجُهَا فَقَالَتْ يَا أَبَا هُرَيْرَةَ - وَرَطَنَتْ لَهُ بِالْفَارِسِيَّةِ - زَوْجِي يُرِيدُ أَنْ يَذْهَبَ بِابْنِي فَقَالَ أَبُو هُرَيْرَةَ اسْتَهِمَا عَلَيْهِ وَرَطَنَ لَهَا بِذَلِكَ فَجَاءَ زَوْجُهَا فَقَالَ مَنْ يُحَاقُّنِي فِي وَلَدِي فَقَالَ أَبُو هُرَيْرَةَ اللَّهُمَّ إِنِّي لاَ أَقُولُ هَذَا إِلاَّ أَنِّي سَمِعْتُ امْرَأَةً جَاءَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا قَاعِدٌ عِنْدَهُ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ زَوْجِي يُرِيدُ أَنْ يَذْهَبَ بِابْنِي وَقَدْ سَقَانِي مِنْ بِئْرِ أَبِي عِنَبَةَ وَقَدْ نَفَعَنِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اسْتَهِمَا عَلَيْهِ ‏"‏ ‏.‏ فَقَالَ زَوْجُهَا مَنْ يُحَاقُّنِي فِي وَلَدِي فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَذَا أَبُوكَ وَهَذِهِ أُمُّكَ فَخُذْ بِيَدِ أَيِّهِمَا شِئْتَ ‏"‏ ‏.‏ فَأَخَذَ بِيَدِ أُمِّهِ فَانْطَلَقَتْ بِهِ ‏.‏\hadithno{2277}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Hilal ibn Usamah quoted Abu Maimunah Salma, client of the people of Medina, as saying:While I was sitting with AbuHurayrah, a Persian woman came to him along with a son of hers. She had been divorced by her husband and they both claimed him. She said: AbuHurayrah, speaking to him in Persian, my husband wishes to take my son away. AbuHurayrah said: Cast lots for him, saying it to her in a foreign language. Then her husband came and asked: Who is disputing with me about my son? AbuHurayrah said: O Allah, I do not say this, except that I heard a woman who came to the Messenger of Allah (ﷺ) while I was sitting with him, and she said: My husband wishes to take away my son, Messenger of Allah, and he draws water for me from the well of AbuInabah, and he has been good to me. The Messenger of Allah (ﷺ) said: Cast lots for him. Her husband said: Who is disputing with me about my son? The Prophet (ﷺ) said: This is your father and this your mother, so take whichever of them you wish by the hand. So he took his mother's hand and she went away with him}}
\hadithdefcmd{abudawud}{2278}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ عَمْرٍو، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ يَزِيدَ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ نَافِعِ بْنِ عُجَيْرٍ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، - رضى الله عنه - قَالَ خَرَجَ زَيْدُ بْنُ حَارِثَةَ إِلَى مَكَّةَ فَقَدِمَ بِابْنَةِ حَمْزَةَ فَقَالَ جَعْفَرٌ أَنَا آخُذُهَا أَنَا أَحَقُّ بِهَا ابْنَةُ عَمِّي وَعِنْدِي خَالَتُهَا وَإِنَّمَا الْخَالَةُ أُمٌّ ‏.‏ فَقَالَ عَلِيٌّ أَنَا أَحَقُّ بِهَا ابْنَةُ عَمِّي وَعِنْدِي ابْنَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهِيَ أَحَقُّ بِهَا ‏.‏ فَقَالَ زَيْدٌ أَنَا أَحَقُّ بِهَا أَنَا خَرَجْتُ إِلَيْهَا وَسَافَرْتُ وَقَدِمْتُ بِهَا ‏.‏ فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم فَذَكَرَ حَدِيثًا قَالَ ‏ "‏ وَأَمَّا الْجَارِيَةُ فَأَقْضِي بِهَا لِجَعْفَرٍ تَكُونُ مَعَ خَالَتِهَا وَإِنَّمَا الْخَالَةُ أُمٌّ ‏"‏ ‏.‏ ‏.‏\hadithno{2278}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ali ibn AbuTalib: Zayd ibn Harithah went out to Mecca and brought the daughter of Hamzah with him. Then Ja'far said: I shall take her; I have more right to her; she is my uncle's daughter and her maternal aunt is my wife; the maternal aunt is like mother. Ali said: I am more entitled to take her. She is my uncle's daughter. The daughter of the Messenger of Allah (ﷺ) is my wife, and she has more right to her. Zayd said: I have more right to her. I went out and journeyed to her, and brought her with me. The Prophet (ﷺ) came out. The narrator mentioned the rest of the tradition. He (i.e. the Prophet) said: As for the girl, I decided in favour of Ja'far. She will live with her maternal aunt. The maternal aunt is like mother}}
\hadithdefcmd{abudawud}{2279}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي فَرْوَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، بِهَذَا الْخَبَرِ وَلَيْسَ بِتَمَامِهِ قَالَ وَقَضَى بِهَا لِجَعْفَرٍ وَقَالَ ‏ "‏ إِنَّ خَالَتَهَا عِنْدَهُ ‏"‏ ‏.‏\hadithno{2279}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{This tradition has been narrated by ‘Abd Al Rahman bin Abi Laila through a different chain of narrators. This version has “He decided that she would be given to Ja’far and said “Her maternal aunt is with him(i.e., his wife)}}
\hadithdefcmd{abudawud}{2280}{حَدَّثَنَا عَبَّادُ بْنُ مُوسَى، أَنَّ إِسْمَاعِيلَ بْنَ جَعْفَرٍ، حَدَّثَهُمْ عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ هَانِئٍ، وَهُبَيْرَةَ، عَنْ عَلِيٍّ، قَالَ لَمَّا خَرَجْنَا مِنْ مَكَّةَ تَبِعَتْنَا بِنْتُ حَمْزَةَ تُنَادِي يَا عَمِّ يَا عَمِّ ‏.‏ فَتَنَاوَلَهَا عَلِيٌّ فَأَخَذَ بِيَدِهَا وَقَالَ دُونَكِ بِنْتَ عَمِّكِ ‏.‏ فَحَمَلَتْهَا فَقَصَّ الْخَبَرَ قَالَ وَقَالَ جَعْفَرٌ ابْنَةُ عَمِّي وَخَالَتُهَا تَحْتِي ‏.‏ فَقَضَى بِهَا النَّبِيُّ صلى الله عليه وسلم لِخَالَتِهَا وَقَالَ ‏ "‏ الْخَالَةُ بِمَنْزِلَةِ الأُمِّ ‏"‏ ‏.‏\hadithno{2280}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: When we came out from Mecca, Hamzah's daughter pursued us crying: My uncle. Ali lifted her and took her by the hand. (Addressing Fatimah he said:) Take your uncle's daughter. She then lifted her. The narrator then transmitted the rest of the tradition. Ja'far said: She is my uncle's daughter. Her maternal aunt is my wife. The Prophet (ﷺ) decided in favour of her maternal aunt, and said: The maternal aunt is like mother}}
\hadithdefcmd{abudawud}{2281}{حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الْحَمِيدِ الْبَهْرَانِيُّ، حَدَّثَنِي يَحْيَى بْنُ صَالِحٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنِي عَمْرُو بْنُ مُهَاجِرٍ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ بْنِ السَّكَنِ الأَنْصَارِيَّةِ، أَنَّهَا طُلِّقَتْ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَمْ يَكُنْ لِلْمُطَلَّقَةِ عِدَّةٌ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ حِينَ طُلِّقَتْ أَسْمَاءُ بِالْعِدَّةِ لِلطَّلاَقِ فَكَانَتْ أَوَّلَ مَنْ أُنْزِلَتْ فِيهَا الْعِدَّةُ لِلْمُطَلَّقَاتِ ‏.‏\hadithno{2281}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr ibn Muhajir reported on the authority of his father:Asma', daughter of Yazid ibn as-Sakan al-Ansariyyah, was divorced in the time of the Messenger of Allah (ﷺ). No waiting period was prescribed for a divorced woman (at that time). When Asma' was divorced, Allah, the Exalted, sent down the injunction of waiting period for divorce. She is the first of the divorced women about whom the verse relating to waiting period was sent down}}
\hadithdefcmd{abudawud}{2282}{حَدَّثَنِي أَحْمَدُ بْنُ مُحَمَّدِ بْنِ ثَابِتٍ الْمَرْوَزِيُّ، حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏\{‏ وَالْمُطَلَّقَاتُ يَتَرَبَّصْنَ بِأَنْفُسِهِنَّ ثَلاَثَةَ قُرُوءٍ ‏\}‏ ‏.‏ وَقَالَ ‏\{‏ وَاللاَّئِي يَئِسْنَ مِنَ الْمَحِيضِ مِنْ نِسَائِكُمْ إِنِ ارْتَبْتُمْ فَعِدَّتُهُنَّ ثَلاَثَةُ أَشْهُرٍ ‏\}‏ فَنُسِخَ مِنْ ذَلِكَ وَقَالَ ‏\{‏ وَإِنْ طَلَّقْتُمُوهُنَّ مِنْ قَبْلِ أَنْ تَمَسُّوهُنَّ ‏\}‏ ‏\{‏ فَمَا لَكُمْ عَلَيْهِنَّ مِنْ عِدَّةٍ تَعْتَدُّونَهَا ‏\}‏ ‏.‏\hadithno{2282}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: Women who are divorced shall wait, keeping themselves apart, three monthly courses; and then said: And for such of your women as despair of menstruation, if ye doubt, their period (of waiting) shall be three months. This was abrogated from the former verse. Again he said: (O ye who believe, if ye wed believing women) and divorce them before ye have touched them, then there is no period that ye should reckon}}
\hadithdefcmd{abudawud}{2283}{حَدَّثَنَا سَهْلُ بْنُ مُحَمَّدِ بْنِ الزُّبَيْرِ الْعَسْكَرِيُّ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ صَالِحِ بْنِ صَالِحٍ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم طَلَّقَ حَفْصَةَ ثُمَّ رَاجَعَهَا ‏.‏\hadithno{2283}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Umar ibn al-Khattab: The Prophet (ﷺ) divorced Hafsah, but he took her back in marriage}}
\hadithdefcmd{abudawud}{2284}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، مَوْلَى الأَسْوَدِ بْنِ سُفْيَانَ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، أَنَّ أَبَا عَمْرِو بْنَ حَفْصٍ، طَلَّقَهَا الْبَتَّةَ وَهُوَ غَائِبٌ فَأَرْسَلَ إِلَيْهَا وَكِيلَهُ بِشَعِيرٍ فَتَسَخَّطَتْهُ فَقَالَ وَاللَّهِ مَا لَكِ عَلَيْنَا مِنْ شَىْءٍ ‏.‏ فَجَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَتْ ذَلِكَ لَهُ فَقَالَ لَهَا ‏"‏ لَيْسَ لَكِ عَلَيْهِ نَفَقَةٌ ‏"‏ ‏.‏ وَأَمَرَهَا أَنْ تَعْتَدَّ فِي بَيْتِ أُمِّ شَرِيكٍ ثُمَّ قَالَ ‏"‏ إِنَّ تِلْكَ امْرَأَةٌ يَغْشَاهَا أَصْحَابِي اعْتَدِّي فِي بَيْتِ ابْنِ أُمِّ مَكْتُومٍ فَإِنَّهُ رَجُلٌ أَعْمَى تَضَعِينَ ثِيَابَكِ وَإِذَا حَلَلْتِ فَآذِنِينِي ‏"‏ ‏.‏ قَالَتْ فَلَمَّا حَلَلْتُ ذَكَرْتُ لَهُ أَنَّ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ وَأَبَا جَهْمٍ خَطَبَانِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَّا أَبُو جَهْمٍ فَلاَ يَضَعُ عَصَاهُ عَنْ عَاتِقِهِ وَأَمَّا مُعَاوِيَةُ فَصُعْلُوكٌ لاَ مَالَ لَهُ انْكِحِي أُسَامَةَ بْنَ زَيْدٍ ‏"‏ ‏.‏ قَالَتْ فَكَرِهْتُهُ ثُمَّ قَالَ ‏"‏ انْكِحِي أُسَامَةَ بْنَ زَيْدٍ ‏.‏ فَنَكَحْتُهُ فَجَعَلَ اللَّهُ تَعَالَى فِيهِ خَيْرًا كَثِيرًا وَاغْتَبَطْتُ بِهِ ‏.‏\hadithno{2284}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1480)}\hadithtrans{Abu Salamah bin ‘Abd Al Rahman reported on the authority of Fatimah daughter of Qais Abu ‘Amr bin Hafs divorced her (Fatimah daughter of Qais) absolutely when he was away from home and his agent sent her home barley. She was displeased with it. He said “I swear by Allah, you have no claim on us. She then came to Apostle of Allah (ﷺ) and mentioned that to him. He said to her “No maintenance is due to you from him. He ordered her to spend the waiting period in the house of Umm Sharik but he said afterwards “that is a woman whom my Companions visit. Spend the waiting period in the house of Ibn Umm Maktum for he is blind and you can undress. Then when you are in a position of being remarried, tell me.” She said “When I was in a position to remarry, I mentioned to him that Mu’awiyah bin Abi Sufyan and Abu Jahm had asked me in marriage. The Apostle of Allah (ﷺ)said “As for Abu Jahm, he does not put down his stick from his shoulder, and as for Mu’awiyah he is a poor man who has no property; marry Usamah bin Zaid. I disliked him but he said “Marry Usamah bin Zaid. So, I married him. And Allah prospered him very much and I was envied.”}}
\hadithdefcmd{abudawud}{2285}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ بْنُ يَزِيدَ الْعَطَّارُ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ فَاطِمَةَ بِنْتَ قَيْسٍ، حَدَّثَتْهُ أَنَّ أَبَا حَفْصِ بْنَ الْمُغِيرَةِ طَلَّقَهَا ثَلاَثًا وَسَاقَ الْحَدِيثَ فِيهِ وَأَنَّ خَالِدَ بْنَ الْوَلِيدِ وَنَفَرًا مِنْ بَنِي مَخْزُومٍ أَتَوُا النَّبِيَّ صلى الله عليه وسلم فَقَالُوا يَا نَبِيَّ اللَّهِ إِنَّ أَبَا حَفْصِ بْنَ الْمُغِيرَةِ طَلَّقَ امْرَأَتَهُ ثَلاَثًا وَإِنَّهُ تَرَكَ لَهَا نَفَقَةً يَسِيرَةً فَقَالَ ‏ "‏ لاَ نَفَقَةَ لَهَا ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ وَحَدِيثُ مَالِكٍ أَتَمُّ ‏.‏\hadithno{2285}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Salamah bin ‘Abd Al Rahman said that Fatimah daughter of Qais told him that Abu Hafs Al Mughirah divorced her three times. He then narrated the rest of the tradition. The version has Khalid bin Walid and some people of Banu Makhzum came to the Prophet (ﷺ) and said Prophet of Allaah (ﷺ) Abu Hafs Al Mughirah divorced his wife three times and he has left a little for her. He said “No maintenance is necessary for her. He then transmitted the rest of the tradition. The tradition narrated by Malik is more perfect}}
\hadithdefcmd{abudawud}{2286}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا أَبُو عَمْرٍو، عَنْ يَحْيَى، حَدَّثَنِي أَبُو سَلَمَةَ، حَدَّثَتْنِي فَاطِمَةُ بِنْتُ قَيْسٍ، أَنَّ أَبَا عَمْرِو بْنَ حَفْصٍ الْمَخْزُومِيَّ، طَلَّقَهَا ثَلاَثًا وَسَاقَ الْحَدِيثَ وَخَبَرَ خَالِدِ بْنِ الْوَلِيدِ قَالَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَيْسَتْ لَهَا نَفَقَةٌ وَلاَ مَسْكَنٌ ‏"‏ ‏.‏ قَالَ فِيهِ وَأَرْسَلَ إِلَيْهَا النَّبِيُّ صلى الله عليه وسلم أَنْ لاَ تَسْبِقِينِي بِنَفْسِكِ ‏.‏\hadithno{2286}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Salamah reported on the authority of Fatimah daughter of Qais that Abu ‘Amr bin Hafs Al Makhzumi divorced her three times. He then narrated the rest of the tradition. He then mentioned about Khalid bin Walid and said that the Prophet (ﷺ) said “There are no maintenance and dwelling for her.” This version has “The Apostle of Allaah(ﷺ) sent a message to her “Do not give her consent for marriage without my permission.””}}
\hadithdefcmd{abudawud}{2287}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، أَنَّ إِسْمَاعِيلَ بْنَ جَعْفَرٍ، حَدَّثَهُمْ حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، قَالَتْ كُنْتُ عِنْدَ رَجُلٍ مِنْ بَنِي مَخْزُومٍ فَطَلَّقَنِي الْبَتَّةَ ثُمَّ سَاقَ نَحْوَ حَدِيثِ مَالِكٍ قَالَ فِيهِ ‏ "‏ وَلاَ تَفُوتِينِي بِنَفْسِكِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ الشَّعْبِيُّ وَالْبَهِيُّ وَعَطَاءٌ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَاصِمٍ وَأَبُو بَكْرِ بْنُ أَبِي الْجَهْمِ كُلُّهُمْ عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ أَنَّ زَوْجَهَا طَلَّقَهَا ثَلاَثًا ‏.‏\hadithno{2287}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Fatimah daughter of Qais said “I was married to a man of Banu Makhzum. He divorced me absolutely. The narrator then transmitted the rest of the tradition like that of Malik. This version has “Do not marry yourself without my permission.” Abu Dawud said Al Sha’bi, Al Bahiyy and ata from abd Al Rahman bin asim and Abu Bakr bin Abi Al Jahm all narrated on the authority of Fatimah daughter of Qais that her husband had divorced her three times}}
\hadithdefcmd{abudawud}{2288}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا سَلَمَةُ بْنُ كُهَيْلٍ، عَنِ الشَّعْبِيِّ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، أَنَّ زَوْجَهَا، طَلَّقَهَا ثَلاَثًا فَلَمْ يَجْعَلْ لَهَا النَّبِيُّ صلى الله عليه وسلم نَفَقَةً وَلاَ سُكْنَى ‏.‏\hadithno{2288}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1480)}\hadithtrans{The tradition mentioned above has also been transmitted by Al Sha’bi through a different chain of narrators. This version has “The husband of Fathima daughter of Qais pronounced her triple divorce. The Prophet (ﷺ) did not allow her to have maintenance and dwelling.”}}
\hadithdefcmd{abudawud}{2289}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدٍ الرَّمْلِيُّ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، أَنَّهَا أَخْبَرَتْهُ أَنَّهَا، كَانَتْ عِنْدَ أَبِي حَفْصِ بْنِ الْمُغِيرَةِ وَأَنَّ أَبَا حَفْصِ بْنَ الْمُغِيرَةِ طَلَّقَهَا آخِرَ ثَلاَثِ تَطْلِيقَاتٍ فَزَعَمَتْ أَنَّهَا جَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَاسْتَفْتَتْهُ فِي خُرُوجِهَا مِنْ بَيْتِهَا فَأَمَرَهَا أَنْ تَنْتَقِلَ إِلَى ابْنِ أُمِّ مَكْتُومٍ الأَعْمَى فَأَبَى مَرْوَانُ أَنْ يُصَدِّقَ حَدِيثَ فَاطِمَةَ فِي خُرُوجِ الْمُطَلَّقَةِ مِنْ بَيْتِهَا ‏.‏ قَالَ عُرْوَةُ وَأَنْكَرَتْ عَائِشَةُ - رضى الله عنها - عَلَى فَاطِمَةَ بِنْتِ قَيْسٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ صَالِحُ بْنُ كَيْسَانَ وَابْنُ جُرَيْجٍ وَشُعَيْبُ بْنُ أَبِي حَمْزَةَ كُلُّهُمْ عَنِ الزُّهْرِيِّ ‏.‏ قَالَ أَبُو دَاوُدَ وَشُعَيْبُ بْنُ أَبِي حَمْزَةَ وَاسْمُ أَبِي حَمْزَةَ دِينَارٌ وَهُوَ مَوْلَى زِيَادٍ ‏.‏\hadithno{2289}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Salamah reported on the authority of Fatimah daughter of Qays who said to him that she was the wife of AbuHafs ibn al-Mughirah who divorced her by three pronouncements. She said that she came to the Messenger of Allah (ﷺ) and sought his opinion about her going out from her house. He commanded her to shift to (the house of )Ibn Umm Maktum who was blind. Marwan denied to confirm the tradition of Fatimah about the going out of a divorced woman from her house. Urwah said:Aisha objected to Fatimah daughter of Qays. Abu Dawud said: Salih b. Kaisan, Ibn Juraij, and Shu'aib b. Abi Hamzah -- all of them narrated on the authority of al-Zuhru in a similar way. Abu Dawud said: Shu'aibn b. Abi Hamzah the name of Abu Hamzah is Dinar. He is a client of Ziyad}}
\hadithdefcmd{abudawud}{2290}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَرْسَلَ مَرْوَانُ إِلَى فَاطِمَةَ فَسَأَلَهَا فَأَخْبَرَتْهُ أَنَّهَا كَانَتْ عِنْدَ أَبِي حَفْصٍ وَكَانَ النَّبِيُّ صلى الله عليه وسلم أَمَّرَ عَلِيَّ بْنَ أَبِي طَالِبٍ - يَعْنِي عَلَى بَعْضِ الْيَمَنِ - فَخَرَجَ مَعَهُ زَوْجُهَا فَبَعَثَ إِلَيْهَا بِتَطْلِيقَةٍ كَانَتْ بَقِيَتْ لَهَا وَأَمَرَ عَيَّاشَ بْنَ أَبِي رَبِيعَةَ وَالْحَارِثَ بْنَ هِشَامٍ أَنْ يُنْفِقَا عَلَيْهَا فَقَالاَ وَاللَّهِ مَا لَهَا نَفَقَةٌ إِلاَّ أَنْ تَكُونَ حَامِلاً ‏.‏ فَأَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ لاَ نَفَقَةَ لَكِ إِلاَّ أَنْ تَكُونِي حَامِلاً ‏"‏ ‏.‏ وَاسْتَأْذَنَتْهُ فِي الاِنْتِقَالِ فَأَذِنَ لَهَا فَقَالَتْ أَيْنَ أَنْتَقِلُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ عِنْدَ ابْنِ أُمِّ مَكْتُومٍ ‏"‏ ‏.‏ وَكَانَ أَعْمَى تَضَعُ ثِيَابَهَا عِنْدَهُ وَلاَ يُبْصِرُهَا فَلَمْ تَزَلْ هُنَاكَ حَتَّى مَضَتْ عِدَّتُهَا فَأَنْكَحَهَا النَّبِيُّ صلى الله عليه وسلم أُسَامَةَ فَرَجَعَ قَبِيصَةُ إِلَى مَرْوَانَ فَأَخْبَرَهُ بِذَلِكَ فَقَالَ مَرْوَانُ لَمْ نَسْمَعْ هَذَا الْحَدِيثَ إِلاَّ مِنَ امْرَأَةٍ فَسَنَأْخُذُ بِالْعِصْمَةِ الَّتِي وَجَدْنَا النَّاسَ عَلَيْهَا فَقَالَتْ فَاطِمَةُ حِينَ بَلَغَهَا ذَلِكَ بَيْنِي وَبَيْنَكُمْ كِتَابُ اللَّهِ قَالَ اللَّهُ تَعَالَى ‏\{‏ فَطَلِّقُوهُنَّ لِعِدَّتِهِنَّ ‏\}‏ حَتَّى ‏\{‏ لاَ تَدْرِي لَعَلَّ اللَّهَ يُحْدِثُ بَعْدَ ذَلِكَ أَمْرًا ‏\}‏ قَالَتْ فَأَىُّ أَمْرٍ يَحْدُثُ بَعْدَ الثَّلاَثِ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ يُونُسُ عَنِ الزُّهْرِيِّ وَأَمَّا الزُّبَيْدِيُّ فَرَوَى الْحَدِيثَيْنِ جَمِيعًا حَدِيثَ عُبَيْدِ اللَّهِ بِمَعْنَى مَعْمَرٍ وَحَدِيثَ أَبِي سَلَمَةَ بِمَعْنَى عُقَيْلٍ وَرَوَاهُ مُحَمَّدُ بْنُ إِسْحَاقَ عَنِ الزُّهْرِيِّ أَنَّ قَبِيصَةَ بْنَ ذُؤَيْبٍ حَدَّثَهُ بِمَعْنًى دَلَّ عَلَى خَبَرِ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ حِينَ قَالَ فَرَجَعَ قَبِيصَةُ إِلَى مَرْوَانَ فَأَخْبَرَهُ بِذَلِكَ ‏.‏\hadithno{2290}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1480)}\hadithtrans{‘Ubaid Allah said “Marwan sent someone (Qabisah) to Fatimah and asked her (about the case). She said that she was the wife of Abu Hafs. The Prophet (ﷺ) appointed ‘Ali as governor in a certain part of Yemen. Her husband also proceeded with him. From there he sent a message to her pronouncing one divorce that had yet remained. He commanded ‘Ayyash bin Abi Rabi’ah and Al Harith bin Hisham to provide maintenance to her. They said “By Allah there is no sustenance for her except in case she is pregnant.” She came to the Prophet(ﷺ) who said “There is no sustenance for you except in case you are pregnant. She then asked permission to shift (from her house) and he gave her permission.” She asked “Where should I shift. Apostle of Allaah(ﷺ)? The Apostle of Allaah(ﷺ) said to Ibn Umm Maktum . He was blind. She would undress herself and he could not see her. She lived there till her waiting period passed. The Prophet (ﷺ) married her to Usamah. Qabisah then returned to Marwan and narrated that to him. Marwan said “We did not hear this tradition except from a woman, so we shall follow the reliable practice on which we found the people”. When this reached Fatimah she said “between me and you is the Book of Allah”. Allaah the exalted said “Divorce them for their waiting period...” Thou knowest not it may be that Allaah will afterward bring some new thing to pass. She said “What a new thing will emerge after triple divorce.” Abu Dawud said “A similar tradition has been narrated by Yunus on the authority of Al Zuhri. As for Al Zubaidi he narrated both traditions, the tradition of ‘Ubaid Allah in the version of Ma’mar and the tradition of Abu Salamah in the version of ‘Aqil.” Abu Dawud said “Muhammad bin Ishaq narrated on the authority of Al Zuhri that Qabisah bin Dhuwaib transmitted to him the version which was narrated by ‘Ubaid Allah bin ‘Abd Allaah which has Qabisah then returned to Marwan and informed him about that.”}}
\hadithdefcmd{abudawud}{2291}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنِي أَبُو أَحْمَدَ، حَدَّثَنَا عَمَّارُ بْنُ رُزَيْقٍ، عَنْ أَبِي إِسْحَاقَ، قَالَ كُنْتُ فِي الْمَسْجِدِ الْجَامِعِ مَعَ الأَسْوَدِ فَقَالَ أَتَتْ فَاطِمَةُ بِنْتُ قَيْسٍ عُمَرَ بْنَ الْخَطَّابِ - رضى الله عنه - فَقَالَ مَا كُنَّا لِنَدَعَ كِتَابَ رَبِّنَا وَسُنَّةَ نَبِيِّنَا صلى الله عليه وسلم لِقَوْلِ امْرَأَةٍ لاَ نَدْرِي أَحَفِظَتْ ذَلِكَ أَمْ لاَ ‏.‏\hadithno{2291}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Zubair Ali Zai: Sahih Muslim (1480)}\hadithtrans{Abu Ishaq said “I was with Al Aswad in the congregational mosque. He said “Fathimah daughter of Qais came to ‘Umar bin Al Khattab(may Allaah be pleased with him). (When she narrated the tradition about her divorce) he said “We are not to leave the Book of our Lord and the Sunnah of our Prophet (ﷺ) for the statement of a woman, we do not know whether she remembered it or not.”}}
\hadithdefcmd{abudawud}{2292}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، قَالَ لَقَدْ عَابَتْ ذَلِكَ عَائِشَةُ - رضى الله عنها - أَشَدَّ الْعَيْبِ يَعْنِي حَدِيثَ فَاطِمَةَ بِنْتِ قَيْسٍ وَقَالَتْ إِنَّ فَاطِمَةَ كَانَتْ فِي مَكَانٍ وَحْشٍ فَخِيفَ عَلَى نَاحِيَتِهَا فَلِذَلِكَ رَخَّصَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2292}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Urwah said:Aisha (Allah be pleased with her) severely objected to the tradition of Fatimah daughter of Qays. She said: Fatimah lived in a desolate house and she feared for her loneliness there. Hence the Messenger of Allah (ﷺ) accorded permission to her (to leave the place)}}
\hadithdefcmd{abudawud}{2293}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّهُ قِيلَ لِعَائِشَةَ أَلَمْ تَرَىْ إِلَى قَوْلِ فَاطِمَةَ قَالَتْ أَمَا إِنَّهُ لاَ خَيْرَ لَهَا فِي ذِكْرِ ذَلِكَ ‏.‏\hadithno{2293}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5325، 5326) Sahih Muslim (1481)}\hadithtrans{Urwah ibn az-Zubayr said:Aisha was asked: Did you not see (i.e. known) the statement of Fatimah? She replied: It is not good for her to mention it (to others)}}
\hadithdefcmd{abudawud}{2294}{حَدَّثَنَا هَارُونُ بْنُ زَيْدٍ، حَدَّثَنَا أَبِي، عَنْ سُفْيَانَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، فِي خُرُوجِ فَاطِمَةَ قَالَ إِنَّمَا كَانَ ذَلِكَ مِنْ سُوءِ الْخُلُقِ ‏.‏\hadithno{2294}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Sulaimah bin Yasar said about leaving the house by Fathimah “That was due to her bad manners.”}}
\hadithdefcmd{abudawud}{2295}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، وَسُلَيْمَانَ بْنِ يَسَارٍ، أَنَّهُ سَمِعَهُمَا يَذْكُرَانِ، أَنَّ يَحْيَى بْنَ سَعِيدِ بْنِ الْعَاصِ، طَلَّقَ بِنْتَ عَبْدِ الرَّحْمَنِ بْنِ الْحَكَمِ الْبَتَّةَ فَانْتَقَلَهَا عَبْدُ الرَّحْمَنِ فَأَرْسَلَتْ عَائِشَةُ - رضى الله عنها - إِلَى مَرْوَانَ بْنِ الْحَكَمِ وَهُوَ أَمِيرُ الْمَدِينَةِ فَقَالَتْ لَهُ اتَّقِ اللَّهَ وَارْدُدِ الْمَرْأَةَ إِلَى بَيْتِهَا ‏.‏ فَقَالَ مَرْوَانُ فِي حَدِيثِ سُلَيْمَانَ إِنَّ عَبْدَ الرَّحْمَنِ غَلَبَنِي ‏.‏ وَقَالَ مَرْوَانُ فِي حَدِيثِ الْقَاسِمِ أَوَمَا بَلَغَكِ شَأْنُ فَاطِمَةَ بِنْتِ قَيْسٍ فَقَالَتْ عَائِشَةُ لاَ يَضُرُّكَ أَنْ لاَ تَذْكُرَ حَدِيثَ فَاطِمَةَ ‏.‏ فَقَالَ مَرْوَانُ إِنْ كَانَ بِكِ الشَّرُّ فَحَسْبُكِ مَا كَانَ بَيْنَ هَذَيْنِ مِنَ الشَّرِّ ‏.‏\hadithno{2295}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5321، 5322)}\hadithtrans{Al-Qasim ibn Muhammad and Sulayman ibn Yasar reported:Yahya ibn Sa'id ibn al-'As divorced the daughter of 'Abd al-Rahman ibn al-Hakam absolutely. 'Abd al-Rahman shifted her (from there). Aisha sent a message to Marwan ibn al-Hakam who was the governor of Medina, and said to him: Fear Allah, and return the woman to her home. Marwan said (according to Sulayman's version): 'Abd al-Rahman forced me. Marwan said (according to the version of al-Qasim): Did not the case of Fatimah daughter of Qays reach you? Aisha replied: There would be no harm to you if you did not make mention of the tradition of Fatimah. Marwan said: If you think that it was due to some evil (i.e. reason), then it is sufficient for you to see that there is also an evil between the two}}
\hadithdefcmd{abudawud}{2296}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا جَعْفَرُ بْنُ بُرْقَانَ، حَدَّثَنَا مَيْمُونُ بْنُ مِهْرَانَ، قَالَ قَدِمْتُ الْمَدِينَةَ فَدُفِعْتُ إِلَى سَعِيدِ بْنِ الْمُسَيَّبِ فَقُلْتُ فَاطِمَةُ بِنْتُ قَيْسٍ طُلِّقَتْ فَخَرَجَتْ مِنْ بَيْتِهَا فَقَالَ سَعِيدٌ تِلْكَ امْرَأَةٌ فَتَنَتِ النَّاسَ إِنَّهَا كَانَتْ لَسِنَةً فَوُضِعَتْ عَلَى يَدَىِ ابْنِ أُمِّ مَكْتُومٍ الأَعْمَى ‏.‏\hadithno{2296}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Maimun bin Mihram said “I came to Median and went to Sa’id bin Al Musayyab”. I said (to him) Fathimah daughter of Qais was divorced and she shifted from her house. Sa’id said “This woman has perverted people. She was arrogant so she was placed with Ibn Umm Makhtum, the blind.”}}
\hadithdefcmd{abudawud}{2297}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ طُلِّقَتْ خَالَتِي ثَلاَثًا فَخَرَجَتْ تَجُدُّ نَخْلاً لَهَا فَلَقِيَهَا رَجُلٌ فَنَهَاهَا فَأَتَتِ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَتْ ذَلِكَ لَهُ فَقَالَ لَهَا ‏ "‏ اخْرُجِي فَجُدِّي نَخْلَكِ لَعَلَّكِ أَنْ تَصَدَّقِي مِنْهُ أَوْ تَفْعَلِي خَيْرًا ‏"‏ ‏.‏\hadithno{2297}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1483)}\hadithtrans{Jabir said “My maternal aunt was divorced by three pronouncements and she went out to cut down fruit from her palm trees. A man met her and forbade her (to go out). So she went to the Prophet (ﷺ) and mentioned it to him. He said “Go out, and cut down fruit from your palm trees for perhaps you may give alms (sadaqah) or do an act of kindness}}
\hadithdefcmd{abudawud}{2298}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، حَدَّثَنِي عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، ‏\{‏ وَالَّذِينَ يُتَوَفَّوْنَ مِنْكُمْ وَيَذَرُونَ أَزْوَاجًا وَصِيَّةً لأَزْوَاجِهِمْ مَتَاعًا إِلَى الْحَوْلِ غَيْرَ إِخْرَاجٍ ‏\}‏ فَنُسِخَ ذَلِكَ بِآيَةِ الْمِيرَاثِ بِمَا فُرِضَ لَهُنَّ مِنَ الرُّبُعِ وَالثُّمُنِ وَنُسِخَ أَجَلُ الْحَوْلِ بِأَنْ جُعِلَ أَجَلُهَا أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏.‏\hadithno{2298}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{The Qur’anic verse “Those of you who die and leave widows should bequeath for their widows a year’s maintenance and residence was abrogated by the verse containing the laws of succession, as one-fourth or one-eighth share was prescribed for them (i.e., the widows). The waiting period for one year was also repealed as a period of four months ten days was prescribed for them}}
\hadithdefcmd{abudawud}{2299}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، أَنَّهَا أَخْبَرَتْهُ بِهَذِهِ الأَحَادِيثِ الثَّلاَثَةِ، قَالَتْ زَيْنَبُ دَخَلْتُ عَلَى أُمِّ حَبِيبَةَ حِينَ تُوُفِّيَ أَبُوهَا أَبُو سُفْيَانَ فَدَعَتْ بِطِيبٍ فِيهِ صُفْرَةٌ خَلُوقٌ أَوْ غَيْرُهُ فَدَهَنَتْ مِنْهُ جَارِيَةً ثُمَّ مَسَّتْ بِعَارِضَيْهَا ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثِ لَيَالٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏ قَالَتْ زَيْنَبُ وَدَخَلْتُ عَلَى زَيْنَبَ بِنْتِ جَحْشٍ حِينَ تُوُفِّيَ أَخُوهَا فَدَعَتْ بِطِيبٍ فَمَسَّتْ مِنْهُ ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ وَهُوَ عَلَى الْمِنْبَرِ ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ تُحِدَّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثِ لَيَالٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏ قَالَتْ زَيْنَبُ وَسَمِعْتُ أُمِّي أُمَّ سَلَمَةَ تَقُولُ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَتِي تُوُفِّيَ عَنْهَا زَوْجُهَا وَقَدِ اشْتَكَتْ عَيْنَهَا أَفَنَكْحُلُهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ ‏"‏ ‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا كُلُّ ذَلِكَ يَقُولُ ‏"‏ لاَ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا هِيَ أَرْبَعَةُ أَشْهُرٍ وَعَشْرٌ وَقَدْ كَانَتْ إِحْدَاكُنَّ فِي الْجَاهِلِيَّةِ تَرْمِي بِالْبَعْرَةِ عَلَى رَأْسِ الْحَوْلِ ‏"‏ ‏.‏ قَالَ حُمَيْدٌ فَقُلْتُ لِزَيْنَبَ وَمَا تَرْمِي بِالْبَعْرَةِ عَلَى رَأْسِ الْحَوْلِ فَقَالَتْ زَيْنَبُ كَانَتِ الْمَرْأَةُ إِذَا تُوُفِّيَ عَنْهَا زَوْجُهَا دَخَلَتْ حِفْشًا وَلَبِسَتْ شَرَّ ثِيَابِهَا وَلَمْ تَمَسَّ طِيبًا وَلاَ شَيْئًا حَتَّى تَمُرَّ بِهَا سَنَةٌ ثُمَّ تُؤْتَى بِدَابَّةٍ حِمَارٍ أَوْ شَاةٍ أَوْ طَائِرٍ فَتَفْتَضُّ بِهِ فَقَلَّمَا تَفْتَضُّ بِشَىْءٍ إِلاَّ مَاتَ ثُمَّ تَخْرُجُ فَتُعْطَى بَعْرَةً فَتَرْمِي بِهَا ثُمَّ تُرَاجِعُ بَعْدُ مَا شَاءَتْ مِنْ طِيبٍ أَوْ غَيْرِهِ ‏.‏ قَالَ أَبُو دَاوُدَ الْحِفْشُ بَيْتٌ صَغِيرٌ ‏.‏\hadithno{2299}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1281، 1282) Sahih Muslim (1486)}\hadithtrans{Humaid ibn Nafi' reported the following three traditions on the authority of Zaynab, daughter of Abu Salamah: Zainab said: I visited Umm Habibah when her father AbuSufyan, died. She asked for some yellow perfume containing saffron (khaluq) or something else. Then she applied it to a girl and touched her cheeks. She said: I have no need of perfume, but I heard the Messenger of Allah (ﷺ) say: It is not lawful for a woman who believes in Allah and the Last Day to observe mourning for one who has died, more than three nights, except for four months and ten days in the case of a husband. Zaynab said: I also visited Zaynab, daughter of Jahsh, when her brother died. She asked for some perfume and used it upon herself. She then said: I have no need of perfume, but I heard the Messenger of Allah (ﷺ) say when he was on the pulpit: It is not lawful for a woman who believes in Allah and the Last Day to observe mourning for one who has died, more than three nights, except for four months and ten days in the case of a husband. Zaynab said: I heard my mother, Umm Salamah, say: A woman came to the Messenger of Allah (ﷺ) and said: Messenger of Allah, the husband of my daughter has died, and she is suffering from sore eyes; may we put antimony in her eyes? The Messenger of Allah (ﷺ) said: No. He said this twice or thrice. Each time he said: No. The Messenger of Allah (ﷺ) said: The waiting period is now four months and ten days. In pre-Islamic days one of you used to throw away a piece of dung at the end of a year. Humayd said: I asked Zaynab: What do you mean by throwing away a piece of dung at the end of a year. Zaynab replied: When the husband of a woman died, she entered a small cell and put on shabby clothes, not touching perfume or any other thing until a year passed. Then an animal such as donkey or sheep or bird was provided for her. She rubbed herself with it. The animal with which she rubbed herself rarely survived. She then came out and was given a piece of dung which she threw away. She then used perfume or something else which she desired. Abu Dawud said: The Arabic word "hafsh" means a small cell}}
\hadithdefcmd{abudawud}{2300}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ سَعْدِ بْنِ إِسْحَاقَ بْنِ كَعْبِ بْنِ عُجْرَةَ، عَنْ عَمَّتِهِ، زَيْنَبَ بِنْتِ كَعْبِ بْنِ عُجْرَةَ أَنَّ الْفُرَيْعَةَ بِنْتَ مَالِكِ بْنِ سِنَانٍ، - وَهِيَ أُخْتُ أَبِي سَعِيدٍ الْخُدْرِيِّ - أَخْبَرَتْهَا أَنَّهَا، جَاءَتْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم تَسْأَلُهُ أَنْ تَرْجِعَ إِلَى أَهْلِهَا فِي بَنِي خُدْرَةَ فَإِنَّ زَوْجَهَا خَرَجَ فِي طَلَبِ أَعْبُدٍ لَهُ أَبَقُوا حَتَّى إِذَا كَانُوا بِطَرَفِ الْقَدُّومِ لَحِقَهُمْ فَقَتَلُوهُ فَسَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ أَرْجِعَ إِلَى أَهْلِي فَإِنِّي لَمْ يَتْرُكْنِي فِي مَسْكَنٍ يَمْلِكُهُ وَلاَ نَفَقَةٍ ‏.‏ قَالَتْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَتْ فَخَرَجْتُ حَتَّى إِذَا كُنْتُ فِي الْحُجْرَةِ أَوْ فِي الْمَسْجِدِ دَعَانِي أَوْ أَمَرَ بِي فَدُعِيتُ لَهُ فَقَالَ ‏"‏ كَيْفَ قُلْتِ ‏"‏ ‏.‏ فَرَدَدْتُ عَلَيْهِ الْقِصَّةَ الَّتِي ذَكَرْتُ مِنْ شَأْنِ زَوْجِي قَالَتْ فَقَالَ ‏"‏ امْكُثِي فِي بَيْتِكِ حَتَّى يَبْلُغَ الْكِتَابُ أَجَلَهُ ‏"‏ ‏.‏ قَالَتْ فَاعْتَدَدْتُ فِيهِ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏.‏ قَالَتْ فَلَمَّا كَانَ عُثْمَانُ بْنُ عَفَّانَ أَرْسَلَ إِلَىَّ فَسَأَلَنِي عَنْ ذَلِكَ فَأَخْبَرْتُهُ فَاتَّبَعَهُ وَقَضَى بِهِ ‏.‏\hadithno{2300}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Zaynab, daughter of Ka'b ibn Ujrah narrated that Furay'ah daughter of Malik ibn Sinan, told her that she came to the Messenger of Allah (ﷺ) and asked him whether she could return to her people, Banu Khidrah, for her husband went out seeking his slaves who ran away. When they met him at al-Qudum, they murdered him. So I asked the Messenger of Allah (ﷺ):"Should I return to my people, for he did not leave any dwelling house of his own and maintenance for me? She said: The Messenger of Allah (ﷺ) replied: Yes. She said: I came out, and when I was in the apartment or in the mosque, he called for me, or he commanded (someone to call me) and, therefore, I was called. He said: what did you say? So I repeated my story which I had already mentioned about my husband. Thereupon he said: Stay in your house till the term lapses. She said: So I passed my waiting period in it (her house) for four months and ten days. When Uthman ibn Affan became caliph, he sent for me and asked me about that; so I informed him, and he followed it and decided cases accordingly}}
\hadithdefcmd{abudawud}{2301}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، حَدَّثَنَا مُوسَى بْنُ مَسْعُودٍ، حَدَّثَنَا شِبْلٌ، عَنِ ابْنِ أَبِي نَجِيحٍ، قَالَ قَالَ عَطَاءٌ قَالَ ابْنُ عَبَّاسٍ نَسَخَتْ هَذِهِ الآيَةُ عِدَّتَهَا عِنْدَ أَهْلِهِ فَتَعْتَدُّ حَيْثُ شَاءَتْ وَهُوَ قَوْلُ اللَّهِ تَعَالَى ‏\{‏ غَيْرَ إِخْرَاجٍ ‏\}‏ قَالَ عَطَاءٌ إِنْ شَاءَتِ اعْتَدَّتْ عِنْدَ أَهْلِهِ وَسَكَنَتْ فِي وَصِيَّتِهَا وَإِنْ شَاءَتْ خَرَجَتْ لِقَوْلِ اللَّهِ تَعَالَى ‏\{‏ فَإِنْ خَرَجْنَ فَلاَ جُنَاحَ عَلَيْكُمْ فِيمَا فَعَلْنَ ‏\}‏ قَالَ عَطَاءٌ ثُمَّ جَاءَ الْمِيرَاثُ فَنَسَخَ السُّكْنَى تَعْتَدُّ حَيْثُ شَاءَتْ ‏.‏\hadithno{2301}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5344، 4531)}\hadithtrans{Ibn ‘Abbas said “The following verse abrogated the rule of passing her waiting period with her people. A year’s maintenance and residence. She may pass her waiting period now anywhere she wishes. ‘Ata said “If she wishes she can pass her waiting period with the people of her husband and live in the house left by her husband by will. Or she may shift if she wishes according to the pronouncement of Allah the Exalted. But if they leave (the residence) there is no blame on you for what they do. Ata’ said “Then the verses regarding inheritance were revealed. The commandment for living in a house (for one year) was repealed. She may pass her waiting period wherever she wishes}}
\hadithdefcmd{abudawud}{2302}{حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ طَهْمَانَ، حَدَّثَنِي هِشَامُ بْنُ حَسَّانَ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْجَرَّاحِ الْقُهُسْتَانِيُّ، عَنْ عَبْدِ اللَّهِ، - يَعْنِي ابْنَ بَكْرٍ - السَّهْمِيِّ عَنْ هِشَامٍ، - وَهَذَا لَفْظُ ابْنِ الْجَرَّاحِ - عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تُحِدُّ الْمَرْأَةُ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ فَإِنَّهَا تُحِدُّ عَلَيْهِ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا لاَ تَلْبَسُ ثَوْبًا مَصْبُوغًا إِلاَّ ثَوْبَ عَصْبٍ وَلاَ تَكْتَحِلُ وَلاَ تَمَسُّ طِيبًا إِلاَّ أَدْنَى طُهْرَتِهَا إِذَا طَهُرَتْ مِنْ مَحِيضِهَا بِنُبْذَةٍ مِنْ قُسْطٍ أَوْ أَظْفَارٍ ‏"‏ ‏.‏ قَالَ يَعْقُوبُ مَكَانَ عَصْبٍ ‏"‏ إِلاَّ مَغْسُولاً ‏"‏ ‏.‏ وَزَادَ يَعْقُوبُ ‏"‏ وَلاَ تَخْتَضِبُ ‏"‏ ‏.‏\hadithno{2302}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5342، 5343) Sahih Muslim (938)}\hadithtrans{‘Umm Athiyah reported the Prophet(ﷺ) as saying “A woman must not observe mourning for more than three (days) except for four months and ten days in the case of a husband and she must not wear a dyed garment except one of the types made of dyed yarn or apply collyrium or touch perfume except for a little costus or azfar when she has been purified after her menstrual courses. The narrator Ya’qub mentioned the words “except washed clothes” instead of the words “one of the types made of dyed yarn”. Ya’qub also added “She must not apply Henna”}}
\hadithdefcmd{abudawud}{2303}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، وَمَالِكُ بْنُ عَبْدِ الْوَاحِدِ الْمِسْمَعِيُّ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ هِشَامٍ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ وَلَيْسَ فِي تَمَامِ حَدِيثِهِمَا ‏.‏ قَالَ الْمِسْمَعِيُّ قَالَ يَزِيدُ وَلاَ أَعْلَمُهُ إِلاَّ قَالَ فِيهِ ‏"‏ وَلاَ تَخْتَضِبُ ‏"‏ ‏.‏ وَزَادَ فِيهِ هَارُونُ ‏"‏ وَلاَ تَلْبَسُ ثَوْبًا مَصْبُوغًا إِلاَّ ثَوْبَ عَصْبٍ ‏"‏ ‏.‏\hadithno{2303}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5342، 5343) Sahih Muslim (938)}\hadithtrans{The tradition mentioned above has also been narrated by Al ‘Umm Athiyah from the Prophet (ﷺ) through a different chain of narrators. The tradition narrated by Yazid bin Harun from Hisham does perfectly correspond to the tradition transmitted by Ibrahim bin Tahman and ‘Abd Allah Al Shami from Hisham. The narrator Al Misma’I reported Yazid as saying “I do not know but that he said “she should not dye herself.” To this the narrator Harun added “She should not wear colored clothes except one of the types made of dyed yarn.”}}
\hadithdefcmd{abudawud}{2304}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ أَبِي بُكَيْرٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ طَهْمَانَ، حَدَّثَنِي بُدَيْلٌ، عَنِ الْحَسَنِ بْنِ مُسْلِمٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ الْمُتَوَفَّى عَنْهَا زَوْجُهَا لاَ تَلْبَسُ الْمُعَصْفَرَ مِنَ الثِّيَابِ وَلاَ الْمُمَشَّقَةَ وَلاَ الْحُلِيَّ وَلاَ تَخْتَضِبُ وَلاَ تَكْتَحِلُ ‏"‏ ‏.‏\hadithno{2304}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: The Prophet (ﷺ) said: A woman whose husband has died must not wear clothes dyed with safflower (usfur) or with red ochre (mishq) and ornaments. She must not apply henna and collyrium}}
\hadithdefcmd{abudawud}{2305}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَخْرَمَةُ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ الْمُغِيرَةَ بْنَ الضَّحَّاكِ، يَقُولُ أَخْبَرَتْنِي أُمُّ حَكِيمٍ بِنْتُ أُسَيْدٍ، عَنْ أُمِّهَا، أَنَّ زَوْجَهَا، تُوُفِّيَ وَكَانَتْ تَشْتَكِي عَيْنَيْهَا فَتَكْتَحِلُ بِالْجَلاَءِ - قَالَ أَحْمَدُ الصَّوَابُ بِكُحْلِ الْجَلاَءِ - فَأَرْسَلَتْ مَوْلاَةً لَهَا إِلَى أُمِّ سَلَمَةَ فَسَأَلَتْهَا عَنْ كُحْلِ الْجَلاَءِ فَقَالَتْ لاَ تَكْتَحِلِي بِهِ إِلاَّ مِنْ أَمْرٍ لاَ بُدَّ مِنْهُ يَشْتَدُّ عَلَيْكِ فَتَكْتَحِلِينَ بِاللَّيْلِ وَتَمْسَحِينَهُ بِالنَّهَارِ ‏.‏ ثُمَّ قَالَتْ عِنْدَ ذَلِكَ أُمُّ سَلَمَةَ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ تُوُفِّيَ أَبُو سَلَمَةَ وَقَدْ جَعَلْتُ عَلَى عَيْنِي صَبِرًا فَقَالَ ‏"‏ مَا هَذَا يَا أُمَّ سَلَمَةَ ‏"‏ ‏.‏ فَقُلْتُ إِنَّمَا هُوَ صَبِرٌ يَا رَسُولَ اللَّهِ لَيْسَ فِيهِ طِيبٌ ‏.‏ قَالَ ‏"‏ إِنَّهُ يَشُبُّ الْوَجْهَ فَلاَ تَجْعَلِيهِ إِلاَّ بِاللَّيْلِ وَتَنْزِعِينَهُ بِالنَّهَارِ وَلاَ تَمْتَشِطِي بِالطِّيبِ وَلاَ بِالْحِنَّاءِ فَإِنَّهُ خِضَابٌ ‏"‏ ‏.‏ قَالَتْ قُلْتُ بِأَىِّ شَىْءٍ أَمْتَشِطُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ بِالسِّدْرِ تُغَلِّفِينَ بِهِ رَأْسَكِ ‏"‏ ‏.‏\hadithno{2305}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Umm Hakim, daughter of Usayd, reported on the authority of her mother that her husband died and she was suffering from sore eyes. She therefore applied collyrium (jala'). Ahmad said:The correct version is "glittering collyrium (kuhl al-jala'). She sent her slave-girl to Umm Salamah, and she asked her about the use of glittering collyrium (kuhl al-jala'). She said: Do not apply it except in the case of dire need which is troubling you. In that case you can use it at night, but you should remove it in the daytime. Then Umm Salamah said: The Messenger of Allah (ﷺ) came to visit me when AbuSalamah died, and I had put the juice of aloes in my eye. He asked : What is this, Umm Salamah? I replied: It is only the juice of aloes and contains no perfume. He said: It gives the face a glow, so apply it only at night and remove it in daytime, and do not comb yourself with scent or henna, for it is a dye. I asked: What should I use when I comb myself, Messenger of Allah? He said: Use lote-tree leaves and smear your head copiously with them}}
\hadithdefcmd{abudawud}{2306}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ أَبَاهُ، كَتَبَ إِلَى عُمَرَ بْنِ عَبْدِ اللَّهِ بْنِ الأَرْقَمِ الزُّهْرِيِّ يَأْمُرُهُ أَنْ يَدْخُلَ، عَلَى سُبَيْعَةَ بِنْتِ الْحَارِثِ الأَسْلَمِيَّةِ فَيَسْأَلَهَا عَنْ حَدِيثِهَا وَعَمَّا قَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ اسْتَفْتَتْهُ فَكَتَبَ عُمَرُ بْنُ عَبْدِ اللَّهِ إِلَى عَبْدِ اللَّهِ بْنِ عُتْبَةَ يُخْبِرُهُ أَنَّ سُبَيْعَةَ أَخْبَرَتْهُ أَنَّهَا كَانَتْ تَحْتَ سَعْدِ ابْنِ خَوْلَةَ - وَهُوَ مِنْ بَنِي عَامِرِ بْنِ لُؤَىٍّ وَهُوَ مِمَّنْ شَهِدَ بَدْرًا - فَتُوُفِّيَ عَنْهَا فِي حَجَّةِ الْوَدَاعِ وَهِيَ حَامِلٌ فَلَمْ تَنْشَبْ أَنْ وَضَعَتْ حَمْلَهَا بَعْدَ وَفَاتِهِ فَلَمَّا تَعَلَّتْ مِنْ نِفَاسِهَا تَجَمَّلَتْ لِلْخُطَّابِ فَدَخَلَ عَلَيْهَا أَبُو السَّنَابِلِ بْنُ بَعْكَكٍ - رَجُلٌ مِنْ بَنِي عَبْدِ الدَّارِ - فَقَالَ لَهَا مَا لِي أَرَاكِ مُتَجَمِّلَةً لَعَلَّكِ تَرْتَجِينَ النِّكَاحَ إِنَّكِ وَاللَّهِ مَا أَنْتِ بِنَاكِحٍ حَتَّى تَمُرَّ عَلَيْكِ أَرْبَعَةُ أَشْهُرٍ وَعَشْرٌ ‏.‏ قَالَتْ سُبَيْعَةُ فَلَمَّا قَالَ لِي ذَلِكَ جَمَعْتُ عَلَىَّ ثِيَابِي حِينَ أَمْسَيْتُ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلْتُهُ عَنْ ذَلِكَ فَأَفْتَانِي بِأَنِّي قَدْ حَلَلْتُ حِينَ وَضَعْتُ حَمْلِي وَأَمَرَنِي بِالتَّزْوِيجِ إِنْ بَدَا لِي ‏.‏ قَالَ ابْنُ شِهَابٍ وَلاَ أَرَى بَأْسًا أَنْ تَتَزَوَّجَ حِينَ وَضَعَتْ وَإِنْ كَانَتْ فِي دَمِهَا غَيْرَ أَنَّهُ لاَ يَقْرَبُهَا زَوْجُهَا حَتَّى تَطْهُرَ ‏.‏\hadithno{2306}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3991) Sahih Muslim (1484)}\hadithtrans{‘Ubaid Allah bin ‘Abd Allah bin ‘Utbah said that his father wrote (a letter) to ‘Abd Allaah bin Al Arqam Al Zuhri asking him to visit Subai’ah daughter of Al Harith Al Aslamiyyah and ask her about her story and what the Apostle of Allaah(ﷺ) said to her when she asked his opinion (about her). So, ‘Umar bin Abd allah wrote in reply to ‘Abd Allah bin ‘Utbah informing him what she told him. She told that she was under (i.e., the wife of) Sa’d bin Khawlah who belonged to Banu Amir bin Luwayy. He was one of those who participated in the battle of Badr. He died at the Farwell Pilgrimage while she was pregnant. Soon after his death she gave birth to a child. When she was purified from her bleeding after child birth she adorned herself for seekers in marriage. Then Abu Al Sanabil bin Ba’kah a man from Banu Abd Al Dar entered upon her and said to her “What is the matter seeing you adorned, perhaps you are seeking marriage? I swear by Allah you cannot marry until four months and ten days pass away. Saubai’ah said “When she said this to me, I gathered my clothes on me when the evening came and I came to the Apostle of Allaah(ﷺ) and asked him about that. He told me that I became lawful when I had delivered a child. He suggested me to marry if I wished. Ibn Shihab said “I do not see any harm if she marries when she gives birth to the child, even though she had the bleeding after the child birth, but her husband should not have sexual intercourse till she is purified}}
\hadithdefcmd{abudawud}{2307}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، - قَالَ عُثْمَانُ حَدَّثَنَا وَقَالَ ابْنُ الْعَلاَءِ، أَخْبَرَنَا - أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ مَنْ شَاءَ لاَعَنْتُهُ لأُنْزِلَتْ سُورَةُ النِّسَاءِ الْقُصْرَى بَعْدَ الأَرْبَعَةِ الأَشْهُرِ وَعَشْرًا ‏.‏\hadithno{2307}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: I can invoke the curse of Allah on anyone who wishes: The smaller surat an-Nisa (i.e. Surat at-Talaq) was revealed after the verse regarding the waiting period of four months and ten days had been revealed}}
\hadithdefcmd{abudawud}{2308}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، أَنَّ مُحَمَّدَ بْنَ جَعْفَرٍ، حَدَّثَهُمْ ح، وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ مَطَرٍ، عَنْ رَجَاءِ بْنِ حَيْوَةَ، عَنْ قَبِيصَةَ بْنِ ذُؤَيْبٍ، عَنْ عَمْرِو بْنِ الْعَاصِ، قَالَ لاَ تَلْبِسُوا عَلَيْنَا سُنَّتَهُ - قَالَ ابْنُ الْمُثَنَّى سُنَّةَ نَبِيِّنَا - صلى الله عليه وسلم عِدَّةُ الْمُتَوَفَّى عَنْهَا أَرْبَعَةُ أَشْهُرٍ وَعَشْرٌ ‏.‏ يَعْنِي أُمَّ الْوَلَدِ ‏.‏\hadithno{2308}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Amr ibn al-'As: Do not confuse us about his Sunnah. Ibn al-Muthanna said: The Sunnah of our Prophet (ﷺ) is that the waiting period of a slave-mother whose husband has died is four months and ten days}}
\hadithdefcmd{abudawud}{2309}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ رَجُلٍ طَلَّقَ امْرَأَتَهُ - يَعْنِي ثَلاَثًا - فَتَزَوَّجَتْ زَوْجًا غَيْرَهُ فَدَخَلَ بِهَا ثُمَّ طَلَّقَهَا قَبْلَ أَنْ يُوَاقِعَهَا أَتَحِلُّ لِزَوْجِهَا الأَوَّلِ قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَحِلُّ لِلأَوَّلِ حَتَّى تَذُوقَ عُسَيْلَةَ الآخَرِ وَيَذُوقَ عُسَيْلَتَهَا ‏"‏ ‏.‏\hadithno{2309}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) was asked about a man who divorced his wife three times, and she married another who entered upon her, but divorced her before having intercourse with her, whether she was lawful for the former husband. She said: The Prophet (ﷺ) replied: She is not lawful for the first (husband) until she tastes the honey of the other husband and he tastes her honey}}
\hadithdefcmd{abudawud}{2310}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَمْرِو بْنِ شُرَحْبِيلَ، عَنْ عَبْدِ اللَّهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَىُّ الذَّنْبِ أَعْظَمُ قَالَ ‏"‏ أَنْ تَجْعَلَ لِلَّهِ نِدًّا وَهُوَ خَلَقَكَ ‏"‏ ‏.‏ قَالَ فَقُلْتُ ثُمَّ أَىٌّ قَالَ ‏"‏ أَنْ تَقْتُلَ وَلَدَكَ مَخَافَةَ أَنْ يَأْكُلَ مَعَكَ ‏"‏ ‏.‏ قَالَ قُلْتُ ثُمَّ أَىٌّ قَالَ ‏"‏ أَنْ تُزَانِيَ حَلِيلَةَ جَارِكَ ‏"‏ ‏.‏ قَالَ وَأَنْزَلَ اللَّهُ تَعَالَى تَصْدِيقَ قَوْلِ النَّبِيِّ صلى الله عليه وسلم ‏\{‏ وَالَّذِينَ لاَ يَدْعُونَ مَعَ اللَّهِ إِلَهًا آخَرَ وَلاَ يَقْتُلُونَ النَّفْسَ الَّتِي حَرَّمَ اللَّهُ إِلاَّ بِالْحَقِّ وَلاَ يَزْنُونَ ‏\}‏ الآيَةَ ‏.‏\hadithno{2310}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6001) Sahih Muslim (141)}\hadithtrans{‘Abd Allaah (bin Masud) said “I asked Apostle of Allaah(ﷺ) which sin is the gravest?” He replied “That you associate someone with Allaah, while He has created you”. I again asked “Which then?” He replied “That you commit adultery with the wife of your neighbor.” Allaah then revealed the following Qur’anic verse in support of the statement of the Prophet (ﷺ) “Those who invoke not with Allaah any other god nor slay such life as Allaah has made sacred except for just cause nor commit fornication.”}}
\hadithdefcmd{abudawud}{2311}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، عَنْ حَجَّاجٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ جَاءَتْ مُسَيْكَةُ لِبَعْضِ الأَنْصَارِ فَقَالَتْ إِنَّ سَيِّدِي يُكْرِهُنِي عَلَى الْبِغَاءِ فَنَزَلَ فِي ذَلِكَ ‏\{‏ وَلاَ تُكْرِهُوا فَتَيَاتِكُمْ عَلَى الْبِغَاءِ ‏\}‏ ‏.‏\hadithno{2311}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: Musaykah, a slave-girl of some Ansari, came and said: My master forces me to commit fornication. Thereupon the following verse was revealed: "But force not your maids to prostitution (when they desire chastity)}}
\hadithdefcmd{abudawud}{2312}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ أَبِيهِ، ‏\{‏ وَمَنْ يُكْرِهْهُنَّ فَإِنَّ اللَّهَ مِنْ بَعْدِ إِكْرَاهِهِنَّ غَفُورٌ رَحِيمٌ ‏\}‏ قَالَ قَالَ سَعِيدُ بْنُ أَبِي الْحَسَنِ غَفُورٌ لَهُنَّ الْمُكْرَهَاتِ ‏.‏\hadithno{2312}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Mu’tamir reported on the authority of his father Sa’id bin Al Hassan explain the Qur’anic verse “But if anyone compels them, yet after such compulsion is Allaah oft-forgiving most merciful(to them), said Allaah is oft-forgiving to those (slave girls) who were compelled (to prostitution)}}
