% Auto-generated chapter 44 for nasai
% Hadiths in this chapter: 257

\hadithdefcmd{nasai}{4449}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ أَبُو قُدَامَةَ السَّرَخْسِيُّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ عَمَّتِهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَطْيَبَ مَا أَكَلَ الرَّجُلُ مِنْ كَسْبِهِ وَإِنَّ وَلَدَ الرَّجُلِ مِنْ كَسْبِهِ ‏"‏ ‏.‏\hadithno{4449}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah said: "The best (most Pure) food that a man eats is that which he has earned himself, and a man's child (and his child's wealth) is part of his earnings" (Sahih)}}
\hadithdefcmd{nasai}{4450}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ عَمَّةٍ، لَهُ عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم ‏ "‏ قَالَ إِنَّ أَوْلاَدَكُمْ مِنْ أَطْيَبِ كَسْبِكُمْ فَكُلُوا مِنْ كَسْبِ أَوْلاَدِكُمْ ‏"‏ ‏.‏\hadithno{4450}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from 'Aishah that the Prophet said:"Your children are part of the best of your earnings, so eat from what your children earn}}
\hadithdefcmd{nasai}{4451}{أَخْبَرَنَا يُوسُفُ بْنُ عِيسَى، قَالَ أَنْبَأَنَا الْفَضْلُ بْنُ مُوسَى، قَالَ أَنْبَأَنَا الأَعْمَشُ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَطْيَبَ مَا أَكَلَ الرَّجُلُ مِنْ كَسْبِهِ وَوَلَدُهُ مِنْ كَسْبِهِ ‏"‏ ‏.‏\hadithno{4451}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah said: 'The best (most pure) food that a man eats is that which he has earned himself, and his child (and his child's wealth) is part of his earning}}
\hadithdefcmd{nasai}{4452}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصِ بْنِ عَبْدِ اللَّهِ النَّيْسَابُورِيُّ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ عُمَرَ بْنِ سَعِيدٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَطْيَبَ مَا أَكَلَ الرَّجُلُ مِنْ كَسْبِهِ وَإِنَّ وَلَدَهُ مِنْ كَسْبِهِ ‏"‏ ‏.‏\hadithno{4452}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah said: 'The best (most pure) food that a man eats is that which he has earned himself, and his child (and his child's wealth) is part of his earning}}
\hadithdefcmd{nasai}{4453}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، قَالَ حَدَّثَنَا خَالِدٌ، - وَهُوَ ابْنُ الْحَارِثِ - قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنِ الشَّعْبِيِّ، قَالَ سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم - فَوَاللَّهِ لاَ أَسْمَعُ بَعْدَهُ أَحَدًا يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم - يَقُولُ ‏"‏ إِنَّ الْحَلاَلَ بَيِّنٌ وَإِنَّ الْحَرَامَ بَيِّنٌ وَإِنَّ بَيْنَ ذَلِكَ أُمُورًا مُشْتَبِهَاتٍ ‏"‏ ‏.‏ وَرُبَّمَا قَالَ ‏"‏ وَإِنَّ بَيْنَ ذَلِكَ أُمُورًا مُشْتَبِهَةً ‏"‏ ‏.‏ قَالَ ‏"‏ وَسَأَضْرِبُ لَكُمْ فِي ذَلِكَ مَثَلاً إِنَّ اللَّهَ عَزَّ وَجَلَّ حَمَى حِمًى وَإِنَّ حِمَى اللَّهِ عَزَّ وَجَلَّ مَا حَرَّمَ وَإِنَّهُ مَنْ يَرْتَعْ حَوْلَ الْحِمَى يُوشِكْ أَنْ يُخَالِطَ الْحِمَى ‏"‏ ‏.‏ وَرُبَّمَا قَالَ ‏"‏ إِنَّهُ مَنْ يَرْعَى حَوْلَ الْحِمَى يُوشِكْ أَنْ يَرْتَعَ فِيهِ وَإِنَّ مَنْ يُخَالِطِ الرِّيبَةَ يُوشِكْ أَنْ يَجْسُرَ ‏"‏ ‏.‏\hadithno{4453}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{An-Nu'man bin Bashir said:"I heard the Messenger of Allah say: "That which is lawful is plain and that which is unlawful is plain, and between them are matters which are not as clear. I will strike a parable for you about that: indeed Allah, the Mighty and Sublime, has established a sanctuary, and the sanctuary of Allah is that which He has forbidden. Whoever approaches the sanctuary is bound to transgress upon it, Or he said: 'Whoever grazes around the sanctuary will soon transgress upon it, and whoever indulges in matters that are not clear, he will soon transgress beyond the limits}}
\hadithdefcmd{nasai}{4454}{حَدَّثَنَا الْقَاسِمُ بْنُ زَكَرِيَّا بْنِ دِينَارٍ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَأْتِي عَلَى النَّاسِ زَمَانٌ مَا يُبَالِي الرَّجُلُ مِنْ أَيْنَ أَصَابَ الْمَالَ مِنْ حَلاَلٍ أَوْ حَرَامٍ ‏"‏ ‏.‏\hadithno{4454}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'There will come a time when a man will not care where his wealth comes from, whether (the source is) Halal or Haram}}
\hadithdefcmd{nasai}{4455}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنْ سَعِيدِ بْنِ أَبِي خَيْرَةَ، عَنِ الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَأْتِي عَلَى النَّاسِ زَمَانٌ يَأْكُلُونَ الرِّبَا فَمَنْ لَمْ يَأْكُلْهُ أَصَابَهُ مِنْ غُبَارِهِ ‏"‏ ‏.‏\hadithno{4455}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: "There will come a time when there will be no one left who does not consume Riba, and whoever does not consume it will nevertheless be affected by residue." (Sahih)}}
\hadithdefcmd{nasai}{4456}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ أَنْبَأَنَا وَهْبُ بْنُ جَرِيرٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنْ عَمْرِو بْنِ تَغْلِبَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنْ أَشْرَاطِ السَّاعَةِ أَنْ يَفْشُوَ الْمَالُ وَيَكْثُرَ وَتَفْشُوَ التِّجَارَةُ وَيَظْهَرَ الْعِلْمُ وَيَبِيعَ الرَّجُلُ الْبَيْعَ فَيَقُولَ لاَ حَتَّى أَسْتَأْمِرَ تَاجِرَ بَنِي فُلاَنٍ وَيُلْتَمَسَ فِي الْحَىِّ الْعَظِيمِ الْكَاتِبُ فَلاَ يُوجَدُ ‏"‏ ‏.‏\hadithno{4456}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Amr bin Taghilb said:"The Messenger of Allah said: 'One of the portents of the Hour will be that wealth becomes widespread and abundant, and trade will become widespread, but knowledge will disappear. A man will try to sell something and will say: "No, not until I consult the merchant of banu so and so: and People will look throughout a vast area for a scribe and will not find one." (Sahih)}}
\hadithdefcmd{nasai}{4457}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، عَنْ يَحْيَى، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي قَتَادَةُ، عَنْ أَبِي الْخَلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ حَكِيمِ بْنِ حِزَامٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَفْتَرِقَا فَإِنْ صَدَقَا وَبَيَّنَا بُورِكَ فِي بَيْعِهِمَا وَإِنْ كَذَبَا وَكَتَمَا مُحِقَ بَرَكَةُ بَيْعِهِمَا ‏"‏ ‏.‏\hadithno{4457}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Hakim bin Hizam said:"The Messenger of Allah said: 'The two parties to a transaction have the choice so long as they have not separated. If they are honest and open, their transaction will be blessed, but if they tell lies and conceal anything, the blessing of their transaction will be lost}}
\hadithdefcmd{nasai}{4458}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عَلِيِّ بْنِ مُدْرِكٍ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ خَرَشَةَ بْنِ الْحُرِّ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ يَوْمَ الْقِيَامَةِ وَلاَ يَنْظُرُ إِلَيْهِمْ وَلاَ يُزَكِّيهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ ‏"‏ ‏.‏ فَقَرَأَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ أَبُو ذَرٍّ خَابُوا وَخَسِرُوا ‏.‏ قَالَ ‏"‏ الْمُسْبِلُ إِزَارَهُ وَالْمُنَفِّقُ سِلْعَتَهُ بِالْحَلِفِ الْكَاذِبِ وَالْمَنَّانُ عَطَاءَهُ ‏"‏ ‏.‏\hadithno{4458}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Dharr that the Prophet said:"There are three to whom Allah will not speak on the Day of Resurrection, or will He look at them, or sanctify them, and theirs will be a painful torment: Abu Dharr said:" May they be lost and doomed: He said: "The one who drags his Izar (below the ankles) the one who sells his product by means of false oaths, and the one who reminds others (Al-Mannan) of what he has given to them}}
\hadithdefcmd{nasai}{4459}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَدَّثَنِي سُلَيْمَانُ الأَعْمَشُ، عَنْ سُلَيْمَانَ بْنِ مُسْهِرٍ، عَنْ خَرَشَةَ بْنِ الْحُرِّ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثَةٌ لاَ يَنْظُرُ اللَّهُ إِلَيْهِمْ يَوْمَ الْقِيَامَةِ وَلاَ يُزَكِّيهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ الَّذِي لاَ يُعْطِي شَيْئًا إِلاَّ مَنَّهُ وَالْمُسْبِلُ إِزَارَهُ وَالْمُنَفِّقُ سِلْعَتَهُ بِالْكَذِبِ ‏"‏ ‏.‏\hadithno{4459}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Dharr that the Prophet said:"There are three at whom Allah will not look on the Day of Resurrection, nor will He sanctify them, and theirs will be a painful torment: the one who does not give anything but he reminds (the recipient of his gift), the one who drags his Izar (below the ankles), and the one who sells his product by means of false oaths." (Sahih)}}
\hadithdefcmd{nasai}{4460}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ أَخْبَرَنِي الْوَلِيدُ، - يَعْنِي ابْنَ كَثِيرٍ - عَنْ مَعْبَدِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِي قَتَادَةَ الأَنْصَارِيِّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِيَّاكُمْ وَكَثْرَةَ الْحَلِفِ فِي الْبَيْعِ فَإِنَّهُ يُنَفِّقُ ثُمَّ يَمْحَقُ ‏"‏ ‏.‏\hadithno{4460}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Qatadah Al-Ansari that he heard the Messenger of Allah say:"Beware of taking oaths a great deal when selling, for it may help you to make a sale but it destroys the blessing}}
\hadithdefcmd{nasai}{4461}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْحَلِفُ مَنْفَقَةٌ لِلسِّلْعَةِ مَمْحَقَةٌ لِلْكَسْبِ ‏"‏ ‏.‏\hadithno{4461}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"Taking oaths may help you to make a sale but it takes (blessing) away from the earnings "(Sahih)}}
\hadithdefcmd{nasai}{4462}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ عَزَّ وَجَلَّ وَلاَ يَنْظُرُ إِلَيْهِمْ يَوْمَ الْقِيَامَةِ وَلاَ يُزَكِّيهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ رَجُلٌ عَلَى فَضْلِ مَاءٍ بِالطَّرِيقِ يَمْنَعُ ابْنَ السَّبِيلِ مِنْهُ وَرَجُلٌ بَايَعَ إِمَامًا لِدُنْيَا إِنْ أَعْطَاهُ مَا يُرِيدُ وَفَّى لَهُ وَإِنْ لَمْ يُعْطِهِ لَمْ يَفِ لَهُ وَرَجُلٌ سَاوَمَ رَجُلاً عَلَى سِلْعَةٍ بَعْدَ الْعَصْرِ فَحَلَفَ لَهُ بِاللَّهِ لَقَدْ أُعْطِيَ بِهَا كَذَا وَكَذَا فَصَدَّقَهُ الآخَرُ ‏"‏ ‏.‏\hadithno{4462}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"There are three to whom Allah will not speak on the Day of Resurrection, or will He look at them, or sanctify them and theirs will be a painful torment: A man who has surplus water when traveling but he withholds it form a wayfarer; a man who swears allegiance to an imam for worldly gains, and if he gives him what he wants he is loyal to him but if he does not give him anything he is not loyal to him: and a man who sells a man his product after 'Asr, swerving by Allah that he bought it for such and such a price, and the other believes him}}
\hadithdefcmd{nasai}{4463}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، عَنْ جَرِيرٍ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ قَيْسِ بْنِ أَبِي غَرَزَةَ، قَالَ كُنَّا بِالْمَدِينَةِ نَبِيعُ الأَوْسَاقَ وَنَبْتَاعُهَا وَنُسَمِّي أَنْفُسَنَا السَّمَاسِرَةَ وَيُسَمِّينَا النَّاسُ فَخَرَجَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَمَّانَا بِاسْمٍ هُوَ خَيْرٌ لَنَا مِنَ الَّذِي سَمَّيْنَا بِهِ أَنْفُسَنَا فَقَالَ ‏ "‏ يَا مَعْشَرَ التُّجَّارِ إِنَّهُ يَشْهَدُ بَيْعَكُمُ الْحَلِفُ وَاللَّغْوُ فَشُوبُوهُ بِالصَّدَقَةِ ‏"‏ ‏.‏\hadithno{4463}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Qays bin Abi Gharazah said:"We used to trade in the markets of Al-Madinah and we used to call ourselves as-Samasir (brokers) and the people called us that, but the Messenger of Allah came out to s and called us by a name that was better than what we called ourselves. He said: "O merchants (Tujjar)! Selling involves (false) oaths and idle talk, so mix some charity with it,"" (Sahih)}}
\hadithdefcmd{nasai}{4464}{أَخْبَرَنَا أَبُو الأَشْعَثِ، عَنْ خَالِدٍ، قَالَ حَدَّثَنَا سَعِيدٌ، - وَهُوَ ابْنُ أَبِي عَرُوبَةَ - عَنْ قَتَادَةَ، عَنْ صَالِحٍ أَبِي الْخَلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ حَكِيمِ بْنِ حِزَامٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَفْتَرِقَا فَإِنْ بَيَّنَا وَصَدَقَا بُورِكَ لَهُمَا فِي بَيْعِهِمَا وَإِنْ كَذَبَا وَكَتَمَا مُحِقَ بَرَكَةُ بَيْعِهِمَا ‏"‏ ‏.‏\hadithno{4464}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Hakim bin Hizam said:The Messenger of Allah said: "The two parties to a transaction have the choice so long as they have not separated. If they are honest and open, their transaction will be blessed, but if they tell lies and conceal anything the blessing of their transaction will be lost}}
\hadithdefcmd{nasai}{4465}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُتَبَايِعَانِ كُلُّ وَاحِدٍ مِنْهُمَا بِالْخِيَارِ عَلَى صَاحِبِهِ مَا لَمْ يَفْتَرِقَا إِلاَّ بَيْعَ الْخِيَارِ ‏"‏ ‏.‏\hadithno{4465}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Malik, from Nafi from'Abdullah bin 'Umar that the Messenger of Allah said:"The two parties to a transaction both have the choice so long as they both chosen to conclude the transaction." (Sahih)}}
\hadithdefcmd{nasai}{4466}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَفْتَرِقَا أَوْ يَكُونَ خِيَارًا ‏"‏ ‏.‏\hadithno{4466}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Yahaya, from 'Ubaidullah who said:"Nafi narrated to me from Ibn 'Umar, tht the Messenger of Allah said: 'the two parties to a transaction both have the choice so long as they have not separated, or they have chosen." (Sahih)}}
\hadithdefcmd{nasai}{4467}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيٍّ الْمَرْوَزِيُّ، قَالَ حَدَّثَنَا مُحْرِزُ بْنُ الْوَضَّاحِ، عَنْ إِسْمَاعِيلَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُتَبَايِعَانِ بِالْخِيَارِ مَا لَمْ يَفْتَرِقَا إِلاَّ أَنْ يَكُونَ الْبَيْعُ كَانَ عَنْ خِيَارٍ فَإِنْ كَانَ الْبَيْعُ عَنْ خِيَارٍ فَقَدْ وَجَبَ الْبَيْعُ ‏"‏ ‏.‏\hadithno{4467}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{it was narrated from Ismail, from Nafi, that Ibn 'Umar said:"The Messenger of Allah said: 'The two parties to a transaction both have the choice so long as they have not separated, unless they have both chosen to conclude they transaction. If they have both chosen to conclude the transaction, then the transaction is binding." (Sahih)}}
\hadithdefcmd{nasai}{4468}{أَخْبَرَنَا عَلِيُّ بْنُ مَيْمُونٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَمْلَى عَلَىَّ نَافِعٌ عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا تَبَايَعَ الْبَيِّعَانِ فَكُلُّ وَاحِدٍ مِنْهُمَا بِالْخِيَارِ مِنْ بَيْعِهِ مَا لَمْ يَفْتَرِقَا أَوْ يَكُونَ بَيْعُهُمَا عَنْ خِيَارٍ فَإِنْ كَانَ عَنْ خِيَارٍ فَقَدْ وَجَبَ الْبَيْعُ ‏"‏ ‏.‏\hadithno{4468}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Juraij:"Nafi dictated to me, from Ibn 'Umar who said: The Messenger of Allah said: 'the two parties to a transaction both have the choice so long as they have not separated, unless they have both chosen to conclude the transaction. If they have both chosen to conclude the transaction, then the transactions binding." (Sahih)}}
\hadithdefcmd{nasai}{4469}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَفْتَرِقَا أَوْ يَقُولَ أَحَدُهُمَا لِلآخَرِ اخْتَرْ ‏"‏ ‏.‏\hadithno{4469}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was a narrated from Ayyub, from Nafi from Ibn 'Umar that the Messenger of Allah said:"The Messenger of Allah said: "The two parties to a transaction both have the choice who long as they have not separated or one of them says to the other: 'Decide!"' (Sahih)}}
\hadithdefcmd{nasai}{4470}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ أَنْبَأَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْبَيِّعَانِ بِالْخِيَارِ حَتَّى يَفْتَرِقَا أَوْ يَكُونَ بَيْعَ خِيَارٍ ‏"‏ ‏.‏ وَرُبَّمَا قَالَ نَافِعٌ ‏"‏ أَوْ يَقُولَ أَحَدُهُمَا لِلآخَرِ اخْتَرْ ‏"‏ ‏.‏\hadithno{4470}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ayyub, from Nafi from Ibn 'Umar, who said:"The Messenger of Allah said: 'The two parties to a transaction both have the choice so long as they have not separated or chosen to conclude the transaction." Or perhaps Nafi said: "Or one of them has said to the other: 'Decide! "(Sahih)}}
\hadithdefcmd{nasai}{4471}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْبَيِّعَانِ بِالْخِيَارِ حَتَّى يَفْتَرِقَا أَوْ يَكُونَ بَيْعَ خِيَارٍ ‏"‏ ‏.‏ وَرُبَّمَا قَالَ نَافِعٌ ‏"‏ أَوْ يَقُولَ أَحَدُهُمَا لِلآخَرِ اخْتَرْ ‏"‏ ‏.‏\hadithno{4471}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Al-Laith from Nafi from Ibn 'Umar who said:"The Messenger of Allah said: 'The two parties to a transaction both have the choice so long as they have not separated or they have chosen to conclude the transaction.' Or perhaps Nafi said: "Or one of them has said to the other: 'Decide! (Sahih)}}
\hadithdefcmd{nasai}{4472}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا تَبَايَعَ الرَّجُلاَنِ فَكُلُّ وَاحِدٍ مِنْهُمَا بِالْخِيَارِ حَتَّى يَفْتَرِقَا ‏"‏ ‏.‏ وَقَالَ مَرَّةً أُخْرَى ‏"‏ مَا لَمْ يَتَفَرَّقَا وَكَانَا جَمِيعًا أَوْ يُخَيِّرَ أَحَدُهُمَا الآخَرَ فَإِنْ خَيَّرَ أَحَدُهُمَا الآخَرَ فَتَبَايَعَا عَلَى ذَلِكَ فَقَدْ وَجَبَ الْبَيْعُ فَإِنْ تَفَرَّقَا بَعْدَ أَنْ تَبَايَعَا وَلَمْ يَتْرُكْ وَاحِدٌ مِنْهُمَا الْبَيْعَ فَقَدْ وَجَبَ الْبَيْعُ ‏"‏ ‏.‏\hadithno{4472}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Al-Laith, from Nafi, from Ibn 'Umar that the Messenger of Allah said:"When two men enter into a transaction, each of them has the choice until they separate." On one occasion he said: "So long as they have not separated and one has not told the other to decide. If one tells the other to decide and they agree upon something, then the transaction is binding. If they separate after entering into a transaction and neither of them has canceled the transaction, then the transaction is binding." (Sahih)}}
\hadithdefcmd{nasai}{4473}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، يَقُولُ سَمِعْتُ نَافِعًا، يُحَدِّثُ عَنِ ابْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْمُتَبَايِعَيْنِ بِالْخِيَارِ فِي بَيْعِهِمَا مَا لَمْ يَفْتَرِقَا إِلاَّ أَنْ يَكُونَ الْبَيْعُ خِيَارًا ‏"‏ ‏.‏ قَالَ نَافِعٌ فَكَانَ عَبْدُ اللَّهِ إِذَا اشْتَرَى شَيْئًا يُعْجِبُهُ فَارَقَ صَاحِبَهُ ‏.‏\hadithno{4473}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Yahya bin Sa 'eed who said:"I heard Nafi narrating from Ibn 'Umar, form the Messenger of Allah 'the two parties to a transaction both have the choice so long as they have not separated unless they have chosen to conclude the transaction. " Nafi said: ''When 'Abdullah bought something he like, he would leave straightaway}}
\hadithdefcmd{nasai}{4474}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ حَدَّثَنَا نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُتَبَايِعَانِ لاَ بَيْعَ بَيْنَهُمَا حَتَّى يَتَفَرَّقَا إِلاَّ بَيْعَ الْخِيَارِ ‏"‏ ‏.‏\hadithno{4474}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Yahya bin Sa 'eed , who said:"Nafi narrated to us from Ibn 'Umar, who said: 'The Messenger of Allah said: There is no transaction between the two parties until they separate, unless they have chosen to conclude the transaction."" (Sahih)}}
\hadithdefcmd{nasai}{4475}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، عَنْ إِسْمَاعِيلَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ بَيِّعَيْنِ لاَ بَيْعَ بَيْنَهُمَا حَتَّى يَتَفَرَّقَا إِلاَّ بَيْعَ الْخِيَارِ ‏"‏ ‏.‏\hadithno{4475}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ismail from 'Abdullah bin Dinar, from Ibn 'Umar, who said:"The Messenger of Allah said: 'When two people meet to engage in trade, the transaction between them is not binding until they separate, unless they have chosen to conclude the transaction}}
\hadithdefcmd{nasai}{4476}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، عَنْ شُعَيْبٍ، عَنِ اللَّيْثِ، عَنِ ابْنِ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ كُلُّ بَيِّعَيْنِ فَلاَ بَيْعَ بَيْنَهُمَا حَتَّى يَتَفَرَّقَا إِلاَّ بَيْعَ الْخِيَارِ ‏"‏ ‏.‏\hadithno{4476}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn Al-Had, from 'Abdullah bin Dinar, from 'Abdullah bin 'Umar, that he heard the Messenger of Allah (ﷺ) say:"When two people meet to engage in trade, the transaction between them is not binding until they separate, unless they have chosen to conclude the transaction}}
\hadithdefcmd{nasai}{4477}{أَخْبَرَنَا عَبْدُ الْحَمِيدِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مَخْلَدٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ بَيِّعَيْنِ لاَ بَيْعَ بَيْنَهُمَا حَتَّى يَتَفَرَّقَا إِلاَّ بَيْعَ الْخِيَارِ ‏"‏ ‏.‏\hadithno{4477}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Sufyan, from 'Amr bin Dinar, from Ibn 'Umar, who said:the Messenger of Allah said: "When two people meet to engage in trade, the transaction between them is not binding until they separate, unless they have chosen to concluded the transaction}}
\hadithdefcmd{nasai}{4478}{أَخْبَرَنَا الرَّبِيعُ بْنُ سُلَيْمَانَ بْنِ دَاوُدَ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ بَكْرٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ كُلُّ بَيِّعَيْنِ لاَ بَيْعَ بَيْنَهُمَا حَتَّى يَتَفَرَّقَا إِلاَّ بَيْعَ الْخِيَارِ ‏"‏ ‏.‏\hadithno{4478}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Yazid bin 'Abdullah, from 'Abdullah bin dinar, from ibn 'Umar that he heard the Messenger of Allah say:"When two people meet to engage in trade the transaction between them is not binding until they separate, unless they have chosen to conclude the transaction}}
\hadithdefcmd{nasai}{4479}{أَخْبَرَنَا عَمْرُو بْنُ يَزِيدَ، عَنْ بَهْزِ بْنِ أَسَدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ بَيِّعَيْنِ فَلاَ بَيْعَ بَيْنَهُمَا حَتَّى يَتَفَرَّقَا إِلاَّ بَيْعَ الْخِيَارِ ‏"‏ ‏.‏\hadithno{4479}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Shu'ban who said:"Abdullah bin Dinr narrated to us, from Ibn'Umar, who said; The Messenger of Allah said; "When two people meet to engage in trade, the transaction between them is not binding until they separate, unless they have chosen to conclude the transaction}}
\hadithdefcmd{nasai}{4480}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا أَوْ يَكُونَ بَيْعُهُمَا عَنْ خِيَارٍ ‏"‏ ‏.‏\hadithno{4480}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Sufyan, from 'Abdullah bin Dinar, from Ibn 'Umar, from the Prophet who said:"Two traders have the choice as long as they have not separated, or, they have chosen to conclude the transaction}}
\hadithdefcmd{nasai}{4481}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ حَتَّى يَتَفَرَّقَا أَوْ يَأْخُذَ كُلُّ وَاحِدٍ مِنْهُمَا مِنَ الْبَيْعِ مَا هَوِيَ وَيَتَخَايَرَانِ ثَلاَثَ مَرَّاتٍ ‏"‏ ‏.‏\hadithno{4481}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Al\_Hasan, from Samurah, that the Prophet of Allah said:"Two trades have the choice as long as until they reach a deal that suits both of them and they confirm it three times}}
\hadithdefcmd{nasai}{4482}{أَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ أَنْبَأَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبَيِّعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا وَيَأْخُذْ أَحَدُهُمَا مَا رَضِيَ مِنْ صَاحِبِهِ أَوْ هَوِيَ ‏"‏ ‏.‏\hadithno{4482}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Al- Hasan from Samurah, who said:"The Messenger of Allah said;" Two traders have the choice as long as they have not separated, or until they reach a deal that suits both of th4em or that is satisfactory (to both)}}
\hadithdefcmd{nasai}{4483}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ أَنْبَأَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُتَبَايِعَانِ بِالْخِيَارِ مَا لَمْ يَتَفَرَّقَا إِلاَّ أَنْ يَكُونَ صَفْقَةَ خِيَارٍ وَلاَ يَحِلُّ لَهُ أَنْ يُفَارِقَ صَاحِبَهُ خَشْيَةَ أَنْ يَسْتَقِيلَهُ ‏"‏ ‏.‏\hadithno{4483}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father , form his grandfather, that the Prophet said:"The two parties to a transaction have the choicer so long as they have not separated, unless they reach an agreement before parting, and it is not permissible to hasten to leave for fear that the other party may change his mind}}
\hadithdefcmd{nasai}{4484}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، ذَكَرَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ يُخْدَعُ فِي الْبَيْعِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا بِعْتَ فَقُلْ لاَ خِلاَبَةَ ‏"‏ ‏.‏ فَكَانَ الرَّجُلُ إِذَا بَاعَ يَقُولُ لاَ خِلاَبَةَ ‏.‏\hadithno{4484}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that:a man told the Messenger of Allah that he was always being cheated. The Messenger of Allah said to him: "When you make a deal, say: There is no intention of cheating" So, whenever the man engages in a deal he says, 'There is no intention of cheating." "(Sahih)}}
\hadithdefcmd{nasai}{4485}{أَخْبَرَنَا يُوسُفُ بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَجُلاً، كَانَ فِي عُقْدَتِهِ ضَعْفٌ كَانَ يُبَايِعُ وَأَنَّ أَهْلَهُ أَتَوُا النَّبِيَّ صلى الله عليه وسلم فَقَالُوا يَا نَبِيَّ اللَّهِ احْجُرْ عَلَيْهِ ‏.‏ فَدَعَاهُ نَبِيُّ اللَّهِ صلى الله عليه وسلم فَنَهَاهُ فَقَالَ يَا نَبِيَّ اللَّهِ إِنِّي لاَ أَصْبِرُ عَنِ الْبَيْعِ ‏.‏ قَالَ ‏ "‏ إِذَا بِعْتَ فَقُلْ لاَ خِلاَبَةَ ‏"‏ ‏.‏\hadithno{4485}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that:there was a man whose mental faculties were lacking, and he used to buy and sell. His family came to the Prophet and said: "O Prophet of Allah stop him." So the Prophet of Allah called him, and told him not to do that. He said: "O Prophet of Allah, I cannot bear to be away from business," He said "If you engaged in a deal then say: 'There is no intention to deceive. "' (Sahih)}}
\hadithdefcmd{nasai}{4486}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنِي أَبُو كَثِيرٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا بَاعَ أَحَدُكُمُ الشَّاةَ أَوِ اللَّقْحَةَ فَلاَ يُحَفِّلْهَا ‏"‏ ‏.‏\hadithno{4486}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah said:"The Messenger of Allah said: 'If any one of you sells a sheep or a milch- camel, let him not refrain from milking it.'' (Sahih)}}
\hadithdefcmd{nasai}{4487}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَلَقُّوا الرُّكْبَانَ لِلْبَيْعِ وَلاَ تُصَرُّوا الإِبِلَ وَالْغَنَمَ مَنِ ابْتَاعَ مِنْ ذَلِكَ شَيْئًا فَهُوَ بِخَيْرِ النَّظَرَيْنِ فَإِنْ شَاءَ أَمْسَكَهَا وَإِنْ شَاءَ أَنْ يَرُدَّهَا رَدَّهَا وَمَعَهَا صَاعُ تَمْرٍ ‏"‏ ‏.‏\hadithno{4487}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"Do not go out to meet the riders, and do not bind the udders of camels and seep. Whoever has boughty anything in that manner has two choices: If he whishes he may keep it, or if he wants to return it he may return it, along with a Sa of dates." (Sahih)}}
\hadithdefcmd{nasai}{4488}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْحَارِثِ، قَالَ حَدَّثَنِي دَاوُدُ بْنُ قَيْسٍ، عَنِ ابْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اشْتَرَى مُصَرَّاةً فَإِنْ رَضِيَهَا إِذَا حَلَبَهَا فَلْيُمْسِكْهَا وَإِنْ كَرِهَهَا فَلْيَرُدَّهَا وَمَعَهَا صَاعٌ مِنْ تَمْرٍ ‏"‏ ‏.‏\hadithno{4488}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"whoever buys a Musarraha, if he is please with it when he milks it, he may keep it, and if he is not please with it, he may return it, along with a Sa of daters"' (Sahih)}}
\hadithdefcmd{nasai}{4489}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ مَنِ ابْتَاعَ مُحَفَّلَةً أَوْ مُصَرَّاةً فَهُوَ بِالْخِيَارِ ثَلاَثَةَ أَيَّامٍ إِنْ شَاءَ أَنْ يُمْسِكَهَا أَمْسَكَهَا وَإِنْ شَاءَ أَنْ يَرُدَّهَا رَدَّهَا وَصَاعًا مِنْ تَمْرٍ لاَ سَمْرَاءَ ‏"‏ ‏.‏\hadithno{4489}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah said:Abu Al- Qasim said: "Whoever buys a Musarrah, he has the choice (of annulling the deal) for three days. If the wishes ti keep it, he may keep it, and if he wishes to return it, he may return it, along with a Sa of daters, not wheat." (Sahih)}}
\hadithdefcmd{nasai}{4490}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ، وَوَكِيعٌ، قَالاَ حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ مَخْلَدِ بْنِ خُفَافٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنَّ الْخَرَاجَ بِالضَّمَانِ ‏.‏\hadithno{4490}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that 'Aishsh said:" The Messenger of Allah ruled that what a slave earns belongs to his guarantor}}
\hadithdefcmd{nasai}{4491}{أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ تَمِيمٍ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ حَدَّثَنِي شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ التَّلَقِّي وَأَنْ يَبِيعَ مُهَاجِرٌ لِلأَعْرَابِيِّ وَعَنِ التَّصْرِيَةِ وَالنَّجْشِ وَأَنْ يَسْتَامَ الرَّجُلُ عَلَى سَوْمِ أَخِيهِ وَأَنْ تَسْأَلَ الْمَرْأَةُ طَلاَقَ أُخْتِهَا ‏.‏\hadithno{4491}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah forbade meeting (the traders on the way) a Muhajhir selling for a Bedouin, keeping the milk in the udder of an animal (so as to increase its price), artificially inflating prices, a man to urge the cancellation of sale already agreed upon and a woman to ask that her sister (in faith) be divorced}}
\hadithdefcmd{nasai}{4492}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ الزِّبْرِقَانِ، قَالَ حَدَّثَنَا يُونُسُ بْنُ عُبَيْدٍ، عَنِ الْحَسَنِ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يَبِيعَ حَاضِرٌ لِبَادٍ وَإِنْ كَانَ أَبَاهُ أَوْ أَخَاهُ ‏.‏\hadithno{4492}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas that:the Prophet forbade a town-dweller to sell for a desert- dweller, even if he was his father or brother. (Sahih)}}
\hadithdefcmd{nasai}{4493}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنِي سَالِمُ بْنُ نُوحٍ، قَالَ أَنْبَأَنَا يُونُسُ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ نُهِينَا أَنْ يَبِيعَ، حَاضِرٌ لِبَادٍ وَإِنْ كَانَ أَخَاهُ أَوْ أَبَاهُ ‏.‏\hadithno{4493}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:"It was forbidden to us for a town-dweller to sell for a desert-dweller, even if he was his father or brother." (Sahih)}}
\hadithdefcmd{nasai}{4494}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنْ أَنَسٍ، قَالَ نُهِينَا أَنْ يَبِيعَ، حَاضِرٌ لِبَادٍ ‏.‏\hadithno{4494}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Anas said:"It was forbidden to us for a town-dweller to sell for a desert-dweller." (Sahih)}}
\hadithdefcmd{nasai}{4495}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَبِيعُ حَاضِرٌ لِبَادٍ دَعُوا النَّاسَ يَرْزُقُ اللَّهُ بَعْضَهُمْ مِنْ بَعْضٍ ‏"‏ ‏.‏\hadithno{4495}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Jabir said:"The Messenger of Allah said: 'A town-dweller should not sell for a direst-dweller. Leave the people alone and let Allah provide for them from one another."" (Sahih)}}
\hadithdefcmd{nasai}{4496}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَلَقُّوا الرُّكْبَانَ لِلْبَيْعِ وَلاَ يَبِعْ بَعْضُكُمْ عَلَى بَيْعِ بَعْضٍ - وَلاَ تَنَاجَشُوا - وَلاَ يَبِيعُ حَاضِرٌ لِبَادٍ ‏"‏ ‏.‏\hadithno{4496}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Do not go out to meet the riders, and do not urge someone to cancel a sale he has already agreed upon os as to sell him your own goods, do not artificially inflate prices, and let not a town-dweller sell for a desert-dweller." (Sahih)}}
\hadithdefcmd{nasai}{4497}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ بْنِ أَعْيَنَ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ اللَّيْثِ، عَنْ أَبِيهِ، عَنْ كَثِيرِ بْنِ فَرْقَدٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ نَهَى عَنِ النَّجْشِ وَالتَّلَقِّي وَأَنْ يَبِيعَ حَاضِرٌ لِبَادٍ ‏.‏\hadithno{4497}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah that:the Messenger of Allah forbade artificially inflating prices, meeting traders on the way, and for a town-dweller to sell for a desert-dweller." (Sahih)}}
\hadithdefcmd{nasai}{4498}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ التَّلَقِّي ‏.‏\hadithno{4498}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that:the Messenger of Allah forbade meeting traders on the way}}
\hadithdefcmd{nasai}{4499}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ قُلْتُ لأَبِي أُسَامَةَ أَحَدَّثَكُمْ عُبَيْدُ اللَّهِ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ تَلَقِّي الْجَلَبِ حَتَّى يَدْخُلَ بِهَا السُّوقَ فَأَقَرَّ بِهِ أَبُو أُسَامَةَ وَقَالَ نَعَمْ ‏.‏\hadithno{4499}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah (ﷺ) forbade meeting traders on the way, until one enters the market with them?" Abu Usamah acknowledged it and said: Yes}}
\hadithdefcmd{nasai}{4500}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُتَلَقَّى الرُّكْبَانُ وَأَنْ يَبِيعَ حَاضِرٌ لِبَادٍ ‏.‏ قُلْتُ لاِبْنِ عَبَّاسٍ مَا قَوْلُهُ حَاضِرٌ لِبَادٍ قَالَ لاَ يَكُونُ لَهُ سِمْسَارًا ‏.‏\hadithno{4500}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrate from Ibn Tawus, from his father, that Ibn 'Abbas said; "The Messenger of Allah forbade meeting the riders, and for a town-dweller." I said to Ibn 'Abbas:"What does a town-dweller (selling) for a desert-dweller mean?" he said: "He should not act as a broker for him}}
\hadithdefcmd{nasai}{4501}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، قَالَ أَنْبَأَنَا هِشَامُ بْنُ حَسَّانَ الْقُرْدُوسِيُّ، أَنَّهُ سَمِعَ ابْنَ سِيرِينَ، يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَلَقُّوا الْجَلَبَ فَمَنْ تَلَقَّاهُ فَاشْتَرَى مِنْهُ فَإِذَا أَتَى سَيِّدُهُ السُّوقَ فَهُوَ بِالْخِيَارِ ‏"‏ ‏.‏\hadithno{4501}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah said:"The Messenger of Allah said: 'Do and whoever meets any of them and buys from him the vendor has the choice of annulling the transaction when he comes to the marketplace}}
\hadithdefcmd{nasai}{4502}{حَدَّثَنَا مُجَاهِدُ بْنُ مُوسَى، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَبِيعَنَّ حَاضِرٌ لِبَادٍ وَلاَ تَنَاجَشُوا وَلاَ يُسَاوِمِ الرَّجُلُ عَلَى سَوْمِ أَخِيهِ وَلاَ يَخْطُبْ عَلَى خِطْبَةِ أَخِيهِ وَلاَ تَسْأَلِ الْمَرْأَةُ طَلاَقَ أُخْتِهَا لِتَكْتَفِئَ مَا فِي إِنَائِهَا وَلِتُنْكَحَ فَإِنَّمَا لَهَا مَا كَتَبَ اللَّهُ لَهَا ‏"‏ ‏.‏\hadithno{4502}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{(It was narrated that Abu Hurairah said:The Messenger of Allah said: "No town-dweller should sell for a desert-dweller, do not artificially inflate prices, no man should urge a seller to cancel a sale already agreed upon with another buy so as to by the goods himself, no one should make a proposal over the proposal of his brother and no woman should make a proposal over the proposal of his brother and no woman should ask for her sister in faith) to be divorced so as to turn over what is in her vessel Deprived her of her share of maintenance) and so that she may get married in her place: she will have what Allah has decreed or her}}
\hadithdefcmd{nasai}{4503}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، وَاللَّيْثِ، - وَاللَّفْظُ لَهُ - عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لاَ يَبِيعُ أَحَدُكُمْ عَلَى بَيْعِ أَخِيهِ ‏"‏ ‏.‏\hadithno{4503}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Prophet said:"No one of you should urge someone to cancel a sale he has already agreed upon with his brother so as to sell him his own goods}}
\hadithdefcmd{nasai}{4504}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبِيعُ الرَّجُلُ عَلَى بَيْعِ أَخِيهِ حَتَّى يَبْتَاعَ أَوْ يَذَرَ ‏"‏ ‏.‏\hadithno{4504}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that the Messenger of Allah said:"Do not urge someone to cancel a sale he has already agreed upon so as to sell him your own goods, unless he bys or changes his mind}}
\hadithdefcmd{nasai}{4505}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ النَّجْشِ ‏.‏\hadithno{4505}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that:the Prophet forbade artificially inflating prices}}
\hadithdefcmd{nasai}{4506}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا بِشْرُ بْنُ شُعَيْبٍ، قَالَ حَدَّثَنَا أَبِي، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَبُو سَلَمَةَ، وَسَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَبِيعُ الرَّجُلُ عَلَى بَيْعِ أَخِيهِ وَلاَ يَبِيعُ حَاضِرٌ لِبَادٍ وَلاَ تَنَاجَشُوا وَلاَ يَزِيدُ الرَّجُلُ عَلَى بَيْعِ أَخِيهِ وَلاَ تَسْأَلِ الْمَرْأَةُ طَلاَقَ الأُخْرَى لِتَكْتَفِئَ مَا فِي إِنَائِهَا ‏"‏ ‏.‏\hadithno{4506}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Abu Hurairah said:"I heard the messenger of Allah say: "No man should urge anyone to cancel a sale he has already agreed upon with his brother so as to sell him his own goods; no town-dweller should sell for a desert-dweller; do not artificially inflate prices; no man should outbid his brother; and no woman should ask for her sister (in faith) to be divorced so as to turn over what is in her vessel (deprive her of her share of maintenance)}}
\hadithdefcmd{nasai}{4507}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبِيعُ حَاضِرٌ لِبَادٍ وَلاَ تَنَاجَشُوا وَلاَ يَزِيدُ الرَّجُلُ عَلَى بَيْعِ أَخِيهِ وَلاَ تَسْأَلُ الْمَرْأَةُ طَلاَقَ أُخْتِهَا لِتَسْتَكْفِئَ بِهِ مَا فِي صَحْفَتِهَا ‏"‏ ‏.‏\hadithno{4507}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Prophet said:"No tow-dweller should sell for desert-dweller, no man should outbid his brother; and no woman should ask for her sister (in faith) to be divorced so as to turn over what is in her bowl (deprive her of her share of maintenance)}}
\hadithdefcmd{nasai}{4508}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، وَعِيسَى بْنُ يُونُسَ، قَالاَ حَدَّثَنَا الأَخْضَرُ بْنُ عَجْلاَنَ، عَنْ أَبِي بَكْرٍ الْحَنَفِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَاعَ قَدَحًا وَحِلْسًا فِيمَنْ يَزِيدُ ‏.‏\hadithno{4508}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Anas bin Malik that:the Messenger of Allah sold a drinking bowl and a blanket (for a horse of camel) to the highest bidder}}
\hadithdefcmd{nasai}{4509}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حِبَّانَ، وَأَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُلاَمَسَةِ وَالْمُنَابَذَةِ ‏.‏\hadithno{4509}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that:the Messenger of Allah forbade Mulamash and Munabadha}}
\hadithdefcmd{nasai}{4510}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ بْنِ إِسْحَاقَ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَامِرُ بْنُ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُلاَمَسَةِ لَمْسِ الثَّوْبِ لاَ يَنْظُرُ إِلَيْهِ وَعَنِ الْمُنَابَذَةِ وَهِيَ طَرْحُ الرَّجُلِ ثَوْبَهُ إِلَى الرَّجُلِ بِالْبَيْعِ قَبْلَ أَنْ يُقَلِّبَهُ أَوْ يَنْظُرَ إِلَيْهِ ‏.‏\hadithno{4510}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Sa' eed Al- Khudri that:the Messenger of Allah forbade Mulamasah, which means touching a garment without looking at it, and Munabadha, which is where one man sells his garment to another man, by throwing it to him, without him checking it or looking at it}}
\hadithdefcmd{nasai}{4511}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُلاَمَسَةِ وَالْمُنَابَذَةِ فِي الْبَيْعِ ‏.‏\hadithno{4511}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa'eed al-Khudri said:"The Messenger of Allah forbade two kinds of transactions: Mulamash and Munabddhah}}
\hadithdefcmd{nasai}{4512}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ الْمَرْوَزِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنِ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعَتَيْنِ عَنِ الْمُلاَمَسَةِ وَالْمُنَابَذَةِ ‏.‏\hadithno{4512}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The messenger of Allah forbade two kinds of transactions: Mulamash and Mumabadha}}
\hadithdefcmd{nasai}{4513}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُصَفَّى بْنِ بُهْلُولٍ، عَنْ مُحَمَّدِ بْنِ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، قَالَ سَمِعْتُ سَعِيدًا، يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُلاَمَسَةِ وَالْمُنَابَذَةِ وَالْمُلاَمَسَةُ أَنْ يَتَبَايَعَ الرَّجُلاَنِ بِالثَّوْبَيْنِ تَحْتَ اللَّيْلِ يَلْمِسُ كُلُّ رَجُلٍ مِنْهُمَا ثَوْبَ صَاحِبِهِ بِيَدِهِ وَالْمُنَابَذَةُ أَنْ يَنْبِذَ الرَّجُلُ إِلَى الرَّجُلِ الثَّوْبَ وَيَنْبُذَ الآخَرُ إِلَيْهِ الثَّوْبَ فَيَتَبَايَعَا عَلَى ذَلِكَ ‏.‏\hadithno{4513}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{<Abu Hurairah said:"The Messenger of Allah forbade Munabadhah and Mulamash. Mulamasah is when two men trade garments with each other under cover of night, each man touching the garment of the other with his hand> and Munabadhah is when one man throws a garment to another and the other throws a garment to him, and they trade them with each other in that manner}}
\hadithdefcmd{nasai}{4514}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ عَامِرَ بْنَ سَعْدٍ، أَخْبَرَهُ أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ رَضِيَ اللَّهُ عَنْهُ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُلاَمَسَةِ وَالْمُلاَمَسَةُ لَمْسُ الثَّوْبِ لاَ يَنْظُرُ إِلَيْهِ وَعَنِ الْمُنَابَذَةِ وَالْمُنَابَذَةُ طَرْحُ الرَّجُلِ ثَوْبَهُ إِلَى الرَّجُلِ قَبْلَ أَنْ يُقَلِّبَهُ ‏.‏\hadithno{4514}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa 'eed A-Khudri said:"The Messenger of Allah forbade Mulamasah, which means touching a garment without looking at it; (and he forbade) Munabadhah which is where one man sells his garment to another man by throwing it to him, without him checking it or looking at it}}
\hadithdefcmd{nasai}{4515}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ لُبْسَتَيْنِ وَعَنْ بَيْعَتَيْنِ أَمَّا الْبَيْعَتَانِ فَالْمُلاَمَسَةُ وَالْمُنَابَذَةُ وَالْمُنَابَذَةُ أَنْ يَقُولَ إِذَا نَبَذْتُ هَذَا الثَّوْبَ فَقَدْ وَجَبَ يَعْنِي الْبَيْعَ وَالْمُلاَمَسَةُ أَنْ يَمَسَّهُ بِيَدِهِ وَلاَ يَنْشُرَهُ وَلاَ يُقَلِّبَهُ إِذَا مَسَّهُ فَقَدْ وَجَبَ الْبَيْعُ ‏.‏\hadithno{4515}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Sa'eed Al-Khudri said:"The Messenger of Allah forbade two kinds of garments and two kinds of transactions. As for the two kinds of transactions, they are Mulamash and Munabadhaha. Munabadha is when a man says, 'I throw this garment, and the transaction becomes binding, and Mulamasah is when a man touches it with his had, without spreading it out and checking it, and once he touches it, the transaction becomes binding}}
\hadithdefcmd{nasai}{4516}{أَخْبَرَنَا هَارُونُ بْنُ زَيْدِ بْنِ أَبِي الزَّرْقَاءِ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا جَعْفَرُ بْنُ بُرْقَانَ، قَالَ بَلَغَنِي عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ لُبْسَتَيْنِ وَنَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعَتَيْنِ عَنِ الْمُنَابَذَةِ وَالْمُلاَمَسَةِ وَهِيَ بُيُوعٌ كَانُوا يَتَبَايَعُونَ بِهَا فِي الْجَاهِلِيَّةِ ‏.‏\hadithno{4516}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Salim that his father said:"The Messenger of Allah forbade two kinds of garments, and he forbade two kinds of transactions for us: Munabadhah and Mulamasah, which are kinds of transactions which were common during the Jahiliyyah}}
\hadithdefcmd{nasai}{4517}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ عُبَيْدَ اللَّهِ، عَنْ خُبَيْبٍ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنْ بَيْعَتَيْنِ أَمَّا الْبَيْعَتَانِ فَالْمُنَابَذَةُ وَالْمُلاَمَسَةُ وَزَعَمَ أَنَّ الْمُلاَمَسَةَ أَنْ يَقُولَ الرَّجُلُ لِلرَّجُلِ أَبِيعُكَ ثَوْبِي بِثَوْبِكَ وَلاَ يَنْظُرَ وَاحِدٌ مِنْهُمَا إِلَى ثَوْبِ الآخَرِ وَلَكِنْ يَلْمِسُهُ لَمْسًا وَأَمَّا الْمُنَابَذَةُ أَنْ يَقُولَ أَنْبُذُ مَا مَعِي وَتَنْبُذُ مَا مَعَكَ لِيَشْتَرِيَ أَحَدُهُمَا مِنَ الآخَرِ وَلاَ يَدْرِي كُلُّ وَاحِدٍ مِنْهُمَا كَمْ مَعَ الآخَرِ وَنَحْوًا مِنْ هَذَا الْوَصْفِ ‏.‏\hadithno{4517}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Hafs bin 'Asim, from Abu Hurairah that the Prophet forbade two kids of transactions:Munabadhah and Mulamasha. And he said that Mulamasah means when one man says to another: "I will sell you my garment for your garment," and neither of them looks at the garment of the others, rather he just touches it. And Munabadhah is when he says: "I will throw what I have and you throw what you have," so that they buy from one another, and neither of them knows how much the other has, and so on}}
\hadithdefcmd{nasai}{4518}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الْحَصَاةِ وَعَنْ بَيْعِ الْغَرَرِ ‏.‏\hadithno{4518}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah forbade Gharar transaction and Hasah transactions}}
\hadithdefcmd{nasai}{4519}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَبِيعُوا الثَّمَرَ حَتَّى يَبْدُوَ صَلاَحُهُ ‏"‏ ‏.‏ نَهَى الْبَائِعَ وَالْمُشْتَرِيَ ‏.‏\hadithno{4519}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Uar that the Messenger of Allah said:"Do not sell fruits until their condition is known. And he forbade (both) the seller and the purchaser (to engage in such a transaction)}}
\hadithdefcmd{nasai}{4520}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثَّمَرِ حَتَّى يَبْدُوَ صَلاَحُهُ ‏.‏\hadithno{4520}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salim, from his father, that:the Messenger of Allah forbade selling fruits until their condition is known}}
\hadithdefcmd{nasai}{4521}{أَخْبَرَنِي يُونُسُ بْنُ عَبْدِ الأَعْلَى، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي سَعِيدٌ، وَأَبُو سَلَمَةَ أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَبِيعُوا الثَّمَرَ حَتَّى يَبْدُوَ صَلاَحُهُ وَلاَ تَبْتَاعُوا الثَّمَرَ بِالتَّمْرِ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ عَنْ أَبِيهِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ مِثْلِهِ سَوَاءً ‏.‏\hadithno{4521}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Do not sell fruits until their condition is known, and do not sell fresh dates (still on the tree) for dried dates."' Ibn Shihab said: "Salim bin 'Abdullah narrated to me, from his father: 'That Allah's Messenger forbade from ..." similarly}}
\hadithdefcmd{nasai}{4522}{أَخْبَرَنَا عَبْدُ الْحَمِيدِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مَخْلَدُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا حَنْظَلَةُ، قَالَ سَمِعْتُ طَاوُسًا، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ قَامَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تَبِيعُوا الثَّمَرَ حَتَّى يَبْدُوَ صَلاَحُهُ ‏"‏ ‏.‏\hadithno{4522}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abdullah bin 'Umar said:"The Messenger of Allah stood up among us ad said: 'Do not sell fruits until their condition is known}}
\hadithdefcmd{nasai}{4523}{حَدَّثَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى عَنِ الْمُخَابَرَةِ وَالْمُزَابَنَةِ وَالْمُحَاقَلَةِ وَأَنْ يُبَاعَ الثَّمَرُ حَتَّى يَبْدُوَ صَلاَحُهُ وَأَنْ لاَ يُبَاعَ إِلاَّ بِالدَّنَانِيرِ وَالدَّرَاهِمِ وَرَخَّصَ فِي الْعَرَايَا ‏.‏\hadithno{4523}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Ata:"I heard Jabir bin 'Abdullah (narrate) from the Prophet that he forbade Mukhabarah, Muzabanah and Muhaqalah, an (he forbade) selling fruits until their condition is known, an that they should only sold for Dinars and Dirhams, but he granted a concession regarding the sale of Araya:}}
\hadithdefcmd{nasai}{4524}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا الْمُفَضَّلُ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، وَأَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْمُخَابَرَةِ وَالْمُزَابَنَةِ وَالْمُحَاقَلَةِ وَبَيْعِ الثَّمَرِ حَتَّى يُطْعَمَ إِلاَّ الْعَرَايَا ‏.‏\hadithno{4524}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir that:the Prophet forbade Mukhabarah, Muzabanah and Muhaqalah, and selling fruits until they were fit to eat, except in the case f 'Aray}}
\hadithdefcmd{nasai}{4525}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ النَّخْلِ حَتَّى يُطْعَمَ ‏.‏\hadithno{4525}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"the Messenger of Allah forbade selling the fruit of date palms until they are fit to eat}}
\hadithdefcmd{nasai}{4526}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثِّمَارِ حَتَّى تُزْهِيَ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ وَمَا تُزْهِيَ قَالَ ‏"‏ حَتَّى تَحْمَرَّ ‏"‏ ‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرَأَيْتَ إِنْ مَنَعَ اللَّهُ الثَّمَرَةَ فَبِمَ يَأْخُذُ أَحَدُكُمْ مَالَ أَخِيهِ ‏"‏ ‏.‏\hadithno{4526}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that:the Messenger of Allah forbade selling fruits before they ripen. It was said: "O Messenger of Allah what does ripen mean?" he said: 'when they turn red." And the Messenger of Allah said: "What do you think if Allah withholds the fruits (causes it not to ripen), why would any one of you take his brother's wealth?}}
\hadithdefcmd{nasai}{4527}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ بِعْتَ مِنْ أَخِيكَ ثَمَرًا فَأَصَابَتْهُ جَائِحَةٌ فَلاَ يَحِلُّ لَكَ أَنْ تَأْخُذَ مِنْهُ شَيْئًا بِمَ تَأْخُذُ مَالَ أَخِيكَ بِغَيْرِ حَقٍّ ‏"‏ ‏.‏\hadithno{4527}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir said:"The Messenger of Allah said: "If you sell fruits to your brother then the crop fails, it is not permissible for you it takes anything from him. Why would you take the wealth of your brother unlawfully?}}
\hadithdefcmd{nasai}{4528}{أَخْبَرَنَا هِشَامُ بْنُ عَمَّارٍ، قَالَ حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، قَالَ حَدَّثَنَا ثَوْرُ بْنُ يَزِيدَ، أَنَّهُ سَمِعَ ابْنَ جُرَيْجٍ، يُحَدِّثُ عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ بَاعَ ثَمَرًا فَأَصَابَتْهُ جَائِحَةٌ فَلاَ يَأْخُذْ مِنْ أَخِيهِ - وَذَكَرَ شَيْئًا - عَلَى مَا يَأْكُلُ أَحَدُكُمْ مَالَ أَخِيهِ الْمُسْلِمِ ‏"‏ ‏.‏\hadithno{4528}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir bin 'Abdullah that the Messenger of Allah said:"Whoever sells fruit then his crop fails, he should not take (anything) from his brother." (And he said something along the lines of) "Why would anyone of you consume the wealth of his Muslim brother?}}
\hadithdefcmd{nasai}{4529}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ حُمَيْدٍ، - وَهُوَ الأَعْرَجُ - عَنْ سُلَيْمَانَ بْنِ عَتِيقٍ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَضَعَ الْجَوَائِحَ ‏.‏\hadithno{4529}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that:the Prophet annulled transaction in the event of crop faioure}}
\hadithdefcmd{nasai}{4530}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ بُكَيْرٍ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ أُصِيبَ رَجُلٌ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ثِمَارٍ ابْتَاعَهَا فَكَثُرَ دَيْنُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَصَدَّقُوا عَلَيْهِ ‏"‏ ‏.‏ فَتَصَدَّقَ النَّاسُ عَلَيْهِ فَلَمْ يَبْلُغْ ذَلِكَ وَفَاءَ دَيْنِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خُذُوا مَا وَجَدْتُمْ وَلَيْسَ لَكُمْ إِلاَّ ذَلِكَ ‏"‏ ‏.‏\hadithno{4530}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{it was narrated that Abu Sa' eed Al-Khudri said:"At the time of the Messenger of Allah, a ma suffered loss of some fruit that he had purchased, and his debts increased. The Messenger of Allah said: 'give him charity.' So the people gave him charity, but that was not enough to pay of his debts. The Messenger of Allah said: "Take what you find but you have no right to or than that}}
\hadithdefcmd{nasai}{4531}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ حُمَيْدٍ الأَعْرَجِ، عَنْ سُلَيْمَانَ بْنِ عَتِيكٍ، - قَالَ قُتَيْبَةُ عَتِيكٌ بِالْكَافِ وَالصَّوَابُ عَتِيقٌ - عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثَّمَرِ سِنِينَ ‏.‏\hadithno{4531}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that:the Prophet forbade selling the harvest for a number of years (in advance)}}
\hadithdefcmd{nasai}{4532}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثَّمَرِ بِالتَّمْرِ ‏.‏ وَقَالَ ابْنُ عُمَرَ حَدَّثَنِي زَيْدُ بْنُ ثَابِتٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي الْعَرَايَا ‏.‏\hadithno{4532}\hadithgrade{Abu Ghuddah: -; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salim, from his father, that:the Prophet forbade selling fresh dates still on the tree for dried dates. Ibn 'Umar said: "Azid bin Thabit narrated to me, that Allah's Messenger permitted that in the case o 'Ayaya}}
\hadithdefcmd{nasai}{4533}{أَخْبَرَنِي زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُزَابَنَةِ وَالْمُزَابَنَةُ أَنْ يُبَاعَ مَا فِي رُءُوسِ النَّخْلِ بِتَمْرٍ بِكَيْلٍ مُسَمًّى إِنْ زَادَ لِي وَإِنْ نَقَصَ فَعَلَىَّ ‏.‏\hadithno{4533}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Umar that:the Messenger of Allah forbade Muzabanah. Ad Muzabanah is when what is art the tops of the trees is sold for a certain amount f dried dates; if there are more then I gain, and if there are less the I lose}}
\hadithdefcmd{nasai}{4534}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُزَابَنَةِ وَالْمُزَابَنَةُ بَيْعُ الثَّمَرِ بِالتَّمْرِ كَيْلاً وَبَيْعُ الْكَرْمِ بِالزَّبِيبِ كَيْلاً ‏.‏\hadithno{4534}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that:the messenger of Allah forbade Muzabana, and Muzabanah means selling fresh dates still on tree for dried dates by measure, and selling fresh grapes for raisins by measure}}
\hadithdefcmd{nasai}{4535}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ طَارِقٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ ‏.‏\hadithno{4535}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Rafi bin Khadij said:"the Messenger of Allah forbade Muhaqalah and Muzabana."(Hasan)}}
\hadithdefcmd{nasai}{4536}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ حَدَّثَنِي زَيْدُ بْنُ ثَابِتٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي الْعَرَايَا ‏.‏\hadithno{4536}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Salim that his father said:"Zaid bin Thabit told me that the Messenger of Allah granted a concession regarding the sale of 'Arays}}
\hadithdefcmd{nasai}{4537}{قَالَ الْحَارِثُ بْنُ مِسْكِينٍ قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي خَارِجَةُ بْنُ زَيْدِ بْنِ ثَابِتٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي الْعَرَايَا بِالتَّمْرِ وَالرُّطَبِ ‏.‏\hadithno{4537}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Kharijah bin Zaid bin Thabit narrated from his father that:the Messenger of Allah granted a concession regarding 'Araya sales regarding dried dates and fresh dates}}
\hadithdefcmd{nasai}{4538}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنْ عَبْدِ اللَّهِ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي بَيْعِ الْعَرَايَا تُبَاعُ بِخِرْصِهَا ‏.‏\hadithno{4538}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Zaid bin Thabit that:the Messenger of Allah granted a concession allowing Araya sales by estimation}}
\hadithdefcmd{nasai}{4539}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ حَدَّثَنِي زَيْدُ بْنُ ثَابِتٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي بَيْعِ الْعَرِيَّةِ بِخِرْصِهَا تَمْرًا ‏.‏\hadithno{4539}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Zaid bin Thabit narrated that:the Messenger of Allah granted a concession allowing 'Araya sales for dried dates by estimation}}
\hadithdefcmd{nasai}{4540}{أَخْبَرَنَا أَبُو دَاوُدَ، قَالَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَالِمًا، أَخْبَرَهُ أَنَّهُ، سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ إِنَّ زَيْدَ بْنَ ثَابِتٍ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَخَّصَ فِي بَيْعِ الْعَرَايَا بِالرُّطَبِ وَبِالتَّمْرِ وَلَمْ يُرَخِّصْ فِي غَيْرِ ذَلِكَ ‏.‏\hadithno{4540}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated the Zaid bin Thabit sadi:"The Messenger of Allah granted a concession allowing 'Araya sales for fresh dates and for dried dates, but he did not allow anything other than that}}
\hadithdefcmd{nasai}{4541}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لَهُ - عَنْ عَبْدِ الرَّحْمَنِ، عَنْ مَالِكٍ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ أَبِي سُفْيَانَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَخَّصَ فِي الْعَرَايَا أَنْ تُبَاعَ بِخَرْصِهَا فِي خَمْسَةِ أَوْسُقٍ أَوْ مَا دُونَ خَمْسَةِ أَوْسُقٍ ‏.‏\hadithno{4541}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Au Hurairah that the prophet granted a concession allowing estimation for 'Ararya sales, so long as they were five Wasq or less then that}}
\hadithdefcmd{nasai}{4542}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ يَحْيَى، عَنْ بُشَيْرِ بْنِ يَسَارٍ، عَنْ سَهْلِ بْنِ أَبِي حَثَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الثَّمَرِ حَتَّى يَبْدُوَ صَلاَحُهُ وَرَخَّصَ فِي الْعَرَايَا أَنْ تُبَاعَ بِخَرْصِهَا يَأْكُلُهَا أَهْلُهَا رُطَبًا ‏.‏\hadithno{4542}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Sahl bin Abi Hathamah that the Prophet forbade selling fruits before their condition was known, but he granted a concession allowing 'Araya sales by estimate, so its people could eat fresh dates}}
\hadithdefcmd{nasai}{4543}{أَخْبَرَنَا الْحُسَيْنُ بْنُ عِيسَى، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ حَدَّثَنِي الْوَلِيدُ بْنُ كَثِيرٍ، قَالَ أَخْبَرَنِي بُشَيْرُ بْنُ يَسَارٍ، أَنَّ رَافِعَ بْنَ خَدِيجٍ، وَسَهْلَ بْنَ أَبِي حَثْمَةَ، حَدَّثَاهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُزَابَنَةِ بَيْعُ الثَّمَرِ بِالتَّمْرِ إِلاَّ لأَصْحَابِ الْعَرَايَا فَإِنَّهُ أَذِنَ لَهُمْ ‏.‏\hadithno{4543}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Rafi bin Khadij and Sahl Bi Abi Hathamah narrated that the Messenger of Allah forbade Muzabanah, which means selling fresh dates still on the tree for dried dates, except in cases of 'Araya, for which he gave permission. (Sahih)}}
\hadithdefcmd{nasai}{4544}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى، عَنْ بُشَيْرِ بْنِ يَسَارٍ، عَنْ أَصْحَابِ، رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُمْ قَالُوا رَخَّصَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَيْعِ الْعَرَايَا بِخَرْصِهَا ‏.‏\hadithno{4544}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Bashir bin yasar that the Companions of the Messenger of Allah said:"The Messenger of Allah granted a concession allowing 'Araya sales by estimate}}
\hadithdefcmd{nasai}{4545}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا مَالِكٌ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ يَزِيدَ، عَنْ زَيْدِ بْنِ عَيَّاشٍ، عَنْ سَعْدٍ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ التَّمْرِ بِالرُّطَبِ فَقَالَ لِمَنْ حَوْلَهُ ‏ "‏ أَيَنْقُصُ الرُّطَبُ إِذَا يَبِسَ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَنَهَى عَنْهُ ‏.‏\hadithno{4545}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{it was narrated that Sa'd said:"The Messenger of Allah was asked about (buying) fresh dates with dried dates, and he said to those who were around him: 'Will fresh dates decrease (in weight or volume) when they dry out?" they said Yes,' so he forbade that}}
\hadithdefcmd{nasai}{4546}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَلِيِّ بْنِ مَيْمُونٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ الْفِرْيَابِيُّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ زَيْدٍ، عَنْ سَعْدِ بْنِ مَالِكٍ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الرُّطَبِ بِالتَّمْرِ فَقَالَ ‏ "‏ أَيَنْقُصُ إِذَا يَبِسَ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَنَهَى عَنْهُ ‏.‏\hadithno{4546}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Sa 'd bin Malik said:"The Messenger of Allah was asked about (buying) said; 'Will fresh dates decrees (in weight or volume) when they dry out? 'They said 'yes so he forbade that}}
\hadithdefcmd{nasai}{4547}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الصُّبْرَةِ مِنَ التَّمْرِ لاَ يُعْلَمُ مَكِيلُهَا بِالْكَيْلِ الْمُسَمَّى مِنَ التَّمْرِ ‏.‏\hadithno{4547}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir bin 'Abdullahsaid:"The Messenger of Allah forbade selling a heap of dried dates whose volume is unknown for known volume of dried dates}}
\hadithdefcmd{nasai}{4548}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تُبَاعُ الصُّبْرَةُ مِنَ الطَّعَامِ بِالصُّبْرَةِ مِنَ الطَّعَامِ وَلاَ الصُّبْرَةُ مِنَ الطَّعَامِ بِالْكَيْلِ الْمُسَمَّى مِنَ الطَّعَامِ ‏"‏ ‏.‏\hadithno{4548}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Zubair narrated that he heard Jabir bin 'Abdullah say:"The Prophet said: ' A heap of grain should not be sold for a heap of grain, or for a heap of grain of known measure}}
\hadithdefcmd{nasai}{4549}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُزَابَنَةِ أَنْ يَبِيعَ ثَمَرَ حَائِطِهِ وَإِنْ كَانَ نَخْلاً بِتَمْرٍ كَيْلاً وَإِنْ كَانَ كَرْمًا أَنْ يَبِيعَهُ بِزَبِيبٍ كَيْلاً وَإِنْ كَانَ زَرْعًا أَنْ يَبِيعَهُ بِكَيْلِ طَعَامٍ نَهَى عَنْ ذَلِكَ كُلِّهِ ‏.‏\hadithno{4549}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'umar said:"The Messenger of Allah forbade Muzabanah, which refers to when a man sells the dates of his grove while they are still on the trees, for a measure of dry on the tree, for a measure of dry dates, estimating the amount( of dates on the trees). Or, if it is grapes, he sells them when they are still on the vines, for a measure of raisins, estimating the amount (of grapes on the vines). Or if it is grain in the field, he sells it for grain that has been harvested, estimating the amount (of grain in the fields). He forbade all of that}}
\hadithdefcmd{nasai}{4550}{حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا مَخْلَدُ بْنُ يَزِيدَ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُخَابَرَةِ وَالْمُزَابَنَةِ وَالْمُحَاقَلَةِ وَعَنْ بَيْعِ الثَّمَرِ قَبْلَ أَنْ يُطْعَمَ وَعَنْ بَيْعِ ذَلِكَ إِلاَّ بِالدَّنَانِيرِ وَالدَّرَاهِمِ ‏.‏\hadithno{4550}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir that:the Messenger of Allah forbade Mukhabarah, Muzabanah and Muhaqalah, and selling dates before they arte fit or eating, and selling them for anything except Dinars and Dirhams}}
\hadithdefcmd{nasai}{4551}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ النَّخْلَةِ حَتَّى تَزْهُوَ وَعَنِ السُّنْبُلِ حَتَّى يَبْيَضَّ وَيَأْمَنَ الْعَاهَةَ نَهَى الْبَائِعَ وَالْمُشْتَرِيَ ‏.‏\hadithno{4551}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'umar that:the Messenger of Allah forbade selling dates in the trees before they ripen or selling ears of corn before the grains become visible and there is no fear of blight. He forbade that to the seller ad the buyer}}
\hadithdefcmd{nasai}{4552}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنِ الأَعْمَشِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ أَبِي صَالِحٍ، أَنَّ رَجُلاً، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَهُ قَالَ يَا رَسُولَ اللَّهِ إِنَّا لاَ نَجِدُ الصَّيْحَانِيَّ وَلاَ الْعِذْقَ بِجَمْعِ التَّمْرِ حَتَّى نَزِيدَهُمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بِعْهُ بِالْوَرِقِ ثُمَّ اشْتَرِ بِهِ ‏"‏ ‏.‏\hadithno{4552}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrate from Abu Salih that:a man form among the companions of the Prophet told him, he said: "O Messenger of Allah we cannot buy Saihani dates or 'idhq dates for the same amount of mixed dates (which are of inferior quality). Should we increase (the amount we give in payment for the better quality dates)?" The messenger of Allah said: "Sell them for silver them buy with it}}
\hadithdefcmd{nasai}{4553}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ عَبْدِ الْمَجِيدِ بْنِ سُهَيْلٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَعَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَعْمَلَ رَجُلاً عَلَى خَيْبَرَ فَجَاءَ بِتَمْرٍ جَنِيبٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَكُلُّ تَمْرِ خَيْبَرَ هَكَذَا ‏"‏ ‏.‏ قَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ إِنَّا لَنَأْخُذُ الصَّاعَ مِنْ هَذَا بِصَاعَيْنِ وَالصَّاعَيْنِ بِالثَّلاَثِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَفْعَلْ بِعِ الْجَمْعَ بِالدَّرَاهِمِ ثُمَّ ابْتَعْ بِالدَّرَاهِمِ جَنِيبًا ‏"‏ ‏.‏\hadithno{4553}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Sa'eed Al'Khudri and Abu Hurairah that:the Messenger of Allah appointed a man in charge of kharibar and he brought some Janib dates. The messenger of Allah said; "Are all the dates if khaibar like this?" He said: "No (by Allah, O Messenger of Allah) we take a Sa of these for two for three Sas (of other types of dates)." The messenger of Allah said: "do not do that Sell the mixed dates for Dirhams then buy the Janib dates with the Dirhams}}
\hadithdefcmd{nasai}{4554}{أَخْبَرَنَا نَصْرُ بْنُ عَلِيٍّ، وَإِسْمَاعِيلُ بْنُ مَسْعُودٍ، - وَاللَّفْظُ لَهُ - عَنْ خَالِدٍ، قَالَ حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِتَمْرٍ رَيَّانٍ - وَكَانَ تَمْرُ رَسُولِ اللَّهِ صلى الله عليه وسلم بَعْلاً فِيهِ يُبْسٌ - فَقَالَ ‏"‏ أَنَّى لَكُمْ هَذَا ‏"‏ ‏.‏ قَالُوا ابْتَعْنَاهُ صَاعًا بِصَاعَيْنِ مِنْ تَمْرِنَا فَقَالَ ‏"‏ لاَ تَفْعَلْ فَإِنَّ هَذَا لاَ يَصِحُّ وَلَكِنْ بِعْ تَمْرَكَ وَاشْتَرِ مِنْ هَذَا حَاجَتَكَ ‏"‏ ‏.‏\hadithno{4554}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Sa'eed Al-udri that:some dates from trees that were irrigated artificially were brought to the Messenger of Allah and the dates of the messenger of Allah were dates from trees that were nourished by their roots. He said: "Where did you get these from?" They said: "We bought a Sa of them for two Sa s of our dates: He said: "Do not do that, for this is not right. Rather sell your dates and but what you need of these}}
\hadithdefcmd{nasai}{4555}{حَدَّثَنِي إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنَا أَبُو سَعِيدٍ الْخُدْرِيُّ، قَالَ كُنَّا نُرْزَقُ تَمْرَ الْجَمْعِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَنَبِيعُ الصَّاعَيْنِ بِالصَّاعِ فَبَلَغَ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ صَاعَىْ تَمْرٍ بِصَاعٍ وَلاَ صَاعَىْ حِنْطَةٍ بِصَاعٍ وَلاَ دِرْهَمًا بِدِرْهَمَيْنِ ‏"‏ ‏.‏\hadithno{4555}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{(A Abu Sa 'eed al- Khudri said:"We used to be given mixed dates during the time of the Messenger of Allah and we would sell two Sa s for one Sa News of that reached the Messenger of Allah and he said Do not sell) two Sa s of dates for a Sa, or two Sa s of wheat for s Sa or a Dirham for two Dirhams}}
\hadithdefcmd{nasai}{4556}{أَخْبَرَنَا هِشَامُ بْنُ عَمَّارٍ، عَنْ يَحْيَى، - وَهُوَ ابْنُ حَمْزَةَ - قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى، قَالَ حَدَّثَنِي أَبُو سَلَمَةَ، قَالَ حَدَّثَنِي أَبُو سَعِيدٍ، قَالَ كُنَّا نَبِيعُ تَمْرَ الْجَمْعِ صَاعَيْنِ بِصَاعٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ صَاعَىْ تَمْرٍ بِصَاعٍ وَلاَ صَاعَىْ حِنْطَةٍ بِصَاعٍ وَلاَ دِرْهَمَيْنِ بِدِرْهَمٍ ‏"‏ ‏.‏\hadithno{4556}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Sa' eed said:"We used to sell two Sa s of mixed dates for a Sa but the Prophet said (Do not sell) two Sa s dates for a Sa or two Sa s wheat or a Sa or two Dirhams for a Dirham}}
\hadithdefcmd{nasai}{4557}{أَخْبَرَنَا هِشَامُ بْنُ عَمَّارٍ، عَنْ يَحْيَى، - وَهُوَ ابْنُ حَمْزَةَ - قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنِي يَحْيَى، قَالَ حَدَّثَنِي عُقْبَةُ بْنُ عَبْدِ الْغَافِرِ، قَالَ حَدَّثَنِي أَبُو سَعِيدٍ، قَالَ أَتَى بِلاَلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم بِتَمْرٍ بَرْنِيٍّ فَقَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ قَالَ اشْتَرَيْتُهُ صَاعًا بِصَاعَيْنِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَوِّهْ عَيْنُ الرِّبَا لاَ تَقْرَبْهُ ‏"‏ ‏.‏\hadithno{4557}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Saeed said:"Bilal brought some Bami dates to the Messenger of Allah and he said: 'What is this? 'He said: 'I bought a Sa of them for two Sas. The Messenger of Allah said: "O! The essence of Riba, do not approach it}}
\hadithdefcmd{nasai}{4558}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ مَالِكِ بْنِ أَوْسِ بْنِ الْحَدَثَانِ، أَنَّهُ سَمِعَ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الذَّهَبُ بِالْوَرِقِ رِبًا إِلاَّ هَاءَ وَهَاءَ وَالتَّمْرُ بِالتَّمْرِ رِبًا إِلاَّ هَاءَ وَهَاءَ وَالْبُرُّ بِالْبُرِّ رِبًا إِلاَّ هَاءَ وَهَاءَ وَالشَّعِيرُ بِالشَّعِيرِ رِبًا إِلاَّ هَاءَ وَ هَاءَ ‏"‏ ‏.‏\hadithno{4558}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Umar bin Al-Khattab said:"The Messenger of Allah said: '(Exchanging) gold for silver is Riba unless it is done on the spot. (Exchanging) dates for dates is Riba unless it is done on the spot. (Exchanging) wheat for wheat is Riba unless it is done on the spot. (Exchanging) barley is Riba unless it is done on the spot}}
\hadithdefcmd{nasai}{4559}{أَخْبَرَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ التَّمْرُ بِالتَّمْرِ وَالْحِنْطَةُ بِالْحِنْطَةِ وَالشَّعِيرُ بِالشَّعِيرِ وَالْمِلْحُ بِالْمِلْحِ يَدًا بِيَدٍ فَمَنْ زَادَ أَوِ ازْدَادَ فَقَدْ أَرْبَى إِلاَّ مَا اخْتَلَفَتْ أَلْوَانُهُ ‏"‏ ‏.‏\hadithno{4559}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah said:"The Messenger of Allah said: 'Dates for dates, wheat for wheat, barley for barley, salt for salt, exchanged hand to hand. Whoever gives more or takes more has engaged in Riba unless they are of different types}}
\hadithdefcmd{nasai}{4560}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، قَالَ حَدَّثَنَا يَزِيدُ، قَالَ حَدَّثَنَا سَلَمَةُ، - وَهُوَ ابْنُ عَلْقَمَةَ - عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ مُسْلِمِ بْنِ يَسَارٍ، وَعَبْدِ اللَّهِ بْنِ عَتِيكٍ، قَالاَ جَمَعَ الْمَنْزِلُ بَيْنَ عُبَادَةَ بْنِ الصَّامِتِ وَمُعَاوِيَةَ حَدَّثَهُمْ عُبَادَةُ، قَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الذَّهَبِ بِالذَّهَبِ وَالْوَرِقِ بِالْوَرِقِ وَالْبُرِّ بِالْبُرِّ وَالشَّعِيرِ بِالشَّعِيرِ وَالتَّمْرِ بِالتَّمْرِ - قَالَ أَحَدُهُمَا وَالْمِلْحِ بِالْمِلْحِ وَلَمْ يَقُلْهُ الآخَرُ - إِلاَّ مِثْلاً بِمِثْلٍ يَدًا بِيَدٍ وَأَمَرَنَا أَنْ نَبِيعَ الذَّهَبَ بِالْوَرِقِ وَالْوَرِقَ بِالذَّهَبِ وَالْبُرَّ بِالشِّعِيرِ وَالشَّعِيرَ بِالْبُرِّ يَدًا بِيَدٍ كَيْفَ شِئْنَا قَالَ أَحَدُهُمَا فَمَنْ زَادَ أَوِ ازْدَادَ فَقَدْ أَرْبَى ‏.‏\hadithno{4560}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Muslim bin Yasar and 'Abdullah bin 'Atik said:"Ubadah bin As-Samit and Muawiyah met at a stopping place on the road. 'Ubadah told them: 'The Messenger of Allah forbade selling gold for gold, silver for silver, wheat for wheat, barley for barley, dates for dates"'- one of them said: 'salt for salt,"' but the other did not say it-"unless it was like for like, hand to hand. And he commanded us to sell gold for silver and silver for gold, and wheat for barley and barley for wheat, and to hand, however we wanted."' And one of them said: "Whoever gives more or ask for more has engaged in Riba}}
\hadithdefcmd{nasai}{4561}{أَخْبَرَنَا الْمُؤَمَّلُ بْنُ هِشَامٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ عُلَيَّةَ - عَنْ سَلَمَةَ بْنِ عَلْقَمَةَ، عَنِ ابْنِ سِيرِينَ، قَالَ حَدَّثَنِي مُسْلِمُ بْنُ يَسَارٍ، وَعَبْدُ اللَّهِ بْنُ عُبَيْدٍ، - وَقَدْ كَانَ يُدْعَى ابْنَ هُرْمُزَ - قَالَ جَمَعَ الْمَنْزِلُ بَيْنَ عُبَادَةَ بْنِ الصَّامِتِ وَبَيْنَ مُعَاوِيَةَ حَدَّثَهُمْ عُبَادَةُ، قَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الذَّهَبِ بِالذَّهَبِ وَالْفِضَّةِ بِالْفِضَّةِ وَالتَّمْرِ بِالتَّمْرِ وَالْبُرِّ بِالْبُرِّ وَالشَّعِيرِ بِالشَّعِيرِ - قَالَ أَحَدُهُمَا وَالْمِلْحِ بِالْمِلْحِ وَلَمْ يَقُلْهُ الآخَرُ - إِلاَّ سَوَاءً بِسَوَاءٍ مِثْلاً بِمِثْلٍ - قَالَ أَحَدُهُمَا مَنْ زَادَ أَوِ ازْدَادَ فَقَدْ أَرْبَى وَلَمْ يَقُلْهُ الآخَرُ - وَأَمَرَنَا أَنْ نَبِيعَ الذَّهَبَ بِالْفِضَّةِ وَالْفِضَّةَ بِالذَّهَبِ وَالْبُرَّ بِالشَّعِيرِ وَالشَّعِيرَ بِالْبُرِّ يَدًا بِيَدٍ كَيْفَ شِئْنَا ‏.‏\hadithno{4561}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Muslim bin Yasar and Abdullah bin Ubaid who was called Ibn Hurmuz narrated that 'Ubadah bin As-Samit and Muawiyah met at a stopping place on the road. 'Ubadah told them:"The Messenger of Allah forbade selling gold for gold, silver for silver, dates for dates, wheat for wheat, barley for barley"- one of them said: "salt for salt," but the other did not say it-"unless it was equal amount for equal amount, like for like." One of them said: "Whoever gives more or takes more has engaged in Riba," but he other one did not say it. "And he commanded us to sell gold for silver and silver for gold, and wheat for barley and barley for wheat, hand to hand, however we wanted}}
\hadithdefcmd{nasai}{4562}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، قَالَ حَدَّثَنَا سَلَمَةُ بْنُ عَلْقَمَةَ، عَنْ مُحَمَّدٍ، قَالَ حَدَّثَنِي مُسْلِمُ بْنُ يَسَارٍ، وَعَبْدُ اللَّهِ بْنُ عُبَيْدٍ، قَالاَ جَمَعَ الْمَنْزِلُ بَيْنَ عُبَادَةَ بْنِ الصَّامِتِ وَبَيْنَ مُعَاوِيَةَ فَقَالَ عُبَادَةُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَبِيعَ الذَّهَبَ بِالذَّهَبِ وَالْوَرِقَ بِالْوَرِقِ وَالْبُرَّ بِالْبُرِّ وَالشَّعِيرَ بِالشَّعِيرِ وَالتَّمْرَ بِالتَّمْرِ - قَالَ أَحَدُهُمَا وَالْمِلْحَ بِالْمِلْحِ وَلَمْ يَقُلِ الآخَرُ - إِلاَّ سَوَاءً بِسَوَاءٍ مِثْلاً بِمِثْلٍ - قَالَ أَحَدُهُمَا مَنْ زَادَ أَوِ ازْدَادَ فَقَدْ أَرْبَى وَلَمْ يَقُلِ الآخَرُ - وَأَمَرَنَا أَنْ نَبِيعَ الذَّهَبَ بِالْوَرِقِ وَالْوَرِقَ بِالذَّهَبِ وَالْبُرَّ بِالشَّعِيرِ وَالشَّعِيرَ بِالْبُرِّ يَدًا بِيَدٍ كَيْفَ شِئْنَا فَبَلَغَ هَذَا الْحَدِيثُ مُعَاوِيَةَ فَقَامَ فَقَالَ مَا بَالُ رِجَالٍ يُحَدِّثُونَ أَحَادِيثَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَدْ صَحِبْنَاهُ وَلَمْ نَسْمَعْهُ مِنْهُ ‏.‏ فَبَلَغَ ذَلِكَ عُبَادَةَ بْنَ الصَّامِتِ فَقَامَ فَأَعَادَ الْحَدِيثَ فَقَالَ لَنُحَدِّثَنَّ بِمَا سَمِعْنَاهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَإِنْ رُغِمَ مُعَاوِيَةُ ‏.‏ خَالَفَهُ قَتَادَةُ رَوَاهُ عَنْ مُسْلِمِ بْنِ يَسَارٍ عَنْ أَبِي الأَشْعَثِ عَنْ عُبَادَةَ ‏.‏\hadithno{4562}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Muslim bin Yasar and 'Abdullah bin 'Ubaid said:"Ubadah bin As-Samit and Muawiyah met at a stopping place on the road. 'Ubadah said: 'The Messenger of Allah forbade us to sell gold for gold, silver for silver, wheat for wheat, barley for barley, dates for dates"' - one of them said: "salt for salt, " but the other did not say "unless it was equal amount for equal amount, like for like." One of them said: "Whoever gives more or takes more has engaged in Riba," but the other one did not say it. "And the commanded us to sell gold for silver and silver for gold, and wheat for barley and barley for wheat, hand to hand, however we wanted.' News of this hadith reached Muawiyah and he stood up and said: 'What is the matter with men who narrate Hadiths from the Messenger of Allah when we accompanied him and we never heard him say it? News of that reached 'Ubadah bin As-Samit and he stood up and repeated the Hadith, then he said: 'We will narrate what we heard from the Messenger of Allah, whether Muawiyah likes it or not."' Qatadah contradicted him, he reported it from Muslim bin Yasar, from Abu Al-=Ashath, from 'Ubadah}}
\hadithdefcmd{nasai}{4563}{أَخْبَرَنِي مُحَمَّدُ بْنُ آدَمَ، عَنْ عَبْدَةَ، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ مُسْلِمِ بْنِ يَسَارٍ، عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، - وَكَانَ بَدْرِيًّا وَكَانَ بَايَعَ النَّبِيَّ صلى الله عليه وسلم أَنْ لاَ يَخَافَ فِي اللَّهِ لَوْمَةَ لاَئِمٍ - أَنَّ عُبَادَةَ قَامَ خَطِيبًا فَقَالَ أَيُّهَا النَّاسُ إِنَّكُمْ قَدْ أَحْدَثْتُمْ بُيُوعًا لاَ أَدْرِي مَا هِيَ أَلاَ إِنَّ الذَّهَبَ بِالذَّهَبِ وَزْنًا بِوَزْنٍ تِبْرُهَا وَعَيْنُهَا وَإِنَّ الْفِضَّةَ بِالْفِضَّةِ وَزْنًا بِوَزْنٍ تِبْرُهَا وَعَيْنُهَا وَلاَ بَأْسَ بِبَيْعِ الْفِضَّةِ بِالذَّهَبِ يَدًا بِيَدٍ وَالْفِضَّةُ أَكْثَرُهُمَا وَلاَ تَصْلُحُ النَّسِيئَةُ أَلاَ إِنَّ الْبُرَّ بِالْبُرِّ وَالشَّعِيرَ بِالشَّعِيرِ مُدْيًا بِمُدْىٍ وَلاَ بَأْسَ بِبَيْعِ الشَّعِيرِ بِالْحِنْطَةِ يَدًا بِيَدٍ وَالشَّعِيرُ أَكْثَرُهُمَا وَلاَ يَصْلُحُ نَسِيئَةً أَلاَ وَإِنَّ التَّمْرَ بِالتَّمْرِ مُدْيًا بِمُدْىٍ حَتَّى ذَكَرَ الْمِلْحَ مُدًّا بِمُدٍّ فَمَنْ زَادَ أَوِ اسْتَزَادَ فَقَدْ أَرْبَى ‏.‏\hadithno{4563}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from 'Ubdah bin As-Samit-who had been present at Badar and had given his pledge to the Prophet swearing not to fear the blame of any blamer for the sake of Allah that 'Ubadah stood up to deliver a speech and said:"O people, you have invented kinds of transactions, I do not know what they are, but make sure it is gold for gold, of the same weight, or silver for silver, of the same weight. There is nothing wrong with selling silver for gold, hand to hand, giving more silver than gold, but no credit is allowed. When you sell wheat for wheat and barley for barley, it should be measure for measure, but there is nothing wrong with selling barley for wheat, hand to hand, giving more barley than wheat, but no credit is allowed. And when you sell dates for dates, it should be measure for measure" And he mentioned salt, "measure for measure, and whoever gives more or asks for more has engaged in Riba}}
\hadithdefcmd{nasai}{4564}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، قَالَ حَدَّثَنَا هَمَّامٌ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي الْخَلِيلِ، عَنْ مُسْلِمٍ الْمَكِّيِّ، عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الذَّهَبُ بِالذَّهَبِ تِبْرُهُ وَعَيْنُهُ وَزْنًا بِوَزْنٍ وَالْفِضَّةُ بِالْفِضَّةِ تِبْرُهُ وَعَيْنُهُ وَزْنًا بِوَزْنٍ وَالْمِلْحُ بِالْمِلْحِ وَالتَّمْرُ بِالتَّمْرِ وَالْبُرُّ بِالْبُرِّ وَالشَّعِيرُ بِالشَّعِيرِ سَوَاءً بِسَوَاءٍ مِثْلاً بِمِثْلٍ فَمَنْ زَادَ أَوِ ازْدَادَ فَقَدْ أَرْبَى ‏"‏ ‏.‏ وَاللَّفْظُ لِمُحَمَّدٍ لَمْ يَذْكُرْ يَعْقُوبُ ‏"‏ وَالشَّعِيرُ بِالشَّعِيرِ ‏"‏ ‏.‏\hadithno{4564}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Ubadah bin As-Samit said:"The messenger of Allah said: 'Gold for gold, of equal measure; silver for silver, of equal measure; salt for salt, dates for dates wheat for wheat, barley for barley, like for like. Whoever gives more or takes more has engaged in Riba."' (Sahih) The wording is that of Muhammad Yaqub did not mention - "Wheat for wheat}}
\hadithdefcmd{nasai}{4565}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ سُلَيْمَانَ بْنِ عَلِيٍّ، أَنَّ أَبَا الْمُتَوَكِّلِ، مَرَّ بِهِمْ فِي السُّوقِ فَقَامَ إِلَيْهِ قَوْمٌ أَنَا مِنْهُمْ قَالَ قُلْنَا أَتَيْنَاكَ لِنَسْأَلَكَ عَنِ الصَّرْفِ ‏.‏ قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ قَالَ لَهُ رَجُلٌ مَا بَيْنَكَ وَبَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم غَيْرُ أَبِي سَعِيدٍ الْخُدْرِيِّ قَالَ لَيْسَ بَيْنِي وَبَيْنَهُ غَيْرُهُ ‏.‏ قَالَ فَإِنَّ الذَّهَبَ بِالذَّهَبِ وَالْوَرِقَ بِالْوَرِقِ - قَالَ سُلَيْمَانُ أَوْ قَالَ وَالْفِضَّةَ بِالْفِضَّةِ - وَالْبُرَّ بِالْبُرِّ وَالشَّعِيرَ بِالشَّعِيرِ وَالتَّمْرَ بِالتَّمْرِ وَالْمِلْحَ بِالْمِلْحِ سَوَاءً بِسَوَاءٍ فَمَنْ زَادَ عَلَى ذَلِكَ أَوِ ازْدَادَ فَقَدْ أَرْبَى وَالآخِذُ وَالْمُعْطِي فِيهِ سَوَاءٌ ‏.‏\hadithno{4565}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Sulaiman bin Ali:"Abu Al-Mutawakkil passed by them in the market and some people, including me, stood up to greet him. We said: 'We have come to you to ask you about transactions.' He said: 'I heard a man say to Abu Saeed Al-Khudri': 'Is there anyone between you and the Messenger of Allah (in the chain of narrators) apart from Abu Saeed Al-Khudri? He said: 'There is no one else between him and I. He said: Gold for gold, silver for silver, wheat for wheat, barley for barley, dates for dates, salt for salt, equal amounts. Whoever gives more than that or takes more has engaged in Riba, and the taker and the giver are the same}}
\hadithdefcmd{nasai}{4566}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ قَالَ إِسْمَاعِيلُ حَدَّثَنَا حَكِيمُ بْنُ جَابِرٍ، ح وَأَنْبَأَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا حَكِيمُ بْنُ جَابِرٍ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ الذَّهَبُ الْكِفَّةُ بِالْكِفَّةِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ يَعْقُوبُ ‏"‏ الْكِفَّةُ بِالْكِفَّةِ ‏"‏ ‏.‏ فَقَالَ مُعَاوِيَةُ إِنَّ هَذَا لاَ يَقُولُ شَيْئًا ‏.‏ قَالَ عُبَادَةُ إِنِّي وَاللَّهِ مَا أُبَالِي أَنْ لاَ أَكُونَ بِأَرْضٍ يَكُونُ بِهَا مُعَاوِيَةُ إِنِّي أَشْهَدُ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ذَلِكَ ‏.‏\hadithno{4566}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Ubadah bin As-Samit said:"I heard the Messenger of Allah say: 'Gold, equal amount."' (One of the narrators) Yaqub did not mention: "Equal amount." Muawiyah said: "This does not mean anything." 'Ubadah said; "By Allah I do not care if I am in a land where Muawiyah is not present. I bear witness that I heard the Messenger of Allah say that}}
\hadithdefcmd{nasai}{4567}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ مُوسَى بْنِ أَبِي تَمِيمٍ، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الدِّينَارُ بِالدِّينَارِ وَالدِّرْهَمُ بِالدِّرْهَمِ لاَ فَضْلَ بَيْنَهُمَا ‏"‏ ‏.‏\hadithno{4567}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"Dinar for Dinar Dirham for Dirham, no difference between them}}
\hadithdefcmd{nasai}{4568}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ حُمَيْدِ بْنِ قَيْسٍ الْمَكِّيِّ، عَنْ مُجَاهِدٍ، قَالَ قَالَ ابْنُ عُمَرَ الدِّينَارُ بِالدِّينَارِ وَالدِّرْهَمُ بِالدِّرْهَمِ لاَ فَضْلَ بَيْنَهُمَا هَذَا عَهْدُ نَبِيِّنَا صلى الله عليه وسلم إِلَيْنَا ‏.‏\hadithno{4568}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Mujahid said:"Umar said: Dinar for Dinar, Dirham for Dirham, no difference between them, this is the obligation that our Prophet enjoined upon us}}
\hadithdefcmd{nasai}{4569}{أَخْبَرَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِيهِ، عَنِ ابْنِ أَبِي نُعْمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الذَّهَبُ بِالذَّهَبِ وَزْنًا بِوَزْنٍ مِثْلاً بِمِثْلٍ وَالْفِضَّةُ بِالْفِضَّةِ وَزْنًا بِوَزْنٍ مِثْلاً بِمِثْلٍ فَمَنْ زَادَ أَوِ ازْدَادَ فَقَدْ أَرْبَى ‏"‏ ‏.‏\hadithno{4569}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Gold for gold, weight for weight, like for like; and silver for silver, weight for weight, like for like. Whoever gives more or takes more has engaged in Riba}}
\hadithdefcmd{nasai}{4570}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَبِيعُوا الذَّهَبَ بِالذَّهَبِ إِلاَّ مِثْلاً بِمِثْلٍ وَلاَ تُشِفُّوا بَعْضَهَا عَلَى بَعْضٍ وَلاَ تَبِيعُوا الْوَرِقَ بِالْوَرِقِ إِلاَّ مِثْلاً بِمِثْلٍ وَلاَ تَبِيعُوا مِنْهَا شَيْئًا غَائِبًا بِنَاجِزٍ ‏"‏ ‏.‏\hadithno{4570}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Saeed Al-Khudri that the Messenger of Allah said:"Do not sell gold for gold except like for like and do not differentiate. Do not sell silver for silver except like for like, and do not sell it in return for something to be paid later}}
\hadithdefcmd{nasai}{4571}{أَخْبَرَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، وَإِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالاَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ نَافِعٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ بَصُرَ عَيْنِي وَسَمِعَ أُذُنِي، مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ النَّهْىَ عَنِ الذَّهَبِ بِالذَّهَبِ وَالْوَرِقِ بِالْوَرِقِ إِلاَّ سَوَاءً بِسَوَاءٍ مِثْلاً بِمِثْلٍ ‏ "‏ وَلاَ تَبِيعُوا غَائِبًا بِنَاجِزٍ وَلاَ تُشِفُّوا أَحَدَهُمَا عَلَى الآخَرِ ‏"‏ ‏.‏\hadithno{4571}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Saeed Al-Khudri said:"My eyes saw and my ears heard the Messenger of Allah. And he mentioned the prohibition of (selling) gold for gold and silver for silver, unless it is equal amounts, like for like. And do not sell it in return for something to be paid later, and do not differentiate}}
\hadithdefcmd{nasai}{4572}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، أَنَّ مُعَاوِيَةَ، بَاعَ سِقَايَةً مِنْ ذَهَبٍ أَوْ وَرِقٍ بِأَكْثَرَ مِنْ وَزْنِهَا فَقَالَ أَبُو الدَّرْدَاءِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ مِثْلِ هَذَا إِلاَّ مِثْلاً بِمِثْلٍ ‏.‏\hadithno{4572}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Ata' bin Yasir that:Muawiyah sold a cup of gold or silver for more than its weight. Abu Ad-Darda' said: "I heard the Messenger of Allah forbid such transactions unless it was like for like}}
\hadithdefcmd{nasai}{4573}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي شُجَاعٍ، سَعِيدِ بْنِ يَزِيدَ عَنْ خَالِدِ بْنِ أَبِي عِمْرَانَ، عَنْ حَنَشٍ الصَّنْعَانِيِّ، عَنْ فَضَالَةَ بْنِ عُبَيْدٍ، قَالَ اشْتَرَيْتُ يَوْمَ خَيْبَرَ قِلاَدَةً فِيهَا ذَهَبٌ وَخَرَزٌ بِاثْنَىْ عَشَرَ دِينَارًا فَفَصَّلْتُهَا فَوَجَدْتُ فِيهَا أَكْثَرَ مِنَ اثْنَىْ عَشَرَ دِينَارًا فَذُكِرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تُبَاعُ حَتَّى تُفَصَّلَ ‏"‏ ‏.‏\hadithno{4573}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated the Fadalah bin 'Ubaid said:"On the Day of Khaibar I bought a necklace containing gold and ggems for twelve Dinars. The I took it apart and found that it contatined more than twelve Dinars. Mentiion of that was made to the Prophet and he said: 'It should not be sold until it is taken apart}}
\hadithdefcmd{nasai}{4574}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ مَحْبُوبٍ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ خَالِدِ بْنِ أَبِي عِمْرَانَ، عَنْ حَنَشٍ الصَّنْعَانِيِّ، عَنْ فَضَالَةَ بْنِ عُبَيْدٍ، قَالَ أَصَبْتُ يَوْمَ خَيْبَرَ قِلاَدَةً فِيهَا ذَهَبٌ وَخَرَزٌ فَأَرَدْتُ أَنْ أَبِيعَهَا فَذُكِرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ افْصِلْ بَعْضَهَا مِنْ بَعْضٍ ثُمَّ بِعْهَا ‏"‏ ‏.‏\hadithno{4574}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Fadalah bin 'Ubad said:"On the Day of Khaibar I got a necklace containing gold and gems, and I wanted to sell it. Mention of that was made to the Prophet and he said: 'Take it apart, and then sell it}}
\hadithdefcmd{nasai}{4575}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، عَنْ سُفْيَانَ، عَنْ عَمْرٍو، عَنْ أَبِي الْمِنْهَالِ، قَالَ بَاعَ شَرِيكٌ لِي وَرِقًا بِنَسِيئَةٍ فَجَاءَنِي فَأَخْبَرَنِي فَقُلْتُ، هَذَا لاَ يَصْلُحُ ‏.‏ فَقَالَ قَدْ وَاللَّهِ بِعْتُهُ فِي السُّوقِ وَمَا عَابَهُ عَلَىَّ أَحَدٌ فَأَتَيْتُ الْبَرَاءَ بْنَ عَازِبٍ فَسَأَلْتُهُ فَقَالَ قَدِمَ عَلَيْنَا النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ وَنَحْنُ نَبِيعُ هَذَا الْبَيْعَ فَقَالَ ‏ "‏ مَا كَانَ يَدًا بِيَدٍ فَلاَ بَأْسَ وَمَا كَانَ نَسِيئَةً فَهُوَ رِبًا ‏"‏ ‏.‏ ثُمَّ قَالَ لِي ائْتِ زَيْدَ بْنَ أَرْقَمَ فَأَتَيْتُهُ فَسَأَلْتُهُ فَقَالَ مِثْلَ ذَلِكَ ‏.‏\hadithno{4575}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that abu Al-Minhal said:"Sharik sold some silver on credit for me. He came to me and told me. And I said: 'This is not correct.' He said; 'By Allah, I did this transaction in the market and no one criticized me .' So I went to Al-Bara bin Azib and asked him about that. He said: 'The Prophet came to us in Al-Madinah and we used to do this kind of transaction, but he said: Whatever is hand to hand, there is nothing wrong with it, but whatever is on credit, is Riba. Then he said to me: 'Go to Zaid bin Arqam.' So I went to him and asked him, and he said the same thing}}
\hadithdefcmd{nasai}{4576}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، وَعَامِرُ بْنُ مُصْعَبٍ، أَنَّهُمَا سَمِعَا أَبَا الْمِنْهَالِ، يَقُولُ سَأَلْتُ الْبَرَاءَ بْنَ عَازِبٍ وَزَيْدَ بْنَ أَرْقَمَ فَقَالاَ كُنَّا تَاجِرَيْنِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلْنَا نَبِيَّ اللَّهِ صلى الله عليه وسلم عَنِ الصَّرْفِ فَقَالَ ‏ "‏ إِنْ كَانَ يَدًا بِيَدٍ فَلاَ بَأْسَ وَإِنْ كَانَ نَسِيئَةً فَلاَ يَصْلُحُ ‏"‏ ‏.‏\hadithno{4576}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Al-Minhal said:" I asked Al-Bara bin 'Azib and Zaid bin Arqam and they said: 'We were merchants at the time of the Messenger of Allah and we asked the Prophet of Allah about money exchange. He said: "If it is done hand to hand there is nothing wrong with it, but if it is done on credit then it is not right}}
\hadithdefcmd{nasai}{4577}{أَخْبَرَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، عَنْ مُحَمَّدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ حَبِيبٍ، قَالَ سَمِعْتُ أَبَا الْمِنْهَالِ، قَالَ سَأَلْتُ الْبَرَاءَ بْنَ عَازِبٍ عَنِ الصَّرْفِ، فَقَالَ سَلْ زَيْدَ بْنَ أَرْقَمَ فَإِنَّهُ خَيْرٌ مِنِّي وَأَعْلَمُ ‏.‏ فَسَأَلْتُ زَيْدًا فَقَالَ سَلِ الْبَرَاءَ فَإِنَّهُ خَيْرٌ مِنِّي وَأَعْلَمُ فَقَالاَ جَمِيعًا نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْوَرِقِ بِالذَّهَبِ دَيْنًا ‏.‏\hadithno{4577}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Al-Minhal said:"I asked Al-Bara bin 'Azib about money exchange. He said: 'Ask Zaid bin Arqam, for he is better than me and more knowledgeable.' So I asked Zaid and he said: 'Ask Al-Bara for he is better than me and more knowledgeable.' And they both said: 'The Messenger of Allah forbade (selling) silver for gold on credit}}
\hadithdefcmd{nasai}{4578}{وَفِيمَا قَرَأَ عَلَيْنَا أَحْمَدُ بْنُ مَنِيعٍ قَالَ حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي إِسْحَاقَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الْفِضَّةِ بِالْفِضَّةِ وَالذَّهَبِ بِالذَّهَبِ إِلاَّ سَوَاءً بِسَوَاءٍ وَأَمَرَنَا أَنْ نَبْتَاعَ الذَّهَبَ بِالْفِضَّةِ كَيْفَ شِئْنَا وَالْفِضَّةَ بِالذَّهَبِ كَيْفَ شِئْنَا ‏.‏\hadithno{4578}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdur-Rahman bin Abi Bakrah narrated that his father said:"The Messenger of Allah forbade selling silver for silver and gold for gold, unless it was of equal amounts. And he told us to sell gold for silver however we wanted, and silver for gold however we wanted}}
\hadithdefcmd{nasai}{4579}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ مُحَمَّدِ بْنِ كَثِيرٍ الْحَرَّانِيُّ، قَالَ حَدَّثَنَا أَبُو تَوْبَةَ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ سَلاَّمٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، قَالَ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَبِيعَ الْفِضَّةَ بِالْفِضَّةِ إِلاَّ عَيْنًا بِعَيْنٍ سَوَاءً بِسَوَاءٍ وَلاَ نَبِيعَ الذَّهَبَ بِالذَّهَبِ إِلاَّ عَيْنًا بِعَيْنٍ سَوَاءً بِسَوَاءٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَبَايَعُوا الذَّهَبَ بِالْفِضَّةِ كَيْفَ شِئْتُمْ وَالْفِضَّةَ بِالذَّهَبِ كَيْفَ شِئْتُمْ ‏"‏ ‏.‏\hadithno{4579}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdur-Rahman bin Abi Bakrah that his father said:"The Messenger of Allah forbade us from selling silver for silver unless it was of equal amounts, or selling gold for gold unless it was of equal amounts. The messenger of Allah said: 'Sell gold for silver however you want, and silver for gold however you want}}
\hadithdefcmd{nasai}{4580}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، سَمِعَ ابْنَ عَبَّاسٍ، يَقُولُ حَدَّثَنِي أُسَامَةُ بْنُ زَيْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ رِبًا إِلاَّ فِي النَّسِيئَةِ ‏"‏ ‏.‏\hadithno{4580}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Usmah bin Zaid Narrated that the Messenger of Allah said:"There is no Riba except in credit}}
\hadithdefcmd{nasai}{4581}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ أَبِي صَالِحٍ، سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ قُلْتُ لاِبْنِ عَبَّاسٍ أَرَأَيْتَ هَذَا الَّذِي تَقُولُ أَشَيْئًا وَجَدْتَهُ فِي كِتَابِ اللَّهِ عَزَّ وَجَلَّ أَوْ شَيْئًا سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ مَا وَجَدْتُهُ فِي كِتَابِ اللَّهِ عَزَّ وَجَلَّ وَلاَ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَكِنْ أُسَامَةُ بْنُ زَيْدٍ أَخْبَرَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا الرِّبَا فِي النَّسِيئَةِ ‏"‏ ‏.‏\hadithno{4581}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Salih heard Abu Saeed Al-Khudri say:"I said to Ibn Abbas: 'Do you think that what you are saying is something that you found in the Book of Allah, or something that you heard from the Messenger of Allah?' He said: 'I did not find it in the Book of Allah, nor did I hear it from the messenger of Allah, rather Usamah bin Zaid told me that the Messenger of Allah said: 'Riba is only in credit}}
\hadithdefcmd{nasai}{4582}{أَخْبَرَنِي أَحْمَدُ بْنُ يَحْيَى، عَنْ أَبِي نُعَيْمٍ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنْتُ أَبِيعُ الإِبِلَ بِالْبَقِيعِ فَأَبِيعُ بِالدَّنَانِيرِ وَآخُذُ الدَّرَاهِمَ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فِي بَيْتِ حَفْصَةَ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أُرِيدُ أَنْ أَسْأَلَكَ إِنِّي أَبِيعُ الإِبِلَ بِالْبَقِيعِ فَأَبِيعُ بِالدَّنَانِيرِ وَآخُذُ الدَّرَاهِمَ قَالَ ‏ "‏ لاَ بَأْسَ أَنْ تَأْخُذَهَا بِسِعْرِ يَوْمِهَا مَا لَمْ تَفْتَرِقَا وَبَيْنَكُمَا شَىْءٌ ‏"‏ ‏.‏\hadithno{4582}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"I used to sell camels at Al-Baqi and I would sell Dinars in exchange for Dirhams. I came to the Prophet in the house of Hafsah and said: 'O Messenger of Allah, I want to ask you: I sell camels in Al-Baqi and I sell Dinars in exchange for Dirhams. He said: 'There is nothing wrong with it if you take the price on that day, unless you depart when there is still unfinished business between you both (buyer and seller)}}
\hadithdefcmd{nasai}{4583}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنِ ابْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنْتُ أَبِيعُ الذَّهَبَ بِالْفِضَّةِ أَوِ الْفِضَّةَ بِالذَّهَبِ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْتُهُ بِذَلِكَ فَقَالَ ‏ "‏ إِذَا بَايَعْتَ صَاحِبَكَ فَلاَ تُفَارِقْهُ وَبَيْنَكَ وَبَيْنَهُ لَبْسٌ ‏"‏ ‏.‏\hadithno{4583}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"I used to sell gold for silver, or silver for gold. I came to the Messenger of Allah and told him about that, and he said: 'If you make a deal with your companion, d o not leave him when there is still any ambiguity (in the deal) between you}}
\hadithdefcmd{nasai}{4584}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ أَنْبَأَنَا مُوسَى بْنُ نَافِعٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، أَنَّهُ كَانَ يَكْرَهُ أَنْ يَأْخُذَ، الدَّنَانِيرَ مِنَ الدَّرَاهِمِ وَالدَّرَاهِمَ مِنَ الدَّنَانِيرِ ‏.‏\hadithno{4584}\hadithgrade{Abu Ghuddah: Sahih Maqtu; Al-Albani: Sahih Maqtu; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Saeed bin Jubair that:he did not like to exchange Dinars for Dirhams or Dirhams for Dinars}}
\hadithdefcmd{nasai}{4585}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ أَنْبَأَنَا مُؤَمَّلٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي هَاشِمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَانَ لاَ يَرَى بَأْسًا - يَعْنِي - فِي قَبْضِ الدَّرَاهِمِ مِنَ الدَّنَانِيرِ وَالدَّنَانِيرِ مِنَ الدَّرَاهِمِ ‏.‏\hadithno{4585}\hadithgrade{Abu Ghuddah: Sahih Muquf; Al-Albani: Sahih Muquf; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Saeed bin Jubair, from Ibn 'Umar, that:he did not see anything wrong with parying Dirhams for Dinars}}
\hadithdefcmd{nasai}{4586}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الْهُذَيْلِ، عَنْ إِبْرَاهِيمَ، فِي قَبْضِ الدَّنَانِيرِ مِنَ الدَّرَاهِمِ أَنَّهُ كَانَ يَكْرَهُهَا إِذَا كَانَ مِنْ قَرْضٍ ‏.‏\hadithno{4586}\hadithgrade{Abu Ghuddah: Sahih Maqtu; Al-Albani: Sahih Maqtu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibrahim, with regard to exchanging Dirnars for Dirhams, that:he disliked it (this transaction) if it was done on credit. (Da 'if)}}
\hadithdefcmd{nasai}{4587}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مُوسَى أَبِي شِهَابٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، أَنَّهُ كَانَ لاَ يَرَى بَأْسًا وَإِنْ كَانَ مِنْ قَرْضٍ ‏.‏\hadithno{4587}\hadithgrade{Abu Ghuddah: Sahih Maqtu; Al-Albani: Sahih Maqtu; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Saeed bin Jubair that:he did not see anything wrong with it even if it was on credit}}
\hadithdefcmd{nasai}{4588}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا مُوسَى بْنُ نَافِعٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، بِمِثْلِهِ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ كَذَا وَجَدْتُهُ فِي هَذَا الْمَوْضِعِ ‏.‏\hadithno{4588}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Something similar was narrated form Saeed bin Jubair. Abu 'Abdur-Rehman (An-Nasai) said:This is what I have found on this topic}}
\hadithdefcmd{nasai}{4589}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَمَّارٍ، قَالَ حَدَّثَنَا الْمُعَافَى، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ رُوَيْدَكَ أَسْأَلُكَ إِنِّي أَبِيعُ الإِبِلَ بِالْبَقِيعِ بِالدَّنَانِيرِ وَآخُذُ الدَّرَاهِمَ ‏.‏ قَالَ ‏ "‏ لاَ بَأْسَ أَنْ تَأْخُذَ بِسِعْرِ يَوْمِهَا مَا لَمْ تَفْتَرِقَا وَبَيْنَكُمَا شَىْءٌ ‏"‏ ‏.‏\hadithno{4589}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Umar said:"I came to the Prophet and said: 'Wait, I want to ask you something. I sell camels in Al-Baqi with a price set in Dinars but I accept Dirhams instead.' He said: 'There is nothing wrong with it if you take the price on that day, still unfinished business between you both (buyer and seller)}}
\hadithdefcmd{nasai}{4590}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، عَنْ شُعْبَةَ، قَالَ أَخْبَرَنِي مُحَارِبُ بْنُ دِثَارٍ، عَنْ جَابِرٍ، قَالَ لَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ دَعَا بِمِيزَانٍ فَوَزَنَ لِي وَزَادَنِي ‏.‏\hadithno{4590}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jabir said:"When the Prophet (ﷺ) came to Al-Madinah, he called for a scale and weighed (something) for me and gave me more}}
\hadithdefcmd{nasai}{4591}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ سُفْيَانَ، عَنْ مِسْعَرٍ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ جَابِرٍ، قَالَ قَضَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَزَادَنِي ‏.‏\hadithno{4591}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir said:'The Messenger of Allah paid off what he owed me, and gave me more}}
\hadithdefcmd{nasai}{4592}{أَخْبَرَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ سِمَاكٍ، عَنْ سُوَيْدِ بْنِ قَيْسٍ، قَالَ جَلَبْتُ أَنَا وَمَخْرَفَةُ الْعَبْدِيُّ، بَزًّا مِنْ هَجَرَ فَأَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ بِمِنًى وَوَزَّانٌ يَزِنُ بِالأَجْرِ فَاشْتَرَى مِنَّا سَرَاوِيلَ فَقَالَ لِلْوَزَّانِ ‏ "‏ زِنْ وَأَرْجِحْ ‏"‏ ‏.‏\hadithno{4592}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Suwaid bin Qais said:"Makhrafah Al-Abdi and I brought some cloth from Hajar, and the Messenger of Allah came to us while we were in Mina where there w a man who weighed (goods) in return for payment. He bought some trousers from us, and said to the man who weighed: 'Weigh it, and allow more}}
\hadithdefcmd{nasai}{4593}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ سَمِعْتُ أَبَا صَفْوَانَ، قَالَ بِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم سَرَاوِيلَ قَبْلَ الْهِجْرَةِ فَأَرْجَحَ لِي ‏.‏\hadithno{4593}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Simak bin Harb said:"I heard Abu Safwan say: 'I bought a pair of trousers from the Messenger of Allah before the Hijrah, and he weighed it for me and allowed me}}
\hadithdefcmd{nasai}{4594}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنِ الْمُلاَئِيِّ، عَنْ سُفْيَانَ، ح وَأَنْبَأَنَا مُحَمَّدُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا أَبُو نُعَيْمٍ، عَنْ سُفْيَانَ، عَنْ حَنْظَلَةَ، عَنْ طَاوُسٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمِكْيَالُ عَلَى مِكْيَالِ أَهْلِ الْمَدِينَةِ وَالْوَزْنُ عَلَى وَزْنِ أَهْلِ مَكَّةَ ‏"‏ ‏.‏ وَاللَّفْظُ لإِسْحَاقَ ‏.‏\hadithno{4594}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: "Volume is to be measured according to the system of the people of Al-Madinah, and weight is to be measured according to the system of the peole of Makkah."' (Sahih) This is the wording of Ishaq (one of the narrators)}}
\hadithdefcmd{nasai}{4595}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَسْتَوْفِيَهُ ‏"‏ ‏.‏\hadithno{4595}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'Whoever buys food, let him not sell it until he has taken possession of it}}
\hadithdefcmd{nasai}{4596}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، قَالَ أَنْبَأَنَا ابْنُ الْقَاسِمِ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَقْبِضَهُ ‏"‏ ‏.‏\hadithno{4596}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Abdullah bin 'Umar that the Messenger of Allah said:"Whoever buys food let him not sell it until he has taken possession of it}}
\hadithdefcmd{nasai}{4597}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا قَاسِمٌ، عَنْ سُفْيَانَ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِيعُهُ حَتَّى يَكْتَالَهُ ‏"‏ ‏.‏\hadithno{4597}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah said: 'Whoever buys food, let him not sell it until he has checked its weight}}
\hadithdefcmd{nasai}{4598}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ عَمْرٍو، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم بِمِثْلِهِ وَالَّذِي قَبْلَهُ حَتَّى يَقْبِضَهُ ‏.‏\hadithno{4598}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Abbas said:"I heard the Prophet say" something similar to the preceding two reports "until he takes possession of it}}
\hadithdefcmd{nasai}{4599}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ طَاوُسٍ، عَنْ طَاوُسٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ أَمَّا الَّذِي نَهَى عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُبَاعَ حَتَّى يُسْتَوْفَى الطَّعَامُ ‏.‏\hadithno{4599}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Tawus said:"I heard Ibn 'Abbas say: 'As for that which the Messenger of Allah forbade, (it is) selling before taking possession of food}}
\hadithdefcmd{nasai}{4600}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ ابْتَاعَ طَعَامًا فَلاَ يَبِيعُهُ حَتَّى يَقْبِضَهُ ‏"‏ ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَأَحْسَبُ أَنَّ كُلَّ شَىْءٍ بِمَنْزِلَةِ الط��َعَامِ ‏.‏\hadithno{4600}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah said: 'Whoever buys food let him not sell it until he takes possession of it. Ibn 'Abbas said: "I think the same applies to everything else as to food}}
\hadithdefcmd{nasai}{4601}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، عَنْ حَجَّاجِ بْنِ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عَطَاءٌ، عَنْ صَفْوَانَ بْنِ مَوْهَبٍ، أَنَّهُ أَخْبَرَهُ عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ صَيْفِيٍّ، عَنْ حَكِيمِ بْنِ حِزَامٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَبِعْ طَعَامًا حَتَّى تَشْتَرِيَهُ وَتَسْتَوْفِيَهُ ‏"‏ ‏.‏\hadithno{4601}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Hakim bin Hizam said:"The Messenger of Allah said: "Do not sell food until you have bought it and taken possession of it}}
\hadithdefcmd{nasai}{4602}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ وَأَخْبَرَنِي عَطَاءٌ، ذَلِكَ عَنْ عَبْدِ اللَّهِ بْنِ عِصْمَةَ الْجُشَمِيِّ، عَنْ حَكِيمِ بْنِ حِزَامٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{4602}\hadithgrade{Al-Albani: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Jurayi said:"Ata' told me that from 'Abdullah bin 'Ismah Al-Jushami from Hakim bin Hizam from the prophet}}
\hadithdefcmd{nasai}{4603}{أَخْبَرَنَا سُلَيْمَانُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ حِزَامِ بْنِ حَكِيمٍ، قَالَ قَالَ حَكِيمُ بْنُ حِزَامٍ ابْتَعْتُ طَعَامًا مِنْ طَعَامِ الصَّدَقَةِ فَرَبِحْتُ فِيهِ قَبْلَ أَنْ أَقْبِضَهُ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ ‏ "‏ لاَ تَبِعْهُ حَتَّى تَقْبِضَهُ ‏"‏ ‏.‏\hadithno{4603}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Hakim bin Hizam said:"I bought some food and made food and made a profit on it (by selling it) before I took possession of it. I came to the Messenger of Allah and told him about that and he said: 'Do not sell it until you take possession of it}}
\hadithdefcmd{nasai}{4604}{أَخْبَرَنَا سُلَيْمَانُ بْنُ دَاوُدَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، عَنِ ابْنِ وَهْبٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنِ الْمُنْذِرِ بْنِ عُبَيْدٍ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يَبِيعَ أَحَدٌ طَعَامًا اشْتَرَاهُ بِكَيْلٍ حَتَّى يَسْتَوْفِيَهُ ‏.‏\hadithno{4604}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn 'Umar that:the Prophet forbade anyone to sell food that he brought}}
\hadithdefcmd{nasai}{4605}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ كُنَّا فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم نَبْتَاعُ الطَّعَامَ فَيَبْعَثُ عَلَيْنَا مَنْ يَأْمُرُنَا بِانْتِقَالِهِ مِنَ الْمَكَانِ الَّذِي ابْتَعْنَا فِيهِ إِلَى مَكَانٍ سِوَاهُ قَبْلَ أَنْ نَبِيعَهُ ‏.‏\hadithno{4605}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that 'Abdullah bin 'Umar said:"During the time the Messenger of Allah we used to buy food, and he sent someone to tell us to remove it from the place where we had bought it, to another place, b before selling}}
\hadithdefcmd{nasai}{4606}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّهُمْ كَانُوا يَبْتَاعُونَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي أَعْلَى السُّوقِ جُزَافًا فَنَهَاهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَبِيعُوهُ فِي مَكَانِهِ حَتَّى يَنْقُلُوهُ ‏.‏\hadithno{4606}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn 'Umar that:they used to buy and sell during the time of the Messenger of Allah at the top of the marketplace without measuring. The Messenger of Allah forbade them to sell it in the place where they had bought it until they moved it}}
\hadithdefcmd{nasai}{4607}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، قَالَ حَدَّثَنَا شُعَيْبُ بْنُ اللَّيْثِ، عَنْ أَبِيهِ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، حَدَّثَهُمْ أَنَّهُمْ، كَانُوا يَبْتَاعُونَ الطَّعَامَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الرُّكْبَانِ فَنَهَاهُمْ أَنْ يَبِيعُوا فِي مَكَانِهِمُ الَّذِي ابْتَاعُوا فِيهِ حَتَّى يَنْقُلُوهُ إِلَى سُوقِ الطَّعَامِ ‏.‏\hadithno{4607}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Nafi that Ibn 'UMar told them, that:they used to buy foold from the riders at the time of the Messenger of Allah and he forbade them to sell it in the place where they had bought it until they moved it to the food market}}
\hadithdefcmd{nasai}{4608}{أَخْبَرَنَا نَصْرُ بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَزِيدُ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّاسَ يُضْرَبُونَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذَا اشْتَرَوُا الطَّعَامَ جُزَافًا أَنْ يَبِيعُوهُ حَتَّى يُئْوُوهُ إِلَى رِحَالِهِمْ ‏.‏\hadithno{4608}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Salim that his father said:"I saw people being beaten (in punishment) at the time of the Messenger of Allah for buying food unmeasured and selling it before bringing it to their own camp}}
\hadithdefcmd{nasai}{4609}{أَخْبَرَنِي مُحَمَّدُ بْنُ آدَمَ، عَنْ حَفْصِ بْنِ غِيَاثٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتِ اشْتَرَى رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ يَهُودِيٍّ طَعَامًا إِلَى أَجَلٍ وَرَهَنَهُ دِرْعَهُ ‏.‏\hadithno{4609}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah bought some food from a Jew with payment to be made later, and he put his shield in pledge for that}}
\hadithdefcmd{nasai}{4610}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ مَشَى إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِخُبْزِ شَعِيرٍ وَإِهَالَةٍ سَنِخَةٍ ‏.‏ قَالَ وَلَقَدْ رَهَنَ دِرْعًا لَهُ عِنْدَ يَهُودِيٍّ بِالْمَدِينَةِ وَأَخَذَ مِنْهُ شَعِيرًا لأَهْلِهِ ‏.‏\hadithno{4610}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas bin Malik that he brought some barley bread and rancid oil to the Messenger of Allah. He said:"He put his armor in pledge for that with a Jew in Al-Madinah, and he took some barley from him for his family}}
\hadithdefcmd{nasai}{4611}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَحُمَيْدُ بْنُ مَسْعَدَةَ، عَنْ يَزِيدَ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ سَلَفٌ وَبَيْعٌ وَلاَ شَرْطَانِ فِي بَيْعٍ وَلاَ بَيْعُ مَا لَيْسَ عِنْدَكَ ‏"‏ ‏.‏\hadithno{4611}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from'Amr bin Shu'aib, from his father that his grandfather, Said:that the Messenger of Allah said: "It is not permissible to lend on the condition of a sale, or to have two conditions in one transaction, or to sell what you do not have." (Sahih)}}
\hadithdefcmd{nasai}{4612}{أَخْبَرَنَا عُثْمَانُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، عَنْ عَبَّادِ بْنِ الْعَوَّامِ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ أَبِي رَجَاءٍ، - قَالَ عُثْمَانُ هُوَ مُحَمَّدُ بْنُ سَيْفٍ - عَنْ مَطَرٍ الْوَرَّاقِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ عَلَى رَجُلٍ بَيْعٌ فِيمَا لاَ يَمْلِكُ ‏"‏ ‏.‏\hadithno{4612}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said:"The Messenger of Allah said: 'No man is bound by a transaction involving the sale of something that he does not possess}}
\hadithdefcmd{nasai}{4613}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا هُشَيْمٌ، قَالَ حَدَّثَنَا أَبُو بِشْرٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، عَنْ حَكِيمِ بْنِ حِزَامٍ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ يَأْتِينِي الرَّجُلُ فَيَسْأَلُنِي الْبَيْعَ لَيْسَ عِنْدِي أَبِيعُهُ مِنْهُ ثُمَّ أَبْتَاعُهُ لَهُ مِنَ السُّوقِ ‏.‏ قَالَ ‏ "‏ لاَ تَبِعْ مَا لَيْسَ عِنْدَكَ ‏"‏ ‏.‏\hadithno{4613}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Hakim bin Hizam said:"I asked the Prophet "O Messenger of Allah, a man may come to me and ask me to sell him something that I do not have. Can I sell it to him then go and buy it from the market?' He said: 'Do not sell what you do not have}}
\hadithdefcmd{nasai}{4614}{أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي الْمُجَالِدِ، قَالَ سَأَلْتُ ابْنَ أَبِي أَوْفَى عَنِ السَّلَفِ، قَالَ كُنَّا نُسْلِفُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ فِي الْبُرِّ وَالشَّعِيرِ وَالتَّمْرِ إِلَى قَوْمٍ لاَ أَدْرِي أَعِنْدَهُمْ أَمْ لاَ ‏.‏ وَابْنُ أَبْزَى قَالَ مِثْلَ ذَلِكَ ‏.‏\hadithno{4614}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that 'Abdullah Ibn Abi Awfa about paying in advance. He said:'We used to pay in advance during the time of the Messenger of Allah and Abu Bakr and 'Umar, for wheat, barley and dates, paying people whom we did not know if they had those things or not.'''Ibn Abza said meaning, similarly}}
\hadithdefcmd{nasai}{4615}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، قَالَ حَدَّثَنَا ابْنُ أَبِي الْمُجَالِدِ، - وَقَالَ مَرَّةً عَبْدُ اللَّهِ وَقَالَ مَرَّةً مُحَمَّدٌ - قَالَ تَمَارَى أَبُو بُرْدَةَ وَعَبْدُ اللَّهِ بْنُ شَدَّادٍ فِي السَّلَمِ فَأَرْسَلُونِي إِلَى ابْنِ أَبِي أَوْفَى فَسَأَلْتُهُ فَقَالَ كُنَّا نُسْلِمُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَلَى عَهْدِ أَبِي بَكْرٍ وَعَلَى عَهْدِ عُمَرَ فِي الْبُرِّ وَالشَّعِيرِ وَالزَّبِيبِ وَالتَّمْرِ إِلَى قَوْمٍ مَا نُرَى عِنْدَهُمْ ‏.‏ وَسَأَلْتُ ابْنَ أَبْزَى فَقَالَ مِثْلَ ذَلِكَ ‏.‏\hadithno{4615}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Ibn Abi Al-Mujalid-on one occasion he (the narrator) said 'Abdullah, and on another occasion he said Muhammad - said:"Abu Burdah and 'Abdullah bin Shaddad argued about payment in advance. They sent me to Ibn Abi Awfa and I asked him (about that). He said: 'We used to pay in advance during the time of the Messenger of Allah and Abu Bakr and 'Umar, for wheat, barley, raisins and dates, paying people whom we did not see it with them." And I asked Ibn Abza and he said something similar to that}}
\hadithdefcmd{nasai}{4616}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ عَبْدِ اللَّهِ بْنِ كَثِيرٍ، عَنْ أَبِي الْمِنْهَالِ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، قَالَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ وَهُمْ يُسْلِفُونَ فِي التَّمْرِ السَّنَتَيْنِ وَالثَّلاَثَ فَنَهَاهُمْ وَقَالَ ‏ "‏ مَنْ أَسْلَفَ سَلَفًا فَلْيُسْلِفْ فِي كَيْلٍ مَعْلُومٍ وَوَزْنٍ مَعْلُومٍ إِلَى أَجَلٍ مَعْلُومٍ ‏"‏ ‏.‏\hadithno{4616}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Al-Minhal said:"I heard Ibn 'Abbas say: 'When the Prophet came (to al-Madinah), they used to pay in advance for dates, two or three years in advance. He forbade them that and said: 'whoever pays in advance for dates, let him pay for a known amount or a known weight, to be delivered at a known time}}
\hadithdefcmd{nasai}{4617}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي رَافِعٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَسْلَفَ مِنْ رَجُلٍ بَكْرًا فَأَتَاهُ يَتَقَاضَاهُ بَكْرَهُ فَقَالَ لِرَجُلٍ ‏"‏ انْطَلِقْ فَابْتَعْ لَهُ بَكْرًا ‏"‏ ‏.‏ فَأَتَاهُ فَقَالَ مَا أَصَبْتُ إِلاَّ بَكْرًا رَبَاعِيًّا خِيَارًا ‏.‏ فَقَالَ ‏"‏ أَعْطِهِ فَإِنَّ خَيْرَ الْمُسْلِمِينَ أَحْسَنُهُمْ قَضَاءً ‏"‏ ‏.‏\hadithno{4617}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Rafi that the Messenger of Allah borrowed a young camel from a man, and then he came to get his camel back. He said to a man:"Go and buy a young camel for him." He came and said: "I could only get a Raba camel of good quality." He said: "Give it to him, for the best of the Muslims is the one who is best in repaying}}
\hadithdefcmd{nasai}{4618}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ لِرَجُلٍ عَلَى النَّبِيِّ صلى الله عليه وسلم سِنٌّ مِنَ الإِبِلِ فَجَاءَ يَتَقَاضَاهُ فَقَالَ ‏"‏ أَعْطُوهُ ‏"‏ ‏.‏ فَلَمْ يَجِدُوا إِلاَّ سِنًّا فَوْقَ سِنِّهِ قَالَ ‏"‏ أَعْطُوهُ ‏"‏ ‏.‏ فَقَالَ أَوْفَيْتَنِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ خِيَارَكُمْ أَحْسَنُكُمْ قَضَاءً ‏"‏ ‏.‏\hadithno{4618}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"A man had lent a camel of a certain age to the Prophet and he came to get it back. He said: "Give it to him" But they could only find a camel that was older than it. He said: "Give it to him." He said: "You have repaid me well," The Messenger of Allah said; "The best of you is the one who is best in repaying}}
\hadithdefcmd{nasai}{4619}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالَ حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ هَانِئٍ، يَقُولُ سَمِعْتُ عِرْبَاضَ بْنَ سَارِيَةَ، يَقُولُ بِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بَكْرًا فَأَتَيْتُهُ أَتَقَاضَاهُ فَقَالَ ‏"‏ أَجَلْ لاَ أَقْضِيكَهَا إِلاَّ نَجِيبَةً ‏"‏ ‏.‏ فَقَضَانِي فَأَحْسَنَ قَضَائِي وَجَاءَهُ أَعْرَابِيٌّ يَتَقَاضَاهُ سِنَّهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعْطُوهُ سِنًّا ‏"‏ ‏.‏ فَأَعْطَوْهُ يَوْمَئِذٍ جَمَلاً فَقَالَ هَذَا خَيْرٌ مِنْ سِنِّي ‏.‏ فَقَالَ ‏"‏ خَيْرُكُمْ خَيْرُكُمْ قَضَاءً ‏"‏ ‏.‏\hadithno{4619}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Irbad bin Saryah said:"I lent a young camel to the Messenger of Allah, and I came to ask him to repay me. He said: 'Yes, I will only repay you with a superior she-camel.' so he repaid me and repaid me well. Then a Bedouin came to him to ask to repay him a camel of a certain age, and the Messenger of Allah said: 'Give him a camel of certain age.' On that day they gave him a mature camel and he said: 'This is better than my camel.' He (The Prophet) Said:' The best of you is the one who is best in repaying}}
\hadithdefcmd{nasai}{4620}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَيَزِيدُ بْنُ زُرَيْعٍ، وَخَالِدُ بْنُ الْحَارِثِ، قَالُوا حَدَّثَنَا شُعْبَةُ، وَأَخْبَرَنِي أَحْمَدُ بْنُ فَضَالَةَ بْنِ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، قَالَ حَدَّثَنَا الْحَسَنُ بْنُ صَالِحٍ، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْحَيَوَانِ بِالْحَيَوَانِ نَسِيئَةً ‏.‏\hadithno{4620}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Sasmurah that:the Messenger of Allah forbade selling animals in exchange for animal's ion credit}}
\hadithdefcmd{nasai}{4621}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ جَاءَ عَبْدٌ فَبَايَعَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الْهِجْرَةِ وَلاَ يَشْعُرُ النَّبِيُّ صلى الله عليه وسلم أَنَّهُ عَبْدٌ فَجَاءَ سَيِّدُهُ يُرِيدُهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ بِعْنِيهِ ‏"‏ ‏.‏ فَاشْتَرَاهُ بِعَبْدَيْنِ أَسْوَدَيْنِ ثُمَّ لَمْ يُبَايِعْ أَحَدًا بَعْدُ حَتَّى يَسْأَلَهُ أَعَبْدٌ هُوَ\hadithno{4621}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir Sair:"A slave came and gave his pledge to the Messenger of Allah to emigrate, and the Prophet did not realize that he was a slave. Then his master came looking for him. The Prophet said; 'Sell him to me.' So he bought him for two black slaves, then he did not accept until he had asked; 'Is he a slave?}}
\hadithdefcmd{nasai}{4622}{أَخْبَرَنَا يَحْيَى بْنُ حَكِيمٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ السَّلَفُ فِي حَبَلِ الْحَبَلَةِ رِبًا ‏"‏ ‏.‏\hadithno{4622}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Abbas that the Propher said:"Paying in advance for the offspring of the offspring of a pregnant animal (Habal al-Habalah) is Riba}}
\hadithdefcmd{nasai}{4623}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ حَبَلِ الْحَبَلَةِ ‏.‏\hadithno{4623}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn 'Umar that:the Prophet forbade selling the offspring of the offspring of a pregnant animal (Habal Al-Habalah)}}
\hadithdefcmd{nasai}{4624}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ حَبَلِ الْحَبَلَةِ ‏.‏\hadithno{4624}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn 'Umar that:the Prophet forbade selling the offspring of the offspring of a pregnant animal (Habal Al-Habalah)}}
\hadithdefcmd{nasai}{4625}{أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، - وَاللَّفْظُ لَهُ - عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ حَبَلِ الْحَبَلَةِ وَكَانَ بَيْعًا يَتَبَايَعُهُ أَهْلُ الْجَاهِلِيَّةِ كَانَ الرَّجُلُ يَبْتَاعُ جَزُورًا إِلَى أَنْ تُنْتَجَ النَّاقَةُ ثُمَّ تُنْتَجَ الَّتِي فِي بَطْنِهَا ‏.‏\hadithno{4625}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that:the Messenger of Allah forbade selling the offspring of the offspring of a pregnant animal (Habal Al-Habalah), which was a transaction practiced by the people of the Jahiliyyah, whereby a man would buy camel to slaughter, but he would wait until the she-camel had produced offspring and the offspring in her belly had then produced offspring}}
\hadithdefcmd{nasai}{4626}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ السِّنِينَ ‏.‏\hadithno{4626}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah forbade selling the produce several years in advance}}
\hadithdefcmd{nasai}{4627}{أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ حُمَيْدٍ الأَعْرَجِ، عَنْ سُلَيْمَانَ، - وَهُوَ ابْنُ عَتِيقٍ - عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ السِّنِينَ ‏.‏\hadithno{4627}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir that:the Messenger of Allah forbade selling the produce several years in advance}}
\hadithdefcmd{nasai}{4628}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، قَالَ حَدَّثَنَا عُمَارَةُ بْنُ أَبِي حَفْصَةَ، قَالَ أَنْبَأَنَا عِكْرِمَةُ، عَنْ عَائِشَةَ، قَالَتْ كَانَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بُرْدَيْنِ قِطْرِيَّيْنِ وَكَانَ إِذَا جَلَسَ فَعَرِقَ فِيهِمَا ثَقُلاَ عَلَيْهِ وَقَدِمَ لِفُلاَنٍ الْيَهُودِيِّ بَزٌّ مِنَ الشَّأْمِ فَقُلْتُ لَوْ أَرْسَلْتَ إِلَيْهِ فَاشْتَرَيْتَ مِنْهُ ثَوْبَيْنِ إِلَى الْمَيْسَرَةِ ‏.‏ فَأَرْسَلَ إِلَيْهِ فَقَالَ قَدْ عَلِمْتُ مَا يُرِيدُ مُحَمَّدٌ إِنَّمَا يُرِيدُ أَنْ يَذْهَبَ بِمَالِي أَوْ يَذْهَبَ بِهِمَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَذَبَ قَدْ عَلِمَ أَنِّي مِنْ أَتْقَاهُمْ لِلَّهِ وَآدَاهُمْ لِلأَمَانَةِ ‏"‏ ‏.‏\hadithno{4628}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah was wearing two Qitri garments which, if he sat and sweated, would become heavy (and uncomfortable). A Jewish man got some fabric from Ash-sham so I said: 'Why don't you send word to him to buy two garments from him, and pay him when things get easier?' So he sent word to him, but he said: 'I know what Muhammad wants; he wants to go away with my money and take them (the two garments).' The Messenger of Allah said; 'He is lying; he knows that I am one of the ones who fear Allah the most, and are most honest in fulfilling trusts}}
\hadithdefcmd{nasai}{4629}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، عَنْ خَالِدٍ، عَنْ حُسَيْنٍ الْمُعَلِّمِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ سَلَفٍ وَبَيْعٍ وَشَرْطَيْنِ فِي بَيْعٍ وَرِبْحِ مَا لَمْ يُضْمَنْ ‏.‏\hadithno{4629}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Amr bin shu'aib, from his father, from his grandfather, that:the Messenger of Allah prohibited lending on the condition of a sale, or to have two conditions in one transaction, or to profit from what you do not posses}}
\hadithdefcmd{nasai}{4630}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ حَدَّثَنَا أَيُّوبُ، قَالَ حَدَّثَنَا عَمْرُو بْنُ شُعَيْبٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ أَبِيهِ، حَتَّى ذَكَرَ عَبْدَ اللَّهِ بْنَ عَمْرٍو قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ سَلَفٌ وَبَيْعٌ وَلاَ شَرْطَانِ فِي بَيْعٍ وَلاَ رِبْحُ مَا لَمْ يُضْمَنْ ‏"‏ ‏.‏\hadithno{4630}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Amr bin shu'aib said:"My father told me, mar rating from his father, from his father (and he mentioned 'Abdullah bin 'Amr) that he said: "The Messenger of Allah said: "It is not permissible to lend on the condition of a sale, or to stipulate two conditions in one transaction, or to make a profit on that which you do not possess}}
\hadithdefcmd{nasai}{4631}{أَخْبَرَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ سَلَفٍ وَبَيْعٍ وَعَنْ شَرْطَيْنِ فِي بَيْعٍ وَاحِدٍ وَعَنْ بَيْعِ مَا لَيْسَ عِنْدَكَ وَعَنْ رِبْحِ مَا لَمْ يُضْمَنْ ‏.‏\hadithno{4631}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Shu'aib, from his father, that his grandfather said:"The Messenger of Allah forbade lending on the condition of a sale, selling what you do not have, and profiting on what you do not possess}}
\hadithdefcmd{nasai}{4632}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالُوا حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعَتَيْنِ فِي بَيْعَةٍ ‏.‏\hadithno{4632}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah forbade two transactions in one}}
\hadithdefcmd{nasai}{4633}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ حُسَيْنٍ، قَالَ حَدَّثَنَا يُونُسُ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ وَالْمُخَابَرَةِ وَعَنِ الثُّنْيَا إِلاَّ أَنْ تُعْلَمَ ‏.‏\hadithno{4633}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir that:the Prophet forbade Muhaqalah, Muzahanah, Mukhabarah and selling with an exception unless it is defined}}
\hadithdefcmd{nasai}{4634}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، وَأَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا ابْنُ عُلَيَّةَ، قَالَ أَنْبَأَنَا أَيُّوبُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُحَاقَلَةِ وَالْمُزَابَنَةِ وَالْمُخَابَرَةِ وَالْمُعَاوَمَةِ وَالثُّنْيَا وَرَخَّصَ فِي الْعَرَايَا ‏.‏\hadithno{4634}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah forbade Muhaqalah, Muzahanah, Mukhabarah, Mu'awamah, and selling with an exception unless it is defined but he gave concession allowing 'Araya}}
\hadithdefcmd{nasai}{4635}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا امْرِئٍ أَبَّرَ نَخْلاً ثُمَّ بَاعَ أَصْلَهَا فَلِلَّذِي أَبَّرَ ثَمَرُ النَّخْلِ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏"‏ ‏.‏\hadithno{4635}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn 'Umar that the Prophet said:"Any man who pollinates a date-palm tree then sells it, the fruits of the tree are for the one who pollinated it, unless the purchaser stipulated otherwise}}
\hadithdefcmd{nasai}{4636}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَنْبَأَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ ابْتَاعَ نَخْلاً بَعْدَ أَنْ تُؤَبَّرَ فَثَمَرَتُهَا لِلْبَائِعِ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ وَمَنْ بَاعَ عَبْدًا وَلَهُ مَالٌ فَمَالُهُ لِلْبَائِعِ إِلاَّ أَنْ يَشْتَرِطَ الْمُبْتَاعُ ‏"‏ ‏.‏\hadithno{4636}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salim, from his father that the Prophet said:"Whoever buys a date-palm tree after it has been pollinated, its fruits belong to the seller, unless the purchaser has stipulated otherwise. And whoever buys a slave who has wealth, his wealth belongs to the seller, unless the purchaser has stipulated otherwise. "(sahih)}}
\hadithdefcmd{nasai}{4637}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَنْبَأَنَا سَعْدَانُ بْنُ يَحْيَى، عَنْ زَكَرِيَّا، عَنْ عَامِرٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَأَعْيَا جَمَلِي فَأَرَدْتُ أَنْ أُسَيِّبَهُ فَلَحِقَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَدَعَا لَهُ فَضَرَبَهُ فَسَارَ سَيْرًا لَمْ يَسِرْ مِثْلَهُ فَقَالَ ‏"‏ بِعْنِيهِ بِوُقِيَّةٍ ‏"‏ ‏.‏ قُلْتُ لاَ ‏.‏ قَالَ ‏"‏ بِعْنِيهِ ‏"‏ ‏.‏ فَبِعْتُهُ بِوُقِيَّةٍ وَاسْتَثْنَيْتُ حُمْلاَنَهُ إِلَى الْمَدِينَةِ فَلَمَّا بَلَغْنَا الْمَدِينَةَ أَتَيْتُهُ بِالْجَمَلِ وَابْتَغَيْتُ ثَمَنَهُ ثُمَّ رَجَعْتُ فَأَرْسَلَ إِلَىَّ فَقَالَ ‏"‏ أَتُرَانِي إِنَّمَا مَاكَسْتُكَ لآخُذَ جَمَلَكَ خُذْ جَمَلَكَ وَدَرَاهِمَكَ ‏"‏ ‏.‏\hadithno{4637}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"I was with the Prophet on a journey, and my camel got tired. I thought I wanted to let it go, but the Messenger of "Allah met me and prayed for it (the camel) and hit it. Then it started to run like never before. He said: 'Sell it to me for one Uwqyah.' I said" 'No.' He said: 'Sell it to me.' So I sold it to him for one Uwqiyah but stipulated an exception, to ride it until we reached al-Madinah. When we reached Al-Medina, I brought the camel to him and asked him for its price, then I went back. He sent word to me saying; 'Do you think I bargained with you to take your camel?' Take your camel and your Dirhams}}
\hadithdefcmd{nasai}{4638}{أَخْبَرَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى بْنِ الطَّبَّاعِ، قَالَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مُغِيرَةَ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرٍ، قَالَ غَزَوْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم عَلَى نَاضِحٍ لَنَا ثُمَّ ذَكَرْتُ الْحَدِيثَ بِطُولِهِ ثُمَّ ذَكَرَ كَلاَمًا مَعْنَاهُ فَأُزْحِفَ الْجَمَلُ فَزَجَرَهُ النَّبِيُّ صلى الله عليه وسلم فَانْتَشَطَ حَتَّى كَانَ أَمَامَ الْجَيْشِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا جَابِرُ مَا أَرَى جَمَلَكَ إِلاَّ قَدِ انْتَشَطَ ‏"‏ ‏.‏ قُلْتُ بِبَرَكَتِكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ بِعْنِيهِ وَلَكَ ظَهْرُهُ حَتَّى تَقْدَمَ ‏"‏ ‏.‏ فَبِعْتُهُ وَكَانَتْ لِي إِلَيْهِ حَاجَةٌ شَدِيدَةٌ وَلَكِنِّي اسْتَحْيَيْتُ مِنْهُ فَلَمَّا قَضَيْنَا غَزَاتَنَا وَدَنَوْنَا اسْتَأْذَنْتُهُ بِالتَّعْجِيلِ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي حَدِيثُ عَهْدٍ بِعُرْسٍ ‏.‏ قَالَ ‏"‏ أَبِكْرًا تَزَوَّجْتَ أَمْ ثَيِّبًا ‏"‏ ‏.‏ قُلْتُ بَلْ ثَيِّبًا يَا رَسُولَ اللَّهِ إِنَّ عَبْدَ اللَّهِ بْنَ عَمْرٍو أُصِيبَ وَتَرَكَ جَوَارِيَ أَبْكَارًا فَكَرِهْتُ أَنْ آتِيَهُنَّ بِمِثْلِهِنَّ فَتَزَوَّجْتُ ثَيِّبًا تُعَلِّمُهُنَّ وَتُؤَدِّبُهُنَّ فَأَذِنَ لِي وَقَالَ لِي ‏"‏ ائْتِ أَهْلَكَ عِشَاءً ‏"‏ ‏.‏ فَلَمَّا قَدِمْتُ أَخْبَرْتُ خَالِي بِبَيْعِيَ الْجَمَلَ فَلاَمَنِي فَلَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم غَدَوْتُ بِالْجَمَلِ فَأَعْطَانِي ثَمَنَ الْجَمَلِ وَالْجَمَلَ وَسَهْمًا مَعَ النَّاسِ ‏.‏\hadithno{4638}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir said:"I went on a campaign with the Messenger of Allah riding a camel of ours," then he quoted the whole Hadih. Then he said words to the effect that: "The camel got tried and the Prophet hit it, so it became energetic and came to the front of the army. The Prophet said: 'O Jabir, I see that your camel has become energetic.' I said: "It is because of your blessing, O Messenger of Allah,' He said: 'Sell it to me, and you can ride it till we arrive (in Al-Madinah). 'So I sold it to him. I was in great need of it myself but I felt too shy to refuse. When we finished our campaign, and we were close to Al-Madinah, I asked his permission to go on ahead. I said: 'O Messenger of Allah, I am newly married.' He said; 'Have you married a virgin or a previously married woman?' I said: 'A previously married woman, O Messenger of Allah. 'Abdullah bin 'Arm died and left behind young druthers, and I did not like to bring to them someone who was like them, so I married a previously married woman who could teach the, and rise them with good manners.' So he gave me permission, and said to me; 'Go to When I arrived, I told my maternal uncle that I had sold the camel and he scolded me. When the Messenger of Allah came, I brought the camel to him, and he gave me the price of the camel, and the camel, and share (of the spoils of war) with the rest of the people}}
\hadithdefcmd{nasai}{4639}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ وَكُنْتُ عَلَى جَمَلٍ فَقَالَ ‏"‏ مَا لَكَ فِي آخِرِ النَّاسِ ‏"‏ ‏.‏ قُلْتُ أَعْيَا بَعِيرِي فَأَخَذَ بِذَنَبِهِ ثُمَّ زَجَرَهُ فَإِنْ كُنْتُ إِنَّمَا أَنَا فِي أَوَّلِ النَّاسِ يُهِمُّنِي رَأْسُهُ فَلَمَّا دَنَوْنَا مِنَ الْمَدِينَةِ قَالَ ‏"‏ مَا فَعَلَ الْجَمَلُ بِعْنِيهِ ‏"‏ ‏.‏ قُلْتُ لاَ بَلْ هُوَ لَكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ لاَ بَلْ بِعْنِيهِ ‏"‏ ‏.‏ قُلْتُ لاَ بَلْ هُوَ لَكَ ‏.‏ قَالَ ‏"‏ لاَ بَلْ بِعْنِيهِ قَدْ أَخَذْتُهُ بِوُقِيَّةٍ ارْكَبْهُ فَإِذَا قَدِمْتَ الْمَدِينَةَ فَائْتِنَا بِهِ ‏"‏ ‏.‏ فَلَمَّا قَدِمْتُ الْمَدِينَةَ جِئْتُهُ بِهِ فَقَالَ لِبِلاَلٍ ‏"‏ يَا بِلاَلُ زِنْ لَهُ أُوقِيَّةً وَزِدْهُ قِيرَاطًا ‏"‏ ‏.‏ قُلْتُ هَذَا شَىْءٌ زَادَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ يُفَارِقْنِي فَجَعَلْتُهُ فِي كِيسٍ فَلَمْ يَزَلْ عِنْدِي حَتَّى جَاءَ أَهْلُ الشَّامِ يَوْمَ الْحَرَّةِ فَأَخَذُوا مِنَّا مَا أَخَذُوا ‏.‏\hadithno{4639}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Jabir 'Abdullah said:"I was with the Messenger of Allah on a journey, and I was riding a camel. He said: 'Why are you at the back of the people?, I said: 'My camel is tired, He took hold of its tail and shouted at it, then I was at the front of the people, worrying that it would go ahead of the others. When we drew close to al-Madinah he said: 'What happened to the camel? Sell it to me.' I said, No, it is yours O Messenger of Allah.; He said, 'No, sell it tome. I said, 'No, it is yours, O Messenger of Allah.' He said: 'No, sell it to me. I will take it for one Uwqiyah but you (continue to) ride it. Then when you reach Al-Madinah, bring it to us.' So when I reached Al-Madinah, I brought it him. He said to Bilal: 'O Bilal, weight out for him one Uwqiyyah and add a Qirat.' I said: 'This is something extra that the Messenger of Allah gave to.' I kept it with me and put it in a bag, and it stayed with me until the people of Ash-Sham came on the Day of Al-Harrah and took from us what they took}}
\hadithdefcmd{nasai}{4640}{أَخْبَرَنَا مُحَمَّدُ بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أَدْرَكَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَكُنْتُ عَلَى نَاضِحٍ لَنَا سَوْءٍ فَقُلْتُ لاَ يَزَالُ لَنَا نَاضِحُ سَوْءٍ يَا لَهْفَاهُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ تَبِيعُنِيهِ يَا جَابِرُ ‏"‏ ‏.‏ قُلْتُ بَلْ هُوَ لَكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ اللَّهُمَّ اغْفِرْ لَهُ اللَّهُمَّ ارْحَمْهُ قَدْ أَخَذْتُهُ بِكَذَا وَكَذَا وَقَدْ أَعَرْتُكَ ظَهْرَهُ إِلَى الْمَدِينَةِ ‏"‏ ‏.‏ فَلَمَّا قَدِمْتُ الْمَدِينَةَ هَيَّأْتُهُ فَذَهَبْتُ بِهِ إِلَيْهِ فَقَالَ ‏"‏ يَا بِلاَلُ أَعْطِهِ ثَمَنَهُ ‏"‏ ‏.‏ فَلَمَّا أَدْبَرْتُ دَعَانِي فَخِفْتُ أَنْ يَرُدَّهُ فَقَالَ ‏"‏ هُوَ لَكَ ‏"‏ ‏.‏\hadithno{4640}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated tat Jabir Said:"The Messenger of Allah caught up with me when I was riding a bad camel of ours, and I said: 'We have a bad camel, mare's the pit! The Prophet said: Will you sell it to me, O Jabir?' I Said, 'No, It is yours, O Messenger of Allah.; He said: 'O Allah forgive him; O Allah, have mercy on him. I will buy it for such and such, and I will lend it to you to ride until (we reach) al-Madinah.' When Reached al-Madinah, I prepared it, and brought it to him, and he said: O Bilal, give him its price,' When I turned to leave, he called me back, and I was afraid that he would give it back at he said: 'It is yours}}
\hadithdefcmd{nasai}{4641}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ أَبِي قَالَ، حَدَّثَنَا أَبُو نَضْرَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا نَسِيرُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا عَلَى نَاضِحٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَبِيعُنِيهِ بِكَذَا وَكَذَا وَاللَّهُ يَغْفِرُ لَكَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ هُوَ لَكَ يَا نَبِيَّ اللَّهِ قَالَ ‏"‏ أَتَبِيعُنِيهِ بِكَذَا وَكَذَا وَاللَّهُ يَغْفِرُ لَكَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ هُوَ لَكَ يَا نَبِيَّ اللَّهِ ‏.‏ قَالَ ‏"‏ أَتَبِيعُنِيهِ بِكَذَا وَكَذَا وَاللَّهُ يَغْفِرُ لَكَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ هُوَ لَكَ ‏.‏ قَالَ أَبُو نَضْرَةَ وَكَانَتْ كَلِمَةً يَقُولُهَا الْمُسْلِمُونَ افْعَلْ كَذَا وَكَذَا وَاللَّهُ يَغْفِرُ لَكَ ‏.‏\hadithno{4641}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jabir bin 'Abdullah said:"We were traveling with the Messenger of Allah and I was riding a camel. The Messenger of Allah said to me: 'Will you sell it to me for such and such, may Allah forgive you?', I said, I said, 'Yes, it is yours, O Prophet of Allah.' He said: 'Will you sell it to me for such and such, may Allah forgive your?' I said: 'Yes, it is yours, O Prophet of "Allah.' He said: 'Will you sell it to me for such and such, may Allah forgives you?' I said: 'Yes, it is yours. '''(One of the narrators) Abu Nadrah said: "This became a phrase that was used by the Muslims: 'Do such and such, may Allah forgive you}}
\hadithdefcmd{nasai}{4642}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتِ اشْتَرَيْتُ بَرِيرَةَ فَاشْتَرَطَ أَهْلُهَا وَلاَءَهَا فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَعْتِقِيهَا فَإِنَّ الْوَلاَءَ لِمَنْ أَعْطَى الْوَرِقَ ‏"‏ ‏.‏ قَالَتْ فَأَعْتَقْتُهَا - قَالَتْ - فَدَعَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَخَيَّرَهَا مِنْ زَوْجِهَا فَاخْتَارَتْ نَفْسَهَا وَكَانَ زَوْجُهَا حُرًّا ‏.‏\hadithno{4642}\hadithgrade{Abu Ghuddah: Shadh; Al-Albani: Shadh; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Aishah said:"I bought Barirah and her masters stipulated that her loyalty (Wala) should be to them, I mentioned that to the Prophet and he said: 'Set her free, and loyalty belongs to the one who pays the silver.''' She said: "so I set her free. The Messenger of Allah called her and gave her the choice regarding her husband, and she chose herself. Her husband was a free man}}
\hadithdefcmd{nasai}{4643}{أَخْبَرَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ، قَالَ سَمِعْتُ الْقَاسِمَ، يُحَدِّثُ عَنْ عَائِشَةَ، أَنَّهَا أَرَادَتْ أَنْ تَشْتَرِيَ، بَرِيرَةَ لِلْعِتْقِ وَأَنَّهُمُ اشْتَرَطُوا وَلاَءَهَا فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اشْتَرِيهَا فَأَعْتِقِيهَا فَإِنَّ الْوَلاَءَ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ وَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِلَحْمٍ فَقِيلَ هَذَا تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ فَقَالَ ‏"‏ هُوَ لَهَا صَدَقَةٌ وَلَنَا هَدِيَّةٌ ‏"‏ ‏.‏ وَخُيِّرَتْ ‏.‏\hadithno{4643}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Aishah that:she wanted to buy Barirah to set her free, but they stipulated that her loyalty (should be to them. She mentioned that to the Messenger of Allah and the Messenger of Allah said: "Buy her, and wet her free and loyalty (Wala) belongs to the one who sets the slave free." Some meat was brought to the Messenger of and it was said that this had been given in charity to Bariirah. He said: "It is charity for her, and a gift for us." And she was given the choice}}
\hadithdefcmd{nasai}{4644}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ عَائِشَةَ، أَرَادَتْ أَنْ تَشْتَرِيَ، جَارِيَةً تَعْتِقُهَا فَقَالَ أَهْلُهَا نَبِيعُكِهَا عَلَى أَنَّ الْوَلاَءَ لَنَا ‏.‏ فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ يَمْنَعُكِ ذَلِكَ فَإِنَّ الْوَلاَءَ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏\hadithno{4644}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from'Abdullah bin 'Umar that 'Aishah wanted to but a slave woman to set her free, but her people said:"We will sell her to you on condition that her loyalty (Walla) is to us," She mentioned that top the Messenger of Allah and he said: "That should not stop you. Loyalty belongs to the one who sets the slave free}}
\hadithdefcmd{nasai}{4645}{أَخْبَرَنَا أَحْمَدُ بْنُ حَفْصِ بْنِ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنِي إِبْرَاهِيمُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الْمَغَانِمِ حَتَّى تُقْسَمَ وَعَنِ الْحَبَالَى أَنْ يُوطَأْنَ حَتَّى يَضَعْنَ مَا فِي بُطُونِهِنَّ وَعَنْ لَحْمِ كُلِّ ذِي نَابٍ مِنَ السِّبَاعِ ‏.‏\hadithno{4645}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah forbade selling something from the spoils of war prior to its distribution, having intercourse with a pregnant woman until she gives birth, and (eating) the flesh of any predator that has fangs}}
\hadithdefcmd{nasai}{4646}{أَخْبَرَنَا عَمْرُو بْنُ زُرَارَةَ، قَالَ أَنْبَأَنَا إِسْمَاعِيلُ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشُّفْعَةُ فِي كُلِّ شِرْكٍ رَبْعَةٍ أَوْ حَائِطٍ لاَ يَصْلُحُ لَهُ أَنْ يَبِيعَ حَتَّى يُؤْذِنَ شَرِيكَهُ فَإِنْ بَاعَ فَهُوَ أَحَقُّ بِهِ حَتَّى يُؤْذِنَهُ ‏"‏ ‏.‏\hadithno{4646}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih Muslim}\hadithtrans{it was narrated that Jabir said:"The Messenger of Allah said: 'Pre-emption is to be given in everything that is shared, whether it is a house or a garden. It is not right to sell it before informing one's partner, and if he sells it he (the partner) has more right to it, unless he gives Permission to sell it to someone else}}
\hadithdefcmd{nasai}{4647}{أَخْبَرَنَا الْهَيْثَمُ بْنُ مَرْوَانَ بْنِ الْهَيْثَمِ بْنِ عِمْرَانَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ بَكَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ حَمْزَةَ - عَنِ الزُّبَيْدِيِّ، أَنَّ الزُّهْرِيَّ، أَخْبَرَهُ عَنْ عُمَارَةَ بْنِ خُزَيْمَةَ، أَنَّ عَمَّهُ، حَدَّثَهُ - وَهُوَ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم - أَنَّ النَّبِيَّ صلى الله عليه وسلم ابْتَاعَ فَرَسًا مِنْ أَعْرَابِيٍّ وَاسْتَتْبَعَهُ لِيَقْبِضَ ثَمَنَ فَرَسِهِ فَأَسْرَعَ النَّبِيُّ صلى الله عليه وسلم وَأَبْطَأَ الأَعْرَابِيُّ وَطَفِقَ الرِّجَالُ يَتَعَرَّضُونَ لِلأَعْرَابِيِّ فَيَسُومُونَهُ بِالْفَرَسِ وَهُمْ لاَ يَشْعُرُونَ أَنَّ النَّبِيَّ صلى الله عليه وسلم ابْتَاعَهُ حَتَّى زَادَ بَعْضُهُمْ فِي السَّوْمِ عَلَى مَا ابْتَاعَهُ بِهِ مِنْهُ فَنَادَى الأَعْرَابِيُّ النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنْ كُنْتَ مُبْتَاعًا هَذَا الْفَرَسَ وَإِلاَّ بِعْتُهُ ‏.‏ فَقَامَ النَّبِيُّ صلى الله عليه وسلم حِينَ سَمِعَ نِدَاءَهُ فَقَالَ ‏"‏ أَلَيْسَ قَدِ ابْتَعْتُهُ مِنْكَ ‏"‏ ‏.‏ قَالَ لاَ وَاللَّهِ مَا بِعْتُكَهُ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قَدِ ابْتَعْتُهُ مِنْكَ ‏"‏ ‏.‏ فَطَفِقَ النَّاسُ يَلُوذُونَ بِالنَّبِيِّ صلى الله عليه وسلم وَبِالأَعْرَابِيِّ وَهُمَا يَتَرَاجَعَانِ وَطَفِقَ الأَعْرَابِيُّ يَقُولُ هَلُمَّ شَاهِدًا يَشْهَدُ أَنِّي قَدْ بِعْتُكَهُ ‏.‏ قَالَ خُزَيْمَةُ بْنُ ثَابِتٍ أَنَا أَشْهَدُ أَنَّكَ قَدْ بِعْتَهُ ‏.‏ قَالَ فَأَقْبَلَ النَّبِيُّ صلى الله عليه وسلم عَلَى خُزَيْمَةَ فَقَالَ ‏"‏ لِمَ تَشْهَدُ ‏"‏ ‏.‏ قَالَ بِتَصْدِيقِكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم شَهَادَةَ خُزَيْمَةَ شَهَادَةَ رَجُلَيْنِ ‏.‏\hadithno{4647}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Umarah bin Khuzaimah that his paternal uncle, who was one of the companions of the Prophet told him, that:the Prophet bought a horse from a Bedouin and asked him to follow him, so that he could pay him for the horse. The Prophet hastened but the Bedouin was slow. Men started to talk to the Bedouin and make offers for the horse, and they did not realize that the Prophet had bought it, until some of them offered more than the Prophet had bought it for. Then the Bedouin called out to the Prophet and said; "Are you going to buy this horse or shall I sell it?" The Prophet stood up when he heard him calling and said: "Have I not bought it from you?" He said: 'No, by Allah, I have not sold it to you, and the Prophet said "I bought it from you." The people started to gaiter around the Prophet and the Bedouion as they were talking, and the Bedouin started to say: "Bring a witness who will testify that you bought it. " Khuzaimah bin habit said: "I bear witness that you bought it" The Prophet turned to Khunzimah and said: "Why are you bearing witness?" He said: "Because I know that you are truthful, O Messenger of Allah" made the testimony of Khuzaimah equivalent to the testimony of two men. (sahih)}}
\hadithdefcmd{nasai}{4648}{أَخْبَرَنَا مُحَمَّدُ بْنُ إِدْرِيسَ، قَالَ حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، قَالَ حَدَّثَنَا أَبِي، عَنْ أَبِي عُمَيْسٍ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدِ بْنِ الأَشْعَثِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ عَبْدُ اللَّهِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا اخْتَلَفَ الْبَيِّعَانِ وَلَيْسَ بَيْنَهُمَا بَيِّنَةٌ فَهُوَ مَا يَقُولُ رَبُّ السِّلْعَةِ أَوْ يَتْرُكَا ‏"‏ ‏.‏\hadithno{4648}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah said:"I heard the Messenger of Allah say: 'If the two parties to a transaction disagree, and neither of them has any proof, then it is as the owner of the goods says, or they may cancel it}}
\hadithdefcmd{nasai}{4649}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، وَيُوسُفُ بْنُ سَعِيدٍ، وَعَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، - وَاللَّفْظُ لإِبْرَاهِيمَ - قَالُوا حَدَّثَنَا حَجَّاجٌ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي إِسْمَاعِيلُ بْنُ أُمَيَّةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُبَيْدٍ، قَالَ حَضَرْنَا أَبَا عُبَيْدَةَ بْنَ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ أَتَاهُ رَجُلاَنِ تَبَايَعَا سِلْعَةً فَقَالَ أَحَدُهُمَا أَخَذْتُهَا بِكَذَا وَبِكَذَا ‏.‏ وَقَالَ هَذَا بِعْتُهَا بِكَذَا وَكَذَا ‏.‏ فَقَالَ أَبُو عُبَيْدَةَ أُتِيَ ابْنُ مَسْعُودٍ فِي مِثْلِ هَذَا فَقَالَ حَضَرْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِمِثْلِ هَذَا فَأَمَرَ الْبَائِعَ أَنْ يَسْتَحْلِفَ ثُمَّ يَخْتَارَ الْمُبْتَاعُ فَإِنْ شَاءَ أَخَذَ وَإِنْ شَاءَ تَرَكَ ‏.‏\hadithno{4649}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Abdul-Malik bin'Ubaid said:"We were with Abu 'Ubaidah bin 'Abdullah bin Mas'ud when two men who were involved in a transaction came to him. One of them said: 'I bought it for such and such', and the other said; 'I sold it to him for such and such,' Abu 'Ubaidah said" 'something like this was brought to Ibn Masud, and he said; I was with something like this was brought to him. He told the seller to swear an oath, them he gave the purchaser the choice; If he wished, he could buy it, and if he wished he could cancel (the transaction)}}
\hadithdefcmd{nasai}{4650}{أَخْبَرَنَا أَحْمَدُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتِ اشْتَرَى رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ يَهُودِيٍّ طَعَامًا بِنَسِيئَةٍ وَأَعْطَاهُ دِرْعًا لَهُ رَهْنًا ‏.‏\hadithno{4650}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"The Messenger of Allah bought some food from a Jew on credit, and he gave him a shield of his as a pledge}}
\hadithdefcmd{nasai}{4651}{أَخْبَرَنَا يُوسُفُ بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا سُفْيَانُ بْنُ حَبِيبٍ، عَنْ هِشَامٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَدِرْعُهُ مَرْهُونَةٌ عِنْدَ يَهُودِيٍّ بِثَلاَثِينَ صَاعًا مِنْ شَعِيرٍ لأَهْلِهِ ‏.‏\hadithno{4651}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah died when his shield was in pledge with a Jew for thirty Sa's of barley for his family}}
\hadithdefcmd{nasai}{4652}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أَعْتَقَ رَجُلٌ مِنْ بَنِي عُذْرَةَ عَبْدًا لَهُ عَنْ دُبُرٍ، فَبَلَغَ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَلَكَ مَالٌ غَيْرُهُ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ يَشْتَرِيهِ مِنِّي ‏"‏ ‏.‏ فَاشْتَرَاهُ نُعَيْمُ بْنُ عَبْدِ اللَّهِ الْعَدَوِيُّ بِثَمَانِمِائَةِ دِرْهَمٍ فَجَاءَ بِهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَدَفَعَهَا إِلَيْهِ ثُمَّ قَالَ ‏"‏ ابْدَأْ بِنَفْسِكَ فَتَصَدَّقْ عَلَيْهَا فَإِنْ فَضَلَ شَىْءٌ فَلأَهْلِكَ فَإِنْ فَضَلَ مِنْ أَهْلِكَ شَىْءٌ فَلِذِي قَرَابَتِكَ فَإِنْ فَضَلَ مِنْ ذِي قَرَابَتِكَ شَىْءٌ فَهَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ يَقُولُ بَيْنَ يَدَيْكَ وَعَنْ يَمِينِكَ وَعَنْ شِمَالِكَ ‏.‏\hadithno{4652}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir said:"A man from Banu 'Adhrah stated that a slave of his was to be set free after he died. News of that reached the Messenger of Allah and he said: 'Do you have any other property basides him/' He said? 'No.' the Messenger of Allah said; 'Who will buy him from me?' Nu'aim bin 'Abdullah Al-Adawi bought him for eight hundred Dirhams, which the Messenger of Allah brought and gave to him (the former owner). Then the Messenger of Allah said: 'Start with yourself and give charity to (yourself). If there is anything left over, then give it to your family; if there is anything left over from your family, then give it to your relatives; if there is anything left over from your relatives, then give it to such and such,' saying 'In front of you, to your right and to your left}}
\hadithdefcmd{nasai}{4653}{أَخْبَرَنَا زِيَادُ بْنُ أَيُّوبَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ يُقَالُ لَهُ أَبُو مَذْكُورٍ أَعْتَقَ غُلامًا لَهُ عَنْ دُبُرٍ يُقَالُ لَهُ يَعْقُوبُ لَمْ يَكُنْ لَهُ مَالٌ غَيْرُهُ فَدَعَا بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَنْ يَشْتَرِيهِ ‏"‏ ‏.‏ فَاشْتَرَاهُ نُعَيْمُ بْنُ عَبْدِ اللَّهِ بِثَمَانِمِائَةِ دِرْهَمٍ فَدَفَعَهَا إِلَيْهِ وَقَالَ ‏"‏ إِذَا كَانَ أَحَدُكُمْ فَقِيرًا فَلْيَبْدَأْ بِنَفْسِهِ فَإِنْ كَانَ فَضْلاً فَعَلَى عِيَالِهِ فَإِنْ كَانَ فَضْلاً فَعَلَى قَرَابَتِهِ أَوْ عَلَى ذِي رَحِمِهِ فَإِنْ كَانَ فَضْلاً فَهَا هُنَا وَهَا هُنَا ‏"‏ ‏.‏\hadithno{4653}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that:a man from among the Ansar who was called Abu (Madhkur) stated that a slave of his who was called Ya'qub was to be set free after he died, and he did not own any other property apart from him. The Messenger of Allah called for him (the slave) to be brought and he said: "Who will buy him?" Nu'aim bin 'Abdullah bought him for eight hundred dirhams, and he gave it to him and said: "If one of you is poor, let him start with himself; if there is anything left over, (let him give it) to his dependents; if there is anything left over, (let him give it) to his relatives; and if there is anything left over, (let him give it) here and there}}
\hadithdefcmd{nasai}{4654}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، وَابْنُ أَبِي خَالِدٍ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَاعَ الْمُدَبَّرَ ‏.‏\hadithno{4654}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Jabir that:the Prophet sold a Mudabbar}}
\hadithdefcmd{nasai}{4655}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ بَرِيرَةَ جَاءَتْ عَائِشَةَ تَسْتَعِينُهَا فِي كِتَابَتِهَا شَيْئًا فَقَالَتْ لَهَا عَائِشَةُ ارْجِعِي إِلَى أَهْلِكِ فَإِنْ أَحَبُّوا أَنْ أَقْضِيَ عَنْكِ كِتَابَتَكِ وَيَكُونَ وَلاَؤُكِ لِي فَعَلْتُ فَذَكَرَتْ ذَلِكَ بَرِيرَةُ لأَهْلِهَا فَأَبَوْا وَقَالُوا إِنْ شَاءَتْ أَنْ تَحْتَسِبَ عَلَيْكِ فَلْتَفْعَلْ وَيَكُونَ لَنَا وَلاَؤُكِ ‏.‏ فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ابْتَاعِي وَأَعْتِقِي فَإِنَّ الْوَلاَءَ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا بَالُ أَقْوَامٍ يَشْتَرِطُونَ شُرُوطًا لَيْسَتْ فِي كِتَابِ اللَّهِ فَمَنِ اشْتَرَطَ شَيْئًا لَيْسَ فِي كِتَابِ اللَّهِ فَلَيْسَ لَهُ وَإِنِ اشْتَرَطَ مِائَةَ شَرْطٍ وَشَرْطُ اللَّهِ أَحَقُّ وَأَوْثَقُ ‏"‏ ‏.‏\hadithno{4655}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from'Aishah that Barirah came to 'Aishah asking her to help her with her contract of manumission.' Aishah said:"Go back to your masters, and if they agree to let me pay off your contract of manumission, and let your loyalty be to me, then I will do it" Barirah told her masters about that, but they refused and said: "If she wants to seek reward (with Allah) by freeing you, let her do so, but your loyalty will be to us." She told the Messenger of Allah about that , and the Messenger of Allah said to her; "Buy her and set her free, and loyalty belongs to the one who set the slave free," Then the Messenger of Allah said: "What is the matter with people who stipulate conditions that are not in the Book of Allah? Whoever stipulates something that is not in the Book of Allah, it is not valid even if he stipulates one hundred conditions? The condition of Allah is more deserving of being followed and is more hinting}}
\hadithdefcmd{nasai}{4656}{أَخْبَرَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي رِجَالٌ، مِنْ أَهْلِ الْعِلْمِ مِنْهُمْ يُونُسُ وَاللَّيْثُ أَنَّ ابْنَ شِهَابٍ أَخْبَرَهُمْ عَنْ عُرْوَةَ عَنْ عَائِشَةَ أَنَّهَا قَالَتْ جَاءَتْ بَرِيرَةُ إِلَىَّ فَقَالَتْ يَا عَائِشَةُ إِنِّي كَاتَبْتُ أَهْلِي عَلَى تِسْعِ أَوَاقٍ فِي كُلِّ عَامٍ أُوقِيَّةٌ فَأَعِينِينِي ‏.‏ وَلَمْ تَكُنْ قَضَتْ مِنْ كِتَابَتِهَا شَيْئًا فَقَالَتْ لَهَا عَائِشَةُ وَنَفِسَتْ فِيهَا ارْجِعِي إِلَى أَهْلِكِ فَإِنْ أَحَبُّوا أَنْ أُعْطِيَهُمْ ذَلِكَ جَمِيعًا وَيَكُونَ وَلاَؤُكِ لِي فَعَلْتُ ‏.‏ فَذَهَبَتْ بَرِيرَةُ إِلَى أَهْلِهَا فَعَرَضَتْ ذَلِكَ عَلَيْهِمْ فَأَبَوْا وَقَالُوا إِنْ شَاءَتْ أَنْ تَحْتَسِبَ عَلَيْكِ فَلْتَفْعَلْ وَيَكُونَ ذَلِكَ لَنَا ‏.‏ فَذَكَرَتْ ذَلِكَ عَائِشَةُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ لاَ يَمْنَعُكِ ذَلِكَ مِنْهَا ابْتَاعِي وَأَعْتِقِي فَإِنَّ الْوَلاَءَ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏ فَفَعَلَتْ وَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّاسِ فَحَمِدَ اللَّهَ تَعَالَى ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَمَا بَالُ النَّاسِ يَشْتَرِطُونَ شُرُوطًا لَيْسَتْ فِي كِتَابِ اللَّهِ مَنِ اشْتَرَطَ شَرْطًا لَيْسَ فِي كِتَابِ اللَّهِ فَهُوَ بَاطِلٌ وَإِنْ كَانَ مِائَةَ شَرْطٍ قَضَاءُ اللَّهِ أَحَقُّ وَشَرْطُ اللَّهِ أَوْثَقُ وَإِنَّمَا الْوَلاَءُ لِمَنْ أَعْتَقَ ‏"‏ ‏.‏\hadithno{4656}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that 'Aishah said:"Barirah came to me and said: 'O 'Sishah, I have drawn up a contract of manumission with my master, (to buy my freedom) in return for nine Uwqiyah, one Uwqiyah to be paid each year; help me,' she had not yet paid anything toward her contract of manumission.' 'Aishah, who liked her and wanted to help her, said: 'Go back to your masters and if they agree to let me pay the whole sum and that your loyalty will be to me, I will do it.' So Barirah went to her masters and suggested that to them, but they refused and said: 'if she wants to seek reward (with Allah) by freeing you, let her do so, but (you loyalty) will be to us, 'Aishah told the Messenger of Allah about that and he said: 'Do not let that stop you. Buy her and set her free, and loyalty belongs to the one who sets the slave free.; so she did that, then the Messenger of Allah stood up before the people, praised and glorified Allah, then said: 'What is the matter with people who stipulate conditions that are not in the Book of Allah? Whoever stipulates conditions that are not in even if there are a hundred conditions? The decree of Allah takes priority, and the conditions of Allah binding. And loyalty belongs to the one who sets the slaves free}}
\hadithdefcmd{nasai}{4657}{أَخْبَرَنَا إِسْمَاعِيلُ بْنُ مَسْعُودٍ، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْوَلاَءِ وَعَنْ هِبَتِهِ ‏.‏\hadithno{4657}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{it was narrated from 'Abdullah that:the Messenger of Allah forbade selling loyalty or giving it away}}
\hadithdefcmd{nasai}{4658}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْوَلاَءِ وَعَنْ هِبَتِهِ ‏.‏\hadithno{4658}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn 'Umar that:the Messenger of Allah forbade selling loyalty or giving it away. (Shah)}}
\hadithdefcmd{nasai}{4659}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ شُعْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ الْوَلاَءِ وَعَنْ هِبَتِهِ ‏.‏\hadithno{4659}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah forbade selling loyalty or giving it away." (Sahih)}}
\hadithdefcmd{nasai}{4660}{أَخْبَرَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى السِّيْنَانِيُّ، عَنْ حُسَيْنِ بْنِ وَاقِدٍ، عَنْ أَيُّوبَ السَّخْتِيَانِيِّ، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ الْمَاءِ ‏.‏\hadithno{4660}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir that:the Messenger of Allah forbade selling water}}
\hadithdefcmd{nasai}{4661}{أَخْبَرَنَا قُتَيْبَةُ، وَعَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، - وَاللَّفْظُ لَهُ - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ سَمِعْتُ أَبَا الْمِنْهَالِ، يَقُولُ سَمِعْتُ إِيَاسَ بْنَ عُمَرَ، - وَقَالَ مَرَّةً ابْنَ عَبْدٍ - يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ بَيْعِ الْمَاءِ ‏.‏ قَالَ قُتَيْبَةُ لَمْ أَفْقَهْ عَنْهُ بَعْضَ حُرُوفِ أَبِي الْمِنْهَالِ كَمَا أَرَدْتُ ‏.‏\hadithno{4661}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Al-Minhal said:"I heard Iyas bin 'Umar" - and on one occasion he said: "Ibn 'Abd - say: 'I heard the Messenger of Allah forbid the sale of water}}
\hadithdefcmd{nasai}{4662}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا دَاوُدُ، عَنْ عَمْرٍو، عَنْ أَبِي الْمِنْهَالِ، عَنْ إِيَاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ فَضْلِ الْمَاءِ ‏.‏ وَبَاعَ قَيِّمُ الْوَهْطِ فَضْلَ مَاءِ الْوَهْطِ فَكَرِهَهُ عَبْدُ اللَّهِ بْنُ عَمْرٍو ‏.‏\hadithno{4662}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Iyas that:the Messenger of Allah forbade selling surplus water. The keeper of al-Wahat sold the surplus water of al-Wahat, and 'Abdullah bin 'Arm disapproved of that}}
\hadithdefcmd{nasai}{4663}{أَخْبَرَنَا إِبْرَاهِيمُ بْنُ الْحَسَنِ، عَنْ حَجَّاجٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، أَنَّ أَبَا الْمِنْهَالِ، أَخْبَرَهُ أَنَّ إِيَاسَ بْنَ عَبْدٍ صَاحِبَ النَّبِيِّ صلى الله عليه وسلم قَالَ لاَ تَبِيعُوا فَضْلَ الْمَاءِ فَإِنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ بَيْعِ فَضْلِ الْمَاءِ ‏.‏\hadithno{4663}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Iya bin 'Abd, the companion of the Prophet said:"do not sell surplus water, for the Prophet forbade the sale of surplus water}}
\hadithdefcmd{nasai}{4664}{أَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنِ ابْنِ وَعْلَةَ الْمِصْرِيِّ، أَنَّهُ سَأَلَ ابْنَ عَبَّاسٍ عَمَّا يُعْصَرُ مِنَ الْعِنَبِ قَالَ ابْنُ عَبَّاسٍ أَهْدَى رَجُلٌ لِرَسُولِ اللَّهِ صلى الله عليه وسلم رَاوِيَةَ خَمْرٍ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلْ عَلِمْتَ أَنَّ اللَّهَ عَزَّ وَجَلَّ حَرَّمَهَا ‏"‏ ‏.‏ فَسَارَّ وَلَمْ أَفْهَمْ مَا سَارَّ كَمَا أَرَدْتُ فَسَأَلْتُ إِنْسَانًا إِلَى جَنْبِهِ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ بِمَ سَارَرْتَهُ ‏"‏ ‏.‏ قَالَ أَمَرْتُهُ أَنْ يَبِيعَهَا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ الَّذِي حَرَّمَ شُرْبَهَا حَرَّمَ بَيْعَهَا ‏"‏ ‏.‏ فَفَتَحَ الْمَزَادَتَيْنِ حَتَّى ذَهَبَ مَا فِيهِمَا ‏.‏\hadithno{4664}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Wa'lah Misri that he asked Ibn 'Abbas about what is produced from grapes. Ibn'Abbas said:"A man gave the Messenger of Allah a skin full of wine, and the Prophet said to him;' did you know that Allah has forbidden it?' He whispered something and I did not understand what he whispered as I wanted to. I asked a person who was beside him and the Prophet said to him; 'What are you whispering about?' He said: 'I told him to sell it.' The Prophet said: 'The One Who forbade drinking it also forbade selling it.' Then he opened the vessels and poured out their contents}}
\hadithdefcmd{nasai}{4665}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا نَزَلَتْ آيَاتُ الرِّبَا قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ فَتَلاَهُنَّ عَلَى النَّاسِ ثُمَّ حَرَّمَ التِّجَارَةَ فِي الْخَمْرِ ‏.‏\hadithno{4665}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that 'Aishah said:"When the Verses of Riba were revealed, the Messenger of Allah (ﷺ) stood up on the Minbar and recited them to the people, then he forbade dealing in wine}}
\hadithdefcmd{nasai}{4666}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، أَنَّهُ سَمِعَ أَبَا مَسْعُودٍ، عُقْبَةَ بْنَ عَمْرٍو قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ثَمَنِ الْكَلْبِ وَمَهْرِ الْبَغِيِّ وَحُلْوَانِ الْكَاهِنِ ‏.‏\hadithno{4666}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Mas'us 'Uqbah bin 'Amr said:"The Messenger of Allah forbade the price of a dog, the gift of a female fornicator, and the fee of a fortuneteller}}
\hadithdefcmd{nasai}{4667}{أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْحَكَمِ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ عِيسَى، قَالَ أَنْبَأَنَا الْمُفَضَّلُ بْنُ فَضَالَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي أَشْيَاءَ حَرَّمَهَا ‏ "‏ وَثَمَنِ الْكَلْبِ ‏"‏ ‏.‏\hadithno{4667}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn 'Abbas said:"The Messenger of Allah said - among the things that be forbade - 'And the price of a dog}}
\hadithdefcmd{nasai}{4668}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، قَالَ أَنْبَأَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ ثَمَنِ الْكَلْبِ وَالسِّنَّوْرِ إِلاَّ كَلْبَ صَيْدٍ ‏.‏ قَالَ أَبُو عَبْدِ الرَّحْمَنِ هَذَا مُنْكَرٌ ‏.‏\hadithno{4668}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin 'Adbullah that:the Messenger of Allah forbade the price of dogs and cats, except hunting dogs. (Da'if) Abu 'Abdur-Rahman (An-Nasa'i) said: This is Munkar}}
\hadithdefcmd{nasai}{4669}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَامَ الْفَتْحِ وَهُوَ بِمَكَّةَ ‏"‏ إِنَّ اللَّهَ وَرَسُولَهُ حَرَّمَ بَيْعَ الْخَمْرِ وَالْمَيْتَةِ وَالْخِنْزِيرِ وَالأَصْنَامِ ‏"‏ ‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ شُحُومَ الْمَيْتَةِ فَإِنَّهُ يُطْلَى بِهَا السُّفُنُ وَيُدَّهَنُ بِهَا الْجُلُودُ وَيَسْتَصْبِحُ بِهَا النَّاسُ ‏.‏ فَقَالَ ‏"‏ لاَ هُوَ حَرَامٌ ‏"‏ ‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ ذَلِكَ ‏"‏ قَاتَلَ اللَّهُ الْيَهُودَ إِنَّ اللَّهَ عَزَّ وَجَلَّ لَمَّا حَرَّمَ عَلَيْهِمْ شُحُومَهَا جَمَّلُوهُ ثُمَّ بَاعُوهُ فَأَكَلُوا ثَمَنَهُ ‏"‏ ‏.‏\hadithno{4669}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir bin 'Abdullah that he heard the Messenger of Allah say, when he was in Makkah during the Year of the Conquest:"Allah and His Messenger have forbidden the sale of wine, dead animals, pigs and idols." It was said: "O messenger of Allah, what do you thing about the fat of the dead animal, for ships are caulked with it, skins are daubed with it and people use it in their lamps." He said: "No, it is Haram." And the Messenger of Allah then said: "My Allah curse the Jews, for when Allah, the Mighty and Sublime, forbade the meat (of dead animals) to them, they melted it down and sold it, and consumed its price}}
\hadithdefcmd{nasai}{4670}{أَخْبَرَنِي إِبْرَاهِيمُ بْنُ الْحَسَنِ، عَنْ حَجَّاجٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ بَيْعِ ضِرَابِ الْجَمَلِ وَعَنْ بَيْعِ الْمَاءِ وَبَيْعِ الأَرْضِ لِلْحَرْثِ يَبِيعُ الرَّجُلُ أَرْضَهُ وَمَاءَهُ فَعَنْ ذَلِكَ نَهَى النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{4670}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir said:"The Messenger of Allah forbade charging stud fees for a camel, the sale of water, the renting of land for cultivation. Selling one's land and water, this is what the Prophet forbade}}
\hadithdefcmd{nasai}{4671}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ عَلِيِّ بْنِ الْحَكَمِ، ح وَأَنْبَأَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَلِيِّ بْنِ الْحَكَمِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ عَسْبِ الْفَحْلِ ‏.‏\hadithno{4671}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah forbade charging stud fees for a stallion}}
\hadithdefcmd{nasai}{4672}{أَخْبَرَنَا عِصْمَةُ بْنُ الْفَضْلِ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ إِبْرَاهِيمَ بْنِ حُمَيْدٍ الرُّؤَاسِيِّ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ جَاءَ رَجُلٌ مِنْ بَنِي الصَّعْقِ أَحَدِ بَنِي كِلاَبٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ عَنْ عَسْبِ الْفَحْلِ فَنَهَاهُ عَنْ ذَلِكَ فَقَالَ إِنَّا نُكْرَمُ عَلَى ذَلِكَ ‏.‏\hadithno{4672}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:"A man from Banu As-Sa'q, one of Banu Kilab, came to the Messenger of Allah and asked him about charging stud fees for a stallion. He forbade him to do that, but he said: 'We give payment for that}}
\hadithdefcmd{nasai}{4673}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، عَنْ مُحَمَّدٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْمُغِيرَةِ، قَالَ سَمِعْتُ ابْنَ أَبِي نُعْمٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ كَسْبِ الْحَجَّامِ وَعَنْ ثَمَنِ الْكَلْبِ وَعَنْ عَسْبِ الْفَحْلِ ‏.‏\hadithno{4673}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih Hadith; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah said:"The Messenger of Allah forbade the earnings of a cupper, the price of a dog and stud fees for a stallion}}
\hadithdefcmd{nasai}{4674}{أَخْبَرَنِي مُحَمَّدُ بْنُ عَلِيِّ بْنِ مَيْمُونٍ، قَالَ حَدَّثَنَا مُحَمَّدٌ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ هِشَامٍ، عَنِ ابْنِ أَبِي نُعْمٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ عَسْبِ الْفَحْلِ ‏.‏\hadithno{4674}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that (Abu Hurairah) said:"The Messenger of Allah forbade the price of a dog and stud fees for a stallion}}
\hadithdefcmd{nasai}{4675}{أَخْبَرَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي حَازِمٍ، ‏\{‏ عَنْ أَبِي هُرَيْرَةَ، ‏\}‏ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ثَمَنِ الْكَلْبِ وَعَسْبِ الْفَحْلِ ‏.‏\hadithno{4675}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that (Abu Hurairah) said:"The Messenger of Allah forbade the price of a dog and stud fees for a stallion}}
\hadithdefcmd{nasai}{4676}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى، عَنْ أَبِي بَكْرِ بْنِ حَزْمٍ، عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا امْرِئٍ أَفْلَسَ ثُمَّ وَجَدَ رَجُلٌ عِنْدَهُ سِلْعَتَهُ بِعَيْنِهَا فَهُوَ أَوْلَى بِهِ مِنْ غَيْرِهِ ‏"‏ ‏.‏\hadithno{4676}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"If a person becomes bankrupt, then a man finds the goods that he sold to him with him, he has more right to them than anyone else}}
\hadithdefcmd{nasai}{4677}{أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ خَالِدٍ، وَإِبْرَاهِيمُ بْنُ الْحَسَنِ، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي ابْنُ أَبِي حُسَيْنٍ، أَنَّ أَبَا بَكْرِ بْنَ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، أَخْبَرَهُ أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ حَدَّثَهُ عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَدِيثِ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم عَنِ الرَّجُلِ، يُعْدِمُ إِذَا وُجِدَ عِنْدَهُ الْمَتَاعُ بِعَيْنِهِ وَعَرَفَهُ أَنَّهُ لِصَاحِبِهِ الَّذِي بَاعَهُ ‏.‏\hadithno{4677}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah from the Prophet, that:if a man becomes bankrupt, then a specific item is found with him, and is recognized, then it belongs to the one who sold it to him}}
\hadithdefcmd{nasai}{4678}{أَخْبَرَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالَ أَنْبَأَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي اللَّيْثُ بْنُ سَعْدٍ، وَعَمْرُو بْنُ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ أُصِيبَ رَجُلٌ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ثِمَارٍ ابْتَاعَهَا وَكَثُرَ دَيْنُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَصَدَّقُوا عَلَيْهِ ‏"‏ ‏.‏ فَتَصَدَّقُوا عَلَيْهِ وَلَمْ يَبْلُغْ ذَلِكَ وَفَاءَ دَيْنِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خُذُوا مَا وَجَدْتُمْ وَلَيْسَ لَكُمْ إِلاَّ ذَلِكَ ‏"‏ ‏.‏\hadithno{4678}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated the Abu Sa'eed Al-Khudri said:"At the time of the Messenger of Allah, a man suffered loss of some fruit that he had purchased, and his debts increased. "The Messenger of Allah said: 'Give him charity.' So the people gave him charity, but that was not enough to pay off his debts. 'The Messenger of Allah said: 'Take what you find, but you have no right to more than that."' (meaning his creditors)}}
\hadithdefcmd{nasai}{4679}{أَخْبَرَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عِكْرِمَةَ بْنِ خَالِدٍ، قَالَ حَدَّثَنِي أُسَيْدُ بْنُ حُضَيْرِ بْنِ سِمَاكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى أَنَّهُ إِذَا وَجَدَهَا فِي يَدِ الرَّجُلِ غَيْرِ الْمُتَّهَمِ فَإِنْ شَاءَ أَخَذَهَا بِمَا اشْتَرَاهَا وَإِنْ شَاءَ اتَّبَعَ سَارِقَهُ وَقَضَى بِذَلِكَ أَبُو بَكْرٍ وَعُمَرُ ‏.‏\hadithno{4679}\hadithgrade{Abu Ghuddah: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Sahih}\hadithtrans{Usaid bin Hudair bin Simak narrated that:the Messenger of Allah ruled that if a man found (his goods) in the possession of a man who was not guilty, then if he wished he could give the man what he had paid for it, or if he wished he could go after the one who had stolen it. Abu Bakr and 'Umar passed similar judgments}}
\hadithdefcmd{nasai}{4680}{أَخْبَرَنَا عَمْرُو بْنُ مَنْصُورٍ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ ذُؤَيْبٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنِ ابْنِ جُرَيْجٍ، وَلَقَدْ، أَخْبَرَنِي عِكْرِمَةُ بْنُ خَالِدٍ، أَنَّ أُسَيْدَ بْنَ حُضَيْرٍ الأَنْصَارِيَّ، ثُمَّ أَحَدَ بَنِي حَارِثَةَ أَخْبَرَهُ أَنَّهُ، كَانَ عَامِلاً عَلَى الْيَمَامَةِ وَأَنَّ مَرْوَانَ كَتَبَ إِلَيْهِ أَنَّ مُعَاوِيَةَ كَتَبَ إِلَيْهِ أَنَّ أَيُّمَا رَجُلٍ سُرِقَ مِنْهُ سَرِقَةٌ فَهُوَ أَحَقُّ بِهَا حَيْثُ وَجَدَهَا ‏.‏ ثُمَّ كَتَبَ بِذَلِكَ مَرْوَانُ إِلَىَّ فَكَتَبْتُ إِلَى مَرْوَانَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَضَى بِأَنَّهُ إِذَا كَانَ الَّذِي ابْتَاعَهَا مِنَ الَّذِي سَرَقَهَا غَيْرُ مُتَّهَمٍ يُخَيَّرُ سَيِّدُهَا فَإِنْ شَاءَ أَخَذَ الَّذِي سُرِقَ مِنْهُ بِثَمَنِهَا وَإِنْ شَاءَ اتَّبَعَ سَارِقَهُ ثُمَّ قَضَى بِذَلِكَ أَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ فَبَعَثَ مَرْوَانُ بِكِتَابِي إِلَى مُعَاوِيَةَ وَكَتَبَ مُعَاوِيَةُ إِلَى مَرْوَانَ إِنَّكَ لَسْتَ أَنْتَ وَلاَ أُسَيْدٌ تَقْضِيَانِ عَلَىَّ وَلَكِنِّي أَقْضِي فِيمَا وُلِّيتُ عَلَيْكُمَا فَأَنْفِذْ لِمَا أَمَرْتُكَ بِهِ ‏.‏ فَبَعَثَ مَرْوَانُ بِكِتَابِ مُعَاوِيَةَ فَقُلْتُ لاَ أَقْضِي بِهِ مَا وُلِّيتُ بِمَا قَالَ مُعَاوِيَةُ ‏.‏\hadithno{4680}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Usaid bin Zubair Al-Ansari, who was one of Banu Harithah narrated that:there was the governor of Al-Yamamah, and Marwan wrote to him saying that Mu'awiyah had written to him, saying that any man who had something stolen from him had more right to it wherever he found it. Then Marwan wrote saying that to me (Usaid). I wrote to Marwan saying that the Prophet had ruled that if the one who bought it from the one who stole it is ot guilty of anything (and did not realize that it was stolen goods), then the owner has the choice: If he wishes, he may buy it from the one who bought it from the thief, or if he wishes he may go after the thief. Abu Bakr, 'Umar and 'Uthman also passed judgment along these lines. Marwan sent my letter to Mu'awiyah, and Mu'awiyah wrote to Marwan (saying): 'Neither you nor Usaid are in a position to tell me what to do, rather I am the one who tells you what to do because I am superior in rank to you, so do what I tell you.' Marwan sent the letter of Mu'awiyah to me, and I said: I will not judge according to Mu'awiyah's opinion as long as I am the governor}}
\hadithdefcmd{nasai}{4681}{حَدَّثَنَا مُحَمَّدُ بْنُ دَاوُدَ، قَالَ حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنْ مُوسَى بْنِ السَّائِبِ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الرَّجُلُ أَحَقُّ بِعَيْنِ مَالِهِ إِذَا وَجَدَهُ وَيَتْبَعُ الْبَائِعُ مَنْ بَاعَهُ ‏"‏ ‏.‏\hadithno{4681}\hadithgrade{Abu Ghuddah: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sammurah that the Messenger of Allah said:"A man has more right to his own wealth when he finds it, and the buyer should pursue the one who sold it to him}}
\hadithdefcmd{nasai}{4682}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا امْرَأَةٍ زَوَّجَهَا وَلِيَّانِ فَهِيَ لِلأَوَّلِ مِنْهُمَا وَمَنْ بَاعَ بَيْعًا مِنْ رَجُلَيْنِ فَهُوَ لِلأَوَّلِ مِنْهُمَا ‏"‏ ‏.‏\hadithno{4682}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Sammurah that the Messenger of Allah said:"If a woman is married off by two guardians, then the first marriage is the one that counts, and if a man sells something to two men, it belongs to the first one}}
\hadithdefcmd{nasai}{4683}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، عَنْ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي رَبِيعَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ اسْتَقْرَضَ مِنِّي النَّبِيُّ صلى الله عليه وسلم أَرْبَعِينَ أَلْفًا فَجَاءَهُ مَالٌ فَدَفَعَهُ إِلَىَّ وَقَالَ ‏ "‏ بَارَكَ اللَّهُ لَكَ فِي أَهْلِكَ وَمَالِكَ إِنَّمَا جَزَاءُ السَّلَفِ الْحَمْدُ وَالأَدَاءُ ‏"‏ ‏.‏\hadithno{4683}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{it was narrated from Isla'il bin Ibrahim bin 'Abdullah bin Abi Rabi'ah, from his father, that his grandfather said:"The Prophet borrowed forty thousand from me, then some wealth came to him, and he paid me back and said: 'May Allah bless your family and your wealth for you: the reward for lending is praise and repayment}}
\hadithdefcmd{nasai}{4684}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، عَنْ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا الْعَلاَءُ، عَنْ أَبِي كَثِيرٍ، مَوْلَى مُحَمَّدِ بْنِ جَحْشٍ عَنْ مُحَمَّدِ بْنِ جَحْشٍ، قَالَ كُنَّا جُلُوسًا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَفَعَ رَأْسَهُ إِلَى السَّمَاءِ ثُمَّ وَضَعَ رَاحَتَهُ عَلَى جَبْهَتِهِ ثُمَّ قَالَ ‏"‏ سُبْحَانَ اللَّهِ مَاذَا نُزِّلَ مِنَ التَّشْدِيدِ ‏"‏ ‏.‏ فَسَكَتْنَا وَفَزِعْنَا فَلَمَّا كَانَ مِنَ الْغَدِ سَأَلْتُهُ يَا رَسُولَ اللَّهِ مَا هَذَا التَّشْدِيدُ الَّذِي نُزِّلَ فَقَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَوْ أَنَّ رَجُلاً قُتِلَ فِي سَبِيلِ اللَّهِ ثُمَّ أُحْيِيَ ثُمَّ قُتِلَ ثُمَّ أُحْيِيَ ثُمَّ قُتِلَ وَعَلَيْهِ دَيْنٌ مَا دَخَلَ الْجَنَّةَ حَتَّى يُقْضَى عَنْهُ دَيْنُهُ ‏"‏ ‏.‏\hadithno{4684}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Muhammad bin Jahsh said:"We were sitting with the Messenger of Allah when he raised his head toward the sky, and put his palm on his forehead, then he said: 'Subhan Allah, what a stern warning has been revealed! We fell silent and were scared. The following day I asked him: 'O Messenger of Allah, what is this stern warning that has been revealed? He said: 'By the One in Whose hand is my soul, if a man were to be killed in the cause of Allah then brought back to life, then killed, but he owed a debt, he would not enter paradise until his debt was paid off}}
\hadithdefcmd{nasai}{4685}{أَخْبَرَنَا مَحْمُودُ بْنُ غَيْلاَنَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ حَدَّثَنَا الثَّوْرِيُّ، عَنْ أَبِيهِ، عَنِ الشَّعْبِيِّ، عَنْ سَمْعَانَ، عَنْ سَمُرَةَ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي جَنَازَةٍ فَقَالَ ‏"‏ أَهَا هُنَا مِنْ بَنِي فُلاَنٍ أَحَدٌ ‏"‏ ‏.‏ ثَلاَثًا فَقَامَ رَجُلٌ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا مَنَعَكَ فِي الْمَرَّتَيْنِ الأُولَيَيْنِ أَنْ لاَ تَكُونَ أَجَبْتَنِي أَمَا إِنِّي لَمْ أُنَوِّهْ بِكَ إِلاَّ بِخَيْرٍ إِنَّ فُلاَنًا - لِرَجُلٍ مِنْهُمْ - مَاتَ مَأْسُورًا بِدَيْنِهِ ‏"‏ ‏.‏\hadithno{4685}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that samurah said:"We were with the Prophet at a funeral, and he said: 'I there anyone from banu so and so here? He said this three times. Then a man stood up, and he said to him: 'What kept you form answering the first two times? I am not going to say anything but good to you, so and so (mentioning the name of a man from among them) has died and he is being detained (from entering Paradise) because of his debt}}
\hadithdefcmd{nasai}{4686}{أَخْبَرَنِي مُحَمَّدُ بْنُ قُدَامَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ زِيَادِ بْنِ عَمْرِو بْنِ هِنْدٍ، عَنْ عِمْرَانَ بْنِ حُذَيْفَةَ، قَالَ كَانَتْ مَيْمُونَةُ تَدَّانُ وَتُكْثِرُ فَقَالَ لَهَا أَهْلُهَا فِي ذَلِكَ وَلاَمُوهَا وَوَجَدُوا عَلَيْهَا فَقَالَتْ لاَ أَتْرُكُ الدَّيْنَ وَقَدْ سَمِعْتُ خَلِيلِي وَصَفِيِّي صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ أَحَدٍ يَدَّانُ دَيْنًا فَعَلِمَ اللَّهُ أَنَّهُ يُرِيدُ قَضَاءَهُ إِلاَّ أَدَّاهُ اللَّهُ عَنْهُ فِي الدُّنْيَا ‏"‏ ‏.‏\hadithno{4686}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Imran bin Hudaifah said:"Maimunah used to take out loans frequently, and some of her family criticized her and denounced her for that. She said: 'I will not stop taking loans, for I heard my close friend and my beloved say: "There is no one who takes out a loans, and Allah knows that he intends to pay it back, but Allah will pay it back for him in this world}}
\hadithdefcmd{nasai}{4687}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، قَالَ حَدَّثَنَا أَبِي، عَنِ الأَعْمَشِ، عَنْ حُصَيْنِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ مَيْمُونَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم اسْتَدَانَتْ فَقِيلَ لَهَا يَا أُمَّ الْمُؤْمِنِينَ تَسْتَدِينِينَ وَلَيْسَ عِنْدَكِ وَفَاءٌ قَالَتْ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَخَذَ دَيْنًا وَهُوَ يُرِيدُ أَنْ يُؤَدِّيَهُ أَعَانَهُ اللَّهُ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4687}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Ubaidullah bin 'Abdullah bin 'Utbah that Maimunah, the wife of the Prophet, took a loan, and it was said to her:"O Mother of the Believers, why have you taken a loan when you do not have the means to pay if off?" She said: "I heard the Messenger of Allah say: 'Whoever takes a loan intending to pay it back, Allah, the Mighty and Sublime, will help him}}
\hadithdefcmd{nasai}{4688}{أَخْبَرَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أُتْبِعَ أَحَدُكُمْ عَلَى مَلِيءٍ فَلْيَتْبَعْ وَالظُّلْمُ مَطْلُ الْغَنِيِّ ‏"‏ ‏.‏\hadithno{4688}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'If one of you is referred to a rich man (to help repay a debt), he should accept that referral, and (wrongdoing) is when a rich man takes a long time to repay a debt}}
\hadithdefcmd{nasai}{4689}{أَخْبَرَنِي مُحَمَّدُ بْنُ آدَمَ، قَالَ حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ وَبْرِ بْنِ أَبِي دُلَيْلَةَ، عَنْ مُحَمَّدِ بْنِ مَيْمُونٍ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَىُّ الْوَاجِدِ يُحِلُّ عِرْضَهُ وَعُقُوبَتَهُ ‏"‏ ‏.‏\hadithno{4689}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Amr bin Ash-Sharid, that his father said:"The Messenger of Allah said: 'if one who can afford it delay repayment, his honor and punishment become permissible}}
\hadithdefcmd{nasai}{4690}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا وَكِيعٌ، قَالَ حَدَّثَنَا وَبْرُ بْنُ أَبِي دُلَيْلَةَ الطَّائِفِيُّ، عَنْ مُحَمَّدِ بْنِ مَيْمُونِ بْنِ مُسَيْكَةَ، - وَأَثْنَى عَلَيْهِ خَيْرًا - عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَىُّ الْوَاجِدِ يُحِلُّ عِرْضَهُ وَعُقُوبَتَهُ ‏"‏ ‏.‏\hadithno{4690}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Amr bin Ash-Shrid, from his father that the Messenger of Allah said:"If one who can afford it delays repayment, his honor and punishment become permissible}}
\hadithdefcmd{nasai}{4691}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، وَالْحَارِثُ بْنُ مِسْكِينٍ، قِرَاءَةً عَلَيْهِ وَأَنَا أَسْمَعُ، وَاللَّفْظُ، لَهُ عَنِ ابْنِ الْقَاسِمِ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَطْلُ الْغَنِيِّ ظُلْمٌ وَإِذَا أُتْبِعَ أَحَدُكُمْ عَلَى مَلِيءٍ فَلْيَتْبَعْ ‏"‏ ‏.‏\hadithno{4691}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:"The Messenger of Allah said: 'Wrongdoing is when a rich man takes a long time to repay a debt, and if one of you is referred to a rich man (to help repay debt), he should accept that referral}}
\hadithdefcmd{nasai}{4692}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ حَدَّثَنَا خَالِدٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ أُتِيَ بِهِ النَّبِيُّ صلى الله عليه وسلم لِيُصَلِّيَ عَلَيْهِ فَقَالَ ‏"‏ إِنَّ عَلَى صَاحِبِكُمْ دَيْنًا ‏"‏ ‏.‏ فَقَالَ أَبُو قَتَادَةَ أَنَا أَتَكَفَّلُ بِهِ ‏.‏ قَالَ ‏"‏ بِالْوَفَاءِ ‏"‏ ‏.‏ قَالَ بِالْوَفَاءِ ‏.‏\hadithno{4692}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from 'Abdullah bin Abi Qatadah, from his father, that a man from among the Ansar was brought to the prophet for him to offer the funeral prayer, and he said:"Your companion owes a debt. " Abu Qutdah said: "I will guarantee it for him. "The prophet said: "In full?" He said: "In full." (Sahah)}}
\hadithdefcmd{nasai}{4693}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنْ وَكِيعٍ، قَالَ حَدَّثَنِي عَلِيُّ بْنُ صَالِحٍ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خِيَارُكُمْ أَحْسَنُكُمْ قَضَاءً ‏"‏ ‏.‏\hadithno{4693}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"The best of you is the one who is best in repaying}}
\hadithdefcmd{nasai}{4694}{أَخْبَرَنَا عِيسَى بْنُ حَمَّادٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ رَجُلاً لَمْ يَعْمَلْ خَيْرًا قَطُّ وَكَانَ يُدَايِنُ النَّاسَ فَيَقُولُ لِرَسُولِهِ خُذْ مَا تَيَسَّرَ وَاتْرُكْ مَا عَسُرَ وَتَجَاوَزْ لَعَلَّ اللَّهَ تَعَالَى أَنْ يَتَجَاوَزَ عَنَّا فَلَمَّا هَلَكَ قَالَ اللَّهُ عَزَّ وَجَلَّ لَهُ هَلْ عَمِلْتَ خَيْرًا قَطُّ قَالَ لاَ إِلاَّ أَنَّهُ كَانَ لِي غُلاَمٌ وَكُنْتُ أُدَايِنُ النَّاسَ فَإِذَا بَعَثْتُهُ لِيَتَقَاضَى قُلْتُ لَهُ خُذْ مَا تَيَسَّرَ وَاتْرُكْ مَا عَسُرَ وَتَجَاوَزْ لَعَلَّ اللَّهَ يَتَجَاوَزُ عَنَّا ‏.‏ قَالَ اللَّهُ تَعَالَى قَدْ تَجَاوَزْتُ عَنْكَ ‏"‏ ‏.‏\hadithno{4694}\hadithgrade{Abu Ghuddah: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah said:"There was a man who never did any good deed, but he used to lend to people and he would say to this messenger: "Take what can be paid easily and leave what is difficult, let them off, and perhaps Allah, the Mighty and Sublime, said to him: 'Did you ever do any good did? He said: No, but I had a slave and I used to lend to people. When I sent him to collect the debts I said to him: Take what can he paid easily and leave what is difficult; let them off, and perhaps Allah will let us off. Allah, the Most High, said: 'I have let you off}}
\hadithdefcmd{nasai}{4695}{أَخْبَرَنَا هِشَامُ بْنُ عَمَّارٍ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا الزُّبَيْدِيُّ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ إِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ كَانَ رَجُلٌ يُدَايِنُ النَّاسَ وَكَانَ إِذَا رَأَى إِعْسَارَ الْمُعْسِرِ قَالَ لِفَتَاهُ تَجَاوَزْ عَنْهُ لَعَلَّ اللَّهَ تَعَالَى يَتَجَاوَزُ عَنَّا ‏.‏ فَلَقِيَ اللَّهَ فَتَجَاوَزَ عَنْهُ ‏"‏ ‏.‏\hadithno{4695}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah said:The prophet said: "A man used to lend to people, but if he realized that someone was going through hardship, he would say to his slave: 'Let him off, perhaps Allah, the Most High, will let us off.' And when he met Allah, He let him off}}
\hadithdefcmd{nasai}{4696}{أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ إِسْمَاعِيلَ ابْنِ عُلَيَّةَ، عَنْ يُونُسَ، عَنْ عَطَاءِ بْنِ فَرُّوخَ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَدْخَلَ اللَّهُ عَزَّ وَجَلَّ رَجُلاً كَانَ سَهْلاً مُشْتَرِيًا وَبَائِعًا وَقَاضِيًا وَمُقْتَضِيًا الْجَنَّةَ ‏"‏ ‏.‏\hadithno{4696}\hadithgrade{Abu Ghuddah: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that 'Uthman bin 'Affan said:"The Messenger of Allah said: 'Allah, the Mighty and Sublime, admitted to paradise a man who was easygoing in buying and selling, in paying off debts and asking for repayment."' (Sahaih)}}
\hadithdefcmd{nasai}{4697}{أَخْبَرَنِي عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي أَبُو إِسْحَاقَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ اشْتَرَكْتُ أَنَا وَعَمَّارٌ، وَسَعْدٌ، يَوْمَ بَدْرٍ فَجَاءَ سَعْدٌ بِأَسِيرَيْنِ وَلَمْ أَجِئْ أَنَا وَعَمَّارٌ بِشَىْءٍ ‏.‏\hadithno{4697}\hadithgrade{Abu Ghuddah: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narratd that 'Abdullah said:"Sa'd, 'Ammar and I entered into a partnership on the Day of Badr, (agreeing to share) whatever was allotted to us. 'Ammar and I did not get anything. But sa'd got two prisoners}}
\hadithdefcmd{nasai}{4698}{أَخْبَرَنَا نُوحُ بْنُ حَبِيبٍ، قَالَ أَنْبَأَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْتَقَ شِرْكًا لَهُ فِي عَبْدٍ أُتِمَّ مَا بَقِيَ فِي مَالِهِ إِنْ كَانَ لَهُ مَالٌ يَبْلُغُ ثَمَنَ الْعَبْدِ ‏"‏ ‏.‏\hadithno{4698}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Salim, from his father, that the Messenger of Allah said:"Whoever sets free his share of a slave should set him free completely from his own wealth, if he has enough wealth to cover the price of the slave}}
\hadithdefcmd{nasai}{4699}{أَخْبَرَنَا عَمْرُو بْنُ عَلِيٍّ، قَالَ حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ زُرَيْعٍ - قَالَ حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ شِرْكًا لَهُ فِي مَمْلُوكٍ وَكَانَ لَهُ مِنَ الْمَالِ مَا يَبْلُغُ ثَمَنَهُ بِقِيمَةِ الْعَبْدِ فَهُوَ عَتِيقٌ مِنْ مَالِهِ ‏"‏ ‏.‏\hadithno{4699}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn 'Umar said:"The Messenger of Allah said: 'Whoever sets free his share of a slave, and he has sufficient wealth to set him free completely by paying the price of the slave, then he should set him free with his own wealth}}
\hadithdefcmd{nasai}{4700}{أَخْبَرَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّكُمْ كَانَتْ لَهُ أَرْضٌ أَوْ نَخْلٌ فَلاَ يَبِعْهَا حَتَّى يَعْرِضَهَا عَلَى شَرِيكِهِ ‏"‏ ‏.‏\hadithno{4700}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Jabir that the Prophet said:"Any one of you who has land, or date palm trees, he should not sell them until he offers them to his partner first}}
\hadithdefcmd{nasai}{4701}{أَخْبَرَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ أَنْبَأَنَا ابْنُ إِدْرِيسَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالشُّفْعَةِ فِي كُلِّ شَرِكَةٍ لَمْ تُقْسَمْ رَبْعَةٍ وَحَائِطٍ لاَ يَحِلُّ لَهُ أَنْ يَبِيعَهُ حَتَّى يُؤْذِنَ شَرِيكَهُ فَإِنْ شَاءَ أَخَذَ وَإِنْ شَاءَ تَرَكَ وَإِنْ بَاعَ وَلَمْ يُؤْذِنْهُ فَهُوَ أَحَقُّ بِهِ ‏.‏\hadithno{4701}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah ruled that pre-emption is to be given in everything that is shared in which the division is not clear, whether it is a house or a garden. It is not permissible to sell it before informing one's partner, who may take it or leave it, as he wishes. He (the share-owner) sells it without informing him, and then he has more right to it}}
\hadithdefcmd{nasai}{4702}{أَخْبَرَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنْ أَبِي رَافِعٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْجَارُ أَحَقُّ بِسَقَبِهِ ‏"‏ ‏.‏\hadithno{4702}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Abu Rafi said:"The Messenger of Allah said" "The neighbor has more right to property that is near}}
\hadithdefcmd{nasai}{4703}{أَخْبَرَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا عِيسَى بْنُ يُونُسَ، قَالَ حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ أَرْضِي لَيْسَ لأَحَدٍ فِيهَا شَرِكَةٌ وَلاَ قِسْمَةٌ إِلاَّ الْجُوَارَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْجَارُ أَحَقُّ بِسَقَبِهِ ‏"‏ ‏.‏\hadithno{4703}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from 'Amr Bin Ash-Sharid, from his father, that a man said:"O Messenger of Allah, not one else has any share in my land, but there are neighbors." He said: "The neighbor has more right to property that is near}}
\hadithdefcmd{nasai}{4704}{أَخْبَرَنَا هِلاَلُ بْنُ بِشْرٍ، قَالَ حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الشُّفْعَةُ فِي كُلِّ مَالٍ لَمْ يُقْسَمْ فَإِذَا وَقَعَتِ الْحُدُودُ وَعُرِفَتِ الطُّرُقُ فَلاَ شُفْعَةَ ‏"‏ ‏.‏\hadithno{4704}\hadithgrade{Abu Ghuddah: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Salamah that the Messenger of Allah said:"Pre-emption takes effect in all cases where land has not been divided. But if the boundaries have been sent, and the roads lay out, then there is no pre-emption}}
\hadithdefcmd{nasai}{4705}{أَخْبَرَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ بْنِ أَبِي رِزْمَةَ، قَالَ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ حُسَيْنٍ، - وَهُوَ ابْنُ وَاقِدٍ - عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم بِالشُّفْعَةِ وَالْجِوَارِ ‏.‏\hadithno{4705}\hadithgrade{Abu Ghuddah: Sahih Lighairihi; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Jabir said:"The Messenger of Allah decreed the principle of pre-emption, and the (rights of) neighbors}}
