% Auto-generated chapter 0 for muslim
% Hadiths in this chapter: 344

\hadithdefcmd{muslim}{1}{\hadithno{1}\hadithtrans{}}
\hadithdefcmd{muslim}{2}{\hadithno{2}\hadithtrans{}}
\hadithdefcmd{muslim}{3}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ إِنَّهُ لَيَمْنَعُنِي أَنْ أُحَدِّثَكُمْ حَدِيثًا كَثِيرًا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَعَمَّدَ عَلَىَّ كَذِبًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{3}\hadithtrans{Zuhayr bin Harb narrated to me, Ismā’īl, rather, Ibn Ulayyah narrated to us, on authority of Abd il-Azīz ibn Suhayb, on authority of Anas bin Mālik, that he said:‘Indeed what prevents me from relating to you a great number of Ḥadīth is that the Messenger of Allah, peace and blessings of Allah upon him, said: ‘Whoever intends to lie upon me, then let him take his seat in the Fire.’}}
\hadithdefcmd{muslim}{4}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْغُبَرِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَذَبَ عَلَىَّ مُتَعَمِّدًا فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{4}\hadithtrans{Muhammad bin Ubayd il-Ghubarī narrated to us, Abū Awānah narrated to us, on authority of Abī Hasīn, on authority of Abī Sālih, on authority of Abū Hurayrah, he said, the Messenger of Allah, peace and blessings of Allah upon him, said:‘Whoever lies upon me intentionally, then let him take his seat in the Fire’}}
\hadithdefcmd{muslim}{5}{\hadithno{5}\hadithtrans{}}
\hadithdefcmd{muslim}{6}{\hadithno{6}\hadithtrans{}}
\hadithdefcmd{muslim}{7}{\hadithno{7}\hadithtrans{}}
\hadithdefcmd{muslim}{8}{\hadithno{8}\hadithtrans{}}
\hadithdefcmd{muslim}{9}{\hadithno{9}\hadithtrans{}}
\hadithdefcmd{muslim}{10}{\hadithno{10}\hadithtrans{}}
\hadithdefcmd{muslim}{11}{\hadithno{11}\hadithtrans{}}
\hadithdefcmd{muslim}{12}{\hadithno{12}\hadithtrans{}}
\hadithdefcmd{muslim}{13}{\hadithno{13}\hadithtrans{}}
\hadithdefcmd{muslim}{14}{\hadithno{14}\hadithtrans{}}
\hadithdefcmd{muslim}{15}{وَحَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ أَبِي أَيُّوبَ، قَالَ حَدَّثَنِي أَبُو هَانِئٍ، عَنْ أَبِي عُثْمَانَ، مُسْلِمِ بْنِ يَسَارٍ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ سَيَكُونُ فِي آخِرِ أُمَّتِي أُنَاسٌ يُحَدِّثُونَكُمْ مَا لَمْ تَسْمَعُوا أَنْتُمْ وَلاَ آبَاؤُكُمْ فَإِيَّاكُمْ وَإِيَّاهُمْ ‏"‏ ‏.‏,وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ حَرْمَلَةَ بْنِ عِمْرَانَ التُّجِيبِيُّ، قَالَ حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ حَدَّثَنِي أَبُو شُرَيْحٍ، أَنَّهُ سَمِعَ شَرَاحِيلَ بْنَ يَزِيدَ، يَقُولُ أَخْبَرَنِي مُسْلِمُ بْنُ يَسَارٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَكُونُ فِي آخِرِ الزَّمَانِ دَجَّالُونَ كَذَّابُونَ يَأْتُونَكُمْ مِنَ الأَحَادِيثِ بِمَا لَمْ تَسْمَعُوا أَنْتُمْ وَلاَ آبَاؤُكُمْ فَإِيَّاكُمْ وَإِيَّاهُمْ لاَ يُضِلُّونَكُمْ وَلاَ يَفْتِنُونَكُمْ ‏"‏ ‏.‏\hadithno{15}\hadithtrans{Muhammad bin Abd Allah bin Numayr and Zuhayr bin Harb narrated to me, they said Abd Allah bin Yazīd narrated to us, he said Sa’īd bin Abī Ayyūb narrated to me, he said Abū Hāni’ narrated to me, on authority of Uthmān Muslim bin Yasār, on authority of Abī Hurayrah, on authority of the Messenger of Allah, peace and blessings of Allah upon him, he said:‘There will be in the last of my nation a people narrating to you what you nor your fathers heard, so beware of them’. ,Harmalah bin Yahyā bin Abd Allah bin Harmalah bin Imrān at-Tujībī narrated to me, he said Ibn Wahb narrated to us, he said Abū Shurayh narrated to me that he heard Sharāhīl bin Yazīd saying ‘Muslim bin Yasār informed me that he heard Abā Hurayrah saying, the Messenger of Allah, peace and blessings of Allah upon him, said:‘There will be in the end of time charlatan liars coming to you with narrations that you nor your fathers heard, so beware of them lest they misguide you and cause you tribulations’.’}}
\hadithdefcmd{muslim}{16}{\hadithno{16}\hadithtrans{}}
\hadithdefcmd{muslim}{17}{\hadithno{17}\hadithtrans{}}
\hadithdefcmd{muslim}{18}{\hadithno{18}\hadithtrans{}}
\hadithdefcmd{muslim}{19}{\hadithno{19}\hadithtrans{}}
\hadithdefcmd{muslim}{20}{\hadithno{20}\hadithtrans{}}
\hadithdefcmd{muslim}{21}{\hadithno{21}\hadithtrans{}}
\hadithdefcmd{muslim}{22}{\hadithno{22}\hadithtrans{}}
\hadithdefcmd{muslim}{23}{\hadithno{23}\hadithtrans{}}
\hadithdefcmd{muslim}{24}{\hadithno{24}\hadithtrans{}}
\hadithdefcmd{muslim}{25}{\hadithno{25}\hadithtrans{}}
\hadithdefcmd{muslim}{26}{\hadithno{26}\hadithtrans{}}
\hadithdefcmd{muslim}{27}{\hadithno{27}\hadithtrans{}}
\hadithdefcmd{muslim}{28}{\hadithno{28}\hadithtrans{}}
\hadithdefcmd{muslim}{29}{\hadithno{29}\hadithtrans{}}
\hadithdefcmd{muslim}{30}{\hadithno{30}\hadithtrans{}}
\hadithdefcmd{muslim}{31}{\hadithno{31}\hadithtrans{}}
\hadithdefcmd{muslim}{32}{\hadithno{32}\hadithtrans{}}
\hadithdefcmd{muslim}{33}{\hadithno{33}\hadithtrans{}}
\hadithdefcmd{muslim}{34}{\hadithno{34}\hadithtrans{}}
\hadithdefcmd{muslim}{35}{\hadithno{35}\hadithtrans{}}
\hadithdefcmd{muslim}{36}{\hadithno{36}\hadithtrans{}}
\hadithdefcmd{muslim}{37}{\hadithno{37}\hadithtrans{}}
\hadithdefcmd{muslim}{38}{\hadithno{38}\hadithtrans{}}
\hadithdefcmd{muslim}{39}{\hadithno{39}\hadithtrans{}}
\hadithdefcmd{muslim}{40}{\hadithno{40}\hadithtrans{}}
\hadithdefcmd{muslim}{41}{\hadithno{41}\hadithtrans{}}
\hadithdefcmd{muslim}{42}{\hadithno{42}\hadithtrans{}}
\hadithdefcmd{muslim}{43}{\hadithno{43}\hadithtrans{}}
\hadithdefcmd{muslim}{44}{\hadithno{44}\hadithtrans{}}
\hadithdefcmd{muslim}{45}{\hadithno{45}\hadithtrans{}}
\hadithdefcmd{muslim}{46}{\hadithno{46}\hadithtrans{}}
\hadithdefcmd{muslim}{47}{\hadithno{47}\hadithtrans{}}
\hadithdefcmd{muslim}{48}{\hadithno{48}\hadithtrans{}}
\hadithdefcmd{muslim}{49}{\hadithno{49}\hadithtrans{}}
\hadithdefcmd{muslim}{50}{\hadithno{50}\hadithtrans{}}
\hadithdefcmd{muslim}{51}{\hadithno{51}\hadithtrans{}}
\hadithdefcmd{muslim}{52}{\hadithno{52}\hadithtrans{}}
\hadithdefcmd{muslim}{53}{\hadithno{53}\hadithtrans{}}
\hadithdefcmd{muslim}{54}{\hadithno{54}\hadithtrans{}}
\hadithdefcmd{muslim}{55}{\hadithno{55}\hadithtrans{}}
\hadithdefcmd{muslim}{56}{\hadithno{56}\hadithtrans{}}
\hadithdefcmd{muslim}{57}{\hadithno{57}\hadithtrans{}}
\hadithdefcmd{muslim}{58}{\hadithno{58}\hadithtrans{}}
\hadithdefcmd{muslim}{59}{\hadithno{59}\hadithtrans{}}
\hadithdefcmd{muslim}{60}{\hadithno{60}\hadithtrans{}}
\hadithdefcmd{muslim}{61}{\hadithno{61}\hadithtrans{}}
\hadithdefcmd{muslim}{62}{\hadithno{62}\hadithtrans{}}
\hadithdefcmd{muslim}{63}{\hadithno{63}\hadithtrans{}}
\hadithdefcmd{muslim}{64}{\hadithno{64}\hadithtrans{}}
\hadithdefcmd{muslim}{65}{\hadithno{65}\hadithtrans{}}
\hadithdefcmd{muslim}{66}{\hadithno{66}\hadithtrans{}}
\hadithdefcmd{muslim}{67}{\hadithno{67}\hadithtrans{}}
\hadithdefcmd{muslim}{68}{\hadithno{68}\hadithtrans{}}
\hadithdefcmd{muslim}{69}{\hadithno{69}\hadithtrans{}}
\hadithdefcmd{muslim}{70}{\hadithno{70}\hadithtrans{}}
\hadithdefcmd{muslim}{71}{\hadithno{71}\hadithtrans{}}
\hadithdefcmd{muslim}{72}{\hadithno{72}\hadithtrans{}}
\hadithdefcmd{muslim}{73}{\hadithno{73}\hadithtrans{}}
\hadithdefcmd{muslim}{74}{\hadithno{74}\hadithtrans{}}
\hadithdefcmd{muslim}{75}{\hadithno{75}\hadithtrans{}}
\hadithdefcmd{muslim}{76}{\hadithno{76}\hadithtrans{}}
\hadithdefcmd{muslim}{77}{\hadithno{77}\hadithtrans{}}
\hadithdefcmd{muslim}{78}{\hadithno{78}\hadithtrans{}}
\hadithdefcmd{muslim}{79}{\hadithno{79}\hadithtrans{}}
\hadithdefcmd{muslim}{80}{\hadithno{80}\hadithtrans{}}
\hadithdefcmd{muslim}{81}{\hadithno{81}\hadithtrans{}}
\hadithdefcmd{muslim}{82}{\hadithno{82}\hadithtrans{}}
\hadithdefcmd{muslim}{83}{\hadithno{83}\hadithtrans{}}
\hadithdefcmd{muslim}{84}{\hadithno{84}\hadithtrans{}}
\hadithdefcmd{muslim}{85}{\hadithno{85}\hadithtrans{}}
\hadithdefcmd{muslim}{86}{\hadithno{86}\hadithtrans{}}
\hadithdefcmd{muslim}{87}{\hadithno{87}\hadithtrans{}}
\hadithdefcmd{muslim}{88}{\hadithno{88}\hadithtrans{}}
\hadithdefcmd{muslim}{89}{\hadithno{89}\hadithtrans{}}
\hadithdefcmd{muslim}{90}{\hadithno{90}\hadithtrans{}}
\hadithdefcmd{muslim}{91}{\hadithno{91}\hadithtrans{}}
\hadithdefcmd{muslim}{92}{\hadithno{92}\hadithtrans{}}
\hadithdefcmd{muslim}{128}{\hadithno{128}\hadithtrans{}}
\hadithdefcmd{muslim}{209}{\hadithno{209}\hadithtrans{}}
\hadithdefcmd{muslim}{248}{\hadithno{248}\hadithtrans{}}
\hadithdefcmd{muslim}{637}{\hadithno{637}\hadithtrans{}}
\hadithdefcmd{muslim}{638}{\hadithno{638}\hadithtrans{}}
\hadithdefcmd{muslim}{794}{\hadithno{794}\hadithtrans{}}
\hadithdefcmd{muslim}{852}{\hadithno{852}\hadithtrans{}}
\hadithdefcmd{muslim}{853}{\hadithno{853}\hadithtrans{}}
\hadithdefcmd{muslim}{881}{\hadithno{881}\hadithtrans{}}
\hadithdefcmd{muslim}{1220}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامٍ، قَالَ حَدَّثَنِي ابْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ مُعَيْقِيبٍ، أَنَّهُمْ سَأَلُوا النَّبِيَّ صلى الله عليه وسلم عَنِ الْمَسْحِ فِي الصَّلاَةِ فَقَالَ ‏"‏ وَاحِدَةٌ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا هِشَامٌ، بِهَذَا الإِسْنَادِ ‏.‏ وَقَالَ فِيهِ حَدَّثَنِي مُعَيْقِيبٌ، ح وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، قَالَ حَدَّثَنِي مُعَيْقِيبٌ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فِي الرَّجُلِ يُسَوِّي التُّرَابَ حَيْثُ يَسْجُدُ قَالَ ‏"‏ إِنْ كُنْتَ فَاعِلاً فَوَاحِدَةً ‏"‏ ‏.‏\hadithno{1220}\hadithtrans{Mu'aiqib said:They asked the Apostle (ﷺ) about the removal of (pebbles) in prayer, whereupon he said: If you do it, do it only once}}
\hadithdefcmd{muslim}{1221}{\hadithno{1221}\hadithtrans{}}
\hadithdefcmd{muslim}{1222}{\hadithno{1222}\hadithtrans{}}
\hadithdefcmd{muslim}{1251}{\hadithno{1251}\hadithtrans{}}
\hadithdefcmd{muslim}{1332}{\hadithno{1332}\hadithtrans{}}
\hadithdefcmd{muslim}{1350}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا حَمْزَةُ الزَّيَّاتُ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مُعَقِّبَاتٌ لاَ يَخِيبُ قَائِلُهُنَّ - أَوْ فَاعِلُهُنَّ - ثَلاَثٌ وَثَلاَثُونَ تَسْبِيحَةً وَثَلاَثٌ وَثَلاَثُونَ تَحْمِيدَةً وَأَرْبَعٌ وَثَلاَثُونَ تَكْبِيرَةً فِي دُبُرِ كُلِّ صَلاَةٍ ‏"‏ ‏.‏ حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا أَسْبَاطُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَمْرُو بْنُ قَيْسٍ الْمُلاَئِيُّ، عَنِ الْحَكَمِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{1350}\hadithtrans{Ka'b b. 'Ujra reported Allah's Messenger (ﷺ) as saying:There are certain ejaculations, the repeaters of which or the performers of which at the end of every prayer will never be caused disappointment:" Glory be to Allah" thirty-three times," Praise be to Allah" thirty-three times, and" Allah is most Great" thirty-four times}}
\hadithdefcmd{muslim}{1351}{\hadithno{1351}\hadithtrans{}}
\hadithdefcmd{muslim}{1354}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا كَبَّرَ فِي الصَّلاَةِ سَكَتَ هُنَيَّةً قَبْلَ أَنْ يَقْرَأَ فَقُلْتُ يَا رَسُولَ اللَّهِ بِأَبِي أَنْتَ وَأُمِّي أَرَأَيْتَ سُكُوتَكَ بَيْنَ التَّكْبِيرِ وَالْقِرَاءَةِ مَا تَقُولُ قَالَ ‏ "‏ أَقُولُ اللَّهُمَّ بَاعِدْ بَيْنِي وَبَيْنَ خَطَايَاىَ كَمَا بَاعَدْتَ بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ اللَّهُمَّ نَقِّنِي مِنْ خَطَايَاىَ كَمَا يُنَقَّى الثَّوْبُ الأَبْيَضُ مِنَ الدَّنَسِ اللَّهُمَّ اغْسِلْنِي مِنْ خَطَايَاىَ بِالثَّلْجِ وَالْمَاءِ وَالْبَرَدِ ‏"‏ ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا ابْنُ فُضَيْلٍ، ح وَحَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، - يَعْنِي ابْنَ زِيَادٍ - كِلاَهُمَا عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِ جَرِيرٍ ‏.‏\hadithno{1354}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) used to observe, silence for a short while between the takbir (at the time of opening the prayer) and the recitation of the Qur'an. I said to him:Messenger of Allah, for whom I would give my father and mother in ransom, what do you recite during your period of silence between the takbir and the recitation? He said: I say (these words):" O Allah, remove my sins from me as Thou hast removed the East from the West. O Allah purify me from sins as a white garment is purified from filth. O Allah! wash away my sins with snow, water, and ice}}
\hadithdefcmd{muslim}{1355}{\hadithno{1355}\hadithtrans{}}
\hadithdefcmd{muslim}{1365}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ حَجَّاجٍ الصَّوَّافِ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، وَعَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِي قَتَادَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ تَقُومُوا حَتَّى تَرَوْنِي ‏"‏ ‏.‏ وَقَالَ ابْنُ حَاتِمٍ ‏"‏ إِذَا أُقِيمَتْ أَوْ نُودِيَ ‏"‏ ‏.‏ وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مَعْمَرٍ، قَالَ أَبُو بَكْرٍ وَحَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ حَجَّاجِ بْنِ أَبِي عُثْمَانَ، ح قَالَ وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، وَعَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، وَقَالَ، إِسْحَاقُ أَخْبَرَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ شَيْبَانَ، كُلُّهُمْ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَزَادَ إِسْحَاقُ فِي رِوَايَتِهِ حَدِيثَ مَعْمَرٍ وَشَيْبَانَ ‏"‏ حَتَّى تَرَوْنِي قَدْ خَرَجْتُ ‏"‏ ‏.‏\hadithno{1365}\hadithtrans{Abu Qatada reported:The Messenger of Allah (ﷺ) said: When the Iqama is pronounced do not get up till you see me Ibn Hatim was in doubt whether it was said:" When the Iqama is pronounced" or" When call is made}}
\hadithdefcmd{muslim}{1366}{\hadithno{1366}\hadithtrans{}}
\hadithdefcmd{muslim}{1428}{\hadithno{1428}\hadithtrans{}}
\hadithdefcmd{muslim}{1429}{\hadithno{1429}\hadithtrans{}}
\hadithdefcmd{muslim}{1648}{\hadithno{1648}\hadithtrans{}}
\hadithdefcmd{muslim}{1718}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِيمَا بَيْنَ أَنْ يَفْرُغَ مِنْ صَلاَةِ الْعِشَاءِ - وَهِيَ الَّتِي يَدْعُو النَّاسُ الْعَتَمَةَ - إِلَى الْفَجْرِ إِحْدَى عَشْرَةَ رَكْعَةً يُسَلِّمُ بَيْنَ كُلِّ رَكْعَتَيْنِ وَيُوتِرُ بِوَاحِدَةٍ فَإِذَا سَكَتَ الْمُؤَذِّنُ مِنْ صَلاَةِ الْفَجْرِ وَتَبَيَّنَ لَهُ الْفَجْرُ وَجَاءَهُ الْمُؤَذِّنُ قَامَ فَرَكَعَ رَكْعَتَيْنِ خَفِيفَتَيْنِ ثُمَّ اضْطَجَعَ عَلَى شِقِّهِ الأَيْمَنِ حَتَّى يَأْتِيَهُ الْمُؤَذِّنُ لِلإِقَامَةِ ‏.‏ وَحَدَّثَنِيهِ حَرْمَلَةُ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ ‏.‏ وَسَاقَ حَرْمَلَةُ الْحَدِيثَ بِمِثْلِهِ غَيْرَ أَنَّهُ لَمْ يَذْكُرْ وَتَبَيَّنَ لَهُ الْفَجْرُ وَجَاءَهُ الْمُؤَذِّنُ ‏.‏ وَلَمْ يَذْكُرِ الإِقَامَةَ ‏.‏ وَسَائِرُ الْحَدِيثِ بِمِثْلِ حَدِيثِ عَمْرٍو سَوَاءً ‏.‏\hadithno{1718}\hadithtrans{A'isha, the wife of the Messenger of Allah (ﷺ), said that between the time when the Messenger of Allah (ﷺ) finished the 'Isha' prayer which is called 'Atama by the people, he used to pray eleven rak'ahs, uttering the salutation at the end of every two rak'ahs, and observing the Witr with a single one. And when the Mu'adhdhin had finished the call (for the) dawn prayer and he saw the dawn clearly and the Mu'adhdhin had come to him, he stood up and prayed two short rak'ahs. Then he lay down on his right side till the Mu'adhdhin came to him for lqama. (This hadith has been narrated with the same chain of transmitters by Ibn Shihab, but in it no mention has been made of Iqama)}}
\hadithdefcmd{muslim}{1719}{\hadithno{1719}\hadithtrans{}}
\hadithdefcmd{muslim}{1778}{\hadithno{1778}\hadithtrans{}}
\hadithdefcmd{muslim}{2045}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ أَبِي عُمَرَ، قَالَ أَبُو بَكْرٍ حَدَّثَنَا سُفْيَانُ بْنُ، عُيَيْنَةَ حَدَّثَنَا أَيُّوبُ، قَالَ سَمِعْتُ عَطَاءً، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ أَشْهَدُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَصَلَّى قَبْلَ الْخُطْبَةِ - قَالَ - ثُمَّ خَطَبَ فَرَأَى أَنَّهُ لَمْ يُسْمِعِ النِّسَاءَ فَأَتَاهُنَّ فَذَكَّرَهُنَّ وَوَعَظَهُنَّ وَأَمَرَهُنَّ بِالصَّدَقَةِ وَبِلاَلٌ قَائِلٌ بِثَوْبِهِ فَجَعَلَتِ الْمَرْأَةُ تُلْقِي الْخَاتَمَ وَالْخُرْصَ وَالشَّىْءَ ‏.‏ وَحَدَّثَنِيهِ أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنِي يَعْقُوبُ الدَّوْرَقِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، كِلاَهُمَا عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{2045}\hadithtrans{Ibn 'Abbas reported:I bear testimony to the Messenger of Allah (ﷺ) offering prayer before Kbutba. He (after saying prayer) delivered the Kutba, and he found that the women could not hear it, so he came to them and exhorted them and preached them and commanded them to give alms, and Bilal had stretched his cloth and the women were throwing rings, earrings and other things. This hadith has been narrated on the authority of Ayyub with the same chain of transmitters}}
\hadithdefcmd{muslim}{2046}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ أَبِي عُمَرَ، قَالَ أَبُو بَكْرٍ حَدَّثَنَا سُفْيَانُ بْنُ، عُيَيْنَةَ حَدَّثَنَا أَيُّوبُ، قَالَ سَمِعْتُ عَطَاءً، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ أَشْهَدُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَصَلَّى قَبْلَ الْخُطْبَةِ - قَالَ - ثُمَّ خَطَبَ فَرَأَى أَنَّهُ لَمْ يُسْمِعِ النِّسَاءَ فَأَتَاهُنَّ فَذَكَّرَهُنَّ وَوَعَظَهُنَّ وَأَمَرَهُنَّ بِالصَّدَقَةِ وَبِلاَلٌ قَائِلٌ بِثَوْبِهِ فَجَعَلَتِ الْمَرْأَةُ تُلْقِي الْخَاتَمَ وَالْخُرْصَ وَالشَّىْءَ ‏.‏ وَحَدَّثَنِيهِ أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، ح وَحَدَّثَنِي يَعْقُوبُ الدَّوْرَقِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، كِلاَهُمَا عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{2046}\hadithtrans{Ibn 'Abbas reported:I bear testimony to the Messenger of Allah (ﷺ) offering prayer before Kbutba. He (after saying prayer) delivered the Kutba, and he found that the women could not hear it, so he came to them and exhorted them and preached them and commanded them to give alms, and Bilal had stretched his cloth and the women were throwing rings, earrings and other things. This hadith has been narrated on the authority of Ayyub with the same chain of transmitters}}
\hadithdefcmd{muslim}{2057}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، عَنْ سَعِيدِ، بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ يَوْمَ أَضْحَى أَوْ فِطْرٍ فَصَلَّى رَكْعَتَيْنِ لَمْ يُصَلِّ قَبْلَهَا وَلاَ بَعْدَهَا ثُمَّ أَتَى النِّسَاءَ وَمَعَهُ بِلاَلٌ فَأَمَرَهُنَّ بِالصَّدَقَةِ فَجَعَلَتِ الْمَرْأَةُ تُلْقِي خُرْصَهَا وَتُلْقِي سِخَابَهَا ‏.‏ وَحَدَّثَنِيهِ عَمْرٌو النَّاقِدُ، حَدَّثَنَا ابْنُ إِدْرِيسَ، ح وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ، وَمُحَمَّدُ، بْنُ بَشَّارٍ جَمِيعًا عَنْ غُنْدَرٍ، كِلاَهُمَا عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{2057}\hadithtrans{Ibn 'Abbas reported that the Messenger of Allah (ﷺ) went out on the day of Adha or Fitr and observed two rak'ahs, and did not observe prayer (at that place) before and after that. He then came to the women along with Bilal and commanded them to give alms and the women began to give their rings and necklaces. This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{2058}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، عَنْ سَعِيدِ، بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ يَوْمَ أَضْحَى أَوْ فِطْرٍ فَصَلَّى رَكْعَتَيْنِ لَمْ يُصَلِّ قَبْلَهَا وَلاَ بَعْدَهَا ثُمَّ أَتَى النِّسَاءَ وَمَعَهُ بِلاَلٌ فَأَمَرَهُنَّ بِالصَّدَقَةِ فَجَعَلَتِ الْمَرْأَةُ تُلْقِي خُرْصَهَا وَتُلْقِي سِخَابَهَا ‏.‏ وَحَدَّثَنِيهِ عَمْرٌو النَّاقِدُ، حَدَّثَنَا ابْنُ إِدْرِيسَ، ح وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ، وَمُحَمَّدُ، بْنُ بَشَّارٍ جَمِيعًا عَنْ غُنْدَرٍ، كِلاَهُمَا عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{2058}\hadithtrans{Ibn 'Abbas reported that the Messenger of Allah (ﷺ) went out on the day of Adha or Fitr and observed two rak'ahs, and did not observe prayer (at that place) before and after that. He then came to the women along with Bilal and commanded them to give alms and the women began to give their rings and necklaces. This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{2093}{وَحَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ نَمِرٍ، أَنَّهُ سَمِعَ ابْنَ شِهَابٍ، يُخْبِرُ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم جَهَرَ فِي صَلاَةِ الْخُسُوفِ بِقِرَاءَتِهِ فَصَلَّى أَرْبَعَ رَكَعَاتٍ فِي رَكْعَتَيْنِ وَأَرْبَعَ سَجَدَاتٍ ‏.‏ قَالَ الزُّهْرِيُّ وَأَخْبَرَنِي كَثِيرُ بْنُ عَبَّاسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ صَلَّى أَرْبَعَ رَكَعَاتٍ فِي رَكْعَتَيْنِ وَأَرْبَعَ سَجَدَاتٍ ‏.‏\hadithno{2093}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) recited loudly in the eclipse prayer, and he observed four rak'ahs in the form of two rak'ahs and four prostrations. Zuhri said:Kathir b. 'Abbas narrated on the authority of Ibn 'Abbas that the Messenger of Allah (ﷺ) observed four rak'ahs and four prostrations in two rak'ahs}}
\hadithdefcmd{muslim}{2100}{وَحَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، قَالَ حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي يَوْمٍ شَدِيدِ الْحَرِّ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِأَصْحَابِهِ فَأَطَالَ الْقِيَامَ حَتَّى جَعَلُوا يَخِرُّونَ ثُمَّ رَكَعَ فَأَطَالَ ثُمَّ رَفَعَ فَأَطَالَ ثُمَّ رَكَعَ فَأَطَالَ ثُمَّ رَفَعَ فَأَطَالَ ثُمَّ سَجَدَ سَجْدَتَيْنِ ثُمَّ قَامَ فَصَنَعَ نَحْوًا مِنْ ذَاكَ فَكَانَتْ أَرْبَعَ رَكَعَاتٍ وَأَرْبَعَ سَجَدَاتٍ ثُمَّ قَالَ ‏"‏ إِنَّهُ عُرِضَ عَلَىَّ كُلُّ شَىْءٍ تُولَجُونَهُ فَعُرِضَتْ عَلَىَّ الْجَنَّةُ حَتَّى لَوْ تَنَاوَلْتُ مِنْهَا قِطْفًا أَخَذْتُهُ - أَوْ قَالَ تَنَاوَلْتُ مِنْهَا قِطْفًا - فَقَصُرَتْ يَدِي عَنْهُ وَعُرِضَتْ عَلَىَّ النَّارُ فَرَأَيْتُ فِيهَا امْرَأَةً مِنْ بَنِي إِسْرَائِيلَ تُعَذَّبُ فِي هِرَّةٍ لَهَا رَبَطَتْهَا فَلَمْ تُطْعِمْهَا وَلَمْ تَدَعْهَا تَأْكُلُ مِنْ خَشَاشِ الأَرْضِ وَرَأَيْتُ أَبَا ثُمَامَةَ عَمْرَو بْنَ مَالِكٍ يَجُرُّ قُصْبَهُ فِي النَّارِ ‏.‏ وَإِنَّهُمْ كَانُوا يَقُولُونَ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَخْسِفَانِ إِلاَّ لِمَوْتِ عَظِيمٍ وَإِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ يُرِيكُمُوهُمَا فَإِذَا خَسَفَا فَصَلُّوا حَتَّى تَنْجَلِيَ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ الصَّبَّاحِ، عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ إِلاَّ أَنَّهُ قَالَ ‏"‏ وَرَأَيْتُ فِي النَّارِ امْرَأَةً حِمْيَرِيَّةً سَوْدَاءَ طَوِيلَةً ‏"‏ ‏.‏ وَلَمْ يَقُلْ ‏"‏ مِنْ بَنِي إِسْرَائِيلَ ‏"‏ ‏\hadithno{2100}\hadithtrans{Jabir b. 'Abdullah reported:The sun eclipsed on one extremely hot day during the lifetime of the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) prayed along with his Companions. He prolonged his qiyam (standing posture in prayer) till they (his Companions) began to fall down. He then observed a long ruku'. He raised his head (and stood up for long) and then observed a long ruku'. He then raised (his head and stood up) for a long time and then made two prostrations. He then stood up and did like this and thus he observed four ruku's and four prostrations (in two rak'ahs) and then said: All these things were brought to me in which you will be made to enter. Paradise was brought to me till (I was so close to it) that if I (had intended) to pluck a bunch (of grapes) out of it. I would have got it, or he (the Holy Prophet) said: I intended to get a bunch (out of that) but my hand could not reach it. Hell was also brought to me and I saw in it a woman belonging to the tribe of Israel who was tormented for a cat whom she had tied, but did not give it food nor set it free to eat the creatures of the earth; and I saw Abu Thumama 'Amr b. Malik who was dragging his intestines in Hell. They (the Arabs) used to say that the sun and the moon do not eclipse but on the death of some great person; but (in reality) both these (the sun and the moon) are among the signs of Allah which are shown to you; so when there is an eclipse, observe prayer till it (the sun or the moon) brightens. This hadith has been narrated by Hisham with the same chain of transmitters except this" I saw a dark woman with a tail stature and loud voice," but he made no mention of" from among Bani Israel}}
\hadithdefcmd{muslim}{2101}{وَحَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، قَالَ حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَسَفَتِ الشَّمْسُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي يَوْمٍ شَدِيدِ الْحَرِّ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِأَصْحَابِهِ فَأَطَالَ الْقِيَامَ حَتَّى جَعَلُوا يَخِرُّونَ ثُمَّ رَكَعَ فَأَطَالَ ثُمَّ رَفَعَ فَأَطَالَ ثُمَّ رَكَعَ فَأَطَالَ ثُمَّ رَفَعَ فَأَطَالَ ثُمَّ سَجَدَ سَجْدَتَيْنِ ثُمَّ قَامَ فَصَنَعَ نَحْوًا مِنْ ذَاكَ فَكَانَتْ أَرْبَعَ رَكَعَاتٍ وَأَرْبَعَ سَجَدَاتٍ ثُمَّ قَالَ ‏"‏ إِنَّهُ عُرِضَ عَلَىَّ كُلُّ شَىْءٍ تُولَجُونَهُ فَعُرِضَتْ عَلَىَّ الْجَنَّةُ حَتَّى لَوْ تَنَاوَلْتُ مِنْهَا قِطْفًا أَخَذْتُهُ - أَوْ قَالَ تَنَاوَلْتُ مِنْهَا قِطْفًا - فَقَصُرَتْ يَدِي عَنْهُ وَعُرِضَتْ عَلَىَّ النَّارُ فَرَأَيْتُ فِيهَا امْرَأَةً مِنْ بَنِي إِسْرَائِيلَ تُعَذَّبُ فِي هِرَّةٍ لَهَا رَبَطَتْهَا فَلَمْ تُطْعِمْهَا وَلَمْ تَدَعْهَا تَأْكُلُ مِنْ خَشَاشِ الأَرْضِ وَرَأَيْتُ أَبَا ثُمَامَةَ عَمْرَو بْنَ مَالِكٍ يَجُرُّ قُصْبَهُ فِي النَّارِ ‏.‏ وَإِنَّهُمْ كَانُوا يَقُولُونَ إِنَّ الشَّمْسَ وَالْقَمَرَ لاَ يَخْسِفَانِ إِلاَّ لِمَوْتِ عَظِيمٍ وَإِنَّهُمَا آيَتَانِ مِنْ آيَاتِ اللَّهِ يُرِيكُمُوهُمَا فَإِذَا خَسَفَا فَصَلُّوا حَتَّى تَنْجَلِيَ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ الصَّبَّاحِ، عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ إِلاَّ أَنَّهُ قَالَ ‏"‏ وَرَأَيْتُ فِي النَّارِ امْرَأَةً حِمْيَرِيَّةً سَوْدَاءَ طَوِيلَةً ‏"‏ ‏.‏ وَلَمْ يَقُلْ ‏"‏ مِنْ بَنِي إِسْرَائِيلَ ‏"‏ ‏\hadithno{2101}\hadithtrans{Jabir b. 'Abdullah reported:The sun eclipsed on one extremely hot day during the lifetime of the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) prayed along with his Companions. He prolonged his qiyam (standing posture in prayer) till they (his Companions) began to fall down. He then observed a long ruku'. He raised his head (and stood up for long) and then observed a long ruku'. He then raised (his head and stood up) for a long time and then made two prostrations. He then stood up and did like this and thus he observed four ruku's and four prostrations (in two rak'ahs) and then said: All these things were brought to me in which you will be made to enter. Paradise was brought to me till (I was so close to it) that if I (had intended) to pluck a bunch (of grapes) out of it. I would have got it, or he (the Holy Prophet) said: I intended to get a bunch (out of that) but my hand could not reach it. Hell was also brought to me and I saw in it a woman belonging to the tribe of Israel who was tormented for a cat whom she had tied, but did not give it food nor set it free to eat the creatures of the earth; and I saw Abu Thumama 'Amr b. Malik who was dragging his intestines in Hell. They (the Arabs) used to say that the sun and the moon do not eclipse but on the death of some great person; but (in reality) both these (the sun and the moon) are among the signs of Allah which are shown to you; so when there is an eclipse, observe prayer till it (the sun or the moon) brightens. This hadith has been narrated by Hisham with the same chain of transmitters except this" I saw a dark woman with a tail stature and loud voice," but he made no mention of" from among Bani Israel}}
\hadithdefcmd{muslim}{2104}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، قَالَتْ أَتَيْتُ عَائِشَةَ فَإِذَا النَّاسُ قِيَامٌ وَإِذَا هِيَ تُصَلِّي فَقُلْتُ مَا شَأْنُ النَّاسِ وَاقْتَصَّ الْحَدِيثَ بِنَحْوِ حَدِيثِ ابْنِ نُمَيْرٍ عَنْ هِشَامٍ ‏.‏ أَخْبَرَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، قَالَ لاَ تَقُلْ كَسَفَتِ الشَّمْسُ وَلَكِنْ قُلْ خَسَفَتِ الشَّمْسُ ‏.‏\hadithno{2104}\hadithtrans{Asma' said:I came to 'A'isha when the people were standing (in prayer) and she was also praying. I said: What is this excitement of the people for? And the rest of the hadith was narrated like one, (narrated above). 'Urwa said: Do not say Kasafat-ush-Shamsu, but say Khasafat-ush-Shamsu}}
\hadithdefcmd{muslim}{2105}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ فَاطِمَةَ، عَنْ أَسْمَاءَ، قَالَتْ أَتَيْتُ عَائِشَةَ فَإِذَا النَّاسُ قِيَامٌ وَإِذَا هِيَ تُصَلِّي فَقُلْتُ مَا شَأْنُ النَّاسِ وَاقْتَصَّ الْحَدِيثَ بِنَحْوِ حَدِيثِ ابْنِ نُمَيْرٍ عَنْ هِشَامٍ ‏.‏ أَخْبَرَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، قَالَ لاَ تَقُلْ كَسَفَتِ الشَّمْسُ وَلَكِنْ قُلْ خَسَفَتِ الشَّمْسُ ‏.‏\hadithno{2105}\hadithtrans{Asma' said:I came to 'A'isha when the people were standing (in prayer) and she was also praying. I said: What is this excitement of the people for? And the rest of the hadith was narrated like one, (narrated above). 'Urwa said: Do not say Kasafat-ush-Shamsu, but say Khasafat-ush-Shamsu}}
\hadithdefcmd{muslim}{2149}{حَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، حَدَّثَنَا أَيُّوبُ، عَنْ عَبْدِ اللَّهِ بْنِ، أَبِي مُلَيْكَةَ قَالَ كُنْتُ جَالِسًا إِلَى جَنْبِ ابْنِ عُمَرَ وَنَحْنُ نَنْتَظِرُ جَنَازَةَ أُمِّ أَبَانٍ بِنْتِ عُثْمَانَ وَعِنْدَهُ عَمْرُو بْنُ عُثْمَانَ فَجَاءَ ابْنُ عَبَّاسٍ يَقُودُهُ قَائِدٌ فَأُرَاهُ أَخْبَرَهُ بِمَكَانِ ابْنِ عُمَرَ، فَجَاءَ حَتَّى جَلَسَ إِلَى جَنْبِي فَكُنْتُ بَيْنَهُمَا فَإِذَا صَوْتٌ مِنَ الدَّارِ فَقَالَ ابْنُ عُمَرَ - كَأَنَّهُ يَعْرِضُ عَلَى عَمْرٍو أَنْ يَقُومَ فَيَنْهَاهُمْ - سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبُكَاءِ أَهْلِهِ ‏"‏ ‏.‏ قَالَ فَأَرْسَلَهَا عَبْدُ اللَّهِ مُرْسَلَةً ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ كُنَّا مَعَ أَمِيرِ الْمُؤْمِنِينَ عُمَرَ بْنِ الْخَطَّابِ حَتَّى إِذَا كُنَّا بِالْبَيْدَاءِ إِذَا هُوَ بِرَجُلٍ نَازِلٍ فِي شَجَرَةٍ فَقَالَ لِيَ اذْهَبْ فَاعْلَمْ لِي مَنْ ذَاكَ الرَّجُلُ ‏.‏ فَذَهَبْتُ فَإِذَا هُوَ صُهَيْبٌ ‏.‏ فَرَجَعْتُ إِلَيْهِ فَقُلْتُ إِنَّكَ أَمَرْتَنِي أَنْ أَعْلَمَ لَكَ مَنْ ذَاكَ وَإِنَّهُ صُهَيْبٌ ‏.‏ قَالَ مُرْهُ فَلْيَلْحَقْ بِنَا ‏.‏ فَقُلْتُ إِنَّ مَعَهُ أَهْلَهُ ‏.‏ قَالَ وَإِنْ كَانَ مَعَهُ أَهْلُهُ - وَرُبَّمَا قَالَ أَيُّوبُ مُرْهُ فَلْيَلْحَقْ بِنَا - فَلَمَّا قَدِمْنَا لَمْ يَلْبَثْ أَمِيرُ الْمُؤْمِنِينَ أَنْ أُصِيبَ فَجَاءَ صُهَيْبٌ يَقُولُ وَاأَخَاهْ وَاصَاحِبَاهْ ‏.‏ فَقَالَ عُمَرُ أَلَمْ تَعْلَمْ أَوْ لَمْ تَسْمَعْ - قَالَ أَيُّوبُ أَوْ قَالَ أَوَلَمْ تَعْلَمْ أَوَلَمْ تَسْمَعْ - أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبَعْضِ بُكَاءِ أَهْلِهِ ‏"‏ ‏.‏ قَالَ فَأَمَّا عَبْدُ اللَّهِ فَأَرْسَلَهَا مُرْسَلَةً وَأَمَّا عُمَرُ فَقَالَ بِبَعْضٍ ‏.‏ فَقُمْتُ فَدَخَلْتُ عَلَى عَائِشَةَ فَحَدَّثْتُهَا بِمَا، قَالَ ابْنُ عُمَرَ فَقَالَتْ لاَ وَاللَّهِ مَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَطُّ ‏"‏ إِنَّ الْمَيِّتَ يُعَذَّبُ بِبُكَاءِ أَحَدٍ ‏"‏ ‏.‏ وَلَكِنَّهُ قَالَ ‏"‏ إِنَّ الْكَافِرَ يَزِيدُهُ اللَّهُ بِبُكَاءِ أَهْلِهِ عَذَابًا وَإِنَّ اللَّهَ لَهُوَ أَضْحَكَ وَأَبْكَى وَلاَ تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَى ‏"‏ ‏.‏ قَالَ أَيُّوبُ قَالَ ابْنُ أَبِي مُلَيْكَةَ حَدَّثَنِي الْقَاسِمُ بْنُ مُحَمَّدٍ قَالَ لَمَّا بَلَغَ عَائِشَةَ قَوْلُ عُمَرَ وَابْنِ عُمَرَ قَالَتْ إِنَّكُمْ لَتُحَدِّثُونِّي عَنْ غَيْرِ كَاذِبَيْنِ وَلاَ مُكَذَّبَيْنِ وَلَكِنَّ السَّمْعَ يُخْطِئُ ‏.‏\hadithno{2149}\hadithtrans{Abdullah b. Abu Mulaika reported:I was sitting by the side of Ibn 'Umar, and we were waiting for the bier of Umm Aban, daughter of 'Uthman, and there was also 'Amr b. 'Uthman. In the meanwhile there came Ibn 'Abbas led by a guide. I conceive that he was informed of the place of Ibn 'Umar. So he came till he sat by my side. While I was between them (Ibn 'Abbas and Ibn 'Umar) there came the noise (of wailing) from the house. Upon this Ibn 'Umar said (that is, he pointed out to 'Amr that he should stand and forbid them, for): I heard the Messenger of Allah (ﷺ) as saying: The dead is punished because of the lamentation of his family. 'Abdullah made it general (what was said for a particular occasion). Ibn 'Abbas said: When we were with the Commander of the believers, 'Umar b. Khattab, we reached Baida', and there was a man under the shadow of the tree. He said to me: Go and inform me who is that person. So I went and (found) that he was Suhaib. I returned to him and said: You commanded me to find out for you who that was, and he is Suhaib. He (Hadrat 'Umar) said: Command him to see us. I said: He has family along with him. He said: (That is of no account) even if he has family along with him. So he (the narrator) told him to see (the Commander of the believers and his party). When we came (to Medina), it was before long that the Commander of the believers was wounded, and Suhaib came weeping and crying: Alas for the brother, alas for the companion. Upon this 'Umar said: Didn't you know, or didn't you hear, that the Messenger of Allah (ﷺ) said:" The dead is punished because of the lamentation of his family"? Then 'Abdullah made it general and 'Umar told it of certain occasions. So I ('Abdullah b. Abu Mulaika) stood up and went to 'A'isha and told her what Ibn 'Umar had said. Upon this she said: I swear by Allah that Allah's Messenger (ﷺ) never said that dead would be punished because of his family's lamenting (for him). What he said was that Allah would increase the punishment of the unbeliever because of his family's lamenting for him. Verily it is Allah Who has caused laughter and weeping. No bearer of a burden will bear another's burden. Ibn Abu Mulaika said that al-Qasim b. Muhammad said that when the words of 'Umar and Ibn 'Umar were conveyed to 'A'isha, she said: You have narrated it to me from those who are neither liar nor those suspected of lying but (sometimes) hearing misleads}}
\hadithdefcmd{muslim}{2150}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ ابْنُ رَافِعٍ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ أَبِي مُلَيْكَةَ، قَالَ تُوُفِّيَتِ ابْنَةٌ لِعُثْمَانَ بْنِ عَفَّانَ بِمَكَّةَ قَالَ فَجِئْنَا لِنَشْهَدَهَا - قَالَ - فَحَضَرَهَا ابْنُ عُمَرَ وَابْنُ عَبَّاسٍ قَالَ وَإِنِّي لَجَالِسٌ بَيْنَهُمَا - قَالَ - جَلَسْتُ إِلَى أَحَدِهِمَا ثُمَّ جَاءَ الآخَرُ فَجَلَسَ إِلَى جَنْبِي فَقَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ لِعَمْرِو بْنِ عُثْمَانَ وَهُوَ مُوَاجِهُهُ أَلاَ تَنْهَى عَنِ الْبُكَاءِ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الْمَيِّتَ لَيُعَذَّبُ بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ قَدْ كَانَ عُمَرُ يَقُولُ بَعْضَ ذَلِكَ ثُمَّ حَدَّثَ فَقَالَ صَدَرْتُ مَعَ عُمَرَ مِنْ مَكَّةَ حَتَّى إِذَا كُنَّا بِالْبَيْدَاءِ إِذَا هُوَ بِرَكْبٍ تَحْتَ ظِلِّ شَجَرَةٍ فَقَالَ اذْهَبْ فَانْظُرْ مَنْ هَؤُلاَءِ الرَّكْبُ فَنَظَرْتُ فَإِذَا هُوَ صُهَيْبٌ - قَالَ - فَأَخْبَرْتُهُ فَقَالَ ادْعُهُ لِي ‏.‏ قَالَ فَرَجَعْتُ إِلَى صُهَيْبٍ فَقُلْتُ ارْتَحِلْ فَالْحَقْ أَمِيرَ الْمُؤْمِنِينَ ‏.‏ فَلَمَّا أَنْ أُصِيبَ عُمَرُ دَخَلَ صُهَيْبٌ يَبْكِي يَقُولُ وَاأَخَاهْ وَاصَاحِبَاهْ ‏.‏ فَقَالَ عُمَرُ يَا صُهَيْبُ أَتَبْكِي عَلَىَّ وَقَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الْمَيِّتَ يُعَذَّبُ بِبَعْضِ بُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ فَلَمَّا مَاتَ عُمَرُ ذَكَرْتُ ذَلِكَ لِعَائِشَةَ فَقَالَتْ يَرْحَمُ اللَّهُ عُمَرَ لاَ وَاللَّهِ مَا حَدَّثَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ يُعَذِّبُ الْمُؤْمِنَ بِبُكَاءِ أَحَدٍ ‏"‏ ‏.‏ وَلَكِنْ قَالَ ‏"‏ إِنَّ اللَّهَ يَزِيدُ الْكَافِرَ عَذَابًا بِبُكَاءِ أَهْلِهِ عَلَيْهِ ‏"‏ قَالَ وَقَالَتْ عَائِشَةُ حَسْبُكُمُ الْقُرْآنُ ‏\{‏ وَلاَ تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَى‏\}‏ قَالَ وَقَالَ ابْنُ عَبَّاسٍ عِنْدَ ذَلِكَ وَاللَّهُ أَضْحَكَ وَأَبْكَى ‏.‏ قَالَ ابْنُ أَبِي مُلَيْكَةَ فَوَاللَّهِ مَا قَالَ ابْنُ عُمَرَ مِنْ شَىْءٍ ‏.‏\hadithno{2150}\hadithtrans{Abdullah b. Abu Mulaika said:The daughter of 'Uthman b. 'Affan died in Mecca. We came to attend her (funeral). Ibn 'Umar and Ibn 'Abbas were also present there, and I was sitting between them. He added: I (first sat) by the side of one of them, then the other one came and he sat by my side. 'Abdullah b. 'Umar said to 'Amr b. 'Uthman who was sitting opposite to him: Will you not prevent the people from lamenting, for the Messenger of Allah (ﷺ) had said:" The dead is punished because of the lamenting of his family for him"? Ibn 'Abbas then said that Umar used to say someting of that nature, and then narrated saying: I proceeded from Mecca along with 'Umar till we reached al-Baida' and there was a party of riders under the shade of a tree. He said (to me): Go and find out who this party is. I cast a glance and there was Suhaib (in that party). So I informed him ('Umar) about it. He said: Call him to me. So I went back to Suhaib and said: Go and meet the Commander of the believers. When 'Umar was wounded, Suhaib came walling: Alas, for the brother! alas for the companion! 'Umar said: O Suhaib, do you wail for me, whereas the Messenger of Allah (ﷺ) said:" The dead would be punished on account of the lamentation of the (members of his family)"? Ibn 'Abbas said: When 'Umar died I made a mention of it to 'A'isha. She said: May Allah have mercy upon 'Umar! I swear by Allah that Allah's Messenger (ﷺ) never said that Allah would punish the believer because of the weeping (of any one of the members of his family), but he said that Allah would increase the punishment of the unbeliever because of the weeping of his family over him. 'A'isha said: The Qur'an is enough for you (when it states):" No bearer of burden will bear another's burden" (vi. 164). Thereupon Ibn 'Abbas said: Allah is He Who has caused laughter and weeping. Ibn Abu Mulaika said: By Allah, Ibn 'Umar said nothing}}
\hadithdefcmd{muslim}{2225}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنِ ابْنِ أَبِي لَيْلَى، أَنَّ قَيْسَ بْنَ سَعْدٍ، وَسَهْلَ بْنَ حُنَيْفٍ، كَانَا بِالْقَادِسِيَّةِ فَمَرَّتْ بِهِمَا جَنَازَةٌ فَقَامَا فَقِيلَ لَهُمَا إِنَّهَا مِنْ أَهْلِ الأَرْضِ ‏.‏ فَقَالاَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّتْ بِهِ جَنَازَةٌ فَقَامَ فَقِيلَ إِنَّهُ يَهُودِيٌّ ‏.‏ فَقَالَ ‏ "‏ أَلَيْسَتْ نَفْسًا ‏"‏ ‏.‏ وَحَدَّثَنِيهِ الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، بِهَذَا الإِسْنَادِ وَفِيهِ فَقَالاَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَرَّتْ عَلَيْنَا جَنَازَةٌ ‏.‏\hadithno{2225}\hadithtrans{It is narrated on the authority of Ibn Abu Laila that while Qais b. Sa'd and Sahl b. Hunaif were both in Qadislyya a bier passed by them and they both stood up. They were told that it was the bier of one of the people of the land (non-Muslim). They said that a bier passed before the Prophet (ﷺ) and he stood up. He was told that he (the dead man) was a Jew. Upon this he remarked:Was he not a human being or did he not have a soul? And in the hadith narrated by 'Amr b. Murra with the same chain of transmitters, (the words) are:" There passed a bier before us}}
\hadithdefcmd{muslim}{2232}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ حَبِيبِ بْنِ عُبَيْدٍ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، سَمِعَهُ يَقُولُ سَمِعْتُ عَوْفَ بْنَ مَالِكٍ، يَقُولُ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى جَنَازَةٍ فَحَفِظْتُ مِنْ دُعَائِهِ وَهُوَ يَقُولُ ‏ "‏ اللَّهُمَّ اغْفِرْ لَهُ وَارْحَمْهُ وَعَافِهِ وَاعْفُ عَنْهُ وَأَكْرِمْ نُزُلَهُ وَوَسِّعْ مُدْخَلَهُ وَاغْسِلْهُ بِالْمَاءِ وَالثَّلْجِ وَالْبَرَدِ وَنَقِّهِ مِنَ الْخَطَايَا كَمَا نَقَّيْتَ الثَّوْبَ الأَبْيَضَ مِنَ الدَّنَسِ وَأَبْدِلْهُ دَارًا خَيْرًا مِنْ دَارِهِ وَأَهْلاً خَيْرًا مِنْ أَهْلِهِ وَزَوْجًا خَيْرًا مِنْ زَوْجِهِ وَأَدْخِلْهُ الْجَنَّةَ وَأَعِذْهُ مِنْ عَذَابِ الْقَبْرِ أَوْ مِنْ عَذَابِ النَّارِ ‏"‏ ‏.‏ قَالَ حَتَّى تَمَنَّيْتُ أَنْ أَكُونَ أَنَا ذَلِكَ الْمَيِّتَ ‏.‏ قَالَ وَحَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ جُبَيْرٍ حَدَّثَهُ عَنْ أَبِيهِ عَنْ عَوْفِ بْنِ مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِ هَذَا الْحَدِيثِ أَيْضًا ‏.‏\hadithno{2232}\hadithtrans{Jubair b. Nufair says:I heard it from 'Auf b. Malik that the Prophet (ﷺ) said prayer on the dead body, and I remembered his prayer:" O Allah! forgive him, have mercy upon him, give him peace and absolve him. Receive him with honour and make his grave spacious; wash him with water, snow and hail. Cleanse him from faults as Thou wouldst cleanse a white garment from impurity. Requite him with an abode more excellent than his abode, with a family better than his family, and with a mate better than his mate. Admit him to the Garden, and protect him from the torment of the grave and the torment of the Fire." ('Auf bin Malik) said: I earnestly desired that I were this dead body}}
\hadithdefcmd{muslim}{2243}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي، الْهَيَّاجِ الأَسَدِيِّ قَالَ قَالَ لِي عَلِيُّ بْنُ أَبِي طَالِبٍ أَلاَّ أَبْعَثُكَ عَلَى مَا بَعَثَنِي عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ لاَ تَدَعَ تِمْثَالاً إِلاَّ طَمَسْتَهُ وَلاَ قَبْرًا مُشْرِفًا إِلاَّ سَوَّيْتَهُ ‏.‏ وَحَدَّثَنِيهِ أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي حَبِيبٌ، بِهَذَا الإِسْنَادِ وَقَالَ وَلاَ صُورَةً إِلاَّ طَمَسْتَهَا ‏.‏\hadithno{2243}\hadithtrans{Abu'l-Hayyaj al-Asadi told that 'Ali (b. Abu Talib) said to him:Should I not send you on the same mission as Allah's Messenger (ﷺ) sent me? Do not leave an image without obliterating it, or a high grave without levelling It. This hadith has been reported by Habib with the same chain of transmitters and he said: (Do not leave) a picture without obliterating it}}
\hadithdefcmd{muslim}{2295}{\hadithno{2295}\hadithtrans{}}
\hadithdefcmd{muslim}{2339}{\hadithno{2339}\hadithtrans{}}
\hadithdefcmd{muslim}{2381}{\hadithno{2381}\hadithtrans{}}
\hadithdefcmd{muslim}{2810}{\hadithno{2810}\hadithtrans{}}
\hadithdefcmd{muslim}{2892}{وَحَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرِو بْنِ دِينَارٍ، وَأَيُّوبَ، عَنْ سَعِيدِ، بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ بَيْنَمَا رَجُلٌ وَاقِفٌ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِعَرَفَةَ إِذْ وَقَعَ مِنْ رَاحِلَتِهِ - قَالَ أَيُّوبُ فَأَوْقَصَتْهُ أَوْ قَالَ - فَأَقْعَصَتْهُ وَقَالَ عَمْرٌو فَوَقَصَتْهُ - فَذُكِرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَكَفِّنُوهُ فِي ثَوْبَيْنِ وَلاَ تُحَنِّطُوهُ وَلاَ تُخَمِّرُوا رَأْسَهُ - قَالَ أَيُّوبُ فَإِنَّ اللَّهَ يَبْعَثُهُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا وَقَالَ عَمْرٌو - فَإِنَّ اللَّهَ يَبْعَثُهُ يَوْمَ الْقِيَامَةِ يُلَبِّي ‏"‏ ‏.‏ وَحَدَّثَنِيهِ عَمْرٌو النَّاقِدُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، قَالَ نُبِّئْتُ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - أَنَّ رَجُلاً، كَانَ وَاقِفًا مَعَ النَّبِيِّ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ ‏.‏ فَذَكَرَ نَحْوَ مَا ذَكَرَ حَمَّادٌ عَنْ أَيُّوبَ ‏.‏\hadithno{2892}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported:While a person was standing in 'Arafat with the Messenger of Allah (ﷺ) he fell down from his camel and broke his neck. This was mentioned to the Messenger of Allah (ﷺ), whereupon he said: Bathe him with water mixed with the leaves of the lote tree and shroud him in two (pieces of) cloth and neither perfume him nor cover his head; (Ayyub said) for Allah would raise him on the Day of Resurrection in the state of pronouncing Talbiya. ('Amr. however, said): Verily Allah would raise him on the Day of Resurrection pronouncing Talbiya. Sa'id b. Jubair narrated this hadith on the authority of Ibn 'Abbas (Allah be pleased with them) that a person was standing with the Messenger of Allah (ﷺ) as he was in the state of Ihram. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2893}{وَحَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرِو بْنِ دِينَارٍ، وَأَيُّوبَ، عَنْ سَعِيدِ، بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - قَالَ بَيْنَمَا رَجُلٌ وَاقِفٌ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِعَرَفَةَ إِذْ وَقَعَ مِنْ رَاحِلَتِهِ - قَالَ أَيُّوبُ فَأَوْقَصَتْهُ أَوْ قَالَ - فَأَقْعَصَتْهُ وَقَالَ عَمْرٌو فَوَقَصَتْهُ - فَذُكِرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ اغْسِلُوهُ بِمَاءٍ وَسِدْرٍ وَكَفِّنُوهُ فِي ثَوْبَيْنِ وَلاَ تُحَنِّطُوهُ وَلاَ تُخَمِّرُوا رَأْسَهُ - قَالَ أَيُّوبُ فَإِنَّ اللَّهَ يَبْعَثُهُ يَوْمَ الْقِيَامَةِ مُلَبِّيًا وَقَالَ عَمْرٌو - فَإِنَّ اللَّهَ يَبْعَثُهُ يَوْمَ الْقِيَامَةِ يُلَبِّي ‏"‏ ‏.‏ وَحَدَّثَنِيهِ عَمْرٌو النَّاقِدُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، قَالَ نُبِّئْتُ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، - رضى الله عنهما - أَنَّ رَجُلاً، كَانَ وَاقِفًا مَعَ النَّبِيِّ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ ‏.‏ فَذَكَرَ نَحْوَ مَا ذَكَرَ حَمَّادٌ عَنْ أَيُّوبَ ‏.‏\hadithno{2893}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported:While a person was standing in 'Arafat with the Messenger of Allah (ﷺ) he fell down from his camel and broke his neck. This was mentioned to the Messenger of Allah (ﷺ), whereupon he said: Bathe him with water mixed with the leaves of the lote tree and shroud him in two (pieces of) cloth and neither perfume him nor cover his head; (Ayyub said) for Allah would raise him on the Day of Resurrection in the state of pronouncing Talbiya. ('Amr. however, said): Verily Allah would raise him on the Day of Resurrection pronouncing Talbiya. Sa'id b. Jubair narrated this hadith on the authority of Ibn 'Abbas (Allah be pleased with them) that a person was standing with the Messenger of Allah (ﷺ) as he was in the state of Ihram. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2978}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي عَبْدُ الصَّمَدِ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ مُطَرِّفٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، - رضى الله عنه - قَالَ تَمَتَّعْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَمْ يَنْزِلْ فِيهِ الْقُرْآنُ ‏.‏ قَالَ رَجُلٌ بِرَأْيِهِ مَا شَاءَ ‏.‏ وَحَدَّثَنِيهِ حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ، حَدَّثَنَا إِسْمَاعِيلُ، بْنُ مُسْلِمٍ حَدَّثَنِي مُحَمَّدُ بْنُ وَاسِعٍ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، - رضى الله عنه - بِهَذَا الْحَدِيثِ قَالَ تَمَتَّعَ نَبِيُّ اللَّهِ صلى الله عليه وسلم وَتَمَتَّعْنَا مَعَهُ ‏.‏\hadithno{2978}\hadithtrans{Imran b. Husain (Allah be pleased with him) reported:We performed Tamattu' (Hajj and 'Umra combining together) in the company of Allah's Messenger (ﷺ), and nothing was revealed in the Qur'an (concerning the abrogation of this practice), and whatever a person (Hadhrat 'Umar) said was his personal opinion. 'Imran b. Husain narrated this hadith (in these words also):" Allah's Apostle (ﷺ) performed Hajj Tamattu' and we also performed it along with him}}
\hadithdefcmd{muslim}{2979}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي عَبْدُ الصَّمَدِ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ مُطَرِّفٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، - رضى الله عنه - قَالَ تَمَتَّعْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلَمْ يَنْزِلْ فِيهِ الْقُرْآنُ ‏.‏ قَالَ رَجُلٌ بِرَأْيِهِ مَا شَاءَ ‏.‏ وَحَدَّثَنِيهِ حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ، حَدَّثَنَا إِسْمَاعِيلُ، بْنُ مُسْلِمٍ حَدَّثَنِي مُحَمَّدُ بْنُ وَاسِعٍ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، - رضى الله عنه - بِهَذَا الْحَدِيثِ قَالَ تَمَتَّعَ نَبِيُّ اللَّهِ صلى الله عليه وسلم وَتَمَتَّعْنَا مَعَهُ ‏.‏\hadithno{2979}\hadithtrans{Imran b. Husain (Allah be pleased with him) reported:We performed Tamattu' (Hajj and 'Umra combining together) in the company of Allah's Messenger (ﷺ), and nothing was revealed in the Qur'an (concerning the abrogation of this practice), and whatever a person (Hadhrat 'Umar) said was his personal opinion. 'Imran b. Husain narrated this hadith (in these words also):" Allah's Apostle (ﷺ) performed Hajj Tamattu' and we also performed it along with him}}
\hadithdefcmd{muslim}{3023}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا دَاوُدُ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم نَصْرُخُ بِالْحَجِّ صُرَاخًا فَلَمَّا قَدِمْنَا مَكَّةَ أَمَرَنَا أَنْ نَجْعَلَهَا عُمْرَةً إِلاَّ مَنْ سَاقَ الْهَدْىَ فَلَمَّا كَانَ يَوْمُ التَّرْوِيَةِ وَرُحْنَا إِلَى مِنًى أَهْلَلْنَا بِالْحَجِّ ‏.‏\hadithno{3023}\hadithtrans{Abu Sa'id (Allah be pleased with him) reported:We went out with Allah's messenger (ﷺ) pronouncing loudly the Talbiya for Hajj When we came to Mecca, he commanded us that we should change this (Ihram for Hajj) to that of Umra except one who had brought the sacrificial animal with him. When it was the day of Tarwiya (8th of Dhul-Hijja) and we went to Mini, we (again) pronounced Talbiya for Hajj}}
\hadithdefcmd{muslim}{3028}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، وَعَبْدِ الْعَزِيزِ، بْنِ صُهَيْبٍ وَحُمَيْدٍ أَنَّهُمْ سَمِعُوا أَنَسًا، - رضى الله عنه - قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَهَلَّ بِهِمَا جَمِيعًا ‏"‏ لَبَّيْكَ عُمْرَةً وَحَجًّا لَبَّيْكَ عُمْرَةً وَحَجًّا ‏"‏ ‏.‏ وَحَدَّثَنِيهِ عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، وَحُمَيْدٍ الطَّوِيلِ قَالَ يَحْيَى سَمِعْتُ أَنَسًا، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ لَبَّيْكَ عُمْرَةً وَحَجًّا ‏"‏ ‏.‏ وَقَالَ حُمَيْدٌ قَالَ أَنَسٌ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لَبَّيْكَ بِعُمْرَةٍ وَحَجٍّ ‏"‏ ‏.‏\hadithno{3028}\hadithtrans{Anas (Allah be pleased with him) reported:I heard Allah's Messenger (ﷺ) pronouncing Talbiya for both simultaneously, Talbiya for 'Umra and Hajj. Talbiya for Uwra and Hajj (he performed both Hajj and Umra as a Qarin). In another version words are: I heard Allah's Messenger (ﷺ) pronouncing Talbiya for Umra and Hajj (simultaneously)}}
\hadithdefcmd{muslim}{3029}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، وَعَبْدِ الْعَزِيزِ، بْنِ صُهَيْبٍ وَحُمَيْدٍ أَنَّهُمْ سَمِعُوا أَنَسًا، - رضى الله عنه - قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَهَلَّ بِهِمَا جَمِيعًا ‏"‏ لَبَّيْكَ عُمْرَةً وَحَجًّا لَبَّيْكَ عُمْرَةً وَحَجًّا ‏"‏ ‏.‏ وَحَدَّثَنِيهِ عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، وَحُمَيْدٍ الطَّوِيلِ قَالَ يَحْيَى سَمِعْتُ أَنَسًا، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ لَبَّيْكَ عُمْرَةً وَحَجًّا ‏"‏ ‏.‏ وَقَالَ حُمَيْدٌ قَالَ أَنَسٌ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لَبَّيْكَ بِعُمْرَةٍ وَحَجٍّ ‏"‏ ‏.‏\hadithno{3029}\hadithtrans{Anas (Allah be pleased with him) reported:I heard Allah's Messenger (ﷺ) pronouncing Talbiya for both simultaneously, Talbiya for 'Umra and Hajj. Talbiya for Uwra and Hajj (he performed both Hajj and Umra as a Qarin). In another version words are: I heard Allah's Messenger (ﷺ) pronouncing Talbiya for Umra and Hajj (simultaneously)}}
\hadithdefcmd{muslim}{3038}{\hadithno{3038}\hadithtrans{}}
\hadithdefcmd{muslim}{3039}{\hadithno{3039}\hadithtrans{}}
\hadithdefcmd{muslim}{3087}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، ح. وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - قَالَ أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ مُحَمَّدِ بْنِ، أَبِي حَرْمَلَةَ عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ رَدِفْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْ عَرَفَاتٍ فَلَمَّا بَلَغَ رَسُولُ اللَّهِ صلى الله عليه وسلم الشِّعْبَ الأَيْسَرَ الَّذِي دُونَ الْمُزْدَلِفَةِ أَنَاخَ فَبَالَ ثُمَّ جَاءَ فَصَبَبْتُ عَلَيْهِ الْوَضُوءَ فَتَوَضَّأَ وُضُوءًا خَفِيفًا ثُمَّ قُلْتُ الصَّلاَةَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏ "‏ الصَّلاَةُ أَمَامَكَ ‏"‏ ‏.‏ فَرَكِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَتَى الْمُزْدَلِفَةَ فَصَلَّى ثُمَّ رَدِفَ الْفَضْلُ رَسُولَ اللَّهِ صلى الله عليه وسلم غَدَاةَ جَمْعٍ. قَالَ كُرَيْبٌ فَأَخْبَرَنِي عَبْدُ اللَّهِ بْنُ عَبَّاسٍ، عَنِ الْفَضْلِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَزَلْ يُلَبِّي حَتَّى بَلَغَ الْجَمْرَةَ ‏.‏\hadithno{3087}\hadithtrans{Usama b. Zaid (Allah be pleased with him) reported:I was sitting behind Allah's Messenger (ﷺ) on the riding animal from 'Arafat. As Allah's Messenger (ﷺ) reached the left side of the mountain which was situated near Muzdalifa, he made the camel kneel down and made water and then came back. I poured water and he, performed light ablution. I then said: Messenger of Allah, it is time for prayer. Thereupon Allah's Messenger (ﷺ) said: The prayer awaits you (at the next station, Muzdalifa). Allah's Messenger (may peaced be upon him) rode on until he came to Muzdalifa and observed prayer. Then al-Fadl (Allah be pleased with him) sat behind Allah's Messenger (ﷺ) and reached (Muzdalifa) in the morning. Kuraib said: 'Abdullah b. 'Abbas (Allah be pleased with them) narrated from al-Fadl (Allah be pleased with him) that Allah's Messenger (ﷺ) continued pronouncing Talbiya until he reached al-Jamara (al-'Aqaba)}}
\hadithdefcmd{muslim}{3092}{وَحَدَّثَنَا سُرَيْجُ بْنُ يُونُسَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا حُصَيْنٌ، عَنْ كَثِيرِ بْنِ مُدْرِكٍ الأَشْجَعِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، أَنَّ عَبْدَ اللَّهِ، لَبَّى حِينَ أَفَاضَ مِنْ جَمْعٍ فَقِيلَ أَعْرَابِيٌّ هَذَا فَقَالَ عَبْدُ اللَّهِ أَنَسِيَ النَّاسُ أَمْ ضَلُّوا سَمِعْتُ الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ يَقُولُ فِي هَذَا الْمَكَانِ ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ ‏"‏ ‏. وَحَدَّثَنَاهُ حَسَنٌ الْحُلْوَانِيُّ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا سُفْيَانُ، عَنْ حُصَيْنٍ، بِهَذَا الإِسْنَادِ ‏\hadithno{3092}\hadithtrans{Abd al-Rahman b. Yazid reported that 'Abdullah (b. Mas'ud) pronounced Talbiya as he returned from the gathering of the people (at Muzdalifa). It was said:He might be a Bedouin (not knowing correctly the rituals of Hajj and, therefore, pronouncing Talbia at this stage), whereupon Abdullah said: Hive the people forgotten (this Sunnah of the Holy Prophet) or have they gone astray? I heard him, upon whom Sibrah al-Baqara was revealed, pronouncing Talbiya at the very place}}
\hadithdefcmd{muslim}{3093}{وَحَدَّثَنَا سُرَيْجُ بْنُ يُونُسَ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا حُصَيْنٌ، عَنْ كَثِيرِ بْنِ مُدْرِكٍ الأَشْجَعِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، أَنَّ عَبْدَ اللَّهِ، لَبَّى حِينَ أَفَاضَ مِنْ جَمْعٍ فَقِيلَ أَعْرَابِيٌّ هَذَا فَقَالَ عَبْدُ اللَّهِ أَنَسِيَ النَّاسُ أَمْ ضَلُّوا سَمِعْتُ الَّذِي أُنْزِلَتْ عَلَيْهِ سُورَةُ الْبَقَرَةِ يَقُولُ فِي هَذَا الْمَكَانِ ‏ "‏ لَبَّيْكَ اللَّهُمَّ لَبَّيْكَ ‏"‏ ‏. وَحَدَّثَنَاهُ حَسَنٌ الْحُلْوَانِيُّ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا سُفْيَانُ، عَنْ حُصَيْنٍ، بِهَذَا الإِسْنَادِ ‏\hadithno{3093}\hadithtrans{Abd al-Rahman b. Yazid reported that 'Abdullah (b. Mas'ud) pronounced Talbiya as he returned from the gathering of the people (at Muzdalifa). It was said:He might be a Bedouin (not knowing correctly the rituals of Hajj and, therefore, pronouncing Talbia at this stage), whereupon Abdullah said: Hive the people forgotten (this Sunnah of the Holy Prophet) or have they gone astray? I heard him, upon whom Sibrah al-Baqara was revealed, pronouncing Talbiya at the very place}}
\hadithdefcmd{muslim}{3108}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَخْبَرَنِي عَدِيُّ بْنُ ثَابِتٍ، أَنَّ عَبْدَ اللَّهِ بْنَ يَزِيدَ الْخَطْمِيَّ، حَدَّثَهُ أَنَّ أَبَا أَيُّوبَ أَخْبَرَهُ أَنَّهُ، صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ الْمَغْرِبَ وَالْعِشَاءَ بِالْمُزْدَلِفَةِ ‏.‏ وَحَدَّثَنَاهُ قُتَيْبَةُ، وَابْنُ، رُمْحٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، بِهَذَا الإِسْنَادِ ‏.‏ قَالَ ابْنُ رُمْحٍ فِي رِوَايَتِهِ عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْخَطْمِيِّ، وَكَانَ، أَمِيرًا عَلَى الْكُوفَةِ عَلَى عَهْدِ ابْنِ الزُّبَيْرِ ‏.‏\hadithno{3108}\hadithtrans{Abdullah b. Yazid al-Khatmi reported on the authority of Abu Ayyub (Allah be pleased with him) that he prayed the sunset and 'Isha' prayers (together) at Muzdalifa in the company of Allah's Messenger (ﷺ) on the occasion of the Farewell Pilgrimage}}
\hadithdefcmd{muslim}{3109}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، أَخْبَرَنِي عَدِيُّ بْنُ ثَابِتٍ، أَنَّ عَبْدَ اللَّهِ بْنَ يَزِيدَ الْخَطْمِيَّ، حَدَّثَهُ أَنَّ أَبَا أَيُّوبَ أَخْبَرَهُ أَنَّهُ، صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ الْمَغْرِبَ وَالْعِشَاءَ بِالْمُزْدَلِفَةِ ‏.‏ وَحَدَّثَنَاهُ قُتَيْبَةُ، وَابْنُ، رُمْحٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، بِهَذَا الإِسْنَادِ ‏.‏ قَالَ ابْنُ رُمْحٍ فِي رِوَايَتِهِ عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْخَطْمِيِّ، وَكَانَ، أَمِيرًا عَلَى الْكُوفَةِ عَلَى عَهْدِ ابْنِ الزُّبَيْرِ ‏.‏\hadithno{3109}\hadithtrans{Abdullah b. Yazid al-Khatmi reported on the authority of Abu Ayyub (Allah be pleased with him) that he prayed the sunset and 'Isha' prayers (together) at Muzdalifa in the company of Allah's Messenger (ﷺ) on the occasion of the Farewell Pilgrimage}}
\hadithdefcmd{muslim}{3222}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، وَعُرْوَةَ، أَنَّ عَائِشَةَ، قَالَتْ حَاضَتْ صَفِيَّةُ بِنْتُ حُيَىٍّ بَعْدَ مَا أَفَاضَتْ - قَالَتْ عَائِشَةُ - فَذَكَرْتُ حِيضَتَهَا لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَحَابِسَتُنَا هِيَ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّهَا قَدْ كَانَتْ أَفَاضَتْ وَطَافَتْ بِالْبَيْتِ ثُمَّ حَاضَتْ بَعْدَ الإِفَاضَةِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَلْتَنْفِرْ‏"‏ ‏.‏\hadithno{3222}\hadithtrans{A'isha (Allah be pleased with her) reported:Safiyyah bint Huyayy entered the period of menses after performing Tawaf Ifada. I made a mention of her menses to Allah's Messenger (ﷺ), whereupon Allah's. Messenger (ﷺ) remarked: Well, then she will detain us. I said: Messenger of Allah. she has performed Tawif Ifada and circumambulated the House, and it was after this that she entered the period of menses. Thereupon Allah's Messenger (ﷺ) said: (If it is so), then proceed forth}}
\hadithdefcmd{muslim}{3223}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، وَأَحْمَدُ بْنُ عِيسَى، قَالَ أَحْمَدُ حَدَّثَنَا وَقَالَ، الآخَرَانِ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ قَالَتْ طَمِثَتْ صَفِيَّةُ بِنْتُ حُيَىٍّ زَوْجُ النَّبِيِّ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ بَعْدَ مَا أَفَاضَتْ طَاهِرًا بِمِثْلِ حَدِيثِ اللَّيْثِ ‏.‏\hadithno{3223}\hadithtrans{This hadith is narrated (from 'A'isha) on the authority of Ibn Shihab with the same chain of transmitters (and the words are):Safiyyah bint Huyayy, the wife of Allah's Apostle (ﷺ), entered the period of menses at the occasion of the Farewell Pilgrimage after she had performed Tawaf Ifada in the state of cleanliness; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{3224}{وَحَدَّثَنَا قُتَيْبَةُ، - يَعْنِي ابْنَ سَعِيدٍ - حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا أَيُّوبُ، كُلُّهُمْ عَنْ عَبْدِ الرَّحْمَنِ، بْنِ الْقَاسِمِ عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا ذَكَرَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ صَفِيَّةَ قَدْ حَاضَتْ ‏.‏ بِمَعْنَى حَدِيثِ الزُّهْرِيِّ ‏.‏\hadithno{3224}\hadithtrans{Abd al-Rahman b. al Qasim narrated on the authority of 'A'isha (Allah be pleased with her) that she made a mention to Allah's Messenger (ﷺ) that Safiyyah had entered the period of menses. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{3225}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا أَفْلَحُ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ كُنَّا نَتَخَوَّفُ أَنْ تَحِيضَ، صَفِيَّةُ قَبْلَ أَنْ تُفِيضَ - قَالَتْ - فَجَاءَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَحَابِسَتُنَا صَفِيَّةُ ‏"‏ ‏.‏ قُلْنَا قَدْ أَفَاضَتْ ‏.‏ قَالَ ‏"‏ فَلاَ إِذًا ‏"‏ ‏.‏\hadithno{3225}\hadithtrans{A'isha (Allah be pleased with her) reported:We feared that Safiyyah might have entered the period of menses before performing Tawaf Ifada. Allah's Messenger (ﷺ) came to us and said: Is Safiyyah going to detain us? Thereupon we said: She has performed Tawaf Ifada. He (the Holy Prophet) said: Then there is no detention (for us) now}}
\hadithdefcmd{muslim}{3226}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ إِنَّ صَفِيَّةَ بِنْتَ حُيَىٍّ قَدْ حَاضَتْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَعَلَّهَا تَحْبِسُنَا أَلَمْ تَكُنْ قَدْ طَافَتْ مَعَكُنَّ بِالْبَيْتِ ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ قَالَ ‏"‏ فَاخْرُجْنَ ‏"‏ ‏.‏\hadithno{3226}\hadithtrans{A'isha (Allah be pleased with her) said to the Messenger of Allah (ﷺ):Messenger of Allah, Safiyyah bint Huyayy has entered the state of menses, whereupon Allah's Messenger (ﷺ) said: Perhaps she is going to detain us. Has she not clicumambulated the House along with you (i. e. whether she has not performed Tawaf Ifada)? They said: Yes. He said: Then they should set out}}
\hadithdefcmd{muslim}{3227}{حَدَّثَنِي الْحَكَمُ بْنُ مُوسَى، حَدَّثَنِي يَحْيَى بْنُ حَمْزَةَ، عَنِ الأَوْزَاعِيِّ، - لَعَلَّهُ قَالَ - عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَرَادَ مِنْ صَفِيَّةَ بَعْضَ مَا يُرِيدُ الرَّجُلُ مِنْ أَهْلِهِ ‏.‏ فَقَالُوا إِنَّهَا حَائِضٌ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ وَإِنَّهَا لَحَابِسَتُنَا ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّهَا قَدْ زَارَتْ يَوْمَ النَّحْرِ ‏.‏ قَالَ ‏"‏ فَلْتَنْفِرْ مَعَكُمْ ‏"‏ ‏.‏\hadithno{3227}\hadithtrans{A'isha (Allah be pleased with her) reported that Allah's Messenger (ﷺ) inclined to do with Safiyyah what a man feels inclined to do with his wife. They said:Messenger of Allah, she has entered the state of menses, whereupon he said: (Well) she is going to detain us. They (his wives) said: Messenger of Allah, she performed Tawaf Ziyara (Tawaf Ifada) on the Day of Nahr. Thereupon he said: Then she should proceed along with you}}
\hadithdefcmd{muslim}{3228}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا أَرَادَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَنْفِرَ إِذَا صَفِيَّةُ عَلَى بَابِ خِبَائِهَا كَئِيبَةً حَزِينَةً ‏.‏ فَقَالَ ‏"‏ عَقْرَى حَلْقَى إِنَّكِ لَحَابِسَتُنَا ‏"‏ ‏.‏ ثُمَّ قَالَ لَهَا ‏"‏ أَكُنْتِ أَفَضْتِ يَوْمَ النَّحْرِ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ فَانْفِرِي ‏"‏ ‏.‏\hadithno{3228}\hadithtrans{A'isha (Allah be pleased with her) reported:When Allah's Apostle (ﷺ) decided to march (for return journey), he found Safiyyah at the door of her tent, sad and downcast. He remarked. Barren, shaven-head, you are going to detain us, and then said: Did you perform Tawaf Ifada on the Day of Nahr? She replied in the affirmative, whereupon he said: Then march on}}
\hadithdefcmd{muslim}{3229}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ عَنْ أَبِي مُعَاوِيَةَ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، جَمِيعًا عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ نَحْوَ حَدِيثِ الْحَكَمِ غَيْرَ أَنَّهُمَا لاَ يَذْكُرَانِ كَئِيبَةً حَزِينَةً ‏.‏\hadithno{3229}\hadithtrans{This hadith is narrated by 'A'isha (Allah be pleased with her) through another chain of transmitters, but no mention is made of" sad and downcast}}
\hadithdefcmd{muslim}{3262}{\hadithno{3262}\hadithtrans{}}
\hadithdefcmd{muslim}{3463}{\hadithno{3463}\hadithtrans{}}
\hadithdefcmd{muslim}{3499}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ مُطَرِّفٍ، عَنْ عَامِرٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الَّذِي يُعْتِقُ جَارِيَتَهُ ثُمَّ يَتَزَوَّجُهَا ‏ "‏ لَهُ أَجْرَانِ ‏"‏ ‏.‏\hadithno{3499}\hadithtrans{Abu Musa reported that Allah's Messenger (ﷺ) said about one who emancipated a slave woman, and then married her, that for him there are two rewards}}
\hadithdefcmd{muslim}{3525}{\hadithno{3525}\hadithtrans{}}
\hadithdefcmd{muslim}{3695}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَمُحَمَّدُ بْنُ أَبِي عُمَرَ، - وَتَقَارَبَا فِي لَفْظِ الْحَدِيثِ - قَالَ ابْنُ أَبِي عُمَرَ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي ثَوْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمْ أَزَلْ حَرِيصًا أَنْأَسْأَلَ عُمَرَ عَنِ الْمَرْأَتَيْنِ مِنْ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم اللَّتَيْنِ قَالَ اللَّهُ تَعَالَى ‏\{‏إِنْ تَتُوبَا إِلَى اللَّهِ فَقَدْ صَغَتْ قُلُوبُكُمَا‏\}‏ حَتَّى حَجَّ عُمَرُ وَحَجَجْتُ مَعَهُ فَلَمَّا كُنَّا بِبَعْضِ الطَّرِيقِ عَدَلَ عُمَرُ وَعَدَلْتُ مَعَهُ بِالإِدَاوَةِ فَتَبَرَّزَ ثُمَّ أَتَانِي فَسَكَبْتُ عَلَى يَدَيْهِ فَتَوَضَّأَ فَقُلْتُ يَا أَمِيرَ الْمُؤْمِنِينَ مَنِ الْمَرْأَتَانِ مِنْ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم اللَّتَانِ قَالَ اللَّهُ عَزَّ وَجَلَّ لَهُمَا ‏\{‏ إِنْ تَتُوبَا إِلَى اللَّهِ فَقَدْ صَغَتْ قُلُوبُكُمَا‏\}‏ قَالَ عُمَرُ وَاعَجَبًا لَكَ يَا ابْنَ عَبَّاسٍ - قَالَ الزُّهْرِيُّ كَرِهَ وَاللَّهِ مَا سَأَلَهُ عَنْهُ وَلَمْ يَكْتُمْهُ - قَالَ هِيَ حَفْصَةُ وَعَائِشَةُ ‏.‏ ثُمَّ أَخَذَ يَسُوقُ الْحَدِيثَ قَالَ كُنَّا مَعْشَرَ قُرَيْشٍ قَوْمًا نَغْلِبُ النِّسَاءَ فَلَمَّا قَدِمْنَا الْمَدِينَةَ وَجَدْنَا قَوْمًا تَغْلِبُهُمْ نِسَاؤُهُمْ فَطَفِقَ نِسَاؤُنَا يَتَعَلَّمْنَ مِنْ نِسَائِهِمْ - قَالَ - وَكَانَ مَنْزِلِي فِي بَنِي أُمَيَّةَ بْنِ زَيْدٍ بِالْعَوَالِي فَتَغَضَّبْتُ يَوْمًا عَلَى امْرَأَتِي فَإِذَا هِيَ تُرَاجِعُنِي فَأَنْكَرْتُ أَنْ تُرَاجِعَنِي ‏.‏ فَقَالَتْ مَا تُنْكِرُ أَنْ أُرَاجِعَكَ فَوَاللَّهِ إِنَّ أَزْوَاجَ النَّبِيِّ صلى الله عليه وسلم لَيُرَاجِعْنَهُ وَتَهْجُرُهُ إِحْدَاهُنَّ الْيَوْمَ إِلَى اللَّيْلِ ‏.‏ فَانْطَلَقْتُ فَدَخَلْتُ عَلَى حَفْصَةَ فَقُلْتُ أَتُرَاجِعِينَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ نَعَمْ ‏.‏ فَقُلْتُ أَتَهْجُرُهُ إِحْدَاكُنَّ الْيَوْمَ إِلَى اللَّيْلِ قَالَتْ نَعَمْ ‏.‏ قُلْتُ قَدْ خَابَ مَنْ فَعَلَ ذَلِكَ مِنْكُنَّ وَخَسِرَ أَفَتَأْمَنُ إِحْدَاكُنَّ أَنْ يَغْضَبَ اللَّهُ عَلَيْهَا لِغَضَبِ رَسُولِهِ صلى الله عليه وسلم فَإِذَا هِيَ قَدْ هَلَكَتْ لاَ تُرَاجِعِي رَسُولَ اللَّهِ صلى الله عليه وسلم وَلاَ تَسْأَلِيهِ شَيْئًا وَسَلِينِي مَا بَدَا لَكِ وَلاَ يَغُرَّنَّكِ أَنْ كَانَتْ جَارَتُكِ هِيَ أَوْسَمَ وَأَحَبَّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْكِ - يُرِيدُ عَائِشَةَ - قَالَ وَكَانَ لِي جَارٌ مِنَ الأَنْصَارِ فَكُنَّا نَتَنَاوَبُ النُّزُولَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَيَنْزِلُ يَوْمًا وَأَنْزِلُ يَوْمًا فَيَأْتِينِي بِخَبَرِ الْوَحْىِ وَغَيْرِهِ وَآتِيهِ بِمِثْلِ ذَلِكَ وَكُنَّا نَتَحَدَّثُ أَنَّ غَسَّانَ تُنْعِلُ الْخَيْلَ لِتَغْزُوَنَا فَنَزَلَ صَاحِبِي ثُمَّ أَتَانِي عِشَاءً فَضَرَبَ بَابِي ثُمَّ نَادَانِي فَخَرَجْتُ إِلَيْهِ فَقَالَ حَدَثَ أَمْرٌ عَظِيمٌ ‏.‏ قُلْتُ مَاذَا أَجَاءَتْ غَسَّانُ قَالَ لاَ بَلْ أَعْظَمُ مِنْ ذَلِكَ وَأَطْوَلُ طَلَّقَ النَّبِيُّ صلى الله عليه وسلم نِسَاءَهُ ‏.‏ فَقُلْتُ قَدْ خَابَتْ حَفْصَةُ وَخَسِرَتْ قَدْ كُنْتُ أَظُنُّ هَذَا كَائِنًا حَتَّى إِذَا صَلَّيْتُ الصُّبْحَ شَدَدْتُ عَلَىَّ ثِيَابِي ثُمَّ نَزَلْتُ فَدَخَلْتُ عَلَى حَفْصَةَ وَهْىَ تَبْكِي فَقُلْتُ أَطَلَّقَكُنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَتْ لاَ أَدْرِي هَا هُوَ ذَا مُعْتَزِلٌ فِي هَذِهِ الْمَشْرُبَةِ ‏.‏ فَأَتَيْتُ غُلاَمًا لَهُ أَسْوَدَ فَقُلْتُ اسْتَأْذِنْ لِعُمَرَ ‏.‏ فَدَخَلَ ثُمَّ خَرَجَ إِلَىَّ فَقَالَ قَدْ ذَكَرْتُكَ لَهُ فَصَمَتَ فَانْطَلَقْتُ حَتَّى انْتَهَيْتُ إِلَى الْمِنْبَرِ فَجَلَسْتُ فَإِذَا عِنْدَهُ رَهْطٌ جُلُوسٌ يَبْكِي بَعْضُهُمْ فَجَلَسْتُ قَلِيلاً ثُمَّ غَلَبَنِي مَا أَجِدُ ثُمَّ أَتَيْتُ الْغُلاَمَ فَقُلْتُ اسْتَأْذِنْ لِعُمَرَ ‏.‏ فَدَخَلَ ثُمَّ خَرَجَ إِلَىَّ ‏.‏ فَقَالَ قَدْ ذَكَرْتُكَ لَهُ فَصَمَتَ ‏.‏ فَوَلَّيْتُ مُدْبِرًا فَإِذَا الْغُلاَمُ يَدْعُونِي فَقَالَ ادْخُلْ فَقَدْ أَذِنَ لَكَ فَدَخَلْتُ فَسَلَّمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِذَا هُوَ مُتَّكِئٌ عَلَى رَمْلِ حَصِيرٍ قَدْ أَثَّرَ فِي جَنْبِهِ فَقُلْتُ أَطَلَّقْتَ يَا رَسُولَ اللَّهِ نِسَاءَكَ فَرَفَعَ رَأْسَهُ إِلَىَّ وَقَالَ ‏"‏ لاَ ‏"‏ ‏.‏ فَقُلْتُ اللَّهُ أَكْبَرُ لَوْ رَأَيْتَنَا يَا رَسُولَ اللَّهِ وَكُنَّا مَعْشَرَ قُرَيْشٍ قَوْمًا نَغْلِبُ النِّسَاءَ فَلَمَّا قَدِمْنَا الْمَدِينَةَ وَجَدْنَا قَوْمًا تَغْلِبُهُمْ نِسَاؤُهُمْ فَطَفِقَ نِسَاؤُنَا يَتَعَلَّمْنَ مِنْ نِسَائِهِمْ فَتَغَضَّبْتُ عَلَى امْرَأَتِي يَوْمًا فَإِذَا هِيَ تُرَاجِعُنِي فَأَنْكَرْتُ أَنْ تُرَاجِعَنِي ‏.‏ فَقَالَتْ مَا تُنْكِرُ أَنْ أُرَاجِعَكَ فَوَاللَّهِ إِنَّ أَزْوَاجَ النَّبِيِّ صلى الله عليه وسلم لَيُرَاجِعْنَهُ وَتَهْجُرُهُ إِحْدَاهُنَّ الْيَوْمَ إِلَى اللَّيْلِ ‏.‏ فَقُلْتُ قَدْ خَابَ مَنْ فَعَلَ ذَلِكَ مِنْهُنَّ وَخَسِرَ أَفَتَأْمَنُ إِحْدَاهُنَّ أَنْ يَغْضَبَ اللَّهُ عَلَيْهَا لِغَضَبِ رَسُولِهِ صلى الله عليه وسلم فَإِذَا هِيَ قَدْ هَلَكَتْ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ قَدْ دَخَلْتُ عَلَى حَفْصَةَ فَقُلْتُ لاَ يَغُرَّنَّكِ أَنْ كَانَتْ جَارَتُكِ هِيَ أَوْسَمُ مِنْكِ وَأَحَبُّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْكِ ‏.‏ فَتَبَسَّمَ أُخْرَى فَقُلْتُ أَسْتَأْنِسُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَجَلَسْتُ فَرَفَعْتُ رَأْسِي فِي الْبَيْتِ فَوَاللَّهِ مَا رَأَيْتُ فِيهِ شَيْئًا يَرُدُّ الْبَصَرَ إِلاَّ أُهُبًا ثَلاَثَةً فَقُلْتُ ادْعُ اللَّهَ يَا رَسُولَ اللَّهِ أَنْ يُوَسِّعَ عَلَى أُمَّتِكَ فَقَدْ وَسَّعَ عَلَى فَارِسَ وَالرُّومِ وَهُمْ لاَ يَعْبُدُونَ اللَّهَ فَاسْتَوَى جَالِسًا ثُمَّ قَالَ ‏"‏ أَفِي شَكٍّ أَنْتَ يَا ابْنَ الْخَطَّابِ أُولَئِكَ قَوْمٌ عُجِّلَتْ لَهُمْ طَيِّبَاتُهُمْ فِي الْحَيَاةِ الدُّنْيَا ‏"‏ ‏.‏ فَقُلْتُ اسْتَغْفِرْ لِي يَا رَسُولَ اللَّهِ ‏.‏ وَكَانَ أَقْسَمَ أَنْ لاَ يَدْخُلَ عَلَيْهِنَّ شَهْرًا مِنْ شِدَّةِ مَوْجِدَتِهِ عَلَيْهِنَّ ‏.‏ حَتَّى عَاتَبَهُ اللَّهُ عَزَّ وَجَلَّ ‏.‏ قَالَ الزُّهْرِيُّ فَأَخْبَرَنِي عُرْوَةُ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا مَضَى تِسْعٌ وَعِشْرُونَ لَيْلَةً دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بَدَأَ بِي فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّكَ أَقْسَمْتَ أَنْ لاَ تَدْخُلَ عَلَيْنَا شَهْرًا وَإِنَّكَ دَخَلْتَ مِنْ تِسْعٍ وَعِشْرِينَ أَعُدُّهُنَّ ‏.‏ فَقَالَ ‏"‏ إِنَّ الشَّهْرَ تِسْعٌ وَعِشْرُونَ - ثُمَّ قَالَ - يَا عَائِشَةُ إِنِّي ذَاكِرٌ لَكِ أَمْرًا فَلاَ عَلَيْكِ أَنْ لاَ تَعْجَلِي فِيهِ حَتَّى تَسْتَأْمِرِي أَبَوَيْكِ ‏"‏ ‏.‏ ثُمَّ قَرَأَ عَلَىَّ الآيَةَ ‏\{‏ يَا أَيُّهَا النَّبِيُّ قُلْ لأَزْوَاجِكَ‏\}‏ حَتَّى بَلَغَ ‏\{‏ أَجْرًا عَظِيمًا‏\}‏ قَالَتْ عَائِشَةُ قَدْ عَلِمَ وَاللَّهِ أَنَّ أَبَوَىَّ لَمْ يَكُونَا لِيَأْمُرَانِي بِفِرَاقِهِ قَالَتْ فَقُلْتُ أَوَفِي هَذَا أَسْتَأْمِرُ أَبَوَىَّ فَإِنِّي أُرِيدُ اللَّهَ وَرَسُولَهُ وَالدَّارَ الآخِرَةَ ‏.‏ قَالَ مَعْمَرٌ فَأَخْبَرَنِي أَيُّوبُ أَنَّ عَائِشَةَ قَالَتْ لاَ تُخْبِرْ نِسَاءَكَ أَنِّي اخْتَرْتُكَ فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ أَرْسَلَنِي مُبَلِّغًا وَلَمْ يُرْسِلْنِي مُتَعَنِّتًا ‏"‏ ‏.‏ قَالَ قَتَادَةُ صَغَتْ قُلُوبُكُمَا مَالَتْ قُلُوبُكُمَا‏.‏\hadithno{3695}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported. I had always been anxious to ask 'Umar (Allah be pleased with him) about the two ladies amongst the wives of Allah's Prophet (may peace be upon Lim) about whom Allah, the Exalted, said:" If you both turn in repentance to Allah, then indeed your hearts are inclined (to this)" (Ixvi. 4), until 'Umar (Allah be pleased with him) set out for Hajj and I also went along with him. And as we were going along a path, 'Umar (Allah be pleased with hiyn) went aside and I also went aside with him with a jug (of water). He answered the call of nature, and then came to me and I poured water over his hands and he performed ablution I said: Commander of the Faithful, who are the two ladies amongst the wives of Allah's Prophet (ﷺ) about whom Allah, the Exalted and Majestic, said: 'If you both turn to Allah in repentance, then indeed your heart are inclined to it"? 'Umar (Allah he pleased with him) said: How strange is it for you, Ibn 'Abbas! (Zuhri said: By Allah, he disliked what he asked about, but did not keep it a secret.) He ('Umar) said: They are Hafsa and 'A'isha; and he then began to narrate the hadith and said: We were such people among the Quraish who dominated women, and as we reached Medina we found there people who were dominated by their women, and our women began to learn (the habits) of their women. He further said: And my house was situated in the suburb of Aledina in the tribe of Banu Umayya b. Zaid. One day I became angry with my wife and she retorted upon me. I did not like that she should retort upon me. She said: You disapprove of my retorting upon you By Allah, the wives of Allah's Apostle (ﷺ) retort upon him, and one of them detaches herself from him for the day until the night. So I ('Umar) went out and visited Hafsa and said: Do you retort upon Allah's Messenger (ﷺ)? She said: Yes. I said; Does any one of you detach herself from him from the day to the night? She said: Yes. He said: She who did like it amongst you in fact failed and incurred loss. Does everyone amongst you not fear the wrath of Allah upon her due to the wrath of His Messenger (ﷺ), and (as a result thereof) she may perish? So do not retort upon Allah's Messenger (ﷺ) and do not ask him for anything, but ask me that which you desire, (and the frank behaviour) of your companion may not mislead you, if she is more graceful and is dearer to Allah's Messenger (ﷺ) than you (meaning 'A'isha) (Allah be pleased with her). He (Hadrat 'Umar further) said: I had a compalaion from the Ansar and, we used to remain in the company of the Messenger (ﷺ) turn by turn. He remained there for a day while I remained there on the other day, and he brought me the news about the revelation and other (matter), and I brought him (the news) like this. And we discussed that the Ghassanids were shoeing the horses in order to attack us. Id y companion once attended (the Apostle). and then came to me at night and knocked at my door and called me, and I came out to him, and he said: A matter of great importance has happened. I said: What is that? Have the Ghassanids come? He said: No, but even more serious and more significant than that: the Prophet (ﷺ) has divorced his wives. I said: Hafsa has failed and has incurred loss. and I feared that it would happen. When it was dawn I observed the dawn prayer and dressed myself, and then came there (in the house of the Holy Prophet) and visited Hafsa, and she was weeping. I said: Has Allah's Messenger (ﷺ) divorced you (all)? She said: I do not know. He has, however, separated himself in his attic. I came to a black servant and said to him: Seek permission for 'Umar. He went in and then came to me and said: I made mention of you to him, but he kept quiet. I then went to the pulpit and sat there, and there was a group of people sitting by it and some of then were weeping. I sat there for some time, until I was overpowered (by that very idea) which was in my mind. I then came back to the boy and said to him: Seek permission for Umar. He went in and came to me and said: I made mention of you to him but he kept quiet. I was about to turn back when the boy called me and said: Go in; permission has been granted to you. I went in and greeted Allah's Messenger (ﷺ) and he was reclining against the couch of mat and it had left its marks upon his side. I said: Messenger of Allah, have you divorced your wives? He raised his head towards me and said: No. I said: Allah is the Greatest. Messenger of Allah, I wish if you had seen how we the people of Quraish had domination over women but when we came to Medina we found people whom their women dominated. So our women began to learn from their women. One dily I became angry with my wife and she began to retort upon me. I did not approve that she should retort upon me. She said: You do not like that I should retort upon you, but, by Allah. the wives of Allah's Apostle (ﷺ) retort upon him and any one of them separates herself from him for a day until night. I said: He who did that amongst them in fact failed and incurred loss. Does any of them feel sate from the wrath of Allahupon her due to the wrath of Allah's Messenger (ﷺ), and she has certainly perished. Allah's Messtnger (ﷺ) smiled, I said: Messenger of Allah, I visited Hafsa and said: (The behaviour) of your companion ('A'isha) may not mislead you, If she is more graceful than you and is dearer to Allah's Messenger (ﷺ) than you. Allah's Messenger (ﷺ) smiled for the second time. I said: Allah's Messenger, way I talk to you about agreeable things? He said: Yes. I sat down and lifted my head (to see things) in the house and, by Allah, I did not see anything significant besides three hides. I said: Messenger of Allah, supplicate the Lord that He should make (life) prosperous for your Ummah as He has made plentiful for the people of Persia and Rome (in spite of the fact) that they do no, worship Allah, the Exalted and Majestic, whereupon he (Allah's Messenger) sat up an I then said: Ibn Khattab, do you doubt that they are a nation whom their nice things have been given immediately in the life of this world. I said: Allah's Messenger! seek pardon for me. And he (Allah's Messenger) had taken an oath that he would not visit them for a month due to extreme annoyance with them until Allah showed His displeasure to him (Allah's Messenger). Zuhri said: 'Urwa informed me that 'A'Isha (Allah be pleased with her) said: When twenty-nine nights were over, Allah's Messenger (ﷺ) visited me, and he began (his visit) with me. I said: Messenger of Allah, you had taken an oath that you would not visit us for a month, while you have visited after I have counted only twenty-nine (nights). Thereupon he said: The month may also be of twenty-nine (days). He then said: 'A'isha, I am going to talk to you about a matter, and you should not be hasty in it (and do not give your final decision) until you have consulted your parents. He then recited this verse to me:" O Prophet, say to your wives" till he reached" mighty reward" (xxxiii. 28). 'A'isha (Allah be pleased with her) said: By Allah, he knew that my parents would not allow me to separate from him. I said: Is there any need to consult my parents in this matter? I in fact choose Allah and His Messenger (ﷺ) and the abode in the Hereafter. Ma'mar said: Ayyub reported to me that 'A'isha said: Don't inform your wives that I have chosen you, whereupon Allah's Apostle (ﷺ) said: Verily Allah has sent me as a conveyer of message, and He has not sent me as a source of hardship (to others). Qatada said:" Saghat qulubukum" means" Your hearts have inclined}}
\hadithdefcmd{muslim}{3725}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، أَنَّهَا أَخْبَرَتْهُ هَذِهِ الأَحَادِيثَ الثَّلاَثَةَ، قَالَ قَالَتْ زَيْنَبُ دَخَلْتُ عَلَى أُمِّ حَبِيبَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ تُوُفِّيَ أَبُوهَا أَبُو سُفْيَانَ فَدَعَتْ أُمُّ حَبِيبَةَ بِطِيبٍ فِيهِ صُفْرَةٌ خَلُوقٌ أَوْ غَيْرُهُ فَدَهَنَتْ مِنْهُ جَارِيَةً ثُمَّ مَسَّتْ بِعَارِضَيْهَا ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَلَى الْمِنْبَرِ ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏ قَالَتْ زَيْنَبُ ثُمَّ دَخَلْتُ عَلَى زَيْنَبَ بِنْتِ جَحْشٍ حِينَ تُوُفِّيَ أَخُوهَا فَدَعَتْ بِطِيبٍ فَمَسَّتْ مِنْهُ ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَلَى الْمِنْبَرِ ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏ قَالَتْ زَيْنَبُ سَمِعْتُ أُمِّي أُمَّ سَلَمَةَ، تَقُولُ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَتِي تُوُفِّيَ عَنْهَا زَوْجُهَا وَقَدِ اشْتَكَتْ عَيْنُهَا أَفَنَكْحُلُهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ ‏"‏ ‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا كُلَّ ذَلِكَ يَقُولُ لاَ ثُمَّ قَالَ ‏"‏ إِنَّمَا هِيَ أَرْبَعَةُ أَشْهُرٍ وَعَشْرٌ وَقَدْ كَانَتْ إِحْدَاكُنَّ فِي الْجَاهِلِيَّةِ تَرْمِي بِالْبَعَرَةِ عَلَى رَأْسِ الْحَوْلِ ‏"‏ ‏.‏ قَالَ حُمَيْدٌ قُلْتُ لِزَيْنَبَ وَمَا تَرْمِي بِالْبَعَرَةِ عَلَى رَأْسِ الْحَوْلِ فَقَالَتْ زَيْنَبُ كَانَتِ الْمَرْأَةُ إِذَا تُوُفِّيَ عَنْهَا زَوْجُهَا دَخَلَتْ حِفْشًا وَلَبِسَتْ شَرَّ ثِيَابِهَا وَلَمْ تَمَسَّ طِيبًا وَلاَ شَيْئًا حَتَّى تَمُرَّ بِهَا سَنَةٌ ثُمَّ تُؤْتَى بِدَابَّةٍ حِمَارٍ أَوْ شَاةٍ أَوْ طَيْرٍ فَتَفْتَضُّ بِهِ فَقَلَّمَا تَفْتَضُّ بِشَىْءٍ إِلاَّ مَاتَ ثُمَّ تَخْرُجُ فَتُعْطَى بَعَرَةً فَتَرْمِي بِهَا ثُمَّ تُرَاجِعُ بَعْدُ مَا شَاءَتْ مِنْ طِيبٍ أَوْ غَيْرِهِ ‏.‏\hadithno{3725}\hadithtrans{Zainab (bint Abu Salama) (Allah be pleased with her) reported:I went to Umm Habiba, the wife of Allah's Apostle (ﷺ), when her father Abu Sufyan had died. Umm Habiba sent for a perfume having yellowness in it or something else like it, and she applied it to a girl and then rubbed it on her cheeks and then said: By Allah, I need no perfume but for the fact that I heard Allah's Messenger (ﷺ) say on the pulpit:" It is not permissible for a woman believing in Allah and the Hereafter to mourn for the dead beyond three days, but (in case of the death) of the husband it is permissible for four months and ten days." Zainab said: I then visited Zainab hint Jahsh (Allah be pleased with her) when her brother died and she sent for perfume and applied it and then said: By Allah, I don't feel any need for the perfume but that I heard Allah's Messenger (ﷺ) say on the pulpit:" It is not permissible for a woman believing in Allah and the Hereafbler to mourn the dead beyond three days except in case of her husband (for whom she can mourn) for four months and ten days." Zainab (Allah be pleased with her) said: I heard my mother Umm Salama (Allah be pleased with her) as saying: A woman came to Allah's Messenger (ﷺ) and said: Allah's Messenger. I have a daughter whose husband has died and there has developed some trouble in her eye; should we apply collyrium to it? Thereupon Allah's Messenger (ﷺ) said: No (repeating it twice or thrice, saying only, NO" all the time). Then he said: It is only four mouths and ten days, whereas in the preIslamic period none of you threw away the dung until one year had passed. Humaid said: I said to Zainab: What is this throwing of dung until a year is passed? Zainab said: When the husband of a woman died, she went into a hut and put on her worst clothes, and did not apply perfume or something like it until a year was over. Then an animal like a donkey, or a goat, or a bird was brought to her and she rubbed her hand over it, and it so happened that one on which she rubbed her hand died. She then came out of her house and she was given dung and she threw it and then she made use of anything like perfume or something else as she liked}}
\hadithdefcmd{muslim}{3726}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، أَنَّهَا أَخْبَرَتْهُ هَذِهِ الأَحَادِيثَ الثَّلاَثَةَ، قَالَ قَالَتْ زَيْنَبُ دَخَلْتُ عَلَى أُمِّ حَبِيبَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ تُوُفِّيَ أَبُوهَا أَبُو سُفْيَانَ فَدَعَتْ أُمُّ حَبِيبَةَ بِطِيبٍ فِيهِ صُفْرَةٌ خَلُوقٌ أَوْ غَيْرُهُ فَدَهَنَتْ مِنْهُ جَارِيَةً ثُمَّ مَسَّتْ بِعَارِضَيْهَا ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَلَى الْمِنْبَرِ ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏ قَالَتْ زَيْنَبُ ثُمَّ دَخَلْتُ عَلَى زَيْنَبَ بِنْتِ جَحْشٍ حِينَ تُوُفِّيَ أَخُوهَا فَدَعَتْ بِطِيبٍ فَمَسَّتْ مِنْهُ ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَلَى الْمِنْبَرِ ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏ قَالَتْ زَيْنَبُ سَمِعْتُ أُمِّي أُمَّ سَلَمَةَ، تَقُولُ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَتِي تُوُفِّيَ عَنْهَا زَوْجُهَا وَقَدِ اشْتَكَتْ عَيْنُهَا أَفَنَكْحُلُهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ ‏"‏ ‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا كُلَّ ذَلِكَ يَقُولُ لاَ ثُمَّ قَالَ ‏"‏ إِنَّمَا هِيَ أَرْبَعَةُ أَشْهُرٍ وَعَشْرٌ وَقَدْ كَانَتْ إِحْدَاكُنَّ فِي الْجَاهِلِيَّةِ تَرْمِي بِالْبَعَرَةِ عَلَى رَأْسِ الْحَوْلِ ‏"‏ ‏.‏ قَالَ حُمَيْدٌ قُلْتُ لِزَيْنَبَ وَمَا تَرْمِي بِالْبَعَرَةِ عَلَى رَأْسِ الْحَوْلِ فَقَالَتْ زَيْنَبُ كَانَتِ الْمَرْأَةُ إِذَا تُوُفِّيَ عَنْهَا زَوْجُهَا دَخَلَتْ حِفْشًا وَلَبِسَتْ شَرَّ ثِيَابِهَا وَلَمْ تَمَسَّ طِيبًا وَلاَ شَيْئًا حَتَّى تَمُرَّ بِهَا سَنَةٌ ثُمَّ تُؤْتَى بِدَابَّةٍ حِمَارٍ أَوْ شَاةٍ أَوْ طَيْرٍ فَتَفْتَضُّ بِهِ فَقَلَّمَا تَفْتَضُّ بِشَىْءٍ إِلاَّ مَاتَ ثُمَّ تَخْرُجُ فَتُعْطَى بَعَرَةً فَتَرْمِي بِهَا ثُمَّ تُرَاجِعُ بَعْدُ مَا شَاءَتْ مِنْ طِيبٍ أَوْ غَيْرِهِ ‏.‏\hadithno{3726}\hadithtrans{Zainab (bint Abu Salama) (Allah be pleased with her) reported:I went to Umm Habiba, the wife of Allah's Apostle (ﷺ), when her father Abu Sufyan had died. Umm Habiba sent for a perfume having yellowness in it or something else like it, and she applied it to a girl and then rubbed it on her cheeks and then said: By Allah, I need no perfume but for the fact that I heard Allah's Messenger (ﷺ) say on the pulpit:" It is not permissible for a woman believing in Allah and the Hereafter to mourn for the dead beyond three days, but (in case of the death) of the husband it is permissible for four months and ten days." Zainab said: I then visited Zainab hint Jahsh (Allah be pleased with her) when her brother died and she sent for perfume and applied it and then said: By Allah, I don't feel any need for the perfume but that I heard Allah's Messenger (ﷺ) say on the pulpit:" It is not permissible for a woman believing in Allah and the Hereafbler to mourn the dead beyond three days except in case of her husband (for whom she can mourn) for four months and ten days." Zainab (Allah be pleased with her) said: I heard my mother Umm Salama (Allah be pleased with her) as saying: A woman came to Allah's Messenger (ﷺ) and said: Allah's Messenger. I have a daughter whose husband has died and there has developed some trouble in her eye; should we apply collyrium to it? Thereupon Allah's Messenger (ﷺ) said: No (repeating it twice or thrice, saying only, NO" all the time). Then he said: It is only four mouths and ten days, whereas in the preIslamic period none of you threw away the dung until one year had passed. Humaid said: I said to Zainab: What is this throwing of dung until a year is passed? Zainab said: When the husband of a woman died, she went into a hut and put on her worst clothes, and did not apply perfume or something like it until a year was over. Then an animal like a donkey, or a goat, or a bird was brought to her and she rubbed her hand over it, and it so happened that one on which she rubbed her hand died. She then came out of her house and she was given dung and she threw it and then she made use of anything like perfume or something else as she liked}}
\hadithdefcmd{muslim}{3727}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ حُمَيْدِ بْنِ نَافِعٍ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، أَنَّهَا أَخْبَرَتْهُ هَذِهِ الأَحَادِيثَ الثَّلاَثَةَ، قَالَ قَالَتْ زَيْنَبُ دَخَلْتُ عَلَى أُمِّ حَبِيبَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ تُوُفِّيَ أَبُوهَا أَبُو سُفْيَانَ فَدَعَتْ أُمُّ حَبِيبَةَ بِطِيبٍ فِيهِ صُفْرَةٌ خَلُوقٌ أَوْ غَيْرُهُ فَدَهَنَتْ مِنْهُ جَارِيَةً ثُمَّ مَسَّتْ بِعَارِضَيْهَا ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَلَى الْمِنْبَرِ ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏ قَالَتْ زَيْنَبُ ثُمَّ دَخَلْتُ عَلَى زَيْنَبَ بِنْتِ جَحْشٍ حِينَ تُوُفِّيَ أَخُوهَا فَدَعَتْ بِطِيبٍ فَمَسَّتْ مِنْهُ ثُمَّ قَالَتْ وَاللَّهِ مَا لِي بِالطِّيبِ مِنْ حَاجَةٍ غَيْرَ أَنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عَلَى الْمِنْبَرِ ‏"‏ لاَ يَحِلُّ لاِمْرَأَةٍ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ تُحِدُّ عَلَى مَيِّتٍ فَوْقَ ثَلاَثٍ إِلاَّ عَلَى زَوْجٍ أَرْبَعَةَ أَشْهُرٍ وَعَشْرًا ‏"‏ ‏.‏ قَالَتْ زَيْنَبُ سَمِعْتُ أُمِّي أُمَّ سَلَمَةَ، تَقُولُ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَتِي تُوُفِّيَ عَنْهَا زَوْجُهَا وَقَدِ اشْتَكَتْ عَيْنُهَا أَفَنَكْحُلُهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ ‏"‏ ‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا كُلَّ ذَلِكَ يَقُولُ لاَ ثُمَّ قَالَ ‏"‏ إِنَّمَا هِيَ أَرْبَعَةُ أَشْهُرٍ وَعَشْرٌ وَقَدْ كَانَتْ إِحْدَاكُنَّ فِي الْجَاهِلِيَّةِ تَرْمِي بِالْبَعَرَةِ عَلَى رَأْسِ الْحَوْلِ ‏"‏ ‏.‏ قَالَ حُمَيْدٌ قُلْتُ لِزَيْنَبَ وَمَا تَرْمِي بِالْبَعَرَةِ عَلَى رَأْسِ الْحَوْلِ فَقَالَتْ زَيْنَبُ كَانَتِ الْمَرْأَةُ إِذَا تُوُفِّيَ عَنْهَا زَوْجُهَا دَخَلَتْ حِفْشًا وَلَبِسَتْ شَرَّ ثِيَابِهَا وَلَمْ تَمَسَّ طِيبًا وَلاَ شَيْئًا حَتَّى تَمُرَّ بِهَا سَنَةٌ ثُمَّ تُؤْتَى بِدَابَّةٍ حِمَارٍ أَوْ شَاةٍ أَوْ طَيْرٍ فَتَفْتَضُّ بِهِ فَقَلَّمَا تَفْتَضُّ بِشَىْءٍ إِلاَّ مَاتَ ثُمَّ تَخْرُجُ فَتُعْطَى بَعَرَةً فَتَرْمِي بِهَا ثُمَّ تُرَاجِعُ بَعْدُ مَا شَاءَتْ مِنْ طِيبٍ أَوْ غَيْرِهِ ‏.‏\hadithno{3727}\hadithtrans{Zainab (bint Abu Salama) (Allah be pleased with her) reported:I went to Umm Habiba, the wife of Allah's Apostle (ﷺ), when her father Abu Sufyan had died. Umm Habiba sent for a perfume having yellowness in it or something else like it, and she applied it to a girl and then rubbed it on her cheeks and then said: By Allah, I need no perfume but for the fact that I heard Allah's Messenger (ﷺ) say on the pulpit:" It is not permissible for a woman believing in Allah and the Hereafter to mourn for the dead beyond three days, but (in case of the death) of the husband it is permissible for four months and ten days." Zainab said: I then visited Zainab hint Jahsh (Allah be pleased with her) when her brother died and she sent for perfume and applied it and then said: By Allah, I don't feel any need for the perfume but that I heard Allah's Messenger (ﷺ) say on the pulpit:" It is not permissible for a woman believing in Allah and the Hereafbler to mourn the dead beyond three days except in case of her husband (for whom she can mourn) for four months and ten days." Zainab (Allah be pleased with her) said: I heard my mother Umm Salama (Allah be pleased with her) as saying: A woman came to Allah's Messenger (ﷺ) and said: Allah's Messenger. I have a daughter whose husband has died and there has developed some trouble in her eye; should we apply collyrium to it? Thereupon Allah's Messenger (ﷺ) said: No (repeating it twice or thrice, saying only, NO" all the time). Then he said: It is only four mouths and ten days, whereas in the preIslamic period none of you threw away the dung until one year had passed. Humaid said: I said to Zainab: What is this throwing of dung until a year is passed? Zainab said: When the husband of a woman died, she went into a hut and put on her worst clothes, and did not apply perfume or something like it until a year was over. Then an animal like a donkey, or a goat, or a bird was brought to her and she rubbed her hand over it, and it so happened that one on which she rubbed her hand died. She then came out of her house and she was given dung and she threw it and then she made use of anything like perfume or something else as she liked}}
\hadithdefcmd{muslim}{3730}{وَحَدَّثَتْهُ زَيْنَبُ، عَنْ أُمِّهَا، وَعَنْ زَيْنَبَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَوْ عَنِ امْرَأَةٍ مِنْ بَعْضِ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3730}\hadithtrans{This hadith was narrated by Zainab from her mother and from Zainab, the wife of Allah's Apostle (ﷺ), or from some other lady from among the wives of the Prophet (ﷺ)}}
\hadithdefcmd{muslim}{3792}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ تَوَلَّى قَوْمًا بِغَيْرِ إِذْنِ مَوَالِيهِ فَعَلَيْهِ لَعْنَةُ اللَّهِ وَالْمَلاَئِكَةِ وَالنَّاسِ أَجْمَعِينَ لاَ يُقْبَلُ مِنْهُ يَوْمَ الْقِيَامَةِ عَدْلٌ وَلاَ صَرْفٌ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ إِبْرَاهِيمُ بْنُ دِينَارٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، حَدَّثَنَا شَيْبَانُ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ ‏"‏ وَمَنْ وَالَى غَيْرَ مَوَالِيهِ بِغَيْرِ إِذْنِهِمْ ‏"‏ ‏.‏\hadithno{3792}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:He who took the freed slave as his ally without the consent of his previous master, there is upon him the curse of Allah and that of His angels and that of the whole mankind, and there will not be accepted from him his obligatory acts or supercrogatory acts on the Day of Resurrection. This hadith is narrated through the same chain of transmitters, but with a slight change of words}}
\hadithdefcmd{muslim}{3836}{\hadithno{3836}\hadithtrans{}}
\hadithdefcmd{muslim}{3842}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ، عُمَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنِ اشْتَرَى طَعَامًا فَلاَ يَبِعْهُ حَتَّى يَسْتَوْفِيَهُ‏"‏ ‏.‏ قَالَ وَكُنَّا نَشْتَرِي الطَّعَامَ مِنَ الرُّكْبَانِ جِزَافًا فَنَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَبِيعَهُ حَتَّى نَنْقُلَهُ مِنْ مَكَانِهِ ‏\hadithno{3842}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:He who buys foodgrain should not sell that before taking possession of it. He (the narrator) said: We used to buy foodgrain from the caravans in bulk, but Allah's Messenger (ﷺ) forbade us to re-sell that until we had shifted it to some other place}}
\hadithdefcmd{muslim}{3845}{\hadithno{3845}\hadithtrans{}}
\hadithdefcmd{muslim}{4251}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنَا سَعِيدُ، بْنُ أَبِي أَيُّوبَ أَنَّ يَزِيدَ بْنَ أَبِي حَبِيبٍ، أَخْبَرَهُ أَنَّ أَبَا الْخَيْرِ حَدَّثَهُ عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، أَنَّهُ قَالَ نَذَرَتْ أُخْتِي ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ مُفَضَّلٍ وَلَمْ يَذْكُرْ فِي الْحَدِيثِ حَافِيَةً ‏.‏ وَزَادَ وَكَانَ أَبُو الْخَيْرِ لاَ يُفَارِقُ عُقْبَةَ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، وَابْنُ أَبِي خَلَفٍ، قَالاَ حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ، جُرَيْجٍ أَخْبَرَنِي يَحْيَى بْنُ أَيُّوبَ، أَنَّ يَزِيدَ بْنَ أَبِي حَبِيبٍ، أَخْبَرَهُ بِهَذَا الإِسْنَادِ، ‏.‏ مِثْلَ حَدِيثِ عَبْدِ الرَّزَّاقِ ‏.‏\hadithno{4251}\hadithtrans{This hadith has been narrated on the authority of 'Uqba b. Amir Juhani. but in this no mention has been made of" barefoot}}
\hadithdefcmd{muslim}{4252}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنَا سَعِيدُ، بْنُ أَبِي أَيُّوبَ أَنَّ يَزِيدَ بْنَ أَبِي حَبِيبٍ، أَخْبَرَهُ أَنَّ أَبَا الْخَيْرِ حَدَّثَهُ عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، أَنَّهُ قَالَ نَذَرَتْ أُخْتِي ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ مُفَضَّلٍ وَلَمْ يَذْكُرْ فِي الْحَدِيثِ حَافِيَةً ‏.‏ وَزَادَ وَكَانَ أَبُو الْخَيْرِ لاَ يُفَارِقُ عُقْبَةَ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، وَابْنُ أَبِي خَلَفٍ، قَالاَ حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ، جُرَيْجٍ أَخْبَرَنِي يَحْيَى بْنُ أَيُّوبَ، أَنَّ يَزِيدَ بْنَ أَبِي حَبِيبٍ، أَخْبَرَهُ بِهَذَا الإِسْنَادِ، ‏.‏ مِثْلَ حَدِيثِ عَبْدِ الرَّزَّاقِ ‏.‏\hadithno{4252}\hadithtrans{This hadith has been narrated on the authority of 'Uqba b. Amir Juhani. but in this no mention has been made of" barefoot}}
\hadithdefcmd{muslim}{4435}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، ح وَحَدَّثَنَا عَبْدُ، بْنُ حُمَيْدٍ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ ‏.‏\hadithno{4435}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{4436}{\hadithno{4436}\hadithtrans{}}
\hadithdefcmd{muslim}{4504}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي الضَّحَّاكُ بْنُ عُثْمَانَ، عَنْ أَبِي النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ اللُّقَطَةِ فَقَالَ ‏"‏ عَرِّفْهَا سَنَةً فَإِنْ لَمْ تُعْتَرَفْ فَاعْرِفْ عِفَاصَهَا وَوِكَاءَهَا ثُمَّ كُلْهَا فَإِنْ جَاءَ صَاحِبُهَا فَأَدِّهَا إِلَيْهِ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا الضَّحَّاكُ بْنُ عُثْمَانَ، بِهَذَا الإِسْنَادِ وَقَالَ فِي الْحَدِيثِ ‏"‏ فَإِنِ اعْتُرِفَتْ فَأَدِّهَا وَإِلاَّ فَاعْرِفْ عِفَاصَهَا وَوِكَاءَهَا وَعَدَدَهَا ‏"‏ ‏.‏\hadithno{4504}\hadithtrans{Zaid b. Khalid al-Juhani reported that Allah's Messenger (ﷺ) was asked about picking up of stray things, whereupon he said:Make announcement of that for one year, but if it is not recognised (by the owner), then recognise its big and strap, then eat it; and if its owner comes, then give that to him. This hadith has been narrated on the authority of Al-Dahhak b. Uthman with the same chain of transmitters but with a slight variation of words}}
\hadithdefcmd{muslim}{4505}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي الضَّحَّاكُ بْنُ عُثْمَانَ، عَنْ أَبِي النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ اللُّقَطَةِ فَقَالَ ‏"‏ عَرِّفْهَا سَنَةً فَإِنْ لَمْ تُعْتَرَفْ فَاعْرِفْ عِفَاصَهَا وَوِكَاءَهَا ثُمَّ كُلْهَا فَإِنْ جَاءَ صَاحِبُهَا فَأَدِّهَا إِلَيْهِ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا الضَّحَّاكُ بْنُ عُثْمَانَ، بِهَذَا الإِسْنَادِ وَقَالَ فِي الْحَدِيثِ ‏"‏ فَإِنِ اعْتُرِفَتْ فَأَدِّهَا وَإِلاَّ فَاعْرِفْ عِفَاصَهَا وَوِكَاءَهَا وَعَدَدَهَا ‏"‏ ‏.‏\hadithno{4505}\hadithtrans{Zaid b. Khalid al-Juhani reported that Allah's Messenger (ﷺ) was asked about picking up of stray things, whereupon he said:Make announcement of that for one year, but if it is not recognised (by the owner), then recognise its big and strap, then eat it; and if its owner comes, then give that to him. This hadith has been narrated on the authority of Al-Dahhak b. Uthman with the same chain of transmitters but with a slight variation of words}}
\hadithdefcmd{muslim}{4521}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، عَنْ سُفْيَانَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا سُفْيَانُ، قَالَ أَمْلاَهُ عَلَيْنَا إِمْلاَءً ح. وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ هَاشِمٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنِي عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - حَدَّثَنَا سُفْيَانُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَمَّرَ أَمِيرًا عَلَى جَيْشٍ أَوْ سَرِيَّةٍ أَوْصَاهُ فِي خَاصَّتِهِ بِتَقْوَى اللَّهِ وَمَنْ مَعَهُ مِنَ الْمُسْلِمِينَ خَيْرًا ثُمَّ قَالَ ‏ "‏ اغْزُوا بِاسْمِ اللَّهِ فِي سَبِيلِ اللَّهِ قَاتِلُوا مَنْ كَفَرَ بِاللَّهِ اغْزُوا وَ لاَ تَغُلُّوا وَلاَ تَغْدِرُوا وَلاَ تَمْثُلُوا وَلاَ تَقْتُلُوا وَلِيدًا وَإِذَا لَقِيتَ عَدُوَّكَ مِنَ الْمُشْرِكِينَ فَادْعُهُمْ إِلَى ثَلاَثِ خِصَالٍ - أَوْ خِلاَلٍ - فَأَيَّتُهُنَّ مَا أَجَابُوكَ فَاقْبَلْ مِنْهُمْ وَكُفَّ عَنْهُمْ ثُمَّ ادْعُهُمْ إِلَى الإِسْلاَمِ فَإِنْ أَجَابُوكَ فَاقْبَلْ مِنْهُمْ وَكُفَّ عَنْهُمْ ثُمَّ ادْعُهُمْ إِلَى التَّحَوُّلِ مِنْ دَارِهِمْ إِلَى دَارِ الْمُهَاجِرِينَ وَأَخْبِرْهُمْ أَنَّهُمْ إِنْ فَعَلُوا ذَلِكَ فَلَهُمْ مَا لِلْمُهَاجِرِينَ وَعَلَيْهِمْ مَا عَلَى الْمُهَاجِرِينَ فَإِنْ أَبَوْا أَنْ يَتَحَوَّلُوا مِنْهَا فَأَخْبِرْهُمْ أَنَّهُمْ يَكُونُونَ كَأَعْرَابِ الْمُسْلِمِينَ يَجْرِي عَلَيْهِمْ حُكْمُ اللَّهِ الَّذِي يَجْرِي عَلَى الْمُؤْمِنِينَ وَلاَ يَكُونُ لَهُمْ فِي الْغَنِيمَةِ وَالْفَىْءِ شَىْءٌ إِلاَّ أَنْ يُجَاهِدُوا مَعَ الْمُسْلِمِينَ فَإِنْ هُمْ أَبَوْا فَسَلْهُمُ الْجِزْيَةَ فَإِنْ هُمْ أَجَابُوكَ فَاقْبَلْ مِنْهُمْ وَكُفَّ عَنْهُمْ فَإِنْ هُمْ أَبَوْا فَاسْتَعِنْ بِاللَّهِ وَقَاتِلْهُمْ ‏.‏ وَإِذَا حَاصَرْتَ أَهْلَ حِصْنٍ فَأَرَادُوكَ أَنْ تَجْعَلَ لَهُمْ ذِمَّةَ اللَّهِ وَذِمَّةَ نَبِيِّهِ فَلاَ تَجْعَلْ لَهُمْ ذِمَّةَ اللَّهِ وَلاَ ذِمَّةَ نَبِيِّهِ وَلَكِنِ اجْعَلْ لَهُمْ ذِمَّتَكَ وَذِمَّةَ أَصْحَابِكَ فَإِنَّكُمْ أَنْ تُخْفِرُوا ذِمَمَكُمْ وَذِمَمَ أَصْحَابِكُمْ أَهْوَنُ مِنْ أَنْ تُخْفِرُوا ذِمَّةَ اللَّهِ وَذِمَّةَ رَسُولِهِ ‏.‏ وَإِذَا حَاصَرْتَ أَهْلَ حِصْنٍ فَأَرَادُوكَ أَنْ تُنْزِلَهُمْ عَلَى حُكْمِ اللَّهِ فَلاَ تُنْزِلْهُمْ عَلَى حُكْمِ اللَّهِ وَلَكِنْ أَنْزِلْهُمْ عَلَى حُكْمِكَ فَإِنَّكَ لاَ تَدْرِي أَتُصِيبُ حُكْمَ اللَّهِ فِيهِمْ أَمْ لاَ ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ هَذَا أَوْ نَحْوَهُ وَزَادَ إِسْحَاقُ فِي آخِرِ حَدِيثِهِ عَنْ يَحْيَى بْنِ آدَمَ قَالَ فَذَكَرْتُ هَذَا الْحَدِيثَ لِمُقَاتِلِ بْنِ حَيَّانَ - قَالَ يَحْيَى يَعْنِي أَنَّ عَلْقَمَةَ يَقُولُهُ لاِبْنِ حَيَّانَ - فَقَالَ حَدَّثَنِي مُسْلِمُ بْنُ هَيْصَمٍ عَنِ النُّعْمَانِ بْنِ مُقَرِّنٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{4521}\hadithtrans{It has been reported from Sulaiman b. Buraida through his father that when the Messenger of Allah (ﷺ) appointed anyone as leader of an army or detachment he would especially exhort him to fear Allah and to be good to the Muslims who were with him. He would say:Fight in the name of Allah and in the way of Allah. Fight against those who disbelieve in Allah. Make a holy war, do not embezzle the spoils; do not break your pledge; and do not mutilate (the dead) bodies; do not kill the children. When you meet your enemies who are polytheists, invite them to three courses of action. If they respond to any one of these, you also accept it and withhold yourself from doing them any harm. Invite them to (accept) Islam; if they respond to you, accept it from them and desist from fighting against them. Then invite them to migrate from their lands to the land of the Muhajireen and inform them that, if they do so, they shall have all the privileges and obligations of the Muhajireen. If they refuse to migrate, tell them that they will have the status of Bedouin Muslims and will be subjected to the Commands of Allah like other Muslims, but they will not get any share from the spoils of war or Fai' except when they actually fight with the Muslims (against the disbelievers). If they refuse to accept Islam, demand from them the Jizya. If they agree to pay, accept it from them and hold off your hands. If they refuse to pay the tax, seek Allah's help and fight them. When you lay siege to a fort and the besieged appeal to you for protection in the name of Allah and His Prophet, do not accord to them the guarantee of Allah and His Prophet, but accord to them your own guarantee and the guarantee of your companions for it is a lesser sin that the security given by you or your companions be disregarded than that the security granted in the name of Allah and His Prophet be violated. When you besiege a fort and the besieged want you to let them out in accordance with Allah's Command, do not let them come out in accordance with His Command, but do so at your (own) command, for you do not know whether or not you will be able to carry out Allah's behest with regard to them}}
\hadithdefcmd{muslim}{4522}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، عَنْ سُفْيَانَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا سُفْيَانُ، قَالَ أَمْلاَهُ عَلَيْنَا إِمْلاَءً ح. وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ هَاشِمٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنِي عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - حَدَّثَنَا سُفْيَانُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَمَّرَ أَمِيرًا عَلَى جَيْشٍ أَوْ سَرِيَّةٍ أَوْصَاهُ فِي خَاصَّتِهِ بِتَقْوَى اللَّهِ وَمَنْ مَعَهُ مِنَ الْمُسْلِمِينَ خَيْرًا ثُمَّ قَالَ ‏ "‏ اغْزُوا بِاسْمِ اللَّهِ فِي سَبِيلِ اللَّهِ قَاتِلُوا مَنْ كَفَرَ بِاللَّهِ اغْزُوا وَ لاَ تَغُلُّوا وَلاَ تَغْدِرُوا وَلاَ تَمْثُلُوا وَلاَ تَقْتُلُوا وَلِيدًا وَإِذَا لَقِيتَ عَدُوَّكَ مِنَ الْمُشْرِكِينَ فَادْعُهُمْ إِلَى ثَلاَثِ خِصَالٍ - أَوْ خِلاَلٍ - فَأَيَّتُهُنَّ مَا أَجَابُوكَ فَاقْبَلْ مِنْهُمْ وَكُفَّ عَنْهُمْ ثُمَّ ادْعُهُمْ إِلَى الإِسْلاَمِ فَإِنْ أَجَابُوكَ فَاقْبَلْ مِنْهُمْ وَكُفَّ عَنْهُمْ ثُمَّ ادْعُهُمْ إِلَى التَّحَوُّلِ مِنْ دَارِهِمْ إِلَى دَارِ الْمُهَاجِرِينَ وَأَخْبِرْهُمْ أَنَّهُمْ إِنْ فَعَلُوا ذَلِكَ فَلَهُمْ مَا لِلْمُهَاجِرِينَ وَعَلَيْهِمْ مَا عَلَى الْمُهَاجِرِينَ فَإِنْ أَبَوْا أَنْ يَتَحَوَّلُوا مِنْهَا فَأَخْبِرْهُمْ أَنَّهُمْ يَكُونُونَ كَأَعْرَابِ الْمُسْلِمِينَ يَجْرِي عَلَيْهِمْ حُكْمُ اللَّهِ الَّذِي يَجْرِي عَلَى الْمُؤْمِنِينَ وَلاَ يَكُونُ لَهُمْ فِي الْغَنِيمَةِ وَالْفَىْءِ شَىْءٌ إِلاَّ أَنْ يُجَاهِدُوا مَعَ الْمُسْلِمِينَ فَإِنْ هُمْ أَبَوْا فَسَلْهُمُ الْجِزْيَةَ فَإِنْ هُمْ أَجَابُوكَ فَاقْبَلْ مِنْهُمْ وَكُفَّ عَنْهُمْ فَإِنْ هُمْ أَبَوْا فَاسْتَعِنْ بِاللَّهِ وَقَاتِلْهُمْ ‏.‏ وَإِذَا حَاصَرْتَ أَهْلَ حِصْنٍ فَأَرَادُوكَ أَنْ تَجْعَلَ لَهُمْ ذِمَّةَ اللَّهِ وَذِمَّةَ نَبِيِّهِ فَلاَ تَجْعَلْ لَهُمْ ذِمَّةَ اللَّهِ وَلاَ ذِمَّةَ نَبِيِّهِ وَلَكِنِ اجْعَلْ لَهُمْ ذِمَّتَكَ وَذِمَّةَ أَصْحَابِكَ فَإِنَّكُمْ أَنْ تُخْفِرُوا ذِمَمَكُمْ وَذِمَمَ أَصْحَابِكُمْ أَهْوَنُ مِنْ أَنْ تُخْفِرُوا ذِمَّةَ اللَّهِ وَذِمَّةَ رَسُولِهِ ‏.‏ وَإِذَا حَاصَرْتَ أَهْلَ حِصْنٍ فَأَرَادُوكَ أَنْ تُنْزِلَهُمْ عَلَى حُكْمِ اللَّهِ فَلاَ تُنْزِلْهُمْ عَلَى حُكْمِ اللَّهِ وَلَكِنْ أَنْزِلْهُمْ عَلَى حُكْمِكَ فَإِنَّكَ لاَ تَدْرِي أَتُصِيبُ حُكْمَ اللَّهِ فِيهِمْ أَمْ لاَ ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ هَذَا أَوْ نَحْوَهُ وَزَادَ إِسْحَاقُ فِي آخِرِ حَدِيثِهِ عَنْ يَحْيَى بْنِ آدَمَ قَالَ فَذَكَرْتُ هَذَا الْحَدِيثَ لِمُقَاتِلِ بْنِ حَيَّانَ - قَالَ يَحْيَى يَعْنِي أَنَّ عَلْقَمَةَ يَقُولُهُ لاِبْنِ حَيَّانَ - فَقَالَ حَدَّثَنِي مُسْلِمُ بْنُ هَيْصَمٍ عَنِ النُّعْمَانِ بْنِ مُقَرِّنٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{4522}\hadithtrans{It has been reported from Sulaiman b. Buraida through his father that when the Messenger of Allah (ﷺ) appointed anyone as leader of an army or detachment he would especially exhort him to fear Allah and to be good to the Muslims who were with him. He would say:Fight in the name of Allah and in the way of Allah. Fight against those who disbelieve in Allah. Make a holy war, do not embezzle the spoils; do not break your pledge; and do not mutilate (the dead) bodies; do not kill the children. When you meet your enemies who are polytheists, invite them to three courses of action. If they respond to any one of these, you also accept it and withhold yourself from doing them any harm. Invite them to (accept) Islam; if they respond to you, accept it from them and desist from fighting against them. Then invite them to migrate from their lands to the land of the Muhajireen and inform them that, if they do so, they shall have all the privileges and obligations of the Muhajireen. If they refuse to migrate, tell them that they will have the status of Bedouin Muslims and will be subjected to the Commands of Allah like other Muslims, but they will not get any share from the spoils of war or Fai' except when they actually fight with the Muslims (against the disbelievers). If they refuse to accept Islam, demand from them the Jizya. If they agree to pay, accept it from them and hold off your hands. If they refuse to pay the tax, seek Allah's help and fight them. When you lay siege to a fort and the besieged appeal to you for protection in the name of Allah and His Prophet, do not accord to them the guarantee of Allah and His Prophet, but accord to them your own guarantee and the guarantee of your companions for it is a lesser sin that the security given by you or your companions be disregarded than that the security granted in the name of Allah and His Prophet be violated. When you besiege a fort and the besieged want you to let them out in accordance with Allah's Command, do not let them come out in accordance with His Command, but do so at your (own) command, for you do not know whether or not you will be able to carry out Allah's behest with regard to them}}
\hadithdefcmd{muslim}{4680}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ أُمَّ سُلَيْمٍ، اتَّخَذَتْ يَوْمَ حُنَيْنٍ خِنْجَرًا فَكَانَ مَعَهَا فَرَآهَا أَبُو طَلْحَةَ فَقَالَ يَا رَسُولَ اللَّهِ هَذِهِ أُمُّ سُلَيْمٍ مَعَهَا خَنْجَرٌ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا هَذَا الْخَنْجَرُ ‏"‏ ‏.‏ قَالَتِ اتَّخَذْتُهُ إِنْ دَنَا مِنِّي أَحَدٌ مِنَ الْمُشْرِكِينَ بَقَرْتُ بِهِ بَطْنَهُ ‏.‏ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَضْحَكُ قَالَتْ يَا رَسُولَ اللَّهِ اقْتُلْ مَنْ بَعْدَنَا مِنَ الطُّلَقَاءِ انْهَزَمُوا بِكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أُمَّ سُلَيْمٍ إِنَّ اللَّهَ قَدْ كَفَى وَأَحْسَنَ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَخْبَرَنَا إِسْحَاقُ بْنُ، عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ عَنْ أَنَسِ بْنِ مَالِكٍ، فِي قِصَّةِ أُمِّ سُلَيْمٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ حَدِيثِ ثَابِتٍ ‏.‏\hadithno{4680}\hadithtrans{It has been narrated on the authority of Anas that, on the Day of Hunain. Umm Sulaim took out a dagger she had in her possession. Abiu Talha saw her and said:Messenger of Allah, this is Umm Sulaim. She is holding a dagger. The Messenger of Allah (ﷺ) asked (her): What for are you holding this dagger? She said: I took it up so that I may tear open the belly of a polytheist who comes near me. The Messenger of Allah (ﷺ) began to smile (at these words). She said: Messenger of Allah, kill all those people-other than us-whom thou hast declared to be free (on the day of the Conquest of Mecca). (They embraced Islam because) they were defeated at your hands (and as such their Islam is not dependable). The Messenger of Allah (ﷺ) said: Umm Sulaim. God is sufficient (against the mischief of the polytheists) and He will be kind to us (so you need not carry this dagger)}}
\hadithdefcmd{muslim}{4681}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ أُمَّ سُلَيْمٍ، اتَّخَذَتْ يَوْمَ حُنَيْنٍ خِنْجَرًا فَكَانَ مَعَهَا فَرَآهَا أَبُو طَلْحَةَ فَقَالَ يَا رَسُولَ اللَّهِ هَذِهِ أُمُّ سُلَيْمٍ مَعَهَا خَنْجَرٌ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا هَذَا الْخَنْجَرُ ‏"‏ ‏.‏ قَالَتِ اتَّخَذْتُهُ إِنْ دَنَا مِنِّي أَحَدٌ مِنَ الْمُشْرِكِينَ بَقَرْتُ بِهِ بَطْنَهُ ‏.‏ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَضْحَكُ قَالَتْ يَا رَسُولَ اللَّهِ اقْتُلْ مَنْ بَعْدَنَا مِنَ الطُّلَقَاءِ انْهَزَمُوا بِكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أُمَّ سُلَيْمٍ إِنَّ اللَّهَ قَدْ كَفَى وَأَحْسَنَ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَخْبَرَنَا إِسْحَاقُ بْنُ، عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ عَنْ أَنَسِ بْنِ مَالِكٍ، فِي قِصَّةِ أُمِّ سُلَيْمٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ حَدِيثِ ثَابِتٍ ‏.‏\hadithno{4681}\hadithtrans{It has been narrated on the authority of Anas that, on the Day of Hunain. Umm Sulaim took out a dagger she had in her possession. Abiu Talha saw her and said:Messenger of Allah, this is Umm Sulaim. She is holding a dagger. The Messenger of Allah (ﷺ) asked (her): What for are you holding this dagger? She said: I took it up so that I may tear open the belly of a polytheist who comes near me. The Messenger of Allah (ﷺ) began to smile (at these words). She said: Messenger of Allah, kill all those people-other than us-whom thou hast declared to be free (on the day of the Conquest of Mecca). (They embraced Islam because) they were defeated at your hands (and as such their Islam is not dependable). The Messenger of Allah (ﷺ) said: Umm Sulaim. God is sufficient (against the mischief of the polytheists) and He will be kind to us (so you need not carry this dagger)}}
\hadithdefcmd{muslim}{4725}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا خَالِدٌ يَعْنِي ابْنَ الْحَارِثِ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى، - يَعْنِي الْقَطَّانَ - كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، ح وَحَدَّثَنَا أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، جَمِيعًا عَنْ أَيُّوبَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، - يَعْنِي ابْنَ عُثْمَانَ - ح وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي أُسَامَةُ، كَلُّ هَؤُلاَءِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، مِثْلَ حَدِيثِ اللَّيْثِ عَنْ نَافِعٍ، ‏.‏ قَالَ أَبُو إِسْحَاقَ حَدَّثَنَا الْحَسَنُ بْنُ بِشْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، بِهَذَا مِثْلَ حَدِيثِ اللَّيْثِ عَنْ نَافِعٍ، ‏.‏\hadithno{4725}\hadithtrans{This tradition has been narrated through more; than one chain of transmitters}}
\hadithdefcmd{muslim}{4726}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا خَالِدٌ يَعْنِي ابْنَ الْحَارِثِ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى، - يَعْنِي الْقَطَّانَ - كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، ح وَحَدَّثَنَا أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، جَمِيعًا عَنْ أَيُّوبَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، - يَعْنِي ابْنَ عُثْمَانَ - ح وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي أُسَامَةُ، كَلُّ هَؤُلاَءِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، مِثْلَ حَدِيثِ اللَّيْثِ عَنْ نَافِعٍ، ‏.‏ قَالَ أَبُو إِسْحَاقَ حَدَّثَنَا الْحَسَنُ بْنُ بِشْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، بِهَذَا مِثْلَ حَدِيثِ اللَّيْثِ عَنْ نَافِعٍ، ‏.‏\hadithno{4726}\hadithtrans{This tradition has been narrated through more; than one chain of transmitters}}
\hadithdefcmd{muslim}{4747}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ الْحِزَامِيُّ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَطَاعَنِي فَقَدْ أَطَاعَ اللَّهَ وَمَنْ يَعْصِنِي فَقَدْ عَصَى اللَّهَ وَمَنْ يُطِعِ الأَمِيرَ فَقَدْ أَطَاعَنِي وَمَنْ يَعْصِ الأَمِيرَ فَقَدْ عَصَانِي ‏"‏ ‏.‏ وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُر " وَمَنْ يَعْصِ الأَمِيرَ فَقَدْ عَصَانِي ‏"‏ ‏.‏\hadithno{4747}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Holy prophet (ﷺ) said:Whoso obeys me obeys God, and whoso disobeys me disobeys God. Whoso obeys the commander (appointed by me) obeys me, and whoso disobeys the commander disobeys me. The same tradition transmitted by different persons omits the portion: And whose disobeys the commander disobeys me}}
\hadithdefcmd{muslim}{4748}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ الْحِزَامِيُّ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَطَاعَنِي فَقَدْ أَطَاعَ اللَّهَ وَمَنْ يَعْصِنِي فَقَدْ عَصَى اللَّهَ وَمَنْ يُطِعِ الأَمِيرَ فَقَدْ أَطَاعَنِي وَمَنْ يَعْصِ الأَمِيرَ فَقَدْ عَصَانِي ‏"‏ ‏.‏ وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُر " وَمَنْ يَعْصِ الأَمِيرَ فَقَدْ عَصَانِي ‏"‏ ‏.‏\hadithno{4748}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Holy prophet (ﷺ) said:Whoso obeys me obeys God, and whoso disobeys me disobeys God. Whoso obeys the commander (appointed by me) obeys me, and whoso disobeys the commander disobeys me. The same tradition transmitted by different persons omits the portion: And whose disobeys the commander disobeys me}}
\hadithdefcmd{muslim}{4780}{وَحَدَّثَنِي يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ بْنُ الْحَجَّاجِ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، يُحَدِّثُ عَنْ أُسَيْدِ بْنِ حُضَيْرٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ خَلاَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏ وَحَدَّثَنِيهِ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ وَلَمْ يَقُلْ خَلاَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4780}\hadithtrans{This tradition has been narrated on the same authority through a different chain of transmitters. Another version of the tradition narrated on the authority of Shu'ba does not include the words:" He took the Messenger of Allah (ﷺ) aside}}
\hadithdefcmd{muslim}{4781}{وَحَدَّثَنِي يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ بْنُ الْحَجَّاجِ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، يُحَدِّثُ عَنْ أُسَيْدِ بْنِ حُضَيْرٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ خَلاَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏ وَحَدَّثَنِيهِ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ وَلَمْ يَقُلْ خَلاَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4781}\hadithtrans{This tradition has been narrated on the same authority through a different chain of transmitters. Another version of the tradition narrated on the authority of Shu'ba does not include the words:" He took the Messenger of Allah (ﷺ) aside}}
\hadithdefcmd{muslim}{4819}{وَحَدَّثَنَاهُ حَامِدُ بْنُ عُمَرَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ طَارِقٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ كَانَ أَبِي مِمَّنْ بَايَعَ رَسُولَ اللَّهِ صلى الله عليه وسلم عِنْدَ الشَّجَرَةِ ‏.‏ قَالَ فَانْطَلَقْنَا فِي قَابِلٍ حَاجِّينَ فَخَفِيَ عَلَيْنَا مَكَانُهَا فَإِنْ كَانَتْ تَبَيَّنَتْ لَكُمْ فَأَنْتُمْ أَعْلَمُ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو أَحْمَدَ، قَالَ وَقَرَأْتُهُ عَلَى نَصْرِ بْنِ عَلِيٍّ عَنْ أَبِي أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنْ طَارِقِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِيهِ، أَنَّهُمْ كَانُوا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ الشَّجَرَةِ قَالَ فَنَسُوهَا مِنَ الْعَامِ الْمُقْبِلِ\hadithno{4819}\hadithtrans{It has been narrated on the authority of Sa'id b. Musayyab who said:My father was one of those who swore fealty to the Messenger of Allah (ﷺ) near the tree. When we passed that way next year intending to perform the Hajj, the place of the tree was hidden to us. If you could point out clearly, you would (certainly) be knowing better. It has also been narrated on the authority of Sa'id b. Musayyib who learnt from his father that they were with the Messenger of Allah (ﷺ) in the year of the Tree (i. e. in the year of the fealty of God's pleasure sworn under the tree at Hudaibiya), but next year they forgot the spot of the tree}}
\hadithdefcmd{muslim}{4820}{وَحَدَّثَنَاهُ حَامِدُ بْنُ عُمَرَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ طَارِقٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ كَانَ أَبِي مِمَّنْ بَايَعَ رَسُولَ اللَّهِ صلى الله عليه وسلم عِنْدَ الشَّجَرَةِ ‏.‏ قَالَ فَانْطَلَقْنَا فِي قَابِلٍ حَاجِّينَ فَخَفِيَ عَلَيْنَا مَكَانُهَا فَإِنْ كَانَتْ تَبَيَّنَتْ لَكُمْ فَأَنْتُمْ أَعْلَمُ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو أَحْمَدَ، قَالَ وَقَرَأْتُهُ عَلَى نَصْرِ بْنِ عَلِيٍّ عَنْ أَبِي أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنْ طَارِقِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِيهِ، أَنَّهُمْ كَانُوا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ الشَّجَرَةِ قَالَ فَنَسُوهَا مِنَ الْعَامِ الْمُقْبِلِ\hadithno{4820}\hadithtrans{It has been narrated on the authority of Sa'id b. Musayyab who said:My father was one of those who swore fealty to the Messenger of Allah (ﷺ) near the tree. When we passed that way next year intending to perform the Hajj, the place of the tree was hidden to us. If you could point out clearly, you would (certainly) be knowing better. It has also been narrated on the authority of Sa'id b. Musayyib who learnt from his father that they were with the Messenger of Allah (ﷺ) in the year of the Tree (i. e. in the year of the fealty of God's pleasure sworn under the tree at Hudaibiya), but next year they forgot the spot of the tree}}
\hadithdefcmd{muslim}{4905}{وَحَدَّثَنِيهِ إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الصَّمَدِ، - يَعْنِي ابْنَ عَبْدِ الْوَارِثِ - قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، حَدَّثَنَا الْحُسَيْنُ، عَنْ يَحْيَى، حَدَّثَنِي أَبُو سَعِيدٍ، مَوْلَى الْمَهْرِيِّ حَدَّثَنِي أَبُو سَعِيدٍ الْخُدْرِيُّ، أَنَّ رَسُولَ اللَّهِ بَعَثَ بَعْثًا ‏.‏ بِمَعْنَاهُ ‏.‏ وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ مُوسَى - عَنْ شَيْبَانَ، عَنْ يَحْيَى، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4905}\hadithtrans{The above tradition has also been narrated through two different chains of transmitters on the authority of Abu Sa'id Khudri and Yahya, respectively}}
\hadithdefcmd{muslim}{4906}{وَحَدَّثَنِيهِ إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الصَّمَدِ، - يَعْنِي ابْنَ عَبْدِ الْوَارِثِ - قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، حَدَّثَنَا الْحُسَيْنُ، عَنْ يَحْيَى، حَدَّثَنِي أَبُو سَعِيدٍ، مَوْلَى الْمَهْرِيِّ حَدَّثَنِي أَبُو سَعِيدٍ الْخُدْرِيُّ، أَنَّ رَسُولَ اللَّهِ بَعَثَ بَعْثًا ‏.‏ بِمَعْنَاهُ ‏.‏ وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ مُوسَى - عَنْ شَيْبَانَ، عَنْ يَحْيَى، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4906}\hadithtrans{The above tradition has also been narrated through two different chains of transmitters on the authority of Abu Sa'id Khudri and Yahya, respectively}}
\hadithdefcmd{muslim}{4968}{وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{4968}\hadithtrans{The above tradition has been narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{4969}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مُحَارِبٍ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَطْرُقَ الرَّجُلُ أَهْلَهُ لَيْلاً يَتَخَوَّنُهُمْ أَوْ يَلْتَمِسُ عَثَرَاتِهِمْ ‏.‏\hadithno{4969}\hadithtrans{It has been narrated (through a different chain of tranmitten) on the authority of Jabir who said:The Messenger of Allah (ﷺ) forbade that a man should come to his family like (an unexpected) night visitor doubting their fidelity and spying into their lapses}}
\hadithdefcmd{muslim}{4970}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، بِهَذَا الإِسْنَادِ قَالَ عَبْدُ الرَّحْمَنِ قَالَ سُفْيَانُ لاَ أَدْرِي هَذَا فِي الْحَدِيثِ أَمْ لاَ ‏.‏ يَعْنِي أَنْ يَتَخَوَّنَهُمْ أَوْ يَلْتَمِسَ عَثَرَاتِهِمْ ‏.‏\hadithno{4970}\hadithtrans{This tradition has been reported through anothee chain. 'Abdurahman, one of the sub-narrators, said "I do not know if it in the hadith or not", meaning (the words) "doubting their fidelity and spying into their lapses}}
\hadithdefcmd{muslim}{4971}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي قَالاَ، جَمِيعًا حَدَّثَنَا شُعْبَةُ، عَنْ مُحَارِبٍ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِكَرَاهَةِ الطُّرُوقِ وَلَمْ يَذْكُرْ يَتَخَوَّنُهُمْ أَوْ يَلْتَمِسُ عَثَرَاتِهِمْ ‏.‏\hadithno{4971}\hadithtrans{A version of the tradition narrated on the authority of Jabir (but through a different chain of transmitters) mentions the undesirability of coining to one's house like a night visitor, but does not contain the words:" Doubting their fidelity or spying into their lapses}}
\hadithdefcmd{muslim}{5112}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو مُسْهِرٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنِي الزُّبَيْدِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنْ ثَوْبَانَ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ ‏ "‏ أَصْلِحْ هَذَا اللَّحْمَ ‏"‏ ‏.‏ قَالَ فَأَصْلَحْتُهُ فَلَمْ يَزَلْ يَأْكُلُ مِنْهُ حَتَّى بَلَغَ الْمَدِينَةَ ‏.‏ وَحَدَّثَنِيهِ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُبَارَكِ، حَدَّثَنَا يَحْيَى، بْنُ حَمْزَةَ بِهَذَا الإِسْنَادِ وَلَمْ يَقُلْ فِي حَجَّةِ الْوَدَاعِ ‏.‏\hadithno{5112}\hadithtrans{Thauban, the freed slave of Allah's Messenger (ﷺ), reported:Allah's Messenger (ﷺ) said to me on the occasion of Hajjat-al-Wada' (the Farewell Pilgrimage): Make the flesh usable. So I made it usable (for him) and he ate it constantly until he reached Medina. This hadith has been narrated on the authority of Yabya b. Hamza with the same chain of transmitters, but he did not say: On the occasion of Hajjat-al-Wada}}
\hadithdefcmd{muslim}{5113}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو مُسْهِرٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنِي الزُّبَيْدِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنْ ثَوْبَانَ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَجَّةِ الْوَدَاعِ ‏ "‏ أَصْلِحْ هَذَا اللَّحْمَ ‏"‏ ‏.‏ قَالَ فَأَصْلَحْتُهُ فَلَمْ يَزَلْ يَأْكُلُ مِنْهُ حَتَّى بَلَغَ الْمَدِينَةَ ‏.‏ وَحَدَّثَنِيهِ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا مُحَمَّدُ بْنُ الْمُبَارَكِ، حَدَّثَنَا يَحْيَى، بْنُ حَمْزَةَ بِهَذَا الإِسْنَادِ وَلَمْ يَقُلْ فِي حَجَّةِ الْوَدَاعِ ‏.‏\hadithno{5113}\hadithtrans{Thauban, the freed slave of Allah's Messenger (ﷺ), reported:Allah's Messenger (ﷺ) said to me on the occasion of Hajjat-al-Wada' (the Farewell Pilgrimage): Make the flesh usable. So I made it usable (for him) and he ate it constantly until he reached Medina. This hadith has been narrated on the authority of Yabya b. Hamza with the same chain of transmitters, but he did not say: On the occasion of Hajjat-al-Wada}}
\hadithdefcmd{muslim}{5204}{قَالَ أَبُو الزُّبَيْرِ وَسَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْجَرِّ وَالْمُزَفَّتِ وَالنَّقِيرِ ‏.‏ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا لَمْ يَجِدْ شَيْئًا يُنْتَبَذُ لَهُ فِيهِ نُبِذَ لَهُ فِي تَوْرٍ مِنْ حِجَارَةٍ ‏.‏\hadithno{5204}\hadithtrans{Jabir b. 'Abdullah reported that Allah's Messenger (ﷺ) forbade (the preparation) of Nabidh in green pitcher, in varnished jar, in hollow stump, and when Allah's Messenger (ﷺ) did not find anything to prepare Nabidh in that (i. e. waterskin), it was prepared for him in a big bowl made of stone}}
\hadithdefcmd{muslim}{5207}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، قَالَ أَبُو بَكْرٍ عَنْ أَبِي سِنَانٍ، وَقَالَ ابْنُ الْمُثَنَّى، عَنْ ضِرَارِ بْنِ مُرَّةَ، عَنْ مُحَارِبٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا ضِرَارُ بْنُ مُرَّةَ، أَبُو سِنَانٍ عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَهَيْتُكُمْ عَنِ النَّبِيذِ إِلاَّ فِي سِقَاءٍ فَاشْرَبُوا فِي الأَسْقِيَةِ كُلِّهَا وَلاَ تَشْرَبُوا مُسْكِرًا ‏"‏ ‏.‏\hadithno{5207}\hadithtrans{Abdullah b. Buraida, on the authority of his father, reported Allah's Messenger (ﷺ) as saying:I had forbidden you from the preparation of Nabidh except in a waterskin. But now you may drink in all vessels, but do not drink what is intoxicant}}
\hadithdefcmd{muslim}{5208}{وَحَدَّثَنَا حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا ضَحَّاكُ بْنُ مَخْلَدٍ، عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ بْنِ، مَرْثَدٍ عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ نَهَيْتُكُمْ عَنِ الظُّرُوفِ وَإِنَّ الظُّرُوفَ - أَوْ ظَرْفًا - لاَ يُحِلُّ شَيْئًا وَلاَ يُحَرِّمُهُ وَكُلُّ مُسْكِرٍ حَرَامٌ ‏"‏ ‏.‏\hadithno{5208}\hadithtrans{Ibn Buraida, on the authority of his father, reported Allah's Messenger (ﷺ) as saying:I had forbidden you (from the preparation of Nabidh) and drinking it in certain vessels, (but now you may do so if you like) for it is not vessels or a vessel that makes a thing lawful or unlawful. It is every intoxicant that is unlawful}}
\hadithdefcmd{muslim}{5214}{\hadithno{5214}\hadithtrans{}}
\hadithdefcmd{muslim}{5384}{\hadithno{5384}\hadithtrans{}}
\hadithdefcmd{muslim}{5393}{\hadithno{5393}\hadithtrans{}}
\hadithdefcmd{muslim}{5519}{حَدَّثَنَا إِسْح��اقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ سَعِيدِ، بْنِ يَسَارٍ أَبِي الْحُبَابِ مَوْلَى بَنِي النَّجَّارِ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، عَنْ أَبِي طَلْحَةَ الأَنْصَارِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ كَلْبٌ وَلاَ تَمَاثِيلُ ‏"‏ ‏.‏ قَالَ فَأَتَيْتُ عَائِشَةَ فَقُلْتُ إِنَّ هَذَا يُخْبِرُنِي أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَدْخُلُ الْمَلاَئِكَةُ بَيْتًا فِيهِ كَلْبٌ وَلاَ تَمَاثِيلُ ‏"‏ ‏.‏ فَهَلْ سَمِعْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ ذَلِكَ فَقَالَتْ لاَ وَلَكِنْ سَأُحَدِّثُكُمْ مَا رَأَيْتُهُ فَعَلَ رَأَيْتُهُ خَرَجَ فِي غَزَاتِهِ فَأَخَذْتُ نَمَطًا فَسَتَرْتُهُ عَلَى الْبَابِ فَلَمَّا قَدِمَ فَرَأَى النَّمَطَ عَرَفْتُ الْكَرَاهِيَةَ فِي وَجْهِهِ فَجَذَبَهُ حَتَّى هَتَكَهُ أَوْ قَطَعَهُ وَقَالَ ‏"‏ إِنَّ اللَّهَ لَمْ يَأْمُرْنَا أَنْ نَكْسُوَ الْحِجَارَةَ وَالطِّينَ ‏"‏ ‏.‏ قَالَتْ فَقَطَعْنَا مِنْهُ وِسَادَتَيْنِ وَحَشَوْتُهُمَا لِيفًا فَلَمْ يَعِبْ ذَلِكَ عَلَىَّ ‏.‏\hadithno{5519}\hadithtrans{Abu Talha Ansari reported Allah's Messenger (ﷺ) as saying:Angels do not enter the house in which there is a picture or portraits. I came to 'A'isha and said to her: This is a news that I have received that Allah's Apostle (ﷺ) had said: Angels do not enter the house in which there is a picture or a dog, (and further added) whether she had heard Allah's Messenger (ﷺ) making a mention of it. She said: No (I did not hear this myself), but I narrate to you what I saw him doing. I bear testimony to the fact that he (the Holy Prophet) set out for an expedition. I took a carpet and screened the door with it. When he (the Holy Prophet) came back he saw that carpet and I perceived signs of disapproval on his face. He pulled it until it was torn or it was cut (into pieces) and he said: God has not commanded us to clothe stones and clay. We cut it (the curtain) and prepared two pillowa out of it by stuffing them with the fibre of date-palms and he (the Holy Prophet) did not find fault with it}}
\hadithdefcmd{muslim}{5521}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ دَاوُدَ، عَنْ عَزْرَةَ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ لَنَا سِتْرٌ فِيهِ تِمْثَالُ طَائِرٍ وَكَانَ الدَّاخِلُ إِذَا دَخَلَ اسْتَقْبَلَهُ فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حَوِّلِي هَذَا فَإِنِّي كُلَّمَا دَخَلْتُ فَرَأَيْتُهُ ذَكَرْتُ الدُّنْيَا ‏"‏ ‏.‏ قَالَتْ وَكَانَتْ لَنَا قَطِيفَةٌ كُنَّا نَقُولُ عَلَمُهَا حَرِيرٌ فَكُنَّا نَلْبَسُهَا ‏.‏ حَدَّثَنِيهِ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، وَعَبْدُ الأَعْلَى، بِهَذَا الإِسْنَادِ قَالَ ابْنُ الْمُثَنَّى وَزَادَ فِيهِ - يُرِيدُ عَبْدَ الأَعْلَى - فَلَمْ يَأْمُرْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَطْعِهِ ‏.‏\hadithno{5521}\hadithtrans{A'isha reported:We had a curtain with us which had portraits of birds upon it. Whenever a visitor came, he found them in front of him. Thereupon Allah's Messenger (ﷺ) said to me: Change them, for whenever I enter the room) I see them and it brings to my mind (the pleasures) of worldly life. She said: We had with us a sheet which had silk badges upon it and we used to wear it. This hadith has been transmitted on the authority of Ibn Muthanna but with this addition: 'Allah's Messenger (ﷺ) did not command us to tear that}}
\hadithdefcmd{muslim}{5522}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ دَاوُدَ، عَنْ عَزْرَةَ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ لَنَا سِتْرٌ فِيهِ تِمْثَالُ طَائِرٍ وَكَانَ الدَّاخِلُ إِذَا دَخَلَ اسْتَقْبَلَهُ فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حَوِّلِي هَذَا فَإِنِّي كُلَّمَا دَخَلْتُ فَرَأَيْتُهُ ذَكَرْتُ الدُّنْيَا ‏"‏ ‏.‏ قَالَتْ وَكَانَتْ لَنَا قَطِيفَةٌ كُنَّا نَقُولُ عَلَمُهَا حَرِيرٌ فَكُنَّا نَلْبَسُهَا ‏.‏ حَدَّثَنِيهِ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، وَعَبْدُ الأَعْلَى، بِهَذَا الإِسْنَادِ قَالَ ابْنُ الْمُثَنَّى وَزَادَ فِيهِ - يُرِيدُ عَبْدَ الأَعْلَى - فَلَمْ يَأْمُرْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِقَطْعِهِ ‏.‏\hadithno{5522}\hadithtrans{A'isha reported:We had a curtain with us which had portraits of birds upon it. Whenever a visitor came, he found them in front of him. Thereupon Allah's Messenger (ﷺ) said to me: Change them, for whenever I enter the room) I see them and it brings to my mind (the pleasures) of worldly life. She said: We had with us a sheet which had silk badges upon it and we used to wear it. This hadith has been transmitted on the authority of Ibn Muthanna but with this addition: 'Allah's Messenger (ﷺ) did not command us to tear that}}
\hadithdefcmd{muslim}{5539}{وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنَا مَنْصُورٌ، عَنْ مُسْلِمِ بْنِ صُبَيْحٍ، قَالَ كُنْتُ مَعَ مَسْرُوقٍ فِي بَيْتٍ فِيهِ تَمَاثِيلُ مَرْيَمَ ‏.‏ فَقَالَ مَسْرُوقٌ هَذَا تَمَاثِيلُ كِسْرَى ‏.‏ فَقُلْتُ لاَ هَذَا تَمَاثِيلُ مَرْيَمَ ‏.‏ فَقَالَ مَسْرُوقٌ أَمَا إِنِّي سَمِعْتُ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَشَدُّ النَّاسِ عَذَابًا يَوْمَ الْقِيَامَةِ الْمُصَوِّرُونَ ‏"‏ ‏.‏ قَالَ مُسْلِمٌ قَرَأْتُ عَلَى نَصْرِ بْنِ عَلِيٍّ الْجَهْضَمِيِّ عَنْ عَبْدِ الأَعْلَى بْنِ عَبْدِ الأَعْلَى، حَدَّثَنَا يَحْيَى بْنُ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ أَبِي الْحَسَنِ، قَالَ جَاءَ رَجُلٌ إِلَى ابْنِ عَبَّاسٍ فَقَالَ إِنِّي رَجُلٌ أُصَوِّرُ هَذِهِ الصُّوَرَ فَأَفْتِنِي فِيهَا ‏.‏ فَقَالَ لَهُ ادْنُ مِنِّي ‏.‏ فَدَنَا مِنْهُ ثُمَّ قَالَ ادْنُ مِنِّي ‏.‏ فَدَنَا حَتَّى وَضَعَ يَدَهُ عَلَى رَأْسِهِ قَالَ أُنَبِّئُكَ بِمَا سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ كُلُّ مُصَوِّرٍ فِي النَّارِ يَجْعَلُ لَهُ بِكُلِّ صُورَةٍ صَوَّرَهَا نَفْسًا فَتُعَذِّبُهُ فِي جَهَنَّمَ ‏"‏ ‏.‏ وَقَالَ إِنْ كُنْتَ لاَ بُدَّ فَاعِلاً فَاصْنَعِ الشَّجَرَ وَمَا لاَ نَفْسَ لَهُ ‏.‏ فَأَقَرَّ بِهِ نَصْرُ بْنُ عَلِيٍّ ‏.‏\hadithno{5539}\hadithtrans{Muslim b. Subaih reported:I was with Masriuq in the house which had the portrayals of Mary (hadrat Maryan). Thereupon Masriuq said: These are portraits of Kisra. I said: No, these are of Mary. Masruq said: I heard Abdullah b, Mas'ud as saying Allah's Messenger (ﷺ) had said: The most grievously tormented people on the Day of Resurrection would be the painters of pictures. (Muslim said): I read this before Nasr b. 'Ali at-Jahdami and he read it before other narrators, the last one being Ibn Sa'id b Abl at Hasan that a person came to Ibn 'Abbas and said: I am the person who paints pictures; give me a religious verdict about them. He (Ibn 'Abbas) said to him: Come near me (still further). He came near him so much so that he placed his hand upon his head and said: I am going to narrate to yor what I heard from Allah's Messenger (ﷺ). I heard him say: All the painters who make pictures would be in the fire of Hell. The soul will be breathed in every picture prepared by him and it shall punish him in the Hell, and he (Ibn 'Abbas) said: If you have to do it at all, then paint the pictures of trees and lifeless things; and Nasr b. 'Ali confirmed it}}
\hadithdefcmd{muslim}{5540}{وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنَا مَنْصُورٌ، عَنْ مُسْلِمِ بْنِ صُبَيْحٍ، قَالَ كُنْتُ مَعَ مَسْرُوقٍ فِي بَيْتٍ فِيهِ تَمَاثِيلُ مَرْيَمَ ‏.‏ فَقَالَ مَسْرُوقٌ هَذَا تَمَاثِيلُ كِسْرَى ‏.‏ فَقُلْتُ لاَ هَذَا تَمَاثِيلُ مَرْيَمَ ‏.‏ فَقَالَ مَسْرُوقٌ أَمَا إِنِّي سَمِعْتُ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَشَدُّ النَّاسِ عَذَابًا يَوْمَ الْقِيَامَةِ الْمُصَوِّرُونَ ‏"‏ ‏.‏ قَالَ مُسْلِمٌ قَرَأْتُ عَلَى نَصْرِ بْنِ عَلِيٍّ الْجَهْضَمِيِّ عَنْ عَبْدِ الأَعْلَى بْنِ عَبْدِ الأَعْلَى، حَدَّثَنَا يَحْيَى بْنُ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ أَبِي الْحَسَنِ، قَالَ جَاءَ رَجُلٌ إِلَى ابْنِ عَبَّاسٍ فَقَالَ إِنِّي رَجُلٌ أُصَوِّرُ هَذِهِ الصُّوَرَ فَأَفْتِنِي فِيهَا ‏.‏ فَقَالَ لَهُ ادْنُ مِنِّي ‏.‏ فَدَنَا مِنْهُ ثُمَّ قَالَ ادْنُ مِنِّي ‏.‏ فَدَنَا حَتَّى وَضَعَ يَدَهُ عَلَى رَأْسِهِ قَالَ أُنَبِّئُكَ بِمَا سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ كُلُّ مُصَوِّرٍ فِي النَّارِ يَجْعَلُ لَهُ بِكُلِّ صُورَةٍ صَوَّرَهَا نَفْسًا فَتُعَذِّبُهُ فِي جَهَنَّمَ ‏"‏ ‏.‏ وَقَالَ إِنْ كُنْتَ لاَ بُدَّ فَاعِلاً فَاصْنَعِ الشَّجَرَ وَمَا لاَ نَفْسَ لَهُ ‏.‏ فَأَقَرَّ بِهِ نَصْرُ بْنُ عَلِيٍّ ‏.‏\hadithno{5540}\hadithtrans{Muslim b. Subaih reported:I was with Masriuq in the house which had the portrayals of Mary (hadrat Maryan). Thereupon Masriuq said: These are portraits of Kisra. I said: No, these are of Mary. Masruq said: I heard Abdullah b, Mas'ud as saying Allah's Messenger (ﷺ) had said: The most grievously tormented people on the Day of Resurrection would be the painters of pictures. (Muslim said): I read this before Nasr b. 'Ali at-Jahdami and he read it before other narrators, the last one being Ibn Sa'id b Abl at Hasan that a person came to Ibn 'Abbas and said: I am the person who paints pictures; give me a religious verdict about them. He (Ibn 'Abbas) said to him: Come near me (still further). He came near him so much so that he placed his hand upon his head and said: I am going to narrate to yor what I heard from Allah's Messenger (ﷺ). I heard him say: All the painters who make pictures would be in the fire of Hell. The soul will be breathed in every picture prepared by him and it shall punish him in the Hell, and he (Ibn 'Abbas) said: If you have to do it at all, then paint the pictures of trees and lifeless things; and Nasr b. 'Ali confirmed it}}
\hadithdefcmd{muslim}{5541}{\hadithno{5541}\hadithtrans{}}
\hadithdefcmd{muslim}{5542}{\hadithno{5542}\hadithtrans{}}
\hadithdefcmd{muslim}{5543}{\hadithno{5543}\hadithtrans{}}
\hadithdefcmd{muslim}{5544}{\hadithno{5544}\hadithtrans{}}
\hadithdefcmd{muslim}{5545}{\hadithno{5545}\hadithtrans{}}
\hadithdefcmd{muslim}{5556}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، حَدَّثَنِي هِشَامُ بْنُ، زَيْدٍ قَالَ سَمِعْتُ أَنَسًا، يَقُولُ دَخَلْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِرْبَدًا وَهُوَ يَسِمُ غَنَمًا ‏.‏ قَالَ أَحْسِبُهُ قَالَ فِي آذَانِهَا ‏.‏ وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ، وَيَحْيَى، وَعَبْدُ الرَّحْمَنِ، كُلُّهُمْ عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5556}\hadithtrans{Anas reported:We went to Allah's Messenger (ﷺ) as he was in the fold and he was cauterising the animals of the flock and I think (he was cauterising them) on their ears. This hadith has been narrated on the authority of Shu'ba through another chain of transmitters}}
\hadithdefcmd{muslim}{5557}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، حَدَّثَنِي هِشَامُ بْنُ، زَيْدٍ قَالَ سَمِعْتُ أَنَسًا، يَقُولُ دَخَلْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِرْبَدًا وَهُوَ يَسِمُ غَنَمًا ‏.‏ قَالَ أَحْسِبُهُ قَالَ فِي آذَانِهَا ‏.‏ وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ، وَيَحْيَى، وَعَبْدُ الرَّحْمَنِ، كُلُّهُمْ عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{5557}\hadithtrans{Anas reported:We went to Allah's Messenger (ﷺ) as he was in the fold and he was cauterising the animals of the flock and I think (he was cauterising them) on their ears. This hadith has been narrated on the authority of Shu'ba through another chain of transmitters}}
\hadithdefcmd{muslim}{5569}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ إِبْرَاهِيمَ بْنِ نَافِعٍ، أَخْبَرَنِي الْحَسَنُ بْنُ مُسْلِمِ بْنِ يَنَّاقَ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، مِنَ الأَنْصَارِ زَوَّجَتِ ابْنَةً لَهَا فَاشْتَكَتْ فَتَسَاقَطَ شَعْرُهَا فَأَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ إِنَّ زَوْجَهَا يُرِيدُهَا أَفَأَصِلُ شَعَرَهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لُعِنَ الْوَاصِلاَتُ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ إِبْرَاهِيمَ بْنِ نَافِعٍ، بِهَذَا الإِسْنَادِ وَقَالَ ‏"‏ لُعِنَ الْمُوصِلاَتُ ‏"‏ ‏.‏\hadithno{5569}\hadithtrans{A'isha reported that a woman from the Ansar married her daughter who had lost her hair because of illness. She came to Allah's Apostle (ﷺ) and said:Her husband wants that false hair should be aaded to her head. Thereupon Allah's Messenger (ﷺ) said: The woman who adds false hair has been cursed. This hadith has been narrated on the authority of Nafi' with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5570}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنْ إِبْرَاهِيمَ بْنِ نَافِعٍ، أَخْبَرَنِي الْحَسَنُ بْنُ مُسْلِمِ بْنِ يَنَّاقَ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ عَائِشَةَ، أَنَّ امْرَأَةً، مِنَ الأَنْصَارِ زَوَّجَتِ ابْنَةً لَهَا فَاشْتَكَتْ فَتَسَاقَطَ شَعْرُهَا فَأَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ إِنَّ زَوْجَهَا يُرِيدُهَا أَفَأَصِلُ شَعَرَهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لُعِنَ الْوَاصِلاَتُ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ إِبْرَاهِيمَ بْنِ نَافِعٍ، بِهَذَا الإِسْنَادِ وَقَالَ ‏"‏ لُعِنَ الْمُوصِلاَتُ ‏"‏ ‏.‏\hadithno{5570}\hadithtrans{A'isha reported that a woman from the Ansar married her daughter who had lost her hair because of illness. She came to Allah's Apostle (ﷺ) and said:Her husband wants that false hair should be aaded to her head. Thereupon Allah's Messenger (ﷺ) said: The woman who adds false hair has been cursed. This hadith has been narrated on the authority of Nafi' with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5571}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ، بْنُ الْمُثَنَّى - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَعَنَ الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ وَالْوَاشِمَةَ وَالْمُسْتَوْشِمَةَ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا صَخْرُ بْنُ، جُوَيْرِيَةَ عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{5571}\hadithtrans{Ibn Umar reported Allah's Messenger (ﷺ) cursing the woman who added false hair and the woman who asked for tattoos. This hadith has been reported on the authority of Abdullah through another chain of transmitters}}
\hadithdefcmd{muslim}{5572}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ، بْنُ الْمُثَنَّى - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَعَنَ الْوَاصِلَةَ وَالْمُسْتَوْصِلَةَ وَالْوَاشِمَةَ وَالْمُسْتَوْشِمَةَ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا صَخْرُ بْنُ، جُوَيْرِيَةَ عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{5572}\hadithtrans{Ibn Umar reported Allah's Messenger (ﷺ) cursing the woman who added false hair and the woman who asked for tattoos. This hadith has been reported on the authority of Abdullah through another chain of transmitters}}
\hadithdefcmd{muslim}{5637}{\hadithno{5637}\hadithtrans{}}
\hadithdefcmd{muslim}{5669}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامٌ، بِهَذَا الإِسْنَادِ وَقَالَ وَكَانَتِ امْرَأَةً يَفْرَعُ النَّاسَ جِسْمُهَا ‏.‏ قَالَ وَإِنَّهُ لَيَتَعَشَّى ‏.‏ وَحَدَّثَنِيهِ سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5669}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters, and the words are:She (Sauda) was a woman who looked to be significant amongst the people (so far as the bulk of her) body was concerned. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{5670}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامٌ، بِهَذَا الإِسْنَادِ وَقَالَ وَكَانَتِ امْرَأَةً يَفْرَعُ النَّاسَ جِسْمُهَا ‏.‏ قَالَ وَإِنَّهُ لَيَتَعَشَّى ‏.‏ وَحَدَّثَنِيهِ سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{5670}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters, and the words are:She (Sauda) was a woman who looked to be significant amongst the people (so far as the bulk of her) body was concerned. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{5762}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَزُهَيْرُ بْنُ حَرْبٍ وَابْنُ أَبِي عُمَرَ - وَاللَّفْظُ لِزُهَيْرٍ - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا سُفْيَانُ، بْنُ عُيَيْنَةَ عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ أُمِّ قَيْسٍ بِنْتِ مِحْصَنٍ، أُخْتِ عُكَّاشَةَ بْنِ مِحْصَنٍ قَالَتْ دَخَلْتُ بِابْنٍ لِي عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم لَمْ يَأْكُلِ الطَّعَامَ فَبَالَ عَلَيْهِ فَدَعَا بِمَاءٍ فَرَشَّهُ ‏.‏ قَالَتْ وَدَخَلْتُ عَلَيْهِ بِابْنٍ لِي قَدْ أَعْلَقْتُ عَلَيْهِ مِنَ الْعُذْرَةِ فَقَالَ ‏ "‏ عَلاَمَهْ تَدْغَرْنَ أَوْلاَدَكُنَّ بِهَذَا الْعِلاَقِ عَلَيْكُنَّ بِهَذَا الْعُودِ الْهِنْدِيِّ فَإِنَّ فِيهِ سَبْعَةَ أَشْفِيَةٍ مِنْهَا ذَاتُ الْجَنْبِ يُسْعَطُ مِنَ الْعُذْرَةِ وَيُلَدُّ مِنْ ذَاتِ الْجَنْبِ ‏"‏ ‏.‏\hadithno{5762}\hadithtrans{Umm Qais, daughter of Mihsan, the sister of 'Ukasha b. Mihsan said:I visited Allah's Messenger (ﷺ) along with my son who had not, by that time, been weaned and he urinated over his (clothes). He ordered water to be brought and sprinkled (it) over them. She (further) said: I visited him (Allah's Apostle) along with my son and I had squeezed the swelling in the uvula, whereupon he said: Why do you afflict your children by compressing like this? Use this Indian aloeswood, for it contains seven types of remedies, one among them being a remedy for pleurisy. It is applied through the nose for a swelling of the uvula and poured into the side of the mouth for pleurisy}}
\hadithdefcmd{muslim}{5764}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ أُمَّ قَيْسٍ بِنْتَ مِحْصَنٍ، - وَكَانَتْ مِنَ الْمُهَاجِرَاتِ الأُوَلِ اللاَّتِي بَايَعْنَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهِيَ أُخْتُ عُكَّاشَةَ بْنِ مِحْصَنٍ أَحَدِ بَنِي أَسَدِ بْنِ خُزَيْمَةَ - قَالَ أَخْبَرَتْنِي أَنَّهَا أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم بِابْنٍ لَهَا لَمْ يَبْلُغْ أَنْ يَأْكُلَ الطَّعَامَ وَقَدْ أَعْلَقَتْ عَلَيْهِ مِنَ الْعُذْرَةِ - قَالَ يُونُسُ أَعْلَقَتْ غَمَزَتْ فَهِيَ تَخَافُ أَنْ يَكُونَ بِهِ عُذْرَةٌ - قَالَتْ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلاَمَهْ تَدْغَرْنَ أَوْلاَدَكُنَّ بِهَذَا الإِعْلاَقِ عَلَيْكُمْ بِهَذَا الْعُودِ الْهِنْدِيِّ - يَعْنِي بِهِ الْكُسْتَ - فَإِنَّ فِيهِ سَبْعَةَ أَشْفِيَةٍ مِنْهَا ذَاتُ الْجَنْبِ ‏"‏ ‏.‏ قَالَ عُبَيْدُ اللَّهِ وَأَخْبَرَتْنِي أَنَّ ابْنَهَا ذَاكَ بَالَ فِي حَجْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَاءٍ فَنَضَحَهُ عَلَى بَوْلِهِ وَلَمْ يَغْسِلْهُ غَسْلاً ‏.‏\hadithno{5764}\hadithtrans{Umm Qais, daughter of Mihsan, was one of the earlier female emigrants who had pledged allegiance to Allah's Messenger (ﷺ). She was the sister of Ukasha b. Mihsan, one of the posterity of Asad b. Khuzaima. She reported that she came to Allah's messenger (ﷺ) along with her son who had not attained the age of weaning and she had compressed the swelling of his uvula. (Yunus said:She compressed the uvula because she was afraid that there might be swelling of uvula.) Thereupon Allah's Messenger (ﷺ) said: Why do you afflict your children by compressing in this way? You should use Indian aloeswood, for it has seven remedies in it, one of them being the remedy for pleurisy. Ubaidullah reported that she had told that that was the child who had urinated in the lap of Allah's Messenger (ﷺ), and Allah's Messenger (ﷺ) called for water and sprinkled it on his urine, but he did not wash it well}}
\hadithdefcmd{muslim}{5826}{وَحَدَّثَنَا حَاجِبُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُ بِقَتْلِ الْكِلاَبِ يَقُولُ ‏\textbackslash\{\}"‏ اقْتُلُوا الْحَيَّاتِ وَالْكِلاَبَ وَاقْتُلُوا ذَا الطُّفْيَتَيْنِ وَالأَبْتَرَ فَإِنَّهُمَا يَلْتَمِسَانِ الْبَصَرَ وَيَسْتَسْقِطَانِ الْحَبَالَى ‏\textbackslash\{\}"‏ ‏.‏ قَالَ الزُّهْرِيُّ وَنُرَى ذَلِكَ مِنْ سُمَّيْهِمَا وَاللَّهُ أَعْلَمُ ‏.‏ قَالَ سَالِمٌ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَلَبِثْتُ لاَ أَتْرُكُ حَيَّةً أَرَاهَا إِلاَّ قَتَلْتُهَا فَبَيْنَا أَنَا أُطَارِدُ حَيَّةً يَوْمًا مِنْ ذَوَاتِ الْبُيُوتِ مَرَّ بِي زَيْدُ بْنُ الْخَطَّابِ أَوْ أَبُو لُبَابَةَ وَأَنَا أُطَارِدُهَا فَقَالَ مَهْلاً يَا عَبْدَ اللَّهِ ‏.‏ فَقُلْتُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِقَتْلِهِنَّ ‏.‏ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ نَهَى عَنْ ذَوَاتِ الْبُيُوتِ ‏.‏ وَحَدَّثَنِيهِ حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا عَبْدُ بْنُ، حُمَيْدٍ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنَا حَسَنٌ الْحُلْوَانِيُّ، حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّ صَالِحًا، قَالَ حَتَّى رَآنِي أَبُو لُبَابَةَ بْنُ عَبْدِ الْمُنْذِرِ وَزَيْدُ بْنُ الْخَطَّابِ فَقَالاَ إِنَّهُ قَدْ نَهَى عَنْ ذَوَاتِ الْبُيُوتِ ‏.‏ وَفِي حَدِيثِ يُونُسَ ‏\textbackslash\{\}"‏ اقْتُلُوا الْحَيَّاتِ ‏\textbackslash\{\}"‏ ‏.‏ وَلَمْ يَقُلْ ‏\textbackslash\{\}"‏ ذَا الطُّفْيَتَيْنِ وَالأَبْتَرَ ‏\textbackslash\{\}"‏ ‏.‏\hadithno{5826}\hadithtrans{Ibn 'Umar reported:I heard Allah's Messenger (ﷺ) commanding the killing of dogs and the killing of the striped and the short-tailed snakes, for both of them affect the eyesight adversely and cause miscarriage. Zuhri said: We thought of their poison (the pernicious effects of these two). Allah, however, knows best. 'Abdullah b. 'Umar said: I did not spare any snake. I rather killed everyone that I saw. One day as I was pursuing a snake from amongst the snakes of the house, Zaid b. Khattab or Abu Lubaba happened to pass by me and found me pursuing it. He said: 'Abdullah, wait. I said: Allah's Messenger (ﷺ) commanded (us) to kill them, whereupon he said that Allah's Messenger (ﷺ) forbade the killing of the snakes of the houses. This hadith has been narrated on the authority of Zuhri with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5827}{وَحَدَّثَنَا حَاجِبُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، عَنِ ابْنِ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُ بِقَتْلِ الْكِلاَبِ يَقُولُ ‏\textbackslash\{\}"‏ اقْتُلُوا الْحَيَّاتِ وَالْكِلاَبَ وَاقْتُلُوا ذَا الطُّفْيَتَيْنِ وَالأَبْتَرَ فَإِنَّهُمَا يَلْتَمِسَانِ الْبَصَرَ وَيَسْتَسْقِطَانِ الْحَبَالَى ‏\textbackslash\{\}"‏ ‏.‏ قَالَ الزُّهْرِيُّ وَنُرَى ذَلِكَ مِنْ سُمَّيْهِمَا وَاللَّهُ أَعْلَمُ ‏.‏ قَالَ سَالِمٌ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَلَبِثْتُ لاَ أَتْرُكُ حَيَّةً أَرَاهَا إِلاَّ قَتَلْتُهَا فَبَيْنَا أَنَا أُطَارِدُ حَيَّةً يَوْمًا مِنْ ذَوَاتِ الْبُيُوتِ مَرَّ بِي زَيْدُ بْنُ الْخَطَّابِ أَوْ أَبُو لُبَابَةَ وَأَنَا أُطَارِدُهَا فَقَالَ مَهْلاً يَا عَبْدَ اللَّهِ ‏.‏ فَقُلْتُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِقَتْلِهِنَّ ‏.‏ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ نَهَى عَنْ ذَوَاتِ الْبُيُوتِ ‏.‏ وَحَدَّثَنِيهِ حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا عَبْدُ بْنُ، حُمَيْدٍ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنَا حَسَنٌ الْحُلْوَانِيُّ، حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّ صَالِحًا، قَالَ حَتَّى رَآنِي أَبُو لُبَابَةَ بْنُ عَبْدِ الْمُنْذِرِ وَزَيْدُ بْنُ الْخَطَّابِ فَقَالاَ إِنَّهُ قَدْ نَهَى عَنْ ذَوَاتِ الْبُيُوتِ ‏.‏ وَفِي حَدِيثِ يُونُسَ ‏\textbackslash\{\}"‏ اقْتُلُوا الْحَيَّاتِ ‏\textbackslash\{\}"‏ ‏.‏ وَلَمْ يَقُلْ ‏\textbackslash\{\}"‏ ذَا الطُّفْيَتَيْنِ وَالأَبْتَرَ ‏\textbackslash\{\}"‏ ‏.‏\hadithno{5827}\hadithtrans{Ibn 'Umar reported:I heard Allah's Messenger (ﷺ) commanding the killing of dogs and the killing of the striped and the short-tailed snakes, for both of them affect the eyesight adversely and cause miscarriage. Zuhri said: We thought of their poison (the pernicious effects of these two). Allah, however, knows best. 'Abdullah b. 'Umar said: I did not spare any snake. I rather killed everyone that I saw. One day as I was pursuing a snake from amongst the snakes of the house, Zaid b. Khattab or Abu Lubaba happened to pass by me and found me pursuing it. He said: 'Abdullah, wait. I said: Allah's Messenger (ﷺ) commanded (us) to kill them, whereupon he said that Allah's Messenger (ﷺ) forbade the killing of the snakes of the houses. This hadith has been narrated on the authority of Zuhri with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5885}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، كِلاَهُمَا عَنِ ابْنِ عُيَيْنَةَ، قَالَ ابْنُ أَبِي عُمَرَ حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنْ أَبِيهِ، قَالَ رَدِفْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمًا فَقَالَ ‏"‏ هَلْ مَعَكَ مِنْ شِعْرِ أُمَيَّةَ بْنِ أَبِي الصَّلْتِ شَيْئًا ‏"‏ ‏.‏ قُلْتُ نَعَمْ قَالَ ‏"‏ هِيهِ ‏"‏ ‏.‏ فَأَنْشَدْتُهُ بَيْتًا فَقَالَ ‏"‏ هِيهِ ‏"‏ ‏.‏ ثُمَّ أَنْشَدْتُهُ بَيْتًا فَقَالَ ‏"‏ هِيهِ ‏"‏ ‏.‏ حَتَّى أَنْشَدْتُهُ مِائَةَ بَيْتٍ ‏.‏ وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، وَأَحْمَدُ بْنُ عَبْدَةَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، عَنْ إِبْرَاهِيمَ، بْنِ مَيْسَرَةَ عَنْ عَمْرِو بْنِ الشَّرِيدِ، أَوْ يَعْقُوبَ بْنِ عَاصِمٍ عَنِ الشَّرِيدِ، قَالَ أَرْدَفَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم خَلْفَهُ ‏.‏ فَذَكَرَ بِمِثْلِهِ ‏.‏\hadithno{5885}\hadithtrans{Amr b. Sharid reported his father as saying:One day when I rode behind Allah's Messenger (ﷺ), he said (to me): Do you remember any poetry of Umayya b. Abu Salt. I said: Yes. He said: Then go on. I recited a couplet, and he said: Go on. Then I again recited a couplet and he said: Go on. I recited one hundred couplets (of his poetry). This hadith has been reported on the authority of Sharid through another chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5886}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، كِلاَهُمَا عَنِ ابْنِ عُيَيْنَةَ، قَالَ ابْنُ أَبِي عُمَرَ حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ بْنِ مَيْسَرَةَ، عَنْ عَمْرِو بْنِ الشَّرِيدِ، عَنْ أَبِيهِ، قَالَ رَدِفْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمًا فَقَالَ ‏"‏ هَلْ مَعَكَ مِنْ شِعْرِ أُمَيَّةَ بْنِ أَبِي الصَّلْتِ شَيْئًا ‏"‏ ‏.‏ قُلْتُ نَعَمْ قَالَ ‏"‏ هِيهِ ‏"‏ ‏.‏ فَأَنْشَدْتُهُ بَيْتًا فَقَالَ ‏"‏ هِيهِ ‏"‏ ‏.‏ ثُمَّ أَنْشَدْتُهُ بَيْتًا فَقَالَ ‏"‏ هِيهِ ‏"‏ ‏.‏ حَتَّى أَنْشَدْتُهُ مِائَةَ بَيْتٍ ‏.‏ وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، وَأَحْمَدُ بْنُ عَبْدَةَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، عَنْ إِبْرَاهِيمَ، بْنِ مَيْسَرَةَ عَنْ عَمْرِو بْنِ الشَّرِيدِ، أَوْ يَعْقُوبَ بْنِ عَاصِمٍ عَنِ الشَّرِيدِ، قَالَ أَرْدَفَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم خَلْفَهُ ‏.‏ فَذَكَرَ بِمِثْلِهِ ‏.‏\hadithno{5886}\hadithtrans{Amr b. Sharid reported his father as saying:One day when I rode behind Allah's Messenger (ﷺ), he said (to me): Do you remember any poetry of Umayya b. Abu Salt. I said: Yes. He said: Then go on. I recited a couplet, and he said: Go on. Then I again recited a couplet and he said: Go on. I recited one hundred couplets (of his poetry). This hadith has been reported on the authority of Sharid through another chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{5935}{حَدَّثَنِي مُحَمَّدُ بْنُ سَهْلٍ التَّمِيمِيُّ، حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنْ عَبْدِ اللَّهِ، بْنِ أَبِي حُسَيْنٍ حَدَّثَنَا نَافِعُ بْنُ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَدِمَ مُسَيْلِمَةُ الْكَذَّابُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم الْمَدِينَةَ فَجَعَلَ يَقُولُ إِنْ جَعَلَ لِي مُحَمَّدٌ الأَمْرَ مِنْ بَعْدِهِ تَبِعْتُهُ ‏.‏ فَقَدِمَهَا فِي بَشَرٍ كَثِيرٍ مِنْ قَوْمِهِ فَأَقْبَلَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم وَمَعَهُ ثَابِتُ بْنُ قَيْسِ بْنِ شَمَّاسٍ وَفِي يَدِ النَّبِيِّ صلى الله عليه وسلم قِطْعَةُ جَرِيدَةٍ حَتَّى وَقَفَ عَلَى مُسَيْلِمَةَ فِي أَصْحَابِهِ قَالَ ‏"‏ لَوْ سَأَلْتَنِي هَذِهِ الْقِطْعَةَ مَا أَعْطَيْتُكَهَا وَلَنْ أَتَعَدَّى أَمْرَ اللَّهِ فِيكَ وَلَئِنْ أَدْبَرْتَ لَيَعْقِرَنَّكَ اللَّهُ وَإِنِّي لأُرَاكَ الَّذِي أُرِيتُ فِيكَ مَا أُرِيتُ وَهَذَا ثَابِتٌ يُجِيبُكَ عَنِّي ‏"‏ ‏.‏ ثُمَّ انْصَرَفَ عَنْهُ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ فَسَأَلْتُ عَنْ قَوْلِ النَّبِيِّ، صلى الله عليه وسلم ‏"‏ إِنَّكَ أَرَى الَّذِي أُرِيتُ فِيكَ مَا أُرِيتُ ‏"‏ ‏.‏ فَأَخْبَرَنِي أَبُو هُرَيْرَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَا أَنَا نَائِمٌ رَأَيْتُ فِي يَدَىَّ سِوَارَيْنِ مِنْ ذَهَبٍ فَأَهَمَّنِي شَأْنُهُمَا فَأُوحِيَ إِلَىَّ فِي الْمَنَامِ أَنِ انْفُخْهُمَا فَنَفَخْتُهُمَا فَطَارَا فَأَوَّلْتُهُمَا كَذَّابَيْنِ يَخْرُجَانِ مِنْ بَعْدِي فَكَانَ أَحَدُهُمَا الْعَنْسِيَّ صَاحِبَ صَنْعَاءَ وَالآخَرُ مُسَيْلِمَةَ صَاحِبَ الْيَمَامَةِ ‏"‏ ‏.‏\hadithno{5935}\hadithtrans{Ibn `Abbas reported that Musailima al-Kadhdhab (the greater liar) (who claimed prophethood after the death of the Holy Prophet) came during the lifetime of Allah's Apostle (ﷺ) to Medina and said:If Muhammad assigns his caliphate to me after him I would follow him, and there came along with him a large body of persons of his tribe, and there came to him Allah's Apostle (ﷺ) along with Thabit b. Qais b. Shammas and the Prophet of Allah (ﷺ) had a piece of wood in his hand until he came in front of Musailima in the company of his companions and said: If you were to ask even this (wood), I would never give it to you. I am not going to do anything against the will of God in your case, and if you turn away (from what I say) Allah will destroy you. And I find you in the same state which I was shown (in the dream) and here is Thabit and he would answer you on my behalf. He (the Holy Prophet) then went back. Ibn `Abbas said: I asked the (meaning of the) words of Allah's Apostle (ﷺ): "You are the same what I was made to see about you in my dream." and Abu Huraira reported that Allah's Messenger (ﷺ) said: While I was sleeping I saw in my hands two gold bangles. This had a disturbing effect upon me and I was given a suggestion in the sleep that I should blow over them, so I blew over them and they were no more. And I interpreted these (two bangles) as the two great liars who would appear after me and the one amongst them was Al-`Anasi the inhabitant of San`a' and the other one Musailima the inhabitant of Yamama}}
\hadithdefcmd{muslim}{5968}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنْ أَبِي حَازِمٍ، قَالَ سَمِعْتُ سَهْلاً، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ أَنَا فَرَطُكُمْ، عَلَى الْحَوْضِ مَنْ وَرَدَ شَرِبَ وَمَنْ شَرِبَ لَمْ يَظْمَأْ أَبَدًا وَلَيَرِدَنَّ عَلَىَّ أَقْوَامٌ أَعْرِفُهُمْ وَيَعْرِفُونِي ثُمَّ يُحَالُ بَيْنِي وَبَيْنَهُمْ ‏"‏ ‏.‏ قَالَ أَبُو حَازِمٍ فَسَمِعَ النُّعْمَانُ بْنُ أَبِي عَيَّاشٍ وَأَنَا أُحَدِّثُهُمْ هَذَا الْحَدِيثَ فَقَالَ هَكَذَا سَمِعْتَ سَهْلاً يَقُولُ قَالَ فَقُلْتُ نَعَمْ ‏.‏ قَالَ وَأَنَا أَشْهَدُ، عَلَى أَبِي سَعِيدٍ الْخُدْرِيِّ لَسَمِعْتُهُ يَزِيدُ فَيَقُولُ ‏"‏ إِنَّهُمْ مِنِّي ‏.‏ فَيُقَالُ إِنَّكَ لاَ تَدْرِي مَا عَمِلُوا بَعْدَكَ ‏.‏ فَأَقُولُ سُحْقًا سُحْقًا لِمَنْ بَدَّلَ بَعْدِي ‏"‏ ‏.‏\hadithno{5968}\hadithtrans{Sahl (b. Sa'd) reported:I heard Allah's Apostle (ﷺ) as saying: I shall go to the Cistern before you and he who comes would drink and he who drinks would never feel thirsty, and there would come to me people whom I would know and who would know me. Then there would be intervention between me and them. Abu Hazim said that Nu'man b. Abu 'Ayyash heard it and I narrated to them this hadith, and said: Is it this that you heard Sahl saying? He said: Yes, and I bear witness to the fact that I heard it from Abu Sa'id Khudri also, but he made this addition that he (the Holy Prophet) would say: They are my followers, and it would be said to him: You do not know what they did after you and I will say to them: Woe to him who changes (his religion) after me}}
\hadithdefcmd{muslim}{5971}{وَحَدَّثَنَا دَاوُدُ بْنُ عَمْرٍو الضَّبِّيُّ، حَدَّثَنَا نَافِعُ بْنُ عُمَرَ الْجُمَحِيُّ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ الْعَاصِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ حَوْضِي مَسِيرَةُ شَهْرٍ وَزَوَايَاهُ سَوَاءٌ وَمَاؤُهُ أَبْيَضُ مِنَ الْوَرِقِ وَرِيحُهُ أَطْيَبُ مِنَ الْمِسْكِ وَكِيزَانُهُ كَنُجُومِ السَّمَاءِ فَمَنْ شَرِبَ مِنْهُ فَلاَ يَظْمَأُ بَعْدَهُ أَبَدًا ‏"‏ ‏.‏ قَالَ وَقَالَتْ أَسْمَاءُ بِنْتُ أَبِي بَكْرٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي عَلَى الْحَوْضِ حَتَّى أَنْظُرَ مَنْ يَرِدُ عَلَىَّ مِنْكُمْ وَسَيُؤْخَذُ أُنَاسٌ دُونِي فَأَقُولُ يَا رَبِّ مِنِّي وَمِنْ أُمَّتِي ‏.‏ فَيُقَالُ أَمَا شَعَرْتَ مَا عَمِلُوا بَعْدَكَ وَاللَّهِ مَا بَرِحُوا بَعْدَكَ يَرْجِعُونَ عَلَى أَعْقَابِهِمْ ‏"‏ ‏.‏ قَالَ فَكَانَ ابْنُ أَبِي مُلَيْكَةَ يَقُولُ اللَّهُمَّ إِنَّا نَعُوذُ بِكَ أَنْ نَرْجِعَ عَلَى أَعْقَابِنَا أَوْ أَنْ نُفْتَنَ عَنْ دِينِنَا\hadithno{5971}\hadithtrans{Abdullah b. `Amr al-`As, reported Allah's Messenger (ﷺ) as saying:My Cistern (is as wide and broad that it requires) a month's journey (to go round it) all, and its sides are equal and its water is whiter than silver, and its odour is more fragrant than the fragrance of musk, and its jugs (placed around it) are like stars in the sky; and he who would drink from it would never feel thirsty after that. Asma', daughter of Abu Bakr said: Allah's Messenger (ﷺ) said: I would be on the Cistern so that I would be seeing those who would be coming to me from you, but some people would be detained (before reaching me). I would say: My Lord, they are my followers and belong to my Ummah, and it would be said to me: Do you know what they did after you? By Allah, they did not do good after you, and they turned back upon their heels. He (the narrator) said: lbn Abu Mulaika used to say (in supplication): O Allah, I seek refuge with Thee that we should turn back upon our heels or put to any trial about our religion}}
\hadithdefcmd{muslim}{5990}{حَدَّثَنَا أَبُو غَسَّانَ الْمِسْمَعِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَأَلْفَاظُهُمْ مُتَقَارِبَةٌ - قَالُوا حَدَّثَنَا مُعَاذٌ، - وَهُوَ ابْنُ هِشَامٍ - حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ الْيَعْمَرِيِّ، عَنْ ثَوْبَانَ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنِّي لَبِعُقْرِ حَوْضِي أَذُودُ النَّاسَ لأَهْلِ الْيَمَنِ أَضْرِبُ بِعَصَاىَ حَتَّى يَرْفَضَّ عَلَيْهِمْ ‏"‏ ‏.‏ فَسُئِلَ عَنْ عَرْضِهِ فَقَالَ ‏"‏ مِنْ مَقَامِي إِلَى عَمَّانَ ‏"‏ ‏.‏ وَسُئِلَ عَنْ شَرَابِهِ فَقَالَ ‏"‏ أَشَدُّ بَيَاضًا مِنَ اللَّبَنِ وَأَحْلَى مِنَ الْعَسَلِ يَغُتُّ فِيهِ مِيزَابَانِ يَمُدَّانِهِ مِنَ الْجَنَّةِ أَحَدُهُمَا مِنْ ذَهَبٍ وَالآخَرُ مِنْ وَرِقٍ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا شَيْبَانُ، عَنْ قَتَادَةَ، بِإِسْنَادِ هِشَامٍ ‏.‏ بِمِثْلِ حَدِيثِهِ غَيْرَ أَنَّهُ قَالَ ‏"‏ أَنَا يَوْمَ الْقِيَامَةِ عِنْدَ عُقْرِ الْحَوْضِ ‏"‏ ‏.‏\hadithno{5990}\hadithtrans{Thauban reported Allah's Apostle (ﷺ) as saying:I would be pushing back from my Cistern the crowd of people. I would strike away from it (the Cistern) with my staff the people of Yemen until the water (of the Haud) would spout forth upon them. He was asked about its breadth. He said: From this place of mine to 'Amman, and he was asked about the drink and he said: It is whiter than milk and sweeter than honey. There would spout into it two streamlets having their sources in Paradise. the one is from gold and the other is from silver. This hadith has been narrated on the authority of Hisham with the same chain of transmitters and the words are:" I would be on the Day of Resurrection near the bank of the Cistern}}
\hadithdefcmd{muslim}{5991}{حَدَّثَنَا أَبُو غَسَّانَ الْمِسْمَعِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَأَلْفَاظُهُمْ مُتَقَارِبَةٌ - قَالُوا حَدَّثَنَا مُعَاذٌ، - وَهُوَ ابْنُ هِشَامٍ - حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ الْيَعْمَرِيِّ، عَنْ ثَوْبَانَ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنِّي لَبِعُقْرِ حَوْضِي أَذُودُ النَّاسَ لأَهْلِ الْيَمَنِ أَضْرِبُ بِعَصَاىَ حَتَّى يَرْفَضَّ عَلَيْهِمْ ‏"‏ ‏.‏ فَسُئِلَ عَنْ عَرْضِهِ فَقَالَ ‏"‏ مِنْ مَقَامِي إِلَى عَمَّانَ ‏"‏ ‏.‏ وَسُئِلَ عَنْ شَرَابِهِ فَقَالَ ‏"‏ أَشَدُّ بَيَاضًا مِنَ اللَّبَنِ وَأَحْلَى مِنَ الْعَسَلِ يَغُتُّ فِيهِ مِيزَابَانِ يَمُدَّانِهِ مِنَ الْجَنَّةِ أَحَدُهُمَا مِنْ ذَهَبٍ وَالآخَرُ مِنْ وَرِقٍ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا شَيْبَانُ، عَنْ قَتَادَةَ، بِإِسْنَادِ هِشَامٍ ‏.‏ بِمِثْلِ حَدِيثِهِ غَيْرَ أَنَّهُ قَالَ ‏"‏ أَنَا يَوْمَ الْقِيَامَةِ عِنْدَ عُقْرِ الْحَوْضِ ‏"‏ ‏.‏\hadithno{5991}\hadithtrans{Thauban reported Allah's Apostle (ﷺ) as saying:I would be pushing back from my Cistern the crowd of people. I would strike away from it (the Cistern) with my staff the people of Yemen until the water (of the Haud) would spout forth upon them. He was asked about its breadth. He said: From this place of mine to 'Amman, and he was asked about the drink and he said: It is whiter than milk and sweeter than honey. There would spout into it two streamlets having their sources in Paradise. the one is from gold and the other is from silver. This hadith has been narrated on the authority of Hisham with the same chain of transmitters and the words are:" I would be on the Day of Resurrection near the bank of the Cistern}}
\hadithdefcmd{muslim}{5995}{\hadithno{5995}\hadithtrans{}}
\hadithdefcmd{muslim}{5996}{\hadithno{5996}\hadithtrans{}}
\hadithdefcmd{muslim}{5997}{\hadithno{5997}\hadithtrans{}}
\hadithdefcmd{muslim}{5998}{\hadithno{5998}\hadithtrans{}}
\hadithdefcmd{muslim}{5999}{\hadithno{5999}\hadithtrans{}}
\hadithdefcmd{muslim}{6000}{\hadithno{6000}\hadithtrans{}}
\hadithdefcmd{muslim}{6001}{\hadithno{6001}\hadithtrans{}}
\hadithdefcmd{muslim}{6002}{\hadithno{6002}\hadithtrans{}}
\hadithdefcmd{muslim}{6003}{\hadithno{6003}\hadithtrans{}}
\hadithdefcmd{muslim}{6015}{حَدَّثَنِي أَبُو مَعْنٍ الرَّقَاشِيُّ، زَيْدُ بْنُ يَزِيدَ أَخْبَرَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ، - وَهُوَ ابْنُ عَمَّارٍ - قَالَ قَالَ إِسْحَاقُ قَالَ أَنَسٌ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ أَحْسَنِ النَّاسِ خُلُقًا فَأَرْسَلَنِي يَوْمًا لِحَاجَةٍ فَقُلْتُ وَاللَّهِ لاَ أَذْهَبُ ‏.‏ وَفِي نَفْسِي أَنْ أَذْهَبَ لِمَا أَمَرَنِي بِهِ نَبِيُّ اللَّهِ صلى الله عليه وسلم فَخَرَجْتُ حَتَّى أَمُرَّ عَلَى صِبْيَانٍ وَهُمْ يَلْعَبُونَ فِي السُّوقِ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَدْ قَبَضَ بِقَفَاىَ مِنْ وَرَائِي - قَالَ - فَنَظَرْتُ إِلَيْهِ وَهُوَ يَضْحَكُ فَقَالَ ‏ "‏ يَا أُنَيْسُ أَذَهَبْتَ حَيْثُ أَمَرْتُكَ ‏"‏ ‏.‏ قَالَ قُلْتُ نَعَمْ أَنَا أَذْهَبُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ أَنَسٌ وَاللَّهِ لَقَدْ خَدَمْتُهُ تِسْعَ سِنِينَ مَا عَلِمْتُهُ قَالَ لِشَىْءٍ صَنَعْتُهُ لِمَ فَعَلْتَ كَذَا وَكَذَا أَوْ لِشَىْءٍ تَرَكْتُهُ هَلاَّ فَعَلْتَ كَذَا وَكَذَا ‏.‏\hadithno{6015}\hadithtrans{Anas reported that Allah's Messenger (ﷺ) had the best disposition amongst people. He sent me on an errand one day, and I said:By Allah, I would not go. I had, however, this idea in my mind that I would do as Allah's Apostle (ﷺ) had commanded me to do. I went out until I happened to come across children who had been playing in the street. In the meanwhile, Allah's Messenger (ﷺ) came there and he caught me by the back of my neck from behind me. As I looked towards him I found him smiling and he said: Unais, did you go where I commanded you to go? I said: Allah's Messenger, yes, I am going. Anas further said: I served him for nine years but I know not that he ever said to me about a thing which I had done why I did that, or about a thing I had left as to why I had not done that}}
\hadithdefcmd{muslim}{6144}{\hadithno{6144}\hadithtrans{}}
\hadithdefcmd{muslim}{6179}{حَدَّثَنِي عَبَّادُ بْنُ مُوسَى، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، أَخْبَرَنِي أَبِي، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ، بْنِ مُطْعِمٍ عَنْ أَبِيهِ، أَنَّ امْرَأَةً، سَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم شَيْئًا فَأَمَرَهَا أَنْ تَرْجِعَ إِلَيْهِ فَقَالَتْ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ جِئْتُ فَلَمْ أَجِدْكَ قَالَ أَبِي كَأَنَّهَا تَعْنِي الْمَوْتَ ‏.‏ قَالَ ‏ "‏ فَإِنْ لَمْ تَجِدِينِي فَأْتِي أَبَا بَكْرٍ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ أَبِيهِ، أَخْبَرَنِي مُحَمَّدُ بْنُ جُبَيْرِ بْنِ مُطْعِمٍ، أَنَّ أَبَاهُ، جُبَيْرَ بْنَ مُطْعِمٍ أَخْبَرَهُ أَنَّ امْرَأَةً أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَكَلَّمَتْهُ فِي شَىْءٍ فَأَمَرَهَا بِأَمْرٍ ‏.‏ بِمِثْلِ حَدِيثِ عَبَّادِ بْنِ مُوسَى ‏.‏\hadithno{6179}\hadithtrans{Muhammad b. Jubair b. Mut'im reported on the authority of his father that a woman asked Allah's Messenger (ﷺ) about something but lit, told her to come to him on some other occasion, whereupon she said:What in your opinion (should I do) if I come to you but do not find you, and it seemed as if she meant that he might die. Thereupon he said: If you do not find me, then come to Abu Bakr. This hadith has been narrated on the authority of Jubair b. Mut'im through another chain of transmitters (and the words are) that a woman came to Allah's Messenger (ﷺ) and discussed with him something and he gave a command as we find in the above-mentioned narration}}
\hadithdefcmd{muslim}{6180}{حَدَّثَنِي عَبَّادُ بْنُ مُوسَى، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، أَخْبَرَنِي أَبِي، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ، بْنِ مُطْعِمٍ عَنْ أَبِيهِ، أَنَّ امْرَأَةً، سَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم شَيْئًا فَأَمَرَهَا أَنْ تَرْجِعَ إِلَيْهِ فَقَالَتْ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ جِئْتُ فَلَمْ أَجِدْكَ قَالَ أَبِي كَأَنَّهَا تَعْنِي الْمَوْتَ ‏.‏ قَالَ ‏ "‏ فَإِنْ لَمْ تَجِدِينِي فَأْتِي أَبَا بَكْرٍ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ أَبِيهِ، أَخْبَرَنِي مُحَمَّدُ بْنُ جُبَيْرِ بْنِ مُطْعِمٍ، أَنَّ أَبَاهُ، جُبَيْرَ بْنَ مُطْعِمٍ أَخْبَرَهُ أَنَّ امْرَأَةً أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَكَلَّمَتْهُ فِي شَىْءٍ فَأَمَرَهَا بِأَمْرٍ ‏.‏ بِمِثْلِ حَدِيثِ عَبَّادِ بْنِ مُوسَى ‏.‏\hadithno{6180}\hadithtrans{Muhammad b. Jubair b. Mut'im reported on the authority of his father that a woman asked Allah's Messenger (ﷺ) about something but lit, told her to come to him on some other occasion, whereupon she said:What in your opinion (should I do) if I come to you but do not find you, and it seemed as if she meant that he might die. Thereupon he said: If you do not find me, then come to Abu Bakr. This hadith has been narrated on the authority of Jubair b. Mut'im through another chain of transmitters (and the words are) that a woman came to Allah's Messenger (ﷺ) and discussed with him something and he gave a command as we find in the above-mentioned narration}}
\hadithdefcmd{muslim}{6200}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ بَيْنَا أَنَا نَائِمٌ إِذْ رَأَيْتُنِي فِي الْجَنَّةِ فَإِذَا امْرَأَةٌ تَوَضَّأُ إِلَى جَانِبِ قَصْرٍ فَقُلْتُ لِمَنْ هَذَا فَقَالُوا لِعُمَرَ بْنِ الْخَطَّابِ ‏.‏ فَذَكَرْتُ غَيْرَةَ عُمَرَ فَوَلَّيْتُ مُدْبِرًا ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَبَكَى عُمَرُ وَنَحْنُ جَمِيعًا فِي ذَلِكَ الْمَجْلِسِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ عُمَرُ بِأَبِي أَنْتَ يَا رَسُولَ اللَّهِ أَعَلَيْكَ أَغَارُ وَحَدَّثَنِيهِ عَمْرٌو النَّاقِدُ، وَحَسَنٌ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالُوا حَدَّثَنَا يَعْقُوبُ بْنُ، إِبْرَاهِيمَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6200}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:While I was asleep I saw myself in Paradise and a woman performing ablution by the side of a palace. I said: For whom is it meant? They said: It is meant for 'Umar b. Khattab. (The Holy Prophet) said: There came across my mind the feeling of Umar and so I turned back and went away. Abu Huraira said: 'Umar wept as we were present in that meeting with Allah's Messenger (ﷺ) amongst us and Umar said: Allah's Messenger, may my father and mother be taken as ransom for you. Could I at all feel any jealousy about you? This hadith has been narrated on the authority of Ibn Shihab with the same chain of transmitters}}
\hadithdefcmd{muslim}{6201}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ بَيْنَا أَنَا نَائِمٌ إِذْ رَأَيْتُنِي فِي الْجَنَّةِ فَإِذَا امْرَأَةٌ تَوَضَّأُ إِلَى جَانِبِ قَصْرٍ فَقُلْتُ لِمَنْ هَذَا فَقَالُوا لِعُمَرَ بْنِ الْخَطَّابِ ‏.‏ فَذَكَرْتُ غَيْرَةَ عُمَرَ فَوَلَّيْتُ مُدْبِرًا ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَبَكَى عُمَرُ وَنَحْنُ جَمِيعًا فِي ذَلِكَ الْمَجْلِسِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ عُمَرُ بِأَبِي أَنْتَ يَا رَسُولَ اللَّهِ أَعَلَيْكَ أَغَارُ وَحَدَّثَنِيهِ عَمْرٌو النَّاقِدُ، وَحَسَنٌ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالُوا حَدَّثَنَا يَعْقُوبُ بْنُ، إِبْرَاهِيمَ حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6201}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:While I was asleep I saw myself in Paradise and a woman performing ablution by the side of a palace. I said: For whom is it meant? They said: It is meant for 'Umar b. Khattab. (The Holy Prophet) said: There came across my mind the feeling of Umar and so I turned back and went away. Abu Huraira said: 'Umar wept as we were present in that meeting with Allah's Messenger (ﷺ) amongst us and Umar said: Allah's Messenger, may my father and mother be taken as ransom for you. Could I at all feel any jealousy about you? This hadith has been narrated on the authority of Ibn Shihab with the same chain of transmitters}}
\hadithdefcmd{muslim}{6410}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَرَّادٍ الأَشْعَرِيُّ، وَمُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ حَدَّثَنِي بُرَيْدٌ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ بَلَغَنَا مَخْرَجُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَنَحْنُ بِالْيَمَنِ فَخَرَجْنَا مُهَاجِرِينَ إِلَيْهِ أَنَا وَأَخَوَانِ لِي أَنَا أَصْغَرُهُمَا أَحَدُهُمَا أَبُو بُرْدَةَ وَالآخَرُ أَبُو رُهْمٍ - إِمَّا قَالَ بِضْعًا وَإِمَّا قَالَ ثَلاَثَةً وَخَمْسِينَ أَوِ اثْنَيْنِ وَخَمْسِينَ رَجُلاً مِنْ قَوْمِي - قَالَ فَرَكِبْنَا سَفِينَةً فَأَلْقَتْنَا سَفِينَتُنَا إِلَى النَّجَاشِيِّ بِالْحَبَشَةِ فَوَافَقْنَا جَعْفَرَ بْنَ أَبِي طَالِبٍ وَأَصْحَابَهُ عِنْدَهُ فَقَالَ جَعْفَرٌ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَنَا هَا هُنَا وَأَمَرَنَا بِالإِقَامَةِ فَأَقِيمُوا مَعَنَا ‏.‏ فَأَقَمْنَا مَعَهُ حَتَّى قَدِمْنَا جَمِيعًا - قَالَ - فَوَافَقْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ افْتَتَحَ خَيْبَرَ فَأَسْهَمَ لَنَا - أَوْ قَالَ أَعْطَانَا مِنْهَا - وَمَا قَسَمَ لأَحَدٍ غَابَ عَنْ فَتْحِ خَيْبَرَ مِنْهَا شَيْئًا إِلاَّ لِمَنْ شَهِدَ مَعَهُ إِلاَّ لأَصْحَابِ سَفِينَتِنَا مَعَ جَعْفَرٍ وَأَصْحَابِهِ قَسَمَ لَهُمْ مَعَهُمْ - قَالَ - فَكَانَ نَاسٌ مِنَ النَّاسِ يَقُولُونَ لَنَا - يَعْنِي لأَهْلِ السَّفِينَةِ - نَحْنُ سَبَقْنَاكُمْ بِالْهِجْرَةِ ‏.‏ قَالَ فَدَخَلَتْ أَسْمَاءُ بِنْتُ عُمَيْسٍ - وَهِيَ مِمَّنْ قَدِمَ مَعَنَا - عَلَى حَفْصَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم زَائِرَةً وَقَدْ كَانَتْ هَاجَرَتْ إِلَى النَّجَاشِيِّ فِيمَنْ هَاجَرَ إِلَيْهِ فَدَخَلَ عُمَرُ عَلَى حَفْصَةَ وَأَسْمَاءُ عِنْدَهَا فَقَالَ عُمَرُ حِينَ رَأَى أَسْمَاءَ مَنْ هَذِهِ قَالَتْ أَسْمَاءُ بِنْتُ عُمَيْسٍ ‏.‏ قَالَ عُمَرُ الْحَبَشِيَّةُ هَذِهِ الْبَحْرِيَّةُ هَذِهِ فَقَالَتْ أَسْمَاءُ نَعَمْ ‏.‏ فَقَالَ عُمَرُ سَبَقْنَاكُمْ بِالْهِجْرَةِ فَنَحْنُ أَحَقُّ بِرَسُولِ اللَّهِ صلى الله عليه وسلم مِنْكُمْ ‏.‏ فَغَضِبَتْ وَقَالَتْ كَلِمَةً كَذَبْتَ يَا عُمَرُ كَلاَّ وَاللَّهِ كُنْتُمْ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يُطْعِمُ جَائِعَكُمْ وَيَعِظُ جَاهِلَكُمْ وَكُنَّا فِي دَارِ أَوْ فِي أَرْضِ الْبُعَدَاءِ الْبُغَضَاءِ فِي الْحَبَشَةِ وَذَلِكَ فِي اللَّهِ وَفِي رَسُولِهِ وَايْمُ اللَّهِ لاَ أَطْعَمُ طَعَامًا وَلاَ أَشْرَبُ شَرَابًا حَتَّى أَذْكُرَ مَا قُلْتَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَنَحْنُ كُنَّا نُؤْذَى وَنُخَافُ وَسَأَذْكُرُ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَأَسْأَلُهُ وَوَاللَّهِ لاَ أَكْذِبُ وَلاَ أَزِيغُ وَلاَ أَزِيدُ عَلَى ذَلِكَ ‏.‏ قَالَ فَلَمَّا جَاءَ النَّبِيُّ صلى الله عليه وسلم قَالَتْ يَا نَبِيَّ اللَّهِ إِنَّ عُمَرَ قَالَ كَذَا وَكَذَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ بِأَحَقَّ بِي مِنْكُمْ وَلَهُ وَلأَصْحَابِهِ هِجْرَةٌ وَاحِدَةٌ وَلَكُمْ أَنْتُمْ أَهْلَ السَّفِينَةِ هِجْرَتَانِ ‏"‏ ‏.‏ قَالَتْ فَلَقَدْ رَأَيْتُ أَبَا مُوسَى وَأَصْحَابَ السَّفِينَةِ يَأْتُونِي أَرْسَالاً يَسْأَلُونِي عَنْ هَذَا الْحَدِيثِ مَا مِنَ الدُّنْيَا شَىْءٌ هُمْ بِهِ أَفْرَحُ وَلاَ أَعْظَمُ فِي أَنْفُسِهِمْ مِمَّا قَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو بُرْدَةَ فَقَالَتْ أَسْمَاءُ فَلَقَدْ رَأَيْتُ أَبَا مُوسَى وَإِنَّهُ لَيَسْتَعِيدُ هَذَا الْحَدِيثَ مِنِّي ‏.‏\hadithno{6410}\hadithtrans{Abu Musa reported:We were in Yemen when we heard of the migration of Allah's Messenger (ﷺ). We also set out as immigrants to him. And I was accompanied by two brothers of mine, I being the youngest of them; one of them was Abu Burda and the other one was Abu Ruhm, and there were some other persons with them. Some say they were fifty-three or fifty-two persons of my tribe. We embarked upon a boat, and the boat sailed away to the Negus of Abyssinia. There we met Ja'far b. Abu Talib and his companions. Ja'far said: Allall's Messenger (ﷺ) has sent us here and has commanded us to stay here and you should also stay with us. So we stayed with him and we came back (to Medina) and met Allah's Messenger (ﷺ) when Khaibar had been conquered. He (the Holy Prophet) allocated a share to us and in the ordinary course he did not allocate the share to one who had been absent on the occasion of the conquest of Khaibar but conferred (a share) upon him only who had been present there with him. He, however, made an exception for the people of the boat, viz. for Ja'far and his companions. He allocated a share to them, and some persons from amongst the people said to us, viz. the people of the boat: We have preceded you in migration. Asma' bint 'Umais who had migrated to Abyssinia and had come back along with them (along with immigrants) visited Hafsa, the wife of Allah's Apostle (ﷺ). (Accordingly), Umar had been sitting with her (Hafsa). As 'Umar saw Asma, he said: Who is she? She (Hafsa) said: She is Asma, daughter of 'Umais. He said: She is an Abyssinian and a sea-woman. Asma said: Yes, it is so. Thereupon 'Umar said: We preceded you in migration and so we have more right to Allah's Messenger (ﷺ) as compared with you. At this she felt annoyed and said: 'Umar, you are not stating the fact; by Allah, you had the privilege of being in the company of the Messenger (ﷺ) who fed the hungry among you and instructed the ignorant amongst you, whereas we had been far (from here) in the land of Abyssinia amongst the enemies and that was all for Allah and Allah's Messenger (ﷺ) and, by Allah, I would never take food nor take water unless I make a mention to Allah's Messenger (ﷺ) of what you have said. We remained in that country in constant trouble and dread and I shall talk about it to Allah's Messenger (way peace be upon him) and ask him (about it). By Allah, I shall not tell a lie and deviate (from the truth) and add anything to that. So, when Allah's Apostle (ﷺ) came, she said: Allah's Apostle, 'Umar says so and so. Upon this Allah's Messenger (ﷺ) said: His right is not more than yours, for him and his companions there is one migration, but for you, i. e. for the people of the boat, there are two migrations. She said: I saw Abu Musa and the people of the boat coming to me in groups and asking me about this hadith, because there was nothing more pleasing and more significant for them than this. Abu Burda reported that Asma said: I saw Abu Musa, asking me to repeat this hadith to him again and again}}
\hadithdefcmd{muslim}{6414}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ اغْفِرْ لِلأَنْصَارِ وَلأَبْنَاءِ الأَنْصَارِ وَأَبْنَاءِ أَبْنَاءِ الأَنْصَارِ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6414}\hadithtrans{Zaid b. Arqam reported that Allah's Messenger (ﷺ) said:O Allah,, grant forgiveness to the Ansar, the offspring of the Ansar and the offspring of the offspring of the Ansar. This hadith has been narrated on the authority of Shulba with the same chain of transmitters}}
\hadithdefcmd{muslim}{6415}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ اغْفِرْ لِلأَنْصَارِ وَلأَبْنَاءِ الأَنْصَارِ وَأَبْنَاءِ أَبْنَاءِ الأَنْصَارِ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6415}\hadithtrans{Zaid b. Arqam reported that Allah's Messenger (ﷺ) said:O Allah,, grant forgiveness to the Ansar, the offspring of the Ansar and the offspring of the offspring of the Ansar. This hadith has been narrated on the authority of Shulba with the same chain of transmitters}}
\hadithdefcmd{muslim}{6505}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ حَبِيبٍ، سَمِعْتُ أَبَا الْعَبَّاسِ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ، يَقُولُ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏ فَذَكَرَ بِمِثْلِهِ ‏.‏ قَالَ مُسْلِمٌ أَبُو الْعَبَّاسِ اسْمُهُ السَّائِبُ بْنُ فَرُّوخَ الْمَكِّيُّ ‏.‏ حَدَّثَنَا أَبُو كُرَيْبٍ، أَخْبَرَنَا ابْنُ بِشْرٍ، عَنْ مِسْعَرٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، عَنْ أَبِي إِسْحَاقَ، ح وَحَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، الْجُعْفِيُّ عَنْ زَائِدَةَ، كِلاَهُمَا عَنِ الأَعْمَشِ، جَمِيعًا عَنْ حَبِيبٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6505}\hadithtrans{This hadith has been narrated on the authority of Habib with the several chains of transmitters}}
\hadithdefcmd{muslim}{6506}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ حَبِيبٍ، سَمِعْتُ أَبَا الْعَبَّاسِ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ، يَقُولُ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏ فَذَكَرَ بِمِثْلِهِ ‏.‏ قَالَ مُسْلِمٌ أَبُو الْعَبَّاسِ اسْمُهُ السَّائِبُ بْنُ فَرُّوخَ الْمَكِّيُّ ‏.‏ حَدَّثَنَا أَبُو كُرَيْبٍ، أَخْبَرَنَا ابْنُ بِشْرٍ، عَنْ مِسْعَرٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، عَنْ أَبِي إِسْحَاقَ، ح وَحَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، الْجُعْفِيُّ عَنْ زَائِدَةَ، كِلاَهُمَا عَنِ الأَعْمَشِ، جَمِيعًا عَنْ حَبِيبٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6506}\hadithtrans{This hadith has been narrated on the authority of Habib with the several chains of transmitters}}
\hadithdefcmd{muslim}{6527}{\hadithno{6527}\hadithtrans{}}
\hadithdefcmd{muslim}{6528}{\hadithno{6528}\hadithtrans{}}
\hadithdefcmd{muslim}{6529}{\hadithno{6529}\hadithtrans{}}
\hadithdefcmd{muslim}{6544}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ تُفْتَحُ أَبْوَابُ الْجَنَّةِ يَوْمَ الاِثْنَيْنِ وَيَوْمَ الْخَمِيسِ فَيُغْفَرُ لِكُلِّ عَبْدٍ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا إِلاَّ رَجُلاً كَانَتْ بَيْنَهُ وَبَيْنَ أَخِيهِ شَحْنَاءُ فَيُقَالُ أَنْظِرُوا هَذَيْنِ حَتَّى يَصْطَلِحَا أَنْظِرُوا هَذَيْنِ حَتَّى يَصْطَلِحَا أَنْظِرُوا هَذَيْنِ حَتَّى يَصْطَلِحَا ‏"‏ ‏.‏ حَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَحْمَدُ بْنُ عَبْدَةَ، الضَّبِّيُّ عَنْ عَبْدِ الْعَزِيزِ الدَّرَاوَرْدِيِّ، كِلاَهُمَا عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، بِإِسْنَادِ مَالِكٍ نَحْوَ حَدِيثِهِ غَيْرَ أَنَّ فِي حَدِيثِ الدَّرَاوَرْدِيِّ ‏"‏ إِلاَّ الْمُتَهَاجِرَيْنِ ‏"‏ ‏.‏ مِنْ رِوَايَةِ ابْنِ عَبْدَةَ وَقَالَ قُتَيْبَةُ ‏"‏ إِلاَّ الْمُهْتَجِرَيْنِ ‏"‏ ‏.‏\hadithno{6544}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The gates of Paradise are not opened but on two days, Monday and Thursday. and then every servant (of Allah) is granted pardon who does not associate anything with Allah except the person in whose (heart) there is rancour against his brother. And it would be said: Look towards both of them until there is reconciliation; look toward both of them until there is reconciliation; look towards both of them until there is reconciliation. This hadith has been narrated on the authority of Suhail who narrated it on the authority of his father with the chain of transmitters of MaIik, but with this variation of wording:, (Those would not be granted pardon) who bycott each other}}
\hadithdefcmd{muslim}{6545}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ تُفْتَحُ أَبْوَابُ الْجَنَّةِ يَوْمَ الاِثْنَيْنِ وَيَوْمَ الْخَمِيسِ فَيُغْفَرُ لِكُلِّ عَبْدٍ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا إِلاَّ رَجُلاً كَانَتْ بَيْنَهُ وَبَيْنَ أَخِيهِ شَحْنَاءُ فَيُقَالُ أَنْظِرُوا هَذَيْنِ حَتَّى يَصْطَلِحَا أَنْظِرُوا هَذَيْنِ حَتَّى يَصْطَلِحَا أَنْظِرُوا هَذَيْنِ حَتَّى يَصْطَلِحَا ‏"‏ ‏.‏ حَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَحْمَدُ بْنُ عَبْدَةَ، الضَّبِّيُّ عَنْ عَبْدِ الْعَزِيزِ الدَّرَاوَرْدِيِّ، كِلاَهُمَا عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، بِإِسْنَادِ مَالِكٍ نَحْوَ حَدِيثِهِ غَيْرَ أَنَّ فِي حَدِيثِ الدَّرَاوَرْدِيِّ ‏"‏ إِلاَّ الْمُتَهَاجِرَيْنِ ‏"‏ ‏.‏ مِنْ رِوَايَةِ ابْنِ عَبْدَةَ وَقَالَ قُتَيْبَةُ ‏"‏ إِلاَّ الْمُهْتَجِرَيْنِ ‏"‏ ‏.‏\hadithno{6545}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The gates of Paradise are not opened but on two days, Monday and Thursday. and then every servant (of Allah) is granted pardon who does not associate anything with Allah except the person in whose (heart) there is rancour against his brother. And it would be said: Look towards both of them until there is reconciliation; look toward both of them until there is reconciliation; look towards both of them until there is reconciliation. This hadith has been narrated on the authority of Suhail who narrated it on the authority of his father with the chain of transmitters of MaIik, but with this variation of wording:, (Those would not be granted pardon) who bycott each other}}
\hadithdefcmd{muslim}{6625}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، وَحَجَّاجُ بْنُ الشَّاعِرِ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّمَا أَنَا بَشَرٌ وَإِنِّي اشْتَرَطْتُ عَلَى رَبِّي عَزَّ وَجَلَّ أَىُّ عَبْدٍ مِنَ الْمُسْلِمِينَ سَبَبْتُهُ أَوْ شَتَمْتُهُ أَنْ يَكُونَ ذَلِكَ لَهُ زَكَاةً وَأَجْرًا ‏"‏ ‏.‏ حَدَّثَنِيهِ ابْنُ أَبِي خَلَفٍ، حَدَّثَنَا رَوْحٌ، ح وَحَدَّثَنَاهُ عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا أَبُو عَاصِمٍ، جَمِيعًا عَنِ ابْنِ جُرَيْجٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6625}\hadithtrans{Jabir b. Abdullah reported Allah's Messenger (ﷺ) as saying:I am a human being and I have made this term with my Lord, the Exalted and Glorious: For any servant amongst Muslims whom I curse or scold, make that a source of purity and reward. This hadith has been narrated on the authority of Ibn Juraij with the same chain of transmitters}}
\hadithdefcmd{muslim}{6626}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، وَحَجَّاجُ بْنُ الشَّاعِرِ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّمَا أَنَا بَشَرٌ وَإِنِّي اشْتَرَطْتُ عَلَى رَبِّي عَزَّ وَجَلَّ أَىُّ عَبْدٍ مِنَ الْمُسْلِمِينَ سَبَبْتُهُ أَوْ شَتَمْتُهُ أَنْ يَكُونَ ذَلِكَ لَهُ زَكَاةً وَأَجْرًا ‏"‏ ‏.‏ حَدَّثَنِيهِ ابْنُ أَبِي خَلَفٍ، حَدَّثَنَا رَوْحٌ، ح وَحَدَّثَنَاهُ عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا أَبُو عَاصِمٍ، جَمِيعًا عَنِ ابْنِ جُرَيْجٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6626}\hadithtrans{Jabir b. Abdullah reported Allah's Messenger (ﷺ) as saying:I am a human being and I have made this term with my Lord, the Exalted and Glorious: For any servant amongst Muslims whom I curse or scold, make that a source of purity and reward. This hadith has been narrated on the authority of Ibn Juraij with the same chain of transmitters}}
\hadithdefcmd{muslim}{6701}{\hadithno{6701}\hadithtrans{}}
\hadithdefcmd{muslim}{6702}{\hadithno{6702}\hadithtrans{}}
\hadithdefcmd{muslim}{6711}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ عَبْدِ، اللَّهِ بْنِ نُمَيْرٍ وَابْنُ أَبِي عُمَرَ - وَاللَّفْظُ لِزُهَيْرٍ - قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ مَتَى السَّاعَةُ قَالَ ‏"‏ وَمَا أَعْدَدْتَ لَهَا ‏"‏ ‏.‏ فَلَمْ يَذْكُرْ كَبِيرًا ‏.‏ قَالَ وَلَكِنِّي أُحِبُّ اللَّهَ وَرَسُولَهُ ‏.‏ قَالَ ‏"‏ فَأَنْتَ مَعَ مَنْ أَحْبَبْتَ ‏"‏ ‏.‏ حَدَّثَنِيهِ مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَجُلاً، مِنَ الأَعْرَابِ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ مَا أَعْدَدْتُ لَهَا مِنْ كَثِيرٍ أَحْمَدُ عَلَيْهِ نَفْسِي ‏.‏\hadithno{6711}\hadithtrans{Anas reported that a person said to Allah's Messenger (ﷺ):When would be the Last Hour? He (the Holy Prophet) said: What preparation have you made for that? And he gave no details, but said: I love Allah and His Messenger. Thereupon he (the Holy Prophet) said: You would be along with one whom you love. Anas b. Malik reported through another chain of transmitters that a desert Arab came to Allah's Messenger (may peace be upon, him), the rest of the hadith is the same but with this variation that he said: I have not made much preparations which merit appreciation for myself}}
\hadithdefcmd{muslim}{6712}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ عَبْدِ، اللَّهِ بْنِ نُمَيْرٍ وَابْنُ أَبِي عُمَرَ - وَاللَّفْظُ لِزُهَيْرٍ - قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ مَتَى السَّاعَةُ قَالَ ‏"‏ وَمَا أَعْدَدْتَ لَهَا ‏"‏ ‏.‏ فَلَمْ يَذْكُرْ كَبِيرًا ‏.‏ قَالَ وَلَكِنِّي أُحِبُّ اللَّهَ وَرَسُولَهُ ‏.‏ قَالَ ‏"‏ فَأَنْتَ مَعَ مَنْ أَحْبَبْتَ ‏"‏ ‏.‏ حَدَّثَنِيهِ مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَجُلاً، مِنَ الأَعْرَابِ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ مَا أَعْدَدْتُ لَهَا مِنْ كَثِيرٍ أَحْمَدُ عَلَيْهِ نَفْسِي ‏.‏\hadithno{6712}\hadithtrans{Anas reported that a person said to Allah's Messenger (ﷺ):When would be the Last Hour? He (the Holy Prophet) said: What preparation have you made for that? And he gave no details, but said: I love Allah and His Messenger. Thereupon he (the Holy Prophet) said: You would be along with one whom you love. Anas b. Malik reported through another chain of transmitters that a desert Arab came to Allah's Messenger (may peace be upon, him), the rest of the hadith is the same but with this variation that he said: I have not made much preparations which merit appreciation for myself}}
\hadithdefcmd{muslim}{6792}{\hadithno{6792}\hadithtrans{}}
\hadithdefcmd{muslim}{6844}{\hadithno{6844}\hadithtrans{}}
\hadithdefcmd{muslim}{6845}{\hadithno{6845}\hadithtrans{}}
\hadithdefcmd{muslim}{6855}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ أَبَا إِسْحَاقَ، يُحَدِّثُ عَنِ الأَغَرِّ أَبِي مُسْلِمٍ، أَنَّهُ قَالَ أَشْهَدُ عَلَى أَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ الْخُدْرِيِّ أَنَّهُمَا شَهِدَا عَلَى النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لاَ يَقْعُدُ قَوْمٌ يَذْكُرُونَ اللَّهَ عَزَّ وَجَلَّ إِلاَّ حَفَّتْهُمُ الْمَلاَئِكَةُ وَغَشِيَتْهُمُ الرَّحْمَةُ وَنَزَلَتْ عَلَيْهِمُ السَّكِينَةُ وَذَكَرَهُمُ اللَّهُ فِيمَنْ عِنْدَهُ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا شُعْبَةُ، فِي هَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{6855}\hadithtrans{(Agharr Abi Muslim reported:I bear witness to the fact that both Abu Huraira and Abu Sa'id Khudri were present when Allah's Messenger may peace be upon him) said: The people do not sit but they are surrounded by angels and covered by Mercy, and there descends upon them tranquillity as they remember Allah, and Allah makes a mention of them to those who are near Him. This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{6856}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ أَبَا إِسْحَاقَ، يُحَدِّثُ عَنِ الأَغَرِّ أَبِي مُسْلِمٍ، أَنَّهُ قَالَ أَشْهَدُ عَلَى أَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ الْخُدْرِيِّ أَنَّهُمَا شَهِدَا عَلَى النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لاَ يَقْعُدُ قَوْمٌ يَذْكُرُونَ اللَّهَ عَزَّ وَجَلَّ إِلاَّ حَفَّتْهُمُ الْمَلاَئِكَةُ وَغَشِيَتْهُمُ الرَّحْمَةُ وَنَزَلَتْ عَلَيْهِمُ السَّكِينَةُ وَذَكَرَهُمُ اللَّهُ فِيمَنْ عِنْدَهُ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا شُعْبَةُ، فِي هَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{6856}\hadithtrans{(Agharr Abi Muslim reported:I bear witness to the fact that both Abu Huraira and Abu Sa'id Khudri were present when Allah's Messenger may peace be upon him) said: The people do not sit but they are surrounded by angels and covered by Mercy, and there descends upon them tranquillity as they remember Allah, and Allah makes a mention of them to those who are near Him. This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{6879}{وَحَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، وَأَبُو الطَّاهِرِ، كِلاَهُمَا عَنِ ابْنِ وَهْبٍ، - وَاللَّفْظُ لِهَارُونَ - حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ وَأَخْبَرَنَا عَمْرٌو، - وَهُوَ ابْنُ الْحَارِثِ - أَنَّ يَزِيدَ بْنَ أَبِي، حَبِيبٍ وَالْحَارِثَ بْنَ يَعْقُوبَ حَدَّثَاهُ عَنْ يَعْقُوبَ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ خَوْلَةَ بِنْتِ حَكِيمٍ السُّلَمِيَّةِ، أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِذَا نَزَلَ أَحَدُكُمْ مَنْزِلاً فَلْيَقُلْ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّاتِ مِنْ شَرِّ مَا خَلَقَ ‏.‏ فَإِنَّهُ لاَ يَضُرُّهُ شَىْءٌ حَتَّى يَرْتَحِلَ مِنْهُ ‏"‏ ‏.‏ قَالَ يَعْقُوبُ وَقَالَ الْقَعْقَاعُ بْنُ حَكِيمٍ عَنْ ذَكْوَانَ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ مَا لَقِيتُ مِنْ عَقْرَبٍ لَدَغَتْنِي الْبَارِحَةَ قَالَ ‏"‏ أَمَا لَوْ قُلْتَ حِينَ أَمْسَيْتَ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّاتِ مِنْ شَرِّ مَا خَلَقَ لَمْ تَضُرُّكَ ‏"‏ ‏.‏\hadithno{6879}\hadithtrans{Khaula bint Hakim Sulamiyya reported:I heard Allah's Messenger (ﷺ) as saying: When any one of you stays at a place, he should say:" I seek refuge in the Perfect Word of Allah from the evil of that He created." Nothing would then do him any harm until he moves from that place. Abu Huraira reported that a person came to Allah's Messenger (ﷺ) and said:" Allah's Messenger, I was stung by a scorpion during the night. Thereupon he said: Had you recited these words in the evening:" I seek refuge in the Perfect Word of Allah from the evil of what He created," it would not have done any harm to you}}
\hadithdefcmd{muslim}{6918}{حَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامَ الْعَيْشِيُّ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا رَوْحٌ، وَهُوَ ابْنُ الْقَاسِمِ عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ فَاطِمَةَ، أَتَتِ النَّبِيَّ صلى الله عليه وسلم تَسْأَلُهُ خَادِمًا وَشَكَتِ الْعَمَلَ فَقَالَ ‏"‏ مَا أَلْفَيْتِيهِ عِنْدَنَا ‏"‏ ‏.‏ قَالَ ‏"‏ أَلاَ أَدُلُّكِ عَلَى مَا هُوَ خَيْرٌ لَكِ مِنْ خَادِمٍ تُسَبِّحِينَ ثَلاَثًا وَثَلاَثِينَ وَتَحْمَدِينَ ثَلاَثًا وَثَلاَثِينَ وَتُكَبِّرِينَ أَرْبَعًا وَثَلاَثِينَ حِينَ تَأْخُذِينَ مَضْجَعَكِ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا حَبَّانُ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا سُهَيْلٌ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6918}\hadithtrans{Abu Huraira reported that Fatima came to Allah's Apostle (ﷺ) and asked for a servant and told him of the hardship of household work. He said:You would not be able to get a servant from us. May I not direct you to what is better than the servant for you? Recite Subhaana Allah thirty-three times, al- Hamdu li-Allah thirty-three times and Allah-o-Akbar thirty-four times as you go to bed. This hadith has been narrated on the authority of Suhail with the same chain of transmitters}}
\hadithdefcmd{muslim}{6919}{حَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامَ الْعَيْشِيُّ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا رَوْحٌ، وَهُوَ ابْنُ الْقَاسِمِ عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ فَاطِمَةَ، أَتَتِ النَّبِيَّ صلى الله عليه وسلم تَسْأَلُهُ خَادِمًا وَشَكَتِ الْعَمَلَ فَقَالَ ‏"‏ مَا أَلْفَيْتِيهِ عِنْدَنَا ‏"‏ ‏.‏ قَالَ ‏"‏ أَلاَ أَدُلُّكِ عَلَى مَا هُوَ خَيْرٌ لَكِ مِنْ خَادِمٍ تُسَبِّحِينَ ثَلاَثًا وَثَلاَثِينَ وَتَحْمَدِينَ ثَلاَثًا وَثَلاَثِينَ وَتُكَبِّرِينَ أَرْبَعًا وَثَلاَثِينَ حِينَ تَأْخُذِينَ مَضْجَعَكِ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا حَبَّانُ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا سُهَيْلٌ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6919}\hadithtrans{Abu Huraira reported that Fatima came to Allah's Apostle (ﷺ) and asked for a servant and told him of the hardship of household work. He said:You would not be able to get a servant from us. May I not direct you to what is better than the servant for you? Recite Subhaana Allah thirty-three times, al- Hamdu li-Allah thirty-three times and Allah-o-Akbar thirty-four times as you go to bed. This hadith has been narrated on the authority of Suhail with the same chain of transmitters}}
\hadithdefcmd{muslim}{6929}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي، سُلَيْمَانَ عَنْ أَبِي الزُّبَيْرِ، عَنْ صَفْوَانَ، - وَهُوَ ابْنُ عَبْدِ اللَّهِ بْنِ صَفْوَانَ - وَكَانَتْ تَحْتَهُ الدَّرْدَاءُ قَالَ قَدِمْتُ الشَّامَ فَأَتَيْتُ أَبَا الدَّرْدَاءِ فِي مَنْزِلِهِ فَلَمْ أَجِدْهُ وَوَجَدْتُ أُمَّ الدَّرْدَاءِ فَقَالَتْ أَتُرِيدُ الْحَجَّ الْعَامَ فَقُلْتُ نَعَمْ ‏.‏ قَالَتْ فَادْعُ اللَّهَ لَنَا بِخَيْرٍ فَإِنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ دَعْوَةُ الْمَرْءِ الْمُسْلِمِ لأَخِيهِ بِظَهْرِ الْغَيْبِ مُسْتَجَابَةٌ عِنْدَ رَأْسِهِ مَلَكٌ مُوَكَّلٌ كُلَّمَا دَعَا لأَخِيهِ بِخَيْرٍ قَالَ الْمَلَكُ الْمُوَكَّلُ بِهِ آمِينَ وَلَكَ بِمِثْلٍ ‏"‏ ‏.‏ قَالَ فَخَرَجْتُ إِلَى السُّوقِ فَلَقِيتُ أَبَا الدَّرْدَاءِ فَقَالَ لِي مِثْلَ ذَلِكَ يَرْوِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{6929}\hadithtrans{Safwan (and he was Ibn 'Abdullah b. Safwan, and he had been married to Umm Darda') reported:I visited Abu Darda's house in Syria. I did not find him there but Umm Darda' (was present at the house). She said: Do you intend to perform Hajj during this year? I said: Yes. She said: Do supplicate Allah for blessings upon us, for Allah's Apostle (may peace be upon hiin) used to say: The supplication of a Muslim for his brother at his back (in his absence) is responded so long as he makes a supplica- tion for blessings for his brother and the commissioned Angel says: Amen, and says: May it be for you too I I went to the bazar and met Abfi Dardi' and he narrated like this from Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{6961}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَلَّهُ أَشَدُّ فَرَحًا بِتَوْبَةِ عَبْدِهِ مِنْ أَحَدِكُمْ إِذَا اسْتَيْقَظَ عَلَى بَعِيرِهِ قَدْ أَضَلَّهُ بِأَرْضِ فَلاَةٍ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ أَحْمَدُ الدَّارِمِيُّ، حَدَّثَنَا حَبَّانُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسُ بْنُ، مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{6961}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said:Allah is more pleased with the repentance of His servant than if one of you gets up and he finds his camel missing in a waterless desert (and then he accidentally finds it). This hadith has been narrated on the authority of Anas b. Malik through another chain of transmitters}}
\hadithdefcmd{muslim}{6962}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَلَّهُ أَشَدُّ فَرَحًا بِتَوْبَةِ عَبْدِهِ مِنْ أَحَدِكُمْ إِذَا اسْتَيْقَظَ عَلَى بَعِيرِهِ قَدْ أَضَلَّهُ بِأَرْضِ فَلاَةٍ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ أَحْمَدُ الدَّارِمِيُّ، حَدَّثَنَا حَبَّانُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسُ بْنُ، مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{6962}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said:Allah is more pleased with the repentance of His servant than if one of you gets up and he finds his camel missing in a waterless desert (and then he accidentally finds it). This hadith has been narrated on the authority of Anas b. Malik through another chain of transmitters}}
\hadithdefcmd{muslim}{6981}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، قَالَ قَالَ لِيَ الزُّهْرِيُّ أَلاَ أُحَدِّثُكَ بِحَدِيثَيْنِ عَجِيبَيْنِ قَالَ الزُّهْرِيُّ أَخْبَرَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أَسْرَفَ رَجُلٌ عَلَى نَفْسِهِ فَلَمَّا حَضَرَهُ الْمَوْتُ أَوْصَى بَنِيهِ فَقَالَ إِذَا أَنَا مُتُّ فَأَحْرِقُونِي ثُمَّ اسْحَقُونِي ثُمَّ اذْرُونِي فِي الرِّيحِ فِي الْبَحْرِ فَوَاللَّهِ لَئِنْ قَدَرَ عَلَىَّ رَبِّي لَيُعَذِّبُنِي عَذَابًا مَا عَذَّبَهُ بِهِ أَحَدًا ‏.‏ قَالَ فَفَعَلُوا ذَلِكَ بِهِ فَقَالَ لِلأَرْضِ أَدِّي مَا أَخَذْتِ ‏.‏ فَإِذَا هُوَ قَائِمٌ فَقَالَ لَهُ مَا حَمَلَكَ عَلَى مَا صَنَعْتَ فَقَالَ خَشْيَتُكَ يَا رَبِّ - أَوْ قَالَ - مَخَافَتُكَ ‏.‏ فَغَفَرَ لَهُ بِذَلِكَ ‏"‏ ‏.‏ قَالَ الزُّهْرِيُّ وَحَدَّثَنِي حُمَيْدٌ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ دَخَلَتِ امْرَأَةٌ النَّارَ فِي هِرَّةٍ رَبَطَتْهَا فَلاَ هِيَ أَطْعَمَتْهَا وَلاَ هِيَ أَرْسَلَتْهَا تَأْكُلُ مِنْ خَشَاشِ الأَرْضِ حَتَّى مَاتَتْ هَزْلاً ‏"‏ ‏.‏ قَالَ الزُّهْرِيُّ ذَلِكَ لِئَلاَّ يَتَّكِلَ رَجُلٌ وَلاَ يَيْأَسَ رَجُلٌ ‏.‏\hadithno{6981}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying that a person committed sin beyond measure and when he was going to die, he left this will:(When I die), bum my dead body and then cast them (the ashes) to the wind and in the ocean. By Allah, if my Lord takes hold of me, He would torment me as He has not tormented anyone else. They did as he had asked them to do. He (the Lord) said to the earth: Return what you have taken. And he was thus restored to his (original form). He (Allah) said to him: What prompted you to do this? He said: My Lord, it was Thine fear or Thine awe, and Allah pardoned him because of this. Abu Huraira reported Allah's Messenger (ﷺ) as saying that a woman was thrown into Hell-Fire because of a cat whom she had tied and did not provide it with food. nor did she set it free to eat vermin of the earth until it died emaciated. Az-Zuhri said: (These two ahadith) show that a person should neither feel confident (of getting into Paradise) because of his deeds, nor should he lose (all hopes) of getting into Paradise}}
\hadithdefcmd{muslim}{6989}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ أَبَا عُبَيْدَةَ، يُحَدِّثُ عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَبْسُطُ يَدَهُ بِاللَّيْلِ لِيَتُوبَ مُسِيءُ النَّهَارِ وَيَبْسُطُ يَدَهُ بِالنَّهَارِ لِيَتُوبَ مُسِيءُ اللَّيْلِ حَتَّى تَطْلُعَ الشَّمْسُ مِنْ مَغْرِبِهَا ‏"‏ ‏.‏ وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{6989}\hadithtrans{Abu Musa reported Allah's Messenger (ﷺ) as saying that Allah, the Exalted and Glorious, Stretches out His Hand during the night so that the people may repent for the fault committed from dawn till dusk and He stretches out His Hand during the day so that the people may repent for the fault committed from dusk to dawn. (He would accept repentance) before the sun rises in the west (before the Day of Resurrection). A hadith like this has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{6990}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ أَبَا عُبَيْدَةَ، يُحَدِّثُ عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَبْسُطُ يَدَهُ بِاللَّيْلِ لِيَتُوبَ مُسِيءُ النَّهَارِ وَيَبْسُطُ يَدَهُ بِالنَّهَارِ لِيَتُوبَ مُسِيءُ اللَّيْلِ حَتَّى تَطْلُعَ الشَّمْسُ مِنْ مَغْرِبِهَا ‏"‏ ‏.‏ وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{6990}\hadithtrans{Abu Musa reported Allah's Messenger (ﷺ) as saying that Allah, the Exalted and Glorious, Stretches out His Hand during the night so that the people may repent for the fault committed from dawn till dusk and He stretches out His Hand during the day so that the people may repent for the fault committed from dusk to dawn. (He would accept repentance) before the sun rises in the west (before the Day of Resurrection). A hadith like this has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{7016}{\hadithno{7016}\hadithtrans{}}
\hadithdefcmd{muslim}{7017}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ سَرْحٍ مَوْلَى بَنِي أُمَيَّةَ أَخْبَرَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ ثُمَّ غَزَا رَسُولُ اللَّهِ صلى الله عليه وسلم غَزْوَةَ تَبُوكَ وَهُوَ يُرِيدُ الرُّومَ وَنَصَارَى الْعَرَبِ بِالشَّامِ ‏.‏ قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبٍ كَانَ قَائِدَ كَعْبٍ مِنْ بَنِيهِ حِينَ عَمِيَ قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ يُحَدِّثُ حَدِيثَهُ حِينَ تَخَلَّفَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ قَالَ كَعْبُ بْنُ مَالِكٍ لَمْ أَتَخَلَّفْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةٍ غَزَاهَا قَطُّ إِلاَّ فِي غَزْوَةِ تَبُوكَ غَيْرَ أَنِّي قَدْ تَخَلَّفْتُ فِي غَزْوَةِ بَدْرٍ وَلَمْ يُعَاتِبْ أَحَدًا تَخَلَّفَ عَنْهُ إِنَّمَا خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْمُسْلِمُونَ يُرِيدُونَ عِيرَ قُرَيْشٍ حَتَّى جَمَعَ اللَّهُ بَيْنَهُمْ وَبَيْنَ عَدُوِّهُمْ عَلَى غَيْرِ مِيعَادٍ وَلَقَدْ شَهِدْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيْلَةَ الْعَقَبَةِ حِينَ تَوَاثَقْنَا عَلَى الإِسْلاَمِ وَمَا أُحِبُّ أَنَّ لِي بِهَا مَشْهَدَ بَدْرٍ وَإِنْ كَانَتْ بَدْرٌ أَذْكَرَ فِي النَّاسِ مِنْهَا وَكَانَ مِنْ خَبَرِي حِينَ تَخَلَّفْتُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ أَنِّي لَمْ أَكُنْ قَطُّ أَقْوَى وَلاَ أَيْسَرَ مِنِّي حِينَ تَخَلَّفْتُ عَنْهُ فِي تِلْكَ الْغَزْوَةِ وَاللَّهِ مَا جَمَعْتُ قَبْلَهَا رَاحِلَتَيْنِ قَطُّ حَتَّى جَمَعْتُهُمَا فِي تِلْكَ الْغَزْوَةِ فَغَزَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَرٍّ شَدِيدٍ وَاسْتَقْبَلَ سَفَرًا بَعِيدًا وَمَفَازًا وَاسْتَقْبَلَ عَدُوًّا كَثِيرًا فَجَلاَ لِلْمُسْلِمِينَ أَمْرَهُمْ لِيَتَأَهَّبُوا أُهْبَةَ غَزْوِهِمْ فَأَخْبَرَهُمْ بِوَجْهِهِمُ الَّذِي يُرِيدُ وَالْمُسْلِمُونَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم كَثِيرٌ وَلاَ يَجْمَعُهُمْ كِتَابُ حَافِظٍ - يُرِيدُ بِذَلِكَ الدِّيوَانَ - قَالَ كَعْبٌ فَقَلَّ رَجُلٌ يُرِيدُ أَنْ يَتَغَيَّبَ يَظُنُّ أَنَّ ذَلِكَ سَيَخْفَى لَهُ مَا لَمْ يَنْزِلْ فِيهِ وَحْىٌ مِنَ اللَّهِ عَزَّ وَجَلَّ وَغَزَا رَسُولُ اللَّهِ صلى الله عليه وسلم تِلْكَ الْغَزْوَةَ حِينَ طَابَتِ الثِّمَارُ وَالظِّلاَلُ فَأَنَا إِلَيْهَا أَصْعَرُ فَتَجَهَّزَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْمُسْلِمُونَ مَعَهُ وَطَفِقْتُ أَغْدُو لِكَىْ أَتَجَهَّزَ مَعَهُمْ فَأَرْجِعُ وَلَمْ أَقْضِ شَيْئًا ‏.‏ وَأَقُولُ فِي نَفْسِي أَنَا قَادِرٌ عَلَى ذَلِكَ إِذَا أَرَدْتُ ‏.‏ فَلَمْ يَزَلْ ذَلِكَ يَتَمَادَى بِي حَتَّى اسْتَمَرَّ بِالنَّاسِ الْجِدُّ فَأَصْبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم غَادِيًا وَالْمُسْلِمُونَ مَعَهُ وَلَمْ أَقْضِ مِنْ جَهَازِي شَيْئًا ثُمَّ غَدَوْتُ فَرَجَعْتُ وَلَمْ أَقْضِ شَيْئًا فَلَمْ يَزَلْ ذَلِكَ يَتَمَادَى بِي حَتَّى أَسْرَعُوا وَتَفَارَطَ الْغَزْوُ فَهَمَمْتُ أَنْ أَرْتَحِلَ فَأُدْرِكَهُمْ فَيَا لَيْتَنِي فَعَلْتُ ثُمَّ لَمْ يُقَدَّرْ ذَلِكَ لِي فَطَفِقْتُ إِذَا خَرَجْتُ فِي النَّاسِ بَعْدَ خُرُوجِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَحْزُنُنِي أَنِّي لاَ أَرَى لِي أُسْوَةً إِلاَّ رَجُلاً مَغْمُوصًا عَلَيْهِ فِي النِّفَاقِ أَوْ رَجُلاً مِمَّنْ عَذَرَ اللَّهُ مِنَ الضُّعَفَاءِ وَلَمْ يَذْكُرْنِي رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى بَلَغَ تَبُوكًا فَقَالَ وَهُوَ جَالِسٌ فِي الْقَوْمِ بِتَبُوكَ ‏"‏ مَا فَعَلَ كَعْبُ بْنُ مَالِكٍ ‏"‏ ‏.‏ قَالَ رَجُلٌ مِنْ بَنِي سَلِمَةَ يَا رَسُولَ اللَّهِ حَبَسَهُ بُرْدَاهُ وَالنَّظَرُ فِي عِطْفَيْهِ ‏.‏ فَقَالَ لَهُ مُعَاذُ بْنُ جَبَلٍ بِئْسَ مَا قُلْتَ وَاللَّهِ يَا رَسُولَ اللَّهِ مَا عَلِمْنَا عَلَيْهِ إِلاَّ خَيْرًا ‏.‏ فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَبَيْنَمَا هُوَ عَلَى ذَلِكَ رَأَى رَجُلاً مُبَيِّضًا يَزُولُ بِهِ السَّرَابُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُنْ أَبَا خَيْثَمَةَ ‏"‏ ‏.‏ فَإِذَا هُو أَبُو خَيْثَمَةَ الأَنْصَارِيُّ وَهُوَ الَّذِي تَصَدَّقَ بِصَاعِ التَّمْرِ حِينَ لَمَزَهُ الْمُنَافِقُونَ ‏.‏ فَقَالَ كَعْبُ بْنُ مَالِكٍ فَلَمَّا بَلَغَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ تَوَجَّهَ قَافِلاً مِنْ تَبُوكَ حَضَرَنِي بَثِّي فَطَفِقْتُ أَتَذَكَّرُ الْكَذِبَ وَأَقُولُ بِمَ أَخْرُجُ مِنْ سَخَطِهِ غَدًا وَأَسْتَعِينُ عَلَى ذَلِكَ كُلَّ ذِي رَأْىٍ مِنْ أَهْلِي فَلَمَّا قِيلَ لِي إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أَظَلَّ قَادِمًا زَاحَ عَنِّي الْبَاطِلُ حَتَّى عَرَفْتُ أَنِّي لَنْ أَنْجُوَ مِنْهُ بِشَىْءٍ أَبَدًا فَأَجْمَعْتُ صِدْقَهُ وَصَبَّحَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَادِمًا وَكَانَ إِذَا قَدِمَ مِنْ سَفَرٍ بَدَأَ بِالْمَسْجِدِ فَرَكَعَ فِيهِ رَكْعَتَيْنِ ثُمَّ جَلَسَ لِلنَّاسِ فَلَمَّا فَعَلَ ذَلِكَ جَاءَهُ الْمُخَلَّفُونَ فَطَفِقُوا يَعْتَذِرُونَ إِلَيْهِ وَيَحْلِفُونَ لَهُ وَكَانُوا بِضْعَةً وَثَمَانِينَ رَجُلاً فَقَبِلَ مِنْهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلاَنِيَتَهُمْ وَبَايَعَهُمْ وَاسْتَغْفَرَ لَهُمْ وَوَكَلَ سَرَائِرَهُمْ إِلَى اللَّهِ حَتَّى جِئْتُ فَلَمَّا سَلَّمْتُ تَبَسَّمَ تَبَسُّمَ الْمُغْضَبِ ثُمَّ قَالَ ‏"‏ تَعَالَ ‏"‏ ‏.‏ فَجِئْتُ أَمْشِي حَتَّى جَلَسْتُ بَيْنَ يَدَيْهِ فَقَالَ لِي ‏"‏ مَا خَلَّفَكَ ‏"‏ ‏.‏ أَلَمْ تَكُنْ قَدِ ابْتَعْتَ ظَهْرَكَ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي وَاللَّهِ لَوْ جَلَسْتُ عِنْدَ غَيْرِكَ مِنْ أَهْلِ الدُّنْيَا لَرَأَيْتُ أَنِّي سَأَخْرُجُ مِنْ سَخَطِهِ بِعُذْرٍ وَلَقَدْ أُعْطِيتُ جَدَلاً وَلَكِنِّي وَاللَّهِ لَقَدْ عَلِمْتُ لَئِنْ حَدَّثْتُكَ الْيَوْمَ حَدِيثَ كَذِبٍ تَرْضَى بِهِ عَنِّي لَيُوشِكَنَّ اللَّهُ أَنْ يُسْخِطَكَ عَلَىَّ وَلَئِنْ حَدَّثْتُكَ حَدِيثَ صِدْقٍ تَجِدُ عَلَىَّ فِيهِ إِنِّي لأَرْجُو فِيهِ عُقْبَى اللَّهِ وَاللَّهِ مَا كَانَ لِي عُذْرٌ وَاللَّهِ مَا كُنْتُ قَطُّ أَقْوَى وَلاَ أَيْسَرَ مِنِّي حِينَ تَخَلَّفْتُ عَنْكَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَّا هَذَا فَقَدْ صَدَقَ فَقُمْ حَتَّى يَقْضِيَ اللَّهُ فِيكَ ‏"‏ ‏.‏ فَقُمْتُ وَثَارَ رِجَالٌ مِنْ بَنِي سَلِمَةَ فَاتَّبَعُونِي فَقَالُوا لِي وَاللَّهِ مَا عَلِمْنَاكَ أَذْنَبْتَ ذَنْبًا قَبْلَ هَذَا لَقَدْ عَجَزْتَ فِي أَنْ لاَ تَكُونَ اعْتَذَرْتَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِمَا اعْتَذَرَ بِهِ إِلَيْهِ الْمُخَلَّفُونَ فَقَدْ كَانَ كَافِيَكَ ذَنْبَكَ اسْتِغْفَارُ رَسُولِ اللَّهِ صلى الله عليه وسلم لَكَ ‏.‏ قَالَ فَوَاللَّهِ مَا زَالُوا يُؤَنِّبُونَنِي حَتَّى أَرَدْتُ أَنْ أَرْجِعَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأُكَذِّبَ نَفْسِي - قَالَ - ثُمَّ قُلْتُ لَهُمْ هَلْ لَقِيَ هَذَا مَعِي مِنْ أَحَدٍ قَالُوا نَعَمْ لَقِيَهُ مَعَكَ رَجُلاَنِ قَالاَ مِثْلَ مَا قُلْتَ فَقِيلَ لَهُمَا مِثْلُ مَا قِيلَ لَكَ - قَالَ - قُلْتُ مَنْ هُمَا قَالُوا مُرَارَةُ بْنُ رَبِيعَةَ الْعَامِرِيُّ وَهِلاَلُ بْنُ أُمَيَّةَ الْوَاقِفِيُّ - قَالَ - فَذَكَرُوا لِي رَجُلَيْنِ صَالِحَيْنِ قَدْ شِهِدَا بَدْرًا فِيهِمَا أُسْوَةٌ - قَالَ - فَمَضَيْتُ حِينَ ذَكَرُوهُمَا لِي ‏.‏ قَالَ وَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم الْمُسْلِمِينَ عَنْ كَلاَمِنَا أَيُّهَا الثَّلاَثَةُ مِنْ بَيْنِ مَنْ تَخَلَّفَ عَنْهُ - قَالَ - فَاجْتَنَبَنَا النَّاسُ - وَقَالَ - تَغَيَّرُوا لَنَا حَتَّى تَنَكَّرَتْ لِي فِي نَفْسِيَ الأَرْضُ فَمَا هِيَ بِالأَرْضِ الَّتِي أَعْرِفُ فَلَبِثْنَا عَلَى ذَلِكَ خَمْسِينَ لَيْلَةً فَأَمَّا صَاحِبَاىَ فَاسْتَكَانَا وَقَعَدَا فِي بُيُوتِهِمَا يَبْكِيَانِ وَأَمَّا أَنَا فَكُنْتُ أَشَبَّ الْقَوْمِ وَأَجْلَدَهُمْ فَكُنْتُ أَخْرُجُ فَأَشْهَدُ الصَّلاَةَ وَأَطُوفُ فِي الأَسْوَاقِ وَلاَ يُكَلِّمُنِي أَحَدٌ وَآتِي رَسُولَ اللَّهِ صلى الله عليه وسلم فَأُسَلِّمُ عَلَيْهِ وَهُوَ فِي مَجْلِسِهِ بَعْدَ الصَّلاَةِ فَأَقُولُ فِي نَفْسِي هَلْ حَرَّكَ شَفَتَيْهِ بِرَدِّ السَّلاَمِ أَمْ لاَ ثُمَّ أُصَلِّي قَرِيبًا مِنْهُ وَأُسَارِقُهُ النَّظَرَ فَإِذَا أَقْبَلْتُ عَلَى صَلاَتِي نَظَرَ إِلَىَّ وَإِذَا الْتَفَتُّ نَحْوَهُ أَعْرَضَ عَنِّي حَتَّى إِذَا طَالَ ذَلِكَ عَلَىَّ مِنْ جَفْوَةِ الْمُسْلِمِينَ مَشَيْتُ حَتَّى تَسَوَّرْتُ جِدَارَ حَائِطِ أَبِي قَتَادَةَ وَهُوَ ابْنُ عَمِّي وَأَحَبُّ النَّاسِ إِلَىَّ فَسَلَّمْتُ عَلَيْهِ فَوَاللَّهِ مَا رَدَّ عَلَىَّ السَّلاَمَ فَقُلْتُ لَهُ يَا أَبَا قَتَادَةَ أَنْشُدُكَ بِاللَّهِ هَلْ تَعْلَمَنَّ أَنِّي أُحِبُّ اللَّهَ وَرَسُولَهُ قَالَ فَسَكَتَ فَعُدْتُ فَنَاشَدْتُهُ فَسَكَتَ فَعُدْتُ فَنَاشَدْتُهُ فَقَالَ اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ فَفَاضَتْ عَيْنَاىَ وَتَوَلَّيْتُ حَتَّى تَسَوَّرْتُ الْجِدَارَ فَبَيْنَا أَنَا أَمْشِي فِي سُوقِ الْمَدِينَةِ إِذَا نَبَطِيٌّ مِنْ نَبَطِ أَهْلِ الشَّامِ مِمَّنْ قَدِمَ بِالطَّعَامِ يَبِيعُهُ بِالْمَدِينَةِ يَقُولُ مَنْ يَدُلُّ عَلَى كَعْبِ بْنِ مَالِكٍ - قَالَ - فَطَفِقَ النَّاسُ يُشِيرُونَ لَهُ إِلَىَّ حَتَّى جَاءَنِي فَدَفَعَ إِلَىَّ كِتَابًا مِنْ مَلِكِ غَسَّانَ وَكُنْتُ كَاتِبًا فَقَرَأْتُهُ فَإِذَا فِيهِ أَمَّا بَعْدُ فَإِنَّهُ قَدْ بَلَغَنَا أَنَّ صَاحِبَكَ قَدْ جَفَاكَ وَلَمْ يَجْعَلْكَ اللَّهُ بِدَارِ هَوَانٍ وَلاَ مَضْيَعَةٍ فَالْحَقْ بِنَا نُوَاسِكَ ‏.‏ قَالَ فَقُلْتُ حِينَ قَرَأْتُهَا وَهَذِهِ أَيْضًا مِنَ الْبَلاَءِ ‏.‏ فَتَيَامَمْتُ بِهَا التَّنُّورَ فَسَجَرْتُهَا بِهَا حَتَّى إِذَا مَضَتْ أَرْبَعُونَ مِنَ الْخَمْسِينَ وَاسْتَلْبَثَ الْوَحْىُ إِذَا رَسُولُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَأْتِينِي فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُكَ أَنْ تَعْتَزِلَ امْرَأَتَكَ ‏.‏ قَالَ فَقُلْتُ أُطَلِّقُهَا أَمْ مَاذَا أَفْعَلُ قَالَ لاَ بَلِ اعْتَزِلْهَا فَلاَ تَقْرَبَنَّهَا - قَالَ - فَأَرْسَلَ إِلَى صَاحِبَىَّ بِمِثْلِ ذَلِكَ - قَالَ - فَقُلْتُ لاِمْرَأَتِي الْحَقِي بِأَهْلِكِ فَكُونِي عِنْدَهُمْ حَتَّى يَقْضِيَ اللَّهُ فِي هَذَا الأَمْرِ - قَالَ - فَجَاءَتِ امْرَأَةُ هِلاَلِ بْنِ أُمَيَّةَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ لَهُ يَا رَسُولَ اللَّهِ إِنَّ هِلاَلَ بْنَ أُمَيَّةَ شَيْخٌ ضَائِعٌ لَيْسَ لَهُ خَادِمٌ فَهَلْ تَكْرَهُ أَنْ أَخْدُمَهُ قَالَ ‏"‏ لاَ وَلَكِنْ لاَ يَقْرَبَنَّكِ ‏"‏ ‏.‏ فَقَالَتْ إِنَّهُ وَاللَّهِ مَا بِهِ حَرَكَةٌ إِلَى شَىْءٍ وَوَاللَّهِ مَا زَالَ يَبْكِي مُنْذُ كَانَ مِنْ أَمْرِهِ مَا كَانَ إِلَى يَوْمِهِ هَذَا ‏.‏ قَالَ فَقَالَ لِي بَعْضُ أَهْلِي لَوِ اسْتَأْذَنْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي امْرَأَتِكَ فَقَدْ أَذِنَ لاِمْرَأَةِ هِلاَلِ بْنِ أُمَيَّةَ أَنْ تَخْدُمَهُ - قَالَ - فَقُلْتُ لاَ أَسْتَأْذِنُ فِيهَا رَسُولَ اللَّهِ صلى الله عليه وسلم وَمَا يُدْرِينِي مَاذَا يَقُولُ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اسْتَأْذَنْتُهُ فِيهَا وَأَنَا رَجُلٌ شَابٌّ - قَالَ - فَلَبِثْتُ بِذَلِكَ عَشْرَ لَيَالٍ فَكَمُلَ لَنَا خَمْسُونَ لَيْلَةً مِنْ حِينَ نُهِيَ عَنْ كَلاَمِنَا - قَالَ - ثُمَّ صَلَّيْتُ صَلاَةَ الْفَجْرِ صَبَاحَ خَمْسِينَ لَيْلَةً عَلَى ظَهْرِ بَيْتٍ مِنْ بُيُوتِنَا فَبَيْنَا أَنَا جَالِسٌ عَلَى الْحَالِ الَّتِي ذَكَرَ اللَّهُ عَزَّ وَجَلَّ مِنَّا قَدْ ضَاقَتْ عَلَىَّ نَفْسِي وَضَاقَتْ عَلَىَّ الأَرْضُ بِمَا رَحُبَتْ سَمِعْتُ صَوْتَ صَارِخٍ أَوْفَى عَلَى سَلْعٍ يَقُولُ بِأَعْلَى صَوْتِهِ يَا كَعْبَ بْنَ مَالِكٍ أَبْشِرْ - قَالَ - فَخَرَرْتُ سَاجِدًا وَعَرَفْتُ أَنْ قَدْ جَاءَ فَرَجٌ ‏.‏ - قَالَ - فَآذَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّاسَ بِتَوْبَةِ اللَّهِ عَلَيْنَا حِينَ صَلَّى صَلاَةَ الْفَجْرِ فَذَهَبَ النَّاسُ يُبَشِّرُونَنَا فَذَهَبَ قِبَلَ صَاحِبَىَّ مُبَشِّرُونَ وَرَكَضَ رَجُلٌ إِلَىَّ فَرَسًا وَسَعَى سَاعٍ مِنْ أَسْلَمَ قِبَلِي وَأَوْفَى الْجَبَلَ فَكَانَ الصَّوْتُ أَسْرَعَ مِنَ الْفَرَسِ فَلَمَّا جَاءَنِي الَّذِي سَمِعْتُ صَوْتَهُ يُبَشِّرُنِي فَنَزَعْتُ لَهُ ثَوْبَىَّ فَكَسَوْتُهُمَا إِيَّاهُ بِبِشَارَتِهِ وَاللَّهِ مَا أَمْلِكُ غَيْرَهُمَا يَوْمَئِذٍ وَاسْتَعَرْتُ ثَوْبَيْنِ ‏.‏ فَلَبِسْتُهُمَا فَانْطَلَقْتُ أَتَأَمَّمُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَلَقَّانِي النَّاسُ فَوْجًا فَوْجًا يُهَنِّئُونِي بِالتَّوْبَةِ وَيَقُولُونَ لِتَهْنِئْكَ تَوْبَةُ اللَّهِ عَلَيْكَ ‏.‏ حَتَّى دَخَلْتُ الْمَسْجِدَ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ فِي الْمَسْجِدِ وَحَوْلَهُ النَّاسُ فَقَامَ طَلْحَةُ بْنُ عُبَيْدِ اللَّهِ يُهَرْوِلُ حَتَّى صَافَحَنِي وَهَنَّأَنِي وَاللَّهِ مَا قَامَ رَجُلٌ مِنَ الْمُهَاجِرِينَ غَيْرُهُ ‏.‏ قَالَ فَكَانَ كَعْبٌ لاَ يَنْسَاهَا لِطَلْحَةَ ‏.‏ قَالَ كَعْبٌ فَلَمَّا سَلَّمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ وَهُوَ يَبْرُقُ وَجْهُهُ مِنَ السُّرُورِ وَيَقُولُ ‏"‏ أَبْشِرْ بِخَيْرِ يَوْمٍ مَرَّ عَلَيْكَ مُنْذُ وَلَدَتْكَ أُمُّكَ ‏"‏ ‏.‏ قَالَ فَقُلْتُ أَمِنْ عِنْدِكَ يَا رَسُولَ اللَّهِ أَمْ مِنْ عِنْدِ اللَّهِ فَقَالَ ‏"‏ لاَ بَلْ مِنْ عِنْدِ اللَّهِ ‏"‏ ‏.‏ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سُرَّ اسْتَنَارَ وَجْهُهُ كَأَنَّ وَجْهَهُ قِطْعَةُ قَمَرٍ - قَالَ - وَكُنَّا نَعْرِفُ ذَلِكَ - قَالَ - فَلَمَّا جَلَسْتُ بَيْنَ يَدَيْهِ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ مِنْ تَوْبَتِي أَنْ أَنْخَلِعَ مِنْ مَالِي صَدَقَةً إِلَى اللَّهِ وَإِلَى رَسُولِهِ صلى الله عليه وسلم ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمْسِكْ بَعْضَ مَالِكَ فَهُوَ خَيْرٌ لَكَ ‏"‏ ‏.‏ قَالَ فَقُلْتُ فَإِنِّي أُمْسِكُ سَهْمِيَ الَّذِي بِخَيْبَرَ - قَالَ - وَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ إِنَّمَا أَنْجَانِي بِالصِّدْقِ وَإِنَّ مِنْ تَوْبَتِي أَنْ لاَ أُحَدِّثَ إِلاَّ صِدْقًا مَا بَقِيتُ - قَالَ - فَوَاللَّهِ مَا عَلِمْتُ أَنَّ أَحَدًا مِنَ الْمُسْلِمِينَ أَبْلاَهُ اللَّهُ فِي صِدْقِ الْحَدِيثِ مُنْذُ ذَكَرْتُ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى يَوْمِي هَذَا أَحْسَنَ مِمَّا أَبْلاَنِي اللَّهُ بِهِ وَاللَّهِ مَا تَعَمَّدْتُ كَذْبَةً مُنْذُ قُلْتُ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى يَوْمِي هَذَا وَإِنِّي لأَرْجُو أَنْ يَحْفَظَنِيَ اللَّهُ فِيمَا بَقِيَ ‏.‏ قَالَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ لَقَدْ تَابَ اللَّهُ عَلَى النَّبِيِّ وَالْمُهَاجِرِينَ وَالأَنْصَارِ الَّذِينَ اتَّبَعُوهُ فِي سَاعَةِ الْعُسْرَةِ مِنْ بَعْدِ مَا كَادَ يَزِيغُ قُلُوبُ فَرِيقٍ مِنْهُمْ ثُمَّ تَابَ عَلَيْهِمْ إِنَّهُ بِهِمْ رَءُوفٌ رَحِيمٌ * وَعَلَى الثَّلاَثَةِ الَّذِينَ خُلِّفُوا حَتَّى إِذَا ضَاقَتْ عَلَيْهِمُ الأَرْضُ بِمَا رَحُبَتْ وَضَاقَتْ عَلَيْهِمْ أَنْفُسُهُمْ‏\}‏ حَتَّى بَلَغَ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا اتَّقُوا اللَّهَ وَكُونُوا مَعَ الصَّادِقِينَ‏\}‏ قَالَ كَعْبٌ وَاللَّهِ مَا أَنْعَمَ اللَّهُ عَلَىَّ مِنْ نِعْمَةٍ قَطُّ بَعْدَ إِذْ هَدَانِي اللَّهُ لِلإِسْلاَمِ أَعْظَمَ فِي نَفْسِي مِنْ صِدْقِي رَسُولَ اللَّهُ صلى الله عليه وسلم أَنْ لاَ أَكُونَ كَذَبْتُهُ فَأَهْلِكَ كَمَا هَلَكَ الَّذِينَ كَذَبُوا إِنَّ اللَّهَ قَالَ لِلَّذِينَ كَذَبُوا حِينَ أَنْزَلَ الْوَحْىَ شَرَّ مَا قَالَ لأَحَدٍ وَقَالَ اللَّهُ ‏\{‏ سَيَحْلِفُونَ بِاللَّهِ لَكُمْ إِذَا انْقَلَبْتُمْ إِلَيْهِمْ لِتُعْرِضُوا عَنْهُمْ فَأَعْرِضُوا عَنْهُمْ إِنَّهُمْ رِجْسٌ وَمَأْوَاهُمْ جَهَنَّمُ جَزَاءً بِمَا كَانُوا يَكْسِبُونَ * يَحْلِفُونَ لَكُمْ لِتَرْضَوْا عَنْهُمْ فَإِنْ تَرْضَوْا عَنْهُمْ فَإِنَّ اللَّهَ لاَ يَرْضَى عَنِ الْقَوْمِ الْفَاسِقِينَ‏\}‏ قَالَ كَعْبٌ كُنَّا خُلِّفْنَا أَيُّهَا الثَّلاَثَةُ عَنْ أَمْرِ أُولَئِكَ الَّذِينَ قَبِلَ مِنْهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ حَلَفُوا لَهُ فَبَايَعَهُمْ وَاسْتَغْفَرَ لَهُمْ وَأَرْجَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَمْرَنَا حَتَّى قَضَى اللَّهُ فِيهِ فَبِذَلِكَ قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَعَلَى الثَّلاَثَةِ الَّذِينَ خُلِّفُوا‏\}‏ وَلَيْسَ الَّذِي ذَكَرَ اللَّهُ مِمَّا خُلِّفْنَا تَخَلُّفَنَا عَنِ الْغَزْوِ وَإِنَّمَا هُوَ تَخْلِيفُهُ إِيَّانَا وَإِرْجَاؤُهُ أَمْرَنَا عَمَّنْ حَلَفَ لَهُ وَاعْتَذَرَ إِلَيْهِ فَقَبِلَ مِنْهُ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا حُجَيْنُ بْنُ الْمُثَنَّى، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، بِإِسْنَادِ يُونُسَ عَنِ الزُّهْرِيِّ، سَوَاءً ‏.‏\hadithno{7017}\hadithtrans{Ibn Shihab reported that Allah's Messenger (ﷺ) made an expedition to Tabuk and he (the Holy Prophet) had in his mind (the idea of threatening the) Christians of Arabia in Syria and those of Rome. Ibn Shihab (further) reported that 'Abd al-Rahman b. 'Abdullah b. Ka'b informed him that Abdullah b. Ka'b who served as the guide of Ka'b b. 'Malik as he became blind that he heard Ka'b b. Malik narrate the story of his remaining behind Allah's Messenger (ﷺ) from the Battle of Tabuk. Ka'b b. Malik said:I never remained behind Allah's Messenger (ﷺ) from any expedition which he undertook except the Battle of Tabuk and that of the Battle of Badr. So far as the Battle of Badr is concerned, nobody was blamed for remaining behind as Allah's Messenger (ﷺ) and the Muslims (did not set out for attack but for waylaying) the caravan of the Quraish, but it was Allah Who made them confront their enemies without their intention (to do so). I had the honour to be with Allah's Messenger (ﷺ) on the night of 'Aqaba when we pledged our allegiance to Islam and it was more dear to me than my participation in the Battle of Badr, although Badr was more popular amongst people as compared with that (Tabuk). And this is my story of remaining back from Allah's Messenger (ﷺ) on the occasion of the Battle of Tabuk. Never did I possess means enough and (my circumstances) more favourable than at the occasion of this expedition. And, by Allah, I had never before this expedition simultaneously in my possession two rides. Allah's Messenger (ﷺ) set out for this expedition in extremely hot season; the journey was long and the land (which he and his army had to cover) was waterless and he had to confront a large army, so he informed the Muslims about the actual situation (they had to face), so that they should adequately equip themselves for this expedition, and he also told them the destination where he intended to go. And the Muslims who accompanied Allah's Messenger (ﷺ) at that time were large in numbers but there was no proper record of them. Ka'b (further) said: Few were the persons who wanted to absent themselves, and were under the impression that they could easily conceal themselves (and thus remain undetected) until revelations from Allah, the Exalted and Glorious (descended in connection with them). And Allah's Messenger (ﷺ) set out on an expedition when the fruits were ripe and their shadows had been lengthened. I had weakness for them and it was during this season that Allah's Messenger (ﷺ) made preparations and the Muslims too along with them. I also set out in the morning so that I should make preparations along with them but I came back and did nothing and said to myself: I have means enough (to make preparations) as soon as I like. And I went on doing this (postponing my preparations) until people were about to depart and it was in the morning that Allah's Messenger (ﷺ) set out and the Muslims too along with him, but I made no preparations. I went early in the morning and came back, but I made no decision. I continued to do so until they (the Muslims) hastened and covered a good deal of distance. I also made up my mind to march on and to meet them. Would that I had done that but perhaps it was not destined for me. After the departure of Allah's Messenger (ﷺ) as I went out amongst people, I was shocked to find that I did not find anyone like me but people who were labelled as hypocrites or the people whom Allah granted exemption because of their incapacity and Allah's Messenger (ﷺ) took no notice of me until he had reached Tabuk. (One day as he was sitting amongst the people in Tabuk) he said: What has happened to Ka'b b. Malik? A person from Banu' Salama said: Allah's Messenger, the (beauty) of his cloak and his appreciation of his sides have allured him and he was thus detained. Mua'dh b. Jabal said: Woe be upon that what you contend. Allah's Messenger, by Allah, we know nothing about him but good. Allah's Messenger (ﷺ), however, kept quiet. It was during that time that he (the Holy Prophet) saw a person (dressed in all white (garment) shattering the illusion of eye (mirage). Thereupon Allah's Messenger (ﷺ) said: May he be Abu Khaithama and, lo, it was Abu Khaithama al-Ansari and he was that person who contributed a sa' of dates and was scoffed at by the hypocrites. Ka'b b. Malik farther said: When this news reached me that Allah's Messenger (ﷺ) was on his way back from Tabuk I was greatly perturbed. I thought of fabricating false stories and asked myself how I would save myself from his anger on the following day. In this connection, I sought the help of every prudent man from amongst the members of my family and when it was said to me that Allah's Messenger (ﷺ) was about to arrive, all the false ideas banished (from my mind) and I came to the conclusion that nothing could save me but the telling of truth, so I decided to speak the truth and it was in the morning that Allah's Messenger (ﷺ) arrived (in Medina). And it was his habit that as he came back from a journey he first went to the mosque and observed two Rak'ahs of nafl prayer (as a mark of gratitude) and then sat amongst people. And as he did that, those who had remained behind him began to put forward their excuses and take an oath before him and they were more than eighty persons. Allah's Messenger (ﷺ) accepted their excuses on the very face of them and accepted their allegiance and sought forgiveness for them and left their secret (intentions) to Allah, until I presented myself to him. I greeted him and he smiled and there was a tinge of anger in that. He (the Holy Prophet) then said to me: Come forward. I went forward until I sat in front of him. He said to me: What kept you back? Could you not afford to go in for a ride? I said: Allah's Messenger, by Allah, if I were to sit in the presence of anybody else from amongst the worldly people I would have definitely saved myself from his anger on one pretext (or the other) and I have also the knack to fall into argumentation, but, by Allah, I am fully aware of the fact that if I were to put forward before you a false excuse to please you Allah would definitely provoke your wrath upon me, and if I speak the truth you may be annoyed with me, but I hope that Allah would make its end well and, by Allah, there is no valid excuse for me. By Allah, I never possessed so good means, and I never had such favourable conditions for me as I had when I stayed behind you (failed to join the expedition). Thereupon, Allah's Messenger (ﷺ) said: This man told the truth, so get up until Allah gives a decision in your case. I stood up and some people of Banu' Salama followed me in hot haste, and they said to me: By Allah, we do not know about you that you committed a sin prior to this. You, however, showed inability to put forward an excuse before Allah's Messenger (ﷺ) as those who stayed behind him have put forward excuses. It would have been enough for the forgiveness of your sin that Allah's Messenger (ﷺ) would have sought forgiveness for you. By Allah, they continued to incite me until I thought of going back to Allah's Messenger (ﷺ) and contradict myself. Then I said to them: Has anyone else also met the same fate? They said: Yes, two persons have met the same fate as has fallen to you and they have made the sane statement as you have made, and the same verdict has been delivered in their case as it has been delivered in your case. I said: Who are they? They said: Murara b. ar-Rabi'a 'Amiri and Hilal b. Umayya al-Waqafi. They made a mention of these two pious persons to me who had participated in the Battle of Badr and there was an example for me in them. I went away when they named these two persons. Allah's Messenger (ﷺ) forbade the Nluslims to talk with three of us from amongst those (persons) who had stayed behind him. The people began to avoid us and their attitude towards us underwent a change and it seemed as if the whole atmosphere had turned (hostile) against us and it was in fact the same atmosphere ot which I was fully aware and in which I had lived (for a fairly long time). We spent fifty nights in this very state and my two friends confined themselves withen their houses and spent (most of the) time in weeping, but as I was young and strong amongst them I got (out of my house), participated in congregational prayers, moved about in the bazar; but none spoke to me. I came to Allah's Messenger (ﷺ) as he sat amongst (people) after the prayer, greeted him and asked myself whether his lips stirred in response to my greetings (or not). Then I observed prayer beside him and looked at him with stealing glances and when I attended to my prayer, he looked at me and when I cast a glance at him he turned away his eyes from me. And when the harsh treatment of the Muslims towards me extended to a (considerable) length of time, I walked until I climbed upon the wall of the garden of Abu Qatada, and he was my cousin, and I had the greatest love for him. I greeted him but, by Allah, he did not respond to my greetings. I said to him: Abu Qatada, I adjure you by Allah, arn't you well aware of the fact that I love Allah and His Messenger (ﷺ) the most. He kept quiet. I again repeated saying: I adjure you by Allah. arn't you well aware of the fact that I love Allah and His Messenger (ﷺ) the most. He kept quiet. I again adjured him, whereupon he said: Allah and the Messenger (ﷺ) are best aware of it. My eyes began to shed tears and I came back climbing down from the wall and as I was walking in the bazar of Medina a Nabatean from amongst the Nabateans of Syria, who had come to sell foodgrains in Medina, asked people to direct him to Ka'b b. Malik. People gave him the indication by pointing towards me. He came to me and delivered to me a letter of the King of Ghassan and as I was a scribe I read that letter and it was written like this:" Coming to my point, it has been conveyed to us that your friend (the Holy Prophet) is subjecting you to cruelty and Allah has not created you for a place where you are to be degraded and where you cannot find your right place, so you come to us that we should accord you honour. As I read that letter I said: This is also a calamity, so I burnt it in the oven. When out of the fifty days, forty days had passed and Allah's Messenger (ﷺ) received no revelation, there came the messenger of Allah's Messenger (ﷺ) to me and said: Verily, Allah's Messenger (ﷺ) has commanded you to remain separate from your wife. I said: Should I divorce her or what (else) should I do? He said: No, but only remain separate from her and don't have sexual contact with her. The same message was sent to my companions. So I said to my wife: You better go to your parents and stay there with them until Allah gives the decision in my case. The wife of Hilal b. Umayya came to Allah's Messenger (ﷺ) and said: Allah's Messenger, Hilal b. Umayya is a senile person, he has no servant. Do you disapprove of my serving him? He said: No, but don't go near him. She said: By Allah, he has no such instinct in him. By Allah, he spends his time in weeping from that day to this day. Some of the members of my family said to me: Were you to seek permission from Allah's Messenger (ﷺ) in regard to your wife as he has granted permission to the wife of Hilal b. Umayya to serve him. I said: I would not seek permission from Allah's Messenger (ﷺ), for I cannot say what Allah's Apostle may say in response to seeking my permission. Moreover, I am a young man. It was in this state that I spent ten more nights and thus fifty nights had passed that (people) had observed boycott with us. It was on the morning of the fiftieth night that I observed my dawn prayer and was sitting on one of the roofs of our houses. And I was in fact sitting in that very state which Allah, the Exalted and Glorious, has described about us in these words:" Life had become hard for myself and the earth had compressed despite its vastness," that I heard the noise of an announcer from the peak of the hill of Sal' saying at the top of his voice: Ka'b b. Malik, there is glad tidings for you. I fell down in prostration and came to realise that there was (a message of) relief for me. Allah's Messenger (ﷺ) had informed the people of the acceptance of our repentance by Allah as he offered the dawn prayer. So the people went on to give us glad tidings and some of them went to my friends in order to give them the glad tidings and a person galloped his horse and came from the tribe of Aslam and his horse reached me more quickly than his voice. And when he came to me whose sound I heard, he gave me the glad tidings. I took off my clothes and clothed him with them because of his bringing good news to me and, by Allah, I possessed nothing else (in the form of clothes) than these two on that occasion, and I asked one to lend me two clothes and dressed myself in them. I came to Allah's Messenger (ﷺ) and on my way I met groups of people who greeted me because of (the acceptance of) repentance and they said: Here is a greeting for you for your repentance being accepted by Allah. (I moved on) until I came to the mosque and Allah's Messenger (ﷺ) had been sitting there amongst persons. So Talha b. 'Ubaidullah got up and rushed towards me and he shook hands with me and greeted me and, by Allah, no person stood up (to greet me) from amongst the emigrants except he. Ka'b said that he never forgot (this good gesture of) Talha. Ka'b further said: I greeted Allah's Messenger (ﷺ) with Assalam-o-'Alaikam and his face was glistening because of delight, and he said: Let there be glad tidings and blessings for you, the like of which (you have neither found nor you will find, as you find today) since your mother gave your birth. I said: Allah's Messenger. is this acceptance of repentance from you or from Allah? He said: No, (it is not from ma), it is from Allah, and it was common with Allah's Messenger (ﷺ) that as he was happy his face brightened up and it looked like a part of the moon and it was from this that we recognised it (his delight). As I sat before him, I said: Allah's Messenger, am I allowed to give in charity my wealth for Allah's sake and for the sake of His Messenger (ﷺ)? Thereupon Allah's Messenger (ﷺ) said: Keep some property with you as it is better for you. I said: I shall keep with me that part (of my property) which fell to my lot (on the occasion of the expedition of) Khaibar. I said: Allah's Messenger, verily, Allah has granted me salvation because of truth and, therefore, (I think) that repentance implies that I should not speak anything but truth as long as I live. He said: By Allah, I do not know whether anyone amongst the Muslims was put to more severe trial than I by Allah because of telling the truth. And since I made a mention of this to Allah's Messenger (ﷺ) up to this day I have not told any lie and, by Allah, I have decided not to tell a lie and I hope that Allah would save me (from trials) for the rest of my life and Allah, the Exalted and Glorious, revealed these verses:" Certainly, Allah has turned in Mercy to the Prophet and the emigrants and the helpers who followed him in the hour of hardship after the hearts of a part of them were about to deviate; then He turned to them in mercy. Surely, to them He is Compassionate, Merciful and (He turned in Mercy) to the three who were left behind until the earth despite its vastness became strait for them and their souls were also straitened to them." And this revelation reached up to the (words):" O you who believe, develop God consciousness, and be with the truthful" (ix. 117-118). Ka'b said: By Allah, since Allah directed me to Islam there has been no blessing more significant for me than this truth of mine which I spoke to Allah's Messenger (ﷺ) and if I were to tell a lie I would have been ruined as were ruined those who told lies, for in regard to those who told lies Allah used harshest words used for anyone as He descended revelation (and the words of Allah are):" They will swear by Allah to you when you return to them so that you may leave them alone. So leave them alone. Surely, they are unclean and their resort is Hell, recompense for what they earned. They will swear to you that you may be pleased with them but if you are pleased with them, yet surely Allah is not pleased with the transgressing people" (ix. 95-96). K'ab said that the matter of us three persons was deferred as compared with those who took an oath in the presence of Allahs Messenger (ﷺ) and he accepted their allegiance and sought forgiveness for them and Allah did not give any decision in regard to us. It was Allah, the Exalted and Glorious, Who gave decisions in our case, three who remained behind. (The words of the Qur'an)" the three who were left behind" do not mean that we remained back from Jihad but these imply that He kept our matter behind them who took oath and presented excuse before Him. This hadith has been narrated on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{7018}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ سَرْحٍ مَوْلَى بَنِي أُمَيَّةَ أَخْبَرَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ ثُمَّ غَزَا رَسُولُ اللَّهِ صلى الله عليه وسلم غَزْوَةَ تَبُوكَ وَهُوَ يُرِيدُ الرُّومَ وَنَصَارَى الْعَرَبِ بِالشَّامِ ‏.‏ قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبٍ كَانَ قَائِدَ كَعْبٍ مِنْ بَنِيهِ حِينَ عَمِيَ قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ يُحَدِّثُ حَدِيثَهُ حِينَ تَخَلَّفَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ قَالَ كَعْبُ بْنُ مَالِكٍ لَمْ أَتَخَلَّفْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةٍ غَزَاهَا قَطُّ إِلاَّ فِي غَزْوَةِ تَبُوكَ غَيْرَ أَنِّي قَدْ تَخَلَّفْتُ فِي غَزْوَةِ بَدْرٍ وَلَمْ يُعَاتِبْ أَحَدًا تَخَلَّفَ عَنْهُ إِنَّمَا خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْمُسْلِمُونَ يُرِيدُونَ عِيرَ قُرَيْشٍ حَتَّى جَمَعَ اللَّهُ بَيْنَهُمْ وَبَيْنَ عَدُوِّهُمْ عَلَى غَيْرِ مِيعَادٍ وَلَقَدْ شَهِدْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيْلَةَ الْعَقَبَةِ حِينَ تَوَاثَقْنَا عَلَى الإِسْلاَمِ وَمَا أُحِبُّ أَنَّ لِي بِهَا مَشْهَدَ بَدْرٍ وَإِنْ كَانَتْ بَدْرٌ أَذْكَرَ فِي النَّاسِ مِنْهَا وَكَانَ مِنْ خَبَرِي حِينَ تَخَلَّفْتُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ أَنِّي لَمْ أَكُنْ قَطُّ أَقْوَى وَلاَ أَيْسَرَ مِنِّي حِينَ تَخَلَّفْتُ عَنْهُ فِي تِلْكَ الْغَزْوَةِ وَاللَّهِ مَا جَمَعْتُ قَبْلَهَا رَاحِلَتَيْنِ قَطُّ حَتَّى جَمَعْتُهُمَا فِي تِلْكَ الْغَزْوَةِ فَغَزَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حَرٍّ شَدِيدٍ وَاسْتَقْبَلَ سَفَرًا بَعِيدًا وَمَفَازًا وَاسْتَقْبَلَ عَدُوًّا كَثِيرًا فَجَلاَ لِلْمُسْلِمِينَ أَمْرَهُمْ لِيَتَأَهَّبُوا أُهْبَةَ غَزْوِهِمْ فَأَخْبَرَهُمْ بِوَجْهِهِمُ الَّذِي يُرِيدُ وَالْمُسْلِمُونَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم كَثِيرٌ وَلاَ يَجْمَعُهُمْ كِتَابُ حَافِظٍ - يُرِيدُ بِذَلِكَ الدِّيوَانَ - قَالَ كَعْبٌ فَقَلَّ رَجُلٌ يُرِيدُ أَنْ يَتَغَيَّبَ يَظُنُّ أَنَّ ذَلِكَ سَيَخْفَى لَهُ مَا لَمْ يَنْزِلْ فِيهِ وَحْىٌ مِنَ اللَّهِ عَزَّ وَجَلَّ وَغَزَا رَسُولُ اللَّهِ صلى الله عليه وسلم تِلْكَ الْغَزْوَةَ حِينَ طَابَتِ الثِّمَارُ وَالظِّلاَلُ فَأَنَا إِلَيْهَا أَصْعَرُ فَتَجَهَّزَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْمُسْلِمُونَ مَعَهُ وَطَفِقْتُ أَغْدُو لِكَىْ أَتَجَهَّزَ مَعَهُمْ فَأَرْجِعُ وَلَمْ أَقْضِ شَيْئًا ‏.‏ وَأَقُولُ فِي نَفْسِي أَنَا قَادِرٌ عَلَى ذَلِكَ إِذَا أَرَدْتُ ‏.‏ فَلَمْ يَزَلْ ذَلِكَ يَتَمَادَى بِي حَتَّى اسْتَمَرَّ بِالنَّاسِ الْجِدُّ فَأَصْبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم غَادِيًا وَالْمُسْلِمُونَ مَعَهُ وَلَمْ أَقْضِ مِنْ جَهَازِي شَيْئًا ثُمَّ غَدَوْتُ فَرَجَعْتُ وَلَمْ أَقْضِ شَيْئًا فَلَمْ يَزَلْ ذَلِكَ يَتَمَادَى بِي حَتَّى أَسْرَعُوا وَتَفَارَطَ الْغَزْوُ فَهَمَمْتُ أَنْ أَرْتَحِلَ فَأُدْرِكَهُمْ فَيَا لَيْتَنِي فَعَلْتُ ثُمَّ لَمْ يُقَدَّرْ ذَلِكَ لِي فَطَفِقْتُ إِذَا خَرَجْتُ فِي النَّاسِ بَعْدَ خُرُوجِ رَسُولِ اللَّهِ صلى الله عليه وسلم يَحْزُنُنِي أَنِّي لاَ أَرَى لِي أُسْوَةً إِلاَّ رَجُلاً مَغْمُوصًا عَلَيْهِ فِي النِّفَاقِ أَوْ رَجُلاً مِمَّنْ عَذَرَ اللَّهُ مِنَ الضُّعَفَاءِ وَلَمْ يَذْكُرْنِي رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى بَلَغَ تَبُوكًا فَقَالَ وَهُوَ جَالِسٌ فِي الْقَوْمِ بِتَبُوكَ ‏"‏ مَا فَعَلَ كَعْبُ بْنُ مَالِكٍ ‏"‏ ‏.‏ قَالَ رَجُلٌ مِنْ بَنِي سَلِمَةَ يَا رَسُولَ اللَّهِ حَبَسَهُ بُرْدَاهُ وَالنَّظَرُ فِي عِطْفَيْهِ ‏.‏ فَقَالَ لَهُ مُعَاذُ بْنُ جَبَلٍ بِئْسَ مَا قُلْتَ وَاللَّهِ يَا رَسُولَ اللَّهِ مَا عَلِمْنَا عَلَيْهِ إِلاَّ خَيْرًا ‏.‏ فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَبَيْنَمَا هُوَ عَلَى ذَلِكَ رَأَى رَجُلاً مُبَيِّضًا يَزُولُ بِهِ السَّرَابُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُنْ أَبَا خَيْثَمَةَ ‏"‏ ‏.‏ فَإِذَا هُو أَبُو خَيْثَمَةَ الأَنْصَارِيُّ وَهُوَ الَّذِي تَصَدَّقَ بِصَاعِ التَّمْرِ حِينَ لَمَزَهُ الْمُنَافِقُونَ ‏.‏ فَقَالَ كَعْبُ بْنُ مَالِكٍ فَلَمَّا بَلَغَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ تَوَجَّهَ قَافِلاً مِنْ تَبُوكَ حَضَرَنِي بَثِّي فَطَفِقْتُ أَتَذَكَّرُ الْكَذِبَ وَأَقُولُ بِمَ أَخْرُجُ مِنْ سَخَطِهِ غَدًا وَأَسْتَعِينُ عَلَى ذَلِكَ كُلَّ ذِي رَأْىٍ مِنْ أَهْلِي فَلَمَّا قِيلَ لِي إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أَظَلَّ قَادِمًا زَاحَ عَنِّي الْبَاطِلُ حَتَّى عَرَفْتُ أَنِّي لَنْ أَنْجُوَ مِنْهُ بِشَىْءٍ أَبَدًا فَأَجْمَعْتُ صِدْقَهُ وَصَبَّحَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَادِمًا وَكَانَ إِذَا قَدِمَ مِنْ سَفَرٍ بَدَأَ بِالْمَسْجِدِ فَرَكَعَ فِيهِ رَكْعَتَيْنِ ثُمَّ جَلَسَ لِلنَّاسِ فَلَمَّا فَعَلَ ذَلِكَ جَاءَهُ الْمُخَلَّفُونَ فَطَفِقُوا يَعْتَذِرُونَ إِلَيْهِ وَيَحْلِفُونَ لَهُ وَكَانُوا بِضْعَةً وَثَمَانِينَ رَجُلاً فَقَبِلَ مِنْهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلاَنِيَتَهُمْ وَبَايَعَهُمْ وَاسْتَغْفَرَ لَهُمْ وَوَكَلَ سَرَائِرَهُمْ إِلَى اللَّهِ حَتَّى جِئْتُ فَلَمَّا سَلَّمْتُ تَبَسَّمَ تَبَسُّمَ الْمُغْضَبِ ثُمَّ قَالَ ‏"‏ تَعَالَ ‏"‏ ‏.‏ فَجِئْتُ أَمْشِي حَتَّى جَلَسْتُ بَيْنَ يَدَيْهِ فَقَالَ لِي ‏"‏ مَا خَلَّفَكَ ‏"‏ ‏.‏ أَلَمْ تَكُنْ قَدِ ابْتَعْتَ ظَهْرَكَ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي وَاللَّهِ لَوْ جَلَسْتُ عِنْدَ غَيْرِكَ مِنْ أَهْلِ الدُّنْيَا لَرَأَيْتُ أَنِّي سَأَخْرُجُ مِنْ سَخَطِهِ بِعُذْرٍ وَلَقَدْ أُعْطِيتُ جَدَلاً وَلَكِنِّي وَاللَّهِ لَقَدْ عَلِمْتُ لَئِنْ حَدَّثْتُكَ الْيَوْمَ حَدِيثَ كَذِبٍ تَرْضَى بِهِ عَنِّي لَيُوشِكَنَّ اللَّهُ أَنْ يُسْخِطَكَ عَلَىَّ وَلَئِنْ حَدَّثْتُكَ حَدِيثَ صِدْقٍ تَجِدُ عَلَىَّ فِيهِ إِنِّي لأَرْجُو فِيهِ عُقْبَى اللَّهِ وَاللَّهِ مَا كَانَ لِي عُذْرٌ وَاللَّهِ مَا كُنْتُ قَطُّ أَقْوَى وَلاَ أَيْسَرَ مِنِّي حِينَ تَخَلَّفْتُ عَنْكَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَّا هَذَا فَقَدْ صَدَقَ فَقُمْ حَتَّى يَقْضِيَ اللَّهُ فِيكَ ‏"‏ ‏.‏ فَقُمْتُ وَثَارَ رِجَالٌ مِنْ بَنِي سَلِمَةَ فَاتَّبَعُونِي فَقَالُوا لِي وَاللَّهِ مَا عَلِمْنَاكَ أَذْنَبْتَ ذَنْبًا قَبْلَ هَذَا لَقَدْ عَجَزْتَ فِي أَنْ لاَ تَكُونَ اعْتَذَرْتَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِمَا اعْتَذَرَ بِهِ إِلَيْهِ الْمُخَلَّفُونَ فَقَدْ كَانَ كَافِيَكَ ذَنْبَكَ اسْتِغْفَارُ رَسُولِ اللَّهِ صلى الله عليه وسلم لَكَ ‏.‏ قَالَ فَوَاللَّهِ مَا زَالُوا يُؤَنِّبُونَنِي حَتَّى أَرَدْتُ أَنْ أَرْجِعَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأُكَذِّبَ نَفْسِي - قَالَ - ثُمَّ قُلْتُ لَهُمْ هَلْ لَقِيَ هَذَا مَعِي مِنْ أَحَدٍ قَالُوا نَعَمْ لَقِيَهُ مَعَكَ رَجُلاَنِ قَالاَ مِثْلَ مَا قُلْتَ فَقِيلَ لَهُمَا مِثْلُ مَا قِيلَ لَكَ - قَالَ - قُلْتُ مَنْ هُمَا قَالُوا مُرَارَةُ بْنُ رَبِيعَةَ الْعَامِرِيُّ وَهِلاَلُ بْنُ أُمَيَّةَ الْوَاقِفِيُّ - قَالَ - فَذَكَرُوا لِي رَجُلَيْنِ صَالِحَيْنِ قَدْ شِهِدَا بَدْرًا فِيهِمَا أُسْوَةٌ - قَالَ - فَمَضَيْتُ حِينَ ذَكَرُوهُمَا لِي ‏.‏ قَالَ وَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم الْمُسْلِمِينَ عَنْ كَلاَمِنَا أَيُّهَا الثَّلاَثَةُ مِنْ بَيْنِ مَنْ تَخَلَّفَ عَنْهُ - قَالَ - فَاجْتَنَبَنَا النَّاسُ - وَقَالَ - تَغَيَّرُوا لَنَا حَتَّى تَنَكَّرَتْ لِي فِي نَفْسِيَ الأَرْضُ فَمَا هِيَ بِالأَرْضِ الَّتِي أَعْرِفُ فَلَبِثْنَا عَلَى ذَلِكَ خَمْسِينَ لَيْلَةً فَأَمَّا صَاحِبَاىَ فَاسْتَكَانَا وَقَعَدَا فِي بُيُوتِهِمَا يَبْكِيَانِ وَأَمَّا أَنَا فَكُنْتُ أَشَبَّ الْقَوْمِ وَأَجْلَدَهُمْ فَكُنْتُ أَخْرُجُ فَأَشْهَدُ الصَّلاَةَ وَأَطُوفُ فِي الأَسْوَاقِ وَلاَ يُكَلِّمُنِي أَحَدٌ وَآتِي رَسُولَ اللَّهِ صلى الله عليه وسلم فَأُسَلِّمُ عَلَيْهِ وَهُوَ فِي مَجْلِسِهِ بَعْدَ الصَّلاَةِ فَأَقُولُ فِي نَفْسِي هَلْ حَرَّكَ شَفَتَيْهِ بِرَدِّ السَّلاَمِ أَمْ لاَ ثُمَّ أُصَلِّي قَرِيبًا مِنْهُ وَأُسَارِقُهُ النَّظَرَ فَإِذَا أَقْبَلْتُ عَلَى صَلاَتِي نَظَرَ إِلَىَّ وَإِذَا الْتَفَتُّ نَحْوَهُ أَعْرَضَ عَنِّي حَتَّى إِذَا طَالَ ذَلِكَ عَلَىَّ مِنْ جَفْوَةِ الْمُسْلِمِينَ مَشَيْتُ حَتَّى تَسَوَّرْتُ جِدَارَ حَائِطِ أَبِي قَتَادَةَ وَهُوَ ابْنُ عَمِّي وَأَحَبُّ النَّاسِ إِلَىَّ فَسَلَّمْتُ عَلَيْهِ فَوَاللَّهِ مَا رَدَّ عَلَىَّ السَّلاَمَ فَقُلْتُ لَهُ يَا أَبَا قَتَادَةَ أَنْشُدُكَ بِاللَّهِ هَلْ تَعْلَمَنَّ أَنِّي أُحِبُّ اللَّهَ وَرَسُولَهُ قَالَ فَسَكَتَ فَعُدْتُ فَنَاشَدْتُهُ فَسَكَتَ فَعُدْتُ فَنَاشَدْتُهُ فَقَالَ اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ فَفَاضَتْ عَيْنَاىَ وَتَوَلَّيْتُ حَتَّى تَسَوَّرْتُ الْجِدَارَ فَبَيْنَا أَنَا أَمْشِي فِي سُوقِ الْمَدِينَةِ إِذَا نَبَطِيٌّ مِنْ نَبَطِ أَهْلِ الشَّامِ مِمَّنْ قَدِمَ بِالطَّعَامِ يَبِيعُهُ بِالْمَدِينَةِ يَقُولُ مَنْ يَدُلُّ عَلَى كَعْبِ بْنِ مَالِكٍ - قَالَ - فَطَفِقَ النَّاسُ يُشِيرُونَ لَهُ إِلَىَّ حَتَّى جَاءَنِي فَدَفَعَ إِلَىَّ كِتَابًا مِنْ مَلِكِ غَسَّانَ وَكُنْتُ كَاتِبًا فَقَرَأْتُهُ فَإِذَا فِيهِ أَمَّا بَعْدُ فَإِنَّهُ قَدْ بَلَغَنَا أَنَّ صَاحِبَكَ قَدْ جَفَاكَ وَلَمْ يَجْعَلْكَ اللَّهُ بِدَارِ هَوَانٍ وَلاَ مَضْيَعَةٍ فَالْحَقْ بِنَا نُوَاسِكَ ‏.‏ قَالَ فَقُلْتُ حِينَ قَرَأْتُهَا وَهَذِهِ أَيْضًا مِنَ الْبَلاَءِ ‏.‏ فَتَيَامَمْتُ بِهَا التَّنُّورَ فَسَجَرْتُهَا بِهَا حَتَّى إِذَا مَضَتْ أَرْبَعُونَ مِنَ الْخَمْسِينَ وَاسْتَلْبَثَ الْوَحْىُ إِذَا رَسُولُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَأْتِينِي فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُكَ أَنْ تَعْتَزِلَ امْرَأَتَكَ ‏.‏ قَالَ فَقُلْتُ أُطَلِّقُهَا أَمْ مَاذَا أَفْعَلُ قَالَ لاَ بَلِ اعْتَزِلْهَا فَلاَ تَقْرَبَنَّهَا - قَالَ - فَأَرْسَلَ إِلَى صَاحِبَىَّ بِمِثْلِ ذَلِكَ - قَالَ - فَقُلْتُ لاِمْرَأَتِي الْحَقِي بِأَهْلِكِ فَكُونِي عِنْدَهُمْ حَتَّى يَقْضِيَ اللَّهُ فِي هَذَا الأَمْرِ - قَالَ - فَجَاءَتِ امْرَأَةُ هِلاَلِ بْنِ أُمَيَّةَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ لَهُ يَا رَسُولَ اللَّهِ إِنَّ هِلاَلَ بْنَ أُمَيَّةَ شَيْخٌ ضَائِعٌ لَيْسَ لَهُ خَادِمٌ فَهَلْ تَكْرَهُ أَنْ أَخْدُمَهُ قَالَ ‏"‏ لاَ وَلَكِنْ لاَ يَقْرَبَنَّكِ ‏"‏ ‏.‏ فَقَالَتْ إِنَّهُ وَاللَّهِ مَا بِهِ حَرَكَةٌ إِلَى شَىْءٍ وَوَاللَّهِ مَا زَالَ يَبْكِي مُنْذُ كَانَ مِنْ أَمْرِهِ مَا كَانَ إِلَى يَوْمِهِ هَذَا ‏.‏ قَالَ فَقَالَ لِي بَعْضُ أَهْلِي لَوِ اسْتَأْذَنْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي امْرَأَتِكَ فَقَدْ أَذِنَ لاِمْرَأَةِ هِلاَلِ بْنِ أُمَيَّةَ أَنْ تَخْدُمَهُ - قَالَ - فَقُلْتُ لاَ أَسْتَأْذِنُ فِيهَا رَسُولَ اللَّهِ صلى الله عليه وسلم وَمَا يُدْرِينِي مَاذَا يَقُولُ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اسْتَأْذَنْتُهُ فِيهَا وَأَنَا رَجُلٌ شَابٌّ - قَالَ - فَلَبِثْتُ بِذَلِكَ عَشْرَ لَيَالٍ فَكَمُلَ لَنَا خَمْسُونَ لَيْلَةً مِنْ حِينَ نُهِيَ عَنْ كَلاَمِنَا - قَالَ - ثُمَّ صَلَّيْتُ صَلاَةَ الْفَجْرِ صَبَاحَ خَمْسِينَ لَيْلَةً عَلَى ظَهْرِ بَيْتٍ مِنْ بُيُوتِنَا فَبَيْنَا أَنَا جَالِسٌ عَلَى الْحَالِ الَّتِي ذَكَرَ اللَّهُ عَزَّ وَجَلَّ مِنَّا قَدْ ضَاقَتْ عَلَىَّ نَفْسِي وَضَاقَتْ عَلَىَّ الأَرْضُ بِمَا رَحُبَتْ سَمِعْتُ صَوْتَ صَارِخٍ أَوْفَى عَلَى سَلْعٍ يَقُولُ بِأَعْلَى صَوْتِهِ يَا كَعْبَ بْنَ مَالِكٍ أَبْشِرْ - قَالَ - فَخَرَرْتُ سَاجِدًا وَعَرَفْتُ أَنْ قَدْ جَاءَ فَرَجٌ ‏.‏ - قَالَ - فَآذَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّاسَ بِتَوْبَةِ اللَّهِ عَلَيْنَا حِينَ صَلَّى صَلاَةَ الْفَجْرِ فَذَهَبَ النَّاسُ يُبَشِّرُونَنَا فَذَهَبَ قِبَلَ صَاحِبَىَّ مُبَشِّرُونَ وَرَكَضَ رَجُلٌ إِلَىَّ فَرَسًا وَسَعَى سَاعٍ مِنْ أَسْلَمَ قِبَلِي وَأَوْفَى الْجَبَلَ فَكَانَ الصَّوْتُ أَسْرَعَ مِنَ الْفَرَسِ فَلَمَّا جَاءَنِي الَّذِي سَمِعْتُ صَوْتَهُ يُبَشِّرُنِي فَنَزَعْتُ لَهُ ثَوْبَىَّ فَكَسَوْتُهُمَا إِيَّاهُ بِبِشَارَتِهِ وَاللَّهِ مَا أَمْلِكُ غَيْرَهُمَا يَوْمَئِذٍ وَاسْتَعَرْتُ ثَوْبَيْنِ ‏.‏ فَلَبِسْتُهُمَا فَانْطَلَقْتُ أَتَأَمَّمُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَتَلَقَّانِي النَّاسُ فَوْجًا فَوْجًا يُهَنِّئُونِي بِالتَّوْبَةِ وَيَقُولُونَ لِتَهْنِئْكَ تَوْبَةُ اللَّهِ عَلَيْكَ ‏.‏ حَتَّى دَخَلْتُ الْمَسْجِدَ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ فِي الْمَسْجِدِ وَحَوْلَهُ النَّاسُ فَقَامَ طَلْحَةُ بْنُ عُبَيْدِ اللَّهِ يُهَرْوِلُ حَتَّى صَافَحَنِي وَهَنَّأَنِي وَاللَّهِ مَا قَامَ رَجُلٌ مِنَ الْمُهَاجِرِينَ غَيْرُهُ ‏.‏ قَالَ فَكَانَ كَعْبٌ لاَ يَنْسَاهَا لِطَلْحَةَ ‏.‏ قَالَ كَعْبٌ فَلَمَّا سَلَّمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ وَهُوَ يَبْرُقُ وَجْهُهُ مِنَ السُّرُورِ وَيَقُولُ ‏"‏ أَبْشِرْ بِخَيْرِ يَوْمٍ مَرَّ عَلَيْكَ مُنْذُ وَلَدَتْكَ أُمُّكَ ‏"‏ ‏.‏ قَالَ فَقُلْتُ أَمِنْ عِنْدِكَ يَا رَسُولَ اللَّهِ أَمْ مِنْ عِنْدِ اللَّهِ فَقَالَ ‏"‏ لاَ بَلْ مِنْ عِنْدِ اللَّهِ ‏"‏ ‏.‏ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سُرَّ اسْتَنَارَ وَجْهُهُ كَأَنَّ وَجْهَهُ قِطْعَةُ قَمَرٍ - قَالَ - وَكُنَّا نَعْرِفُ ذَلِكَ - قَالَ - فَلَمَّا جَلَسْتُ بَيْنَ يَدَيْهِ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ مِنْ تَوْبَتِي أَنْ أَنْخَلِعَ مِنْ مَالِي صَدَقَةً إِلَى اللَّهِ وَإِلَى رَسُولِهِ صلى الله عليه وسلم ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمْسِكْ بَعْضَ مَالِكَ فَهُوَ خَيْرٌ لَكَ ‏"‏ ‏.‏ قَالَ فَقُلْتُ فَإِنِّي أُمْسِكُ سَهْمِيَ الَّذِي بِخَيْبَرَ - قَالَ - وَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ اللَّهَ إِنَّمَا أَنْجَانِي بِالصِّدْقِ وَإِنَّ مِنْ تَوْبَتِي أَنْ لاَ أُحَدِّثَ إِلاَّ صِدْقًا مَا بَقِيتُ - قَالَ - فَوَاللَّهِ مَا عَلِمْتُ أَنَّ أَحَدًا مِنَ الْمُسْلِمِينَ أَبْلاَهُ اللَّهُ فِي صِدْقِ الْحَدِيثِ مُنْذُ ذَكَرْتُ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى يَوْمِي هَذَا أَحْسَنَ مِمَّا أَبْلاَنِي اللَّهُ بِهِ وَاللَّهِ مَا تَعَمَّدْتُ كَذْبَةً مُنْذُ قُلْتُ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى يَوْمِي هَذَا وَإِنِّي لأَرْجُو أَنْ يَحْفَظَنِيَ اللَّهُ فِيمَا بَقِيَ ‏.‏ قَالَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ لَقَدْ تَابَ اللَّهُ عَلَى النَّبِيِّ وَالْمُهَاجِرِينَ وَالأَنْصَارِ الَّذِينَ اتَّبَعُوهُ فِي سَاعَةِ الْعُسْرَةِ مِنْ بَعْدِ مَا كَادَ يَزِيغُ قُلُوبُ فَرِيقٍ مِنْهُمْ ثُمَّ تَابَ عَلَيْهِمْ إِنَّهُ بِهِمْ رَءُوفٌ رَحِيمٌ * وَعَلَى الثَّلاَثَةِ الَّذِينَ خُلِّفُوا حَتَّى إِذَا ضَاقَتْ عَلَيْهِمُ الأَرْضُ بِمَا رَحُبَتْ وَضَاقَتْ عَلَيْهِمْ أَنْفُسُهُمْ‏\}‏ حَتَّى بَلَغَ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا اتَّقُوا اللَّهَ وَكُونُوا مَعَ الصَّادِقِينَ‏\}‏ قَالَ كَعْبٌ وَاللَّهِ مَا أَنْعَمَ اللَّهُ عَلَىَّ مِنْ نِعْمَةٍ قَطُّ بَعْدَ إِذْ هَدَانِي اللَّهُ لِلإِسْلاَمِ أَعْظَمَ فِي نَفْسِي مِنْ صِدْقِي رَسُولَ اللَّهُ صلى الله عليه وسلم أَنْ لاَ أَكُونَ كَذَبْتُهُ فَأَهْلِكَ كَمَا هَلَكَ الَّذِينَ كَذَبُوا إِنَّ اللَّهَ قَالَ لِلَّذِينَ كَذَبُوا حِينَ أَنْزَلَ الْوَحْىَ شَرَّ مَا قَالَ لأَحَدٍ وَقَالَ اللَّهُ ‏\{‏ سَيَحْلِفُونَ بِاللَّهِ لَكُمْ إِذَا انْقَلَبْتُمْ إِلَيْهِمْ لِتُعْرِضُوا عَنْهُمْ فَأَعْرِضُوا عَنْهُمْ إِنَّهُمْ رِجْسٌ وَمَأْوَاهُمْ جَهَنَّمُ جَزَاءً بِمَا كَانُوا يَكْسِبُونَ * يَحْلِفُونَ لَكُمْ لِتَرْضَوْا عَنْهُمْ فَإِنْ تَرْضَوْا عَنْهُمْ فَإِنَّ اللَّهَ لاَ يَرْضَى عَنِ الْقَوْمِ الْفَاسِقِينَ‏\}‏ قَالَ كَعْبٌ كُنَّا خُلِّفْنَا أَيُّهَا الثَّلاَثَةُ عَنْ أَمْرِ أُولَئِكَ الَّذِينَ قَبِلَ مِنْهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ حَلَفُوا لَهُ فَبَايَعَهُمْ وَاسْتَغْفَرَ لَهُمْ وَأَرْجَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَمْرَنَا حَتَّى قَضَى اللَّهُ فِيهِ فَبِذَلِكَ قَالَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَعَلَى الثَّلاَثَةِ الَّذِينَ خُلِّفُوا‏\}‏ وَلَيْسَ الَّذِي ذَكَرَ اللَّهُ مِمَّا خُلِّفْنَا تَخَلُّفَنَا عَنِ الْغَزْوِ وَإِنَّمَا هُوَ تَخْلِيفُهُ إِيَّانَا وَإِرْجَاؤُهُ أَمْرَنَا عَمَّنْ حَلَفَ لَهُ وَاعْتَذَرَ إِلَيْهِ فَقَبِلَ مِنْهُ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا حُجَيْنُ بْنُ الْمُثَنَّى، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، بِإِسْنَادِ يُونُسَ عَنِ الزُّهْرِيِّ، سَوَاءً ‏.‏\hadithno{7018}\hadithtrans{Ibn Shihab reported that Allah's Messenger (ﷺ) made an expedition to Tabuk and he (the Holy Prophet) had in his mind (the idea of threatening the) Christians of Arabia in Syria and those of Rome. Ibn Shihab (further) reported that 'Abd al-Rahman b. 'Abdullah b. Ka'b informed him that Abdullah b. Ka'b who served as the guide of Ka'b b. 'Malik as he became blind that he heard Ka'b b. Malik narrate the story of his remaining behind Allah's Messenger (ﷺ) from the Battle of Tabuk. Ka'b b. Malik said:I never remained behind Allah's Messenger (ﷺ) from any expedition which he undertook except the Battle of Tabuk and that of the Battle of Badr. So far as the Battle of Badr is concerned, nobody was blamed for remaining behind as Allah's Messenger (ﷺ) and the Muslims (did not set out for attack but for waylaying) the caravan of the Quraish, but it was Allah Who made them confront their enemies without their intention (to do so). I had the honour to be with Allah's Messenger (ﷺ) on the night of 'Aqaba when we pledged our allegiance to Islam and it was more dear to me than my participation in the Battle of Badr, although Badr was more popular amongst people as compared with that (Tabuk). And this is my story of remaining back from Allah's Messenger (ﷺ) on the occasion of the Battle of Tabuk. Never did I possess means enough and (my circumstances) more favourable than at the occasion of this expedition. And, by Allah, I had never before this expedition simultaneously in my possession two rides. Allah's Messenger (ﷺ) set out for this expedition in extremely hot season; the journey was long and the land (which he and his army had to cover) was waterless and he had to confront a large army, so he informed the Muslims about the actual situation (they had to face), so that they should adequately equip themselves for this expedition, and he also told them the destination where he intended to go. And the Muslims who accompanied Allah's Messenger (ﷺ) at that time were large in numbers but there was no proper record of them. Ka'b (further) said: Few were the persons who wanted to absent themselves, and were under the impression that they could easily conceal themselves (and thus remain undetected) until revelations from Allah, the Exalted and Glorious (descended in connection with them). And Allah's Messenger (ﷺ) set out on an expedition when the fruits were ripe and their shadows had been lengthened. I had weakness for them and it was during this season that Allah's Messenger (ﷺ) made preparations and the Muslims too along with them. I also set out in the morning so that I should make preparations along with them but I came back and did nothing and said to myself: I have means enough (to make preparations) as soon as I like. And I went on doing this (postponing my preparations) until people were about to depart and it was in the morning that Allah's Messenger (ﷺ) set out and the Muslims too along with him, but I made no preparations. I went early in the morning and came back, but I made no decision. I continued to do so until they (the Muslims) hastened and covered a good deal of distance. I also made up my mind to march on and to meet them. Would that I had done that but perhaps it was not destined for me. After the departure of Allah's Messenger (ﷺ) as I went out amongst people, I was shocked to find that I did not find anyone like me but people who were labelled as hypocrites or the people whom Allah granted exemption because of their incapacity and Allah's Messenger (ﷺ) took no notice of me until he had reached Tabuk. (One day as he was sitting amongst the people in Tabuk) he said: What has happened to Ka'b b. Malik? A person from Banu' Salama said: Allah's Messenger, the (beauty) of his cloak and his appreciation of his sides have allured him and he was thus detained. Mua'dh b. Jabal said: Woe be upon that what you contend. Allah's Messenger, by Allah, we know nothing about him but good. Allah's Messenger (ﷺ), however, kept quiet. It was during that time that he (the Holy Prophet) saw a person (dressed in all white (garment) shattering the illusion of eye (mirage). Thereupon Allah's Messenger (ﷺ) said: May he be Abu Khaithama and, lo, it was Abu Khaithama al-Ansari and he was that person who contributed a sa' of dates and was scoffed at by the hypocrites. Ka'b b. Malik farther said: When this news reached me that Allah's Messenger (ﷺ) was on his way back from Tabuk I was greatly perturbed. I thought of fabricating false stories and asked myself how I would save myself from his anger on the following day. In this connection, I sought the help of every prudent man from amongst the members of my family and when it was said to me that Allah's Messenger (ﷺ) was about to arrive, all the false ideas banished (from my mind) and I came to the conclusion that nothing could save me but the telling of truth, so I decided to speak the truth and it was in the morning that Allah's Messenger (ﷺ) arrived (in Medina). And it was his habit that as he came back from a journey he first went to the mosque and observed two Rak'ahs of nafl prayer (as a mark of gratitude) and then sat amongst people. And as he did that, those who had remained behind him began to put forward their excuses and take an oath before him and they were more than eighty persons. Allah's Messenger (ﷺ) accepted their excuses on the very face of them and accepted their allegiance and sought forgiveness for them and left their secret (intentions) to Allah, until I presented myself to him. I greeted him and he smiled and there was a tinge of anger in that. He (the Holy Prophet) then said to me: Come forward. I went forward until I sat in front of him. He said to me: What kept you back? Could you not afford to go in for a ride? I said: Allah's Messenger, by Allah, if I were to sit in the presence of anybody else from amongst the worldly people I would have definitely saved myself from his anger on one pretext (or the other) and I have also the knack to fall into argumentation, but, by Allah, I am fully aware of the fact that if I were to put forward before you a false excuse to please you Allah would definitely provoke your wrath upon me, and if I speak the truth you may be annoyed with me, but I hope that Allah would make its end well and, by Allah, there is no valid excuse for me. By Allah, I never possessed so good means, and I never had such favourable conditions for me as I had when I stayed behind you (failed to join the expedition). Thereupon, Allah's Messenger (ﷺ) said: This man told the truth, so get up until Allah gives a decision in your case. I stood up and some people of Banu' Salama followed me in hot haste, and they said to me: By Allah, we do not know about you that you committed a sin prior to this. You, however, showed inability to put forward an excuse before Allah's Messenger (ﷺ) as those who stayed behind him have put forward excuses. It would have been enough for the forgiveness of your sin that Allah's Messenger (ﷺ) would have sought forgiveness for you. By Allah, they continued to incite me until I thought of going back to Allah's Messenger (ﷺ) and contradict myself. Then I said to them: Has anyone else also met the same fate? They said: Yes, two persons have met the same fate as has fallen to you and they have made the sane statement as you have made, and the same verdict has been delivered in their case as it has been delivered in your case. I said: Who are they? They said: Murara b. ar-Rabi'a 'Amiri and Hilal b. Umayya al-Waqafi. They made a mention of these two pious persons to me who had participated in the Battle of Badr and there was an example for me in them. I went away when they named these two persons. Allah's Messenger (ﷺ) forbade the Nluslims to talk with three of us from amongst those (persons) who had stayed behind him. The people began to avoid us and their attitude towards us underwent a change and it seemed as if the whole atmosphere had turned (hostile) against us and it was in fact the same atmosphere ot which I was fully aware and in which I had lived (for a fairly long time). We spent fifty nights in this very state and my two friends confined themselves withen their houses and spent (most of the) time in weeping, but as I was young and strong amongst them I got (out of my house), participated in congregational prayers, moved about in the bazar; but none spoke to me. I came to Allah's Messenger (ﷺ) as he sat amongst (people) after the prayer, greeted him and asked myself whether his lips stirred in response to my greetings (or not). Then I observed prayer beside him and looked at him with stealing glances and when I attended to my prayer, he looked at me and when I cast a glance at him he turned away his eyes from me. And when the harsh treatment of the Muslims towards me extended to a (considerable) length of time, I walked until I climbed upon the wall of the garden of Abu Qatada, and he was my cousin, and I had the greatest love for him. I greeted him but, by Allah, he did not respond to my greetings. I said to him: Abu Qatada, I adjure you by Allah, arn't you well aware of the fact that I love Allah and His Messenger (ﷺ) the most. He kept quiet. I again repeated saying: I adjure you by Allah. arn't you well aware of the fact that I love Allah and His Messenger (ﷺ) the most. He kept quiet. I again adjured him, whereupon he said: Allah and the Messenger (ﷺ) are best aware of it. My eyes began to shed tears and I came back climbing down from the wall and as I was walking in the bazar of Medina a Nabatean from amongst the Nabateans of Syria, who had come to sell foodgrains in Medina, asked people to direct him to Ka'b b. Malik. People gave him the indication by pointing towards me. He came to me and delivered to me a letter of the King of Ghassan and as I was a scribe I read that letter and it was written like this:" Coming to my point, it has been conveyed to us that your friend (the Holy Prophet) is subjecting you to cruelty and Allah has not created you for a place where you are to be degraded and where you cannot find your right place, so you come to us that we should accord you honour. As I read that letter I said: This is also a calamity, so I burnt it in the oven. When out of the fifty days, forty days had passed and Allah's Messenger (ﷺ) received no revelation, there came the messenger of Allah's Messenger (ﷺ) to me and said: Verily, Allah's Messenger (ﷺ) has commanded you to remain separate from your wife. I said: Should I divorce her or what (else) should I do? He said: No, but only remain separate from her and don't have sexual contact with her. The same message was sent to my companions. So I said to my wife: You better go to your parents and stay there with them until Allah gives the decision in my case. The wife of Hilal b. Umayya came to Allah's Messenger (ﷺ) and said: Allah's Messenger, Hilal b. Umayya is a senile person, he has no servant. Do you disapprove of my serving him? He said: No, but don't go near him. She said: By Allah, he has no such instinct in him. By Allah, he spends his time in weeping from that day to this day. Some of the members of my family said to me: Were you to seek permission from Allah's Messenger (ﷺ) in regard to your wife as he has granted permission to the wife of Hilal b. Umayya to serve him. I said: I would not seek permission from Allah's Messenger (ﷺ), for I cannot say what Allah's Apostle may say in response to seeking my permission. Moreover, I am a young man. It was in this state that I spent ten more nights and thus fifty nights had passed that (people) had observed boycott with us. It was on the morning of the fiftieth night that I observed my dawn prayer and was sitting on one of the roofs of our houses. And I was in fact sitting in that very state which Allah, the Exalted and Glorious, has described about us in these words:" Life had become hard for myself and the earth had compressed despite its vastness," that I heard the noise of an announcer from the peak of the hill of Sal' saying at the top of his voice: Ka'b b. Malik, there is glad tidings for you. I fell down in prostration and came to realise that there was (a message of) relief for me. Allah's Messenger (ﷺ) had informed the people of the acceptance of our repentance by Allah as he offered the dawn prayer. So the people went on to give us glad tidings and some of them went to my friends in order to give them the glad tidings and a person galloped his horse and came from the tribe of Aslam and his horse reached me more quickly than his voice. And when he came to me whose sound I heard, he gave me the glad tidings. I took off my clothes and clothed him with them because of his bringing good news to me and, by Allah, I possessed nothing else (in the form of clothes) than these two on that occasion, and I asked one to lend me two clothes and dressed myself in them. I came to Allah's Messenger (ﷺ) and on my way I met groups of people who greeted me because of (the acceptance of) repentance and they said: Here is a greeting for you for your repentance being accepted by Allah. (I moved on) until I came to the mosque and Allah's Messenger (ﷺ) had been sitting there amongst persons. So Talha b. 'Ubaidullah got up and rushed towards me and he shook hands with me and greeted me and, by Allah, no person stood up (to greet me) from amongst the emigrants except he. Ka'b said that he never forgot (this good gesture of) Talha. Ka'b further said: I greeted Allah's Messenger (ﷺ) with Assalam-o-'Alaikam and his face was glistening because of delight, and he said: Let there be glad tidings and blessings for you, the like of which (you have neither found nor you will find, as you find today) since your mother gave your birth. I said: Allah's Messenger. is this acceptance of repentance from you or from Allah? He said: No, (it is not from ma), it is from Allah, and it was common with Allah's Messenger (ﷺ) that as he was happy his face brightened up and it looked like a part of the moon and it was from this that we recognised it (his delight). As I sat before him, I said: Allah's Messenger, am I allowed to give in charity my wealth for Allah's sake and for the sake of His Messenger (ﷺ)? Thereupon Allah's Messenger (ﷺ) said: Keep some property with you as it is better for you. I said: I shall keep with me that part (of my property) which fell to my lot (on the occasion of the expedition of) Khaibar. I said: Allah's Messenger, verily, Allah has granted me salvation because of truth and, therefore, (I think) that repentance implies that I should not speak anything but truth as long as I live. He said: By Allah, I do not know whether anyone amongst the Muslims was put to more severe trial than I by Allah because of telling the truth. And since I made a mention of this to Allah's Messenger (ﷺ) up to this day I have not told any lie and, by Allah, I have decided not to tell a lie and I hope that Allah would save me (from trials) for the rest of my life and Allah, the Exalted and Glorious, revealed these verses:" Certainly, Allah has turned in Mercy to the Prophet and the emigrants and the helpers who followed him in the hour of hardship after the hearts of a part of them were about to deviate; then He turned to them in mercy. Surely, to them He is Compassionate, Merciful and (He turned in Mercy) to the three who were left behind until the earth despite its vastness became strait for them and their souls were also straitened to them." And this revelation reached up to the (words):" O you who believe, develop God consciousness, and be with the truthful" (ix. 117-118). Ka'b said: By Allah, since Allah directed me to Islam there has been no blessing more significant for me than this truth of mine which I spoke to Allah's Messenger (ﷺ) and if I were to tell a lie I would have been ruined as were ruined those who told lies, for in regard to those who told lies Allah used harshest words used for anyone as He descended revelation (and the words of Allah are):" They will swear by Allah to you when you return to them so that you may leave them alone. So leave them alone. Surely, they are unclean and their resort is Hell, recompense for what they earned. They will swear to you that you may be pleased with them but if you are pleased with them, yet surely Allah is not pleased with the transgressing people" (ix. 95-96). K'ab said that the matter of us three persons was deferred as compared with those who took an oath in the presence of Allahs Messenger (ﷺ) and he accepted their allegiance and sought forgiveness for them and Allah did not give any decision in regard to us. It was Allah, the Exalted and Glorious, Who gave decisions in our case, three who remained behind. (The words of the Qur'an)" the three who were left behind" do not mean that we remained back from Jihad but these imply that He kept our matter behind them who took oath and presented excuse before Him. This hadith has been narrated on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{7020}{\hadithno{7020}\hadithtrans{}}
\hadithdefcmd{muslim}{7076}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، أَنَّ أَهْلَ، مَكَّةَ سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يُرِيَهُمْ آيَةً فَأَرَاهُمُ انْشِقَاقَ الْقَمَرِ مَرَّتَيْنِ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، بِمَعْنَى حَدِيثِ شَيْبَانَ ‏.‏\hadithno{7076}\hadithtrans{Anas reported that the people of Mecca demanded from Allah's Messenger (ﷺ) that he should show them (some) signs (miracles) and he showed twice the splitting of the moon. This hadlth has been narrated on the authority of Anas through another chain of transmitters}}
\hadithdefcmd{muslim}{7077}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، أَنَّ أَهْلَ، مَكَّةَ سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يُرِيَهُمْ آيَةً فَأَرَاهُمُ انْشِقَاقَ الْقَمَرِ مَرَّتَيْنِ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، بِمَعْنَى حَدِيثِ شَيْبَانَ ‏.‏\hadithno{7077}\hadithtrans{Anas reported that the people of Mecca demanded from Allah's Messenger (ﷺ) that he should show them (some) signs (miracles) and he showed twice the splitting of the moon. This hadlth has been narrated on the authority of Anas through another chain of transmitters}}
\hadithdefcmd{muslim}{7080}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَأَبُو أُسَامَةَ عَنِ الأَعْمَشِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ أَحَدَ أَصْبَرُ عَلَى أَذًى يَسْمَعُهُ مِنَ اللَّهِ عَزَّ وَجَلَّ إِنَّهُ يُشْرَكُ بِهِ وَيُجْعَلُ لَهُ الْوَلَدُ ثُمَّ هُوَ يُعَافِيهِمْ وَيَرْزُقُهُمْ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا سَعِيدُ بْنُ جُبَيْرٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ إِلاَّ قَوْلَهُ ‏"‏ وَيُجْعَلُ لَهُ الْوَلَدُ ‏"‏ ‏.‏ فَإِنَّهُ لَمْ يَذْكُرْهُ ‏.‏\hadithno{7080}\hadithtrans{Abu Musa reported that Allah's Messenger (ﷺ) said:There is none to show more patience at listening to the most irksome things than Allah, the Exalted and Glorious. 'Partnership is associated to Him (polytheism), and (fatherhood) of a child is attributed to Him, but in spite of this He protects them (people) and provides them sustenance.' This hadith has been transmitted on the authority of Abu Musa with a slight variation of wording}}
\hadithdefcmd{muslim}{7081}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَأَبُو أُسَامَةَ عَنِ الأَعْمَشِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ أَحَدَ أَصْبَرُ عَلَى أَذًى يَسْمَعُهُ مِنَ اللَّهِ عَزَّ وَجَلَّ إِنَّهُ يُشْرَكُ بِهِ وَيُجْعَلُ لَهُ الْوَلَدُ ثُمَّ هُوَ يُعَافِيهِمْ وَيَرْزُقُهُمْ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا سَعِيدُ بْنُ جُبَيْرٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ السُّلَمِيِّ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ إِلاَّ قَوْلَهُ ‏"‏ وَيُجْعَلُ لَهُ الْوَلَدُ ‏"‏ ‏.‏ فَإِنَّهُ لَمْ يَذْكُرْهُ ‏.‏\hadithno{7081}\hadithtrans{Abu Musa reported that Allah's Messenger (ﷺ) said:There is none to show more patience at listening to the most irksome things than Allah, the Exalted and Glorious. 'Partnership is associated to Him (polytheism), and (fatherhood) of a child is attributed to Him, but in spite of this He protects them (people) and provides them sustenance.' This hadith has been transmitted on the authority of Abu Musa with a slight variation of wording}}
\hadithdefcmd{muslim}{7111}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ بُكَيْرٍ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لَنْ يُنْجِيَ أَحَدًا مِنْكُمْ عَمَلُهُ ‏"‏ ‏.‏ قَالَ رَجُلٌ وَلاَ إِيَّاكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَلاَ إِيَّاىَ إِلاَّ أَنْ يَتَغَمَّدَنِيَ اللَّهُ مِنْهُ بِرَحْمَةٍ وَلَكِنْ سَدِّدُوا ‏"‏ ‏.‏ وَحَدَّثَنِيهِ يُونُسُ بْنُ عَبْدِ الأَعْلَى الصَّدَفِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو، بْنُ الْحَارِثِ عَنْ بُكَيْرِ بْنِ الأَشَجِّ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ ‏"‏ بِرَحْمَةٍ مِنْهُ وَفَضْلٍ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ ‏"‏ وَلَكِنْ سَدِّدُوا ‏"‏ ‏.‏\hadithno{7111}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:None amongst you would attain salvation purely because of his deeds. A person said: Allah's Messenger, even you? Thereupon he said: Yes, not even I except that Allah wraps me in Mercy, but you should act with moderation. This hadith has been transmitted on the authority of Bukair b. al-Ashajj with a slight variation of wording}}
\hadithdefcmd{muslim}{7112}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ بُكَيْرٍ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لَنْ يُنْجِيَ أَحَدًا مِنْكُمْ عَمَلُهُ ‏"‏ ‏.‏ قَالَ رَجُلٌ وَلاَ إِيَّاكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَلاَ إِيَّاىَ إِلاَّ أَنْ يَتَغَمَّدَنِيَ اللَّهُ مِنْهُ بِرَحْمَةٍ وَلَكِنْ سَدِّدُوا ‏"‏ ‏.‏ وَحَدَّثَنِيهِ يُونُسُ بْنُ عَبْدِ الأَعْلَى الصَّدَفِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو، بْنُ الْحَارِثِ عَنْ بُكَيْرِ بْنِ الأَشَجِّ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ ‏"‏ بِرَحْمَةٍ مِنْهُ وَفَضْلٍ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ ‏"‏ وَلَكِنْ سَدِّدُوا ‏"‏ ‏.‏\hadithno{7112}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:None amongst you would attain salvation purely because of his deeds. A person said: Allah's Messenger, even you? Thereupon he said: Yes, not even I except that Allah wraps me in Mercy, but you should act with moderation. This hadith has been transmitted on the authority of Bukair b. al-Ashajj with a slight variation of wording}}
\hadithdefcmd{muslim}{7138}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا الْمَخْزُومِيُّ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَبِي، حَازِمٍ عَنْ سَهْلِ بْنِ سَعْدٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ فِي الْجَنَّةِ لَشَجَرَةً يَسِيرُ الرَّاكِبُ فِي ظِلِّهَا مِائَةَ عَامٍ لاَ يَقْطَعُهَا ‏"‏ ‏.‏ قَالَ أَبُو حَازِمٍ فَحَدَّثْتُ بِهِ النُّعْمَانَ بْنَ أَبِي عَيَّاشٍ الزُّرَقِيَّ، فَقَالَ حَدَّثَنِي أَبُو سَعِيدٍ الْخُدْرِيُّ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ فِي الْجَنَّةِ شَجَرَةً يَسِيرُ الرَّاكِبُ الْجَوَادَ الْمُضَمَّرَ السَّرِيعَ مِائَةَ عَامٍ مَا يَقْطَعُهَا ‏"‏ ‏.‏\hadithno{7138}\hadithtrans{Sahl b. Sa'd reported Allah's Messenger (ﷺ) as saying:In Paradise, there is a tree under the shadow of which a rider can travel for a hundred years without covering (the distance) completely. This hadith has also been transmitted on the authority of Abu Sa'id al-Khudri that Allah's Apostle (ﷺ) is reported to have said: In Paradise, there is a tree under the shadow of which a rider of a fine and swift-footed horse would travel for a hundred years without covering the distance completely. There would be the pleasure of Allah for the inmates of Paradise and He would never be annoyed with them}}
\hadithdefcmd{muslim}{7141}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ أَهْلَ الْجَنَّةِ لَيَتَرَاءَوْنَ الْغُرْفَةَ فِي الْجَنَّةِ كَمَا تَرَاءَوْنَ الْكَوْكَبَ فِي السَّمَاءِ ‏"‏ ‏.‏ قَالَ فَحَدَّثْتُ بِذَلِكَ النُّعْمَانَ بْنَ أَبِي عَيَّاشٍ، فَقَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ كَمَا تَرَاءَوْنَ الْكَوْكَبَ الدُّرِّيَّ فِي الأُفُقِ الشَّرْقِيِّ أَوِ الْغَرْبِيِّ ‏"‏ ‏.‏\hadithno{7141}\hadithtrans{Sahl b. Sa'd reported Allah's Messenger (ﷺ) as saying:The inmates of Paradise will look to the upper apartment of Paradise as you see the planets in the sky. I narrated this hadith to Nu'man b. Abi 'Ayyash and he said: I heard Abu Sa'id al-Khudri as saying: As you see the shining planets in the eastern and western (sides of) horizon}}
\hadithdefcmd{muslim}{7144}{\hadithno{7144}\hadithtrans{}}
\hadithdefcmd{muslim}{7256}{\hadithno{7256}\hadithtrans{}}
\hadithdefcmd{muslim}{7301}{\hadithno{7301}\hadithtrans{}}
\hadithdefcmd{muslim}{7302}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ بْنِ مُحَمَّدِ بْنِ أَبَانَ بْنِ صَالِحٍ، وَمُحَمَّدُ بْنُ يَزِيدَ الرِّفَاعِيُّ، - وَاللَّفْظُ لاِبْنِ أَبَانَ - قَالاَ حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ أَبِي إِسْمَاعِيلَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي، هُرَيْرَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لاَ تَذْهَبُ الدُّنْيَا حَتَّى يَمُرَّ الرَّجُلُ عَلَى الْقَبْرِ فَيَتَمَرَّغُ عَلَيْهِ وَيَقُولُ يَا لَيْتَنِي كُنْتُ مَكَانَ صَاحِبِ هَذَا الْقَبْرِ وَلَيْسَ بِهِ الدِّينُ إِلاَّ الْبَلاَءُ ‏"‏ ‏.‏\hadithno{7302}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:By Him, in Whose hand is my life, the world would not come to an end until a person would pass by a grave, would roll over it and express the desire that he should be in the place of the occupant of that grave not because of religious reasons but because of this calamity}}
\hadithdefcmd{muslim}{7319}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا أَبِي، حَدَّثَنَا دَاوُدُ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، وَجَابِرِ بْنِ عَبْدِ اللَّهِ، قَالاَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَكُونُ فِي آخِرِ الزَّمَانِ خَلِيفَةٌ يَقْسِمُ الْمَالَ وَلاَ يَعُدُّهُ ‏"‏ ‏.‏\hadithno{7319}\hadithtrans{Abu Sa'id and Jabir b. Abdullah reported that Allah's Messenger (ﷺ) said:There would be in the last phase of the time a caliph who would distribute wealth but would not count}}
\hadithdefcmd{muslim}{7325}{\hadithno{7325}\hadithtrans{}}
\hadithdefcmd{muslim}{7329}{\hadithno{7329}\hadithtrans{}}
\hadithdefcmd{muslim}{7330}{\hadithno{7330}\hadithtrans{}}
\hadithdefcmd{muslim}{7331}{\hadithno{7331}\hadithtrans{}}
\hadithdefcmd{muslim}{7332}{\hadithno{7332}\hadithtrans{}}
\hadithdefcmd{muslim}{7333}{\hadithno{7333}\hadithtrans{}}
\hadithdefcmd{muslim}{7334}{\hadithno{7334}\hadithtrans{}}
\hadithdefcmd{muslim}{7335}{\hadithno{7335}\hadithtrans{}}
\hadithdefcmd{muslim}{7336}{\hadithno{7336}\hadithtrans{}}
\hadithdefcmd{muslim}{7337}{\hadithno{7337}\hadithtrans{}}
\hadithdefcmd{muslim}{7338}{\hadithno{7338}\hadithtrans{}}
\hadithdefcmd{muslim}{7339}{\hadithno{7339}\hadithtrans{}}
\hadithdefcmd{muslim}{7340}{\hadithno{7340}\hadithtrans{}}
\hadithdefcmd{muslim}{7341}{\hadithno{7341}\hadithtrans{}}
\hadithdefcmd{muslim}{7342}{\hadithno{7342}\hadithtrans{}}
\hadithdefcmd{muslim}{7343}{\hadithno{7343}\hadithtrans{}}
\hadithdefcmd{muslim}{7354}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ حَرْمَلَةَ بْنِ عِمْرَانَ التُّجِيبِيُّ، أَخْبَرَنِي ابْنُ، وَهْبٍ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ أَخْبَرَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ انْطَلَقَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَهْطٍ قِبَلَ ابْنِ صَيَّادٍ حَتَّى وَجَدَهُ يَلْعَبُ مَعَ الصِّبْيَانِ عِنْدَ أُطُمِ بَنِي مَغَالَةَ وَقَدْ قَارَبَ ابْنُ صَيَّادٍ يَوْمَئِذٍ الْحُلُمَ فَلَمْ يَشْعُرْ حَتَّى ضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ظَهْرَهُ بِيَدِهِ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاِبْنِ صَيَّادٍ ‏"‏ أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ ‏"‏ ‏.‏ فَنَظَرَ إِلَيْهِ ابْنُ صَيَّادٍ فَقَالَ أَشْهَدُ أَنَّكَ رَسُولُ الأُمِّيِّينَ ‏.‏ فَقَالَ ابْنُ صَيَّادٍ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ فَرَفَضَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ آمَنْتُ بِاللَّهِ وَبِرُسُلِهِ ‏"‏ ‏.‏ ثُمَّ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَاذَا تَرَى ‏"‏ ‏.‏ قَالَ ابْنُ صَيَّادٍ يَأْتِينِي صَادِقٌ وَكَاذِبٌ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خُلِّطَ عَلَيْكَ الأَمْرُ ‏"‏ ‏.‏ ثُمَّ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي قَدْ خَبَأْتُ لَكَ خَبِيئًا ‏"‏ ‏.‏ فَقَالَ ابْنُ صَيَّادٍ ‏"‏ هُوَ الدُّخُّ ‏"‏ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اخْسَأْ فَلَنْ تَعْدُوَ قَدْرَكَ ‏"‏ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ ذَرْنِي يَا رَسُولَ اللَّهِ أَضْرِبْ عُنُقَهُ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ يَكُنْهُ فَلَنْ تُسَلَّطَ عَلَيْهِ وَإِنْ لَمْ يَكُنْهُ فَلاَ خَيْرَ لَكَ فِي قَتْلِهِ ‏"‏ ‏.‏ وَقَالَ سَالِمُ بْنُ عَبْدِ اللَّهِ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ انْطَلَقَ بَعْدَ ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأُبَىُّ بْنُ كَعْبٍ الأَنْصَارِيُّ إِلَى النَّخْلِ الَّتِي فِيهَا ابْنُ صَيَّادٍ حَتَّى إِذَا دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّخْلَ طَفِقَ يَتَّقِي بِجُذُوعِ النَّخْلِ وَهُوَ يَخْتِلُ أَنْ يَسْمَعَ مِنِ ابْنِ صَيَّادٍ شَيْئًا قَبْلَ أَنْ يَرَاهُ ابْنُ صَيَّادٍ فَرَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ مُضْطَجِعٌ عَلَى فِرَاشٍ فِي قَطِيفَةٍ لَهُ فِيهَا زَمْزَمَةٌ فَرَأَتْ أُمُّ ابْنِ صَيَّادٍ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يَتَّقِي بِجُذُوعِ النَّخْلِ فَقَالَتْ لاِبْنِ صَيَّادٍ يَا صَافِ - وَهُوَ اسْمُ ابْنِ صَيَّادٍ - هَذَا مُحَمَّدٌ ‏.‏ فَثَارَ ابْنُ صَيَّادٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ تَرَكَتْهُ بَيَّنَ ‏"‏ ‏.‏ قَالَ سَالِمٌ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّاسِ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ ذَكَرَ الدَّجَّالَ فَقَالَ ‏"‏ إِنِّي لأُنْذِرُكُمُوهُ مَا مِنْ نَبِيٍّ إِلاَّ وَقَدْ أَنْذَرَهُ قَوْمَهُ لَقَدْ أَنْذَرَهُ نُوحٌ قَوْمَهُ وَلَكِنْ أَقُولُ لَكُمْ فِيهِ قَوْلاً لَمْ يَقُلْهُ نَبِيٌّ لِقَوْمِهِ تَعَلَّمُوا أَنَّهُ أَعْوَرُ وَأَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى لَيْسَ بِأَعْوَرَ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ وَأَخْبَرَنِي عُمَرُ بْنُ ثَابِتٍ الأَنْصَارِيُّ أَنَّهُ أَخْبَرَهُ بَعْضُ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ يَوْمَ حَذَّرَ النَّاسَ الدَّجَّالَ ‏"‏ إِنَّهُ مَكْتُوبٌ بَيْنَ عَيْنَيْهِ كَافِرٌ يَقْرَؤُهُ مَنْ كَرِهَ عَمَلَهُ أَوْ يَقْرَؤُهُ كُلُّ مُؤْمِنٍ ‏"‏ ‏.‏ وَقَالَ ‏"‏ تَعَلَّمُوا أَنَّهُ لَنْ يَرَى أَحَدٌ مِنْكُمْ رَبَّهُ عَزَّ وَجَلَّ حَتَّى يَمُوتَ ‏"‏ ‏.‏\hadithno{7354}\hadithtrans{Abdullah b. Umar reported:'Umar b. Khattab went along with Allah's Messenger (ﷺ) in the company of some persons to Ibn Sayyad that he found him playing with children near the battlement of Bani Maghala and Ibn Sayyad was at that time just at the threshold of adolescence and he did not perceive (the presence of Holy Prophet) until Allah's Messenger (ﷺ) struck his back with his hands. Allah's Messenger (ﷺ) said: Ibn Sayyad, don't you bear witness that I am the messenger of Allah? Ibn Sayyad looked toward him and he said: I bear witness to the fact that you the messenger of the unlettered. Ibn Sayyad said to the Allah's Messenger (ﷺ): Do you bear witness to the fact that I am the messenger of Allah? Allah's Messenger (ﷺ) rejected this and said: I affirm my faith in Allah and in His messengers. Then Allah's Messenger (ﷺ) said to him: What do you see? Ibn Sayyad said: It is a Dukh. Thereupon Allah's Messenger (ﷺ) said: May you be disgraced and dishonoured, you would not not be able to go beyond your rank. 'Umar b. Khattab said: Allah's Messenger, permit me that I should strike his neck. Thereupon Allah's Messenger (ﷺ) said: If he is the same (Dajjal) who would appear near the Last Hour, you would not be able to overpower him, and if he is not that there is no good for you to kill him. 'Abdullah b. 'Umar further narrated that after some time Allah's Messenger (ﷺ) and Ubayy b. Ka'b went towards the palm trees where Ibn Sayyad was. When Allah's Messenger (ﷺ) went near the tree he hid himself behind a tree with the intention of hearing something from Ibn sayyad before Ibn Sayyad could see him, but Allah's Messenger (ﷺ) saw him on a bed with a blanket around him from which a murmuring sound was being heard and Ibn Sayyad's mother saw Allah's Messenger (ﷺ) behind the trunk of the palm tree. She said to Ibn Sayyad: Saf (that being his name), here is Muhammad. Thereupon Ibn Sayyad jumped up murmuring and Allah's Messenger (ﷺ) said: If she had left him alone he would have made things clear. Abdullah b. Umar told that Allah's Messenger (ﷺ) stood up amongst the people and lauded Allah as He deserved, then he made a mention of the Dajjal and said: I warn you of him and there is no Prophet who has not warned his people against the Dajjal. Even Noah warned (against him) but I am going to tell you a thing which no Prophet told his people. You must know that he (the Dajjal) is one-eyed and Allah, the Exalted and Glorious, is not one-eyed. Ibn Shihab said: 'Umar b. Thabit al-Ansari informed me that some of the Companions of Allah's Messenger (ﷺ) informed him that the day when Allah's Messenger (ﷺ) warned people against the Dajjal, he also said: There would be written between his two eyes (the word) Kafir (infidel) and everyone who would resent his deeds would be able to read or every Muslim would be about to read, and he also said: Bear this thing in mind that none amongst you would be able to see Allah, the Exalted and Glorious, until he dies}}
\hadithdefcmd{muslim}{7355}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ حَرْمَلَةَ بْنِ عِمْرَانَ التُّجِيبِيُّ، أَخْبَرَنِي ابْنُ، وَهْبٍ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ أَخْبَرَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ انْطَلَقَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَهْطٍ قِبَلَ ابْنِ صَيَّادٍ حَتَّى وَجَدَهُ يَلْعَبُ مَعَ الصِّبْيَانِ عِنْدَ أُطُمِ بَنِي مَغَالَةَ وَقَدْ قَارَبَ ابْنُ صَيَّادٍ يَوْمَئِذٍ الْحُلُمَ فَلَمْ يَشْعُرْ حَتَّى ضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ظَهْرَهُ بِيَدِهِ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاِبْنِ صَيَّادٍ ‏"‏ أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ ‏"‏ ‏.‏ فَنَظَرَ إِلَيْهِ ابْنُ صَيَّادٍ فَقَالَ أَشْهَدُ أَنَّكَ رَسُولُ الأُمِّيِّينَ ‏.‏ فَقَالَ ابْنُ صَيَّادٍ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ فَرَفَضَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ آمَنْتُ بِاللَّهِ وَبِرُسُلِهِ ‏"‏ ‏.‏ ثُمَّ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَاذَا تَرَى ‏"‏ ‏.‏ قَالَ ابْنُ صَيَّادٍ يَأْتِينِي صَادِقٌ وَكَاذِبٌ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خُلِّطَ عَلَيْكَ الأَمْرُ ‏"‏ ‏.‏ ثُمَّ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي قَدْ خَبَأْتُ لَكَ خَبِيئًا ‏"‏ ‏.‏ فَقَالَ ابْنُ صَيَّادٍ ‏"‏ هُوَ الدُّخُّ ‏"‏ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اخْسَأْ فَلَنْ تَعْدُوَ قَدْرَكَ ‏"‏ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ ذَرْنِي يَا رَسُولَ اللَّهِ أَضْرِبْ عُنُقَهُ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ يَكُنْهُ فَلَنْ تُسَلَّطَ عَلَيْهِ وَإِنْ لَمْ يَكُنْهُ فَلاَ خَيْرَ لَكَ فِي قَتْلِهِ ‏"‏ ‏.‏ وَقَالَ سَالِمُ بْنُ عَبْدِ اللَّهِ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ انْطَلَقَ بَعْدَ ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأُبَىُّ بْنُ كَعْبٍ الأَنْصَارِيُّ إِلَى النَّخْلِ الَّتِي فِيهَا ابْنُ صَيَّادٍ حَتَّى إِذَا دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّخْلَ طَفِقَ يَتَّقِي بِجُذُوعِ النَّخْلِ وَهُوَ يَخْتِلُ أَنْ يَسْمَعَ مِنِ ابْنِ صَيَّادٍ شَيْئًا قَبْلَ أَنْ يَرَاهُ ابْنُ صَيَّادٍ فَرَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ مُضْطَجِعٌ عَلَى فِرَاشٍ فِي قَطِيفَةٍ لَهُ فِيهَا زَمْزَمَةٌ فَرَأَتْ أُمُّ ابْنِ صَيَّادٍ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يَتَّقِي بِجُذُوعِ النَّخْلِ فَقَالَتْ لاِبْنِ صَيَّادٍ يَا صَافِ - وَهُوَ اسْمُ ابْنِ صَيَّادٍ - هَذَا مُحَمَّدٌ ‏.‏ فَثَارَ ابْنُ صَيَّادٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ تَرَكَتْهُ بَيَّنَ ‏"‏ ‏.‏ قَالَ سَالِمٌ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّاسِ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ ذَكَرَ الدَّجَّالَ فَقَالَ ‏"‏ إِنِّي لأُنْذِرُكُمُوهُ مَا مِنْ نَبِيٍّ إِلاَّ وَقَدْ أَنْذَرَهُ قَوْمَهُ لَقَدْ أَنْذَرَهُ نُوحٌ قَوْمَهُ وَلَكِنْ أَقُولُ لَكُمْ فِيهِ قَوْلاً لَمْ يَقُلْهُ نَبِيٌّ لِقَوْمِهِ تَعَلَّمُوا أَنَّهُ أَعْوَرُ وَأَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى لَيْسَ بِأَعْوَرَ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ وَأَخْبَرَنِي عُمَرُ بْنُ ثَابِتٍ الأَنْصَارِيُّ أَنَّهُ أَخْبَرَهُ بَعْضُ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ يَوْمَ حَذَّرَ النَّاسَ الدَّجَّالَ ‏"‏ إِنَّهُ مَكْتُوبٌ بَيْنَ عَيْنَيْهِ كَافِرٌ يَقْرَؤُهُ مَنْ كَرِهَ عَمَلَهُ أَوْ يَقْرَؤُهُ كُلُّ مُؤْمِنٍ ‏"‏ ‏.‏ وَقَالَ ‏"‏ تَعَلَّمُوا أَنَّهُ لَنْ يَرَى أَحَدٌ مِنْكُمْ رَبَّهُ عَزَّ وَجَلَّ حَتَّى يَمُوتَ ‏"‏ ‏.‏\hadithno{7355}\hadithtrans{Abdullah b. Umar reported:'Umar b. Khattab went along with Allah's Messenger (ﷺ) in the company of some persons to Ibn Sayyad that he found him playing with children near the battlement of Bani Maghala and Ibn Sayyad was at that time just at the threshold of adolescence and he did not perceive (the presence of Holy Prophet) until Allah's Messenger (ﷺ) struck his back with his hands. Allah's Messenger (ﷺ) said: Ibn Sayyad, don't you bear witness that I am the messenger of Allah? Ibn Sayyad looked toward him and he said: I bear witness to the fact that you the messenger of the unlettered. Ibn Sayyad said to the Allah's Messenger (ﷺ): Do you bear witness to the fact that I am the messenger of Allah? Allah's Messenger (ﷺ) rejected this and said: I affirm my faith in Allah and in His messengers. Then Allah's Messenger (ﷺ) said to him: What do you see? Ibn Sayyad said: It is a Dukh. Thereupon Allah's Messenger (ﷺ) said: May you be disgraced and dishonoured, you would not not be able to go beyond your rank. 'Umar b. Khattab said: Allah's Messenger, permit me that I should strike his neck. Thereupon Allah's Messenger (ﷺ) said: If he is the same (Dajjal) who would appear near the Last Hour, you would not be able to overpower him, and if he is not that there is no good for you to kill him. 'Abdullah b. 'Umar further narrated that after some time Allah's Messenger (ﷺ) and Ubayy b. Ka'b went towards the palm trees where Ibn Sayyad was. When Allah's Messenger (ﷺ) went near the tree he hid himself behind a tree with the intention of hearing something from Ibn sayyad before Ibn Sayyad could see him, but Allah's Messenger (ﷺ) saw him on a bed with a blanket around him from which a murmuring sound was being heard and Ibn Sayyad's mother saw Allah's Messenger (ﷺ) behind the trunk of the palm tree. She said to Ibn Sayyad: Saf (that being his name), here is Muhammad. Thereupon Ibn Sayyad jumped up murmuring and Allah's Messenger (ﷺ) said: If she had left him alone he would have made things clear. Abdullah b. Umar told that Allah's Messenger (ﷺ) stood up amongst the people and lauded Allah as He deserved, then he made a mention of the Dajjal and said: I warn you of him and there is no Prophet who has not warned his people against the Dajjal. Even Noah warned (against him) but I am going to tell you a thing which no Prophet told his people. You must know that he (the Dajjal) is one-eyed and Allah, the Exalted and Glorious, is not one-eyed. Ibn Shihab said: 'Umar b. Thabit al-Ansari informed me that some of the Companions of Allah's Messenger (ﷺ) informed him that the day when Allah's Messenger (ﷺ) warned people against the Dajjal, he also said: There would be written between his two eyes (the word) Kafir (infidel) and everyone who would resent his deeds would be able to read or every Muslim would be about to read, and he also said: Bear this thing in mind that none amongst you would be able to see Allah, the Exalted and Glorious, until he dies}}
\hadithdefcmd{muslim}{7368}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لَهُ - حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ رِبْعِيِّ بْنِ، حِرَاشٍ عَنْ حُذَيْفَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ فِي الدَّجَّالِ ‏ "‏ إِنَّ مَعَهُ مَاءً وَنَارًا فَنَارُهُ مَاءٌ بَارِدٌ وَمَاؤُهُ نَارٌ فَلاَ تَهْلِكُوا ‏"‏ ‏.‏ قَالَ أَبُو مَسْعُودٍ وَأَنَا سَمِعْتُهُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{7368}\hadithtrans{Hudhaifa reported Allah's Messenger (ﷺ) as saying:the Dajjal would have with him water and fire and his fire would have the effect of cold water and his water would have the effect of fire, so don't put yourself to ruin. Abu Mas'ud reported: I also heard it from Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{7371}{\hadithno{7371}\hadithtrans{}}
\hadithdefcmd{muslim}{7447}{\hadithno{7447}\hadithtrans{}}
\hadithdefcmd{muslim}{7448}{\hadithno{7448}\hadithtrans{}}
\hadithdefcmd{muslim}{7449}{\hadithno{7449}\hadithtrans{}}
\hadithdefcmd{muslim}{7450}{\hadithno{7450}\hadithtrans{}}
\hadithdefcmd{muslim}{7451}{\hadithno{7451}\hadithtrans{}}
\hadithdefcmd{muslim}{7452}{\hadithno{7452}\hadithtrans{}}
\hadithdefcmd{muslim}{7453}{\hadithno{7453}\hadithtrans{}}
\hadithdefcmd{muslim}{7454}{\hadithno{7454}\hadithtrans{}}
\hadithdefcmd{muslim}{7455}{\hadithno{7455}\hadithtrans{}}
\hadithdefcmd{muslim}{7456}{\hadithno{7456}\hadithtrans{}}
\hadithdefcmd{muslim}{7457}{\hadithno{7457}\hadithtrans{}}
\hadithdefcmd{muslim}{7458}{\hadithno{7458}\hadithtrans{}}
\hadithdefcmd{muslim}{7459}{\hadithno{7459}\hadithtrans{}}
\hadithdefcmd{muslim}{7460}{\hadithno{7460}\hadithtrans{}}
\hadithdefcmd{muslim}{7461}{\hadithno{7461}\hadithtrans{}}
\hadithdefcmd{muslim}{7462}{\hadithno{7462}\hadithtrans{}}
\hadithdefcmd{muslim}{7463}{\hadithno{7463}\hadithtrans{}}
\hadithdefcmd{muslim}{7498}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُلْدَغُ الْمُؤْمِنُ مِنْ جُحْرٍ وَاحِدٍ مَرَّتَيْنِ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ حَاتِمٍ، قَالاَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَخِي، ابْنِ شِهَابٍ عَنْ عَمِّهِ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{7498}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said:The believer does not allow to be stung twice from one (and the same) hole. This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{7499}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُلْدَغُ الْمُؤْمِنُ مِنْ جُحْرٍ وَاحِدٍ مَرَّتَيْنِ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ حَاتِمٍ، قَالاَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَخِي، ابْنِ شِهَابٍ عَنْ عَمِّهِ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{7499}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said:The believer does not allow to be stung twice from one (and the same) hole. This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{7512}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، وَمُحَمَّدُ بْنُ عَبَّادٍ، - وَتَقَارَبَا فِي لَفْظِ الْحَدِيثِ - وَالسِّيَاقُ لِهَارُونَ قَالاَ حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ عَنْ يَعْقُوبَ بْنِ مُجَاهِدٍ أَبِي حَزْرَةَ عَنْ عُبَادَةَ بْنِ الْوَلِيدِ بْنِ عُبَادَةَ بْنِ الصَّامِتِ قَالَ خَرَجْتُ أَنَا وَأَبِي نَطْلُبُ الْعِلْمَ فِي هَذَا الْحَىِّ مِنَ الأَنْصَارِ قَبْلَ أَنْ يَهْلِكُوا فَكَانَ أَوَّلُ مَنْ لَقِينَا أَبَا الْيَسَرِ صَاحِبَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَعَهُ غُلاَمٌ لَهُ مَعَهُ ضِمَامَةٌ مِنْ صُحُفٍ وَعَلَى أَبِي الْيَسَرِ بُرْدَةٌ وَمَعَافِرِيٌّ وَعَلَى غُلاَمِهِ بُرْدَةٌ وَمَعَافِرِيٌّ فَقَالَ لَهُ أَبِي يَا عَمِّ إِنِّي أَرَى فِي وَجْهِكَ سَفْعَةً مِنْ غَضَبٍ ‏.‏ قَالَ أَجَلْ كَانَ لِي عَلَى فُلاَنِ بْنِ فُلاَنٍ الْحَرَامِيِّ مَالٌ فَأَتَيْتُ أَهْلَهُ فَسَلَّمْتُ فَقُلْتُ ثَمَّ هُوَ قَالُوا لاَ ‏.‏ فَخَرَجَ عَلَىَّ ابْنٌ لَهُ جَفْرٌ فَقُلْتُ لَهُ أَيْنَ أَبُوكَ قَالَ سَمِعَ صَوْتَكَ فَدَخَلَ أَرِيكَةَ أُمِّي ‏.‏ فَقُلْتُ اخْرُجْ إِلَىَّ فَقَدْ عَلِمْتُ أَيْنَ أَنْتَ ‏.‏ فَخَرَجَ فَقُلْتُ مَا حَمَلَكَ عَلَى أَنِ اخْتَبَأْتَ مِنِّي قَالَ أَنَا وَاللَّهِ أُحَدِّثُكَ ثُمَّ لاَ أَكْذِبُكَ خَشِيتُ وَاللَّهِ أَنْ أُحَدِّثَكَ فَأَكْذِبَكَ وَأَنْ أَعِدَكَ فَأُخْلِفَكَ وَكُنْتَ صَاحِبَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكُنْتُ وَاللَّهِ مُعْسِرًا ‏.‏ قَالَ قُلْتُ آللَّهِ ‏.‏ قَالَ اللَّهِ ‏.‏ قُلْتُ آللَّهِ ‏.‏ قَالَ اللَّهِ ‏.‏ قُلْتُ آللَّهِ ‏.‏ قَالَ اللَّهِ ‏.‏ قَالَ فَأَتَى بِصَحِيفَتِهِ فَمَحَاهَا بِيَدِهِ فَقَالَ إِنْ وَجَدْتَ قَضَاءً فَاقْضِنِي وَإِلاَّ أَنْتَ فِي حِلٍّ فَأَشْهَدُ بَصَرُ عَيْنَىَّ هَاتَيْنِ - وَوَضَعَ إِصْبَعَيْهِ عَلَى عَيْنَيْهِ - وَسَمْعُ أُذُنَىَّ هَاتَيْنِ وَوَعَاهُ قَلْبِي هَذَا - وَأَشَارَ إِلَى مَنَاطِ قَلْبِهِ - رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يَقُولُ ‏"‏ مَنْ أَنْظَرَ مُعْسِرًا أَوْ وَضَعَ عَنْهُ أَظَلَّهُ اللَّهُ فِي ظِلِّهِ ‏"‏ ‏.‏ قَالَ فَقُلْتُ لَهُ أَنَا يَا عَمِّ لَوْ أَنَّكَ أَخَذْتَ بُرْدَةَ غُلاَمِكَ وَأَعْطَيْتَهُ مَعَافِرِيَّكَ وَأَخَذْتَ مَعَافِرِيَّهُ وَأَعْطَيْتَهُ بُرْدَتَكَ فَكَانَتْ عَلَيْكَ حُلَّةٌ وَعَلَيْهِ حُلَّةٌ ‏.‏ فَمَسَحَ رَأْسِي وَقَالَ اللَّهُمَّ بَارِكْ فِيهِ يَا ابْنَ أَخِي بَصَرُ عَيْنَىَّ هَاتَيْنِ وَسَمْعُ أُذُنَىَّ هَاتَيْنِ وَوَعَاهُ قَلْبِي هَذَا - وَأَشَارَ إِلَى مَنَاطِ قَلْبِهِ - رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يَقُولُ ‏"‏ أَطْعِمُوهُمْ مِمَّا تَأْكُلُونَ وَأَلْبِسُوهُمْ مِمَّا تَلْبَسُونَ ‏"‏ ‏.‏ وَكَانَ أَنْ أَعْطَيْتُهُ مِنْ مَتَاعِ الدُّنْيَا أَهْوَنَ عَلَىَّ مِنْ أَنْ يَأْخُذَ مِنْ حَسَنَاتِي يَوْمَ الْقِيَامَةِ ‏.‏ ثُمَّ مَضَيْنَا حَتَّى أَتَيْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ فِي مَسْجِدِهِ وَهُوَ يُصَلِّي فِي ثَوْبٍ وَاحِدٍ مُشْتَمِلاً بِهِ فَتَخَطَّيْتُ الْقَوْمَ حَتَّى جَلَسْتُ بَيْنَهُ وَبَيْنَ الْقِبْلَةِ فَقُلْتُ يَرْحَمُكَ اللَّهُ أَتُصَلِّي فِي ثَوْبٍ وَاحِدٍ وَرِدَاؤُكَ إِلَى جَنْبِكَ قَالَ فَقَالَ بِيَدِهِ فِي صَدْرِي هَكَذَا وَفَرَّقَ بَيْنَ أَصَابِعِهِ وَقَوَّسَهَا أَرَدْتُ أَنْ يَدْخُلَ عَلَىَّ الأَحْمَقُ مِثْلُكَ فَيَرَانِي كَيْفَ أَصْنَعُ فَيَصْنَعُ مِثْلَهُ ‏.‏ أَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مَسْجِدِنَا هَذَا وَفِي يَدِهِ عُرْجُونُ ابْنِ طَابٍ فَرَأَى فِي قِبْلَةِ الْمَسْجِدِ نُخَامَةً فَحَكَّهَا بِالْعُرْجُونِ ثُمَّ أَقْبَلَ عَلَيْنَا فَقَالَ ‏"‏ أَيُّكُمْ يُحِبُّ أَنْ يُعْرِضَ اللَّهُ عَنْهُ ‏"‏ ‏.‏ قَالَ فَخَشَعْنَا ثُمَّ قَالَ ‏"‏ أَيُّكُمْ يُحِبُّ أَنْ يُعْرِضَ اللَّهُ عَنْهُ ‏"‏ ‏.‏ قَالَ فَخَشَعْنَا ثُمَّ قَالَ ‏"‏ أَيُّكُمْ يُحِبُّ أَنْ يُعْرِضَ اللَّهُ عَنْهُ ‏"‏ ‏.‏ قُلْنَا لاَ أَيُّنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَإِنَّ أَحَدَكُمْ إِذَا قَامَ يُصَلِّي فَإِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى قِبَلَ وَجْهِهِ فَلاَ يَبْصُقَنَّ قِبَلَ وَجْهِهِ وَلاَ عَنْ يَمِينِهِ وَلْيَبْصُقْ عَنْ يَسَارِهِ تَحْتَ رِجْلِهِ الْيُسْرَى فَإِنْ عَجِلَتْ بِهِ بَادِرَةٌ فَلْيَقُلْ بِثَوْبِهِ هَكَذَا ‏"‏ ‏.‏ ثُمَّ طَوَى ثَوْبَهُ بَعْضَهُ عَلَى بَعْضٍ فَقَالَ ‏"‏ أَرُونِي عَبِيرًا ‏"‏ ‏.‏ فَقَامَ فَتًى مِنَ الْحَىِّ يَشْتَدُّ إِلَى أَهْلِهِ فَجَاءَ بِخَلُوقٍ فِي رَاحَتِهِ فَأَخَذَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَعَلَهُ عَلَى رَأْسِ الْعُرْجُونِ ثُمَّ لَطَخَ بِهِ عَلَى أَثَرِ النُّخَامَةِ ‏.‏ فَقَالَ جَابِرٌ فَمِنْ هُنَاكَ جَعَلْتُمُ الْخَلُوقَ فِي مَسَاجِدِكُمْ ‏.‏ سِرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ بَطْنِ بُوَاطٍ وَهُوَ يَطْلُبُ الْمَجْدِيَّ بْنَ عَمْرٍو الْجُهَنِيَّ وَكَانَ النَّاضِحُ يَعْتَقِبُهُ مِنَّا الْخَمْسَةُ وَالسِّتَّةُ وَالسَّبْعَةُ فَدَارَتْ عُقْبَةُ رَجُلٍ مِنَ الأَنْصَارِ عَلَى نَاضِحٍ لَهُ فَأَنَاخَهُ فَرَكِبَهُ ثُمَّ بَعَثَهُ فَتَلَدَّنَ عَلَيْهِ بَعْضَ التَّلَدُّنِ فَقَالَ لَهُ شَأْ لَعَنَكَ اللَّهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ هَذَا اللاَّعِنُ بَعِيرَهُ ‏"‏ ‏.‏ قَالَ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ انْزِلْ عَنْهُ فَلاَ تَصْحَبْنَا بِمَلْعُونٍ لاَ تَدْعُوا عَلَى أَنْفُسِكُمْ وَلاَ تَدْعُوا عَلَى أَوْلاَدِكُمْ وَلاَ تَدْعُوا عَلَى أَمْوَالِكُمْ لاَ تُوَافِقُوا مِنَ اللَّهِ سَاعَةً يُسْأَلُ فِيهَا عَطَاءٌ فَيَسْتَجِيبُ لَكُمْ ‏"‏ ‏.‏ سِرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا كَانَتْ عُشَيْشِيَةٌ وَدَنَوْنَا مَاءً مِنْ مِيَاهِ الْعَرَبِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ رَجُلٌ يَتَقَدَّمُنَا فَيَمْدُرُ الْحَوْضَ فَيَشْرَبُ وَيَسْقِينَا ‏"‏ ‏.‏ قَالَ جَابِرٌ فَقُمْتُ فَقُلْتُ هَذَا رَجُلٌ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَىُّ رَجُلٍ مَعَ جَابِرٍ ‏"‏ ‏.‏ فَقَامَ جَبَّارُ بْنُ صَخْرٍ فَانْطَلَقْنَا إِلَى الْبِئْرِ فَنَزَعْنَا فِي الْحَوْضِ سَجْلاً أَوْ سَجْلَيْنِ ثُمَّ مَدَرْنَاهُ ثُمَّ نَزَعْنَا فِيهِ حَتَّى أَفْهَقْنَاهُ فَكَانَ أَوَّلَ طَالِعٍ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَتَأْذَنَانِ ‏"‏ ‏.‏ قُلْنَا نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ فَأَشْرَعَ نَاقَتَهُ فَشَرِبَتْ شَنَقَ لَهَا فَشَجَتْ فَبَالَتْ ثُمَّ عَدَلَ بِهَا فَأَنَاخَهَا ثُمَّ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْحَوْضِ فَتَوَضَّأَ مِنْهُ ثُمَّ قُمْتُ فَتَوَضَّأْتُ مِنْ مُتَوَضَّإِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَهَبَ جَبَّارُ بْنُ صَخْرٍ يَقْضِي حَاجَتَهُ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِيُصَلِّيَ وَكَانَتْ عَلَىَّ بُرْدَةٌ ذَهَبْتُ أَنْ أُخَالِفَ بَيْنَ طَرَفَيْهَا فَلَمْ تَبْلُغْ لِي وَكَانَتْ لَهَا ذَبَاذِبُ فَنَكَّسْتُهَا ثُمَّ خَالَفْتُ بَيْنَ طَرَفَيْهَا ثُمَّ تَوَاقَصْتُ عَلَيْهَا ثُمَّ جِئْتُ حَتَّى قُمْتُ عَنْ يَسَارِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخَذَ بِيَدِي فَأَدَارَنِي حَتَّى أَقَامَنِي عَنْ يَمِينِهِ ثُمَّ جَاءَ جَبَّارُ بْنُ صَخْرٍ فَتَوَضَّأَ ثُمَّ جَاءَ فَقَامَ عَنْ يَسَارِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدَيْنَا جَمِيعًا فَدَفَعَنَا حَتَّى أَقَامَنَا خَلْفَهُ فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَرْمُقُنِي وَأَنَا لاَ أَشْعُرُ ثُمَّ فَطِنْتُ بِهِ فَقَالَ هَكَذَا بِيَدِهِ يَعْنِي شُدَّ وَسَطَكَ فَلَمَّا فَرَغَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يَا جَابِرُ ‏"‏ ‏.‏ قُلْتُ لَبَّيْكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِذَا كَانَ وَاسِعًا فَخَالِفْ بَيْنَ طَرَفَيْهِ وَإِذَا كَانَ ضَيِّقًا فَاشْدُدْهُ عَلَى حِقْوِكَ ‏"‏ ‏.‏ سِرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكَانَ قُوتُ كُلِّ رَجُلٍ مِنَّا فِي كُلِّ يَوْمٍ تَمْرَةً فَكَانَ يَمَصُّهَا ثُمَّ يَصُرُّهَا فِي ثَوْبِهِ وَكُنَّا نَخْتَبِطُ بِقِسِيِّنَا وَنَأْكُلُ حَتَّى قَرِحَتْ أَشْدَاقُنَا فَأُقْسِمُ أُخْطِئَهَا رَجُلٌ مِنَّا يَوْمًا فَانْطَلَقْنَا بِهِ نَنْعَشُهُ فَشَهِدْنَا أَنَّهُ لَمْ يُعْطَهَا فَأُعْطِيَهَا فَقَامَ فَأَخَذَهَا ‏.‏ سِرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى نَزَلْنَا وَادِيًا أَفْيَحَ فَذَهَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْضِي حَاجَتَهُ فَاتَّبَعْتُهُ بِإِدَاوَةٍ مِنْ مَاءٍ فَنَظَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ يَرَ شَيْئًا يَسْتَتِرُ بِهِ فَإِذَا شَجَرَتَانِ بِشَاطِئِ الْوَادِي فَانْطَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى إِحْدَاهُمَا فَأَخَذَ بِغُصْنٍ مِنْ أَغْصَانِهَا فَقَالَ ‏"‏ انْقَادِي عَلَىَّ بِإِذْنِ اللَّهِ ‏"‏ ‏.‏ فَانْقَادَتْ مَعَهُ كَالْبَعِيرِ الْمَخْشُوشِ الَّذِي يُصَانِعُ قَائِدَهُ حَتَّى أَتَى الشَّجَرَةَ الأُخْرَى فَأَخَذَ بِغُصْنٍ مِنْ أَغْصَانِهَا فَقَالَ ‏"‏ انْقَادِي عَلَىَّ بِإِذْنِ اللَّهِ ‏"‏ ‏.‏ فَانْقَادَتْ مَعَهُ كَذَلِكَ حَتَّى إِذَا كَانَ بِالْمَنْصَفِ مِمَّا بَيْنَهُمَا لأَمَ بَيْنَهُمَا - يَعْنِي جَمَعَهُمَا - فَقَالَ ‏"‏ الْتَئِمَا عَلَىَّ بِإِذْنِ اللَّهِ ‏"‏ ‏.‏ فَالْتَأَمَتَا قَالَ جَابِرٌ فَخَرَجْتُ أُحْضِرُ مَخَافَةَ أَنْ يُحِسَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِقُرْبِي فَيَبْتَعِدَ - وَقَالَ مُحَمَّدُ بْنُ عَبَّادٍ فَيَتَبَعَّدَ - فَجَلَسْتُ أُحَدِّثُ نَفْسِي فَحَانَتْ مِنِّي لَفْتَةٌ فَإِذَا أَنَا بِرَسُولِ اللَّهِ صلى الله عليه وسلم مُقْبِلاً وَإِذَا الشَّجَرَتَانِ قَدِ افْتَرَقَتَا فَقَامَتْ كُلُّ وَاحِدَةٍ مِنْهُمَا عَلَى سَاقٍ فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَقَفَ وَقْفَةً فَقَالَ بِرَأْسِهِ هَكَذَا - وَأَشَارَ أَبُو إِسْمَاعِيلَ بِرَأْسِهِ يَمِينًا وَشِمَالاً - ثُمَّ أَقْبَلَ فَلَمَّا انْتَهَى إِلَىَّ قَالَ ‏"‏ يَا جَابِرُ هَلْ رَأَيْتَ مَقَامِي ‏"‏ ‏.‏ قُلْتُ نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَانْطَلِقْ إِلَى الشَّجَرَتَيْنِ فَاقْطَعْ مِنْ كُلِّ وَاحِدَةٍ مِنْهُمَا غُصْنًا فَأَقْبِلْ بِهِمَا حَتَّى إِذَا قُمْتَ مَقَامِي فَأَرْسِلْ غُصْنًا عَنْ يَمِينِكَ وَغُصْنًا عَنْ يَسَارِكَ ‏"‏ ‏.‏ قَالَ جَابِرٌ فَقُمْتُ فَأَخَذْتُ حَجَرًا فَكَسَرْتُهُ وَحَسَرْتُهُ فَانْذَلَقَ لِي فَأَتَيْتُ الشَّجَرَتَيْنِ فَقَطَعْتُ مِنْ كُلِّ وَاحِدَةٍ مِنْهُمَا غُصْنًا ثُمَّ أَقْبَلْتُ أَجُرُّهُمَا حَتَّى قُمْتُ مَقَامَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَرْسَلْتُ غُصْنًا عَنْ يَمِينِي وَغُصْنًا عَنْ يَسَارِي ثُمَّ لَحِقْتُهُ فَقُلْتُ قَدْ فَعَلْتُ يَا رَسُولَ اللَّهِ فَعَمَّ ذَاكَ قَالَ ‏"‏ إِنِّي مَرَرْتُ بِقَبْرَيْنِ يُعَذَّبَانِ فَأَحْبَبْتُ بِشَفَاعَتِي أَنْ يُرَفَّهَ عَنْهُمَا مَا دَامَ الْغُصْنَانِ رَطْبَيْنِ ‏"‏ ‏.‏ قَالَ فَأَتَيْنَا الْعَسْكَرَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا جَابِرُ نَادِ بِوَضُوءٍ ‏"‏ ‏.‏ فَقُلْتُ أَلاَ وَضُوءَ أَلاَ وَضُوءَ أَلاَ وَضُوءَ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَا وَجَدْتُ فِي الرَّكْبِ مِنْ قَطْرَةٍ وَكَانَ ��َجُلٌ مِنَ الأَنْصَارِ يُبَرِّدُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم الْمَاءَ فِي أَشْجَابٍ لَهُ عَلَى حِمَارَةٍ مِنْ جَرِيدٍ قَالَ فَقَالَ لِيَ ‏"‏ انْطَلِقْ إِلَى فُلاَنِ بْنِ فُلاَنٍ الأَنْصَارِيِّ فَانْظُرْ هَلْ فِي أَشْجَابِهِ مِنْ شَىْءٍ ‏"‏ ‏.‏ قَالَ فَانْطَلَقْتُ إِلَيْهِ فَنَظَرْتُ فِيهَا فَلَمْ أَجِدْ فِيهَا إِلاَّ قَطْرَةً فِي عَزْلاَءِ شَجْبٍ مِنْهَا لَوْ أَنِّي أُفْرِغُهُ لَشَرِبَهُ يَابِسُهُ ‏.‏ فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي لَمْ أَجِدْ فِيهَا إِلاَّ قَطْرَةً فِي عَزْلاَءِ شَجْبٍ مِنْهَا لَوْ أَنِّي أُفْرِغُهُ لَشَرِبَهُ يَابِسُهُ قَالَ ‏"‏ اذْهَبْ فَأْتِنِي بِهِ ‏"‏ ‏.‏ فَأَتَيْتُهُ بِهِ فَأَخَذَهُ بِيَدِهِ فَجَعَلَ يَتَكَلَّمُ بِشَىْءٍ لاَ أَدْرِي مَا هُوَ وَيَغْمِزُهُ بِيَدَيْهِ ثُمَّ أَعْطَانِيهِ فَقَالَ ‏"‏ يَا جَابِرُ نَادِ بِجَفْنَةٍ ‏"‏ ‏.‏ فَقُلْتُ يَا جَفْنَةَ الرَّكْبِ ‏.‏ فَأُتِيتُ بِهَا تُحْمَلُ فَوَضَعْتُهَا بَيْنَ يَدَيْهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ فِي الْجَفْنَةِ هَكَذَا فَبَسَطَهَا وَفَرَّقَ بَيْنَ أَصَابِعِهِ ثُمَّ وَضَعَهَا فِي قَعْرِ الْجَفْنَةِ وَقَالَ ‏"‏ خُذْ يَا جَابِرُ فَصُبَّ عَلَىَّ وَقُلْ بِاسْمِ اللَّهِ ‏"‏ ‏.‏ فَصَبَبْتُ عَلَيْهِ وَقُلْتُ بِاسْمِ اللَّهِ ‏.‏ فَرَأَيْتُ الْمَاءَ يَتَفَوَّرُ مِنْ بَيْنِ أَصَابِعِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ فَارَتِ الْجَفْنَةُ وَدَارَتْ حَتَّى امْتَلأَتْ فَقَالَ ‏"‏ يَا جَابِرُ نَادِ مَنْ كَانَ لَهُ حَاجَةٌ بِمَاءٍ ‏"‏ ‏.‏ قَالَ فَأَتَى النَّاسُ فَاسْتَقَوْا حَتَّى رَوَوْا قَالَ فَقُلْتُ هَلْ بَقِيَ أَحَدٌ لَهُ حَاجَةٌ فَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ مِنَ الْجَفْنَةِ وَهِيَ مَلأَى ‏.‏ وَشَكَا النَّاسُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الْجُوعَ فَقَالَ ‏"‏ عَسَى اللَّهُ أَنْ يُطْعِمَكُمْ ‏"‏ ‏.‏ فَأَتَيْنَا سِيفَ الْبَحْرِ فَزَخَرَ الْبَحْرُ زَخْرَةً فَأَلْقَى دَابَّةً فَأَوْرَيْنَا عَلَى شِقِّهَا النَّارَ فَاطَّبَخْنَا وَاشْتَوَيْنَا وَأَكَلْنَا حَتَّى شَبِعْنَا ‏.‏ قَالَ جَابِرٌ فَدَخَلْتُ أَنَا وَفُلاَنٌ وَفُلاَنٌ حَتَّى عَدَّ خَمْسَةً فِي حِجَاجِ عَيْنِهَا مَا يَرَانَا أَحَدٌ حَتَّى خَرَجْنَا فَأَخَذْنَا ضِلَعًا مِنْ أَضْلاَعِهِ فَقَوَّسْنَاهُ ثُمَّ دَعَوْنَا بِأَعْظَمِ رَجُلٍ فِي الرَّكْبِ وَأَعْظَمِ جَمَلٍ فِي الرَّكْبِ وَأَعْظَمِ كِفْلٍ فِي الرَّكْبِ فَدَخَلَ تَحْتَهُ مَا يُطَأْطِئُ رَأْسَهُ ‏.‏\hadithno{7512}\hadithtrans{Ubadah b. Walid b. Samit reported:I and my father set out in search of knowledge to a tribe of the Ansar before their death (i. e. before the Companions of the Prophet left the world) and I was the first to meet Abu Yasar, a Companion of Allah's Messenger (ﷺ) and there was a young man with him who carried the record of letters with him and there was a mantle prepared by the tribe of Ma'afiri upon him. And his servant too had a Ma'afiri mantle over him. My father said to him: My uncle, I see the signs of anger or that of agony on your face. He said: Yes, such and such person, the son of so and so, of the tribe of Harami owed me a debt. I went to his family, extended salutations and said: Where is he? They said: He is not here. Then came out to me his son who was at the threshold of his youth. I said to him: Where is your father? He said: No sooner did he hear your sound than he hid himself behind my mother's bedstead. I said to him: Walk out to me, for I know where you are. He came out. I said to him: What prompted you to hide yourself from me? He said: By God, whatever I would say to you would not be a lie. By Allah, I fear that I should tell a lie to you and in case of making promise with you I should break it, as you are the Companion of Allah's Messenger (ﷺ). The fact is that I was hard up in regard to money. I said: Do you adjure by Allah? He said: I adjure by Allah. I said: Do you adjure by Allah? He said: I adjure by Allah. I said: Do you adjure by Allah? He said: I adjure by Allah. Then he brought his promissory note and he wrote off (the debt) with his hand and said: Make payment when you find yourself solvent enough to pay me back; if you are not, then there is no liability upon you. These two eyes of mine saw, and he (Abu'I-Yasar) placed his fingers upon his eyes and these two ears of mine heard and my heart retained, and he pointed towards his heart that Allah's Messenger (ﷺ) said: He who gives time to one who is financially hard up (in the payment of debt) or writes off his debt, Allah will provide him His shadow. I said to him: My uncle, if you get the cloak of your servant and you give him your two clothes, or take his two clothes of Ma'afir and give him your cloak, then there would be one dress for you and one for him. He wiped my head and said: O Allah, bless the son of my brother. O, son of my brother, these two very eyes of mine saw and these two ears of mine listened to and this heart of mine retained this, and he pointed towards the heart that Allah's Messenger (ﷺ) said: Feed them (the servants) and clothe them (the servants) what you wear, and if I give him the goods of the world, it is easy for me than this that he should take my virtues on the Day of Resurrection. We went on till we came to Jabir b. Abdullah in the mosque and he was busy in observing prayer in one cloth which he had joined at its opposite ends. I made my way through the people till I sat between him and the Qibla and I said: May Allah have mercy upon you. Do you observe prayer with one cloth on your body whereas your mantle is lying at your side? He pointed me with his hand towards my breast just like this and he separated his fingers and bent them in the shape of a bow. And (he said): I thought that a fool like you should come to me so that he should see me as I do and he should then also do like it. Allah's Messenger (ﷺ) came to us in this very mosque and he had in his hand the twig of the palm-tree and he saw mucus towards the Qibla of the mosque and he erased it with the help of the twig. He then came to us and said: Who amongst you likes that Allah should turn His face away from him? We were afraid. He then again said: Who amongst you likes that Allah should turn His face away from him? We were afraid. He again said: Who amongst you likes that Allah should turn His face away from him? We said: Allah's Messenger, none of us likes it. And he said: If one amongst you stands for prayer, Allah, the Exalted and Glorious, is before him he should not spit in front of him, or on his right side, but should spit on his left side beneath his left foot and if he is impelled to do so all of a sudden (in spite of himself) he should then spit in his cloth and fold it in some part of it. (and he further said: ) Bring some sweet-smelling thing. A young man who belonged to our tribe stood up, went and brought scent in his palm. Allah's Messenger (ﷺ) took that and applied it to the end of that twig and then touched the place where there had been mucus. Jabir said: This is why you should apply scent to your mosques. It is reported on the same authority: We set out along with Allah's Messenger (ﷺ) on an expedition of Batn Buwat. He (the Holy Prophet) was in search of al-Majdi b. 'Amr al-Juhani. (We had so meagre equipment) that five. six or seven of us had one camel to ride and so we mounted it turn by turn. Once there wan. the turn of an Ansari to ride upon the camel. He made it kneel down to ride over it (and after having. mounted it), he tried to raise it up but it hesitated. So he said. May there be curse of Allah upon you! Thereupon Allah's Messenger (ﷺ) said: Who is there to curse his camel? He said: Allah's Messenger, it' is I. Thereupon he said: Get down from the camel and let us not have in our company the cursed one. Don't curse your own selves, nor your children. nor your belongings. There is the possibility that your curse may synchronies with the time when Allah is about to confer upon you what you demand and thus your prayer may be readily responded. It is reported on the same authority: We set out on an expedition along with Allah's Messenger (ﷺ) until it was evening, and we had been near a. water reservoir of Arabia. Allah's Messenger (ﷺ) said: Who would be the person who would go ahead and set right the reservoir and drink water himself and serve us with it? Jabir said: I stood up and said: Allah's Messenger, it is I who am ready to do that. Thereupon Allah's Messenger (ﷺ) said: Who is the person to accompany Jabir? And then Jabbar b. Sakhr stood up. So we went to that well and poured in that tank a bucket or two of water and plastered it with clay and then began to fill it (with water) until it was filled to the brim. Allah's Messenger (ﷺ) was the first who appeared before us, and he said: Do you (both) permit me to drink water out of it? We said: Yea, Allah's Messenger. He led his camel to drink water and it drank. He then pulled its rein and it stretched its legs and began to urinate. He then took it aside and made it kneel down at another place and then came to the tank and performed ablution. I then got up and performed ablution like the ablution of Allah's Messenger (ﷺ), and Jabbar b. Sakhr went in order to relieve himself and Allah's Messenger (ﷺ) got up to observe prayer and there was a mantle over me. I tried to invert its ends but it was too short (to cover my body easily). It had its borders. I then inverted it (the mantle) and drew its opposite ends and then tied them at my neck. I then came and stood upon the left side of Allah's Messenger (ﷺ). He caught hold of me and made me go round behind him, until he made me stand on his right side. Then Jabbar b. Sakhr came. He performed ablution and then came and stood on the left side of Allah's Messenger (ﷺ). Then Allah's Messenger (ﷺ) caught hold of our hands together, pushed us back and made us stand behind him. Then Allah's Messenger (ﷺ) began to look upon me with darting looks, but I did not perceive that. After that I became aware of it and he pointed with the gesture of his hand that I should wrap my loin-cloth. When Allah's Messenger (ﷺ) had finished the prayer, he said: Jabir! I said: Allah's Messenger, at thy beck and call. He said: When the cloth around you is inadequate, then tie the opposite ends but when it is small, tie it over the lower body. Jabir reported: We set out on an expedition with Allah's Messenger (ﷺ) and the only means of sustenance for every person amongst us was only one date for a day and we used to chew it. And we struck the leaves with the help of our bow and ate them until the sides of our mouths were injured. It so happened one day that a person was overlooked and not given a date. We carried that person and bore witness to the fact that he had not been given that date so he was offered that and he got up and received that. Jabir reported: We set out on an expedition along with Allah's Messenger (ﷺ) until we got down at a spacious valley and Allah's Messenger (ﷺ) went to relieve himself. I followed him with a bucket full of water and Allah's Messenger (ﷺ) looked about and he found no privacy but two trees at the end of the valley and Allah's Messenger (may. peace be upon him) went to one of them and took hold of one of its twigs and said: Be thou under my control by the permission of Allah, and so it came under his control like the camel who has its nosestring in the hand of its rider, and then he came to the second tree and took hold of a twig and said: Be thou under my control with the permission of Allah, and it came under his control, and when he came in the middle of the two trees he joined together the two twigs and said: join with the permission of Allah. Jabir said: I was afraid lest Allah's Messenger (ﷺ) should be aware of my nearness and go still farther. And Muhammad b. Abbad has used the word" faitab'd" and I began to talk to myself. And as I saw, I suddenly found Allah's Messenger (ﷺ) before me and the two trees were separated and each one of them was standing at its place. I saw Allah's Messenger (ﷺ) standing for a short time, nodding his head towards right and left. Isma'il pointed towards the right and left with the help of his head (in order to demonstrate how the Prophet had pointed). Then he (the Holy Prophet) came to me and said: Jabir did you see my place where I was standing? I said: Allah's Messenger, yes. He then said: Then you should go to those two trees and cut a twig from each of them and go to that place with them where I was standing and stand there where I was standing and place a twig on the right and a twig on the left. Jabir said: I set out and took hold of a stone and broke it and sharpened it and then I came to those trees and cut a twig from each one of them. I then came dragging them until I stood at the place where Allah's Messenger (ﷺ) had been standing and placed a twig on the right and a twig on the left. Then I met him and said: Allah's Messenger, I have done that, but (kindly) explain to me the reason for it. Thereupon he said: I passed by two graves the occupants of which had been undergoing torment. I liked to make intercession for them so that the might be relieved of this torment y as long as these twigs remain fresh. Jabir said: We came back to the (camp of the) army and Allah's Messenger (ﷺ) said: Jabir, call people for per- forming wudu. I cried: Come and perform wudu, come and perform wudu, come and perform wudu. I said: Allah's Messenger, there is not even a drop of water in the army camp, and there. was a person who used to cool the water for Allah's Messenger (ﷺ) in the old water-skin which kept hanging by the twig. He asked me to go to such and such Ansari and ask him to see if there was any water in that skin. I went to him and cast a glance in it but did not find anything but a drop in the mouth of that water-skin and if I were to draw that, the water-skin's,. dried part would suck it up. I came to Allah's Messenger (ﷺ) and said: Allah's Messenger, I have not found anything in it but a drop of water in the mouth of the water-skin and now if I were to draw that, it would be absorbed. He said: Go and bring that to me. I brought that to him. He took hold of it -and began to utter something which I could not understand and then pressed it with his hand and gave that to me and said: Jabir, announce for the tub to be brought. So I announced that the tub of the army (be brought). It was brought accordingly and I placed it before him (the Holy Prophet). Thereupon Allah's Messenger (ﷺ) placed his hands in the tub like this: with his fingers stretched out, and then he placed his fingers at the bottom of the tub and said: Jabir, take it (that waters-skin) and pour water over me, by reciting Bismillah, and I poured water and I said: Bismillah, and found water sprouting out between the fingers of Allah's Messenger (ﷺ). Then that tub gushed forth until it was filled up and the Messenger (ﷺ) said: Jabir, make an announcement to the effect: He who needs water should take that. Jabir said: The people came and got water until they were all satiated. I said: Is there anyone left who wants to get it? And Allah's Messenger (ﷺ) then lifted up his hand from that tub and it was still full. Then the people made a complaint to Allah's Messenger (ﷺ) about hunger and he said: May Allah provide you food! We came to the bank of the ocean and the ocean was tossing and it threw out a big animal and we lit fire and cooked it and took it until we had eaten to our heart's content. Jabir said: I and such and such five persons entered Its socket and nobody could see us until we had come out, and we took hold of one of its ribs and twisted it into a sort of arch, then we called the tallest of the persons of the army and the hugest of the camels of the army and it had the big saddle over it, and it could easily pass through it without the rider having need to bend down}}
\hadithdefcmd{muslim}{7513}{\hadithno{7513}\hadithtrans{}}
\hadithdefcmd{muslim}{7514}{\hadithno{7514}\hadithtrans{}}
\hadithdefcmd{muslim}{7515}{\hadithno{7515}\hadithtrans{}}
\hadithdefcmd{muslim}{7516}{\hadithno{7516}\hadithtrans{}}
\hadithdefcmd{muslim}{7517}{\hadithno{7517}\hadithtrans{}}
\hadithdefcmd{muslim}{7518}{\hadithno{7518}\hadithtrans{}}
\hadithdefcmd{muslim}{7519}{\hadithno{7519}\hadithtrans{}}
\hadithdefcmd{muslim}{7555}{حَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ الْعَبْدِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ، ‏\{‏ أُولَئِكَ الَّذِينَ يَدْعُونَ يَبْتَغُونَ إِلَى رَبِّهِمُ الْوَسِيلَةَ‏\}‏ قَالَ كَانَ نَفَرٌ مِنَ الإِنْسِ يَعْبُدُونَ نَفَرًا مِنَ الْجِنِّ فَأَسْلَمَ النَّفَرُ مِنَ الْجِنِّ ‏.‏ وَاسْتَمْسَكَ الإِنْسُ بِعِبَادَتِهِمْ فَنَزَلَتْ ‏\{‏ أُولَئِكَ الَّذِينَ يَدْعُونَ يَبْتَغُونَ إِلَى رَبِّهِمُ الْوَسِيلَةَ‏\}‏ وَحَدَّثَنِيهِ بِشْرُ بْنُ خَالِدٍ، أَخْبَرَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{7555}\hadithtrans{Abdullah b. Mas'ud reported in connection with the verse:" Those whom they call upon, themselves seek the means of access to their Lord," that it related to a group of people who worshipped a party amongst the Jinn. The group from amongst the Jinn embraced Islam, but the people kept worshipping them as they did before, and it was (on this occasion) that the verse was revealed:" Those whom they call upon, themselves seek the means of access to their Lord." This hadith has been narrated on the authority of Sulaiman with the same chain of transmitters}}
\hadithdefcmd{muslim}{7557}{\hadithno{7557}\hadithtrans{}}
