% Auto-generated chapter 16 for muslim
% Hadiths in this chapter: 168

\hadithdefcmd{muslim}{388}{\hadithno{388}\hadithtrans{}}
\hadithdefcmd{muslim}{3398}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَمُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ جَمِيعًا عَنْ أَبِي مُعَاوِيَةَ، - وَاللَّفْظُ لِيَحْيَى أَخْبَرَنَا أَبُو مُعَاوِيَةَ، - عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ كُنْتُ أَمْشِي مَعَ عَبْدِ اللَّهِ بِمِنًى فَلَقِيَهُ عُثْمَانُ فَقَامَ مَعَهُ يُحَدِّثُهُ فَقَالَ لَهُ عُثْمَانُ يَا أَبَا عَبْدِ الرَّحْمَنِ أَلاَ نُزَوِّجُكَ جَارِيَةً شَابَّةً لَعَلَّهَا تُذَكِّرُكَ بَعْضَ مَا مَضَى مِنْ زَمَانِكَ ‏.‏ قَالَ فَقَالَ عَبْدُ اللَّهِ لَئِنْ قُلْتَ ذَاكَ لَقَدْ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا مَعْشَرَ الشَّبَابِ مَنِ اسْتَطَاعَ مِنْكُمُ الْبَاءَةَ فَلْيَتَزَوَّجْ فَإِنَّهُ أَغَضُّ لِلْبَصَرِ وَأَحْصَنُ لِلْفَرْجِ وَمَنْ لَمْ يَسْتَطِعْ فَعَلَيْهِ بِالصَّوْمِ فَإِنَّهُ لَهُ وِجَاءٌ ‏"‏ ‏.‏\hadithno{3398}\hadithtrans{Alqama reported:While I was walking with 'Abdullah at Mina, 'Uthman happened to meet him. He stopped there and began to talk with him. Uthman said to him: Abu 'Abd al-Rahman, should we not marry you to a young girl who may recall to you some of the past of your bygone days; thereupon he said: If you say so, Allah's Messenger (ﷺ) said: 0 young men, those among you who can support a wife should marry, for it restrains eyes from casting (evil glances). and preserves one from immorality; but those who cannot should devote themselves to fasting for it is a means of controlling sexual desire}}
\hadithdefcmd{muslim}{3399}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ إِنِّي لأَمْشِي مَعَ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ بِمِنًى إِذْ لَقِيَهُ عُثْمَانُ بْنُ عَفَّانَ فَقَالَ هَلُمَّ يَا أَبَا عَبْدِ الرَّحْمَنِ قَالَ فَاسْتَخْلاَهُ فَلَمَّا رَأَى عَبْدُ اللَّهِ أَنْ لَيْسَتْ لَهُ حَاجَةٌ - قَالَ - قَالَ لِي تَعَالَ يَا عَلْقَمَةُ - قَالَ - فَجِئْتُ فَقَالَ لَهُ عُثْمَانُ أَلاَ نُزَوِّجُكَ يَا أَبَا عَبْدِ الرَّحْمَنِ جَارِيَةً بِكْرًا لَعَلَّهُ يَرْجِعُ إِلَيْكَ مِنْ نَفْسِكَ مَا كُنْتَ تَعْهَدُ فَقَالَ عَبْدُ اللَّهِ لَئِنْ قُلْتَ ذَاكَ ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ أَبِي مُعَاوِيَةَ ‏.‏\hadithno{3399}\hadithtrans{Alqama reported:While I was going along with 'Abdullah b. Ma'sud (Allah he pleased with him) in Mina, 'Uthman b. 'Affan (Allah be pleased with him) happened to meet him and said: Come here, Abu 'Abd al-Rahman (kunya of Abdullah b. Mas'ud), and he isolated him (from me), and when 'Abdullah (b. Mas'ud) saw that there was no need (for this privacy), he said to me: 'Alqama, come on, and so I went there. (Then) 'Uthman said to him: Abu Abd al-Rahman, should we not marry you to a virgin girl that your past may be recalled to your mind? 'Abdullah said: If you say so, the rest of the hadith is the same as narrated above}}
\hadithdefcmd{muslim}{3400}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا مَعْشَرَ الشَّبَابِ مَنِ اسْتَطَاعَ مِنْكُمُ الْبَاءَةَ فَلْيَتَزَوَّجْ فَإِنَّهُ أَغَضُّ لِلْبَصَرِ وَأَحْصَنُ لِلْفَرْجِ وَمَنْ لَمْ يَسْتَطِعْ فَعَلَيْهِ بِالصَّوْمِ فَإِنَّهُ لَهُ وِجَاءٌ ‏"‏ ‏.‏\hadithno{3400}\hadithtrans{Abdullah (b. Mas'ud) (Allah be pleased with him) reported that Allah's Messenger (ﷺ) said to us:0 young men, those among you who can support a wife should marry, for it restrains eyes (from casting evil glances) and preserves one from immorality; but he who cannot afford It should observe fast for it is a means of controlling the sexual desire}}
\hadithdefcmd{muslim}{3401}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، قَالَ دَخَلْتُ أَنَا وَعَمِّي، عَلْقَمَةُ وَالأَسْوَدُ عَلَى عَبْدِ اللَّهِ بْنِ مَسْعُودٍ قَالَ وَأَنَا شَابٌّ، يَوْمَئِذٍ فَذَكَرَ حَدِيثًا رُئِيتُ أَنَّهُ حَدَّثَ بِهِ، مِنْ أَجْلِي قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ أَبِي مُعَاوِيَةَ وَزَادَ قَالَ فَلَمْ أَلْبَثْ حَتَّى تَزَوَّجْتُ ‏.‏\hadithno{3401}\hadithtrans{Abu al-Rahman b. Yazid said:I and my uncle 'Alqama and al-Aswad went to 'Abdullah b. Mas'ud (Allah be pleased with him). He (the narrator further) said: I was at that time young, and he narrated a hadith which it seemed he narrated for me that Allah's Messenger (ﷺ) said like one transmitted by Mu'awiya, and further added: I lost no time in marrying}}
\hadithdefcmd{muslim}{3402}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ سَعِيدٍ الأَشَجُّ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ عُمَارَةَ بْنِ، عُمَيْرٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ دَخَلْنَا عَلَيْهِ وَأَنَا أَحْدَثُ الْقَوْمِ، بِمِثْلِ حَدِيثِهِمْ وَلَمْ يَذْكُرْ فَلَمْ أَلْبَثْ حَتَّى تَزَوَّجْتُ ‏.‏\hadithno{3402}\hadithtrans{Abd al-Rahman b. Yazid reported on the authority of Abdullah:We went to him, and I was the youngest of all (of us), but he did not mention:" I lost no time in marrying}}
\hadithdefcmd{muslim}{3403}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ الْعَبْدِيُّ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ نَفَرًا، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم سَأَلُوا أَزْوَاجَ النَّبِيِّ صلى الله عليه وسلم عَنْ عَمَلِهِ فِي السِّرِّ فَقَالَ بَعْضُهُمْ لاَ أَتَزَوَّجُ النِّسَاءَ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ آكُلُ اللَّحْمَ ‏.‏ وَقَالَ بَعْضُهُمْ لاَ أَنَامُ عَلَى فِرَاشٍ ‏.‏ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ‏.‏ فَقَالَ ‏ "‏ مَا بَالُ أَقْوَامٍ قَالُوا كَذَا وَكَذَا لَكِنِّي أُصَلِّي وَأَنَامُ وَأَصُومُ وَأُفْطِرُ وَأَتَزَوَّجُ النِّسَاءَ فَمَنْ رَغِبَ عَنْ سُنَّتِي فَلَيْسَ مِنِّي ‏"‏ ‏.‏\hadithno{3403}\hadithtrans{Anas (Allah be pleased with him) reported that some of the Companions of Allah's Apostle (ﷺ) asked his (the Prophet's) wives about the acts that he performed in private. Someone among them (among his Companions) said:I will not marry women; someone among them said: I will not eat meat; and someone among them said: I will not lie down in bed. He (the Holy Prophet) praised Allah and glorified Him, and said: What has happened to these people that they say so and so, whereas I observe prayer and sleep too; I observe fast and suspend observing them; I marry women also? And he who turns away from my Sunnah, he has no relation with Me}}
\hadithdefcmd{muslim}{3404}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ - وَاللَّفْظُ لَهُ - أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ، الْمُسَيَّبِ عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ رَدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى عُثْمَانَ بْنِ مَظْعُونٍ التَّبَتُّلَ وَلَوْ أَذِنَ لَهُ لاَخْتَصَيْنَا ‏.‏\hadithno{3404}\hadithtrans{Sa'd b. Abi Waqqas (Allah be pleased with him) reported:The Messengger of Allah (ﷺ) rejected (the idea) of Uthman b. Muz'unliving in celibacy (saying): And if he (the Holy Prophet) had given me permission We would have got ourselves castrated}}
\hadithdefcmd{muslim}{3405}{وَحَدَّثَنِي أَبُو عِمْرَانَ، مُحَمَّدُ بْنُ جَعْفَرِ بْنِ زِيَادٍ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ، شِهَابٍ الزُّهْرِيِّ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ سَمِعْتُ سَعْدًا، يَقُولُ رُدَّ عَلَى عُثْمَانَ بْنِ مَظْعُونٍ التَّبَتُّلُ وَلَوْ أُذِنَ لَهُ لاَخْتَصَيْنَا ‏.‏\hadithno{3405}\hadithtrans{Sa'id b. al-Musayyib reported:I heard Sa'd (b. Abi Waqqas) saying that the idea of 'Uthman b. Maz'un for living in celibacy was rejected (by the Holy Prophet), and if he had been given permission they would have got themselves castrated}}
\hadithdefcmd{muslim}{3406}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا حُجَيْنُ بْنُ الْمُثَنَّى، حَدَّثَنَا لَيْثٌ، عَنْ عُقَيْلٍ، عَنِ ابْنِ، شِهَابٍ أَنَّهُ قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّهُ سَمِعَ سَعْدَ بْنَ أَبِي وَقَّاصٍ، يَقُولُ أَرَادَ عُثْمَانُ بْنُ مَظْعُونٍ أَنْ يَتَبَتَّلَ، فَنَهَاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَوْ أَجَازَ لَهُ ذَلِكَ لاَخْتَصَيْنَا ‏.‏\hadithno{3406}\hadithtrans{Sa'id b. al Musayyib heard Sa'd b. Abi Waqqas (Allah be pleased with him) saying that Uthman b. Maz'un decided to live in celibacy, but Allah's Messenger (ﷺ) forbade him to do so, and if he had permitted him, we would have got ourselves castrated}}
\hadithdefcmd{muslim}{3407}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا هِشَامُ بْنُ أَبِي عَبْدِ اللَّهِ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى امْرَأَةً فَأَتَى امْرَأَتَهُ زَيْنَبَ وَهْىَ تَمْعَسُ مَنِيئَةً لَهَا فَقَضَى حَاجَتَهُ ثُمَّ خَرَجَ إِلَى أَصْحَابِهِ فَقَالَ ‏ "‏ إِنَّ الْمَرْأَةَ تُقْبِلُ فِي صُورَةِ شَيْطَانٍ وَتُدْبِرُ فِي صُورَةِ شَيْطَانٍ فَإِذَا أَبْصَرَ أَحَدُكُمُ امْرَأَةً فَلْيَأْتِ أَهْلَهُ فَإِنَّ ذَلِكَ يَرُدُّ مَا فِي نَفْسِهِ ‏"‏ ‏.‏\hadithno{3407}\hadithtrans{Jabir reported that Allah's Messenger (ﷺ) saw a woman, and so he came to his wife, Zainab, as she was tanning a leather and had sexual intercourse with her. He then went to his Companions and told them:The woman advances and retires in the shape of a devil, so when one of you sees a woman, he should come to his wife, for that will repel what he feels in his heart}}
\hadithdefcmd{muslim}{3408}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا حَرْبُ بْنُ أَبِي، الْعَالِيَةِ حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى امْرَأَةً ‏.‏ فَذَكَرَ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ فَأَتَى امْرَأَتَهُ زَيْنَبَ وَهْىَ تَمْعَسُ مَنِيئَةً ‏.‏ وَلَمْ يَذْكُرْ تُدْبِرُ فِي صُورَةِ شَيْطَانٍ ‏.‏\hadithno{3408}\hadithtrans{Jabir b. 'Abdullah reported that Allah's Apostle (ﷺ) saw a woman; and the rest of the hadith was narrated but (with this exception) that he said he came to his wife Zainab, who was tanning a (piece of) leather, and he made no mention of:" She retires in the shape of satan}}
\hadithdefcmd{muslim}{3409}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، قَالَ قَالَ جَابِرٌ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا أَحَدُكُمْ أَعْجَبَتْهُ الْمَرْأَةُ فَوَقَعَتْ فِي قَلْبِهِ فَلْيَعْمِدْ إِلَى امْرَأَتِهِ فَلْيُوَاقِعْهَا فَإِنَّ ذَلِكَ يَرُدُّ مَا فِي نَفْسِهِ ‏"‏ ‏.‏\hadithno{3409}\hadithtrans{Jabir heard Allah's Apostle (ﷺ) say:When a woman fascinates any one of you and she captivates his heart, he should go to his wife and have an intercourse with her, for it would repel what he feels}}
\hadithdefcmd{muslim}{3410}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ الْهَمْدَانِيُّ، حَدَّثَنَا أَبِي وَوَكِيعٌ، وَابْنُ، بِشْرٍ عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ، يَقُولُ كُنَّا نَغْزُو مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيْسَ لَنَا نِسَاءٌ فَقُلْنَا أَلاَ نَسْتَخْصِي فَنَهَانَا عَنْ ذَلِكَ ثُمَّ رَخَّصَ لَنَا أَنْ نَنْكِحَ الْمَرْأَةَ بِالثَّوْبِ إِلَى أَجَلٍ ثُمَّ قَرَأَ عَبْدُ اللَّهِ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تُحَرِّمُوا طَيِّبَاتِ مَا أَحَلَّ اللَّهُ لَكُمْ وَلاَ تَعْتَدُوا إِنَّ اللَّهَ لاَ يُحِبُّ الْمُعْتَدِينَ‏\}‏ ‏.‏\hadithno{3410}\hadithtrans{Abdullah (b. Mas'ud) reported:We were on an expedition with Allah's Messenger (ﷺ) and we had no women with us. We said: Should we not have ourselves castrated? He (the Holy Prophet) forbade us to do so He then granted us permission that we should contract temporary marriage for a stipulated period giving her a garment, and 'Abdullah then recited this verse: 'Those who believe do not make unlawful the good things which Allah has made lawful for you, and do not transgress. Allah does not like trangressers" (al-Qur'an, v)}}
\hadithdefcmd{muslim}{3411}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ وَقَالَ ثُمَّ قَرَأَ عَلَيْنَا هَذِهِ الآيَةَ ‏.‏ وَلَمْ يَقُلْ قَرَأَ عَبْدُ اللَّهِ ‏.‏\hadithno{3411}\hadithtrans{This hadith has been narrated on the authority of Jarir with the same chain of transmitters and he also recited this (above-mentioned verse) to us, but he did not say that 'Abdullah recited it}}
\hadithdefcmd{muslim}{3412}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْمَاعِيلَ، بِهَذَا الإِسْنَادِ قَالَ كُنَّا وَنَحْنُ شَبَابٌ فَقُلْنَا يَا رَسُولَ اللَّهِ أَلاَ نَسْتَخْصِي وَلَمْ يَقُلْ نَغْزُو ‏.‏\hadithno{3412}\hadithtrans{This hadith has been narrated on the authority of Isma'il with the same chain of transmitters (and the words are):" We were young, so we said: Allah's Messenger, should we not have ourselves castrated? But he (the narrator) did not say; We were on an expedition}}
\hadithdefcmd{muslim}{3413}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ دِينَارٍ، قَالَ سَمِعْتُ الْحَسَنَ بْنَ مُحَمَّدٍ، يُحَدِّثُ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، وَسَلَمَةَ بْنِ الأَكْوَعِ، قَالاَ خَرَجَ عَلَيْنَا مُنَادِي رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أَذِنَ لَكُمْ أَنْ تَسْتَمْتِعُوا ‏.‏ يَعْنِي مُتْعَةَ النِّسَاءِ ‏.‏\hadithno{3413}\hadithtrans{Jabir b. 'Abdullah and Salama b. al-Akwa' said:There came to us the proclaimer of Allah's Messenger (ﷺ) and said: Allah's Messenger (ﷺ) has granted you permission to benefit yourselves, i. e. to contract temporary marriage with women}}
\hadithdefcmd{muslim}{3414}{وَحَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامَ الْعَيْشِيُّ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا رَوْحٌ، - يَعْنِي ابْنَ الْقَاسِمِ - عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ الْحَسَنِ بْنِ مُحَمَّدٍ، عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، وَجَابِرِ بْنِ عَبْدِ اللَّهِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَانَا فَأَذِنَ لَنَا فِي الْمُتْعَةِ ‏.‏\hadithno{3414}\hadithtrans{Salama b. al. Akwa' and Jabir b. Abdullah reported:Allah's Messenger (ﷺ) came to us and permitted us to contract temporary marriage}}
\hadithdefcmd{muslim}{3415}{وَحَدَّثَنَا الْحَسَنُ الْحُلْوَانِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ قَالَ عَطَاءٌ قَدِمَ جَابِرُ بْنُ عَبْدِ اللَّهِ مُعْتَمِرًا فَجِئْنَاهُ فِي مَنْزِلِهِ فَسَأَلَهُ الْقَوْمُ عَنْ أَشْيَاءَ ثُمَّ ذَكَرُوا الْمُتْعَةَ فَقَالَ نَعَمِ اسْتَمْتَعْنَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ ‏.‏\hadithno{3415}\hadithtrans{Ibn Uraij reported:'Ati' reported that jibir b. Abdullah came to perform 'Umra, and we came to his abode, and the people asked him about different things, and then they made a mention of temporary marriage, whereupon he said: Yes, we had been benefiting ourselves by this temporary marriage during the lifetime of the Prophet (ﷺ) and during the time of Abu Bakr and 'Umar}}
\hadithdefcmd{muslim}{3416}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ كُنَّا نَسْتَمْتِعُ بِالْقُبْضَةِ مِنَ التَّمْرِ وَالدَّقِيقِ الأَيَّامَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ حَتَّى نَهَى عَنْهُ عُمَرُ فِي شَأْنِ عَمْرِو بْنِ حُرَيْثٍ ‏.‏\hadithno{3416}\hadithtrans{Jabir b. 'Abdullah reported:We contracted temporary marriage giving a handful of (tales or flour as a dower during the lifetime of Allah's Messenger (ﷺ) and durnig the time of Abu Bakr until 'Umar forbade it in the case of 'Amr b. Huraith}}
\hadithdefcmd{muslim}{3417}{حَدَّثَنَا حَامِدُ بْنُ عُمَرَ الْبَكْرَاوِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، - يَعْنِي ابْنَ زِيَادٍ - عَنْ عَاصِمٍ، عَنْ أَبِي نَضْرَةَ، قَالَ كُنْتُ عِنْدَ جَابِرِ بْنِ عَبْدِ اللَّهِ فَأَتَاهُ آتٍ فَقَالَ ابْنُ عَبَّاسٍ وَابْنُ الزُّبَيْرِ اخْتَلَفَا فِي الْمُتْعَتَيْنِ فَقَالَ جَابِرٌ فَعَلْنَاهُمَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ نَهَانَا عَنْهُمَا عُمَرُ فَلَمْ نَعُدْ لَهُمَا ‏.‏\hadithno{3417}\hadithtrans{Abu Nadra reported:While I was in the company of Jabir b. Abdullah, a person came to him and said that Ibn 'Abbas and Ibn Zubair differed on the two types of Mut'as (Tamattu' of Hajj 1846 and Tamattu' with women), whereupon Jabir said: We used to do these two during the lifetime of Allah's Messenger (ﷺ). Umar then forbade us to do them, and so we did not revert to them}}
\hadithdefcmd{muslim}{3418}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا أَبُو عُمَيْسٍ، عَنْ إِيَاسِ بْنِ سَلَمَةَ، عَنْ أَبِيهِ، قَالَ رَخَّصَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَامَ أَوْطَاسٍ فِي الْمُتْعَةِ ثَلاَثًا ثُمَّ نَهَى عَنْهَا ‏.‏\hadithno{3418}\hadithtrans{Iyas b. Salama reported on the authority of his father that Allah's Messenger (ﷺ) gave sanction for contracting temporary marriage for three nights in the year of Autas 1847 and then forbade it}}
\hadithdefcmd{muslim}{3419}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ الرَّبِيعِ بْنِ سَبْرَةَ الْجُهَنِيِّ، عَنْ أَبِيهِ، سَبْرَةَ أَنَّهُ قَالَ أَذِنَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْمُتْعَةِ فَانْطَلَقْتُ أَنَا وَرَجُلٌ إِلَى امْرَأَةٍ مِنْ بَنِي عَامِرٍ كَأَنَّهَا بَكْرَةٌ عَيْطَاءُ فَعَرَضْنَا عَلَيْهَا أَنْفُسَنَا فَقَالَتْ مَا تُعْطِي فَقُلْتُ رِدَائِي ‏.‏ وَقَالَ صَاحِبِي رِدَائِي ‏.‏ وَكَانَ رِدَاءُ صَاحِبِي أَجْوَدَ مِنْ رِدَائِي وَ كُنْتُ أَشَبَّ مِنْهُ فَإِذَا نَظَرَتْ إِلَى رِدَاءِ صَاحِبِي أَعْجَبَهَا وَإِذَا نَظَرَتْ إِلَىَّ أَعْجَبْتُهَا ثُمَّ قَالَتْ أَنْتَ وَرِدَاؤُكَ يَكْفِينِي ‏.‏ فَمَكَثْتُ مَعَهَا ثَلاَثًا ثُمَّ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ عِنْدَهُ شَىْءٌ مِنْ هَذِهِ النِّسَاءِ الَّتِي يَتَمَتَّعُ فَلْيُخَلِّ سَبِيلَهَا ‏"‏ ‏.‏\hadithno{3419}\hadithtrans{Sabra Juhanni reported:Allah's Messenger (ﷺ) permitted temporary marriage for us. So I and another person went out and saw a woman of Bana 'Amir, who was like a young long-necked she-camel. We presented ourselves to her (for contracting temporary marriage), whereupon she said: What dower would you give me? I said: My cloak. And my companion also said: My cloak. And the cloak of-my companion was superior to my cloak, but I was younger than he. So when she looked at the cloak of my companion she liked it, and when she cast a glance at me I looked more attractive to her. She then said: Well, you and your cloak are sufficient for me. I remained with her for three nights, and then Allah's Messenger (ﷺ) said: He who has any such woman with whom he had contracted temporary marriage, he should let her off}}
\hadithdefcmd{muslim}{3420}{حَدَّثَنَا أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ مُفَضَّلٍ - حَدَّثَنَا عُمَارَةُ بْنُ غَزِيَّةَ، عَنِ الرَّبِيعِ بْنِ سَبْرَةَ، أَنَّ أَبَاهُ، غَزَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَتْحَ مَكَّةَ قَالَ فَأَقَمْنَا بِهَا خَمْسَ عَشْرَةَ - ثَلاَثِينَ بَيْنَ لَيْلَةٍ وَيَوْمٍ - فَأَذِنَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مُتْعَةِ النِّسَاءِ فَخَرَجْتُ أَنَا وَرَجُلٌ مِنْ قَوْمِي وَلِي عَلَيْهِ فَضْلٌ فِي الْجَمَالِ وَهُوَ قَرِيبٌ مِنَ الدَّمَامَةِ مَعَ كُلِّ وَاحِدٍ مِنَّا بُرْدٌ فَبُرْدِي خَلَقٌ وَأَمَّا بُرْدُ ابْنِ عَمِّي فَبُرْدٌ جَدِيدٌ غَضٌّ حَتَّى إِذَا كُنَّا بِأَسْفَلِ مَكَّةَ أَوْ بِأَعْلاَهَا فَتَلَقَّتْنَا فَتَاةٌ مِثْلُ الْبَكْرَةِ الْعَنَطْنَطَةِ فَقُلْنَا هَلْ لَكِ أَنْ يَسْتَمْتِعَ مِنْكِ أَحَدُنَا قَالَتْ وَمَاذَا تَبْذُلاَنِ فَنَشَرَ كُلُّ وَاحِدٍ مِنَّا بُرْدَهُ فَجَعَلَتْ تَنْظُرُ إِلَى الرَّجُلَيْنِ وَيَرَاهَا صَاحِبِي تَنْظُرُ إِلَى عِطْفِهَا فَقَالَ إِنَّ بُرْدَ هَذَا خَلَقٌ وَبُرْدِي جَدِيدٌ غَضٌّ ‏.‏ فَتَقُولُ بُرْدُ هَذَا لاَ بَأْسَ بِهِ ‏.‏ ثَلاَثَ مِرَارٍ أَوْ مَرَّتَيْنِ ثُمَّ اسْتَمْتَعْتُ مِنْهَا فَلَمْ أَخْرُجْ حَتَّى حَرَّمَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3420}\hadithtrans{Rabi' b. Sabra reported that his father went on an expedition with Allah's Messenger (ﷺ) during the Victory of Mecca, and we stayed there for fifteen days (i. e. for thirteen full days and a day and a night), and Allah's Messenger (ﷺ) permitted us to contract temporary marriage with women. So I and another person of my tribe went out, and I was more handsome than he, whereas he was almost ugly. Each one of us had a cloaks, My cloak was worn out, whereas the cloak of my cousin was quite new. As we reached the lower or the upper side of Mecca, we came across a young woman like a young smart long-necked she-camel. We said:Is it possible that one of us may contract temporary marriage with you? She said: What will you give me as a dower? Each one of us spread his cloak. She began to cast a glance on both the persons. My companion also looked at her when she was casting a glance at her side and he said: This cloak of his is worn out, whereas my cloak is quite new. She, however, said twice or thrice: There is no harm in (accepting) this cloak (the old one). So I contracted temporary marriage with her, and I did not come out (of this) until Allah's Messenger (ﷺ) declared it forbidden}}
\hadithdefcmd{muslim}{3421}{وَحَدَّثَنِي أَحْمَدُ بْنُ سَعِيدِ بْنِ صَخْرٍ الدَّارِمِيُّ، حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عُمَارَةُ بْنُ غَزِيَّةَ، حَدَّثَنِي الرَّبِيعُ بْنُ سَبْرَةَ الْجُهَنِيُّ، عَنْ أَبِيهِ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ إِلَى مَكَّةَ ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ بِشْرٍ ‏.‏ وَزَادَ قَالَتْ وَهَلْ يَصْلُحُ ذَاكَ وَفِيهِ قَالَ إِنَّ بُرْدَ هَذَا خَلَقٌ مَحٌّ ‏.‏\hadithno{3421}\hadithtrans{Rabi' b. S'abra al-jahanni reported on the authority of his father. We went with Allah's Messenger (ﷺ) to Mecca during the year of Victory and he narrated like this a hadith transmitted by Bishr (the previous one) but with this addition:" She said: Can it be possible?" And it is also mentioned in it:" He said: The cloak of this (man) is old and worn out}}
\hadithdefcmd{muslim}{3422}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عُمَرَ، حَدَّثَنِي الرَّبِيعُ بْنُ سَبْرَةَ الْجُهَنِيُّ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، كَانَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ إِنِّي قَدْ كُنْتُ أَذِنْتُ لَكُمْ فِي الاِسْتِمْتَاعِ مِنَ النِّسَاءِ وَإِنَّ اللَّهَ قَدْ حَرَّمَ ذَلِكَ إِلَى يَوْمِ الْقِيَامَةِ فَمَنْ كَانَ عِنْدَهُ مِنْهُنَّ شَىْءٌ فَلْيُخَلِّ سَبِيلَهُ وَلاَ تَأْخُذُوا مِمَّا آتَيْتُمُوهُنَّ شَيْئًا‏"‏ ‏.‏\hadithno{3422}\hadithtrans{Sabra al-Juhani reported on the authority of his father that while he was with Allah's Messenger (ﷺ) he said:O people, I had permitted you to contract temporary marriage with women, but Allah has forbidden it (now) until the Day of Resurrection. So he who has any (woman with this type of marriage contract) he should let her off, and do not take back anything you have given to them (as dower)}}
\hadithdefcmd{muslim}{3423}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ عُمَرَ، بِهَذَا الإِسْنَادِ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَائِمًا بَيْنَ الرُّكْنِ وَالْبَابِ وَهُوَ يَقُولُ بِمِثْلِ حَدِيثِ ابْنِ نُمَيْرٍ ‏.‏\hadithno{3423}\hadithtrans{This hadith has been narrated on the authority of 'Abd al-'Aziz b 'Umar with the same chain of transmitters, and he said:I saw Allah's Messenger (ﷺ) standing between the pillar and the gate (of the Ka'ba) and he was relating a hadith as narrated by Ibn Numair}}
\hadithdefcmd{muslim}{3424}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ الرَّبِيعِ بْنِ سَبْرَةَ الْجُهَنِيِّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْمُتْعَةِ عَامَ الْفَتْحِ حِينَ دَخَلْنَا مَكَّةَ ثُمَّ لَمْ نَخْرُجْ مِنْهَا حَتَّى نَهَانَا عَنْهَا‏.‏\hadithno{3424}\hadithtrans{Abd al-Malik b. Rabi' b. Sabraal-Juhanni reported on the authority of his father who narrated it on the authority of his father (i e. 'Abd al-Malik's grandfather, Sabura al-Juhanniy Allah's Messenger (ﷺ) permitted us to contract temporary marriage in the Year of Victory, as we entered Mecca, and we did come out of it but he forbade us to do it}}
\hadithdefcmd{muslim}{3425}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ الرَّبِيعِ بْنِ سَبْرَةَ بْنِ مَعْبَدٍ، قَالَ سَمِعْتُ أَبِي رَبِيعَ بْنَ سَبْرَةَ، يُحَدِّثُ عَنْ أَبِيهِ، سَبْرَةَ بْنِ مَعْبَدٍ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم عَامَ فَتْحِ مَكَّةَ أَمَرَ أَصْحَابَهُ بِالتَّمَتُّعِ مِنَ النِّسَاءِ - قَالَ - فَخَرَجْتُ أَنَا وَصَاحِبٌ لِي مِنْ بَنِي سُلَيْمٍ حَتَّى وَجَدْنَا جَارِيَةً مِنْ بَنِي عَامِرٍ كَأَنَّهَا بَكْرَةٌ عَيْطَاءُ فَخَطَبْنَاهَا إِلَى نَفْسِهَا وَعَرَضْنَا عَلَيْهَا بُرْدَيْنَا فَجَعَلَتْ تَنْظُرُ فَتَرَانِي أَجْمَلَ مِنْ صَاحِبِي وَتَرَى بُرْدَ صَاحِبِي أَحْسَنَ مِنْ بُرْدِي فَآمَرَتْ نَفْسَهَا سَاعَةً ثُمَّ اخْتَارَتْنِي عَلَى صَاحِبِي فَكُنَّ مَعَنَا ثَلاَثًا ثُمَّ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِفِرَاقِهِنَّ ‏.‏\hadithno{3425}\hadithtrans{Sabra b. Ma'bad reported that Allah's Apostle (ﷺ) permitted his Companions to contract temporary marriage with women in the Year of Victory. So I and a friend of mine from Banu Sulaim went out, until we found a young woman of Banu Amir who was like a young she-camel having a long neck. We proposed to her for contracting temporary marriage with us, and presented to her our cloaks (as dower). She began to look and found me more handsome than my friend, but found the cloak of my friend more beautiful than my cloak. She thought in her mind for a while, but then preferred me to my friend. So I remained with her for three (nights), and then Allah's Messenger (ﷺ) commanded us to part with them (such women)}}
\hadithdefcmd{muslim}{3426}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنِ الرَّبِيعِ بْنِ سَبْرَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ نِكَاحِ الْمُتْعَةِ ‏.‏\hadithno{3426}\hadithtrans{Rabi' b. Sabra reported on the authority of his father that Allah's Apostle (ﷺ) prohibited the contracting of temporary marriage}}
\hadithdefcmd{muslim}{3427}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنِ الرَّبِيعِ، بْنِ سَبْرَةَ عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى يَوْمَ الْفَتْحِ عَنْ مُتْعَةِ النِّسَاءِ‏.‏\hadithno{3427}\hadithtrans{Rabi' b. Sabra reported on the authority of his father that Allah's Messenger (ﷺ) forbade on the Day of Victory to contract temporary marriage with women}}
\hadithdefcmd{muslim}{3428}{وَحَدَّثَنِيهِ حَسَنٌ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، عَنْ يَعْقُوبَ بْنِ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، أَخْبَرَنَا ابْنُ شِهَابٍ، عَنِ الرَّبِيعِ بْنِ سَبْرَةَ الْجُهَنِيِّ، عَنْ أَبِيهِ، أَنَّهُ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُتْعَةِ زَمَانَ الْفَتْحِ مُتْعَةِ النِّسَاءِ وَأَنَّ أَبَاهُ كَانَ تَمَتَّعَ بِبُرْدَيْنِ أَحْمَرَيْنِ\hadithno{3428}\hadithtrans{This hadith has been narrated on the authority of Rabi' b. Sabra that Allah's Messenger (ﷺ) forbade to contract temporary marriage with women at the time of Victory, and that his father had contracted the marriage for two red cloaks}}
\hadithdefcmd{muslim}{3429}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَبْدَ اللَّهِ بْنَ الزُّبَيْرِ، قَامَ بِمَكَّةَ فَقَالَ إِنَّ نَاسًا - أَعْمَى اللَّهُ قُلُوبَهُمْ كَمَا أَعْمَى أَبْصَارَهُمْ - يُفْتُونَ بِالْمُتْعَةِ - يُعَرِّضُ بِرَجُلٍ - فَنَادَاهُ فَقَالَ إِنَّكَ لَجِلْفٌ جَافٍ فَلَعَمْرِي لَقَدْ كَانَتِ الْمُتْعَةُ تُفْعَلُ عَلَى عَهْدِ إِمَامِ الْمُتَّقِينَ - يُرِيدُ رَسُولَ اللَّهِ صلى الله عليه وسلم - فَقَالَ لَهُ ابْنُ الزُّبَيْرِ فَجَرِّبْ بِنَفْسِكَ فَوَاللَّهِ لَئِنْ فَعَلْتَهَا لأَرْجُمَنَّكَ بِأَحْجَارِكَ ‏.‏ قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي خَالِدُ بْنُ الْمُهَاجِرِ بْنِ سَيْفِ اللَّهِ أَنَّهُ بَيْنَا هُوَ جَالِسٌ عِنْدَ رَجُلٍ جَاءَهُ رَجُلٌ فَاسْتَفْتَاهُ فِي الْمُتْعَةِ فَأَمَرَهُ بِهَا فَقَالَ لَهُ ابْنُ أَبِي عَمْرَةَ الأَنْصَارِيُّ مَهْلاً ‏.‏ قَالَ مَا هِيَ وَاللَّهِ لَقَدْ فُعِلَتْ فِي عَهْدِ إِمَامِ الْمُتَّقِينَ ‏.‏ قَالَ ابْنُ أَبِي عَمْرَةَ إِنَّهَا كَانَتْ رُخْصَةً فِي أَوَّلِ الإِسْلاَمِ لِمَنِ اضْطُرَّ إِلَيْهَا كَالْمَيْتَةِ وَالدَّمِ وَلَحْمِ الْخِنْزِيرِ ثُمَّ أَحْكَمَ اللَّهُ الدِّينَ وَنَهَى عَنْهَا ‏.‏ قَالَ ابْنُ شِهَابٍ وَأَخْبَرَنِي رَبِيعُ بْنُ سَبْرَةَ الْجُهَنِيُّ أَنَّ أَبَاهُ قَالَ قَدْ كُنْتُ اسْتَمْتَعْتُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم امْرَأَةً مِنْ بَنِي عَامِرٍ بِبُرْدَيْنِ أَحْمَرَيْنِ ثُمَّ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْمُتْعَةِ ‏.‏ قَالَ ابْنُ شِهَابٍ وَسَمِعْتُ رَبِيعَ بْنَ سَبْرَةَ يُحَدِّثُ ذَلِكَ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ وَأَنَا جَالِسٌ ‏.‏\hadithno{3429}\hadithtrans{Urwa b. Zabair reported that 'Abdullah b. Zubair (Allah be pleased with him) stood up (and delivered an address) in Mecca saying:Allah has made blind the hearts of some people as He has deprived them of eyesight that they give religious verdict in favour of temporary marriage, while he was alluding to a person (Ibn 'Abbas). Ibn Abbas called him and said: You are an uncouth person, devoid of sense. By my life, Mut'a was practised during the lifetime of the leader of the pious (he meant Allah's Messenger, may peace be upon him), and Ibn Zubair said to him: just do it yourselves, and by Allah, if you do that I will stone you with your stones. Ibn Shihab said. Khalid b. Muhajir b. Saifullah informed me: While I was sitting in the company of a person, a person came to him and he asked for a religious verdict about Mut'a and he permitted him to do it. Ibn Abu 'Amrah al-Ansari (Allah be pleased with him) said to him: Be gentle. It was permitted in- the early days of Islam, (for one) who was driven to it under the stress of necessity just as (the eating of) carrion and the blood and flesh of swine and then Allah intensified (the commands of) His religion and prohibited it (altogether). Ibn Shihab reported: Rabi' b. Sabra told me that his father (Sabra) said: I contracted temporary marriage with a woman of Banu 'Amir for two cloaks during the lifetime of Allah's Messenger (ﷺ) ; then he forbade us to do Mut'a. Ibn Shihab said: I heard Rabi' b. Sabra narrating it to Umar b. 'Abd al-'Aziz and I was sitting there}}
\hadithdefcmd{muslim}{3430}{وَحَدَّثَنِي سَلَمَةَ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنِ ابْنِ أَبِي عَبْلَةَ، عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، قَالَ حَدَّثَنَا الرَّبِيعُ بْنُ سَبْرَةَ الْجُهَنِيُّ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْمُتْعَةِ وَقَالَ ‏ "‏ أَلاَ إِنَّهَا حَرَامٌ مِنْ يَوْمِكُمْ هَذَا إِلَى يَوْمِ الْقِيَامَةِ وَمَنْ كَانَ أَعْطَى شَيْئًا فَلاَ يَأْخُذْهُ ‏"‏ ‏.‏\hadithno{3430}\hadithtrans{Sabra al-Juhanni reported on the authority of his father:Allah's Messenger (ﷺ) prohibited the contracting of temporary marriage and said: Behold, it is forbidden from this very day of yours to the Day of Resurrection, and he who has given something (as a dower) should not take it back}}
\hadithdefcmd{muslim}{3431}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ، وَالْحَسَنِ، ابْنَىْ مُحَمَّدِ بْنِ عَلِيٍّ عَنْ أَبِيهِمَا، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ مُتْعَةِ النِّسَاءِ يَوْمَ خَيْبَرَ وَعَنْ أَكْلِ لُحُومِ الْحُمُرِ الإِنْسِيَّةِ ‏.‏\hadithno{3431}\hadithtrans{Ali b. AbiTalib reported that Allah's Messenger (ﷺ) prohibited on the Day of Khaibar the contracting of temporary marriage with women and the eating of the flesh of domestic asses}}
\hadithdefcmd{muslim}{3432}{وَحَدَّثَنَاهُ عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ الضُّبَعِيُّ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ مَالِكٍ، بِهَذَا الإِسْنَادِ وَقَالَ سَمِعَ عَلِيَّ بْنَ أَبِي طَالِبٍ، يَقُولُ لِفُلاَنٍ إِنَّكَ رَجُلٌ تَائِهٌ نَهَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ يَحْيَى بْنِ يَحْيَى عَنْ مَالِكٍ ‏.‏\hadithno{3432}\hadithtrans{Malik narrated this hadith on the authority of the same chain of trans- witters that 'Ali b. Abil Talib said to a person:You are a person led astray; Allah's Messenger (ﷺ) forbade us (to do Mut'a), as is stated In the hadith transmitted on the authority of Yahya b. Malik}}
\hadithdefcmd{muslim}{3433}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ وَزُهَيْرُ بْنُ حَرْبٍ جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنِ الزُّهْرِيِّ، عَنِ الْحَسَنِ، وَعَبْدِ اللَّهِ، ابْنَىْ مُحَمَّدِ بْنِ عَلِيٍّ عَنْ أَبِيهِمَا، عَنْ عَلِيٍّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنْ نِكَاحِ الْمُتْعَةِ يَوْمَ خَيْبَرَ وَعَنْ لُحُومِ الْحُمُرِ الأَهْلِيَّةِ ‏.‏\hadithno{3433}\hadithtrans{Muhammad b. 'Ali narrated on the authority of his father 'Ali that Allah's Apostle (ﷺ) on the Day of Khaibar prohibited for ever the contracting of temporary marriage and eating of the flesh of the domestic asses}}
\hadithdefcmd{muslim}{3434}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنِ ابْنِ شِهَابٍ، عَنِ الْحَسَنِ، وَعَبْدِ اللَّهِ، ابْنَىْ مُحَمَّدِ بْنِ عَلِيٍّ عَنْ أَبِيهِمَا، عَنْ عَلِيٍّ، أَنَّهُ سَمِعَ ابْنَ عَبَّاسٍ، يُلَيِّنُ فِي مُتْعَةِ النِّسَاءِ فَقَالَ مَهْلاً يَا ابْنَ عَبَّاسٍ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْهَا يَوْمَ خَيْبَرَ وَعَنْ لُحُومِ الْحُمُرِ الإِنْسِيَّةِ ‏.‏\hadithno{3434}\hadithtrans{Ali (Allah be pleased with him) heard that Ibn Abbas (Allah be pleased with them) gave some relaxation in connection with the contracting of temporary marriage, whereupon he said:Don't be hasty (in your religious verdict), Ibn 'Abbas, for Allah's Messenger (ﷺ) on the Day of Khaibar prohibited that forever - along with the eating of flesh of domestic asses}}
\hadithdefcmd{muslim}{3435}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنِ الْحَسَنِ، وَعَبْدِ اللَّهِ، ابْنَىْ مُحَمَّدِ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ عَنْ أَبِيهِمَا، أَنَّهُ سَمِعَ عَلِيَّ بْنَ أَبِي طَالِبٍ، يَقُولُ لاِبْنِ عَبَّاسٍ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ مُتْعَةِ النِّسَاءِ يَوْمَ خَيْبَرَ وَعَنْ أَكْلِ لُحُومِ الْحُمُرِ الإِنْسِيَّةِ ‏.‏\hadithno{3435}\hadithtrans{Ali (Allah be pleased with him) said to Ibn 'Abbas (Allah be pleased with them) that Allah's Messenger (ﷺ) on the Day of Khaibar forbade forever the contracting of temporary marriage and the eating of the flesh of domestic asses}}
\hadithdefcmd{muslim}{3436}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ‏ "‏ لاَ يُجْمَعُ بَيْنَ الْمَرْأَةِ وَعَمَّتِهَا وَلاَ بَيْنَ الْمَرْأَةِ وَخَالَتِهَا‏"‏ ‏.‏\hadithno{3436}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (may peace upon him) having said this:One should not combine a woman and her father's sister, nor a woman and her mother's sister in marriage}}
\hadithdefcmd{muslim}{3437}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ أَرْبَعِ نِسْوَةٍ أَنْ يُجْمَعَ بَيْنَهُنَّ الْمَرْأَةِ وَعَمَّتِهَا وَالْمَرْأَةِ وَخَالَتِهَا ‏.‏\hadithno{3437}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:that Allah's Messenger (ﷺ) forbade combining of four women in marriage: a woman with her father's sister, and a woman with her mother's sister}}
\hadithdefcmd{muslim}{3438}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ الْعَزِيزِ، - قَالَ ابْنُ مَسْلَمَةَ مَدَنِيٌّ مِنَ الأَنْصَارِ مِنْ وَلَدِ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ - عَنِ ابْنِ شِهَابٍ، عَنْ قَبِيصَةَ بْنِ ذُؤَيْبٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُنْكَحُ الْعَمَّةُ عَلَى بِنْتِ الأَخِ وَلاَ ابْنَةُ الأُخْتِ عَلَى الْخَالَةِ ‏"‏ ‏.‏\hadithno{3438}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:I heard Allah's Messenger (ﷺ) say: Father's sister should not be combined with her brother's daughter, nor the daughter of a sister with her mother's sister}}
\hadithdefcmd{muslim}{3439}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي قَبِيصَةُ بْنُ ذُؤَيْبٍ الْكَعْبِيُّ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَجْمَعَ الرَّجُلُ بَيْنَ الْمَرْأَةِ وَعَمَّتِهَا وَبَيْنَ الْمَرْأَةِ وَخَالَتِهَا ‏.‏ قَالَ ابْنُ شِهَابٍ فَنُرَى خَالَةَ أَبِيهَا وَعَمَّةَ أَبِيهَا بِتِلْكَ الْمَنْزِلَةِ ‏.‏\hadithno{3439}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Allah's Messenger (ﷺ) forbade a person to combine in marriage a womanarid her father's sister, and a woman and her mother's sister. Ibn Shihab said:So we regarded the paternal aunt of her (wife's) father and the maternal aunt of her (wife's) father at the same level}}
\hadithdefcmd{muslim}{3440}{وَحَدَّثَنِي أَبُو مَعْنٍ الرَّقَاشِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، أَنَّهُ كَتَبَ إِلَيْهِ عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُنْكَحُ الْمَرْأَةُ عَلَى عَمَّتِهَا وَلاَ عَلَى خَالَتِهَا ‏"‏ ‏.‏\hadithno{3440}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:One should not combine in marriage a woman with her father's sister, or her mother's sister}}
\hadithdefcmd{muslim}{3441}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنْ يَحْيَى، حَدَّثَنِي أَبُو سَلَمَةَ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ‏.‏\hadithno{3441}\hadithtrans{A hadith like this has been narrated on the authority of Abu Huraira (Allah be pleased with him) through another chain of transmitters}}
\hadithdefcmd{muslim}{3442}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَخْطُبُ الرَّجُلُ عَلَى خِطْبَةِ أَخِيهِ وَلاَ يَسُومُ عَلَى سَوْمِ أَخِيهِ وَلاَ تُنْكَحُ الْمَرْأَةُ عَلَى عَمَّتِهَا وَلاَ عَلَى خَالَتِهَا وَلاَ تَسْأَلُ الْمَرْأَةُ طَلاَقَ أُخْتِهَا لِتَكْتَفِئَ صَحْفَتَهَا وَلْتَنْكِحْ فَإِنَّمَا لَهَا مَا كَتَبَ اللَّهُ لَهَا ‏"‏ ‏.‏\hadithno{3442}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:A man must not make proposal of marriage to a woman when his brother has done so already. And he must not offer a price for a thing for which his brother had already offered a price; and a woman must not be combined in marriage with her father's sister, nor with her mother's sister, and a woman must not ask to have her sister divorced in order to deprive her of what belongs to her, but she must marry, because she will have what Allah has decreed for her}}
\hadithdefcmd{muslim}{3443}{وَحَدَّثَنِي مُحْرِزُ بْنُ عَوْنِ بْنِ أَبِي عَوْنٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ دَاوُدَ بْنِ أَبِي، هِنْدٍ عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُنْكَحَ الْمَرْأَةُ عَلَى عَمَّتِهَا أَوْ خَالَتِهَا أَوْ أَنْ تَسْأَلَ الْمَرْأَةُ طَلاَقَ أُخْتِهَا لِتَكْتَفِئَ مَا فِي صَحْفَتِهَا فَإِنَّ اللَّهَ عَزَّ وَجَلَّ رَازِقُهَا ‏.‏\hadithno{3443}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Allah's Messenger (ﷺ) forbade the combining of a woman in marriage with her father's sister, or with her mother's sister, or that a woman should ask for divorce for her sister in order to deprive her of what belongs to her. Allah, the Exalted'and Majestic, is her Sustainer too}}
\hadithdefcmd{muslim}{3444}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ وَأَبُو بَكْرِ بْنُ نَافِعٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى وَابْنِ نَافِعٍ - قَالُوا أَخْبَرَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُجْمَعَ بَيْنَ الْمَرْأَةِ وَعَمَّتِهَا وَبَيْنَ الْمَرْأَةِ وَخَالَتِهَا ‏.‏\hadithno{3444}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Allah's Messenger (ﷺ) forbade to combine a woman and her father's sister, and a woman and her mother's sister}}
\hadithdefcmd{muslim}{3445}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا وَرْقَاءُ، عَنْ عَمْرِو بْنِ دِينَارٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{3445}\hadithtrans{A hadith like this has been transmitted on the authority of Amr b. Dinar}}
\hadithdefcmd{muslim}{3446}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنْ نُبَيْهِ بْنِ وَهْبٍ، أَنَّفَقَالَ أَبَانٌ سَمِعْتُ عُثْمَانَ بْنَ عَفَّانَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَنْكِحُ الْمُحْرِمُ وَلاَ يُنْكَحُ وَلاَ يَخْطُبُ ‏"‏ ‏.‏\hadithno{3446}\hadithtrans{Nubaih b. Wahb reported that 'Umar b. Ubaidullah intended to marry Talha b. 'Umar with the daughter of Shaiba b. Jubair; so he sent a messenger to Aban b. Uthman to attend the marriage, and he was at that time the Amir of Hajj. Aban said:I heard 'Uthman b. 'Affan say that Allah's Messenger (ﷺ) had stated: A Muhrim must neither marry himself, nor arrange the marriage of another one, nor should he make the proposal of marriage}}
\hadithdefcmd{muslim}{3447}{وَحَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، حَدَّثَنِي نُبَيْهُ بْنُ وَهْبٍ، قَالَ بَعَثَنِي عُمَرُ بْنُ عُبَيْدِ اللَّهِ بْنِ مَعْمَرٍ وَكَانَ يَخْطُبُ بِنْتَ شَيْبَةَ بْنِ عُثْمَانَ عَلَى ابْنِهِ فَأَرْسَلَنِي إِلَى أَبَانِ بْنِ عُثْمَانَ وَهُوَ عَلَى الْمَوْسِمِ فَقَالَ أَلاَ أُرَاهُ أَعْرَابِيًّا ‏ "‏ إِنَّ الْمُحْرِمَ لاَ يَنْكِحُ وَلاَ يُنْكَحُ ‏"‏ ‏.‏ أَخْبَرَنَا بِذَلِكَ عُثْمَانُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3447}\hadithtrans{Nubaih b. Wahb reported:Umar b. Ubaidullah b. Ma'mar sent me to Aban b. Uthman as he wanted to make the proposal of the marriage of his son with the daughter of Shaiba b. Uthman. He (Aban b. Uthman) was at that time (busy) in the season of Pilgrimage. He said: I deem him to be a man of the desert (for it is a common thing) that a Muhrim can neither marry, nor is he allowed to be married to anyone. It is Uthman (b. Affan) who reported this to us from Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{3448}{وَحَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، ح وَحَدَّثَنِي أَبُو الْخَطَّابِ، زِيَادُ بْنُ يَحْيَى حَدَّثَنَا مُحَمَّدُ بْنُ سَوَاءٍ، قَالاَ جَمِيعًا حَدَّثَنَا سَعِيدٌ، عَنْ مَطَرٍ، وَيَعْلَى بْنِ حَكِيمٍ، عَنْ نَافِعٍ، عَنْ نُبَيْهِ بْنِ وَهْبٍ، عَنْ أَبَانِ بْنِ عُثْمَانَ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَنْكِحُ الْمُحْرِمُ وَلاَ يُنْكَحُ وَلاَ يَخْطُبُ ‏"‏ ‏.‏\hadithno{3448}\hadithtrans{Uthman b. 'Affan reported that Allah's Messenger (ﷺ) had said:A Muhrim should neither marry himself, nor should he be got married to anyone, nor should he make the proposal of marriage}}
\hadithdefcmd{muslim}{3449}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ، عُيَيْنَةَ - قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ نُبَيْهِ بْنِ وَهْبٍ، عَنْ أَبَانِ بْنِ عُثْمَانَ، عَنْ عُثْمَانَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُحْرِمُ لاَ يَنْكِحُ وَلاَ يَخْطُبُ ‏"‏ ‏.‏\hadithno{3449}\hadithtrans{Uthman (b. 'Affan) reported it directly from Allah's Apostle (ﷺ) that he said:A Muhrim should neithermarry (in that state) nor make the proposal of marriage}}
\hadithdefcmd{muslim}{3450}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي خَالِدُ بْنُ يَزِيدَ، حَدَّثَنِي سَعِيدُ بْنُ أَبِي هِلاَلٍ، عَنْ نُبَيْهِ بْنِ وَهْبٍ، أَنَّ عُمَرَ بْنَ عُبَيْدِ اللَّهِ بْنِ مَعْمَرٍ، أَرَادَ أَنْ يُنْكِحَ، ابْنَهُ طَلْحَةَ بِنْتَ شَيْبَةَ بْنِ جُبَيْرٍ فِي الْحَجِّ وَأَبَانُ بْنُ عُثْمَانَ يَوْمَئِذٍ أَمِيرُ الْحَاجِّ فَأَرْسَلَ إِلَى أَبَانٍ إِنِّي قَدْ أَرَدْتُ أَنْ أُنْكِحَ، طَلْحَةَ بْنَ عُمَرَ فَأُحِبُّ أَنْ تَحْضُرَ، ذَلِكَ ‏.‏ فَقَالَ لَهُ أَبَانٌ أَلاَ أُرَاكَ عِرَاقِيًّا جَافِيًا إِنِّي سَمِعْتُ عُثْمَانَ بْنَ عَفَّانَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَنْكِحُ الْمُحْرِمُ ‏"‏ ‏.‏\hadithno{3450}\hadithtrans{Nabaih b. Wahb reported that Umar b. 'Ubaidullah b. Ma'mar intended to marry his son Talha with the daughter of Shaiba b. Jubair during the Pilgrimage. Aban b. Uthman was at that time the Amir of Pilgrims. So he ('Umar b. Ubaidullah) sent someone (as a messenger) to Aban saying:I intend to marry Talha b. 'Umar and I earnestly desire you to be present there (in this ceremony of marriage). Aban said to him: I find you a block-headed 'Iraqi. I heard 'Uthman b. 'Affan say that Allah's Messenger (ﷺ) said: A Muhrim should not marry}}
\hadithdefcmd{muslim}{3451}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ وَإِسْحَاقُ الْحَنْظَلِيُّ جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ ابْنُ نُمَيْرٍ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ أَبِي الشَّعْثَاءِ، أَنَّ ابْنَ، عَبَّاسٍ أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم تَزَوَّجَ مَيْمُونَةَ وَهُوَ مُحْرِمٌ ‏.‏ زَادَ ابْنُ نُمَيْرٍ فَحَدَّثْتُ بِهِ الزُّهْرِيَّ فَقَالَ أَخْبَرَنِي يَزِيدُ بْنُ الأَصَمِّ أَنَّهُ نَكَحَهَا وَهُوَ حَلاَلٌ ‏.‏\hadithno{3451}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported that Allah's Apostle (ﷺ) married Maimuna in the state of Ihram. Ibn Numair made this addition:" I narrated it to Zuhri and he said: Yazid b. al-Asamm (Allah be pleased with him) told me that he (the Holy Prophet) married her when he was not a muhrim}}
\hadithdefcmd{muslim}{3452}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا دَاوُدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ زَيْدٍ أَبِي الشَّعْثَاءِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ تَزَوَّجَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَيْمُونَةَ وَهُوَ مُحْرِمٌ ‏.‏\hadithno{3452}\hadithtrans{Ibn 'Abbas (Allah be pleased with them) reported:Allah's Messenger. (ﷺ) married Maimuna while he was a Muhrim}}
\hadithdefcmd{muslim}{3453}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنَا أَبُو فَزَارَةَ، عَنْ يَزِيدَ بْنِ الأَصَمِّ، حَدَّثَتْنِي مَيْمُونَةُ بِنْتُ الْحَارِثِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَزَوَّجَهَا وَهُوَ حَلاَلٌ قَالَ وَكَانَتْ خَالَتِي وَخَالَةَ ابْنِ عَبَّاسٍ ‏.‏\hadithno{3453}\hadithtrans{Yazid b. al-Asamm reported:Maimuna daughter of al-Harith narrated to me that Allah's Messenger (ﷺ) married her and he was not in the state of Ihram. And she (Maimuna) was my mother's sister and that of Ibn 'Abbas (Allah be pleased with them)}}
\hadithdefcmd{muslim}{3454}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبِعْ بَعْضُكُمْ عَلَى بَيْعِ بَعْضٍ وَلاَ يَخْطُبْ بَعْضُكُمْ عَلَى خِطْبَةِ بَعْضٍ ‏"‏ ‏.‏\hadithno{3454}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Apostle (ﷺ) as having said this:None amongst you should outbid another in a transaction, nor should he make proposals of marriage upon the proposal made by someone else}}
\hadithdefcmd{muslim}{3455}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، جَمِيعًا عَنْ يَحْيَى الْقَطَّانِ، قَالَ زُهَيْرٌ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَبِعِ الرَّجُلُ عَلَى بَيْعِ أَخِيهِ وَلاَ يَخْطُبْ عَلَى خِطْبَةِ أَخِيهِ إِلاَّ أَنْ يَأْذَنَ لَهُ ‏"‏ ‏.‏\hadithno{3455}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Apostle (ﷺ) as having said this:A person should not enter into a transaction when his brother (had already entered into but not finalised), and he should not make proposal of marriage upon the proposal already made by his brother, until he permits it}}
\hadithdefcmd{muslim}{3456}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ\hadithno{3456}\hadithtrans{Narrated Ibn Umar :The above hadith has been narrated by Ibn Umar through another chain}}
\hadithdefcmd{muslim}{3457}{وَحَدَّثَنِيهِ أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، بِهَذَا الإِسْنَادِ‏.‏\hadithno{3457}\hadithtrans{A hadith like this has been reported on the authority of Nafi' with the same chain of transmitters}}
\hadithdefcmd{muslim}{3458}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ أَبِي عُمَرَ، قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ، بْنُ عُيَيْنَةَ عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى أَنْ يَبِيعَ حَاضِرٌ لِبَادٍ أَوْ يَتَنَاجَشُوا أَوْ يَخْطُبَ الرَّجُلُ عَلَى خِطْبَةِ أَخِيهِ أَوْ يَبِيعَ عَلَى بَيْعِ أَخِيهِ وَلاَ تَسْأَلِ الْمَرْأَةُ طَلاَقَ أُخْتِهَا لِتَكْتَفِئَ مَا فِي إِنَائِهَا أَوْ مَا فِي صَحْفَتِهَا ‏.‏ زَادَ عَمْرٌو فِي رِوَايَتِهِ وَلاَ يَسُمِ الرَّجُلُ عَلَى سَوْمِ أَخِيهِ ‏.‏\hadithno{3458}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as having forbidden a dweller of the town selling the merchandise of a villager or outbidding in a sale (in order that another might fall into a snare), or a person making the proposal of marriage when his brother has already made such a proposal, or entering into a transaction when his brother has already entered; and a woman asking the divorce of her sister in order to deprive her of what belongs to her. 'Amr made this addition:" The person should not purchase in opposition to his brother}}
\hadithdefcmd{muslim}{3459}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَنَاجَشُوا وَلاَ يَبِعِ الْمَرْءُ عَلَى بَيْعِ أَخِيهِ وَلاَ يَبِعْ حَاضِرٌ لِبَادٍ وَلاَ يَخْطُبِ الْمَرْءُ عَلَى خِطْبَةِ أَخِيهِ وَلاَ تَسْأَلِ الْمَرْأَةُ طَلاَقَ الأُخْرَى لِتَكْتَفِئَ مَا فِي إِنَائِهَا ‏"‏ ‏.‏\hadithno{3459}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as having said this:Do not outbid in a sale in order to ensnare. No man should enter into a transaction in which his brother has already entered, and no dweller of the town should sell on behalf of the villager. And no man should make a proposal of marriage which his brother has already made and no woman should ask for the divorce of another (co-wife) in order to deprive her of what belongs to her}}
\hadithdefcmd{muslim}{3460}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، جَمِيعًا عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّ فِي حَدِيثِ مَعْمَرٍ ‏ "‏ وَلاَ يَزِدِ الرَّجُلُ عَلَى بَيْعِ أَخِيهِ ‏"‏ ‏.‏\hadithno{3460}\hadithtrans{A hadith like this has been narrated on the authority of Zuhri with the same chain of transmitters but with a slight alteration}}
\hadithdefcmd{muslim}{3461}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ جَمِيعًا عَنْ إِسْمَاعِيلَ بْنِ جَعْفَرٍ، - قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ، - أَخْبَرَنِي الْعَلاَءُ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَسُمِ الْمُسْلِمُ عَلَى سَوْمِ أَخِيهِ وَلاَ يَخْطُبْ عَلَى خِطْبَتِهِ ‏"‏ ‏.‏\hadithno{3461}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:The Muslim should not purchase in opposition to his brother, and he should not make the proposal of marriage on the proposal already made by his brother}}
\hadithdefcmd{muslim}{3462}{وَحَدَّثَنِي أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا شُعْبَةُ، عَنِ الْعَلاَءِ، وَسُهَيْلٍ عَنْ أَبِيهِمَا، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنَاهُ مُحَمَّدُ، بْنُ الْمُثَنَّى حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ أَنَّهُمْ قَالُوا ‏ "‏ عَلَى سَوْمِ أَخِيهِ وَخِطْبَةِ أَخِيهِ ‏"‏ ‏.‏\hadithno{3462}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira (Allah be pleased with him) through another chain of transmitters}}
\hadithdefcmd{muslim}{3464}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنِ اللَّيْثِ، وَغَيْرِهِ، عَنْ يَزِيدَ بْنِ، أَبِي حَبِيبٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ شُمَاسَةَ، أَنَّهُ سَمِعَ عُقْبَةَ بْنَ عَامِرٍ، عَلَى الْمِنْبَرِ يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُؤْمِنُ أَخُو الْمُؤْمِنِ فَلاَ يَحِلُّ لِلْمُؤْمِنِ أَنْ يَبْتَاعَ عَلَى بَيْعِ أَخِيهِ وَلاَ يَخْطُبَ عَلَى خِطْبَةِ أَخِيهِ حَتَّى يَذَرَ ‏"‏ ‏.‏\hadithno{3464}\hadithtrans{Uqba b. 'Amir said on the pulpit that Allah's Messenger (ﷺ) said:A believer is the brother of a believer, so it is not lawful for a believer to outbid his brother, and he should not propose an engagement when his brother has thus proposed until he gives it up}}
\hadithdefcmd{muslim}{3465}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الشِّغَارِ ‏.‏ وَالشِّغَارُ أَنْ يُزَوِّجَ الرَّجُلُ ابْنَتَهُ عَلَى أَنْ يُزَوِّجَهُ ابْنَتَهُ وَلَيْسَ بَيْنَهُمَا صَدَاقٌ ‏.‏\hadithno{3465}\hadithtrans{Ibn Umar (Allah be pleased with them) said that Allah's Messenger (ﷺ) prohibited Shighar which means that a man gives his daughter in marriage on the condition that the other gives his daughter to him in marriage with- out any dower being paid by either}}
\hadithdefcmd{muslim}{3466}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالُوا حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّ فِي حَدِيثِ عُبَيْدِ اللَّهِ قَالَ قُلْتُ لِنَافِعٍ مَا الشِّغَارُ\hadithno{3466}\hadithtrans{A hadith like this has been narrated on the authority of" Abdullah b. 'Umar (Allah be pleased with them) but with a slight variation of words}}
\hadithdefcmd{muslim}{3467}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ السَّرَّاجِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الشِّغَارِ ‏.‏\hadithno{3467}\hadithtrans{Ibn Umar (Allah be pleased with them) reported that Allah's Messenger (ﷺ) prohibited Shighar}}
\hadithdefcmd{muslim}{3468}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ شِغَارَ فِي الإِسْلاَمِ ‏"‏ ‏.‏\hadithno{3468}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Messenger (ﷺ) as having said:There is no Shighar in islam}}
\hadithdefcmd{muslim}{3469}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ عَنْ عُبَيْدِ اللَّهِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الشِّغَارِ ‏.‏ زَادَ ابْنُ نُمَيْرٍ وَالشِّغَارُ أَنْ يَقُولَ الرَّجُلُ لِلرَّجُلِ زَوِّجْنِي ابْنَتَكَ وَأُزَوِّجُكَ ابْنَتِي أَوْ زَوِّجْنِي أُخْتَكَ وَأُزَوِّجُكَ أُخْتِي ‏.‏\hadithno{3469}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Allah's Messenger (ﷺ) prohibited Shighar. Ibn Numair added:Shighar means that a person should say to the other person: Give me the hand of your daughter in marriage and I will (in return) marry my daughter to you; or merry me your sister, and I will marry my sister to you}}
\hadithdefcmd{muslim}{3470}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ، عَنْ عُبَيْدِ اللَّهِ، - وَهُوَ ابْنُ عُمَرَ - بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ زِيَادَةَ ابْنِ نُمَيْرٍ ‏.‏\hadithno{3470}\hadithtrans{This hadith has been narrated on the authority of Ibn Vmar with the same chain of transmitters, but there is no mention of Ibn Numair}}
\hadithdefcmd{muslim}{3471}{وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ ح وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، عَنْ عَبْدِ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الشِّغَارِ ‏.‏\hadithno{3471}\hadithtrans{Jabir b. Abdullah (Allah be pleased with him) reported that Allah's Messenger (ﷺ) prohibited Shighar}}
\hadithdefcmd{muslim}{3472}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا هُشَيْمٌ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مَرْثَدِ بْنِ عَبْدِ، اللَّهِ الْيَزَنِيِّ عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ أَحَقَّ الشَّرْطِ أَنْ يُوفَى بِهِ مَا اسْتَحْلَلْتُمْ بِهِ الْفُرُوجَ ‏"‏ ‏.‏ هَذَا لَفْظُ حَدِيثِ أَبِي بَكْرٍ وَابْنِ الْمُثَنَّى ‏.‏ غَيْرَ أَنَّ ابْنَ الْمُثَنَّى قَالَ ‏"‏ الشُّرُوطِ ‏"‏ ‏.‏\hadithno{3472}\hadithtrans{Uqba b. Amir (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:The most worthy condition which must be fulfilled is that which makes sexual intercourse lawful. In the narration transmitted by Ibn Muthanna (instead of the word" condition" ) it is" conditions}}
\hadithdefcmd{muslim}{3473}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ الْقَوَارِيرِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، حَدَّثَنَا أَبُو سَلَمَةَ، حَدَّثَنَا أَبُو هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تُنْكَحُ الأَيِّمُ حَتَّى تُسْتَأْمَرَ وَلاَ تُنْكَحُ الْبِكْرُ حَتَّى تُسْتَأْذَنَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَكَيْفَ إِذْنُهَا قَالَ ‏"‏ أَنْ تَسْكُتَ ‏"‏ ‏.‏\hadithno{3473}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as having said:A woman without a husband (or divorced or a widow) must not be married until she is consulted, and a virgin must not be married until her permission is sought. They asked the Prophet of Allah (ﷺ): How her (virgin's) consent can be solicited? He (the Holy Prophet) said: That she keeps silence}}
\hadithdefcmd{muslim}{3474}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْحَجَّاجُ بْنُ أَبِي، عُثْمَانَ ح وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ مُوسَى، أَخْبَرَنَا عِيسَى، - يَعْنِي ابْنَ يُونُسَ - عَنِ الأَوْزَاعِيِّ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا حُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، ح وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، وَمُحَمَّدُ بْنُ رَافِعٍ قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، الدَّارِمِيُّ أَخْبَرَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا مُعَاوِيَةُ، كُلُّهُمْ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، ‏.‏ بِمِثْلِ مَعْنَى حَدِيثِ هِشَامٍ وَإِسْنَادِهِ ‏.‏ وَاتَّفَقَ لَفْظُ حَدِيثِ هِشَامٍ وَشَيْبَانَ وَمُعَاوِيَةَ بْنِ سَلاَّمٍ فِي هَذَا الْحَدِيثِ‏.‏\hadithno{3474}\hadithtrans{This hadith has been narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{3475}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ ابْنِ جُرَيْجٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، جَمِيعًا عَنْ عَبْدِ الرَّزَّاقِ، - وَاللَّفْظُ لاِبْنِ رَافِعٍ - حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ سَمِعْتُ ابْنَ أَبِي مُلَيْكَةَ، يَقُولُ قَالَ ذَكْوَانُ مَوْلَى عَائِشَةَ سَمِعْتُ عَائِشَةَ، تَقُولُ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْجَارِيَةِ يُنْكِحُهَا أَهْلُهَا أَتُسْتَأْمَرُ أَمْ لاَ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ تُسْتَأْمَرُ ‏"‏ ‏.‏ فَقَالَتْ عَائِشَةُ فَقُلْتُ لَهُ فَإِنَّهَا تَسْتَحْيِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَذَلِكَ إِذْنُهَا إِذَا هِيَ سَكَتَتْ ‏"‏ ‏.‏\hadithno{3475}\hadithtrans{A'isha (Allah be pleased with her) reported:I asked Allah's Messenger (ﷺ) about a virgin whose marriage is solemnised by her guardian, whether it was necessary or not to consult her. Allah's Messerger (ﷺ) said: Yes, she must be consulted. 'A'isha reported: I told him that she feels shy, whereupon Allah's Messenger (ﷺ) said: Her silence implies her consent}}
\hadithdefcmd{muslim}{3476}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا يَحْيَى، بْنُ يَحْيَى - وَاللَّفْظُ لَهُ - قَالَ قُلْتُ لِمَالِكٍ حَدَّثَكَ عَبْدُ اللَّهِ بْنُ الْفَضْلِ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الأَيِّمُ أَحَقُّ بِنَفْسِهَا مِنْ وَلِيِّهَا وَالْبِكْرُ تُسْتَأْذَنُ فِي نَفْسِهَا وَإِذْنُهَا صُمَاتُهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏\hadithno{3476}\hadithtrans{Ibn 'Abbas (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying:A woman without a husband has more right to her person than her guardian, and a virgin's consent must be asked from her, and her silence implies her consent}}
\hadithdefcmd{muslim}{3477}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ زِيَادِ بْنِ سَعْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، سَمِعَ نَافِعَ بْنَ جُبَيْرٍ، يُخْبِرُ عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الثَّيِّبُ أَحَقُّ بِنَفْسِهَا مِنْ وَلِيِّهَا وَالْبِكْرُ تُسْتَأْمَرُ وَإِذْنُهَا سُكُوتُهَا ‏"‏ ‏.‏\hadithno{3477}\hadithtrans{Ibn Abbas (Allah be pleased with them) reported Allah's Messenger (ﷺ) as saying:A woman who has been previously married (Thayyib) has more right to her person than her guardian. And a virgin should also be consulted, and her silence implies her consent}}
\hadithdefcmd{muslim}{3478}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، بِهَذَا الإِسْنَادِ وَقَالَ ‏"‏ الثَّيِّبُ أَحَقُّ بِنَفْسِهَا مِنْ وَلِيِّهَا وَالْبِكْرُ يَسْتَأْذِنُهَا أَبُوهَا فِي نَفْسِهَا وَإِذْنُهَا صُمَاتُهَا ‏"‏ ‏.‏ وَرُبَّمَا قَالَ ‏"‏ وَصَمْتُهَا إِقْرَارُهَا ‏"‏ ‏.‏\hadithno{3478}\hadithtrans{Sufyan reported on the basis of the same chain of transmitters (and the words are):A woman who has been previously married (Thayyib) has more right to her person than her guardian; and a virgin's father must ask her consent from her, her consent being her silence, At times he said: Her silence is her affirmation}}
\hadithdefcmd{muslim}{3479}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي، شَيْبَةَ قَالَ وَجَدْتُ فِي كِتَابِي عَنْ أَبِي أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ تَزَوَّجَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم لِسِتِّ سِنِينَ وَبَنَى بِي وَأَنَا بِنْتُ تِسْعِ سِنِينَ ‏.‏ قَالَتْ فَقَدِمْنَا الْمَدِينَةَ فَوُعِكْتُ شَهْرًا فَوَفَى شَعْرِي جُمَيْمَةً فَأَتَتْنِي أُمُّ رُومَانَ وَأَنَا عَلَى أُرْجُوحَةٍ وَمَعِي صَوَاحِبِي فَصَرَخَتْ بِي فَأَتَيْتُهَا وَمَا أَدْرِي مَا تُرِيدُ بِي فَأَخَذَتْ بِيَدِي فَأَوْقَفَتْنِي عَلَى الْبَابِ ‏.‏ فَقُلْتُ هَهْ هَهْ ‏.‏ حَتَّى ذَهَبَ نَفَسِي فَأَدْخَلَتْنِي بَيْتًا فَإِذَا نِسْوَةٌ مِنَ الأَنْصَارِ فَقُلْنَ عَلَى الْخَيْرِ وَالْبَرَكَةِ وَعَلَى خَيْرِ طَائِرٍ ‏.‏ فَأَسْلَمَتْنِي إِلَيْهِنَّ فَغَسَلْنَ رَأْسِي وَأَصْلَحْنَنِي فَلَمْ يَرُعْنِي إِلاَّ وَرَسُولُ اللَّهِ صلى الله عليه وسلم ضُحًى فَأَسْلَمْنَنِي إِلَيْهِ ‏.‏\hadithno{3479}\hadithtrans{A'isha (Allah be pleased with her) reported:Allah's Messenger (ﷺ) married me when I was six years old, and I was admitted to his house at the age of nine. She further said: We went to Medina and I had an attack of fever for a month, and my hair had come down to the earlobes. Umm Ruman (my mother) came to me and I was at that time on a swing along with my playmates. She called me loudly and I went to her and I did not know what she had wanted of me. She took hold of my hand and took me to the door, and I was saying: Ha, ha (as if I was gasping), until the agitation of my heart was over. She took me to a house, where had gathered the women of the Ansar. They all blessed me and wished me good luck and said: May you have share in good. She (my mother) entrusted me to them. They washed my head and embellished me and nothing frightened me. Allah's Messenger (, may peace be upon him) came there in the morning, and I was entrusted to him}}
\hadithdefcmd{muslim}{3480}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدَةُ، - هُوَ ابْنُ سُلَيْمَانَ - عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ تَزَوَّجَنِي النَّبِيُّ صلى الله عليه وسلم وَأَنَا بِنْتُ سِتِّ سِنِينَ وَبَنَى بِي وَأَنَا بِنْتُ تِسْعِ سِنِينَ ‏.‏\hadithno{3480}\hadithtrans{A'isha (Allah be pleased with her) reported:Allah's Apostle (ﷺ) married me when I was six years old, and I was admitted to his house when I was nine years old}}
\hadithdefcmd{muslim}{3481}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم تَزَوَّجَهَا وَهْىَ بِنْتُ سَبْعِ سِنِينَ وَزُفَّتْ إِلَيْهِ وَهِيَ بِنْتُ تِسْعِ سِنِينَ وَلُعَبُهَا مَعَهَا وَمَاتَ عَنْهَا وَهِيَ بِنْتُ ثَمَانَ عَشْرَةَ ‏.‏\hadithno{3481}\hadithtrans{A'isha (Allah be pleased with her) reported that Allah's Apostle (ﷺ) married her when she was seven years old, and he was taken to his house as a bride when she was nine, and her dolls were with her; and when he (the Holy Prophet) died she was eighteen years old}}
\hadithdefcmd{muslim}{3482}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَأَبُو كُرَيْبٍ قَالَ يَحْيَى وَإِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ تَزَوَّجَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَهْىَ بِنْتُ سِتٍّ وَبَنَى بِهَا وَهْىَ بِنْتُ تِسْعٍ وَمَاتَ عَنْهَا وَهْىَ بِنْتُ ثَمَانَ عَشْرَةَ ‏.‏\hadithno{3482}\hadithtrans{Narrated 'A'isha :'A'isha (Allah be pleased with her) reported that Allah's Apostle (ﷺ) married her when she was six years old, and he (the Holy Prophet) took her to his house when she was nine, and when he (the Holy Prophet) died she was eighteen years old}}
\hadithdefcmd{muslim}{3483}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ تَزَوَّجَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي شَوَّالٍ وَبَنَى بِي فِي شَوَّالٍ فَأَىُّ نِسَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَ أَحْظَى عِنْدَهُ مِنِّي ‏.‏ قَالَ وَكَانَتْ عَائِشَةُ تَسْتَحِبُّ أَنْ تُدْخِلَ نِسَاءَهَا فِي شَوَّالٍ ‏.‏\hadithno{3483}\hadithtrans{A'isha (Allah be pleased with her) reported:Allah's Messenger (ﷺ) contracted marriage with me in Shawwal and took me to his house as a bride during Shawwal. And who among the wives of Allah's Messenger (ﷺ) was dearer to him than I, and' A'isha liked that the women (of her family) should enter the houses as brides during the month of Shawwal}}
\hadithdefcmd{muslim}{3484}{وَحَدَّثَنَاهُ ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سُفْيَانُ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ فِعْلَ عَائِشَةَ‏.‏\hadithno{3484}\hadithtrans{This hadith has been narrated on the authority of Sufyan with the same chain of transmitters, but he made no mention of the act of 'A'isha (being admitted as a wife in the house of the Holy Prophet)}}
\hadithdefcmd{muslim}{3485}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي، هُرَيْرَةَ قَالَ كُنْتُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَأَتَاهُ رَجُلٌ فَأَخْبَرَهُ أَنَّهُ تَزَوَّجَ امْرَأَةً مِنَ الأَنْصَارِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَنَظَرْتَ إِلَيْهَا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَاذْهَبْ فَانْظُرْ إِلَيْهَا فَإِنَّ فِي أَعْيُنِ الأَنْصَارِ شَيْئًا ‏"‏ ‏.‏\hadithno{3485}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:I was in the company of Allah's Messenger (ﷺ) when there came a man and informed him that he had contracted to marry a woman of the Ansar. Thereupon Allah's Messenger (ﷺ) said: Did you cast a glance at her? He said: No. He said: Go and cast a glance at her, for there is something in the eyes of the Ansar}}
\hadithdefcmd{muslim}{3486}{وَحَدَّثَنِي يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، حَدَّثَنَا يَزِيدُ بْنُ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنِّي تَزَوَّجْتُ امْرَأَةً مِنَ الأَنْصَارِ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلْ نَظَرْتَ إِلَيْهَا فَإِنَّ فِي عُيُونِ الأَنْصَارِ شَيْئًا ‏"‏ ‏.‏ قَالَ قَدْ نَظَرْتُ إِلَيْهَا ‏.‏ قَالَ ‏"‏ عَلَى كَمْ تَزَوَّجْتَهَا ‏"‏ ‏.‏ قَالَ عَلَى أَرْبَعِ أَوَاقٍ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَلَى أَرْبَعِ أَوَاقٍ كَأَنَّمَا تَنْحِتُونَ الْفِضَّةَ مِنْ عُرْضِ هَذَا الْجَبَلِ مَا عِنْدَنَا مَا نُعْطِيكَ وَلَكِنْ عَسَى أَنْ نَبْعَثَكَ فِي بَعْثٍ تُصِيبُ مِنْهُ ‏"‏ ‏.‏ قَالَ فَبَعَثَ بَعْثًا إِلَى بَنِي عَبْسٍ بَعَثَ ذَلِكَ الرَّجُلَ فِيهِمْ ‏.‏\hadithno{3486}\hadithtrans{Abu Huraira (Allah be pleased with him) reported:A man came to Allah's Messenger (ﷺ) and said: I have contracted marriage with a woman of the Ansar, whereupon Allah's Apostle (ﷺ) said: Did you cast a glance at her, for there is something in the eyes of the Ansar? He said: I did cast a glance at her, whereupon he said: For what (dower) did you marry her? He said: For four 'uqiyas. Thereupon Allah's Apostle (ﷺ) said: For four 'uqiyas; it seems as if you dig out silver from the side of this mountain (and that is why you are prepared to pay such a large amount of dower). We have nothing which we should give you. There is a possibility that we may send you to an (expedition) where you may get (booty). So he sent that man (in the expedition) which was despatched to Banu 'Abs}}
\hadithdefcmd{muslim}{3487}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ الثَّقَفِيُّ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، ح وَحَدَّثَنَاهُ قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلِ بْنِ سَعْدٍ، السَّاعِدِيِّ قَالَ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ جِئْتُ أَهَبُ لَكَ نَفْسِي ‏.‏ فَنَظَرَ إِلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَعَّدَ النَّظَرَ فِيهَا وَصَوَّبَهُ ثُمَّ طَأْطَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَأْسَهُ فَلَمَّا رَأَتِ الْمَرْأَةُ أَنَّهُ لَمْ يَقْضِ فِيهَا شَيْئًا جَلَسَتْ فَقَامَ رَجُلٌ مِنْ أَصْحَابِهِ فَقَالَ يَا رَسُولَ اللَّهِ إِنْ لَمْ يَكُنْ لَكَ بِهَا حَاجَةٌ فَزَوِّجْنِيهَا ‏.‏ فَقَالَ ‏"‏ فَهَلْ عِنْدَكَ مِنْ شَىْءٍ ‏"‏ ‏.‏ فَقَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ اذْهَبْ إِلَى أَهْلِكَ فَانْظُرْ هَلْ تَجِدُ شَيْئًا ‏"‏ ‏.‏ فَذَهَبَ ثُمَّ رَجَعَ فَقَالَ لاَ وَاللَّهِ مَا وَجَدْتُ شَيْئًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ انْظُرْ وَلَوْ خَاتِمًا مِنْ حَدِيدٍ ‏"‏ ‏.‏ فَذَهَبَ ثُمَّ رَجَعَ ‏.‏ فَقَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ وَلاَ خَاتِمًا مِنْ حَدِيدٍ ‏.‏ وَلَكِنْ هَذَا إِزَارِي - قَالَ سَهْلٌ مَا لَهُ رِدَاءٌ - فَلَهَا نِصْفُهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا تَصْنَعُ بِإِزَارِكَ إِنْ لَبِسْتَهُ لَمْ يَكُنْ عَلَيْهَا مِنْهُ شَىْءٌ وَإِنْ لَبِسَتْهُ لَمْ يَكُنْ عَلَيْكَ مِنْهُ شَىْءٌ ‏"‏ ‏.‏ فَجَلَسَ الرَّجُلُ حَتَّى إِذَا طَالَ مَجْلِسُهُ قَامَ فَرَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مُوَلِّيًا فَأَمَرَ بِهِ فَدُعِيَ فَلَمَّا جَاءَ قَالَ ‏"‏ مَاذَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ مَعِي سُورَةُ كَذَا وَسُورَةُ كَذَا - عَدَّدَهَا ‏.‏ فَقَالَ ‏"‏ تَقْرَؤُهُنَّ عَنْ ظَهْرِ قَلْبِكَ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ اذْهَبْ فَقَدْ مَلَّكْتُكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏ ‏.‏ هَذَا حَدِيثُ ابْنِ أَبِي حَازِمٍ وَحَدِيثُ يَعْقُوبَ يُقَارِبُهُ فِي اللَّفْظِ ‏.‏\hadithno{3487}\hadithtrans{Sahl b. Sa'd al-Sa'idi (Allah be pleased with him) reported:A woman came to Allah's Messenger. (ﷺ) and said: Messenger of Allah, I have come to you to entrust myself to you (you may contract my marriage with anyone at your discretion). Allah's Messenger (ﷺ) saw her and cast a glance at her from head to foot. Allah's Messenger (ﷺ) then lowered his head. When the woman saw that he had made no decision in regard to her, she sat down. There stood up a person from amongst his companions and said: Messenger of Allah, marry her to me if you have no need of her. He (the Prophet) said: is there anything with you (which you con give as a dower)? He said: No, Messenger of Allah, by Allah I have nothing. Thereupon Allah's Messenger (ﷺ) said: Go to your people (family) and see if you can find something. He returned and said: I have found nothing. The Messenger of Allah (ﷺ) said: See even if it is an iron ring. He went and returned and said: No, by Allah, not even an iron ring, but only this lower garment of mine (Sahl said that he had no upper garment), half of which (I am prepared to part with) for her. Thereupon Allah's Messenger (ﷺ) said: How can your lower garment serve your purpose, for it you wear it, she would not be able to make any use of it and if she wears it there would not be anything on you? The man sat down and as the sitting prolonged he stood up (in disappointment) and as he was going back Allah's Messenger (ﷺ) commanded (him) to be called back, and as he came, he said to him: Do you know any part of the Qur'an? He said: I know such and such surahs (and he counted them), whereupon he (ﷺ) said: Can you recite them from heart (from your memory)? He said: Yes, whereupon he (Allah's Messenger) said: Go, I have given her to you in marriage for the part of the Qur'an which you know}}
\hadithdefcmd{muslim}{3488}{وَحَدَّثَنَاهُ خَلَفُ بْنُ هِشَامٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، ح وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنِ الدَّرَاوَرْدِيِّ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ، أَبِي شَيْبَةَ حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، كُلُّهُمْ عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، بِهَذَا الْحَدِيثِ يَزِيدُ بَعْضُهُمْ عَلَى بَعْضٍ غَيْرَ أَنَّ فِي حَدِيثِ زَائِدَةَ قَالَ ‏ "‏ انْطَلِقْ فَقَدْ زَوَّجْتُكَهَا فَعَلِّمْهَا مِنَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{3488}\hadithtrans{This hadith has been narrated on the authority of Sahl b. Sa'd with a minor alteration of words, but the hadith transmitted through Za'idah (the words are that the Holy Prophet) said:Go, I have married her to you, and you teach her something of the Qur'an}}
\hadithdefcmd{muslim}{3489}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، حَدَّثَنِي يَزِيدُ بْنُ عَبْدِ، اللَّهِ بْنِ أُسَامَةَ بْنِ الْهَادِ ح وَحَدَّثَنِي مُحَمَّدُ بْنُ أَبِي عُمَرَ الْمَكِّيُّ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدُ، الْعَزِيزِ عَنْ يَزِيدَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ قَالَ سَأَلْتُ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم كَمْ كَانَ صَدَاقُ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ كَانَ صَدَاقُهُ لأَزْوَاجِهِ ثِنْتَىْ عَشْرَةَ أُوقِيَّةً وَنَشًّا ‏.‏ قَالَتْ أَتَدْرِي مَا النَّشُّ قَالَ قُلْتُ لاَ ‏.‏ قَالَتْ نِصْفُ أُوقِيَّةٍ ‏.‏ فَتِلْكَ خَمْسُمِائَةِ دِرْهَمٍ فَهَذَا صَدَاقُ رَسُولِ اللَّهِ صلى الله عليه وسلم لأَزْوَاجِهِ‏.‏\hadithno{3489}\hadithtrans{Abu Salama b. 'Abd al-Rahman reported:I asked 'A'isha, the wife of Allah's Messenger (ﷺ): What is the amount of dower of Allah's Messenger (ﷺ)? She said: It was twelve 'uqiyas and one nash. She said: Do you know what is al-nash? I said: No. She said: It is half of uqiya, and it amounts to five hundred dirhams, and that was the dower given by Allah's Messenger (ﷺ) to his wives}}
\hadithdefcmd{muslim}{3490}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَأَبُو الرَّبِيعِ، سُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ وَقُتَيْبَةُ بْنُ سَعِيدٍ وَاللَّفْظُ لِيَحْيَى قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى عَلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ أَثَرَ صُفْرَةٍ فَقَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ إِنِّي تَزَوَّجْتُ امْرَأَةً عَلَى وَزْنِ نَوَاةٍ مِنْ ذَهَبٍ ‏.‏ قَالَ ‏"‏ فَبَارَكَ اللَّهُ لَكَ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏\hadithno{3490}\hadithtrans{Anas b. Malik reported that Allah's Apostle (ﷺ) saw the trace of yellowness on 'Abd al-Rahman b. 'Auf and said:What is this? Thereupon he said: Allah's Messenger, I have married a woman for a date-stone's weight of gold. He said: God bless you! Hold a wedding feast, even if only with a sheep}}
\hadithdefcmd{muslim}{3491}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْغُبَرِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ، تَزَوَّجَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى وَزْنِ نَوَاةٍ مِنْ ذَهَبٍ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏\hadithno{3491}\hadithtrans{Anas b. Malik (Allah be pleasedwith him) reported that 'Abd al-Rahman b. 'Auf (Allah be pleased with him) married during the lifetime of Allah's Messenger (ﷺ) for a nawat weight of gold and the messenger of Allah (ﷺ) said to him:Give a feast even with a sheep}}
\hadithdefcmd{muslim}{3492}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا وَكِيعٌ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، وَحُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ، تَزَوَّجَ امْرَأَةً عَلَى وَزْنِ نَوَاةٍ مِنْ ذَهَبٍ وَأَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ ‏ "‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏ ‏.‏\hadithno{3492}\hadithtrans{Anas b. Malik (Allah be pleased with him) reported that 'Abd al-Rahman b. 'Auf (Allah be pleased with him) married a woman for a date-stone's weight of gold and Allah's Apostle (ﷺ) said to him:Hold a wedding feast, even if only with a sheep}}
\hadithdefcmd{muslim}{3493}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَهَارُونُ، بْنُ عَبْدِ اللَّهِ قَالاَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ خِرَاشٍ، حَدَّثَنَا شَبَابَةُ، كُلُّهُمْ عَنْ شُعْبَةَ، عَنْ حُمَيْدٍ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّ فِي، حَدِيثِ وَهْبٍ قَالَ قَالَ عَبْدُ الرَّحْمَنِ تَزَوَّجْتُ امْرَأَةً ‏.‏\hadithno{3493}\hadithtrans{This hadith has been narrated on the authority of Humaid with the same chain of transmitters except (with this minor alteration of words) that 'Abd al-Rahman said:" I married a woman}}
\hadithdefcmd{muslim}{3494}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ قُدَامَةَ، قَالاَ أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ صُهَيْبٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ قَالَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ رَآنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَعَلَىَّ بَشَاشَةُ الْعُرْسِ فَقُلْتُ تَزَوَّجْتُ امْرَأَةً مِنَ الأَنْصَارِ ‏.‏ فَقَالَ ‏ "‏ كَمْ أَصْدَقْتَهَا ‏"‏ ‏.‏ فَقُلْتُ نَوَاةً ‏.‏ وَفِي حَدِيثِ إِسْحَاقَ مِنْ ذَهَبٍ ‏.‏\hadithno{3494}\hadithtrans{Abd al-Rahman b. 'Auf (Allah be pleased with him) reported that Allah's Messenger (ﷺ) saw the signs of the happiness of wedding in me, and I said:I have married a woman of the Ansar. He said: How much Mahr have you paid? I said: For a date-stone weight of gold. And in the hadith transmitted by Ishaq (it is): (nawat weight) of gold}}
\hadithdefcmd{muslim}{3495}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي حَمْزَةَ، - قَالَ شُعْبَةُ وَاسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ أَبِي عَبْدِ اللَّهِ - عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ عَبْدَ الرَّحْمَنِ، تَزَوَّجَ امْرَأَةً عَلَى وَزْنِ نَوَاةٍ مِنْ ذَهَبٍ ‏.‏\hadithno{3495}\hadithtrans{Anas b. Malik reported that 'Abd al-Rahman married a woman for a datestone weight of gold}}
\hadithdefcmd{muslim}{3496}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا وَهْبٌ، أَخْبَرَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ فَقَالَ رَجُلٌ مِنْ وَلَدِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ مِنْ ذَهَبٍ ‏\hadithno{3496}\hadithtrans{Shu'ba has narrattd this hadith with the same chain of transmitters except for (this alteration) that he said that a person from among the sons of 'Abd al Rahman said:" from gold}}
\hadithdefcmd{muslim}{3497}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غَزَا خَيْبَرَ قَالَ فَصَلَّيْنَا عِنْدَهَا صَلاَةَ الْغَدَاةِ بِغَلَسٍ فَرَكِبَ نَبِيُّ اللَّهِ صلى الله عليه وسلم وَرَكِبَ أَبُو طَلْحَةَ وَأَنَا رَدِيفُ أَبِي طَلْحَةَ فَأَجْرَى نَبِيُّ اللَّهِ صلى الله عليه وسلم فِي زُقَاقِ خَيْبَرَ وَإِنَّ رُكْبَتِي لَتَمَسُّ فَخِذَ نَبِيِّ اللَّهِ صلى الله عليه وسلم وَانْحَسَرَ الإِزَارُ عَنْ فَخِذِ نَبِيِّ اللَّهِ صلى الله عليه وسلم فَإِنِّي لأَرَى بَيَاضَ فَخِذِ نَبِيِّ اللَّهِ صلى الله عليه وسلم فَلَمَّا دَخَلَ الْقَرْيَةَ قَالَ ‏"‏ اللَّهُ أَكْبَرُ خَرِبَتْ خَيْبَرُ إِنَّا إِذَا نَزَلْنَا بِسَاحَةِ قَوْمٍ فَسَاءَ صَبَاحُ الْمُنْذَرِينَ ‏"‏ ‏.‏ قَالَهَا ثَلاَثَ مَرَّاتٍ قَالَ وَقَدْ خَرَجَ الْقَوْمُ إِلَى أَعْمَالِهِمْ فَقَالُوا مُحَمَّدٌ وَاللَّهِ ‏.‏ قَالَ عَبْدُ الْعَزِيزِ وَقَالَ بَعْضُ أَصْحَابِنَا مُحَمَّدٌ وَالْخَمِيسُ ‏.‏ قَالَ وَأَصَبْنَاهَا عَنْوَةً وَجُمِعَ السَّبْىُ فَجَاءَهُ دِحْيَةُ فَقَالَ يَا رَسُولَ اللَّهِ أَعْطِنِي جَارِيَةً مِنَ السَّبْىِ ‏.‏ فَقَالَ ‏"‏ اذْهَبْ فَخُذْ جَارِيَةً ‏"‏ ‏.‏ فَأَخَذَ صَفِيَّةَ بِنْتَ حُيَىٍّ فَجَاءَ رَجُلٌ إِلَى نَبِيِّ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا نَبِيَّ اللَّهِ أَعْطَيْتَ دِحْيَةَ صَفِيَّةَ بِنْتَ حُيَىٍّ سَيِّدِ قُرَيْظَةَ وَالنَّضِيرِ مَا تَصْلُحُ إِلاَّ لَكَ ‏.‏ قَالَ ‏"‏ ادْعُوهُ بِهَا ‏"‏ ‏.‏ قَالَ فَجَاءَ بِهَا فَلَمَّا نَظَرَ إِلَيْهَا النَّبِيُّ صلى الله عليه وسلم قَالَ ‏"‏ خُذْ جَارِيَةً مِنَ السَّبْىِ غَيْرَهَا ‏"‏ ‏.‏ قَالَ وَأَعْتَقَهَا وَتَزَوَّجَهَا ‏.‏ فَقَالَ لَهُ ثَابِتٌ يَا أَبَا حَمْزَةَ مَا أَصْدَقَهَا قَالَ نَفْسَهَا أَعْتَقَهَا وَتَزَوَّجَهَا حَتَّى إِذَا كَانَ بِالطَّرِيقِ جَهَّزَتْهَا لَهُ أُمُّ سُلَيْمٍ فَأَهْدَتْهَا لَهُ مِنَ اللَّيْلِ فَأَصْبَحَ النَّبِيُّ صلى الله عليه وسلم عَرُوسًا فَقَالَ ‏"‏ مَنْ كَانَ عِنْدَهُ شَىْءٌ فَلْيَجِئْ بِهِ ‏"‏ قَالَ وَبَسَطَ نِطَعًا قَالَ فَجَعَلَ الرَّجُلُ يَجِيءُ بِالأَقِطِ وَجَعَلَ الرَّجُلُ يَجِيءُ بِالتَّمْرِ وَجَعَلَ الرَّجُلُ يَجِيءُ بِالسَّمْنِ فَحَاسُوا حَيْسًا ‏.‏ فَكَانَتْ وَلِيمَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3497}\hadithtrans{Anas (Allah be pleased with him) reported that Allah's Messenger (ﷺ) set out on an expedition to Khaibar and we observed our morning prayer in early hours of the dawn. The Messenger of Allah (ﷺ) then mounted and so did Abu Talha ride, and I was seating myself behind Abu Talha. Allah's Apostle (ﷺ) moved in the narrow street of Khaibar (and we rode so close to each other in the street) that my knee touched the leg of Allah's Apostle (ﷺ). (A part of the) lower garment of Allah's Apostle (ﷺ) slipped from his leg and I could see the whiteness of the leg of Allah's Apostle (ﷺ). As he entered the habitation he called:Allahu Akbar (Allah is the Greatest). Khaibar is ruined. And when we get down in the valley of a people evil is the morning of the warned ones. He repeated it thrice. In the meanwhile the people went out for their work, and said: By Allah, Muhammad (has come). Abd al-'Aziz or some of our companions said: Muhammad and the army (have come). He said: We took it (the territory of Khaibar) by force, and there were gathered the prisoners of war. There came Dihya and he said: Messenger of Allah, bestow upon me a girl from among the prisoners. He said: Go and get any girl. He made a choice for Safiyya daughter of Huyayy (b. Akhtab). There came a person to Allah's Apostle (ﷺ) and said: Apostle of Allah, you have bestowed Safiyya bint Huyayy, the chief of Quraiza and al-Nadir, upon Dihya and she is worthy of you only. He said: Call him along with her. So he came along with her. When Allah's Apostle (ﷺ) saw her he said: Take any other woman from among the prisoners. He (the narrator) said: He (the Holy Prophet) then granted her emancipation and married her. Thabit said to him: Abu Hamza, how much dower did he (the Holy Prophet) give to her? He said: He granted her freedom and then married her. On the way Umm Sulaim embellished her and then sent her to him (the Holy Prophet) at night. Allah's Apostle (ﷺ) appeared as a bridegroom in the morning. He (the Holy Prophet) said: He who has anything (to eat) should bring that. Then the cloth was spread. A person came with cheese, another came with dates, and still another came with refined butter, and they prepared hais and that was the wedding feast of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{3498}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ ثَابِتٍ، وَعَبْدِ، الْعَزِيزِ بْنِ صُهَيْبٍ عَنْ أَنَسٍ، ح وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ ثَابِتٍ، وَشُعَيْبِ، بْنِ حَبْحَابٍ عَنْ أَنَسٍ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، وَعَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْغُبَرِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي عُثْمَانَ، عَنْ أَنَسٍ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ شُعَيْبِ بْنِ الْحَبْحَابِ، عَنْ أَنَسٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، وَعُمَرُ بْنُ سَعْدٍ، وَعَبْدُ الرَّزَّاقِ، جَمِيعًا عَنْ سُفْيَانَ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنْ شُعَيْبِ بْنِ الْحَبْحَابِ، عَنْ أَنَسٍ، كُلُّهُمْ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ أَعْتَقَ صَفِيَّةَ وَجَعَلَ عِتْقَهَا صَدَاقَهَا ‏.‏ وَفِي حَدِيثِ مُعَاذٍ عَنْ أَبِيهِ تَزَوَّجَ صَفِيَّةَ وَأَصْدَقَهَا عِتْقَهَا\hadithno{3498}\hadithtrans{This hadith has been narrated through another chain of transmitters on the authority of Anas that Allah's Apostle (ﷺ) emancipated Safiyya, and her emancipation was treated as her wedding gift, and in the hadith transmitted by Mu'adh on the authority of his father (the words are):" He (the Holy Prophet) married Safiyya and bestowed her emancipation as her wedding gift}}
\hadithdefcmd{muslim}{3500}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، قَالَ كُنْتُ رِدْفَ أَبِي طَلْحَةَ يَوْمَ خَيْبَرَ وَقَدَمِي تَمَسُّ قَدَمَ رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ - فَأَتَيْنَاهُمْ حِينَ بَزَغَتِ الشَّمْسُ وَقَدْ أَخْرَجُوا مَوَاشِيَهُمَ وَخَرَجُوا بِفُئُوسِهِمْ وَمَكَاتِلِهِمْ وَمُرُورِهِمْ فَقَالُوا مُحَمَّدٌ وَالْخَمِيسُ - قَالَ - وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَرِبَتْ خَيْبَرُ إِنَّا إِذَا نَزَلْنَا بِسَاحَةِ قَوْمٍ فَسَاءَ صَبَاحُ الْمُنْذَرِينَ ‏"‏ ‏.‏ قَالَ وَهَزَمَهُمُ اللَّهُ عَزَّ وَجَلَّ وَوَقَعَتْ فِي سَهْمِ دَحْيَةَ جَارِيَةٌ جَمِيلَةٌ فَاشْتَرَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَبْعَةِ أَرْؤُسٍ ثُمَّ دَفَعَهَا إِلَى أُمِّ سُلَيْمٍ تُصَنِّعُهَا لَهُ وَتُهَيِّئُهَا - قَالَ وَأَحْسِبُهُ قَالَ - وَتَعْتَدُّ فِي بَيْتِهَا وَهِيَ صَفِيَّةُ بِنْتُ حُيَىٍّ - قَالَ - وَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَلِيمَتَهَا التَّمْرَ وَالأَقِطَ وَالسَّمْنَ فُحِصَتِ الأَرْضُ أَفَاحِيصَ وَجِيءَ بِالأَنْطَاعِ فَوُضِعَتْ فِيهَا وَجِيءَ بِالأَقِطِ وَالسَّمْنِ فَشَبِعَ النَّاسُ - قَالَ - وَقَالَ النَّاسُ لاَ نَدْرِي أَتَزَوَّجَهَا أَمِ اتَّخَذَهَا أُمَّ وَلَدٍ ‏.‏ قَالُوا إِنْ حَجَبَهَا فَهْىَ امْرَأَتُهُ وَإِنْ لَمْ يَحْجُبْهَا فَهْىَ أُمُّ وَلَدٍ فَلَمَّا أَرَادَ أَنْ يَرْكَبَ حَجَبَهَا فَقَعَدَتْ عَلَى عَجُزِ الْبَعِيرِ فَعَرَفُوا أَنَّهُ قَدْ تَزَوَّجَهَا ‏.‏ فَلَمَّا دَنَوْا مِنَ الْمَدِينَةِ دَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَدَفَعْنَا - قَالَ - فَعَثَرَتِ النَّاقَةُ الْعَضْبَاءُ وَنَدَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَدَرَتْ فَقَامَ فَسَتَرَهَا وَقَدْ أَشْرَفَتِ النِّسَاءُ فَقُلْنَ أَبْعَدَ اللَّهُ الْيَهُودِيَّةَ ‏.‏ قَالَ قُلْتُ يَا أَبَا حَمْزَةَ أَوَقَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ إِي وَاللَّهِ لَقَدْ وَقَعَ ‏\hadithno{3500}\hadithtrans{Anas (Allah be pleased with him) reported:I was sitting behind Abu Talha on the Day of Khaibar and my feet touched the foot of Allah's Messenger (ﷺ), and we came (to the people of Khaibar) when the sun had risen and they had driven out their cattle, and had themselves come out with their axes, large baskets and hatchets, and they said: (Here come) Muhammad and the army. Allah's Messenger (ﷺ) said: Khaibar is ruined. Verily when we get down in the valley of a people, evil is the morning of the warned ones (al-Qur'an, xxxvii. 177). Allah, the Majestic and the Glorious, defeated them (the inhabitants of Khaibar), and there fell to the lot of Dihya a beautiful girl, and Allah's Messenger (ﷺ) got her in exchange of seven heads, and then entrusted her to Umm Sulaim so that she might embellish her and prepare her (for marriage) with him. He (the narrator) said: He had been under the impression that he had said that so that she might spend her period of 'Iddah in her (Umm Sulaim's) house. (The woman) was Safiyya daughter of Huyayy. Allah's Messenger (ﷺ) arranged the wedding feast consisting of dates, cheese, and refined butter, and pits were dug and tiers were set in them dining cloths, and there was brought cheese and refined butter, and these were placed there. And the people ate to their fill, and they said: We do not know whether he (the Holy Prophet) had married her (as a free woman), or as a slave woman. They said: If he (the Holy Prophet) would make her wear the veil, then she would be a (free married) woman, and if he would not make her wear the veil, then she should be a slave woman. When he intended to ride, he made her wear the veil and she sat on the hind part of the camel; so they came to know that he had married her. As they approached Medina, Allah's Messenger (ﷺ) drove (his ride) quickly and so we did. 'Adba' (the name of Allah's Apostle's camel) stumbled and Allah's Messenger (ﷺ) fell down and she (Radrat Safiyya: also fell down. He (the Holy Prophet) stood up and covered her. Women looked towards her and said: May Allah keep away the Jewess! He (the narrator) said: I said: Aba Hamza, did Allah's Messenger (ﷺ) really fall down? He said: Yes, by Allah, he in fact fell down}}
\hadithdefcmd{muslim}{3501}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا سُلَيْمَانُ، عَنْ ثَابِثٍ، عَنْ أَنَسٍ، ح وَحَدَّثَنِي بِهِ عَبْدُ اللَّهِ بْنُ هَاشِمِ بْنِ حَيَّانَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا بَهْزٌ، حَدَّثَنَا سُلَيْمَانُ، بْنُ الْمُغِيرَةِ عَنْ ثَابِتٍ، حَدَّثَنَا أَنَسٌ، قَالَ صَارَتْ صَفِيَّةُ لِدَحْيَةَ فِي مَقْسَمِهِ وَجَعَلُوا يَمْدَحُونَهَا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ - وَيَقُولُونَ مَا رَأَيْنَا فِي السَّبْىِ مِثْلَهَا - قَالَ - فَبَعَثَ إِلَى دِحْيَةَ فَأَعْطَاهُ بِهَا مَا أَرَادَ ثُمَّ دَفَعَهَا إِلَى أُمِّي فَقَالَ ‏"‏ أَصْلِحِيهَا ‏"‏ ‏.‏ قَالَ ثُمَّ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ خَيْبَرَ حَتَّى إِذَا جَعَلَهَا فِي ظَهْرِهِ نَزَلَ ثُمَّ ضَرَبَ عَلَيْهَا الْقُبَّةَ فَلَمَّا أَصْبَحَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ كَانَ عِنْدَهُ فَضْلُ زَادٍ فَلْيَأْتِنَا بِهِ ‏"‏ ‏.‏ قَالَ فَجَعَلَ الرَّجُلُ يَجِيءُ بِفَضْلِ التَّمْرِ وَفَضْلِ السَّوِيقِ حَتَّى جَعَلُوا مِنْ ذَلِكَ سَوَادًا حَيْسًا فَجَعَلُوا يَأْكُلُونَ مِنْ ذَلِكَ الْحَيْسِ وَيَشْرَبُونَ مِنْ حِيَاضٍ إِلَى جَنْبِهِمْ مِنْ مَاءِ السَّمَاءِ - قَالَ - فَقَالَ أَنَسٌ فَكَانَتْ تِلْكَ وَلِيمَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَيْهَا - قَالَ - فَانْطَلَقْنَا حَتَّى إِذَا رَأَيْنَا جُدُرَ الْمَدِينَةِ هَشِشْنَا إِلَيْهَا فَرَفَعْنَا مَطِيَّنَا وَرَفَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَطِيَّتَهُ - قَالَ - وَصَفِيَّةُ خَلْفَهُ قَدْ أَرْدَفَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم - قَالَ - فَعَثَرَتْ مَطِيَّةُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَصُرِعَ وَصُرِعَتْ قَالَ فَلَيْسَ أَحَدٌ مِنَ النَّاسِ يَنْظُرُ إِلَيْهِ وَلاَ إِلَيْهَا حَتَّى قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَتَرَهَا - قَالَ - فَأَتَيْنَاهُ فَقَالَ ‏"‏ لَمْ نُضَرَّ ‏"‏ ‏.‏ قَالَ فَدَخَلْنَا الْمَدِينَةَ فَخَرَجَ جَوَارِي نِسَائِهِ يَتَرَاءَيْنَهَا وَيَشْمَتْنَ بِصَرْعَتِهَا ‏.‏\hadithno{3501}\hadithtrans{Anas, (Allah be pleased with him) reported:Safiyya (Allah be pleased with her) fell to the lot of Dihya in the spoils of war, and they praised her in the presence of Allah's Messenger (ﷺ) and said: We have not seen the like of her among the captives of war. He sent (a messenger) to Dihya and he gave him whatever he demanded. He then sent her to my mother and asked her to embellish her. Allah's Messenger (ﷺ) then got out of Khaibar until when he was on the other side of it, he halted, and a tent was pitched for him. When it was morning Allah's Messenger (ﷺ) said: He who has surplus of provision with him should bring that to us. Some persons would bring the surplus of dates, and the other surplus of mush of barley until there became a heap of bals. They began to eat the hais and began to drink out of the pond which had the water of rainfall in it and which was situated by their side. Anas said that that constituted the wedding feast of Allah's Messenger (ﷺ). He (further) said: We proceeded until we saw the walls of Medina, and we were delighted. We made our mounts run quickly and Allah's Messenger (ﷺ) also made his mount run quickly. And Safiyya (Allah be pleased with her) was at his back, and Allah's Messenger (ﷺ) had seated her behind him. The camel of Allah's Messenger (ﷺ) stumbled and he (the Holy Prophet) fell down and she also fell down. And none among the people was seeing him and her, until Allah's Messeuger (ﷺ) stood up and he covered her, and we came to him and he said: We have received no injury. We entered Medina and there came out the young ladies of the household. They saw her (hadrat Safiyya) and blamed her for falling down}}
\hadithdefcmd{muslim}{3502}{قَالَ أَنَسٌ وَشَهِدْتُ وَلِيمَةَ زَيْنَبَ فَأَشْبَعَ النَّاسَ خُبْزًا وَلَحْمًا وَكَانَ يَبْعَثُنِي فَأَدْعُو النَّاسَ فَلَمَّا فَرَغَ قَامَ وَتَبِعْتُهُ فَتَخَلَّفَ رَجُلاَنِ اسْتَأْنَسَ بِهِمَا الْحَدِيثُ لَمْ يَخْرُجَا فَجَعَلَ يَمُرُّ عَلَى نِسَائِهِ فَيُسَلِّمُ عَلَى كُلِّ وَاحِدَةٍ مِنْهُنَّ ‏"‏ سَلاَمٌ عَلَيْكُمْ كَيْفَ أَنْتُمْ يَا أَهْلَ الْبَيْتِ ‏"‏ ‏.‏ فَيَقُولُونَ بِخَيْرٍ يَا رَسُولَ اللَّهِ كَيْفَ وَجَدْتَ أَهْلَكَ فَيَقُولُ ‏"‏ بِخَيْرٍ ‏"‏ ‏.‏ فَلَمَّا فَرَغَ رَجَعَ وَرَجَعْتُ مَعَهُ فَلَمَّا بَلَغَ الْبَابَ إِذَا هُوَ بِالرَّجُلَيْنِ قَدِ اسْتَأْنَسَ بِهِمَا الْحَدِيثُ فَلَمَّا رَأَيَاهُ قَدْ رَجَعَ قَامَا فَخَرَجَا فَوَاللَّهِ مَا أَدْرِي أَنَا أَخْبَرْتُهُ أَمْ أُنْزِلَ عَلَيْهِ الْوَحْىُ بِأَنَّهُمَا قَدْ خَرَجَا فَرَجَعَ وَرَجَعْتُ مَعَهُ فَلَمَّا وَضَعَ رِجْلَهُ فِي أُسْكُفَّةِ الْبَابِ أَرْخَى الْحِجَابَ بَيْنِي وَبَيْنَهُ وَأَنْزَلَ اللَّهُ تَعَالَى هَذِهِ الآيَةَ ‏\{‏ لاَ تَدْخُلُوا بُيُوتَ النَّبِيِّ إِلاَّ أَنْ يُؤْذَنَ لَكُمْ‏\}‏ الآيَةَ ‏.‏\hadithno{3502}\hadithtrans{Anas said:I also saw the wedding feast of Zainab, and he (the Holy Prophet) served bread and meat to the people, and made them eat to their heart's content, and he (the Holy Prophet) sent me to call people, and as he was free (from the ceremony) he stood up and I followed him. Two persons were left and they were busy in talking and did not get out (of the apartment). He (the Holy Prophet) then proceeded towards (the apartments of) his wives. He greeted with as-Salamu 'alaikum to every one of them and said: Members of the household, how are you? They said: Messenger of Allah, we are in good state 'How do you find your family? He would say: In good state. When he was free from (this work of exchanging greetings) he came back, and I also came back along with him. And as he reached the door, (he found) that the two men were still busy in talking. And when they saw him having returned, they stood up and went out; and by Allah! I do not know whether I had informed him, or there was a revelation to him (to the affect) that they had gone. He (the Holy Prophet) then came back and I also returned along with him, and as he put his step on the threshold of his door he hung a curtain between me and him, and (it was on this occasion) that Allah revealed this verse: (" O you who believe), do not enter the houses of the Prophet unless permission is given to 'you" (xxxiii)}}
\hadithdefcmd{muslim}{3503}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، حَدَّثَنَا بَهْزٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو النَّضْرِ، هَاشِمُ بْنُ الْقَاسِمِ قَالاَ جَمِيعًا حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، وَهَذَا حَدِيثُ بَهْزٍ قَالَ لَمَّا انْقَضَتْ عِدَّةُ زَيْنَبَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِزَيْدٍ ‏"‏ فَاذْكُرْهَا عَلَىَّ ‏"‏ ‏.‏ قَالَ فَانْطَلَقَ زَيْدٌ حَتَّى أَتَاهَا وَهْىَ تُخَمِّرُ عَجِينَهَا قَالَ فَلَمَّا رَأَيْتُهَا عَظُمَتْ فِي صَدْرِي حَتَّى مَا أَسْتَطِيعُ أَنْ أَنْظُرَ إِلَيْهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَهَا فَوَلَّيْتُهَا ظَهْرِي وَنَكَصْتُ عَلَى عَقِبِي فَقُلْتُ يَا زَيْنَبُ أَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَذْكُرُكِ ‏.‏ قَالَتْ مَا أَنَا بِصَانِعَةٍ شَيْئًا حَتَّى أُوَامِرَ رَبِّي ‏.‏ فَقَامَتْ إِلَى مَسْجِدِهَا وَنَزَلَ الْقُرْآنُ وَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَدَخَلَ عَلَيْهَا بِغَيْرِ إِذْنٍ قَالَ فَقَالَ وَلَقَدْ رَأَيْتُنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَطْعَمَنَا الْخُبْزَ وَاللَّحْمَ حِينَ امْتَدَّ النَّهَارُ فَخَرَجَ النَّاسُ وَبَقِيَ رِجَالٌ يَتَحَدَّثُونَ فِي الْبَيْتِ بَعْدَ الطَّعَامِ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَاتَّبَعْتُهُ فَجَعَلَ يَتَتَبَّعُ حُجَرَ نِسَائِهِ يُسَلِّمُ عَلَيْهِنَّ وَيَقُلْنَ يَا رَسُولَ اللَّهِ كَيْفَ وَجَدْتَ أَهْلَكَ قَالَ فَمَا أَدْرِي أَنَا أَخْبَرْتُهُ أَنَّ الْقَوْمَ خَرَجُوا أَوْ أَخْبَرَنِي - قَالَ - فَانْطَلَقَ حَتَّى دَخَلَ الْبَيْتَ فَذَهَبْتُ أَدْخُلُ مَعَهُ فَأَلْقَى السِّتْرَ بَيْنِي وَبَيْنَهُ وَنَزَلَ الْحِجَابُ قَالَ وَوُعِظَ الْقَوْمُ بِمَا وُعِظُوا بِهِ ‏.‏ زَادَ ابْنُ رَافِعٍ فِي حَدِيثِهِ ‏\{‏ لاَ تَدْخُلُوا بُيُوتَ النَّبِيِّ إِلاَّ أَنْ يُؤْذَنَ لَكُمْ إِلَى طَعَامٍ غَيْرَ نَاظِرِينَ إِنَاهُ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ وَاللَّهُ لاَ يَسْتَحْيِي مِنَ الْحَقِّ‏\}‏\hadithno{3503}\hadithtrans{Anas (Allah be pleased with him) reported:When the 'Iddah of Zainab was over, Allah's Messenger (ﷺ) said to Zaid to make a mention to her about him. Zaid went on until he came to her and she was fermenting her flour. He (Zaid) said: As I saw her I felt in my heart an idea of her greatness so much so that I could not see towards her (simply for the fact) that Allah's Messenger (ﷺ) had made a mention of her. So I turned my back towards her. and I turned upon my heels, and said: Zainab, Allah's Messenger (ﷺ) has sent (me) with a message to you. She said: I do not do anything until I solicit the will of my Lord. So she stood at her place of worship and the (verse of) the Qur'an (pertaining to her marriage) were revealed, and Allah's Messenger (ﷺ) came to her without permission. He (the narrator) said: I saw that Allah's Messenger (ﷺ) served us bread and meat until it was broad day light and the people went away, but some persons who were busy in con- versation stayed on in the house after the meal. Allah's Messenger (ﷺ) also went out and I also followed him, and he began to visit the apartments of his wives greeting them (with the words): As-Salamu 'alaikum, and they would say: Allah's Messenger, how did you find your family (hadrat Zainab)? He (the narrator) stated: I do not know whether I had informed him that the people had gone out or he (the Holy Prophet) informed me (about that). He moved on until he entered the apartment, and I also went and wanted to enter (the apartment) along with him, but he threw a curtain between me and him, as (the verfes pertaining to seclusion) had been revealed, and people were instructed in what they had been instructed. Ibn Rafii had made this addition in his narration:" O you who believe, enter not the houses of the Prophet unless permission is given to you for a meal, not waiting for its cooking being finished..." to the words"... Allah forbears not from the truth}}
\hadithdefcmd{muslim}{3504}{حَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَأَبُو كَامِلٍ فُضَيْلُ بْنُ حُسَيْنٍ وَقُتَيْبَةُ بْنُ سَعِيدٍ قَالُوا حَدَّثَنَا حَمَّادٌ، - وَهُوَ ابْنُ زَيْدٍ - عَنْ ثَابِتٍ، عَنْ أَنَسٍ، - وَفِي رِوَايَةِ أَبِي كَامِلٍ سَمِعْتُ أَنَسًا، - قَالَ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَوْلَمَ عَلَى امْرَأَةٍ - وَقَالَ أَبُو كَامِلٍ عَلَى شَىْءٍ - مِنْ نِسَائِهِ مَا أَوْلَمَ عَلَى زَيْنَبَ فَإِنَّهُ ذَبَحَ شَاةً ‏.‏\hadithno{3504}\hadithtrans{Anas (Allah be pleased with him) reported:I did not see Allah's Messenger (ﷺ) giving a wedding feast (on the marriage) of any one (of his wives) as he did in the case of (his marriage with) Zainab, for then he sacrificed a goat (on this occasion)}}
\hadithdefcmd{muslim}{3505}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ عَبَّادِ بْنِ جَبَلَةَ بْنِ أَبِي رَوَّادٍ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ جَعْفَرٍ - حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ مَا أَوْلَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى امْرَأَةٍ مِنْ نِسَائِهِ أَكْثَرَ أَوْ أَفْضَلَ مِمَّا أَوْلَمَ عَلَى زَيْنَبَ ‏.‏ فَقَالَ ثَابِتٌ الْبُنَانِيُّ بِمَا أَوْلَمَ قَالَ أَطْعَمَهُمْ خُبْزًا وَلَحْمًا حَتَّى تَرَكُوهُ ‏.‏\hadithno{3505}\hadithtrans{Anas b. Malik (Allah be pleased with him) reported:Allah's Messenger (ﷺ) gave no better wedding feast than the one he did (on the occasion of his marriage with) Zainab. Thabit al-Bunani (one of the narrators) said: What did he serve in the wedding feast? He (Anas) said: He fed them bread and meat (so lavishly) that they (the guests) abandoned it (of their own accord after having taken them to their hearts' content)}}
\hadithdefcmd{muslim}{3506}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، وَعَاصِمُ بْنُ النَّضْرِ التَّيْمِيُّ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، كُلُّهُمْ عَنْ مُعْتَمِرٍ، - وَاللَّفْظُ لاِبْنِ حَبِيبٍ - حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ أَبِي، حَدَّثَنَا أَبُو مِجْلَزٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا تَزَوَّجَ النَّبِيُّ صلى الله عليه وسلم زَيْنَبَ بِنْتَ جَحْشٍ دَعَا الْقَوْمَ فَطَعِمُوا ثُمَّ جَلَسُوا يَتَحَدَّثُونَ - قَالَ - فَأَخَذَ كَأَنَّهُ يَتَهَيَّأُ لِلْقِيَامِ فَلَمْ يَقُومُوا فَلَمَّا رَأَى ذَلِكَ قَامَ فَلَمَّا قَامَ قَامَ مَنْ قَامَ مِنَ الْقَوْمِ ‏.‏ زَادَ عَاصِمٌ وَابْنُ عَبْدِ الأَعْلَى فِي حَدِيثِهِمَا قَالَ فَقَعَدَ ثَلاَثَةٌ وَإِنَّ النَّبِيَّ صلى الله عليه وسلم جَاءَ لِيَدْخُلَ فَإِذَا الْقَوْمُ جُلُوسٌ ثُمَّ إِنَّهُمْ قَامُوا فَانْطَلَقُوا - قَالَ - فَجِئْتُ فَأَخْبَرْتُ النَّبِيَّ صلى الله عليه وسلم أَنَّهُمْ قَدِ انْطَلَقُوا - قَالَ - فَجَاءَ حَتَّى دَخَلَ فَذَهَبْتُ أَدْخُلُ فَأَلْقَى الْحِجَابَ بَيْنِي وَبَيْنَهُ - قَالَ - وَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَدْخُلُوا بُيُوتَ النَّبِيِّ إِلاَّ أَنْ يُؤْذَنَ لَكُمْ إِلَى طَعَامٍ غَيْرَ نَاظِرِينَ إِنَاهُ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ إِنَّ ذَلِكُمْ كَانَ عِنْدَ اللَّهِ عَظِيمًا‏\}‏ ‏.‏\hadithno{3506}\hadithtrans{Anas b. Malik (Allah be pleased with him) reported:When Allah's Apostle (ﷺ) married Zainab bint jahsh, he invited people (to the wedding feast) and they ate food. They then sat there and entered into conversation. He (the Holy Prophet) made a stir as if he was preparing to stand up, but (the persons busy in talking) did not stand up. When he (the Holy Prophet) saw it, he stood up and when he did so, some other persons stood up. 'Asim and Abd al-A'la in their narrations made this addition: Three (persons) sat there, and Allah's Apostle (ﷺ) came there to enter (the apartment) but he found the people sitting there. Then they stood up and went away. He said: Then I came and informed Allah's Apostle (ﷺ) that they had gone away. He (the Holy Prophet) then came there until he entered (the apartment). I also went and was about to enter, when he hung a curtain between me and him (and it was on this occasion that) Allah, the Exalted and Majestic, revealed this verse:" O you who believe, enter not the houses of the Prophet unless permission is given to you for a meal, not waiting for its cooking being finished to the (words)" Surely this is serious in the sight of Allah" (xxxiii)}}
\hadithdefcmd{muslim}{3507}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، قَالَ ابْنُ شِهَابٍ إِنَّ أَنَسَ بْنَ مَالِكٍ قَالَ أَنَا أَعْلَمُ النَّاسِ، بِالْحِجَابِ لَقَدْ كَانَ أُبَىُّ بْنُ كَعْبٍ يَسْأَلُنِي عَنْهُ ‏.‏ قَالَ أَنَسٌ أَصْبَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَرُوسًا بِزَيْنَبَ بِنْتِ جَحْشٍ - قَالَ - وَكَانَ تَزَوَّجَهَا بِالْمَدِينَةِ فَدَعَا النَّاسَ لِلطَّعَامِ بَعْدَ ارْتِفَاعِ النَّهَارِ فَجَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَجَلَسَ مَعَهُ رِجَالٌ بَعْدَ مَا قَامَ الْقَوْمُ حَتَّى قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَمَشَى فَمَشَيْتُ مَعَهُ حَتَّى بَلَغَ بَابَ حُجْرَةِ عَائِشَةَ ثُمَّ ظَنَّ أَنَّهُمْ قَدْ خَرَجُوا فَرَجَعَ وَرَجَعْتُ مَعَهُ فَإِذَا هُمْ جُلُوسٌ مَكَانَهُمْ فَرَجَعَ فَرَجَعْتُ الثَّانِيَةَ حَتَّى بَلَغَ حُجْرَةَ عَائِشَةَ فَرَجَعَ فَرَجَعْتُ فَإِذَا هُمْ قَدْ قَامُوا فَضَرَبَ بَيْنِي وَبَيْنَهُ بِالسِّتْرِ وَأَنْزَلَ اللَّهُ آيَةَ الْحِجَابِ.‏\hadithno{3507}\hadithtrans{Anas b. Malik (Allah be pleased with him) reported:I was the best informed among the people pertaining to Hijab (veil and seclusion). Ubayy b. Ka'b used to ask me about it. Anas (Allah be pleased with him) thus narrated: The Messenger of Allah (ﷺ) got up in the morning as a bridegroom of Zainab bint jahsh (Allah be pleased witt her) as he had married her at Medina. He invited people to the wedding feast after the day had well risen. There sat Allah's Messenger (ﷺ) and there kept sitting along with him some persons after the people had stood up (for departure) ; then Allah's Messenger (ﷺ) stood up and walked on and I also walked along with him until he reached the door of the apartment of 'A'isha (Allah be pleased with her). He then thought that they (those who had been sitting there after meal) had gone away. So he returned and I also returned with him, but they were still sitting at their places. So he returned for the second time and I also returned until he reached the apartment of 'A'isha. He again returned and I also returned and they had (by that time) stood up, and he hung a curtain between me and him (at the door of the apartment of Hadrat Zainab, where he had to stay), and Allah revealed the verse pertaining to veil}}
\hadithdefcmd{muslim}{3508}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَعْفَرٌ، - يَعْنِي ابْنَ سُلَيْمَانَ - عَنِ الْجَعْدِ أَبِي عُثْمَانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ تَزَوَّجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَدَخَلَ بِأَهْلِهِ - قَالَ - فَصَنَعَتْ أُمِّي أُمُّ سُلَيْمٍ حَيْسًا فَجَعَلَتْهُ فِي تَوْرٍ فَقَالَتْ يَا أَنَسُ اذْهَبْ بِهَذَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْ بَعَثَتْ بِهَذَا إِلَيْكَ أُمِّي وَهْىَ تُقْرِئُكَ السَّلاَمَ وَتَقُولُ إِنَّ هَذَا لَكَ مِنَّا قَلِيلٌ يَا رَسُولَ اللَّهِ - قَالَ - فَذَهَبْتُ بِهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ إِنَّ أُمِّي تُقْرِئُكَ السَّلاَمَ وَتَقُولُ إِنَّ هَذَا لَكَ مِنَّا قَلِيلٌ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ ضَعْهُ - ثُمَّ قَالَ - اذْهَبْ فَادْعُ لِي فُلاَنًا وَفُلاَنًا وَفُلاَنًا وَمَنْ لَقِيتَ ‏"‏ ‏.‏ وَسَمَّى رِجَالاً - قَالَ - فَدَعَوْتُ مَنْ سَمَّى وَمَنْ لَقِيتُ ‏.‏ قَالَ قُلْتُ لأَنَسٍ عَدَدَ كَمْ كَانُوا قَالَ زُهَاءَ ثَلاَثِمِائَةٍ ‏.‏ وَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَنَسُ هَاتِ التَّوْرَ ‏"‏ ‏.‏ قَالَ فَدَخَلُوا حَتَّى امْتَلأَتِ الصُّفَّةُ وَالْحُجْرَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لِيَتَحَلَّقْ عَشَرَةٌ عَشَرَةٌ وَلْيَأْكُلْ كُلُّ إِنْسَانٍ مِمَّا يَلِيهِ ‏"‏ ‏.‏ قَالَ فَأَكَلُوا حَتَّى شَبِعُوا - قَالَ - فَخَرَجَتْ طَائِفَةٌ وَدَخَلَتْ طَائِفَةٌ حَتَّى أَكَلُوا كُلُّهُمْ ‏.‏ فَقَالَ لِي ‏"‏ يَا أَنَسُ ارْفَعْ ‏"‏ ‏.‏ قَالَ فَرَفَعْتُ فَمَا أَدْرِي حِينَ وَضَعْتُ كَانَ أَكْثَرَ أَمْ حِينَ رَفَعْتُ - قَالَ - وَجَلَسَ طَوَائِفُ مِنْهُمْ يَتَحَدَّثُونَ فِي بَيْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَرَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ وَزَوْجَتُهُ مُوَلِّيَةٌ وَجْهَهَا إِلَى الْحَائِطِ فَثَقُلُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَلَّمَ عَلَى نِسَائِهِ ثُمَّ رَجَعَ فَلَمَّا رَأَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ رَجَعَ ظَنُّوا أَنَّهُمْ قَدْ ثَقُلُوا عَلَيْهِ - قَالَ - فَابْتَدَرُوا الْبَابَ فَخَرَجُوا كُلُّهُمْ وَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم َتَّى أَرْخَى السِّتْرَ وَدَخَلَ وَأَنَا جَالِسٌ فِي الْحُجْرَةِ فَلَمْ يَلْبَثْ إِلاَّ يَسِيرًا حَتَّى خَرَجَ عَلَىَّ ‏.‏ وَأُنْزِلَتْ هَذِهِ الآيَةُ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَرَأَهُنَّ عَلَى النَّاسِ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَدْخُلُوا بُيُوتَ النَّبِيِّ إِلاَّ أَنْ يُؤْذَنَ لَكُمْ إِلَى طَعَامٍ غَيْرَ نَاظِرِينَ إِنَاهُ وَلَكِنْ إِذَا دُعِيتُمْ فَادْخُلُوا فَإِذَا طَعِمْتُمْ فَانْتَشِرُوا وَلاَ مُسْتَأْنِسِينَ لِحَدِيثٍ إِنَّ ذَلِكُمْ كَانَ يُؤْذِي النَّبِيَّ‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏ قَالَ الْجَعْدُ قَالَ أَنَسُ بْنُ مَالِكٍ أَنَا أَحْدَثُ النَّاسِ عَهْدًا بِهَذِهِ الآيَاتِ وَحُجِبْنَ نِسَاءُ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3508}\hadithtrans{Anas b. Malik (Allah be pleased with him) reported:Allah's Messenger (ﷺ) contracted marriage and he went to his wife. My mother Umm Sulaim prepared hais and placed it in an earthen vessel and said: Anas, take it to Allah's Messenger (ﷺ) and say: My mother has sent that to you and she offers greetings to you, and says that it is a humble gift for you on our behalf, Messenger of Allah. So I went along with it to Allah's Messenger (ﷺ) and said: My mother offers you salutations, and says that it is a humble gift for you on our behalf. He said: Place it here, and then said: Go and invite on my behalf so and so and anyone whom you meet, and he even named some persons. He (Anas) said: I invited whom he had named and whom I met. I (one of the narrators) said: I said to Anas: How many (persons) were there? He (Anas) said: They were about three hundred persons. Then Allah's Messenger (ﷺ) (said to me): Anas, bring that earthen vessel. They (the guests) then began to enter until the courtyard and the apartment were fully packed. Allah's Messenger (ﷺ) said: Make a circle of ten (guests), and every person should eat from that nearest to him. They began to eat, until they ate to their fill. A group went out (after eating the food), and another group came in until all of them had eaten. He (the Holy Prophet) said to me: Anas, lift it (the earthen vessel), so I lifted it, but I could not assess whether it had more (food) when I placed it (before Allah's Messenger) or when I lifted it (after the people had been served out of it). A group among them (the guests) began to talk in the house of Allah's Messenger (ﷺ) and the Messenger of Allah (ﷺ) was sitting and his wife had been sitting with her face turned towards the wall. It was troublesome for Allah's Messenger (ﷺ), so Allah's Messenger (ﷺ) went out and greeted his wives. He then returned. When they (the guests) saw that Allah's Messenger (ﷺ) had returned they thought that it (their overstay) was something troublesome for him. He (the narrator) said: They hastened towards the door and all of them went out. And there came Allah's Messenger (ﷺ) and he hung a curtain and went in, and I was sitting in his apartment and he did not stay but for a short while. He then came to me and these verses were revealed. Allah's Messenger (ﷺ) came out and recited them to the people:" O you who believe, enter not the houses of the Prophet unless permission is given to you for a meal, not waiting for its cooking being finished-but when you are invited, enter, and when you have taken food, disperse not seeking to listen to talk. Surely this gives the Prophet trouble", to the end of verse (xxxiii. 53). (Al-Ja'd said that Anas [b. Malik] stated: I am the first amongst the people to hear these verses), and henceforth the wives of the Apostle (ﷺ) began to observe seclusion (al-hijab)}}
\hadithdefcmd{muslim}{3509}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دُعِيَ أَحَدُكُمْ إِلَى الْوَلِيمَةِ فَلْيَأْتِهَا ‏"‏ ‏.‏\hadithno{3509}\hadithtrans{Ibn Umar (Allah be pleased with him) reported that Allah's Messenger (ﷺ) said:When any one of you is invited to a feast, he should attend it}}
\hadithdefcmd{muslim}{3510}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دُعِيَ أَحَدُكُمْ إِلَى الْوَلِيمَةِ فَلْيُجِبْ ‏"‏ ‏.‏ قَالَ خَالِدٌ فَإِذَا عُبَيْدُ اللَّهِ يُنَزِّلُهُ عَلَى الْعُرْسِ ‏.‏\hadithno{3510}\hadithtrans{Ibn 'Umar (Allah be pleased with them) reported Allah's Apostle (ﷺ) as saying:When any one of you is invited to a feast, he should accept. 'Ubaidallah took this feast to be a wedding feast}}
\hadithdefcmd{muslim}{3511}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دُعِيَ أَحَدُكُمْ إِلَى وَلِيمَةِ عُرْسٍ فَلْيُجِبْ ‏"‏ ‏.‏\hadithno{3511}\hadithtrans{Ibn Umar (Allah be pleased withthem) reported Allah's Apostle (ﷺ) having said this:When any one of you is invited to a wedding feast, he should accept that}}
\hadithdefcmd{muslim}{3512}{حَدَّثَنِي أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ائْتُوا الدَّعْوَةَ إِذَا دُعِيتُمْ ‏"‏ ‏.‏\hadithno{3512}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Messenger (may be upon him) having said this:Accept the feast, when you are invited}}
\hadithdefcmd{muslim}{3513}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، كَانَ يَقُولُ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ إِذَا دَعَا أَحَدُكُمْ أَخَاهُ فَلْيُجِبْ عُرْسًا كَانَ أَوْ نَحْوَهُ ‏"‏ ‏.‏\hadithno{3513}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Apostle (ﷺ) as saying:When any one of you invites his brother, he (the latter) should accept his wedding feast, or any other like it}}
\hadithdefcmd{muslim}{3514}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنِي عِيسَى بْنُ الْمُنْذِرِ، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنَا الزُّبَيْدِيُّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ دُعِيَ إِلَى عُرْسٍ أَوْ نَحْوِهِ فَلْيُجِبْ ‏"‏ ‏.‏\hadithno{3514}\hadithtrans{Ibn 'Umar (Allah be pleated with them) reported Allah's Messenger (ﷺ) having said:He who is invited to a wedding feast or like it, he should accept it}}
\hadithdefcmd{muslim}{3515}{حَدَّثَنِي حُمَيْدُ بْنُ مَسْعَدَةَ الْبَاهِلِيُّ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ، أُمَيَّةَ عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ائْتُوا الدَّعْوَةَ إِذَا دُعِيتُمْ ‏"‏ ‏.‏\hadithno{3515}\hadithtrans{Abdullah b. Umar (Allah be pleased with them) reported Allah's Messen- ger (ﷺ) as saying:Come to the feast, when you are invited}}
\hadithdefcmd{muslim}{3516}{وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي مُوسَى بْنُ عُقْبَةَ، عَنْ نَافِعٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَجِيبُوا هَذِهِ الدَّعْوَةَ إِذَا دُعِيتُمْ لَهَا ‏"‏ ‏.‏ قَالَ وَكَانَ عَبْدُ اللَّهِ بْنُ عُمَرَ يَأْتِي الدَّعْوَةَ فِي الْعُرْسِ وَغَيْرِ الْعُرْسِ وَيَأْتِيهَا وَهُوَ صَائِمٌ ‏.‏\hadithno{3516}\hadithtrans{Nafil reported:I heard Abdullah b. Umar (Allah be pleased with them) narrating that Allah's Messenger (ﷺ) said: Accept the feast when you are invited to it. And Abdullah (b. Umar) used to come to the feast, whether it was a wedding feast or other than that, and he would come there even in the state of fasting}}
\hadithdefcmd{muslim}{3517}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي عُمَرُ بْنُ مُحَمَّدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دُعِيتُمْ إِلَى كُرَاعٍ فَأَجِيبُوا ‏"‏ ‏.‏\hadithno{3517}\hadithtrans{Ibn Umar (Allah be pleased with them) reported Allah's Apostle (ﷺ) having said:When you are invited to a feast (even though it is) the leg of the sheep, you should accept it}}
\hadithdefcmd{muslim}{3518}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ، اللَّهِ بْنِ نُمَيْرٍ حَدَّثَنَا أَبِي قَالاَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا دُعِيَ أَحَدُكُمْ إِلَى طَعَامٍ فَلْيُجِبْ فَإِنْ شَاءَ طَعِمَ وَإِنْ شَاءَ تَرَكَ ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ ابْنُ الْمُثَنَّى ‏"‏ إِلَى طَعَامٍ ‏"‏ ‏.‏\hadithno{3518}\hadithtrans{Jabir (Allah be pleased with him) reported that Allah's Messenger (may peace he upon him) said:When any one of you is invited to a feast, he should accept it. He may eat if he likes, or he may abandon (eating) if he likes. Ibn Mathanni did not make mention of the word" feast}}
\hadithdefcmd{muslim}{3519}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، بِهَذَا الإِسْنَادِ بِمِثْلِهِ\hadithno{3519}\hadithtrans{A hadith like this has been narrated on the authority of Abd Zubair with the same chain of transmitters}}
\hadithdefcmd{muslim}{3520}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دُعِيَ أَحَدُكُمْ فَلْيُجِبْ فَإِنْ كَانَ صَائِمًا فَلْيُصَلِّ وَإِنْ كَانَ مُفْطِرًا فَلْيَطْعَمْ ‏\hadithno{3520}\hadithtrans{Abu Haraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:If any one of you is invited, he should accept (the invitation). In case he is fasting, he should pray (in order to bless the inmates of the house), and if he is not fasting he should eat}}
\hadithdefcmd{muslim}{3521}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ كَانَ يَقُولُ بِئْسَ الطَّعَامُ طَعَامُ الْوَلِيمَةِ يُدْعَى إِلَيْهِ الأَغْنِيَاءُ وَيُتْرَكُ الْمَسَاكِينُ فَمَنْ لَمْ يَأْتِ الدَّعْوَةَ فَقَدْ عَصَى اللَّهَ وَرَسُولَهُ ‏.‏\hadithno{3521}\hadithtrans{Abu Huraira (Allah be pleased with him) used to say:The worst kind of food is the wedding feast to which the rich are invited and the poor are ignored. He who does not come to the feast, he in fact disobeys Allah and His Messenger (ﷺ)}}
\hadithdefcmd{muslim}{3522}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، قَالَ قُلْتُ لِلزُّهْرِيِّ يَا أَبَا بَكْرٍ كَيْفَ هَذَا الْحَدِيثُ شَرُّ الطَّعَامِ طَعَامُ الأَغْنِيَاءِ فَضَحِكَ فَقَالَ لَيْسَ هُوَ شَرُّ الطَّعَامِ طَعَامُ الأَغْنِيَاءِ ‏.‏ قَالَ سُفْيَانُ وَكَانَ أَبِي غَنِيًّا فَأَفْزَعَنِي هَذَا الْحَدِيثُ حِينَ سَمِعْتُ بِهِ فَسَأَلْتُ عَنْهُ الزُّهْرِيَّ فَقَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ الأَعْرَجُ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ يَقُولُ شَرُّ الطَّعَامِ طَعَامُ الْوَلِيمَةِ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ مَالِكٍ\hadithno{3522}\hadithtrans{Sufyan reported:I said to Zuhri: Abu Bakr, what does this hadith mean:" The worst kind of food is at a wedding feast of the rich"? He laughed and said: The food served in the feast given by the rich is not worst (in itself). Sufyan said: My father was rich, so I felt disturbed when I heard this hadith, so I asked Zuhri who said: I heard from 'Abd al-Rahman al-Alraj that he heard Abu Huraira (Allah he pleased with him) say: The worst kind of food is that served at the wedding feast. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{3523}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، عَنْ عَبْدِ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَعَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ شَرُّ الطَّعَامِ طَعَامُ الْوَلِيمَةِ ‏.‏ نَحْوَ حَدِيثِ مَالِكٍ. وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، نَحْوَ ذَلِكَ ‏.‏\hadithno{3523}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira (Allah be pleased with him) through another chain of transmitters. A hadith like this has been narrated by Abu Huraira (Allah be pleased with him) through another chain of transmitters}}
\hadithdefcmd{muslim}{3524}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ زِيَادَ بْنَ سَعْدٍ، قَالَ سَمِعْتُ ثَابِتًا، الأَعْرَجَ يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ شَرُّ الطَّعَامِ طَعَامُ الْوَلِيمَةِ يُمْنَعُهَا مَنْ يَأْتِيهَا وَيُدْعَى إِلَيْهَا مَنْ يَأْبَاهَا وَمَنْ لَمْ يُجِبِ الدَّعْوَةَ فَقَدْ عَصَى اللَّهَ وَرَسُولَهُ ‏"‏ ‏.‏\hadithno{3524}\hadithtrans{Abu Haraira (Allah be pleased with him) reported Allah's Apostle (ﷺ) as saying. The worst kind of food is at the wedding feast from which one who comes is turned away, and he who refuses it is invited, and he who did not accept the invitation disobeyed Allah and His Messenger (ﷺ)}}
\hadithdefcmd{muslim}{3526}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، - وَاللَّفْظُ لِعَمْرٍو - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ جَاءَتِ امْرَأَةُ رِفَاعَةَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ كُنْتُ عِنْدَ رِفَاعَةَ فَطَلَّقَنِي فَبَتَّ طَلاَقِي فَتَزَوَّجْتُ عَبْدَ الرَّحْمَنِ بْنَ الزَّبِيرِ وَإِنَّ مَا مَعَهُ مِثْلُ هُدْبَةِ الثَّوْبِ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَتُرِيدِينَ أَنْ تَرْجِعِي إِلَى رِفَاعَةَ لاَ حَتَّى تَذُوقِي عُسَيْلَتَهُ وَيَذُوقَ عُسَيْلَتَكِ ‏"‏ ‏.‏ قَالَتْ وَأَبُو بَكْرٍ عِنْدَهُ وَخَالِدٌ بِالْبَابِ يَنْتَظِرُ أَنْ يُؤْذَنَ لَهُ فَنَادَى يَا أَبَا بَكْرٍ أَلاَ تَسْمَعُ هَذِهِ مَا تَجْهَرُ بِهِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3526}\hadithtrans{A'isha (Allah he pleased with her) reported:There came the wife of Rifa'a to Allah's Apostle (ﷺ) and said: I was married to Rifa'a but he divorced me, making may divorce irrevocable. Afterwards I married Abd al-Rahman b. al-Zubair, but all he possesses is like the fringe of a garment (i. e. he is sexually weak). Thereupon Allah's Messenger (ﷺ) smiled, and said: Do you wish to return to Rifa'a. (You) cannot (do it) until you have tasted his sweetness and he ('Abd al-Rahman) has tasted your sweetness. Abu Bakr was at that time near him (the Holy Prophet) and Khalid (b. Sa'id) was at the door waiting for the permission to be granted to him to enter), He (Khalid) said; Abu Bakr, do you hear what she is saying loudly in the presence of Allah's Messenger (ﷺ)?}}
\hadithdefcmd{muslim}{3527}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، - وَاللَّفْظُ لِحَرْمَلَةَ - قَالَ أَبُو الطَّاهِرِ حَدَّثَنَا وَقَالَ، حَرْمَلَةُ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ رِفَاعَةَ الْقُرَظِيَّ طَلَّقَ امْرَأَتَهُ فَبَتَّ طَلاَقَهَا فَتَزَوَّجَتْ بَعْدَهُ عَبْدَ الرَّحْمَنِ بْنَ الزَّبِيرِ فَجَاءَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّهَا كَانَتْ تَحْتَ رِفَاعَةَ فَطَلَّقَهَا آخِرَ ثَلاَثِ تَطْلِيقَاتٍ فَتَزَوَّجْتُ بَعْدَهُ عَبْدَ الرَّحْمَنِ بْنَ الزَّبِيرِ وَإِنَّهُ وَاللَّهِ مَا مَعَهُ إِلاَّ مِثْلُ الْهُدْبَةِ وَأَخَذَتْ بِهُدْبَةٍ مِنْ جِلْبَابِهَا ‏.‏ قَالَ فَتَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم ضَاحِكًا فَقَالَ ‏ "‏ لَعَلَّكِ تُرِيدِينَ أَنْ تَرْجِعِي إِلَى رِفَاعَةَ لاَ حَتَّى يَذُوقَ عُسَيْلَتَكِ وَتَذُوقِي عُسَيْلَتَهُ ‏"‏ ‏.‏ وَأَبُو بَكْرٍ الصِّدِّيقُ جَالِسٌ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَخَالِدُ بْنُ سَعِيدِ بْنِ الْعَاصِ جَالِسٌ بِبَابِ الْحُجْرَةِ لَمْ يُؤْذَنْ لَهُ قَالَ فَطَفِقَ خَالِدٌ يُنَادِي أَبَا بَكْرٍ أَلاَ تَزْجُرُ هَذِهِ عَمَّا تَجْهَرُ بِهِ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم\hadithno{3527}\hadithtrans{A'isha (Allah be pleased with her), the wife of Allah's Apostle (ﷺ), reported that Rifa'a al-Quraid (Allah be pleased with him) divorced his wife, making her divorce irrevocable. Afterwards she married Abd at-Rahman b. al-Zubair (Allah be pleased with him), She came to Allah'sApostle (may peace be upon him and said to Allah's messenger (ﷺ) that she had been the wife of Rifa'a (Allah be pleased with him) and he had divorced her by three pronouncements and afterwards she married 'Abd al-Rahman b. al-Zubair. By Allah, all he possesses is like the fringe of a garment, and she took hold of the fringe of her garment. Thereupon Allah's Messenger (ﷺ) laughed and said:Perhaps you wish to return to Rifa'a, (but you) cannot (do it) until he has tasted your sweetness and you have tasted his sweetness. Abu Bakr al-siddiq (Allah be pleased with him) was sitting at that time with Allah's Messenger (ﷺ) and Khalid b. Sa'id b. al-'As (Allah be pleased with him) was sitting at the door of his apartment and he was not permitted to (enter the room), and Kbalid called loudly saying: Abu Bakr, why don't you scold her for what she is saying loudly in the presence of Allah's Messenger (ﷺ)?}}
\hadithdefcmd{muslim}{3528}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رِفَاعَةَ الْقُرَظِيَّ، طَلَّقَ امْرَأَتَهُ فَتَزَوَّجَهَا عَبْدُ الرَّحْمَنِ بْنُ الزَّبِيرِ فَجَاءَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ رِفَاعَةَ طَلَّقَهَا آخِرَ ثَلاَثِ تَطْلِيقَاتٍ ‏.‏ بِمِثْلِ حَدِيثِ يُونُسَ ‏.‏\hadithno{3528}\hadithtrans{A'isha (Allah be pleased with her) reported that Rifa`a al Qurazi divorced his wife and afterwards `Abd al-Rahman b. al-Zubair married her. She came to Allah's Apostle (ﷺ) and said:Messenger of Allah, Rifa`a has divorced me by three pronouncements. (The rest of the hadith is the same)}}
\hadithdefcmd{muslim}{3529}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الْمَرْأَةِ يَتَزَوَّجُهَا الرَّجُلُ فَيُطَلِّقُهَا فَتَتَزَوَّجُ رَجُلاً فَيُطَلِّقُهَا قَبْلَ أَنْ يَدْخُلَ بِهَا أَتَحِلُّ لِزَوْجِهَا الأَوَّلِ قَالَ ‏ "‏ لاَ حَتَّى يَذُوقَ عُسَيْلَتَهَا ‏"‏‏.‏\hadithno{3529}\hadithtrans{A'isha (Allah be pleased with her) reported that Allah's Messenger (ﷺ) was asked about a woman whom a man married and then divorced her, and then she married (another) person, and she was divorced before sexual intercourse with her, whether it was lawful for her first husband (to marry her in this state). He (the Holy Prophet) said:No, until he has tasted her sweetness}}
\hadithdefcmd{muslim}{3530}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ فُضَيْلٍ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ جَمِيعًا عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{3530}\hadithtrans{A hadith like this has been narrated on the authority of Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{3531}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ طَلَّقَ رَجُلٌ امْرَأَتَهُ ثَلاَثًا فَتَزَوَّجَهَا رَجُلٌ ثُمَّ طَلَّقَهَا قَبْلَ أَنْ يَدْخُلَ بِهَا فَأَرَادَ زَوْجُهَا الأَوَّلُ أَنْ يَتَزَوَّجَهَا فَسُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ ‏ "‏ لاَ حَتَّى يَذُوقَ الآخِرُ مِنْ عُسَيْلَتِهَا مَا ذَاقَ الأَوَّلُ ‏"‏ ‏.‏\hadithno{3531}\hadithtrans{A'Asha (Allah be pleased with her) reported:A person divorced his wife by three pronouncements; then another person married her and he also divorced her without having sexual intercourse with her. Then the first husband of her intended to remarry her. It was about such a case that Allah's Messenger (ﷺ) was asked, whereupon he said: No, until the second one has tasted her sweetness as the first one had tasted}}
\hadithdefcmd{muslim}{3532}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - جَمِيعًا عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏ وَفِي حَدِيثِ يَحْيَى عَنْ عُبَيْدِ اللَّهِ حَدَّثَنَا الْقَاسِمُ عَنْ عَائِشَةَ ‏.‏\hadithno{3532}\hadithtrans{A hadith like this has been narrated on the same chain of transmitters by 'A'isha (Allah be pleased with her)}}
\hadithdefcmd{muslim}{3533}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِيَحْيَى - قَالاَ أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَالِمٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ أَنَّ أَحَدَهُمْ إِذَا أَرَادَ أَنْ يَأْتِيَ أَهْلَهُ قَالَ بِاسْمِ اللَّهِ اللَّهُمَّ جَنِّبْنَا الشَّيْطَانَ وَجَنِّبِ الشَّيْطَانَ مَا رَزَقْتَنَا فَإِنَّهُ إِنْ يُقَدَّرْ بَيْنَهُمَا وَلَدٌ فِي ذَلِكَ لَمْ يَضُرَّهُ شَيْطَانٌ أَبَدًا ‏"‏‏.‏\hadithno{3533}\hadithtrans{Ibn" Abbas (Allah be pleased with thern) reported that Allah's Messenger (ﷺ) said:If anyone amongst you intends to go to his wife he should say: In the name of Allah,0 Allah protect us against Satan and keep away the Satan from the one that you have bestowed upon us, and if He has ordained a male child for them, Satan will never be able to do any harm to him}}
\hadithdefcmd{muslim}{3534}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، جَمِيعًا عَنِ الثَّوْرِيِّ، كِلاَهُمَا عَنْ مَنْصُورٍ، بِمَعْنَى حَدِيثِ جَرِيرٍ غَيْرَ أَنَّ شُعْبَةَ لَيْسَ فِي حَدِيثِهِ ذِكْرُ ‏"‏ بِاسْمِ اللَّهِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ عَبْدِ الرَّزَّاقِ عَنِ الثَّوْرِيِّ ‏"‏ بِاسْمِ اللَّهِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ نُمَيْرٍ قَالَ مَنْصُورٌ أُرَاهُ قَالَ ‏"‏ بِاسْمِ اللَّهِ ‏"‏ ‏.‏\hadithno{3534}\hadithtrans{This hadith is narrated through another chain of transmitters and there is no mention of (the words)" Bismillah" (In the name of Allah) in it}}
\hadithdefcmd{muslim}{3535}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالُوا حَدَّثَنَا سُفْيَانُ عَنِ ابْنِ الْمُنْكَدِرِ سَمِعَ جَابرًا يَقُولُ كَانَتِ الْيَهُودُ تَقُولُ إِذَا أَتَى الرَّجُلُ امْرَأَتَهُ مِنْ دُبُرِهَا فِي قُبُلِهَا كَانَ الْوَلَدُ أَحْوَلَ فَنَزَلَتْ ‏\{‏ نِسَاؤُكُمْ حَرْثٌ لَكُمْ فَأْتُوا حَرْثَكُمْ أَنَّى شِئْتُمْ‏\}‏\hadithno{3535}\hadithtrans{Jabir (Allah be pleased with him) declared that the Jews used to say:When a man has intercourse with his wife through the vagina but being on her back. the child will have squint, so the verse came down:" Your wives are your tilth; go then unto your tilth as you may desire" (ii)}}
\hadithdefcmd{muslim}{3536}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ الْهَادِ، عَنْ أَبِي حَازِمٍ، عَنْ مُحَمَّدِ، بْنِ الْمُنْكَدِرِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ يَهُودَ، كَانَتْ تَقُولُ إِذَا أُتِيَتِ الْمَرْأَةُ مِنْ دُبُرِهَا فِي قُبُلِهَا ثُمَّ حَمَلَتْ كَانَ وَلَدُهَا أَحْوَلَ ‏.‏ قَالَ فَأُنْزِلَتْ ‏\{‏ نِسَاؤُكُمْ حَرْثٌ لَكُمْ فَأْتُوا حَرْثَكُمْ أَنَّى شِئْتُمْ‏\}‏\hadithno{3536}\hadithtrans{Jabir (b. Abdullah) (Allah be pleased with him) reported that the Jews used to say that when one comes to one's wife through the vagina, but being on her back, and she becomes pregnant, the child has a squint. So the verse came down:" Your wives are your ti'Ith; go then unto your tilth, as you may desire}}
\hadithdefcmd{muslim}{3537}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، ح وَحَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، عَنْ أَيُّوبَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنِي عُبَيْدُ اللَّهِ، بْنُ سَعِيدٍ وَهَارُونُ بْنُ عَبْدِ اللَّهِ وَأَبُو مَعْنٍ الرَّقَاشِيُّ قَالُوا حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ النُّعْمَانَ بْنَ رَاشِدٍ، يُحَدِّثُ عَنِ الزُّهْرِيِّ، ح وَحَدَّثَنِي سُلَيْمَانُ بْنُ مَعْبَدٍ، حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - وَهُوَ ابْنُ الْمُخْتَارِ - عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، كُلُّ هَؤُلاَءِ عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ، بِهَذَا الْحَدِيثِ وَزَادَ فِي حَدِيثِ النُّعْمَانِ عَنِ الزُّهْرِيِّ إِنْ شَاءَ مُجَبِّيَةً وَإِنْ شَاءَ غَيْرَ مُجَبِّيَةٍ غَيْرَ أَنَّ ذَلِكَ فِي صِمَامٍ وَاحِدٍ ‏.‏\hadithno{3537}\hadithtrans{This hadith has been reported on the authority of Jabir through another chain of transmitters, but in the hadith transmitted on the authority of Zuhri there is an addition (of these words):" If he likes he may (have intercourse) being on the back or in front of her, but it should be through one opening (vagina)}}
\hadithdefcmd{muslim}{3538}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا بَاتَتِ الْمَرْأَةُ هَاجِرَةً فِرَاشَ زَوْجِهَا لَعَنَتْهَا الْمَلاَئِكَةُ حَتَّى تُصْبِحَ ‏"‏ ‏.‏\hadithno{3538}\hadithtrans{Abu Huraira (Allah be pleased with him) reported that Allah's Apostle (ﷺ) said:When a woman spends the night away from the bed of her husband, the angels curse her until morning}}
\hadithdefcmd{muslim}{3539}{وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ حَتَّى تَرْجِعَ ‏"‏ ‏.‏\hadithno{3539}\hadithtrans{This hadith has been narrated through the same chain of transmitters (with a slight variation):" He said: Until she comes back}}
\hadithdefcmd{muslim}{3540}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا مَرْوَانُ، عَنْ يَزِيدَ، - يَعْنِي ابْنَ كَيْسَانَ - عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ مَا مِنْ رَجُلٍ يَدْعُو امْرَأَتَهُ إِلَى فِرَاشِهَا فَتَأْبَى عَلَيْهِ إِلاَّ كَانَ الَّذِي فِي السَّمَاءِ سَاخِطًا عَلَيْهَا حَتَّى يَرْضَى عَنْهَا ‏"‏ ‏\hadithno{3540}\hadithtrans{Abu Huraira (Allah be pleased with him) reported Allah's Messenger (ﷺ) as saying:By Him in Whose Hand is my life, when a man calls his wife to his bed, and she does not respond, the One Who is in the heaven is displeased with her until he (her husband) is pleased with her}}
\hadithdefcmd{muslim}{3541}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنِي أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا جَرِيرٌ، كُلُّهُمْ عَنِ الأَعْمَشِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دَعَا الرَّجُلُ امْرَأَتَهُ إِلَى فِرَاشِهِ فَلَمْ تَأْتِهِ فَبَاتَ غَضْبَانَ عَلَيْهَا لَعَنَتْهَا الْمَلاَئِكَةُ حَتَّى تُصْبِحَ ‏"‏ ‏.‏\hadithno{3541}\hadithtrans{Abu Huraira (Allah he pleased with him) reported Allah's Messenger (may, peace be upon him) as saying:When a man invites his wife to his bed and she does not come, and he (the husband) spends the sight being angry with her, the angels curse her until morning}}
\hadithdefcmd{muslim}{3542}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنْ عُمَرَ بْنِ حَمْزَةَ الْعُمَرِيِّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَعْدٍ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنْ أَشَرِّ النَّاسِ عِنْدَ اللَّهِ مَنْزِلَةً يَوْمَ الْقِيَامَةِ الرَّجُلَ يُفْضِي إِلَى امْرَأَتِهِ وَتُفْضِي إِلَيْهِ ثُمَّ يَنْشُرُ سِرَّهَا ‏"‏ ‏.‏\hadithno{3542}\hadithtrans{Abu Sa'id al-Khudri (Allah he pleased with him) reported that Allah's Messenger (may peace be upoin him) said:The most wicked among the people in the eye of Allah on the Day of judgment is the men who goes to his wife and she comes to him, and then he divulges her secret}}
\hadithdefcmd{muslim}{3543}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عُمَرَ، بْنِ حَمْزَةَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَعْدٍ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ أَعْظَمِ الأَمَانَةِ عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ الرَّجُلَ يُفْضِي إِلَى امْرَأَتِهِ وَتُفْضِي إِلَيْهِ ثُمَّ يَنْشُرُ سِرَّهَا ‏"‏ ‏.‏ وَقَالَ ابْنُ نُمَيْرٍ ‏"‏ إِنَّ أَعْظَمَ ‏"‏ ‏.‏\hadithno{3543}\hadithtrans{Abu Sirma al-Khudri (Allah he pleased with him ) reported Allah's Messen- ger (ﷺ) as saying:The most important of the trusts in the sight of Allah on the Day of judgment is that a man goes to his wife and she goes to him (and the breach of this trust is) that he should divulge her secret Ibn Numair narrates this hadith with a slight change of wording}}
\hadithdefcmd{muslim}{3544}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، بْنُ جَعْفَرٍ أَخْبَرَنِي رَبِيعَةُ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ ابْنِ مُحَيْرِيزٍ، أَنَّهُ قَالَ دَخَلْتُ أَنَا وَأَبُو صِرْمَةَ عَلَى أَبِي سَعِيدٍ الْخُدْرِيِّ فَسَأَلَهُ أَبُو صِرْمَةَ فَقَالَ يَا أَبَا سَعِيدٍ هَلْ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَذْكُرُ الْعَزْلَ فَقَالَ نَعَمْ غَزَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم غَزْوَةَ بَلْمُصْطَلِقِ فَسَبَيْنَا كَرَائِمَ الْعَرَبِ فَطَالَتْ عَلَيْنَا الْعُزْبَةُ وَرَغِبْنَا فِي الْفِدَاءِ فَأَرَدْنَا أَنْ نَسْتَمْتِعَ وَنَعْزِلَ فَقُلْنَا نَفْعَلُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَظْهُرِنَا لاَ نَسْأَلُهُ ‏.‏ فَسَأَلْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ عَلَيْكُمْ أَنْ لاَ تَفْعَلُوا مَا كَتَبَ اللَّهُ خَلْقَ نَسَمَةٍ هِيَ كَائِنَةٌ إِلَى يَوْمِ الْقِيَامَةِ إِلاَّ سَتَكُونُ ‏"‏ ‏.‏\hadithno{3544}\hadithtrans{Abu Sirma said to Abu Sa'id al Khadri (Allah he pleased with him):0 Abu Sa'id, did you hear Allah's Messenger (ﷺ) mentioning al-'azl? He said: Yes, and added: We went out with Allah's Messenger (ﷺ) on the expedition to the Bi'l-Mustaliq and took captive some excellent Arab women; and we desired them, for we were suffering from the absence of our wives, (but at the same time) we also desired ransom for them. So we decided to have sexual intercourse with them but by observing 'azl (Withdrawing the male sexual organ before emission of semen to avoid-conception). But we said: We are doing an act whereas Allah's Messenger is amongst us; why not ask him? So we asked Allah's Mes- senger (ﷺ), and he said: It does not matter if you do not do it, for every soul that is to be born up to the Day of Resurrection will be born}}
\hadithdefcmd{muslim}{3545}{حَدَّثَنِي مُحَمَّدُ بْنُ الْفَرَجِ، مَوْلَى بَنِي هَاشِمٍ حَدَّثَنَا مُحَمَّدُ بْنُ الزِّبْرِقَانِ، حَدَّثَنَا مُوسَى، بْنُ عُقْبَةَ عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، بِهَذَا الإِسْنَادِ فِي مَعْنَى حَدِيثِ رَبِيعَةَ غَيْرَ أَنَّهُ قَالَ ‏ "‏ فَإِنَّ اللَّهَ كَتَبَ مَنْ هُوَ خَالِقٌ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{3545}\hadithtrans{A hadith like this has been narrated on the authority of Habban with the same chain of transmitters (but with this alteration) that he said:" Allah has ordained whom he has to createuntil the Day of judgment}}
\hadithdefcmd{muslim}{3546}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ الضُّبَعِيُّ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ مُحَيْرِيزٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ أَخْبَرَهُ قَالَ أَصَبْنَا سَبَايَا فَكُنَّا نَعْزِلُ ثُمَّ سَأَلْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَقَالَ لَنَا ‏ "‏ وَإِنَّكُمْ لَتَفْعَلُونَ وَإِنَّكُمْ لَتَفْعَلُونَ وَإِنَّكُمْ لَتَفْعَلُونَ مَا مِنْ نَسَمَةٍ كَائِنَةٍ إِلَى يَوْمِ الْقِيَامَةِ إِلاَّ هِيَ كَائِنَةٌ ‏"‏ ‏.‏\hadithno{3546}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported:We took women captives, and we wanted to do 'azl with them. We then asked Allah's Messen- ger (ﷺ) about it, and he said to us: Verily you do it, verily you do it, verily you do it, but the soul which has to be born until the Day of judg- ment must be born}}
\hadithdefcmd{muslim}{3547}{وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا شُعْبَةُ، عَنْ أَنَسِ، بْنِ سِيرِينَ عَنْ مَعْبَدِ بْنِ سِيرِينَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قُلْتُ لَهُ سَمِعْتَهُ مِنْ أَبِي سَعِيدٍ، قَالَ نَعَمْ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ عَلَيْكُمْ أَنْ لاَ تَفْعَلُوا فَإِنَّمَا هُوَ الْقَدَرُ‏"‏ ‏.‏\hadithno{3547}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) (was asked if he had heard it himself), to which he said:Yes. (I heard) Allah's Apostle (ﷺ) as saying: There is no harm if you do not practise it, for it (the birth of the child) is something ordained (by Allah)}}
\hadithdefcmd{muslim}{3548}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا يَحْيَى، بْنُ حَبِيبٍ حَدَّثَنَا خَالِدٌ يَعْنِي ابْنَ الْحَارِثِ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، بْنُ مَهْدِيٍّ وَبَهْزٌ قَالُوا جَمِيعًا حَدَّثَنَا شُعْبَةُ، عَنْ أَنَسِ بْنِ سِيرِينَ، بِهَذَا الإِسْنَادِ مِثْلَهُ غَيْرَ أَنَّ فِي حَدِيثِهِمْ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ فِي الْعَزْلِ ‏ "‏ لاَ عَلَيْكُمْ أَنْ لاَ تَفْعَلُوا ذَاكُمْ فَإِنَّمَا هُوَ الْقَدَرُ ‏"‏ ‏.‏ وَفِي رِوَايَةِ بَهْزٍ قَالَ شُعْبَةُ قُلْتُ لَهُ سَمِعْتَهُ مِنْ أَبِي سَعِيدٍ قَالَ نَعَمْ ‏.‏\hadithno{3548}\hadithtrans{This hadith is reported on the authority of Abu Sa'id with the same chain of transmitters but with a slight variation (of words)}}
\hadithdefcmd{muslim}{3549}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ - وَاللَّفْظُ لأَبِي كَامِلٍ - قَالاَ حَدَّثَنَا حَمَّادٌ، - وَهُوَ ابْنُ زَيْدٍ - حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ بِشْرِ بْنِ مَسْعُودٍ، رَدَّهُ إِلَى أَبِي سَعِيدٍ الْخُدْرِيِّ قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنِ الْعَزْلِ فَقَالَ ‏"‏ لاَ عَلَيْكُمْ أَنْ لاَ تَفْعَلُوا ذَاكُمْ فَإِنَّمَا هُوَ الْقَدَرُ ‏"‏ ‏.‏ قَالَ مُحَمَّدٌ وَقَوْلُهُ ‏"‏ لاَ عَلَيْكُمْ ‏"‏ ‏.‏ أَقْرَبُ إِلَى النَّهْىِ ‏.‏\hadithno{3549}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported that Allah's Apostle (ﷺ) was asked about 'azl, whereupon he said:There is no harm if you do not do that, for it (the birth of the child) is something ordained. Muhammad (one of the narrators) said: (The words) La 'alaykum (there is no harm) implies its Prohibition}}
\hadithdefcmd{muslim}{3550}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ بِشْرٍ الأَنْصَارِيِّ، ‏.‏ قَالَ فَرَدَّ الْحَدِيثَ حَتَّى رَدَّهُ إِلَى أَبِي سَعِيدٍ الْخُدْرِيِّ قَالَ ذُكِرَ الْعَزْلُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ وَمَا ذَاكُمْ ‏"‏ ‏.‏ قَالُوا الرَّجُلُ تَكُونُ لَهُ الْمَرْأَةُ تُرْضِعُ فَيُصِيبُ مِنْهَا وَيَكْرَهُ أَنْ تَحْمِلَ مِنْهُ وَالرَّجُلُ تَكُونُ لَهُ الأَمَةُ فَيُصِيبُ مِنْهَا وَيَكْرَهُ أَنْ تَحْمِلَ مِنْهُ ‏.‏ قَالَ ‏"‏ فَلاَ عَلَيْكُمْ أَنْ لاَ تَفْعَلُوا ذَاكُمْ فَإِنَّمَا هُوَ الْقَدَرُ ‏"‏ ‏.‏ قَالَ ابْنُ عَوْنٍ فَحَدَّثْتُ بِهِ الْحَسَنَ فَقَالَ وَاللَّهِ لَكَأَنَّ هَذَا زَجْرٌ ‏.‏\hadithno{3550}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported that mention was made of 'azl in the presence of Allah's Apostle (ﷺ) whereupon he said:Why do you practise it? They said: There is a man whose wife has to suckle the child, and if that person has a sexual intercourse with her (she may conceive) which he does not like, and there is another person who has a slave-girl and he has a sexual intercourse with her, but he does not like her to have conception so that she may not become Umm Walad, whereupon he (the Holy Prophet) said: There is no harm if you do not do that, for that (the birth of the child) is something pre- ordained. Ibn 'Aun said: I made a mention of this hadith to Hasan, and he said: By Allah, (it seems) as if there is upbraiding in it (for 'azl)}}
\hadithdefcmd{muslim}{3551}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنِ ابْنِ عَوْنٍ، قَالَ حَدَّثْتُ مُحَمَّدًا، عَنْ إِبْرَاهِيمَ، بِحَدِيثِ عَبْدِ الرَّحْمَنِ بْنِ بِشْرٍ - يَعْنِي حَدِيثَ الْعَزْلِ - فَقَالَ إِيَّاىَ حَدَّثَهُ عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ، ‏.‏\hadithno{3551}\hadithtrans{Ibn 'Aun reported:I reported to Muhammad on the authority of Ibrahim the hadith reported by 'Abd al-Rahmann b. Bishr (the hadith concerning 'azl), where- upon he said: That (hadith) Abd al-Rahman b. Bishr had narrated to me (also)}}
\hadithdefcmd{muslim}{3552}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا هِشَامٌ، عَنْ مُحَمَّدٍ، عَنْ مَعْبَدِ، بْنِ سِيرِينَ قَالَ قُلْنَا لأَبِي سَعِيدٍ هَلْ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَذْكُرُ فِي الْعَزْلِ شَيْئًا قَالَ نَعَمْ ‏.‏ وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ ابْنِ عَوْنٍ إِلَى قَوْلِهِ ‏ "‏ الْقَدَرُ ‏"‏ ‏.‏\hadithno{3552}\hadithtrans{Ma'bad b. Sirin said to Abu Sa'id (Allah be pleased with him):Did you hear Allah's Messenger (ﷺ) making a mention of something in regard to al-'azl? Thereupon he said: Yes. The rest (of the hadith is the same)}}
\hadithdefcmd{muslim}{3553}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، وَأَحْمَدُ بْنُ عَبْدَةَ، قَالَ ابْنُ عَبْدَةَ أَخْبَرَنَا وَقَالَ، عُبَيْدُ اللَّهِ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ قَزَعَةَ، عَنْ أَبِي سَعِيدٍ، الْخُدْرِيِّ قَالَ ذُكِرَ الْعَزْلُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ وَلِمَ يَفْعَلُ ذَلِكَ أَحَدُكُمْ - وَلَمْ يَقُلْ فَلاَ يَفْعَلْ ذَلِكَ أَحَدُكُمْ - فَإِنَّهُ لَيْسَتْ نَفْسٌ مَخْلُوقَةٌ إِلاَّ اللَّهُ خَالِقُهَا ‏"‏ ‏.‏\hadithno{3553}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported:Mention was made about al-'azl in the presence of Allah's Messenger (ﷺ), whereupon he said: Why any one of you practises it? (He did not say: One of you should not do it), for there is no created soul, whose creator is not Allah}}
\hadithdefcmd{muslim}{3554}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي مُعَاوِيَةُ، - يَعْنِي ابْنَ صَالِحٍ - عَنْ عَلِيِّ بْنِ أَبِي طَلْحَةَ، عَنْ أَبِي الْوَدَّاكِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، سَمِعَهُ يَقُولُ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْعَزْلِ فَقَالَ ‏ "‏ مَا مِنْ كُلِّ الْمَاءِ يَكُونُ الْوَلَدُ وَإِذَا أَرَادَ اللَّهُ خَلْقَ شَىْءٍ لَمْ يَمْنَعْهُ شَىْءٌ ‏"‏ ‏.‏\hadithno{3554}\hadithtrans{Abu Sa'id al-Khudri (Allah be pleased with him) reported that Allah's Messenger (ﷺ) was asked about 'azl, whereupon he said:The child does not come from all the liquid (sermen) and when Allah intends to create anything nothing can prevent it (from coming into existence)}}
\hadithdefcmd{muslim}{3555}{حَدَّثَنِي أَحْمَدُ بْنُ الْمُنْذِرِ الْبَصْرِيُّ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، حَدَّثَنَا مُعَاوِيَةُ، أَخْبَرَنِي عَلِيُّ بْنُ أَبِي طَلْحَةَ الْهَاشِمِيُّ، عَنْ أَبِي الْوَدَّاكِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{3555}\hadithtrans{A hadith like this has been transmitted by Abu Sa'id from Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{3556}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، أَخْبَرَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَجُلاً، أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ لِي جَارِيَةً هِيَ خَادِمُنَا وَسَانِيَتُنَا وَأَنَا أَطُوفُ عَلَيْهَا وَأَنَا أَكْرَهُ أَنْ تَحْمِلَ ‏.‏ فَقَالَ ‏"‏ اعْزِلْ عَنْهَا إِنْ شِئْتَ فَإِنَّهُ سَيَأْتِيهَا مَا قُدِّرَ لَهَا ‏"‏ ‏.‏ فَلَبِثَ الرَّجُلُ ثُمَّ أَتَاهُ فَقَالَ إِنَّ الْجَارِيَةَ قَدْ حَبِلَتْ ‏.‏ فَقَالَ ‏"‏ قَدْ أَخْبَرْتُكَ أَنَّهُ سَيَأْتِيهَا مَا قُدِّرَ لَهَا ‏"‏ ‏.‏\hadithno{3556}\hadithtrans{Jabir (Allah be pleased with him) reported that a man came to Allah's Messenger (ﷺ) and said:I have a slave-girl who is our servant and she carries water for us and I have intercourse with her, but I do not want her to conceive. He said: Practise 'azl, if you so like, but what is decreed for her will come to her. The person stayed back (for some time) and then came and said: The girl has become pregnant, whereupon he said: I told you what was decreed for her would come to her}}
\hadithdefcmd{muslim}{3557}{حَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ سَعِيدِ بْنِ حَسَّانَ، عَنْ عُرْوَةَ بْنِ عِيَاضٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ سَأَلَ رَجُلٌ النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنَّ عِنْدِي جَارِيَةً لِي وَأَنَا أَعْزِلُ عَنْهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ ذَلِكَ لَنْ يَمْنَعَ شَيْئًا أَرَادَهُ اللَّهُ ‏"‏ ‏.‏ قَالَ فَجَاءَ الرَّجُلُ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ الْجَارِيَةَ الَّتِي كُنْتُ ذَكَرْتُهَا لَكَ حَمَلَتْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَنَا عَبْدُ اللَّهِ وَرَسُولُهُ‏"‏ ‏.‏\hadithno{3557}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported that a person asked Allah's Apostle (ﷺ) saying:I have a slave-girl and I practise 'azl with her, whereupon Allah's Messenger (ﷺ) said: This cannot prevent that which Allah has decreed. The person then came (after some time) and said: Messenger of Allah, the slave-girl about whom I talked to you has conceived, whereupon Allah's Messeuger (ﷺ) said: I am the servant of Allah and His Messenger}}
\hadithdefcmd{muslim}{3558}{وَحَدَّثَنَا حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سَعِيدُ بْنُ حَسَّانَ، قَاصُّ أَهْلِ مَكَّةَ أَخْبَرَنِي عُرْوَةُ بْنُ عِيَاضِ بْنِ عَدِيِّ بْنِ الْخِيَارِ النَّوْفَلِيُّ، عَنْ جَابِرِ بْنِ عَبْدِ، اللَّهِ قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ سُفْيَانَ ‏.‏\hadithno{3558}\hadithtrans{Jabir b. 'Abdullah (Allah be pleased with them) reported:A person came to Allah's Apostle (the rest of the hadith is the same)}}
\hadithdefcmd{muslim}{3559}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، أَبُو بَكْرٍ حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ عَطَاءٍ، عَنْ جَابِرٍ، قَالَ كُنَّا نَعْزِلُ وَالْقُرْآنُ يَنْزِلُ ‏.‏ زَادَ إِسْحَاقُ قَالَ سُفْيَانُ لَوْ كَانَ شَيْئًا يُنْهَى عَنْهُ لَنَهَانَا عَنْهُ الْقُرْآنُ\hadithno{3559}\hadithtrans{Jabir (Allah be pleased with him) reported:We used to practise 'azl while the Qur'an was revealed (during the days when the Prophet was alive)}}
\hadithdefcmd{muslim}{3560}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ عَطَاءٍ، قَالَ سَمِعْتُ جَابِرًا، يَقُولُ لَقَدْ كُنَّا نَعْزِلُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{3560}\hadithtrans{Jabir (Allah be pleased with him) reported:We used to practise 'azl during the life of Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{3561}{وَحَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا مُعَاذٌ، - يَعْنِي ابْنَ هِشَامٍ - حَدَّثَنِي أَبِي، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ كُنَّا نَعْزِلُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَلَغَ ذَلِكَ نَبِيَّ اللَّهِ صلى الله عليه وسلم فَلَمْ يَنْهَنَا ‏.‏\hadithno{3561}\hadithtrans{Jabir (Allah be pleased with him) reported:We used to practise 'azl during the lifetime of Allah's Messenger (ﷺ). This (the news of this practise) reached Allah's Apostle (ﷺ), and he did not forbid us}}
\hadithdefcmd{muslim}{3562}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ يَزِيدَ بْنِ خُمَيْرٍ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ جُبَيْرٍ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ أَبِي الدَّرْدَاءِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ أَتَى بِامْرَأَةٍ مُجِحٍّ عَلَى بَابِ فُسْطَاطٍ فَقَالَ ‏"‏ لَعَلَّهُ يُرِيدُ أَنْ يُلِمَّ بِهَا ‏"‏ ‏.‏ فَقَالُوا نَعَمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَقَدْ هَمَمْتُ أَنْ أَلْعَنَهُ لَعْنًا يَدْخُلُ مَعَهُ قَبْرَهُ كَيْفَ يُوَرِّثُهُ وَهُوَ لاَ يَحِلُّ لَهُ كَيْفَ يَسْتَخْدِمُهُ وَهُوَ لاَ يَحِلُّ لَهُ ‏"‏ ‏.‏\hadithno{3562}\hadithtrans{Abu Darda' (Allah be pleased with him) related from the Prophet of Allah (ﷺ) that he came upon a woman who was in the advanced stage of pregnancy at the door of a tent. He (the Holy Prophet) said:Perhaps he (the man accompanying her) intends to cohabit with her. They said: Yes. Thereupon Allah's Messenger (ﷺ) said: I have decided to curse him with such a curse as may go along with him to his grave. How can he own him (the child to be born) and that is not lawful for him, and how can he take him as a servant for that is not lawful for him?}}
\hadithdefcmd{muslim}{3563}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، جَمِيعًا عَنْ شُعْبَةَ، فِي هَذَا الإِسْنَادِ ‏.‏\hadithno{3563}\hadithtrans{A hadith like this has been transmitted on the authority of Shu'ba}}
\hadithdefcmd{muslim}{3564}{وَحَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ عَنْ عُرْوَةَ عَنْ عَائِشَةَ عَنْ جُدَامَةَ بِنْتِ وَهْبٍ الأَسَدِيَّةِ أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَقَدْ هَمَمْتُ أَنْ أَنْهَى عَنِ الْغِيلَةِ حَتَّى ذَكَرْتُ أَنَّ الرُّومَ وَفَارِسَ يَصْنَعُونَ ذَلِكَ فَلاَ يَضُرُّ أَوْلاَدَهُمْ ‏"‏ ‏.‏ قَالَ مُسْلِمٌ وَأَمَّا خَلَفٌ فَقَالَ عَنْ جُذَامَةَ الأَسَدِيَّةِ ‏.‏ وَالصَّحِيحُ مَا قَالَهُ يَحْيَى بِالدَّالِ ‏.‏\hadithno{3564}\hadithtrans{Judaima daughter of Wahb al-Asadiyya (Allah be pleased with her) reported that she heard Allah's Messenger (ﷺ) assaying:I intended to prohibit cohabitation with a suckling woman until I considered that the Romans and the Persians do it without any injury being caused to their children thereby. (Imam Muslim said: Khalaf reported it from Judamat al-'Asadiyya, but the correct wording is what has been stated by Yahya)}}
\hadithdefcmd{muslim}{3565}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا الْمُقْرِئُ، حَدَّثَنَا سَعِيدُ، بْنُ أَبِي أَيُّوبَ حَدَّثَنِي أَبُو الأَسْوَدِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنْ جُدَامَةَ بِنْتِ وَهْبٍ، أُخْتِ عُكَّاشَةَ قَالَتْ حَضَرْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي أُنَاسٍ وَهُوَ يَقُولُ ‏"‏ لَقَدْ هَمَمْتُ أَنْ أَنْهَى عَنِ الْغِيلَةِ فَنَظَرْتُ فِي الرُّومِ وَفَارِسَ فَإِذَا هُمْ يُغِيلُونَ أَوْلاَدَهُمْ فَلاَ يَضُرُّ أَوْلاَدَهُمْ ذَلِكَ شَيْئًا ‏"‏ ‏.‏ ثُمَّ سَأَلُوهُ عَنِ الْعَزْلِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ذَلِكَ الْوَأْدُ الْخَفِيُّ ‏"‏ ‏.‏ زَادَ عُبَيْدُ اللَّهِ فِي حَدِيثِهِ عَنِ الْمُقْرِئِ وَهْىَ ‏\{‏ وَإِذَا الْمَوْءُودَةُ سُئِلَتْ‏\}‏\hadithno{3565}\hadithtrans{Judama daughter of Wahb, sister of Ukkasha (Allah be pleased with her). reported:I went to Allah's Messenger (ﷺ) along with some persons and he was saying: I intended to prohibit cohabitation with the suckling women, but I considered the Greeks and Persians, and saw that they suckle their children and this thing (cohabitation) does not do any harm to them (to the suckling women). Then they asked him about 'azl, whereupon he said. That is the secret (way of) burying alive, and Ubaidullah has made this addition in the hadith transmitted by al-Muqri and that is:" When the one buried alive is asked}}
\hadithdefcmd{muslim}{3566}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ إِسْحَاقَ، حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ الْقُرَشِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنْ جُدَامَةَ بِنْتِ وَهْبٍ، الأَسَدِيَّةِ أَنَّهَا قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ سَعِيدِ بْنِ أَبِي أَيُّوبَ فِي الْعَزْلِ وَالْغِيلَةِ ‏.‏ غَيْرَ أَنَّهُ قَالَ ‏ "‏ الْغِيَالِ ‏"‏ ‏.‏\hadithno{3566}\hadithtrans{Judama bint Wahb al-Asadiyya (Allah be pleased with her) reported:I heard Allah's Messenger (ﷺ) saying this. The rest of the hadith is the same concerning 'azl and ghila (cohabitating with a suckling woman), but with a slight variation of words}}
\hadithdefcmd{muslim}{3567}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لاِبْنِ نُمَيْرٍ - قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمَقْبُرِيُّ، حَدَّثَنَا حَيْوَةُ، حَدَّثَنِي عَيَّاشُ بْنُ عَبَّاسٍ، أَنَّ أَبَا النَّضْرِ، حَدَّثَهُ عَنْ عَامِرِ بْنِ سَعْدٍ، أَنَّ أُسَامَةَ بْنَ زَيْدٍ، أَخْبَرَ وَالِدَهُ، سَعْدَ بْنَ أَبِي وَقَّاصٍ أَنَّ رَجُلاً، جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنِّي أَعْزِلُ عَنِ امْرَأَتِي ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لِمَ تَفْعَلُ ذَلِكَ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ أُشْفِقُ عَلَى وَلَدِهَا أَوْ عَلَى أَوْلاَدِهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ كَانَ ذَلِكَ ضَارًّا ضَرَّ فَارِسَ وَالرُّومَ ‏"‏ ‏.‏ وَقَالَ زُهَيْرٌ فِي رِوَايَتِهِ ‏"‏ إِنْ كَانَ لِذَلِكَ فَلاَ مَا ضَارَ ذَلِكَ فَارِسَ وَلاَ الرُّومَ ‏"‏\hadithno{3567}\hadithtrans{Sa'd b. Abu Waqqas (Allah be pleased with him) reported that a person came to Allah's Messenger (ﷺ) and said:I do 'azi with my wife. Thereupon Allah's Messenger (ﷺ) said: Why do you do that? The person said: I fear harm to her child or her children. Thereupon Allah's Messenger (way peace be upon him) said: If that were harmful it would harm the Persians and the Greeks}}
