% Auto-generated chapter 45 for muslim
% Hadiths in this chapter: 210

\hadithdefcmd{muslim}{6500}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدِ بْنِ جَمِيلِ بْنِ طَرِيفٍ الثَّقَفِيُّ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا جَرِيرٌ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ مَنْ أَحَقُّ النَّاسِ بِحُسْنِ صَحَابَتِي قَالَ ‏"‏ أُمُّكَ ‏"‏ ‏.‏ قَالَ ثُمَّ مَنْ قَالَ ‏"‏ ثُمَّ أُمُّكَ ‏"‏ ‏.‏ قَالَ ثُمَّ مَنْ قَالَ ‏"‏ ثُمَّ أُمُّكَ ‏"‏ ‏.‏ قَالَ ثُمَّ مَنْ قَالَ ‏"‏ ثُمَّ أَبُوكَ ‏"‏ ‏.‏ وَفِي حَدِيثِ قُتَيْبَةَ مَنْ أَحَقُّ بِحُسْنِ صَحَابَتِي وَلَمْ يَذْكُرِ النَّاسَ ‏.‏\hadithno{6500}\hadithtrans{Abu Huraira reported that a person came to Allah, 's Messenger (ﷺ) and said:Who among the people is most deserving of a fine treatment from my hand? He said: Your mother. He again said: Then who (is the next one)? He said: Again it is your mother (who deserves the best treatment from you). He said: Then who (is the next one)? He (the Holy Prophet) said: Again, it is your mother. He (again) said: Then who? Thereupon he said: Then it is your father. In the hadith transmitted on the authority of Qutalba, there is no mention of the word" the people}}
\hadithdefcmd{muslim}{6501}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ أَبِيهِ، عَنْ عُمَارَةَ، بْنِ الْقَعْقَاعِ عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ مَنْ أَحَقُّ بِحُسْنِ الصُّحْبَةِ قَالَ ‏ "‏ أُمُّكَ ثُمَّ أُمُّكَ ثُمَّ أُمُّكَ ثُمَّ أَبُوكَ ثُمَّ أَدْنَاكَ أَدْنَاكَ ‏"‏ ‏.‏\hadithno{6501}\hadithtrans{Abu Huraira reported that a person said:Allah's Messenger, who amongst the people is most deserving of my good treatment? He said: Your mother, again your mother, again your mother, then your father, then your nearest relatives according to the order (of nearness)}}
\hadithdefcmd{muslim}{6502}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، عَنْ عُمَارَةَ، وَابْنِ، شُبْرُمَةَ عَنْ أَبِي، زُرْعَةَ عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ جَرِيرٍ وَزَادَ فَقَالَ ‏ "‏ نَعَمْ وَأَبِيكَ لَتُنَبَّأَنَّ ‏"‏ ‏.‏\hadithno{6502}\hadithtrans{Abu Huraira reported:A person came to Allah's Apostle (ﷺ). The rest of the hadith is the same as transmitted by jarir but with this addition: By your father, you would get the information}}
\hadithdefcmd{muslim}{6503}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا مُحَمَّدُ بْنُ طَلْحَةَ، ح وَحَدَّثَنِي أَحْمَدُ، بْنُ خِرَاشٍ حَدَّثَنَا حَبَّانُ، حَدَّثَنَا وُهَيْبٌ، كِلاَهُمَا عَنِ ابْنِ شُبْرُمَةَ، بِهَذَا الإِسْنَادِ فِي حَدِيثِ وُهَيْبٍ مَنْ أَبَرُّ وَفِي حَدِيثِ مُحَمَّدِ بْنِ طَلْحَةَ أَىُّ النَّاسِ أَحَقُّ مِنِّي بِحُسْنِ الصُّحْبَةِ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ جَرِيرٍ ‏.‏\hadithno{6503}\hadithtrans{This hadith has been narrated on the authority of Ibn Shubruma with the same chain of transmitters and the hadith transmitted on the authority of Wuhaib there is a slight variation of wording. Same is the case with the hadith transmitted on the authority of Muhammad b. Talha (and the words are):" Who amongst the people deserves the best treatment from me}}
\hadithdefcmd{muslim}{6504}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ حَبِيبٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ الْقَطَّانَ - عَنْ سُفْيَانَ، وَشُعْبَةَ قَالاَ حَدَّثَنَا حَبِيبٌ، عَنْ أَبِي الْعَبَّاسِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم يَسْتَأْذِنُهُ فِي الْجِهَادِ فَقَالَ ‏"‏ أَحَىٌّ وَالِدَاكَ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَفِيهِمَا فَجَاهِدْ ‏"‏ ‏.‏\hadithno{6504}\hadithtrans{Abdullah b. 'Amr reported that a person came to Allah's Apostle (ﷺ) and sought permission (to participate) in Jihad, whereupon he (the Holy Prophet) said:Are your parents living? He said: Yes. Thereupon he (the Holy Prophet) said: You should put in your best efforts (in their) service}}
\hadithdefcmd{muslim}{6507}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، أَنَّ نَاعِمًا، مَوْلَى أُمِّ سَلَمَةَ حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ قَالَ أَقْبَلَ رَجُلٌ إِلَى نَبِيِّ اللَّهِ صلى الله عليه وسلم فَقَالَ أُبَايِعُكَ عَلَى الْهِجْرَةِ وَالْجِهَادِ أَبْتَغِي الأَجْرَ مِنَ اللَّهِ ‏.‏ قَالَ ‏"‏ فَهَلْ مِنْ وَالِدَيْكَ أَحَدٌ حَىٌّ ‏"‏ ‏.‏ قَالَ نَعَمْ بَلْ كِلاَهُمَا ‏.‏ قَالَ ‏"‏ فَتَبْتَغِي الأَجْرَ مِنَ اللَّهِ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَارْجِعْ إِلَى وَالِدَيْكَ فَأَحْسِنْ صُحْبَتَهُمَا ‏"‏ ‏.‏\hadithno{6507}\hadithtrans{Yazid b. Abu Habib reported that Na'im, the freed slave of Umm Salama, reported to him that 'Abdullah b. 'Amr b. 'As said:There came to Allah's Apostle (ﷺ) a person and said: I owe allegiance to you for migration and Jihad seeking reward only from Allah. He (the Holy Prophet) said: Is one from amongst your parents living? He said: Yes, of course, both are living. He further asked: Do you want to seek reward from Allah? He said: Yes. Thereupon Allah's Messenger (ﷺ) said: Go back to your parents and accord them benevolent treatment}}
\hadithdefcmd{muslim}{6508}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، حَدَّثَنَا حُمَيْدُ بْنُ هِلاَلٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ كَانَ جُرَيْجٌ يَتَعَبَّدُ فِي صَوْمَعَةٍ فَجَاءَتْ أُمُّهُ ‏.‏ قَالَ حُمَيْدٌ فَوَصَفَ لَنَا أَبُو رَافِعٍ صِفَةَ أَبِي هُرَيْرَةَ لِصِفَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم أُمَّهُ حِينَ دَعَتْهُ كَيْفَ جَعَلَتْ كَفَّهَا فَوْقَ حَاجِبِهَا ثُمَّ رَفَعَتْ رَأْسَهَا إِلَيْهِ تَدْعُوهُ فَقَالَتْ يَا جُرَيْجُ أَنَا أُمُّكَ كَلِّمْنِي ‏.‏ فَصَادَفَتْهُ يُصَلِّي فَقَالَ اللَّهُمَّ أُمِّي وَصَلاَتِي ‏.‏ فَاخْتَارَ صَلاَتَهُ فَرَجَعَتْ ثُمَّ عَادَتْ فِي الثَّانِيَةِ فَقَالَتْ يَا جُرَيْجُ أَنَا أُمُّكَ فَكَلِّمْنِي ‏.‏ قَالَ اللَّهُمَّ أُمِّي وَصَلاَتِي ‏.‏ فَاخْتَارَ صَلاَتَهُ فَقَالَتِ اللَّهُمَّ إِنَّ هَذَا جُرَيْجٌ وَهُوَ ابْنِي وَإِنِّي كَلَّمْتُهُ فَأَبَى أَنْ يُكَلِّمَنِي اللَّهُمَّ فَلاَ تُمِتْهُ حَتَّى تُرِيَهُ الْمُومِسَاتِ ‏.‏ قَالَ وَلَوْ دَعَتْ عَلَيْهِ أَنْ يُفْتَنَ لَفُتِنَ ‏.‏ قَالَ وَكَانَ رَاعِي ضَأْنٍ يَأْوِي إِلَى دَيْرِهِ - قَالَ - فَخَرَجَتِ امْرَأَةٌ مِنَ الْقَرْيَةِ فَوَقَعَ عَلَيْهَا الرَّاعِي فَحَمَلَتْ فَوَلَدَتْ غُلاَمًا فَقِيلَ لَهَا مَا هَذَا قَالَتْ مِنْ صَاحِبِ هَذَا الدَّيْرِ ‏.‏ قَالَ فَجَاءُوا بِفُئُوسِهِمْ وَمَسَاحِيهِمْ فَنَادَوْهُ فَصَادَفُوهُ يُصَلِّي فَلَمْ يُكَلِّمْهُمْ - قَالَ - فَأَخَذُوا يَهْدِمُونَ دَيْرَهُ فَلَمَّا رَأَى ذَلِكَ نَزَلَ إِلَيْهِمْ فَقَالُوا لَهُ سَلْ هَذِهِ - قَالَ - فَتَبَسَّمَ ثُمَّ مَسَحَ رَأْسَ الصَّبِيِّ فَقَالَ مَنْ أَبُوكَ قَالَ أَبِي رَاعِي الضَّأْنِ ‏.‏ فَلَمَّا سَمِعُوا ذَلِكَ مِنْهُ قَالُوا نَبْنِي مَا هَدَمْنَا مِنْ دَيْرِكَ بِالذَّهَبِ وَالْفِضَّةِ ‏.‏ قَالَ لاَ وَلَكِنْ أَعِيدُوهُ تُرَابًا كَمَا كَانَ ثُمَّ عَلاَهُ ‏.‏\hadithno{6508}\hadithtrans{Abu Huraira reported that Juraij was one who was devoted to (prayer) in the temple. His mother came to him. Humaid said that Abu Rafi' demonstrated before us like the demonstration made by abu Huraira to whom Allah's Messenger (ﷺ) had demonstrated as his mother called him placing her palms upon the eyebrows and lifting her head for calling him and said:Juraij, it is your mother, so talk to her. She found him at that time absorbed in prayer, so he said (to himself): O Lord, my mother (is calling me) (whereas I am absorbed) in my prayer. He opted for prayer. She (his mother) went back, then came again for the second time and said: O Juraij, it is your mother (calling you), so talk to me. He said: O Allah. there is my mother also and my prayer, and he opted for prayer. She said: O Allah, this Juraij is my son. I pray to talk to him but he refuses to talk to me. O Allah, don't bring death to him unless he has seen the prostitutes, and had she invoked the curse upon him (from the heart of her heart) he would have been involved in some turmoil. There was a shepherd living near by his temple (the temple where Juraij was engaged in prayer). It so happened that a woman of that village came there and that shepherd committed fornication with her and she became pregnant and gave birth to a child. It was said to her: Whose child is this? She said: He is the child of one who is living in this temple. So there came persons with hatchets and spades. They called Juraij. He was absorbed in prayer and he did not talk to them and they were about to demolish that temple that he saw them and then came to them and they said: Ask her (this woman) what she says. He smiled and then touched the head of the child and said: Who is your father? He (the child) said: My father is the shepherd of the sheep, and when they heard this, they said: We are prepared to rebuild with gold and silver what we have demolished from your temple. He said: No, rebuild it with clay as it had been before. He then went up (to his room and absorbed himself in prayer)}}
\hadithdefcmd{muslim}{6509}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لَمْ يَتَكَلَّمْ فِي الْمَهْدِ إِلاَّ ثَلاَثَةٌ عِيسَى ابْنُ مَرْيَمَ وَصَاحِبُ جُرَيْجٍ وَكَانَ جُرَيْجٌ رَجُلاً عَابِدًا فَاتَّخَذَ صَوْمَعَةً فَكَانَ فِيهَا فَأَتَتْهُ أُمُّهُ وَهُوَ يُصَلِّي فَقَالَتْ يَا جُرَيْجُ ‏.‏ فَقَالَ يَا رَبِّ أُمِّي وَصَلاَتِي ‏.‏ فَأَقْبَلَ عَلَى صَلاَتِهِ فَانْصَرَفَتْ فَلَمَّا كَانَ مِنَ الْغَدِ أَتَتْهُ وَهُوَ يُصَلِّي فَقَالَتْ يَا جُرَيْجُ فَقَالَ يَا رَبِّ أُمِّي وَصَلاَتِي فَأَقْبَلَ عَلَى صَلاَتِهِ فَانْصَرَفَتْ فَلَمَّا كَانَ مِنَ الْغَدِ أَتَتْهُ وَهُوَ يُصَلِّي فَقَالَتْ يَا جُرَيْجُ ‏.‏ فَقَالَ أَىْ رَبِّ أُمِّي وَصَلاَتِي ‏.‏ فَأَقْبَلَ عَلَى صَلاَتِهِ فَقَالَتِ اللَّهُمَّ لاَ تُمِتْهُ حَتَّى يَنْظُرَ إِلَى وُجُوهِ الْمُومِسَاتِ ‏.‏ فَتَذَاكَرَ بَنُو إِسْرَائِيلَ جُرَيْجًا وَعِبَادَتَهُ وَكَانَتِ امْرَأَةٌ بَغِيٌّ يُتَمَثَّلُ بِحُسْنِهَا فَقَالَتْ إِنْ شِئْتُمْ لأَفْتِنَنَّهُ لَكُمْ - قَالَ - فَتَعَرَّضَتْ لَهُ فَلَمْ يَلْتَفِتْ إِلَيْهَا فَأَتَتْ رَاعِيًا كَانَ يَأْوِي إِلَى صَوْمَعَتِهِ فَأَمْكَنَتْهُ مِنْ نَفْسِهَا فَوَقَعَ عَلَيْهَا فَحَمَلَتْ فَلَمَّا وَلَدَتْ قَالَتْ هُوَ مِنْ جُرَيْجٍ ‏.‏ فَأَتَوْهُ فَاسْتَنْزَلُوهُ وَهَدَمُوا صَوْمَعَتَهُ وَجَعَلُوا يَضْرِبُونَهُ فَقَالَ مَا شَأْنُكُمْ قَالُوا زَنَيْتَ بِهَذِهِ الْبَغِيِّ فَوَلَدَتْ مِنْكَ ‏.‏ فَقَالَ أَيْنَ الصَّبِيُّ فَجَاءُوا بِهِ فَقَالَ دَعُونِي حَتَّى أُصَلِّيَ فَصَلَّى فَلَمَّا انْصَرَفَ أَتَى الصَّبِيَّ فَطَعَنَ فِي بَطْنِهِ وَقَالَ يَا غُلاَمُ مَنْ أَبُوكَ قَالَ فُلاَنٌ الرَّاعِي - قَالَ - فَأَقْبَلُوا عَلَى جُرَيْجٍ يُقَبِّلُونَهُ وَيَتَمَسَّحُونَ بِهِ وَقَالُوا نَبْنِي لَكَ صَوْمَعَتَكَ مِنْ ذَهَبٍ ‏.‏ قَالَ لاَ أَعِيدُوهَا مِنْ طِينٍ كَمَا كَانَتْ ‏.‏ فَفَعَلُوا ‏.‏ وَبَيْنَا صَبِيٌّ يَرْضَعُ مِنْ أُمِّهِ فَمَرَّ رَجُلٌ رَاكِبٌ عَلَى دَابَّةٍ فَارِهَةٍ وَشَارَةٍ حَسَنَةٍ فَقَالَتْ أُمُّهُ اللَّهُمَّ اجْعَلِ ابْنِي مِثْلَ هَذَا ‏.‏ فَتَرَكَ الثَّدْىَ وَأَقْبَلَ إِلَيْهِ فَنَظَرَ إِلَيْهِ فَقَالَ اللَّهُمَّ لاَ تَجْعَلْنِي مِثْلَهُ ‏.‏ ثُمَّ أَقْبَلَ عَلَى ثَدْيِهِ فَجَعَلَ يَرْتَضِعُ ‏.‏ قَالَ فَكَأَنِّي أَنْظُرُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يَحْكِي ارْتِضَاعَهُ بِإِصْبَعِهِ السَّبَّابَةِ فِي فَمِهِ فَجَعَلَ يَمُصُّهَا ‏.‏ قَالَ وَمَرُّوا بِجَارِيَةٍ وَهُمْ يَضْرِبُونَهَا وَيَقُولُونَ زَنَيْتِ سَرَقْتِ ‏.‏ وَهِيَ تَقُولُ حَسْبِيَ اللَّهُ وَنِعْمَ الْوَكِيلُ ‏.‏ فَقَالَتْ أُمُّهُ اللَّهُمَّ لاَ تَجْعَلِ ابْنِي مِثْلَهَا ‏.‏ فَتَرَكَ الرَّضَاعَ وَنَظَرَ إِلَيْهَا فَقَالَ اللَّهُمَّ اجْعَلْنِي مِثْلَهَا ‏.‏ فَهُنَاكَ تَرَاجَعَا الْحَدِيثَ فَقَالَتْ حَلْقَى مَرَّ رَجُلٌ حَسَنُ الْهَيْئَةِ فَقُلْتُ اللَّهُمَّ اجْعَلِ ابْنِي مِثْلَهُ ‏.‏ فَقُلْتَ اللَّهُمَّ لاَ تَجْعَلْنِي مِثْلَهُ ‏.‏ وَمَرُّوا بِهَذِهِ الأَمَةِ وَهُمْ يَضْرِبُونَهَا وَيَقُولُونَ زَنَيْتِ سَرَقْتِ ‏.‏ فَقُلْتُ اللَّهُمَّ لاَ تَجْعَلِ ابْنِي مِثْلَهَا ‏.‏ فَقُلْتَ اللَّهُمَّ اجْعَلْنِي مِثْلَهَا قَالَ إِنَّ ذَاكَ الرَّجُلَ كَانَ جَبَّارًا فَقُلْتُ اللَّهُمَّ لاَ تَجْعَلْنِي مِثْلَهُ ‏.‏ وَإِنَّ هَذِهِ يَقُولُونَ لَهَا زَنَيْتِ ‏.‏ وَلَمْ تَزْنِ وَسَرَقْتِ وَلَمْ تَسْرِقْ فَقُلْتُ اللَّهُمَّ اجْعَلْنِي مِثْلَهَا ‏.‏\hadithno{6509}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:None spoke in the cradle but only three (persons), Christ son of Mary, the second one the companion of Juraij. Juraij had got constructed a temple and confined himself in that. His mother came to him as he was busy in prayer and she said: Juraij. He said: My Lord, my mother (is calling me while I am engaged in) my prayer. He continued with the prayer. She returned and she came on the next day and he was busy in prayer, and she said: Juraij. And he said: My Lord, my mother (is calling me while I am engaged) in prayer, and he continued with the prayer and she went back, and then on the next day she again came and he was busy in prayer and she said: Juraij. And he said: My Lord, my mother (is calling me while I am engaged in my prayer, and he continued with the prayer, and she said: My Lord, don't give him death unless he has seen the fate of the prostitutes. The story of Juraij and that of his meditation and prayer gained currency amongst Bani Isra'il. There was a prostitute who had been a beauty incarnate. She said (to the people): If you like I can allure him to evil. She presented herself to him but he paid no heed (to her). She came to a shepherd who lived near the temple and she offered herself to him and he had a sexual intercourse with her and so she became pregnant arid when she gave birth to a child she said: This is from Juraij. So they came and asked him to get down and demolished the temple and began to beat him. He said: What is the matter? They said: You have committed fornication with this prostitute and she has given birth to a child from your loins. He said: Where is the child? They brought him (the child) and he said: just leave me so that I should observe prayer. And he observed prayer and when he finished, he came to the child. He struck his stomach and said: O boy, who is your father? lie said: He is such shepherd. So they turned towards Juraij, kissed him and touched him (for seeking blessing) and said: We are prepared to construct your temple with gold. He said. No, just rebuild it with mud as it had been, and they did that. Then there was a babe who was sucking his mother that a person dressed in fine garment came riding upon a beast. His mother said: O Allah, make my child like this one. He (the babe) left sucking and began to see towards him, and said: O Allah, don't make me like him. He then returned to the chest and began to suck the milk of his mother. He (Abu Huraira) said: I perceived as if I am seeing Allah's Messenger (ﷺ) as he is explaining the scene of his sucking milk with his forefinger in his mouth and sucking that. He (Abu Huraira) further reported Allah's Apostle (may be peace upon him) as saying: There happened to pass by him a girl who was being beaten and they were saying: You have committed adultery and you have committed theft and she was saying: Allah is enough for me and He is my good Protector, and his mother said: O Allah, don't make my child like her and he left sucking the milk, and looked towards her and said: O Allah, make me like her, and there was a talk between them. She said: O with shaven head, a good-looking person happened to pass by and I said: O Allah, make my child like him, and you said: O Allah, don't make me like him, and they passed by a girl while they were beating her and saying: You committed fornication and you committed theft, and I said: O Allah, don't make my child like her, and you said: O Allah, make me like her. Thereupon he said: That person was a tyrant, and I said: O Allah, don't make me like him, and they were saying about her: You committed fornication whereas in fact she had not committed that and they were saying: You have committed theft whereas she had not committed theft, so I said: O Allah, make me like her}}
\hadithdefcmd{muslim}{6510}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ رَغِمَ أَنْفُ ثُمَّ رَغِمَ أَنْفُ ثُمَّ رَغِمَ أَنْفُ ‏"‏ ‏.‏ قِيلَ مَنْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ مَنْ أَدْرَكَ أَبَوَيْهِ عِنْدَ الْكِبَرِ أَحَدَهُمَا أَوْ كِلَيْهِمَا فَلَمْ يَدْخُلِ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{6510}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:Let him be humbled into dust; let him be humbled into dust. It was said: Allah's Messenger, who is he? He said: He who sees either of his parents during their old age or he sees both of them, but he does not enter Paradise}}
\hadithdefcmd{muslim}{6511}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ رَغِمَ أَنْفُهُ ثُمَّ رَغِمَ أَنْفُهُ ثُمَّ رَغِمَ أَنْفُهُ ‏"‏ ‏.‏ قِيلَ مَنْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ مَنْ أَدْرَكَ وَالِدَيْهِ عِنْدَ الْكِبَرِ أَحَدَهُمَا أَوْ كِلَيْهِمَا ثُمَّ لَمْ يَدْخُلِ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{6511}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Let him be humbled, let him be humbled. It was said: Allah's Messenger, who is he? He said. He who finds his parents in old age, either one or both of them, and does not enter Paradise}}
\hadithdefcmd{muslim}{6512}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، حَدَّثَنِي سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَغِمَ أَنْفُهُ ‏"‏ ‏.‏ ثَلاَثًا ثُمَّ ذَكَرَ مِثْلَهُ ‏.‏\hadithno{6512}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Let him be humbled thrice, and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{6513}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي سَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنِ الْوَلِيدِ بْنِ أَبِي الْوَلِيدِ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَجُلاً، مِنَ الأَعْرَابِ لَقِيَهُ بِطَرِيقِ مَكَّةَ فَسَلَّمَ عَلَيْهِ عَبْدُ اللَّهِ وَحَمَلَهُ عَلَى حِمَارٍ كَانَ يَرْكَبُهُ وَأَعْطَاهُ عِمَامَةً كَانَتْ عَلَى رَأْسِهِ فَقَالَ ابْنُ دِينَارٍ فَقُلْنَا لَهُ أَصْلَحَكَ اللَّهُ إِنَّهُمُ الأَعْرَابُ وَإِنَّهُمْ يَرْضَوْنَ بِالْيَسِيرِ ‏.‏ فَقَالَ عَبْدُ اللَّهِ إِنَّ أَبَا هَذَا كَانَ وُدًّا لِعُمَرَ بْنِ الْخَطَّابِ وَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ أَبَرَّ الْبِرِّ صِلَةُ الْوَلَدِ أَهْلَ وُدِّ أَبِيهِ ‏"‏ ‏.‏\hadithno{6513}\hadithtrans{Ibn Dinar reported that a desert Arab met Abdullah b. 'Umar on the way to Mecca. 'Abdullah greeted him and mounted him upon the donkey on which he had been riding and gave him the turban that he had on his head. Ibn Dinar (further) reported:We said to him ('Abdullah b. 'Umar): May Allah do good to you, these are desert Arabs and they are satisfied even with meagre (things). Thereupon Abdullah said: His father was loved dearly by 'Umar b. Khattib and I heard Allah's Messenger (ﷺ) as saying: The finest act of goodness on the part of a son is to treat kindly the loved ones of his father}}
\hadithdefcmd{muslim}{6514}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي حَيْوَةُ بْنُ شُرَيْحٍ، عَنِ ابْنِ، الْهَادِ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَبَرُّ الْبِرِّ أَنْ يَصِلَ الرَّجُلُ وُدَّ أَبِيهِ ‏"‏ ‏.‏\hadithno{6514}\hadithtrans{Abdullah b. Umar reported Allah's Apostle (ﷺ) as saying:The finest act of goodness is that a person should treat kindly the loved ones of his father}}
\hadithdefcmd{muslim}{6515}{حَدَّثَنَا حَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، وَاللَّيْثُ بْنُ سَعْدٍ جَمِيعًا عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ أُسَامَةَ بْنِ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ كَانَ إِذَا خَرَجَ إِلَى مَكَّةَ كَانَ لَهُ حِمَارٌ يَتَرَوَّحُ عَلَيْهِ إِذَا مَلَّ رُكُوبَ الرَّاحِلَةِ وَعِمَامَةٌ يَشُدُّ بِهَا رَأْسَهُ فَبَيْنَا هُوَ يَوْمًا عَلَى ذَلِكَ الْحِمَارِ إِذْ مَرَّ بِهِ أَعْرَابِيٌّ فَقَالَ أَلَسْتَ ابْنَ فُلاَنِ بْنِ فُلاَنٍ قَالَ بَلَى ‏.‏ فَأَعْطَاهُ الْحِمَارَ وَقَالَ ارْكَبْ هَذَا وَالْعِمَامَةَ - قَالَ - اشْدُدْ بِهَا رَأْسَكَ ‏.‏ فَقَالَ لَهُ بَعْضُ أَصْحَابِهِ غَفَرَ اللَّهُ لَكَ أَعْطَيْتَ هَذَا الأَعْرَابِيَّ حِمَارًا كُنْتَ تَرَوَّحُ عَلَيْهِ وَعِمَامَةً كُنْتَ تَشُدُّ بِهَا رَأْسَكَ ‏.‏ فَقَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ مِنْ أَبَرِّ الْبِرِّ صِلَةَ الرَّجُلِ أَهْلَ وُدِّ أَبِيهِ بَعْدَ أَنْ يُوَلِّيَ ‏"‏ ‏.‏ وَإِنَّ أَبَاهُ كَانَ صَدِيقًا لِعُمَرَ ‏.‏\hadithno{6515}\hadithtrans{Abdullah b. Dinar reported that when 'Abdullah b. 'Umar set out to Mecea, 'he kept a donkey with him which he used as a diversion from the tedium of journey on the camel's back and had a turban which he tied round his head. One day, as he was riding the donkey a desert Arab happened to pass by him. He ('Abdullah b. 'Umar) said:Arn't you so and so? He said: Yes He gave him his donkey and said: Ride it, and tie the turban round your head. Some of his companions said: May Allah pardon you, you gave to this desert Arab the donkey on which you enjoyed ride for diversion and the turban which you tied round your. head. Thereupon he said: Verily I heard Allah's Messenger (ﷺ) as saying: The finest act of goodness is the kind treatment of a person to the loved ones of his father after his death and the father of this person was a friend of 'Umar}}
\hadithdefcmd{muslim}{6516}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنِ النَّوَّاسِ بْنِ سَمْعَانَ الأَنْصَارِيِّ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْبِرِّ وَالإِثْمِ فَقَالَ ‏ "‏ الْبِرُّ حُسْنُ الْخُلُقِ وَالإِثْمُ مَا حَاكَ فِي صَدْرِكَ وَكَرِهْتَ أَنْ يَطَّلِعَ عَلَيْهِ النَّاسُ ‏"‏ ‏.‏\hadithno{6516}\hadithtrans{Nawwas b. Sam'an al-Ansari reported:I asked Allah's Messenger (ﷺ) about virtue and vice. He said: Virtue is a kind disposition and vice is what rankles in your heart and that you disapprove that people should come to know of it}}
\hadithdefcmd{muslim}{6517}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي مُعَاوِيَةُ، - يَعْنِي ابْنَ صَالِحٍ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنْ نَوَّاسِ بْنِ سِمْعَانَ، قَالَ أَقَمْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْمَدِينَةِ سَنَةً مَا يَمْنَعُنِي مِنَ الْهِجْرَةِ إِلاَّ الْمَسْأَلَةُ كَانَ أَحَدُنَا إِذَا هَاجَرَ لَمْ يَسْأَلْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ شَىْءٍ - قَالَ - فَسَأَلْتُهُ عَنِ الْبِرِّ وَالإِثْمِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبِرُّ حُسْنُ الْخُلُقِ وَالإِثْمُ مَا حَاكَ فِي نَفْسِكَ وَكَرِهْتَ أَنْ يَطَّلِعَ عَلَيْهِ النَّاسُ ‏"‏ ‏.‏\hadithno{6517}\hadithtrans{Nawwas b. Sam'an reported:I stayed with Allah's Messenger (ﷺ) for one year. What obstructed me to migrate was (nothing) but (persistent) inquiries from him (about Islam). (It was a common observation) that when anyone of us migrated (to Medina) he ceased to ask (too many questions) from Allah's Messenger (ﷺ). So I asked him about virtue and vice. Thereupon Allah's Messenger (ﷺ) said: Virtue is a kind disposition and vice is what rankles in your mind and that you disapprove of its being known to the people}}
\hadithdefcmd{muslim}{6518}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدِ بْنِ جَمِيلِ بْنِ طَرِيفِ بْنِ عَبْدِ اللَّهِ الثَّقَفِيُّ، وَمُحَمَّدُ بْنُ عَبَّادٍ، قَالاَ حَدَّثَنَا حَاتِمٌ، - وَهُوَ ابْنُ إِسْمَاعِيلَ - عَنْ مُعَاوِيَةَ، - وَهُوَ ابْنُ أَبِي مُزَرِّدٍ مَوْلَى بَنِي هَاشِمٍ - حَدَّثَنِي عَمِّي أَبُو الْحُبَابِ، سَعِيدُ بْنُ يَسَارٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ خَلَقَ الْخَلْقَ حَتَّى إِذَا فَرَغَ مِنْهُمْ قَامَتِ الرَّحِمُ فَقَالَتْ هَذَا مَقَامُ الْعَائِذِ مِنَ الْقَطِيعَةِ ‏.‏ قَالَ نَعَمْ أَمَا تَرْضَيْنَ أَنْ أَصِلَ مَنْ وَصَلَكِ وَأَقْطَعَ مَنْ قَطَعَكِ قَالَتْ بَلَى ‏.‏ قَالَ فَذَاكَ لَكِ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَءُوا إِنْ شِئْتُمْ ‏\{‏ فَهَلْ عَسَيْتُمْ إِنْ تَوَلَّيْتُمْ أَنْ تُفْسِدُوا فِي الأَرْضِ وَتُقَطِّعُوا أَرْحَامَكُمْ * أُولَئِكَ الَّذِينَ لَعَنَهُمُ اللَّهُ فَأَصَمَّهُمْ وَأَعْمَى أَبْصَارَهُمْ * أَفَلاَ يَتَدَبَّرُونَ الْقُرْآنَ أَمْ عَلَى قُلُوبٍ أَقْفَالُهَا‏\}‏ ‏"‏ ‏.‏\hadithno{6518}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said:Verily Allah created the universe and when He had finished that, ties of relationship came forward and said This is the place for him who seeks refuge from severing (of blood-relationship). He said: Yes. Are you not satisfied that I should keep relationship with one who joins your ties of relationship and sever it with one who severs your (ties of relationship)? They (the ties of blood) said: Certainly so. Thereupon He said: Well, that is how things are for you. Allah's Messenger (ﷺ) then said: Recite if you like:" But if you turn away you are sure to make mischief in the land and cut off the ties of kinship. Those it is whom Allah has cursed, so He has made them deaf and blinded their eyes. Do they not reflect on the Qur'an? Or, are there locks on their hearts?}}
\hadithdefcmd{muslim}{6519}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ مُعَاوِيَةَ بْنِ أَبِي مُزَرِّدٍ، عَنْ يَزِيدَ بْنِ رُومَانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الرَّحِمُ مُعَلَّقَةٌ بِالْعَرْشِ تَقُولُ مَنْ وَصَلَنِي وَصَلَهُ اللَّهُ وَمَنْ قَطَعَنِي قَطَعَهُ اللَّهُ ‏"‏ ‏.‏\hadithno{6519}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) as saying:The tie of kinship is suspended to the Throne and says: He who unites me Allah would unite him and he who severed me Allah would sever him}}
\hadithdefcmd{muslim}{6520}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ مُحَمَّدِ، بْنِ جُبَيْرِ بْنِ مُطْعِمٍ عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ قَاطِعٌ ‏"‏ ‏.‏ قَالَ ابْنُ أَبِي عُمَرَ قَالَ سُفْيَانُ يَعْنِي قَاطِعَ رَحِمٍ ‏.‏\hadithno{6520}\hadithtrans{Jubair b. Mut'im reported on the authority of his father that Allah's Messenger (ﷺ) said:The severer would not enter Paradise. Ibn Umar said that Sufyan (explained it as): One who severs the tie of kinship would not enter Paradise}}
\hadithdefcmd{muslim}{6521}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ الضُّبَعِيُّ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، أَنَّ مُحَمَّدَ بْنَ جُبَيْرِ بْنِ مُطْعِمٍ، أَخْبَرَهُ أَنَّ أَبَاهُ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَدْخُلُ الْجَنَّةَ قَاطِعُ رَحِمٍ ‏"‏ ‏.‏\hadithno{6521}\hadithtrans{Jubair b. Mutlim reported that his father narrated to him that Allah's Messenger (ﷺ) said:The severer of the tie of kinship would not get into Paradise}}
\hadithdefcmd{muslim}{6522}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، عَنْ عَبْدِ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ وَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{6522}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{6523}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ سَرَّهُ أَنْ يُبْسَطَ عَلَيْهِ رِزْقُهُ أَوْ يُنْسَأَ فِي أَثَرِهِ فَلْيَصِلْ رَحِمَهُ ‏"‏ ‏.‏\hadithno{6523}\hadithtrans{Anas b. Malik reported:I heard Allah's Messenger (ﷺ) as saying: He who is desirous that his means of sustenance should be expanded for him or his age may be lengthened, should join the tie of relationship}}
\hadithdefcmd{muslim}{6524}{وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ، خَالِدٍ قَالَ قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَحَبَّ أَنْ يُبْسَطَ لَهُ فِي رِزْقِهِ وَيُنْسَأَ لَهُ فِي أَثَرِهِ فَلْيَصِلْ رَحِمَهُ ‏"‏ ‏.‏\hadithno{6524}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said:He who likes that his sustenance should be expanded and his age may be lengthened should join the tie of kinship}}
\hadithdefcmd{muslim}{6525}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ الْعَلاَءَ بْنَ عَبْدِ الرَّحْمَنِ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ أَبِي، هُرَيْرَةَ أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ إِنَّ لِي قَرَابَةً أَصِلُهُمْ وَيَقْطَعُونِي وَأُحْسِنُ إِلَيْهِمْ وَيُسِيئُونَ إِلَىَّ وَأَحْلُمُ عَنْهُمْ وَيَجْهَلُونَ عَلَىَّ ‏.‏ فَقَالَ ‏ "‏ لَئِنْ كُنْتَ كَمَا قُلْتَ فَكَأَنَّمَا تُسِفُّهُمُ الْمَلَّ وَلاَ يَزَالُ مَعَكَ مِنَ اللَّهِ ظَهِيرٌ عَلَيْهِمْ مَا دُمْتَ عَلَى ذَلِكَ ‏"‏ ‏.‏\hadithno{6525}\hadithtrans{Abu Huraira reported that a person said:Allah's Messenger, I have relatives with whom I try, to have close relationship, but they sever (this relation). I treat them well, but they treat me ill. I am sweet to them but they are harsh towards me. Upon this he (the Holy Prophet) said: If it is so as you say, then you in fact throw hot ashes (upon their faces) and there would always remain with you on behalf of Allah (an Angel to support you) who would keep you dominant over them so long as you adhere to this (path of righteousness)}}
\hadithdefcmd{muslim}{6526}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَبَاغَضُوا وَلاَ تَحَاسَدُوا وَلاَ تَدَابَرُوا وَكُونُوا عِبَادَ اللَّهِ إِخْوَانًا وَلاَ يَحِلُّ لِمُسْلِمٍ أَنْ يَهْجُرَ أَخَاهُ فَوْقَ ثَلاَثٍ ‏"‏ ‏.‏\hadithno{6526}\hadithtrans{Anas b. Malik reported Allah's Messenger (ﷺ) as saying:Neither nurse mutual hatred, nor jealousy, nor enmity, and become as fellow brothers and servants of Allah. It is not lawful for a Muslim that he should keep his relations estranged with his brother beyond three days}}
\hadithdefcmd{muslim}{6530}{حَدَّثَنَا حَاجِبُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ الزُّبَيْدِيُّ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ح وَحَدَّثَنِيهِ حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ مَالِكٍ ‏.‏\hadithno{6530}\hadithtrans{Anas b. Malik reported Allah's Messenger (ﷺ) as saying like this. This hadith has been narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{6531}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ أَبِي عُمَرَ، وَعَمْرٌو النَّاقِدُ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ وَزَادَ ابْنُ عُيَيْنَةَ ‏ "‏ وَلاَ تَقَاطَعُوا ‏"‏ ‏.‏\hadithno{6531}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters with the addition of Ibn Uyaina (and the words are):" Do not cut off (mutual relations)}}
\hadithdefcmd{muslim}{6532}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ، اللَّيْثِيِّ عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لِمُسْلِمٍ أَنْ يَهْجُرَ أَخَاهُ فَوْقَ ثَلاَثِ لَيَالٍ يَلْتَقِيَانِ فَيُعْرِضُ هَذَا وَيُعْرِضُ هَذَا وَخَيْرُهُمَا الَّذِي يَبْدَأُ بِالسَّلاَمِ ‏"‏ ‏.‏\hadithno{6532}\hadithtrans{Abu Ayyub Ansiri reported Allah's Messenger (ﷺ) as saying:It is not permissible for a Muslim to have estranged relations with his brother beyond three nights, the one turning one way and the other turning the other way when they meet; the better of the two is one who is the first to give a greeting}}
\hadithdefcmd{muslim}{6533}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ قَالُوا حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا حَاجِبُ، بْنُ الْوَلِيدِ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَمُحَمَّدُ، بْنُ رَافِعٍ وَعَبْدُ بْنُ حُمَيْدٍ عَنْ عَبْدِ الرَّزَّاقِ، عَنْ مَعْمَرٍ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِإِسْنَادِ مَالِكٍ وَمِثْلِ حَدِيثِهِ إِلاَّ قَوْلَهُ ‏"‏ فَيُعْرِضُ هَذَا وَيُعْرِضُ هَذَا ‏"‏ ‏.‏ فَإِنَّهُمْ جَمِيعًا قَالُوا فِي حَدِيثِهِمْ غَيْرَ مَالِكٍ ‏"‏ فَيَصُدُّ هَذَا وَيَصُدُّ هَذَا ‏"‏ ‏.‏\hadithno{6533}\hadithtrans{This hadith has been transmitted on the authority of Zuhri with a slight variation of wording (and the words are):" The one turning away and the other turning away when they meet and one avoids the other and the other also avoids him}}
\hadithdefcmd{muslim}{6534}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، - وَهُوَ ابْنُ عُثْمَانَ - عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَحِلُّ لِلْمُؤْمِنِ أَنْ يَهْجُرَ أَخَاهُ فَوْقَ ثَلاَثَةِ أَيَّامٍ ‏"‏ ‏.‏\hadithno{6534}\hadithtrans{Abdullah b. 'Umar reported Allah's Messenger (ﷺ) as saying:It is not permissible for a Muslim to have estranged relations with his brother beyond three days}}
\hadithdefcmd{muslim}{6535}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ هِجْرَةَ بَعْدَ ثَلاَثٍ ‏"‏ ‏.‏\hadithno{6535}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There should be no estranged relations beyond three days}}
\hadithdefcmd{muslim}{6536}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِيَّاكُمْ وَالظَّنَّ فَإِنَّ الظَّنَّ أَكْذَبُ الْحَدِيثِ وَلاَ تَحَسَّسُوا وَلاَ تَجَسَّسُوا وَلاَ تَنَافَسُوا وَلاَ تَحَاسَدُوا وَلاَ تَبَاغَضُوا وَلاَ تَدَابَرُوا وَكُونُوا عِبَادَ اللَّهِ إِخْوَانًا ‏"‏ ‏.‏\hadithno{6536}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Avoid suspicion, for suspicion is the gravest lie in talk and do not be inquisitive about one another and do not spy upon one another and do not feel envy with the other, and nurse no malice, and nurse no aversion and hostility against one another. And be fellow-brothers and servants of Allah}}
\hadithdefcmd{muslim}{6537}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَهَجَّرُوا وَلاَ تَدَابَرُوا وَلاَ تَحَسَّسُوا وَلاَ يَبِعْ بَعْضُكُمْ عَلَى بَيْعِ بَعْضٍ وَكُونُوا عِبَادَ اللَّهِ إِخْوَانًا ‏"‏ ‏.‏\hadithno{6537}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Don't have estranged relations (with the others) and don't nurse enmity and don't enter into a transaction when the other (has already entered) and be fellow-brothers and servants of Allah}}
\hadithdefcmd{muslim}{6538}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي، هُرَيْرَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَحَاسَدُوا وَلاَ تَبَاغَضُوا وَلاَ تَجَسَّسُوا وَلاَ تَحَسَّسُوا وَلاَ تَنَاجَشُوا وَكُونُوا عِبَادَ اللَّهِ إِخْوَانًا ‏"‏ ‏.‏\hadithno{6538}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying. Don't nurse malice against one another, don't nurse aversion against one another and don't be inquisitive about one another and don't outbid one another (with a view to raising the price) and be fellow-brothers and servants of Allah}}
\hadithdefcmd{muslim}{6539}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَعَلِيُّ بْنُ نَصْرٍ الْجَهْضَمِيُّ، قَالاَ حَدَّثَنَا وَهْبُ، بْنُ جَرِيرٍ حَدَّثَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏ "‏ لاَ تَقَاطَعُوا وَلاَ تَدَابَرُوا وَلاَ تَبَاغَضُوا وَلاَ تَحَاسَدُوا وَكُونُوا إِخْوَانًا كَمَا أَمَرَكُمُ اللَّهُ ‏"‏ ‏.‏\hadithno{6539}\hadithtrans{This hadith has been narrated on the authority of A'mash with the same chain of transmit ters (and the words are):" Don't sever relations of kinship, don't bear enmity against one another, don't bear aversion against one another and don't feel envy against the other and live as fellow-brothers as Allah has commanded you}}
\hadithdefcmd{muslim}{6540}{وَحَدَّثَنِي أَحْمَدُ بْنُ سَعِيدٍ الدَّارِمِيُّ، حَدَّثَنَا حَبَّانُ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَبَاغَضُوا وَلاَ تَدَابَرُوا وَلاَ تَنَافَسُوا وَكُونُوا عِبَادَ اللَّهِ إِخْوَانًا ‏"‏ ‏.‏\hadithno{6540}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Don't bear aversion against one another and don't be jealous of one another and be servants of Allah}}
\hadithdefcmd{muslim}{6541}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا دَاوُدُ، - يَعْنِي ابْنَ قَيْسٍ - عَنْ أَبِي، سَعِيدٍ مَوْلَى عَامِرِ بْنِ كُرَيْزٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَحَاسَدُوا وَلاَ تَنَاجَشُوا وَلاَ تَبَاغَضُوا وَلاَ تَدَابَرُوا وَلاَ يَبِعْ بَعْضُكُمْ عَلَى بَيْعِ بَعْضٍ وَكُونُوا عِبَادَ اللَّهِ إِخْوَانًا ‏.‏ الْمُسْلِمُ أَخُو الْمُسْلِمِ لاَ يَظْلِمُهُ وَلاَ يَخْذُلُهُ وَلاَ يَحْقِرُهُ ‏.‏ التَّقْوَى هَا هُنَا ‏"‏ ‏.‏ وَيُشِيرُ إِلَى صَدْرِهِ ثَلاَثَ مَرَّاتٍ ‏"‏ بِحَسْبِ امْرِئٍ مِنَ الشَّرِّ أَنْ يَحْقِرَ أَخَاهُ الْمُسْلِمَ كُلُّ الْمُسْلِمِ عَلَى الْمُسْلِمِ حَرَامٌ دَمُهُ وَمَالُهُ وَعِرْضُهُ ‏"‏ ‏.‏\hadithno{6541}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Don't nurse grudge and don't bid him out for raising the price and don't nurse aversion or enmity and don't enter into a transaction when the others have entered into that transaction and be as fellow-brothers and servants of Allah. A Muslim is the brother of a Muslim. He neither oppresses him nor humiliates him nor looks down upon him. The piety is here, (and while saying so) he pointed towards his chest thrice. It is a serious evil for a Muslim that he should look down upon his brother Muslim. All things of a Muslim are inviolable for his brother in faith: his blood, his wealth and his honour}}
\hadithdefcmd{muslim}{6542}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ أُسَامَةَ، - وَهُوَ ابْنُ زَيْدٍ - أَنَّهُ سَمِعَ أَبَا سَعِيدٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ كُرَيْزٍ يَقُولُ سَمِعْتُ أَبَا، هُرَيْرَةَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ دَاوُدَ وَزَادَ وَنَقَصَ وَمِمَّا زَادَ فِيهِ ‏ "‏ إِنَّ اللَّهَ لاَ يَنْظُرُ إِلَى أَجْسَادِكُمْ وَلاَ إِلَى صُوَرِكُمْ وَلَكِنْ يَنْظُرُ إِلَى قُلُوبِكُمْ ‏"‏ ‏.‏ وَأَشَارَ بِأَصَابِعِهِ إِلَى صَدْرِهِ ‏.‏\hadithno{6542}\hadithtrans{This hadith has been transmitted on the authority of Abu Huraira with some addition (and it is this):" Verily Allah does not look to your bodies nor to your faces but He looks to your hearts," and he pointed towards the heart with his fingers}}
\hadithdefcmd{muslim}{6543}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا كَثِيرُ بْنُ هِشَامٍ، حَدَّثَنَا جَعْفَرُ بْنُ بُرْقَانَ، عَنْ يَزِيدَ بْنِ، الأَصَمِّ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ لاَ يَنْظُرُ إِلَى صُوَرِكُمْ وَأَمْوَالِكُمْ وَلَكِنْ يَنْظُرُ إِلَى قُلُوبِكُمْ وَأَعْمَالِكُمْ ‏"‏ ‏.‏\hadithno{6543}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Verily Allah does not look to your faces and your wealth but He looks to your heart and to your deeds}}
\hadithdefcmd{muslim}{6546}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ مُسْلِمِ بْنِ أَبِي مَرْيَمَ، عَنْ أَبِي صَالِحٍ، سَمِعَ أَبَا هُرَيْرَةَ، رَفَعَهُ مَرَّةً قَالَ ‏ "‏ تُعْرَضُ الأَعْمَالُ فِي كُلِّ يَوْمِ خَمِيسٍ وَاثْنَيْنِ فَيَغْفِرُ اللَّهُ عَزَّ وَجَلَّ فِي ذَلِكَ الْيَوْمِ لِكُلِّ امْرِئٍ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا إِلاَّ امْرَأً كَانَتْ بَيْنَهُ وَبَيْنَ أَخِيهِ شَحْنَاءُ فَيُقَالُ ارْكُوا هَذَيْنِ حَتَّى يَصْطَلِحَا ارْكُوا هَذَيْنِ حَتَّى يَصْطَلِحَا ‏"‏ ‏.‏\hadithno{6546}\hadithtrans{Abu Huraira reported it as a marfu' hadith (and the words are):The deeds are presented on every Thursday and Monday and Allah, the Exalted and Glorious. grants pardon to every person who does not associate anything with Allah except the person in whose (heart) there is rancour against his brother. It would be said: Put both of them off until they are reconciled}}
\hadithdefcmd{muslim}{6547}{حَدَّثَنَا أَبُو الطَّاهِرِ، وَعَمْرُو بْنُ سَوَّادٍ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا مَالِكُ بْنُ، أَنَسٍ عَنْ مُسْلِمِ بْنِ أَبِي مَرْيَمَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تُعْرَضُ أَعْمَالُ النَّاسِ فِي كُلِّ جُمُعَةٍ مَرَّتَيْنِ يَوْمَ الاِثْنَيْنِ وَيَوْمَ الْخَمِيسِ فَيُغْفَرُ لِكُلِّ عَبْدٍ مُؤْمِنٍ إِلاَّ عَبْدًا بَيْنَهُ وَبَيْنَ أَخِيهِ شَحْنَاءُ فَيُقَالُ اتْرُكُوا - أَوِ ارْكُوا - هَذَيْنِ حَتَّى يَفِيئَا ‏"‏ ‏.‏\hadithno{6547}\hadithtrans{Abu Huraim reported Allah's Messenger (ﷺ) as saying The deeds of people would be presented every week on two days, viz. Monday and Thursday, and every believing servant would be granted pardon except the one in whose (heart) there is rancour against his brother and it would he said:Leave them and put them off until they are turned to reconciliation}}
\hadithdefcmd{muslim}{6548}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ، الرَّحْمَنِ بْنِ مَعْمَرٍ عَنْ أَبِي الْحُبَابِ، سَعِيدِ بْنِ يَسَارٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يَقُولُ يَوْمَ الْقِيَامَةِ أَيْنَ الْمُتَحَابُّونَ بِجَلاَلِي الْيَوْمَ أُظِلُّهُمْ فِي ظِلِّي يَوْمَ لاَ ظِلَّ إِلاَّ ظِلِّي ‏"‏ ‏.‏\hadithno{6548}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Verily. Allah would say on the Day of Resurrection: Where are those who have mutual love for My Glory's sake? Today I shall shelter them in My shadow when there is no other shadow but the shadow of Mine}}
\hadithdefcmd{muslim}{6549}{حَدَّثَنِي عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ أَنَّ رَجُلاً زَارَ أَخًا لَهُ فِي قَرْيَةٍ أُخْرَى فَأَرْصَدَ اللَّهُ لَهُ عَلَى مَدْرَجَتِهِ مَلَكًا فَلَمَّا أَتَى عَلَيْهِ قَالَ أَيْنَ تُرِيدُ قَالَ أُرِيدُ أَخًا لِي فِي هَذِهِ الْقَرْيَةِ ‏.‏ قَالَ هَلْ لَكَ عَلَيْهِ مِنْ نِعْمَةٍ تَرُبُّهَا قَالَ لاَ غَيْرَ أَنِّي أَحْبَبْتُهُ فِي اللَّهِ عَزَّ وَجَلَّ ‏.‏ قَالَ فَإِنِّي رَسُولُ اللَّهِ إِلَيْكَ بِأَنَّ اللَّهَ قَدْ أَحَبَّكَ كَمَا أَحْبَبْتَهُ فِيهِ ‏"‏ ‏.‏\hadithno{6549}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:A person visited his brother in another town and Allah deputed an Angel to wait for him on his way and when he came to him he said: Where do you intend to go? He said: I intend to go to my brother in this town. He said: Have you done any favour to him (the repayment of which you intend to get)? He said: No, excepting this that I love Mm for the sake of Allah, the Exalted and Glorious. Thereupon he said: I am a meesenger to you from, Allah: (to inform you) that Allah loves you as you love him (for His sake)}}
\hadithdefcmd{muslim}{6550}{قَالَ الشَّيْخُ أَبُو أَحْمَدَ أَخْبَرَنِي أَبُو بَكْرٍ، مُحَمَّدُ بْنُ زَنْجُويَهْ الْقُشَيْرِيُّ حَدَّثَنَا عَبْدُ، الأَعْلَى بْنُ حَمَّادٍ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{6550}\hadithtrans{This hadith has been narrated on the authority of Hammid b. Salama with the same of transmitters}}
\hadithdefcmd{muslim}{6551}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَأَبُو الرَّبِيعِ الزَّهْرَانِيُّ، قَالاَ حَدَّثَنَا حَمَّادٌ، - يَعْنِيَانِ ابْنَ زَيْدٍ - عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ، عَنْ ثَوْبَانَ، قَالَ أَبُو الرَّبِيعِ رَفَعَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَفِي حَدِيثِ سَعِيدٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَائِدُ الْمَرِيضِ فِي مَخْرَفَةِ الْجَنَّةِ حَتَّى يَرْجِعَ ‏"‏ ‏.‏\hadithno{6551}\hadithtrans{Abu Rabi' reported directly from Allah's Apostle (may peace upon him) as saying:The one who visits the sick is in fact like one who is in the fruit garden of Paradise so long as he does not return}}
\hadithdefcmd{muslim}{6552}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا هُشَيْمٌ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي، أَسْمَاءَ عَنْ ثَوْبَانَ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ عَادَ مَرِيضًا لَمْ يَزَلْ فِي خُرْفَةِ الْجَنَّةِ حَتَّى يَرْجِعَ ‏"‏ ‏.‏\hadithno{6552}\hadithtrans{Thauban, the freed slave of Allah's Messenger (ﷺ), reported that Allah's Messenger (ﷺ) said:He who visits the sick continues to remain in the fruit garden of Paradise until he returns}}
\hadithdefcmd{muslim}{6553}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ الرَّحَبِيِّ، عَنْ ثَوْبَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْمُسْلِمَ إِذَا عَادَ أَخَاهُ الْمُسْلِمَ لَمْ يَزَلْ فِي خُرْفَةِ الْجَنَّةِ حَتَّى يَرْجِعَ ‏"‏ ‏.‏\hadithno{6553}\hadithtrans{Thauban reported Allah's Apostle (ﷺ) as saying:Verily, when a Muslim visits his brother in Islam he is supposed to remain in the fruit garden of Paradise until he returns}}
\hadithdefcmd{muslim}{6554}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنْ يَزِيدَ، - وَاللَّفْظُ لِزُهَيْرٍ - حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا عَاصِمٌ الأَحْوَلُ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، - وَهُوَ أَبُو قِلاَبَةَ - عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، عَنْ أَبِي أَسْمَاءَ الرَّحَبِيِّ، عَنْ ثَوْبَانَ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ عَادَ مَرِيضًا لَمْ يَزَلْ فِي خُرْفَةِ الْجَنَّةِ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ وَمَا خُرْفَةُ الْجَنَّةِ قَالَ ‏"‏ جَنَاهَا ‏"‏ ‏.‏\hadithno{6554}\hadithtrans{Thauban, the freed slave of Allah's Messenger (ﷺ), reported Allah's Messenger (ﷺ) as saying:He who visits the sick is supposed to remain in the fruit garden of Paradise. It was said: Allah's Messenger, what is this Khurfat-ul-jannah? He said: It is a place abounding in fruits}}
\hadithdefcmd{muslim}{6555}{حَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6555}\hadithtrans{This hadith has been narrated on the authority of Asim al-Ahwal with the same chain of transmitters}}
\hadithdefcmd{muslim}{6556}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَقُولُ يَوْمَ الْقِيَامَةِ يَا ابْنَ آدَمَ مَرِضْتُ فَلَمْ تَعُدْنِي ‏.‏ قَالَ يَا رَبِّ كَيْفَ أَعُودُكَ وَأَنْتَ رَبُّ الْعَالَمِينَ ‏.‏ قَالَ أَمَا عَلِمْتَ أَنَّ عَبْدِي فُلاَنًا مَرِضَ فَلَمْ تَعُدْهُ أَمَا عَلِمْتَ أَنَّكَ لَوْ عُدْتَهُ لَوَجَدْتَنِي عِنْدَهُ يَا ابْنَ آدَمَ اسْتَطْعَمْتُكَ فَلَمْ تُطْعِمْنِي ‏.‏ قَالَ يَا رَبِّ وَكَيْفَ أُطْعِمُكَ وَأَنْتَ رَبُّ الْعَالَمِينَ ‏.‏ قَالَ أَمَا عَلِمْتَ أَنَّهُ اسْتَطْعَمَكَ عَبْدِي فُلاَنٌ فَلَمْ تُطْعِمْهُ أَمَا عَلِمْتَ أَنَّكَ لَوْ أَطْعَمْتَهُ لَوَجَدْتَ ذَلِكَ عِنْدِي يَا ابْنَ آدَمَ اسْتَسْقَيْتُكَ فَلَمْ تَسْقِنِي ‏.‏ قَالَ يَا رَبِّ كَيْفَ أَسْقِيكَ وَأَنْتَ رَبُّ الْعَالَمِينَ قَالَ اسْتَسْقَاكَ عَبْدِي فُلاَنٌ فَلَمْ تَسْقِهِ أَمَا إِنَّكَ لَوْ سَقَيْتَهُ وَجَدْتَ ذَلِكَ عِنْدِي ‏"‏ ‏.‏\hadithno{6556}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Verily, Allah, the Exalted and Glorious, would say on the Day of Resurrection: O son of Adam, I was sick but you did not visit Me. He would say: O my Lord; how could I visit Thee whereas Thou art the Lord of the worlds? Thereupon He would say: Didn't you know that such and such servant of Mine was sick but you did not visit him and were you not aware of this that if you had visited him, you would have found Me by him? O son of Adam, I asked food from you but you did not feed Me. He would say: My Lord, how could I feed Thee whereas Thou art the Lord of the worlds? He said: Didn't you know that such and such servant of Mine asked food from you but you did not feed him, and were you not aware that if you had fed him you would have found him by My side? (The Lord would again say: ) O son of Adam, I asked drink from you but you did not provide Me. He would say: My Lord, how could I provide Thee whereas Thou art the Lord of the worlds? Thereupon He would say: Such and such of servant of Mine asked you for a drink but you did not provide him, and had you provided him drink you would have found him near Me}}
\hadithdefcmd{muslim}{6557}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، عُثْمَانُ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، قَالَ قَالَتْ عَائِشَةُ مَا رَأَيْتُ رَجُلاً أَشَدَّ عَلَيْهِ الْوَجَعُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ وَفِي رِوَايَةِ عُثْمَانَ مَكَانَ الْوَجَعِ وَجَعًا ‏.‏\hadithno{6557}\hadithtrans{A'isha reported, I did not see anyone else being afflicted with more severe illness than Allah's Messenger (ﷺ). In the narration transmitted by 'Uthman there is a slight variation of wording}}
\hadithdefcmd{muslim}{6558}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، أَخْبَرَنِي أَبِي ح، وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، ح وَحَدَّثَنِي بِشْرُ بْنُ خَالِدٍ، أَخْبَرَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - كُلُّهُمْ عَنْ شُعْبَةَ، عَنِ الأَعْمَشِ، ح وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، ح وَحَدَّثَنَا ابْنُ، نُمَيْرٍ حَدَّثَنَا مُصْعَبُ بْنُ الْمِقْدَامِ، كِلاَهُمَا عَنْ سُفْيَانَ، عَنِ الأَعْمَشِ، بِإِسْنَادِ جَرِيرٍ مِثْلَ حَدِيثِهِ ‏.‏\hadithno{6558}\hadithtrans{This hadith has been narrated on the authority of A'mash through other chains of transmitters}}
\hadithdefcmd{muslim}{6559}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنِ الْحَارِثِ بْنِ سُوَيْدٍ، عَنْ عَبْدِ اللَّهِ، قَالَ دَخَلْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يُوعَكُ فَمَسِسْتُهُ بِيَدِي فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّكَ لَتُوعَكُ وَعْكًا شَدِيدًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَجَلْ إِنِّي أُوعَكُ كَمَا يُوعَكُ رَجُلاَنِ مِنْكُمْ ‏"‏ ‏.‏ قَالَ فَقُلْتُ ذَلِكَ أَنَّ لَكَ أَجْرَيْنِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَجَلْ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ مُسْلِمٍ يُصِيبُهُ أَذًى مِنْ مَرَضٍ فَمَا سِوَاهُ إِلاَّ حَطَّ اللَّهُ بِهِ سَيِّئَاتِهِ كَمَا تَحُطُّ الشَّجَرَةُ وَرَقَهَا ‏"‏ ‏.‏ وَلَيْسَ فِي حَدِيثِ زُهَيْرٍ فَمَسِسْتُهُ بِيَدِي ‏.‏\hadithno{6559}\hadithtrans{Abdullah reported:I visited Allah's Messenger (ﷺ) as he was running a high temperature. I touched his body with my hand and said to him: Allah's Messenger, you are running a high temperature, whereupon Allah's Messenger (ﷺ) said: Yes, it is so. I comparatively have a more severe fever than any one of you. I said: Is it because there is a double reward in store for you? Thereupon Allah's Messenger (ﷺ) said: Yes, it is so. And Allah's Messenger (ﷺ) again said: When a Muslim falls ill, his compensation is that his minor sins are obliterated just as leaves fall (in autumn). In the hadith transmitted on the authority of Zubair there is (no mention of these words):" I touched his body with my hands}}
\hadithdefcmd{muslim}{6560}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، وَيَحْيَى بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي غَنِيَّةَ، كُلُّهُمْ عَنِ الأَعْمَشِ، بِإِسْنَادِ جَرِيرٍ ‏.‏ نَحْوَ حَدِيثِهِ وَزَادَ فِي حَدِيثِ أَبِي مُعَاوِيَةَ قَالَ ‏ "‏ نَعَمْ وَالَّذِي نَفْسِي بِيَدِهِ مَا عَلَى الأَرْضِ مُسْلِمٌ ‏"‏ ‏.‏\hadithno{6560}\hadithtrans{This hadith has been transmitted on the authority of jarir and the hadith transmitted on the authority of Abu Mu'awiya there is an addition of these words:He said: Yes, by Him in Whose Hand is my life, there is no Muslim upon the earth." The rest of the hadith is the same}}
\hadithdefcmd{muslim}{6561}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنْ جَرِيرٍ، قَالَ زُهَيْرٌ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، قَالَ دَخَلَ شَبَابٌ مِنْ قُرَيْشٍ عَلَى عَائِشَةَ وَهِيَ بِمِنًى وَهُمْ يَضْحَكُونَ فَقَالَتْ مَا يُضْحِكُكُمْ قَالُوا فُلاَنٌ خَرَّ عَلَى طُنُبِ فُسْطَاطٍ فَكَادَتْ عُنُقُهُ أَوْ عَيْنُهُ أَنْ تَذْهَبَ ‏.‏ فَقَالَتْ لاَ تَضْحَكُوا فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ مُسْلِمٍ يُشَاكُ شَوْكَةً فَمَا فَوْقَهَا إِلاَّ كُتِبَتْ لَهُ بِهَا دَرَجَةٌ وَمُحِيَتْ عَنْهُ بِهَا خَطِيئَةٌ ‏"‏ ‏.‏\hadithno{6561}\hadithtrans{Aswad reported that some young men from the Quraish visited 'A'isha as she was in Mina and they were laughing. She said:What makes you laugh? They said: Such and such person stumbled against the rope of the tent and he was about to break his neck or lose his eyes. She said: Don't laugh for I heard Allah's Messenger (ﷺ) as saying: If a Muslim runs a thorn or (gets into trouble) severe than this, there is assured for him (a higher) rank and his sins are obliterated}}
\hadithdefcmd{muslim}{6562}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَاللَّفْظُ لَهُمَا ح وَحَدَّثَنَا إِسْحَاقُ الْحَنْظَلِيُّ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا يُصِيبُ الْمُؤْمِنَ مِنْ شَوْكَةٍ فَمَا فَوْقَهَا إِلاَّ رَفَعَهُ اللَّهُ بِهَا دَرَجَةً أَوْ حَطَّ عَنْهُ بِهَا خَطِيئَةً ‏"‏ ‏.‏\hadithno{6562}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) as saying:A believer does not receive (the trouble) of running a thorn or more than that but Allah elevates him in rank or effaces his sins because of that}}
\hadithdefcmd{muslim}{6563}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُصِيبُ الْمُؤْمِنَ شَوْكَةٌ فَمَا فَوْقَهَا إِلاَّ قَصَّ اللَّهُ بِهَا مِنْ خَطِيئَتِهِ ‏"‏ ‏.‏\hadithno{6563}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) as saying:A believer does not undergo (the trouble) of running a thorn or more than that when Allah effaces his sins}}
\hadithdefcmd{muslim}{6564}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا هِشَامٌ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6564}\hadithtrans{The above hadith has been transmitted by Hisham with the same chain}}
\hadithdefcmd{muslim}{6565}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكُ بْنُ أَنَسٍ، وَيُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ مُصِيبَةٍ يُصَابُ بِهَا الْمُسْلِمُ إِلاَّ كُفِّرَ بِهَا عَنْهُ حَتَّى الشَّوْكَةِ يُشَاكُهَا ‏"‏ ‏.‏\hadithno{6565}\hadithtrans{A'isha reported:Allah's Messenger (ﷺ) said: There is no trouble that comes to a believer except that it obliterates from his sins, even if it is the pricking of a thorn}}
\hadithdefcmd{muslim}{6566}{حَدَّثَنَا أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُصِيبُ الْمُؤْمِنَ مِنْ مُصِيبَةٍ حَتَّى الشَّوْكَةِ إِلاَّ قُصَّ بِهَا مِنْ خَطَايَاهُ أَوْ كُفِّرَ بِهَا مِنْ خَطَايَاهُ ‏"‏ ‏.‏ لاَ يَدْرِي يَزِيدُ أَيَّتُهُمَا قَالَ عُرْوَةُ ‏.‏\hadithno{6566}\hadithtrans{A'isha said:No trouble comes to a believer even if it is the pricking of a thorn that it becomes (the means) whereby his sins are effaced or his sins are obliterated. Yazid says: He does not know which word 'Urwa said (whether he said Qussa or Kuffira)}}
\hadithdefcmd{muslim}{6567}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنَا حَيْوَةُ، حَدَّثَنَا ابْنُ الْهَادِ، عَنْ أَبِي بَكْرِ بْنِ حَزْمٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ شَىْءٍ يُصِيبُ الْمُؤْمِنَ حَتَّى الشَّوْكَةِ تُصِيبُهُ إِلاَّ كَتَبَ اللَّهُ لَهُ بِهَا حَسَنَةً أَوْ حُطَّتْ عَنْهُ بِهَا خَطِيئَةٌ ‏"‏ ‏.‏\hadithno{6567}\hadithtrans{A'isha reported:I heard Allah's Messenger (ﷺ) as saying: There is nothing (in the form of trouble) that comes to a believer even if it is the pricking of a thorn that there is decreed for him by Allah good or his sins are obliterated}}
\hadithdefcmd{muslim}{6568}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ، كَثِيرٍ عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ، وَأَبِي، هُرَيْرَةَ أَنَّهُمَا سَمِعَا رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا يُصِيبُ الْمُؤْمِنَ مِنْ وَصَبٍ وَلاَ نَصَبٍ وَلاَ سَقَمٍ وَلاَ حَزَنٍ حَتَّى الْهَمِّ يُهَمُّهُ إِلاَّ كُفِّرَ بِهِ مِنْ سَيِّئَاتِهِ ‏"‏ ‏.‏\hadithno{6568}\hadithtrans{Abu Sa'id and abu Huraira reported that they heard Allah's Messenger (ﷺ) as saying:Never a believer is stricken with discomfort, hardship or illness, grief or even with mental worry that his sins are not expiated for him}}
\hadithdefcmd{muslim}{6569}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ كِلاَهُمَا عَنِ ابْنِ عُيَيْنَةَ، - وَاللَّفْظُ لِقُتَيْبَةَ - حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ مُحَيْصِنٍ، شَيْخٍ مِنْ قُرَيْشٍ سَمِعَ مُحَمَّدَ بْنَ قَيْسِ بْنِ مَخْرَمَةَ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، قَالَ لَمَّا نَزَلَتْ ‏\{‏ مَنْ يَعْمَلْ سُوءًا يُجْزَ بِهِ‏\}‏ بَلَغَتْ مِنَ الْمُسْلِمِينَ مَبْلَغًا شَدِيدًا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَارِبُوا وَسَدِّدُوا فَفِي كُلِّ مَا يُصَابُ بِهِ الْمُسْلِمُ كَفَّارَةٌ حَتَّى النَّكْبَةِ يُنْكَبُهَا أَوِ الشَّوْكَةِ يُشَاكُهَا ‏"‏ ‏.‏ قَالَ مُسْلِمٌ هُوَ عُمَرُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ مُحَيْصِنٍ مِنْ أَهْلِ مَكَّةَ ‏.‏\hadithno{6569}\hadithtrans{Abu Huraira reported that when this verse was revealed:"Whoever does evil will be requited for it", and when this was conveyed to the Muslims they were greatly perturbed. Thereupon Allah's Messenger (ﷺ) said: Be moderate and stand firm in trouble that falls to the lot of a Muslim (as that) is an expiation for him; even stumbling on the path or the pricking of a thorn (are an expiation for him). Muslim said that 'Umar b. Abd al-Rahman Muhaisin was from amongst the people of Mecca}}
\hadithdefcmd{muslim}{6570}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا الْحَجَّاجُ الصَّوَّافُ، حَدَّثَنِي أَبُو الزُّبَيْرِ، حَدَّثَنَا جَابِرُ بْنُ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَلَى أُمِّ السَّائِبِ أَوْ أُمِّ الْمُسَيَّبِ فَقَالَ ‏"‏ مَا لَكِ يَا أُمَّ السَّائِبِ أَوْ يَا أُمَّ الْمُسَيَّبِ تُزَفْزِفِينَ ‏"‏ ‏.‏ قَالَتِ الْحُمَّى لاَ بَارَكَ اللَّهُ فِيهَا ‏.‏ فَقَالَ ‏"‏ لاَ تَسُبِّي الْحُمَّى فَإِنَّهَا تُذْهِبُ خَطَايَا بَنِي آدَمَ كَمَا يُذْهِبُ الْكِيرُ خَبَثَ الْحَدِيدِ ‏"‏ ‏.‏\hadithno{6570}\hadithtrans{Jabir b. Abdullah reported that Allah's Messenger (ﷺ) visited Umm Sa'ib or Umm Musayyib and said:Umm Sa'ib or Umm Musayyib. why is it that you are shivering? She said:" It is fever and may it not be blessed by Allah, whereupon he (the Holy Prophet) said: Don't curse fever for it expiates the sin of the children of Adam just as furnace removes the alloy of iron}}
\hadithdefcmd{muslim}{6571}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَبِشْرُ بْنُ الْمُفَضَّلِ، قَالاَ حَدَّثَنَا عِمْرَانُ أَبُو بَكْرٍ، حَدَّثَنِي عَطَاءُ بْنُ أَبِي رَبَاحٍ، قَالَ قَالَ لِي ابْنُ عَبَّاسٍ أَلاَ أُرِيكَ امْرَأَةً مِنْ أَهْلِ الْجَنَّةِ قُلْتُ بَلَى ‏.‏ قَالَ هَذِهِ الْمَرْأَةُ السَّوْدَاءُ أَتَتِ النَّبِيَّ صلى الله عليه وسلم قَالَتْ إِنِّي أُصْرَعُ وَإِنِّي أَتَكَشَّفُ فَادْعُ اللَّهَ لِي ‏.‏ قَالَ ‏"‏ إِنْ شِئْتِ صَبَرْتِ وَلَكِ الْجَنَّةُ وَإِنْ شِئْتِ دَعَوْتُ اللَّهَ أَنْ يُعَافِيَكِ ‏.‏ قَالَتْ أَصْبِرُ ‏.‏ قَالَتْ فَإِنِّي أَتَكَشَّفُ فَادْعُ اللَّهَ أَنْ لاَ أَتَكَشَّفَ ‏.‏ فَدَعَا لَهَا ‏.‏\hadithno{6571}\hadithtrans{Ata' b. Abi Rabih said:Ibn Abbas said to me: May I show you a woman of Paradise? I said: Yes. He said: Here is this dark-complexioned woman. She came to Allah's Apostle (ﷺ) and said: I am suffering from falling sickness and I become naked; supplicate Allah for me, whereupon he (the Holy Prophet) said: Show endurance as you can do and there would be Paradise for you and, if you desire, I supplicate Allah that He may cure you. She said: I am prepared to show endurance (but the unbearable trouble is) that I become naked, so supplicate Allah that He should not let me become naked, so he supplicated for her}}
\hadithdefcmd{muslim}{6572}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ بَهْرَامَ الدَّارِمِيُّ، حَدَّثَنَا مَرْوَانُ، - يَعْنِي ابْنَ مُحَمَّدٍ الدِّمَشْقِيَّ - حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِيمَا رَوَى عَنِ اللَّهِ، تَبَارَكَ وَتَعَالَى أَنَّهُ قَالَ ‏ "‏ يَا عِبَادِي إِنِّي حَرَّمْتُ الظُّلْمَ عَلَى نَفْسِي وَجَعَلْتُهُ بَيْنَكُمْ مُحَرَّمًا فَلاَ تَظَالَمُوا يَا عِبَادِي كُلُّكُمْ ضَالٌّ إِلاَّ مَنْ هَدَيْتُهُ فَاسْتَهْدُونِي أَهْدِكُمْ يَا عِبَادِي كُلُّكُمْ جَائِعٌ إِلاَّ مَنْ أَطْعَمْتُهُ فَاسْتَطْعِمُونِي أُطْعِمْكُمْ يَا عِبَادِي كُلُّكُمْ عَارٍ إِلاَّ مَنْ كَسَوْتُهُ فَاسْتَكْسُونِي أَكْسُكُمْ يَا عِبَادِي إِنَّكُمْ تُخْطِئُونَ بِاللَّيْلِ وَالنَّهَارِ وَأَنَا أَغْفِرُ الذُّنُوبَ جَمِيعًا فَاسْتَغْفِرُونِي أَغْفِرْ لَكُمْ يَا عِبَادِي إِنَّكُمْ لَنْ تَبْلُغُوا ضَرِّي فَتَضُرُّونِي وَلَنْ تَبْلُغُوا نَفْعِي فَتَنْفَعُونِي يَا عِبَادِي لَوْ أَنَّ أَوَّلَكُمْ وَآخِرَكُمْ وَإِنْسَكُمْ وَجِنَّكُمْ كَانُوا عَلَى أَتْقَى قَلْبِ رَجُلٍ وَاحِدٍ مِنْكُمْ مَا زَادَ ذَلِكَ فِي مُلْكِي شَيْئًا يَا عِبَادِي لَوْ أَنَّ أَوَّلَكُمْ وَآخِرَكُمْ وَإِنْسَكُمْ وَجِنَّكُمْ كَانُوا عَلَى أَفْجَرِ قَلْبِ رَجُلٍ وَاحِدٍ مَا نَقَصَ ذَلِكَ مِنْ مُلْكِي شَيْئًا يَا عِبَادِي لَوْ أَنَّ أَوَّلَكُمْ وَآخِرَكُمْ وَإِنْسَكُمْ وَجِنَّكُمْ قَامُوا فِي صَعِيدٍ وَاحِدٍ فَسَأَلُونِي فَأَعْطَيْتُ كُلَّ إِنْسَانٍ مَسْأَلَتَهُ مَا نَقَصَ ذَلِكَ مِمَّا عِنْدِي إِلاَّ كَمَا يَنْقُصُ الْمِخْيَطُ إِذَا أُدْخِلَ الْبَحْرَ يَا عِبَادِي إِنَّمَا هِيَ أَعْمَالُكُمْ أُحْصِيهَا لَكُمْ ثُمَّ أُوَفِّيكُمْ إِيَّاهَا فَمَنْ وَجَدَ خَيْرًا فَلْيَحْمَدِ اللَّهَ وَمَنْ وَجَدَ غَيْرَ ذَلِكَ فَلاَ يَلُومَنَّ إِلاَّ نَفْسَهُ ‏"‏ ‏.‏ قَالَ سَعِيدٌ كَانَ أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ إِذَا حَدَّثَ بِهَذَا الْحَدِيثِ جَثَا عَلَى رُكْبَتَيْهِ ‏.‏\hadithno{6572}\hadithtrans{Abu Dharr reported Allah's Messenger (ﷺ) as saying that Allah, the Exalted and Glorious, said:"O My servants, I have forbidden oppression for Myself and have made it forbidden amongst you, so do not oppress one another. O My servants, all of you are astray except for those I have guided, so seek guidance of Me and I shall guide you, O My servants, all of you are hungry except for those I have fed, so seek food of Me and I shall feed you. O My servants, all of you are naked except for those I have clothed, so seek clothing of Me and I shall clothe you. O My servants, you sin by night and by day, and I forgive all sins, so seek forgiveness of Me and I shall forgive you. O My servants, you will not attain harming Me so as to harm Me, and will not attain benefitting Me so as to benefit Me. O My servants, were the first of you and the last of you, the human of you and the jinn of you to be as pious as the most pious heart of any one man of you, that would not increase My dominion in anything. O My servants, were the first of you and the last of you, the human of you and the jinn of you to be as wicked as the most wicked heart of any one man of you, that would not decrease My dominion in anything. O My servants, were the first of you and the last of you, the human of you and the jinn of you to rise up in one place and make a request of Me, and were I to give everyone what he requested, that would not decrease what I have, any more that a needle decreases the sea if put into it. O My servants, it is but your deeds that I record for you and then recompense you for. So let him who finds good, praise Allah, and let him who finds other than that blame no one but himself." Sa'id said that when Abu Idris Khaulini narrated this hadith he knelt upon his knees}}
\hadithdefcmd{muslim}{6573}{حَدَّثَنِيهِ أَبُو بَكْرِ بْنُ إِسْحَاقَ، حَدَّثَنَا أَبُو مُسْهِرٍ، حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الْعَزِيزِ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّ مَرْوَانَ أَتَمُّهُمَا حَدِيثًا ‏.‏\hadithno{6573}\hadithtrans{The hadith is narrated through Abu Mushir from Sa'id bin 'Abdil'Aziz except that the previous hadith through Marwan was the more complete of the two}}
\hadithdefcmd{muslim}{6574}{قَالَ أَبُو إِسْحَاقَ حَدَّثَنَا بِهَذَا الْحَدِيثِ الْحَسَنُ، وَالْحُسَيْنُ، ابْنَا بِشْرٍ وَمُحَمَّدُ بْنُ يَحْيَى قَالُوا حَدَّثَنَا أَبُو مُسْهِرٍ، ‏.‏ فَذَكَرُوا الْحَدِيثَ بِطُولِهِ ‏.‏\hadithno{6574}\hadithtrans{This hadith is also transmitted through Ibna Bashr and Muhammad bin Muhammad through Abu Mashur through the same chain, narrated to its (full) extent}}
\hadithdefcmd{muslim}{6575}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، كِلاَهُمَا عَنْ عَبْدِ الصَّمَدِ بْنِ عَبْدِ، الْوَارِثِ حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِيمَا يَرْوِي عَنْ رَبِّهِ تَبَارَكَ وَتَعَالَى ‏ "‏ إِنِّي حَرَّمْتُ عَلَى نَفْسِي الظُّلْمَ وَعَلَى عِبَادِي فَلاَ تَظَالَمُوا ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ بِنَحْوِهِ وَحَدِيثُ أَبِي إِدْرِيسَ الَّذِي ذَكَرْنَاهُ أَتَمُّ مِنْ هَذَا ‏.‏\hadithno{6575}\hadithtrans{Abu Dharr reported Allah's Messenger (ﷺ) as saying that he reported it from his Lord, the Exalted and Glorious:Verily I have made oppression unlawful for Me and for My servants too, so do not commit oppression. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{6576}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا دَاوُدُ، - يَعْنِي ابْنَ قَيْسٍ - عَنْ عُبَيْدِ، اللَّهِ بْنِ مِقْسَمٍ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اتَّقُوا الظُّلْمَ فَإِنَّ الظُّلْمَ ظُلُمَاتٌ يَوْمَ الْقِيَامَةِ وَاتَّقُوا الشُّحَّ فَإِنَّ الشُّحَّ أَهْلَكَ مَنْ كَانَ قَبْلَكُمْ حَمَلَهُمْ عَلَى أَنْ سَفَكُوا دِمَاءَهُمْ وَاسْتَحَلُّوا مَحَارِمَهُمْ ‏"‏ ‏.‏\hadithno{6576}\hadithtrans{Jabir b. Abdullah reported that Allah's Messenger (ﷺ) said:Be on your guard against committing oppression, for oppression is a darkness on the Day of Resurrection, and be on your guard against stinginess for stinginess destroyed those who were before you, as it incited them to shed blood and make lawful what was unlawful for them}}
\hadithdefcmd{muslim}{6577}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ الْمَاجِشُونُ، عَنْ عَبْدِ اللَّهِ، بْنِ دِينَارٍ عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الظُّلْمَ ظُلُمَاتٌ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{6577}\hadithtrans{Ibu 'Umar reported Allah's Messenger (ﷺ) as saying:Oppression is the darkness on the Day of Resurrection}}
\hadithdefcmd{muslim}{6578}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُسْلِمُ أَخُو الْمُسْلِمِ لاَ يَظْلِمُهُ وَلاَ يُسْلِمُهُ مَنْ كَانَ فِي حَاجَةِ أَخِيهِ كَانَ اللَّهُ فِي حَاجَتِهِ وَمَنْ فَرَّجَ عَنْ مُسْلِمٍ كُرْبَةً فَرَّجَ اللَّهُ عَنْهُ بِهَا كُرْبَةً مِنْ كُرَبِ يَوْمِ الْقِيَامَةِ وَمَنْ سَتَرَ مُسْلِمًا سَتَرَهُ اللَّهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{6578}\hadithtrans{Salim reported on the authority of his father that Allah's Messenger (ﷺ) said:A Muslim is the brother of a fellow-Muslim. He should neither commit oppression upon him nor ruin him, and he who meets the need of a brot'ier, Allah would meet big needs, and he who relieved a Muslim from hardship Allah would relieve him from the hardships to which he would be put on the Day of Resurrection, and he who did not expose (the follies of a Muslim) Allah would conceal his follies on the Day of Resurrection}}
\hadithdefcmd{muslim}{6579}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَتَدْرُونَ مَا الْمُفْلِسُ ‏"‏ ‏.‏ قَالُوا الْمُفْلِسُ فِينَا مَنْ لاَ دِرْهَمَ لَهُ وَلاَ مَتَاعَ ‏.‏ فَقَالَ ‏"‏ إِنَّ الْمُفْلِسَ مِنْ أُمَّتِي يَأْتِي يَوْمَ الْقِيَامَةِ بِصَلاَةٍ وَصِيَامٍ وَزَكَاةٍ وَيَأْتِي قَدْ شَتَمَ هَذَا وَقَذَفَ هَذَا وَأَكَلَ مَالَ هَذَا وَسَفَكَ دَمَ هَذَا وَضَرَبَ هَذَا فَيُعْطَى هَذَا مِنْ حَسَنَاتِهِ وَهَذَا مِنْ حَسَنَاتِهِ فَإِنْ فَنِيَتْ حَسَنَاتُهُ قَبْلَ أَنْ يُقْضَى مَا عَلَيْهِ أُخِذَ مِنْ خَطَايَاهُمْ فَطُرِحَتْ عَلَيْهِ ثُمَّ طُرِحَ فِي النَّارِ ‏"‏ ‏.‏\hadithno{6579}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Do you know who is poor? They (the Companions of the Holy Prophet) said: A poor man amongst us is one who has neither dirham with him nor wealth. He (the Holy Prophet) said: The poor of my Umma would be he who would come on the Day of Resurrection with prayers and fasts and Zakat but (he would find himself bankrupt on that day as he would have exhausted his funds of virtues) since he hurled abuses upon others, brought calumny against others and unlawfully consumed the wealth of others and shed the blood of others and beat others, and his virtues would be credited to the account of one (who suffered at his hand). And if his good deeds fall short to clear the account, then his sins would be entered in (his account) and he would be thrown in the Hell-Fire}}
\hadithdefcmd{muslim}{6580}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَتُؤَدُّنَّ الْحُقُوقَ إِلَى أَهْلِهَا يَوْمَ الْقِيَامَةِ حَتَّى يُقَادَ لِلشَّاةِ الْجَلْحَاءِ مِنَ الشَّاةِ الْقَرْنَاءِ ‏"‏ ‏.‏\hadithno{6580}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:“Rights will certainly be restored to those entitled to them on the Day of Resurrection, (to the point that) even the hornless sheep will lay claim upon the horned one.”}}
\hadithdefcmd{muslim}{6581}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا بُرَيْدُ بْنُ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يُمْلِي لِلظَّالِمِ فَإِذَا أَخَذَهُ لَمْ يُفْلِتْهُ ‏"‏ ‏.‏ ثُمَّ قَرَأَ ‏\{‏ وَكَذَلِكَ أَخْذُ رَبِّكَ إِذَا أَخَذَ الْقُرَى وَهِيَ ظَالِمَةٌ إِنَّ أَخْذَهُ أَلِيمٌ شَدِيدٌ‏\}‏\hadithno{6581}\hadithtrans{Abu Musa reported Allah's Messenger (ﷺ) as saying:Allah, the Exalted and Glorious, grants respite to the oppessor. But when He lays Hand upon him, He does not then let him off. Re (the Holy Prophet) then recited this verse:" Such is the chastisement of thy Lord when He chastises the towns (inhabited by) wrongdoing persons. Surely, His punishment is painful, severe" (xi)}}
\hadithdefcmd{muslim}{6582}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ اقْتَتَلَ غُلاَمَانِ غُلاَمٌ مِنَ الْمُهَاجِرِينَ وَغُلاَمٌ مِنَ الأَنْصَارِ فَنَادَى الْمُهَاجِرُ أَوِ الْمُهَاجِرُونَ يَا لَلْمُهَاجِرِينَ ‏.‏ وَنَادَى الأَنْصَارِيُّ يَا لَلأَنْصَارِ ‏.‏ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا هَذَا دَعْوَى أَهْلِ الْجَاهِلِيَّةِ ‏"‏ ‏.‏ قَالُوا لاَ يَا رَسُولَ اللَّهِ إِلاَّ أَنَّ غُلاَمَيْنِ اقْتَتَلاَ فَكَسَعَ أَحَدُهُمَا الآخَرَ قَالَ ‏"‏ فَلاَ بَأْسَ وَلْيَنْصُرِ الرَّجُلُ أَخَاهُ ظَالِمًا أَوْ مَظْلُومًا إِنْ كَانَ ظَالِمًا فَلْيَنْهَهُ فَإِنَّهُ لَهُ نَصْرٌ وَإِنْ كَانَ مَظْلُومًا فَلْيَنْصُرْهُ ‏"‏ ‏.‏\hadithno{6582}\hadithtrans{Jabir b. Abdullah reported that two young men, one from the Muhajirin (emigrants) and the other one from the Angr (helpers) fell into dispute and the Muhajir called his fellow Muhajirin, and the Ansari (the helper) called the Ansar (for help). In the meanwhile, Allah's Messenger (ﷺ) came there and said:What is this, the proclamation of the days of jahiliya (ignorance)? They said: Allah's Messenger, there is nothing serious. The two young men fell into dispute and the one struck at the back of the other. Thereupon he (the Holy Prophet) said: Well, a person should help his brother whether he is an oppressor or an oppressed. If he is the oppressor he should prevent him from doing it, for that is his help; and if he is the oppressed he should be helped (against oppression)}}
\hadithdefcmd{muslim}{6583}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَأَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، وَابْنُ أَبِي، عُمَرَ - وَاللَّفْظُ لاِبْنِ أَبِي شَيْبَةَ - قَالَ ابْنُ عَبْدَةَ أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا سُفْيَانُ بْنُ، عُيَيْنَةَ قَالَ سَمِعَ عَمْرٌو، جَابِرَ بْنَ عَبْدِ اللَّهِ يَقُولُ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي غَزَاةٍ فَكَسَعَ رَجُلٌ مِنَ الْمُهَاجِرِينَ رَجُلاً مِنَ الأَنْصَارِ فَقَالَ الأَنْصَارِيُّ يَا لَلأَنْصَارِ وَقَالَ الْمُهَاجِرِيُّ يَا لَلْمُهَاجِرِينَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا بَالُ دَعْوَى الْجَاهِلِيَّةِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ كَسَعَ رَجُلٌ مِنَ الْمُهَاجِرِينَ رَجُلاً مِنَ الأَنْصَارِ ‏.‏ فَقَالَ ‏"‏ دَعُوهَا فَإِنَّهَا مُنْتِنَةٌ ‏"‏ ‏.‏ فَسَمِعَهَا عَبْدُ اللَّهِ بْنُ أُبَىٍّ فَقَالَ قَدْ فَعَلُوهَا وَاللَّهِ لَئِنْ رَجَعْنَا إِلَى الْمَدِينَةِ لَيُخْرِجَنَّ الأَعَزُّ مِنْهَا الأَذَلَّ ‏.‏ قَالَ عُمَرُ دَعْنِي أَضْرِبْ عُنُقَ هَذَا الْمُنَافِقِ فَقَالَ ‏"‏ دَعْهُ لاَ يَتَحَدَّثُ النَّاسُ أَنَّ مُحَمَّدًا يَقْتُلُ أَصْحَابَهُ ‏"‏ ‏.‏\hadithno{6583}\hadithtrans{Jabir b. Abdullah reported:We were along with Allah's Messenger (ﷺ) in an expedition that a person from amongst the emigrants struck at the back of a person from the Ansir. The Ansiri said: O Ansar! And the Muhijir said: O Emigrants! Thereupon Allah's Messenger (ﷺ) said: What are these proclamations of the Days of Ignorance? They said: Allah's Messenger, a person from the emigrants struck at the back of an Ansari, whereupon he said: It is something disgusting. 'Abdullah b. Ubayy heard it and said: They have indeed done it. By Allah, when we would return to Medina the respectable amongst them (the Ansar) would turn away the mean (the emigrants). Thereupon 'Umar said: Permit me so that I should strike the neck of this hypocrite. But he (the Holy Prophet) said: Leave him, the people may not say that Muhammad kills his companions}}
\hadithdefcmd{muslim}{6584}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالَ ابْنُ رَافِعٍ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَسَعَ رَجُلٌ مِنَ الْمُهَاجِرِينَ رَجُلاً مِنَ الأَنْصَارِ فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَسَأَلَهُ الْقَوَدَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ دَعُوهَا فَإِنَّهَا مُنْتِنَةٌ ‏"‏ ‏.‏ قَالَ ابْنُ مَنْصُورٍ فِي رِوَايَتِهِ عَمْرٌو قَالَ سَمِعْتُ جَابِرًا ‏.‏\hadithno{6584}\hadithtrans{Jabir b. 'Abdullah reported that a person from the emigrants struck the back of an Ansari. He came to Allah's Apostle (ﷺ) and asked for compensation. Thereupon Allah's Apostle (ﷺ) said:Leave it. for it is something disgusting. Ibn Mansur said that in the narration transmitted on the authority of Amr (these words are also found):" I heard Jabir}}
\hadithdefcmd{muslim}{6585}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو عَامِرٍ الأَشْعَرِيُّ قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، وَأَبُو أُسَامَةَ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، وَابْنُ، إِدْرِيسَ وَأَبُو أُسَامَةَ كُلُّهُمْ عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُؤْمِنُ لِلْمُؤْمِنِ كَالْبُنْيَانِ يَشُدُّ بَعْضُهُ بَعْضًا ‏"‏ ‏.‏\hadithno{6585}\hadithtrans{Abu Musa reported Allah's Messenger (ﷺ) as saying:A believer is like a brick for another believer, the one supporting the other}}
\hadithdefcmd{muslim}{6586}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا زَكَرِيَّاءُ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلُ الْمُؤْمِنِينَ فِي تَوَادِّهِمْ وَتَرَاحُمِهِمْ وَتَعَاطُفِهِمْ مَثَلُ الْجَسَدِ إِذَا اشْتَكَى مِنْهُ عُضْوٌ تَدَاعَى لَهُ سَائِرُ الْجَسَدِ بِالسَّهَرِ وَالْحُمَّى ‏"‏ ‏.‏\hadithno{6586}\hadithtrans{Nu'man b. Bashir reported Allah's Messenger (ﷺ) as saying:The similitude of believers in regard to mutual love, affection, fellow-feeling is that of one body; when any limb of it aches, the whole body aches, because of sleeplessness and fever}}
\hadithdefcmd{muslim}{6587}{حَدَّثَنَا إِسْحَاقُ الْحَنْظَلِيُّ، أَخْبَرَنَا جَرِيرٌ، عَنْ مُطَرِّفٍ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ، بَشِيرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ ‏.‏\hadithno{6587}\hadithtrans{Nu'man b. Bashir reported a hadith like this from Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{6588}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُؤْمِنُونَ كَرَجُلٍ وَاحِدٍ إِنِ اشْتَكَى رَأْسُهُ تَدَاعَى لَهُ سَائِرُ الْجَسَدِ بِالْحُمَّى وَالسَّهَرِ ‏"‏ ‏.‏\hadithno{6588}\hadithtrans{Nu'man b. Bashir reported Allah's Messenger (ﷺ) as saying:The believers are like one person; if his head aches, the whole body aches with fever and sleeplessness}}
\hadithdefcmd{muslim}{6589}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنِ الأَعْمَشِ، عَنْ خَيْثَمَةَ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمُسْلِمُونَ كَرَجُلٍ وَاحِدٍ إِنِ اشْتَكَى عَيْنُهُ اشْتَكَى كُلُّهُ وَإِنِ اشْتَكَى رَأْسُهُ اشْتَكَى كُلُّهُ ‏"‏ ‏.‏\hadithno{6589}\hadithtrans{Nu'man b. Bashir reported that Muslims are like one body of a person; if the eye is sore, the whole body aches, and if the head aches, the whole body aches}}
\hadithdefcmd{muslim}{6590}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنِ الأَعْمَشِ، عَنِ الشَّعْبِيِّ، عَنِ النُّعْمَانِ، بْنِ بَشِيرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{6590}\hadithtrans{A hadith like this has been narrated on the authority of Nu'man b. Bashir through another chain of transmitters}}
\hadithdefcmd{muslim}{6591}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُسْتَبَّانِ مَا قَالاَ فَعَلَى الْبَادِئِ مَا لَمْ يَعْتَدِ الْمَظْلُومُ ‏"‏ ‏.‏\hadithno{6591}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When two persons indulge in hurling (abuses) upon one another, it would be the first one who would be the sinner so long as the oppressed does not transgress the limits}}
\hadithdefcmd{muslim}{6592}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا نَقَصَتْ صَدَقَةٌ مِنْ مَالٍ وَمَا زَادَ اللَّهُ عَبْدًا بِعَفْوٍ إِلاَّ عِزًّا وَمَا تَوَاضَعَ أَحَدٌ لِلَّهِ إِلاَّ رَفَعَهُ اللَّهُ ‏"‏ ‏.‏\hadithno{6592}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Charity does not decrease wealth, no one forgives another except that Allah increases his honor, and no one humbles himself for the sake of Allah except that Allah raises his status}}
\hadithdefcmd{muslim}{6593}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَتَدْرُونَ مَا الْغِيبَةُ ‏"‏ ‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ ذِكْرُكَ أَخَاكَ بِمَا يَكْرَهُ ‏"‏ ‏.‏ قِيلَ أَفَرَأَيْتَ إِنْ كَانَ فِي أَخِي مَا أَقُولُ قَالَ ‏"‏ إِنْ كَانَ فِيهِ مَا تَقُولُ فَقَدِ اغْتَبْتَهُ وَإِنْ لَمْ يَكُنْ فِيهِ فَقَدْ بَهَتَّهُ ‏"‏ ‏.‏\hadithno{6593}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Do you know what is backbiting? They (the Companions) said: Allah and His Messenger know best. Thereupon he (the Holy Prophet) said: Backbiting implies your talking about your brother in a manner which he does not like. It was said to him: What is your opinion about this that if I actually find (that failing) in my brother which I made a mention of? He said: If (that failing) is actually found (in him) what you assert, you in fact backbited him, and if that is not in him it is a slander}}
\hadithdefcmd{muslim}{6594}{حَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامٍ الْعَيْشِيُّ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا رَوْحٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَسْتُرُ اللَّهُ عَلَى عَبْدٍ فِي الدُّنْيَا إِلاَّ سَتَرَهُ اللَّهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{6594}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:The servant (whose fault) Allah conceals in this world, Allah would also conceal (his faults) on the Day of Resurrection}}
\hadithdefcmd{muslim}{6595}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَسْتُرُ عَبْدٌ عَبْدًا فِي الدُّنْيَا إِلاَّ سَتَرَهُ اللَّهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{6595}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:The servant (who conceals) the faults of others in this world, Allah would conceal his faults on the Day of Resurrection}}
\hadithdefcmd{muslim}{6596}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَزُهَيْرُ بْنُ حَرْبٍ وَابْنُ نُمَيْرٍ كُلُّهُمْ عَنِ ابْنِ عُيَيْنَةَ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالَ حَدَّثَنَا سُفْيَانُ، - وَهُوَ ابْنُ عُيَيْنَةَ - عَنِ ابْنِ الْمُنْكَدِرِ، سَمِعَ عُرْوَةَ بْنَ الزُّبَيْرِ، يَقُولُ حَدَّثَتْنِي عَائِشَةُ، أَنَّ رَجُلاً، اسْتَأْذَنَ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ ائْذَنُوا لَهُ فَلَبِئْسَ ابْنُ الْعَشِيرَةِ أَوْ بِئْسَ رَجُلُ الْعَشِيرَةِ ‏"‏ ‏.‏ فَلَمَّا دَخَلَ عَلَيْهِ أَلاَنَ لَهُ الْقَوْلَ قَالَتْ عَائِشَةُ فَقُلْتُ يَا رَسُولَ اللَّهِ قُلْتَ لَهُ الَّذِي قُلْتَ ثُمَّ أَلَنْتَ لَهُ الْقَوْلَ قَالَ ‏"‏ يَا عَائِشَةُ إِنَّ شَرَّ النَّاسِ مَنْزِلَةً عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ مَنْ وَدَعَهُ أَوْ تَرَكَهُ النَّاسُ اتِّقَاءَ فُحْشِهِ ‏"‏ ‏.‏\hadithno{6596}\hadithtrans{A'isha reported that a person sought permission from Allah's Apostle (ﷺ) to see him. He said:Grant him permission. (and also added: ) He is a bad son of his tribe or he is a bad person of his tribe. When he came in he used kind words for him. 'A'isha reported that she said: Allah's Messenger, you said about him what you had to say and then you treated him with kindness. He said: A'isha, verily in the eye of Allah, worst amongst the person in rank on the Day of Resurrection is one whom the people abandon or desert out of the fear of indecency}}
\hadithdefcmd{muslim}{6597}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، كِلاَهُمَا عَنْ عَبْدِ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ الْمُنْكَدِرِ، فِي هَذَا الإِسْنَادِ ‏.‏ مِثْلَ مَعْنَاهُ غَيْرَ أَنَّهُ قَالَ ‏ "‏ بِئْسَ أَخُو الْقَوْمِ وَابْنُ الْعَشِيرَةِ ‏"‏ ‏.‏\hadithno{6597}\hadithtrans{This hadith has been reported on the authority of Ibn Munkadir with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{6598}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، حَدَّثَنَا مَنْصُورٌ، عَنْ تَمِيمِ بْنِ سَلَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هِلاَلٍ، عَنْ جَرِيرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ يُحْرَمِ الرِّفْقَ يُحْرَمِ الْخَيْرَ ‏"‏ ‏.‏\hadithno{6598}\hadithtrans{Jarir reported from Allah's Messenger (ﷺ):He who is deprived of tenderly feelings is in fact deprived of good}}
\hadithdefcmd{muslim}{6599}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو سَعِيدٍ الأَشَجُّ وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ قَالُوا حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا حَفْصٌ، - يَعْنِي ابْنَ غِيَاثٍ - كُلُّهُمْ عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ، بْنُ إِبْرَاهِيمَ - وَاللَّفْظُ لَهُمَا - قَالَ زُهَيْرٌ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ تَمِيمِ بْنِ سَلَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هِلاَلٍ الْعَبْسِيِّ، قَالَ سَمِعْتُ جَرِيرًا، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ يُحْرَمِ الرِّفْقَ يُحْرَمِ الْخَيْرَ ‏"‏ ‏.‏\hadithno{6599}\hadithtrans{Jarir reported Allah's Messenger (ﷺ) as saying:He who is deprived of tenderly feelings is in fact deprived of good}}
\hadithdefcmd{muslim}{6600}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، عَنْ مُحَمَّدِ بْنِ أَبِي إِسْمَاعِيلَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هِلاَلٍ، قَالَ سَمِعْتُ جَرِيرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ حُرِمَ الرِّفْقَ حُرِمَ الْخَيْرَ أَوْ مَنْ يُحْرَمِ الرِّفْقَ يُحْرَمِ الْخَيْرَ ‏"‏ ‏.‏\hadithno{6600}\hadithtrans{Jarir b. 'Abdullah reported Allah's Apostle (ﷺ) as saying:He who is deprived of tenderly feelings is in fact deprived of good and he who is deprived of tenderly feelings is in fact deprived of good}}
\hadithdefcmd{muslim}{6601}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي حَيْوَةُ، حَدَّثَنِي ابْنُ الْهَادِ، عَنْ أَبِي بَكْرِ بْنِ حَزْمٍ، عَنْ عَمْرَةَ، - يَعْنِي بِنْتَ عَبْدِ الرَّحْمَنِ - عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَا عَائِشَةُ إِنَّ اللَّهَ رَفِيقٌ يُحِبُّ الرِّفْقَ وَيُعْطِي عَلَى الرِّفْقِ مَا لاَ يُعْطِي عَلَى الْعُنْفِ وَمَا لاَ يُعْطِي عَلَى مَا سِوَاهُ ‏"‏ ‏.‏\hadithno{6601}\hadithtrans{A'isha, the wife of Allah's Apostle (ﷺ), reported that Allah's Messenger (ﷺ) said:'A'isha, verily Allah is kind and He loves kindness and confers upon kindness which he does not confer upon severity and does not confer upon anything else besides it (kindness)}}
\hadithdefcmd{muslim}{6602}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ الْمِقْدَامِ، - وَهُوَ ابْنُ شُرَيْحِ بْنِ هَانِئٍ - عَنْ أَبِيهِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الرِّفْقَ لاَ يَكُونُ فِي شَىْءٍ إِلاَّ زَانَهُ وَلاَ يُنْزَعُ مِنْ شَىْءٍ إِلاَّ شَانَهُ ‏"‏ ‏.‏\hadithno{6602}\hadithtrans{A'isha, the wife of Allah's Apostle (ﷺ), reported Allah's Apostle (ﷺ) as saying:Kindness is not to be found in anything but that it adds to its beauty and it is not withdrawn from anything but it makes it defective}}
\hadithdefcmd{muslim}{6603}{حَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ الْمِقْدَامَ بْنَ شُرَيْحِ بْنِ هَانِئٍ، بِهَذَا الإِسْنَادِ وَزَادَ فِي الْحَدِيثِ رَكِبَتْ عَائِشَةُ بَعِيرًا فَكَانَتْ فِيهِ صُعُوبَةٌ فَجَعَلَتْ تُرَدِّدُهُ فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلَيْكِ بِالرِّفْقِ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِهِ ‏.‏\hadithno{6603}\hadithtrans{This hadith has been reported by Miqdam b. Shuraih b. Hani with the same chain of transmitters but with this addition:" 'A'isha mounted upon a wild camel and she began to make that go round and round. Thereupon Allah's Messenger (ﷺ) said: You should show kindness, and then he made a mention of this hadith}}
\hadithdefcmd{muslim}{6604}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ عُلَيَّةَ، قَالَ زُهَيْرٌ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ، حُصَيْنٍ قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ وَامْرَأَةٌ مِنَ الأَنْصَارِ عَلَى نَاقَةٍ فَضَجِرَتْ فَلَعَنَتْهَا فَسَمِعَ ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ خُذُوا مَا عَلَيْهَا وَدَعُوهَا فَإِنَّهَا مَلْعُونَةٌ ‏"‏ ‏.‏ قَالَ عِمْرَانُ فَكَأَنِّي أَرَاهَا الآنَ تَمْشِي فِي النَّاسِ مَا يَعْرِضُ لَهَا أَحَدٌ ‏.‏\hadithno{6604}\hadithtrans{Imran b. Husain reported:We were with Allah's Messenger (ﷺ) in some of his journeys and there was a woman from the Ansar riding a she-camel that it shied and she invoked curse upon that. Allah's Messenger (ﷺ) heard it and said: Unload that and set it free for it is accursed. 'Imran said: I still perceive that (dromedary) walking amongst people and none taking any notice of that}}
\hadithdefcmd{muslim}{6605}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو الرَّبِيعِ، قَالاَ حَدَّثَنَا حَمَّادٌ، وَهُوَ ابْنُ زَيْدٍ ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا الثَّقَفِيُّ، كِلاَهُمَا عَنْ أَيُّوبَ، بِإِسْنَادِ إِسْمَاعِيلَ ‏.‏ نَحْوَ حَدِيثِهِ إِلاَّ أَنَّ فِي حَدِيثِ حَمَّادٍ قَالَ عِمْرَانُ فَكَأَنِّي أَنْظُرُ إِلَيْهَا نَاقَةً وَرْقَاءَ وَفِي حَدِيثِ الثَّقَفِيِّ فَقَالَ ‏ "‏ خُذُوا مَا عَلَيْهَا وَأَعْرُوهَا فَإِنَّهَا مَلْعُونَةٌ ‏"‏ ‏.‏\hadithno{6605}\hadithtrans{Imran reported:I perceive as if I am looking towards that dromedary, and in the hadith transmitted on the authority of Thaqafi (the words are):" Unload it and make its back bare for it is accursed}}
\hadithdefcmd{muslim}{6606}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، فُضَيْلُ بْنُ حُسَيْنٍ حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ، عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ، قَالَ بَيْنَمَا جَارِيَةٌ عَلَى نَاقَةٍ عَلَيْهَا بَعْضُ مَتَاعِ الْقَوْمِ إِذْ بَصُرَتْ بِالنَّبِيِّ صلى الله عليه وسلم وَتَضَايَقَ بِهِمُ الْجَبَلُ فَقَالَتْ حَلْ اللَّهُمَّ الْعَنْهَا ‏.‏ قَالَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تُصَاحِبُنَا نَاقَةٌ عَلَيْهَا لَعْنَةٌ ‏"‏ ‏.‏\hadithno{6606}\hadithtrans{Abu Burza al-Aslami reported that a slave-girl was riding a dromedary and there was also the luggage of people upon it. that she suddenly saw Allah's Apostle (ﷺ). The way of the mountain was narrow and she said (to that dromedary):Go ahead (but that dromedary did not move). She (that slave-girl), out of anger, said: O Allah, let that (dromedary) be damned. Thereupon Allah's Apostle (ﷺ) said: Let the dromedary on which the curse has been invoked not proceed with us}}
\hadithdefcmd{muslim}{6607}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا الْمُعْتَمِرُ، ح وَحَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - جَمِيعًا عَنْ سُلَيْمَانَ التَّيْمِيِّ، بِهَذَا الإِسْنَادِ وَزَادَ فِي حَدِيثِ الْمُعْتَمِرِ ‏ "‏ لاَ ايْمُ اللَّهِ لاَ تُصَاحِبُنَا رَاحِلَةٌ عَلَيْهَا لَعْنَةٌ مِنَ اللَّهِ ‏"‏ ‏.‏ أَوْ كَمَا قَالَ ‏.‏\hadithno{6607}\hadithtrans{This hadith has been narrated on the authority of Sulaiman Taimi with the same chain of transmitters but with a variation of words (and that is):" By Allah, let that accompany us not which has been damned, or he said like it}}
\hadithdefcmd{muslim}{6608}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي سُلَيْمَانُ، - وَهُوَ ابْنُ بِلاَلٍ - عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، حَدَّثَهُ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَنْبَغِي لِصِدِّيقٍ أَنْ يَكُونَ لَعَّانًا ‏"‏ ‏.‏\hadithno{6608}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:It does not seem proper for a Siddiq that he should be an invoker of curse}}
\hadithdefcmd{muslim}{6609}{حَدَّثَنِيهِ أَبُو كُرَيْبٍ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ، الرَّحْمَنِ بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6609}\hadithtrans{This hadith has been narrated on the authority of Abu Kuraib with the same chain of transmitters}}
\hadithdefcmd{muslim}{6610}{حَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنِي حَفْصُ بْنُ مَيْسَرَةَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ عَبْدَ الْمَلِكِ، بْنَ مَرْوَانَ بَعَثَ إِلَى أُمِّ الدَّرْدَاءِ بِأَنْجَادٍ مِنْ عِنْدِهِ فَلَمَّا أَنْ كَانَ ذَاتَ لَيْلَةٍ قَامَ عَبْدُ الْمَلِكِ مِنَ اللَّيْلِ فَدَعَا خَادِمَهُ فَكَأَنَّهُ أَبْطَأَ عَلَيْهِ فَلَعَنَهُ فَلَمَّا أَصْبَحَ قَالَتْ لَهُ أُمُّ الدَّرْدَاءِ سَمِعْتُكَ اللَّيْلَةَ لَعَنْتَ خَادِمَكَ حِينَ دَعَوْتَهُ ‏.‏ فَقَالَتْ سَمِعْتُ أَبَا الدَّرْدَاءِ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَكُونُ اللَّعَّانُونَ شُفَعَاءَ وَلاَ شُهَدَاءَ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{6610}\hadithtrans{Zaid b. Aslam reported that 'Abd al-Malik b. Marwan sent some domestic goods for decoration to Umm Darda' on his own behalf, and when it was night 'Abd al-Malik got up and called for the servant. It seemed as if he (the servant) was late (in responding to his call), so he ('Abd al-Malik) invoked curse upon him, and when it was morning Umm Darda' said to him:I heard you cursing your servant during the night when you called him, and she said: I heard Abu Darda' as saying that Allah's Messenger (ﷺ) said: The invoker of curse would neither be intercessor nor witness on the Day of Resurrection}}
\hadithdefcmd{muslim}{6611}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو غَسَّانَ الْمِسْمَعِيُّ وَعَاصِمُ بْنُ النَّضْرِ التَّيْمِيُّ قَالُوا حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، كِلاَهُمَا عَنْ مَعْمَرٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، فِي هَذَا الإِسْنَادِ بِمِثْلِ مَعْنَى حَدِيثِ حَفْصِ بْنِ مَيْسَرَةَ ‏.‏\hadithno{6611}\hadithtrans{This hadith has been narrated on the authority of Zaid b. Aslam with the same chain of transmitters}}
\hadithdefcmd{muslim}{6612}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ هِشَامِ بْنِ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، وَأَبِي، حَازِمٍ عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّعَّانِينَ لاَ يَكُونُونَ شُهَدَاءَ وَلاَ شُفَعَاءَ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{6612}\hadithtrans{Umm Darda' reported on the authority of Abu Darda' as saying:I heard Allah's Messenger (ﷺ) as saying: The invoker of curse would neither be witness nor intercessor on the Day of Resurrection}}
\hadithdefcmd{muslim}{6613}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا مَرْوَانُ، - يَعْنِيَانِ الْفَزَارِيَّ - عَنْ يَزِيدَ، - وَهُوَ ابْنُ كَيْسَانَ - عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ ادْعُ عَلَى الْمُشْرِكِينَ قَالَ ‏ "‏ إِنِّي لَمْ أُبْعَثْ لَعَّانًا وَإِنَّمَا بُعِثْتُ رَحْمَةً ‏"‏ ‏.‏\hadithno{6613}\hadithtrans{Abu Huraira reported it was said to Allah's Messenger (ﷺ):Invoke curse upon the polytheists, whereupon he said: I have not been sent as the invoker of curse, but I have been sent as mercy}}
\hadithdefcmd{muslim}{6614}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم رَجُلاَنِ فَكَلَّمَاهُ بِشَىْءٍ لاَ أَدْرِي مَا هُوَ فَأَغْضَبَاهُ فَلَعَنَهُمَا وَسَبَّهُمَا فَلَمَّا خَرَجَا قُلْتُ يَا رَسُولَ اللَّهِ مَنْ أَصَابَ مِنَ الْخَيْرِ شَيْئًا مَا أَصَابَهُ هَذَانِ قَالَ ‏"‏ وَمَا ذَاكِ ‏"‏ ‏.‏ قَالَتْ قُلْتُ لَعَنْتَهُمَا وَسَبَبْتَهُمَا قَالَ ‏"‏ أَوَمَا عَلِمْتِ مَا شَارَطْتُ عَلَيْهِ رَبِّي قُلْتُ اللَّهُمَّ إِنَّمَا أَنَا بَشَرٌ فَأَىُّ الْمُسْلِمِينَ لَعَنْتُهُ أَوْ سَبَبْتُهُ فَاجْعَلْهُ لَهُ زَكَاةً وَأَجْرًا ‏"‏ ‏.‏\hadithno{6614}\hadithtrans{A'isha reported that two persons visited Allah's Messenger (ﷺ) and both of them talked about a thing, of which I am not aware, but that annoyed him and he invoked curse upon both of them and hurled malediction, and when they went out I said:Allah's Messenger, the good would reach everyone but it would not reach these two. He said: Why so? I said: Because you have invoked curse and hurled malediction upon both of them. He said: Don't you know that I have made condition with my Lord saying thus: O Allah, I am a human being and that for a Muslim upon whom I invoke curse or hurl malediction make it a source of purity and reward}}
\hadithdefcmd{muslim}{6615}{حَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَاهُ عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ خَشْرَمٍ، جَمِيعًا عَنْ عِيسَى بْنِ يُونُسَ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ جَرِيرٍ وَقَالَ فِي حَدِيثِ عِيسَى فَخَلَوَا بِهِ فَسَبَّهُمَا وَلَعَنَهُمَا وَأَخْرَجَهُمَا ‏.‏\hadithno{6615}\hadithtrans{This hadith has been reported on the authority of A'mash with the same chain of transmitters and the hadith transmitted on the authority of 'Isa (the words are):" He had a private meeting with them and hurled malediction upon them and cursed them and sent them out}}
\hadithdefcmd{muslim}{6616}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ إِنَّمَا أَنَا بَشَرٌ فَأَيُّمَا رَجُلٍ مِنَ الْمُسْلِمِينَ سَبَبْتُهُ أَوْ لَعَنْتُهُ أَوْ جَلَدْتُهُ فَاجْعَلْهَا لَهُ زَكَاةً وَرَحْمَةً ‏"‏ ‏.‏\hadithno{6616}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:O Allah, I am a human being and for any person amongst Muslims upon whom I hurl malediction or invoke curse or give him whipping make it a source of purity and mercy}}
\hadithdefcmd{muslim}{6617}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ إِلاَّ أَنَّ فِيهِ ‏ "‏ زَكَاةً وَأَجْرًا ‏"‏ ‏.‏\hadithno{6617}\hadithtrans{Jabir reported Allah's Apostle (ﷺ) a hadith like it but with a slight variation of wording}}
\hadithdefcmd{muslim}{6618}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِإِسْنَادِ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ ‏.‏ مِثْلَ حَدِيثِهِ غَيْرَ أَنَّ فِي، حَدِيثِ عِيسَى جَعَلَ ‏"‏ وَأَجْرًا ‏"‏ ‏.‏ فِي حَدِيثِ أَبِي هُرَيْرَةَ وَجَعَلَ ‏"‏ وَرَحْمَةً ‏"‏ ‏.‏ فِي حَدِيثِ جَابِرٍ ‏.‏\hadithno{6618}\hadithtrans{This hadith has been transmitted on the authority of A'mash and in the hadith transmitted on the authority of 'Isa the words are:Make it a source of reward, and in the hadith transmitted on the authority of Abu Huraira (the words are):" Make it a source of mercy}}
\hadithdefcmd{muslim}{6619}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَتَّخِذُ عِنْدَكَ عَهْدًا لَنْ تُخْلِفَنِيهِ فَإِنَّمَا أَنَا بَشَرٌ فَأَىُّ الْمُؤْمِنِينَ آذَيْتُهُ شَتَمْتُهُ لَعَنْتُهُ جَلَدْتُهُ فَاجْعَلْهَا لَهُ صَلاَةً وَزَكَاةً وَقُرْبَةً تُقَرِّبُهُ بِهَا إِلَيْكَ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{6619}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:O Allah, I make a covenant with Thee against which Thou wouldst never go. I am a human being and thus for a Muslim whom I give any harm or whom I scold or upon whom I invoke curse or whom I beat, make this a source of blessing, purification and nearness to Thee on the Day of Resurrection}}
\hadithdefcmd{muslim}{6620}{حَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَبُو الزِّنَادِ، بِهَذَا الإِسْنَادِ نَحْوَهُ إِلاَّ أَنَّهُ قَالَ ‏"‏ أَوْ جَلَدُّهُ ‏"‏ ‏.‏ قَالَ أَبُو الزِّنَادِ وَهِيَ لُغَةُ أَبِي هُرَيْرَةَ وَإِنَّمَا هِيَ ‏"‏ جَلَدْتُهُ ‏"‏ ‏.‏\hadithno{6620}\hadithtrans{This hadith has been transmitted on the authority of Abu Zinad with a slight variation of wording}}
\hadithdefcmd{muslim}{6621}{حَدَّثَنِي سُلَيْمَانُ بْنُ مَعْبَدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ ‏.‏\hadithno{6621}\hadithtrans{A hadith like this has been reported on the authority of Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{6622}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ سَالِمٍ، مَوْلَى النَّصْرِيِّينَ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنَّمَا مُحَمَّدٌ بَشَرٌ يَغْضَبُ كَمَا يَغْضَبُ الْبَشَرُ وَإِنِّي قَدِ اتَّخَذْتُ عِنْدَكَ عَهْدًا لَنْ تُخْلِفَنِيهِ فَأَيُّمَا مُؤْمِنٍ آذَيْتُهُ أَوْ سَبَبْتُهُ أَوْ جَلَدْتُهُ فَاجْعَلْهَا لَهُ كَفَّارَةً وَقُرْبَةً تُقَرِّبُهُ بِهَا إِلَيْكَ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{6622}\hadithtrans{Salim, the freed slave of Nasriyyin, said:I heard Abu Huraira as saying that he heard Allah's Messenger (ﷺ) as saying: O Allah, Muhammad is a human being. I lose my temper just as human beings lose temper, and I have held a covenant with Thee which Thou wouldst not break: For a believer whom I give any trouble or invoke curse or beat, make that an expiation (of his sins and a source of) his nearness to Thee on the Day of Resurrection}}
\hadithdefcmd{muslim}{6623}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ فَأَيُّمَا عَبْدٍ مُؤْمِنٍ سَبَبْتُهُ فَاجْعَلْ ذَلِكَ لَهُ قُرْبَةً إِلَيْكَ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{6623}\hadithtrans{Abu Huraira reported that he heard Allah's Messenger (ﷺ) as saying:O Allah, for any believing servant whom I curse make that as a source of nearness to Thee on the Day of Resurrection}}
\hadithdefcmd{muslim}{6624}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ زُهَيْرٌ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَخِي ابْنِ شِهَابٍ، عَنْ عَمِّهِ، حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي اتَّخَذْتُ عِنْدَكَ عَهْدًا لَنْ تُخْلِفَنِيهِ فَأَيُّمَا مُؤْمِنٍ سَبَبْتُهُ أَوْ جَلَدْتُهُ فَاجْعَلْ ذَلِكَ كَفَّارَةً لَهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{6624}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:I have held covenant with Thee which Thou wouldst not break, so for any believer whom I curse or beat, make that an expiation on the Day of Resurrection}}
\hadithdefcmd{muslim}{6627}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَأَبُو مَعْنٍ الرَّقَاشِيُّ - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا عُمَرُ، بْنُ يُونُسَ حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْحَاقُ بْنُ أَبِي طَلْحَةَ، حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، قَالَ كَانَتْ عِنْدَ أُمِّ سُلَيْمٍ يَتِيمَةٌ وَهِيَ أُمُّ أَنَسٍ فَرَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم الْيَتِيمَةَ فَقَالَ ‏"‏ آنْتِ هِيَهْ لَقَدْ كَبِرْتِ لاَ كَبِرَ سِنُّكِ ‏"‏ ‏.‏ فَرَجَعَتِ الْيَتِيمَةُ إِلَى أُمِّ سُلَيْمٍ تَبْكِي فَقَالَتْ أُمُّ سُلَيْمٍ مَا لَكِ يَا بُنَيَّةُ قَالَتِ الْجَارِيَةُ دَعَا عَلَىَّ نَبِيُّ اللَّهِ صلى الله عليه وسلم أَنْ لاَ يَكْبَرَ سِنِّي فَالآنَ لاَ يَكْبَرُ سِنِّي أَبَدًا - أَوْ قَالَتْ قَرْنِي - فَخَرَجَتْ أُمُّ سُلَيْمٍ مُسْتَعْجِلَةً تَلُوثُ خِمَارَهَا حَتَّى لَقِيَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا لَكِ يَا أُمَّ سُلَيْمٍ ‏"‏ ‏.‏ فَقَالَتْ يَا نَبِيَّ اللَّهِ أَدَعَوْتَ عَلَى يَتِيمَتِي قَالَ ‏"‏ وَمَا ذَاكِ يَا أُمَّ سُلَيْمٍ ‏"‏ ‏.‏ قَالَتْ زَعَمَتْ أَنَّكَ دَعَوْتَ أَنْ لاَ يَكْبَرَ سِنُّهَا وَلاَ يَكْبَرَ قَرْنُهَا - قَالَ - فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ يَا أُمَّ سُلَيْمٍ أَمَا تَعْلَمِينَ أَنَّ شَرْطِي عَلَى رَبِّي أَنِّي اشْتَرَطْتُ عَلَى رَبِّي فَقُلْتُ إِنَّمَا أَنَا بَشَرٌ أَرْضَى كَمَا يَرْضَى الْبَشَرُ وَأَغْضَبُ كَمَا يَغْضَبُ الْبَشَرُ فَأَيُّمَا أَحَدٍ دَعَوْتُ عَلَيْهِ مِنْ أُمَّتِي بِدَعْوَةٍ لَيْسَ لَهَا بِأَهْلٍ أَنْ تَجْعَلَهَا لَهُ طَهُورًا وَزَكَاةً وَقُرْبَةً يُقَرِّبُهُ بِهَا مِنْهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ وَقَالَ أَبُو مَعْنٍ يُتَيِّمَةٌ ‏.‏ بِالتَّصْغِيرِ فِي الْمَوَاضِعِ الثَّلاَثَةِ مِنَ الْحَدِيثِ ‏.‏\hadithno{6627}\hadithtrans{Anas b. Malik reported that there was an orphan girl with Umm Sulaim (who was the mother of Anas). Allah's Messenger (ﷺ) saw that orphan girl and said:O, it is you; you have grown young. May you not advance in years! That slave-girl returned to Umm Sulaim weeping. Umm Sulaim said: O daughter, what is the matter with you? She said: Allah's Apostle (ﷺ) has invoked curse upon me that I should not grow in age and thus I would never grow in age, or she said, in my (length) of life. Umm Sulaim went out wrapping her head-dress hurriedly until she met Allah's Messenger (ﷺ). He said to her: Umm Sulaim, what is the matter with you? She said: Allah's Apostle, you invoked curse upon my orphan girl. He said: Umm Sulaim, what is that? She said: She (the orphan girl) states you have cursed her saying that she might not grow in age or grow in life. Allah's Messenger (ﷺ) smiled and then said: Umm Sulaim, don't you know that I have made this term with my Lord. And the term with my Lord is that I said to Him: 1 am a human being and I am pleased just as a human being is pleased and I lose temper just as a human being loses temper, so for any person from amongst my Ummah whom I curse and he in no way deserves it, let that, O Lord, be made a source of purification and purity and nearness to (Allah) on the Day of Resurrection}}
\hadithdefcmd{muslim}{6628}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، ح وَحَدَّثَنَا ابْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا أُمَيَّةُ بْنُ خَالِدٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي حَمْزَةَ الْقَصَّابِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنْتُ أَلْعَبُ مَعَ الصِّبْيَانِ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَتَوَارَيْتُ خَلْفَ بَابٍ - قَالَ - فَجَاءَ فَحَطَأَنِي حَطْأَةً وَقَالَ ‏"‏ اذْهَبْ وَادْعُ لِي مُعَاوِيَةَ ‏"‏ ‏.‏ قَالَ فَجِئْتُ فَقُلْتُ هُوَ يَأْكُلُ - قَالَ - ثُمَّ قَالَ لِيَ ‏"‏ اذْهَبْ وَادْعُ لِي مُعَاوِيَةَ ‏"‏ ‏.‏ قَالَ فَجِئْتُ فَقُلْتُ هُوَ يَأْكُلُ فَقَالَ ‏"‏ لاَ أَشْبَعَ اللَّهُ بَطْنَهُ ‏"‏ ‏.‏ قَالَ ابْنُ الْمُثَنَّى قُلْتُ لأُمَيَّةَ مَا حَطَأَنِي قَالَ قَفَدَنِي قَفْدَةً ‏.‏\hadithno{6628}\hadithtrans{Ibn Abbas reported:I was playing with children that Allah's Messenger (ﷺ) happened to pass by (us). I hid myself behind the door. He (the Prophet) came and patted my shoulders and said: Go and call Mu'awiya. I returned and said: He is busy in taking food. He again asked me to go and call Mu'awiya to him. I went (and came back) and said that he was busy in taking food, whereupon he said: May Allah not fill his belly! Ibn Muthanna, said: I asked Umm Umayya what he meant by the word Hatani. He said: It means "he patted my shoulders}}
\hadithdefcmd{muslim}{6629}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنَا أَبُو حَمْزَةَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ كُنْتُ أَلْعَبُ مَعَ الصِّبْيَانِ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاخْتَبَأْتُ مِنْهُ ‏.‏ فَذَكَرَ بِمِثْلِهِ ‏.‏\hadithno{6629}\hadithtrans{This hadith has been transmitted on the authority of Ibn Abbas with a slight variation of wording}}
\hadithdefcmd{muslim}{6630}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ مِنْ شَرِّ النَّاسِ ذَا الْوَجْهَيْنِ الَّذِي يَأْتِي هَؤُلاَءِ بِوَجْهٍ وَهَؤُلاَءِ بِوَجْهٍ ‏"‏ ‏.‏\hadithno{6630}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The worst amongst the people is the double-faced one; he comes to some people with one face and to others with the other face}}
\hadithdefcmd{muslim}{6631}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ شَرَّ النَّاسِ ذُو الْوَجْهَيْنِ الَّذِي يَأْتِي هَؤُلاَءِ بِوَجْهٍ وَهَؤُلاَءِ بِوَجْهٍ ‏"‏ ‏.‏\hadithno{6631}\hadithtrans{Abu Huraira reported that he heard Allah's Messenger (ﷺ) as saying:The worst amongst people is one with the double face. He comes to some people with one face and to others with the other face}}
\hadithdefcmd{muslim}{6632}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَجِدُونَ مِنْ شَرِّ النَّاسِ ذَا الْوَجْهَيْنِ الَّذِي يَأْتِي هَؤُلاَءِ بِوَجْهٍ وَهَؤُلاَءِ بِوَجْهٍ ‏"‏ ‏.‏\hadithno{6632}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:You will find the worst amongst the people one having double face. He comes to some people with one face and to the others with the other face}}
\hadithdefcmd{muslim}{6633}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّ أُمَّهُ أُمَّ كُلْثُومٍ بِنْتَ عُقْبَةَ بْنِ أَبِي مُعَيْطٍ، وَكَانَتْ، مِنَ الْمُهَاجِرَاتِ الأُوَلِ اللاَّتِي بَايَعْنَ النَّبِيَّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يَقُولُ ‏ "‏ لَيْسَ الْكَذَّابُ الَّذِي يُصْلِحُ بَيْنَ النَّاسِ وَيَقُولُ خَيْرًا وَيَنْمِي خَيْرًا ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ وَلَمْ أَسْمَعْ يُرَخَّصُ فِي شَىْءٍ مِمَّا يَقُولُ النَّاسُ كَذِبٌ إِلاَّ فِي ثَلاَثٍ الْحَرْبُ وَالإِصْلاَحُ بَيْنَ النَّاسِ وَحَدِيثُ الرَّجُلِ امْرَأَتَهُ وَحَدِيثُ الْمَرْأَةِ زَوْجَهَا ‏.‏\hadithno{6633}\hadithtrans{Humaid b. 'Abd al-Rahman b. 'Auf reported that his mother Umm Kulthum daughter of 'Uqba b. Abu Mu'ait, and she was one amongst the first emigrants who pledged allegiance to Allah's Apostle (ﷺ), as saying that she heard Allah's Messenger (ﷺ) as saying:A liar is not one who tries to bring reconciliation amongst people and speaks good (in order to avert dispute), or he conveys good. Ibn Shihab said he did not hear that exemption was granted in anything what the people speak as lie but in three cases: in battle, for bringing reconciliation amongst persons and the narration of the words of the husband to his wife, and the narration of the words of a wife to her husband (in a twisted form in order to bring reconciliation between them)}}
\hadithdefcmd{muslim}{6634}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، حَدَّثَنَا مُحَمَّدُ بْنُ مُسْلِمِ بْنِ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّفِي حَدِيثِ صَالِحٍ وَقَالَتْ وَلَمْ أَسْمَعْهُ يُرَخِّصُ فِي شَىْءٍ مِمَّا يَقُولُ النَّاسُ إِلاَّ فِي ثَلاَثٍ ‏.‏ بِمِثْلِ مَا جَعَلَهُ يُونُسُ مِنْ قَوْلِ ابْنِ شِهَابٍ ‏.‏\hadithno{6634}\hadithtrans{This hadith has been narrated on the authority of Ibn Shihab with the same chain of transmitters but with a slight variation of wording}}
\hadithdefcmd{muslim}{6635}{وَحَدَّثَنَاهُ عَمْرٌو النَّاقِدُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ إِلَى قَوْلِهِ ‏ "‏ وَنَمَى خَيْرًا ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ مَا بَعْدَهُ ‏.‏\hadithno{6635}\hadithtrans{This hadith has been transmitted on the authority of Zuhri with a slight variation of wording}}
\hadithdefcmd{muslim}{6636}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ أَبَا إِسْحَاقَ، يُحَدِّثُ عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ إِنَّ مُحَمَّدًا صلى الله عليه وسلم قَالَ ‏"‏ أَلاَ أُنَبِّئُكُمْ مَا الْعَضْهُ هِيَ النَّمِيمَةُ الْقَالَةُ بَيْنَ النَّاسِ ‏"‏ ‏.‏ وَإِنَّ مُحَمَّدًا صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ الرَّجُلَ يَصْدُقُ حَتَّى يُكْتَبَ صِدِّيقًا وَيَكْذِبُ حَتَّى يُكْتَبَ كَذَّابًا ‏"‏ ‏.‏\hadithno{6636}\hadithtrans{Abdullah b. Mas'ud reported that Muhammad (ﷺ) said:Should I inform you that slandering, that is in fact a tale-carrying which creates dissension amongst people, (and) he (further) said: The person tells the truth until he is recorded as truthful, and lie tells a lie until lie is recorded as a liar}}
\hadithdefcmd{muslim}{6637}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الصِّدْقَ يَهْدِي إِلَى الْبِرِّ وَإِنَّ الْبِرَّ يَهْدِي إِلَى الْجَنَّةِ وَإِنَّ الرَّجُلَ لَيَصْدُقُ حَتَّى يُكْتَبَ صِدِّيقًا وَإِنَّ الْكَذِبَ يَهْدِي إِلَى الْفُجُورِ وَإِنَّ الْفُجُورَ يَهْدِي إِلَى النَّارِ وَإِنَّ الرَّجُلَ لَيَكْذِبُ حَتَّى يُكْتَبَ كَذَّابًا ‏"‏ ‏.‏\hadithno{6637}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying:Truth leads one to Paradise and virtue leads one to Paradise and the person tells the truth until he is recorded as truthful, and lie leads to obscenity and obscenity leads to Hell, and the person tells a lie until he is recorded as a liar}}
\hadithdefcmd{muslim}{6638}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهَنَّادُ بْنُ السَّرِيِّ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الصِّدْقَ بِرٌّ وَإِنَّ الْبِرَّ يَهْدِي إِلَى الْجَنَّةِ وَإِنَّ الْعَبْدَ لَيَتَحَرَّى الصِّدْقَ حَتَّى يُكْتَبَ عِنْدَ اللَّهِ صِدِّيقًا وَإِنَّ الْكَذِبَ فُجُورٌ وَإِنَّ الْفُجُورَ يَهْدِي إِلَى النَّارِ وَإِنَّ الْعَبْدَ لَيَتَحَرَّى الْكَذِبَ حَتَّى يُكْتَبَ كَذَّابًا ‏"‏ ‏.‏ قَالَ ابْنُ أَبِي شَيْبَةَ فِي رِوَايَتِهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{6638}\hadithtrans{Abdullah b. Mas'ud reported Allah's Messenger (ﷺ) as saying:Telling of truth is a virtue and virtue leads to Paradise and the servant who endeavours to tell the truth is recorded as truthful, and lie is obscenity and obscenity leads to Hell-Fire, and the servant who endeavours to tell a lie is recorded as a liar. Ibn Abu Shaiba reported this from Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{6639}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، قَالاَ حَدَّثَنَا الأَعْمَشُ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلَيْكُمْ بِالصِّدْقِ فَإِنَّ الصِّدْقَ يَهْدِي إِلَى الْبِرِّ وَإِنَّ الْبِرَّ يَهْدِي إِلَى الْجَنَّةِ وَمَا يَزَالُ الرَّجُلُ يَصْدُقُ وَيَتَحَرَّى الصِّدْقَ حَتَّى يُكْتَبَ عِنْدَ اللَّهِ صِدِّيقًا وَإِيَّاكُمْ وَالْكَذِبَ فَإِنَّ الْكَذِبَ يَهْدِي إِلَى الْفُجُورِ وَإِنَّ الْفُجُورَ يَهْدِي إِلَى النَّارِ وَمَا يَزَالُ الرَّجُلُ يَكْذِبُ وَيَتَحَرَّى الْكَذِبَ حَتَّى يُكْتَبَ عِنْدَ اللَّهِ كَذَّابًا ‏"‏ ‏.‏\hadithno{6639}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying:It is obligatory for you to tell the truth, for truth leads to virtue and virtue leads to Paradise, and the man who continues to speak the truth and endeavours to tell the truth is eventually recorded as truthful with Allah, and beware of telling of a lie for telling of a lie leads to obscenity and obscenity leads to Hell-Fire, and the person who keeps telling lies and endeavours to tell a lie is recorded as a liar with Allah}}
\hadithdefcmd{muslim}{6640}{حَدَّثَنَا مِنْجَابُ بْنُ الْحَارِثِ التَّمِيمِيُّ، أَخْبَرَنَا ابْنُ مُسْهِرٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ، إِبْرَاهِيمَ الْحَنْظَلِيُّ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ وَلَمْ يَذْكُرْ فِي حَدِيثِ عِيسَى ‏"‏ وَيَتَحَرَّى الصِّدْقَ وَيَتَحَرَّى الْكَذِبَ ‏"‏ ‏.‏ وَفِي حَدِيثِ ابْنِ مُسْهِرٍ ‏"‏ حَتَّى يَكْتُبَهُ اللَّهُ ‏"‏ ‏.‏\hadithno{6640}\hadithtrans{This hadith has been reported on the authority of A'mash with the same chain of transmitters and no mention is made in the hadith transmitted on the authority of 'Isa (of these words):" He who endeavours to tell the truth and endeavours to tell a lie," and in the hadith transmitted on the authority of Mushir (the words are):" Until Allah records it}}
\hadithdefcmd{muslim}{6641}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لِقُتَيْبَةَ - قَالاَ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنِ الْحَارِثِ بْنِ سُوَيْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا تَعُدُّونَ الرَّقُوبَ فِيكُمْ ‏"‏ ‏.‏ قَالَ قُلْنَا الَّذِي لاَ يُولَدُ لَهُ ‏.‏ قَالَ ‏"‏ لَيْسَ ذَاكَ بِالرَّقُوبِ وَلَكِنَّهُ الرَّجُلُ الَّذِي لَمْ يُقَدِّمْ مِنْ وَلَدِهِ شَيْئًا ‏"‏ ‏.‏ قَالَ ‏"‏ فَمَا تَعُدُّونَ الصُّرَعَةَ فِيكُمْ ‏"‏ ‏.‏ قَالَ قُلْنَا الَّذِي لاَ يَصْرَعُهُ الرِّجَالُ ‏.‏ قَالَ ‏"‏ لَيْسَ بِذَلِكَ وَلَكِنَّهُ الَّذِي يَمْلِكُ نَفْسَهُ عِنْدَ الْغَضَبِ ‏"‏ ‏.‏\hadithno{6641}\hadithtrans{Abdullah b. Mas'ud reported Allah's Messenger (ﷺ) as saying:Whom do you count as" Raqub" amongst you? They (his Companions) said: One who has no children (the children are born unto him but they do not survive). Thereupon he (the Holy Prophet) said: He is not a Raqub but Raqub is one who does not find his child as the forerunner (in Paradise). He then said: Whom do you count as a wrestler amongst you? We said: He who wrestles with persons. He said: No, it is not he but one who controls himself when in a fit of rage}}
\hadithdefcmd{muslim}{6642}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ مِثْلَ مَعْنَاهُ ‏.‏\hadithno{6642}\hadithtrans{This hadith has been narrated on the authority of A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{6643}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَعَبْدُ الأَعْلَى بْنُ حَمَّادٍ، قَالاَ كِلاَهُمَا قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ الشَّدِيدُ بِالصُّرَعَةِ إِنَّمَا الشَّدِيدُ الَّذِي يَمْلِكُ نَفْسَهُ عِنْدَ الْغَضَبِ ‏"‏ ‏.‏\hadithno{6643}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The strong-man is not one who wrestles well but the strong man is one who controls himself when he is in a fit of rage}}
\hadithdefcmd{muslim}{6644}{حَدَّثَنَا حَاجِبُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لَيْسَ الشَّدِيدُ بِالصُّرَعَةِ ‏"‏ ‏.‏ قَالُوا فَالشَّدِيدُ أَيُّمَ هُوَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الَّذِي يَمْلِكُ نَفْسَهُ عِنْدَ الْغَضَبِ ‏"‏ ‏.‏\hadithno{6644}\hadithtrans{Abu Huraira reported:I heard Allah's Messenger (ﷺ) as saying: One is not strong because of one's wrestling skillfully. They said: Allah's Messenger, then who is strong? He said: He who controls his anger when he is in a fit of rage}}
\hadithdefcmd{muslim}{6645}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ عَبْدِ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ بَهْرَامَ، أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{6645}\hadithtrans{This hadith has been reported on the authority of Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{6646}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ ابْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ سُلَيْمَانَ بْنِ صُرَدٍ، قَالَ اسْتَبَّ رَجُلاَنِ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَجَعَلَ أَحَدُهُمَا تَحْمَرُّ عَيْنَاهُ وَتَنْتَفِخُ أَوْدَاجُهُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي لأَعْرِفُ كَلِمَةً لَوْ قَالَهَا لَذَهَبَ عَنْهُ الَّذِي يَجِدُ أَعُوذُ بِاللَّهِ مِنَ الشَّيْطَانِ الرَّجِيمِ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ وَهَلْ تَرَى بِي مِنْ جُنُونٍ قَالَ ابْنُ الْعَلاَءِ فَقَالَ وَهَلْ تَرَى ‏.‏ وَلَمْ يَذْكُرِ الرَّجُلَ\hadithno{6646}\hadithtrans{Sulaiman b. Surad reported that two persons abused each other in the presence of Allah's Apostle (ﷺ) and the eyes of one of them became red as embers and the veins of his neck were swollen. Thereupon Allah's Messenger (ﷺ) said:I know of a wording, if he were to utter that, his fit of rage (would be no more and that wording is): I seek refuge with Allah from Satan the accursed. The person said: Do you find any madness in me? Ibn al-'Ala' said: Do you see it? And he made no mention of the person}}
\hadithdefcmd{muslim}{6647}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا أَبُو أُسَامَةَ، سَمِعْتُ الأَعْمَشَ، يَقُولُ سَمِعْتُ عَدِيَّ بْنَ ثَابِتٍ، يَقُولُ حَدَّثَنَا سُلَيْمَانُ بْنُ صُرَدٍ، قَالَ اسْتَبَّ رَجُلاَنِ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَجَعَلَ أَحَدُهُمَا يَغْضَبُ وَيَحْمَرُّ وَجْهُهُ فَنَظَرَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنِّي لأَعْلَمُ كَلِمَةً لَوْ قَالَهَا لَذَهَبَ ذَا عَنْهُ أَعُوذُ بِاللَّهِ مِنَ الشَّيْطَانِ الرَّجِيمِ ‏"‏ ‏.‏ فَقَامَ إِلَى الرَّجُلِ رَجُلٌ مِمَّنْ سَمِعَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ أَتَدْرِي مَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم آنِفًا قَالَ ‏"‏ إِنِّي لأَعْلَمُ كَلِمَةً لَوْ قَالَهَا لَذَهَبَ ذَا عَنْهُ أَعُوذُ بِاللَّهِ مِنَ الشَّيْطَانِ الرَّجِيمِ ‏"‏ ‏.‏ فَقَالَ لَهُ الرَّجُلُ أَمَجْنُونًا تَرَانِي\hadithno{6647}\hadithtrans{Sulaiman b. Surad reported that two persons abused each other in the presence of Allah's Apostle (ﷺ) and one of them fell into a rage and his face became red. Allah's Apostle (ﷺ) saw him and said:I know of a wording; if he were to utter that, he would get out (of the fit of anger) (and the wording is): I seek refuge with Allah from Satan, the accursed. Thereupon, a person went to him who had heard that from Allah's Apostle (ﷺ) and said to him: Do you know what Allah's Messenger (ﷺ) said? He (the Holy Prophet) said: I know of a wording; if he were to say that, (the fit) would be no more (and the words are): I seek refuge with Allah from Satan, the accursed. And the person said to him: Do you find me mad?}}
\hadithdefcmd{muslim}{6648}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6648}\hadithtrans{This hadith has been reported on the authority of A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{6649}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَمَّا صَوَّرَ اللَّهُ آدَمَ فِي الْجَنَّةِ تَرَكَهُ مَا شَاءَ اللَّهُ أَنْ يَتْرُكَهُ فَجَعَلَ إِبْلِيسُ يُطِيفُ بِهِ يَنْظُرُ مَا هُوَ فَلَمَّا رَآهُ أَجْوَفَ عَرَفَ أَنَّهُ خُلِقَ خَلْقًا لاَ يَتَمَالَكُ ‏"‏ ‏.‏\hadithno{6649}\hadithtrans{Anas reported Allah's Messenger (ﷺ) as saying:When Allah fashioned Adam in Paradise, He left him as He liked him to leave. Then Iblis roamed round him to see what actually that was and when he found him hollow from within, he recognised that he had been created with a disposition that he would not have control over himself}}
\hadithdefcmd{muslim}{6650}{حَدَّثَنَا أَبُو بَكْرِ بْنُ نَافِعٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادٌ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{6650}\hadithtrans{A hadith like this has been narrated on the authority of Humaid with the same chain of transmitters}}
\hadithdefcmd{muslim}{6651}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي الْحِزَامِيَّ - عَنِ أَبِي، الزِّنَادِ عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا قَاتَلَ أَحَدُكُمْ أَخَاهُ فَلْيَجْتَنِبِ الْوَجْهَ ‏"‏ ‏.‏\hadithno{6651}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When any one of you fights with his brother he should avoid striking at the face}}
\hadithdefcmd{muslim}{6652}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ إِذَا ضَرَبَ أَحَدُكُمْ ‏"‏ ‏.‏\hadithno{6652}\hadithtrans{This hadith has been transmitted on the authority of Abu Zinad and he said:" When one amongst you strikes (at the face)}}
\hadithdefcmd{muslim}{6653}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَاتَلَ أَحَدُكُمْ أَخَاهُ فَلْيَتَّقِ الْوَجْهَ ‏"‏ ‏.‏\hadithno{6653}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:When any one of you fights with his brother, he should spare his face}}
\hadithdefcmd{muslim}{6654}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، سَمِعَ أَبَا، أَيُّوبَ يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا قَاتَلَ أَحَدُكُمْ أَخَاهُ فَلاَ يَلْطِمَنَّ الْوَجْهَ ‏"‏ ‏.‏\hadithno{6654}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When any one of you fights with his brother, he should not slap at the face}}
\hadithdefcmd{muslim}{6655}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنِي أَبِي، حَدَّثَنَا الْمُثَنَّى، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ، حَاتِمٍ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنِ الْمُثَنَّى بْنِ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَبِي أَيُّوبَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَفِي حَدِيثِ ابْنِ حَاتِمٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَاتَلَ أَحَدُكُمْ أَخَاهُ فَلْيَجْتَنِبِ الْوَجْهَ فَإِنَّ اللَّهَ خَلَقَ آدَمَ عَلَى صُورَتِهِ ‏"‏ ‏.‏\hadithno{6655}\hadithtrans{This hadith has been transmitted on the authority of Abu Huraira and in the hadith transmitted on the authority of Ibn Hatim Allah's Apostle (ﷺ) is reported to have said:When any one of you fights with his brother, he should avoid his face for Allah created Adam in His own image}}
\hadithdefcmd{muslim}{6656}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي عَبْدُ الصَّمَدِ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ يَحْيَى، بْنِ مَالِكٍ الْمَرَاغِيِّ - وَهُوَ أَبُو أَيُّوبَ - عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَاتَلَ أَحَدُكُمْ أَخَاهُ فَلْيَجْتَنِبِ الْوَجْهَ ‏"‏ ‏.‏\hadithno{6656}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When any one of you fights with his brother, he should avoid the face}}
\hadithdefcmd{muslim}{6657}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ هِشَامِ بْنِ حَكِيمِ بْنِ حِزَامٍ، قَالَ مَرَّ بِالشَّامِ عَلَى أُنَاسٍ وَقَدْ أُقِيمُوا فِي الشَّمْسِ وَصُبَّ عَلَى رُءُوسِهِمُ الزَّيْتُ فَقَالَ مَا هَذَا قِيلَ يُعَذَّبُونَ فِي الْخَرَاجِ ‏.‏ فَقَالَ أَمَا إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ يُعَذِّبُ الَّذِينَ يُعَذِّبُونَ فِي الدُّنْيَا ‏"‏ ‏.‏\hadithno{6657}\hadithtrans{Urwa reported on the authority of his father that Hisham b. Hakim b. Hizam happened to pass by some people in Syria who had been made to stand in the sun and olive-oil was being poured upon their heads. He said:What is this? It was said: They are being punished for (not paying) the Kharaj (the government revenue). Thereupon he said: Allah would punish those who torment people in this world (without any genuine reason)}}
\hadithdefcmd{muslim}{6658}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، قَالَ مَرَّ هِشَامُ بْنُ حَكِيمِ بْنِ حِزَامٍ عَلَى أُنَاسٍ مِنَ الأَنْبَاطِ بِالشَّامِ قَدْ أُقِيمُوا فِي الشَّمْسِ فَقَالَ مَا شَأْنُهُمْ قَالُوا حُبِسُوا فِي الْجِزْيَةِ ‏.‏ فَقَالَ هِشَامٌ أَشْهَدُ لَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ يُعَذِّبُ الَّذِينَ يُعَذِّبُونَ النَّاسَ فِي الدُّنْيَا ‏"‏ ‏.‏\hadithno{6658}\hadithtrans{Hisham reported on the authority of his father that Hisham b. Hakim b. Hizam happened to pass by people, the farmers of Syria, who had been made to stand in the sun. He said:What is the matter with them? They said: They have been detained for Jizya. Thereupon Hisham said: I bear testimony to the fact that I heard Allah's Messenger (ﷺ) as saying: Allah would torment those who torment people in the world}}
\hadithdefcmd{muslim}{6659}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، وَأَبُو مُعَاوِيَةَ ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، كُلُّهُمْ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ وَزَادَ فِي حَدِيثِ جَرِيرٍ قَالَ وَأَمِيرُهُمْ يَوْمَئِذٍ عُمَيْرُ بْنُ سَعْدٍ عَلَى فِلَسْطِينَ فَدَخَلَ عَلَيْهِ فَحَدَّثَهُ فَأَمَرَ بِهِمْ فَخُلُّوا ‏.‏\hadithno{6659}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters and he made this addition of Jarir that (Hisham b. Hakim) went to Umair b. Sa'd who was then ruler in Palestine and he narrated to him this hadith and he (submitting before the words of the Prophet) commanded that they should be let off and so they were let off}}
\hadithdefcmd{muslim}{6660}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، بْنِ الزُّبَيْرِ أَنَّ هِشَامَ بْنَ حَكِيمٍ، وَجَدَ رَجُلاً وَهُوَ عَلَى حِمْصَ يُشَمِّسُ نَاسًا مِنَ النَّبَطِ فِي أَدَاءِ الْجِزْيَةِ فَقَالَ مَا هَذَا إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ يُعَذِّبُ الَّذِينَ يُعَذِّبُونَ النَّاسَ فِي الدُّنْيَا ‏"‏ ‏.‏\hadithno{6660}\hadithtrans{Urwa b. Zubair reported that Hisham b. Hakim found a person (the ruler of Hims) who had been detaining some Nabateans in connection with the dues of Jizya. He said:What is this? I heard Allah's Messenger (ﷺ) as saying: Allah would torment those persons who torment people in the world}}
\hadithdefcmd{muslim}{6661}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، أَبُو بَكْرٍ حَدَّثَنَا - سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، سَمِعَ جَابِرًا، يَقُولُ مَرَّ رَجُلٌ فِي الْمَسْجِدِ بِسِهَامٍ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَمْسِكْ بِنِصَالِهَا ‏"‏ ‏.‏\hadithno{6661}\hadithtrans{Amr heard Jabir as saying:A person happened to come to the mosque with an arrow; thereupon Allah's Messenger (ﷺ) said to him: Take hold of its pointed head}}
\hadithdefcmd{muslim}{6662}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو الرَّبِيعِ، قَالَ أَبُو الرَّبِيعِ حَدَّثَنَا وَقَالَ، يَحْيَى - وَاللَّفْظُ لَهُ - أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَجُلاً، مَرَّ بِأَسْهُمٍ فِي الْمَسْجِدِ قَدْ أَبْدَى نُصُولَهَا فَأُمِرَ أَنْ يَأْخُذَ بِنُصُولِهَا كَىْ لاَ يَخْدِشَ مُسْلِمًا ‏.‏\hadithno{6662}\hadithtrans{Jabir b. Abdullah reported that a person happened to come to the mosque with arrows and their iron-ends were exposed, so he was commanded that he should grasp the pointed heads so that these might not do any harm to a Muslim}}
\hadithdefcmd{muslim}{6663}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ أَمَرَ رَجُلاً كَانَ يَتَصَدَّقُ بِالنَّبْلِ فِي الْمَسْجِدِ أَنْ لاَ يَمُرَّ بِهَا إِلاَّ وَهُوَ آخِذٌ بِنُصُولِهَا ‏.‏ وَقَالَ ابْنُ رُمْحٍ كَانَ يَصَّدَّقُ بِالنَّبْلِ ‏.‏\hadithno{6663}\hadithtrans{Jabir reported that Allah's Messenger (ﷺ) commanded a person who had been distributing arrows freely in the mosque that he should not move about in the mosque but by catching hold of their iron-heads. Ibn Rumh narrated this with a slight variation of wording}}
\hadithdefcmd{muslim}{6664}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي، مُوسَى أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا مَرَّ أَحَدُكُمْ فِي مَجْلِسٍ أَوْ سُوقٍ وَبِيَدِهِ نَبْلٌ فَلْيَأْخُذْ بِنِصَالِهَا ثُمَّ لْيَأْخُذْ بِنِصَالِهَا ثُمَّ لْيَأْخُذْ بِنِصَالِهَا ‏"‏ ‏.‏ قَالَ فَقَالَ أَبُو مُوسَى وَاللَّهِ مَا مُتْنَا حَتَّى سَدَّدْنَاهَا بَعْضُنَا فِي وُجُوهِ بَعْضٍ ‏.‏\hadithno{6664}\hadithtrans{Abd Musa reported that Allah's Messenger (ﷺ) said:When any one of you happens to go to a meeting or the bazar with an arrow in his hand he must grasp its pointed head; then (he again said): He must grasp its pointed head. Abu Musa said: By Allah, we did not court death until some of us had flung arrows upon the faces of one another}}
\hadithdefcmd{muslim}{6665}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَرَّادٍ الأَشْعَرِيُّ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، - وَاللَّفْظُ لِعَبْدِ اللَّهِ - قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا مَرَّ أَحَدُكُمْ فِي مَسْجِدِنَا أَوْ فِي سُوقِنَا وَمَعَهُ نَبْلٌ فَلْيُمْسِكْ عَلَى نِصَالِهَا بِكَفِّهِ أَنْ يُصِيبَ أَحَدًا مِنَ الْمُسْلِمِينَ مِنْهَا بِشَىْءٍ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ لِيَقْبِضْ عَلَى نِصَالِهَا ‏"‏ ‏.‏\hadithno{6665}\hadithtrans{Abu Musa reported Allah's Apostle (ﷺ) assaying:He who amongst you moves in the mosque or in the bazar and there is an arrow with him he should take hold of its iron-head in his palm, so that none amongst the Muslims should receive any injury from it, or he said, should catch its iron-head}}
\hadithdefcmd{muslim}{6666}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، قَالَ عَمْرٌو حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ مَنْ أَشَارَ إِلَى أَخِيهِ بِحَدِيدَةٍ فَإِنَّ الْمَلاَئِكَةَ تَلْعَنُهُ حَتَّى وَإِنْ كَانَ أَخَاهُ لأَبِيهِ وَأُمِّهِ ‏"‏ ‏.‏\hadithno{6666}\hadithtrans{Abu Huraira reported:Abu'l-Qasim (the kunya of Allah's Messenger, may peace be upon him), said: He who pointed a weapon towards his brother the angels invoke curse upon him even if he is his real brother so long as he does not abandon it (the pointing of weapon towards one's brother Muslim)}}
\hadithdefcmd{muslim}{6667}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{6667}\hadithtrans{Abu Huraira reported a hadith like this from Allah's Apostle (ﷺ) through another chain of transmitters}}
\hadithdefcmd{muslim}{6668}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُشِيرُ أَحَدُكُمْ إِلَى أَخِيهِ بِالسِّلاَحِ فَإِنَّهُ لاَ يَدْرِي أَحَدُكُمْ لَعَلَّ الشَّيْطَانَ يَنْزِعُ فِي يَدِهِ فَيَقَعُ فِي حُفْرَةٍ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{6668}\hadithtrans{Abu Huraira reported a hadith from Allah's Messenger (ﷺ) ; (one of them was this) that Allah's Messenger (ﷺ) said:None amongst you should point a weapon towards his brother, for he does not know that Satan might cause the weapon (to slip) from his hand and (he may injure anyone) and thus he may fall into Hell-Fire}}
\hadithdefcmd{muslim}{6669}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي، صَالِحٍ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَمَا رَجُلٌ يَمْشِي بِطَرِيقٍ وَجَدَ غُصْنَ شَوْكٍ عَلَى الطَّرِيقِ فَأَخَّرَهُ فَشَكَرَ اللَّهُ لَهُ فَغَفَرَ لَهُ ‏"‏ ‏.‏\hadithno{6669}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:While a person was going along the path he found a thorny branch upon it. He pushed it to a side and Allah approved (this action) of his and (as a mark of appreciation) granted him pardon}}
\hadithdefcmd{muslim}{6670}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَرَّ رَجُلٌ بِغُصْنِ شَجَرَةٍ عَلَى ظَهْرِ طَرِيقٍ فَقَالَ وَاللَّهِ لأُنَحِّيَنَّ هَذَا عَنِ الْمُسْلِمِينَ لاَ يُؤْذِيهِمْ ‏.‏ فَأُدْخِلَ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{6670}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:A person while walking along the path saw the branches of a tree lying there. He said: By Allah, I shall remove these from this so that these may not do harm to the Muslims, and he was admitted to Paradise}}
\hadithdefcmd{muslim}{6671}{حَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، حَدَّثَنَا شَيْبَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَقَدْ رَأَيْتُ رَجُلاً يَتَقَلَّبُ فِي الْجَنَّةِ فِي شَجَرَةٍ قَطَعَهَا مِنْ ظَهْرِ الطَّرِيقِ كَانَتْ تُؤْذِي النَّاسَ ‏"‏ ‏.‏\hadithno{6671}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying that he saw a person enjoying himself in Paradise because of the tree that he cut from the path which was a source of inconvenience to the people}}
\hadithdefcmd{muslim}{6672}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ شَجَرَةً كَانَتْ تُؤْذِي الْمُسْلِمِينَ فَجَاءَ رَجُلٌ فَقَطَعَهَا فَدَخَلَ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{6672}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying that there was a tree which caused inconvenience to the Muslims; a person came there and cut that (tree) (and thus entered ) Paradise}}
\hadithdefcmd{muslim}{6673}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ أَبَانَ بْنِ صَمْعَةَ، حَدَّثَنِي أَبُو الْوَازِعِ حَدَّثَنِي أَبُو بَرْزَةَ، قَالَ قُلْتُ يَا نَبِيَّ اللَّهِ عَلِّمْنِي شَيْئًا أَنْتَفِعُ بِهِ قَالَ ‏ "‏ اعْزِلِ الأَذَى عَنْ طَرِيقِ الْمُسْلِمِينَ ‏"‏ ‏.‏\hadithno{6673}\hadithtrans{Abu Barza reported:I said: Allah's Messenger, teach me something so that I may derive benefit from it. He said: Remove the troublesome thing from the paths of the Muslims}}
\hadithdefcmd{muslim}{6674}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو بَكْرِ بْنُ شُعَيْبِ بْنِ الْحَبْحَابِ، عَنْ أَبِي الْوَازِعِ، الرَّاسِبِيِّ عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ، أَنَّ أَبَا بَرْزَةَ، قَالَ قُلْتُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ إِنِّي لاَ أَدْرِي لَعَسَى أَنْ تَمْضِيَ وَأَبْقَى بَعْدَكَ فَزَوِّدْنِي شَيْئًا يَنْفَعُنِي اللَّهُ بِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ افْعَلْ كَذَا افْعَلْ كَذَا - أَبُو بَكْرٍ نَسِيَهُ - وَأَمِرَّ الأَذَى عَنِ الطَّرِيقِ ‏"‏ ‏.‏\hadithno{6674}\hadithtrans{Abu Barza reported that he said to Allah's Messenger (ﷺ):Allah's Messenger, I do not know whether I would survive after you, so confer upon me something by which Allah should benefit me. Thereupon Allah's Messenger (ﷺ) said: Do this and that and remove the troublesome things from the paths}}
\hadithdefcmd{muslim}{6675}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ بْنِ عُبَيْدٍ الضُّبَعِيُّ، حَدَّثَنَا جُوَيْرِيَةُ، - يَعْنِي ابْنَ أَسْمَاءَ - عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عُذِّبَتِ امْرَأَةٌ فِي هِرَّةٍ سَجَنَتْهَا حَتَّى مَاتَتْ فَدَخَلَتْ فِيهَا النَّارَ لاَ هِيَ أَطْعَمَتْهَا وَسَقَتْهَا إِذْ هِيَ حَبَسَتْهَا وَلاَ هِيَ تَرَكَتْهَا تَأْكُلُ مِنْ خَشَاشِ الأَرْضِ ‏"‏ ‏.‏\hadithno{6675}\hadithtrans{Abdullah reported that Allah's Messenger (ﷺ) said:A woman was tormented because of a cat which she had confined until it died and she had to get into Hell. She did not allow it either to eat or drink as it was confined, nor did she free it so that it might eat the vermin of the earth}}
\hadithdefcmd{muslim}{6676}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، وَعَبْدُ اللَّهِ بْنُ جَعْفَرِ بْنِ يَحْيَى بْنِ خَالِدٍ، جَمِيعًا عَنْ مَعْنِ بْنِ عِيسَى، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ جُوَيْرِيَةَ ‏.‏\hadithno{6676}\hadithtrans{The above hadith is narrated through another chain of transmitters with the same meaning}}
\hadithdefcmd{muslim}{6677}{وَحَدَّثَنِيهِ نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عُذِّبَتِ امْرَأَةٌ فِي هِرَّةٍ أَوْثَقَتْهَا فَلَمْ تُطْعِمْهَا وَلَمْ تَسْقِهَا وَلَمْ تَدَعْهَا تَأْكُلُ مِنْ خَشَاشِ الأَرْضِ ‏"‏ ‏.‏\hadithno{6677}\hadithtrans{This hadith has been reported on the authority of Ibn 'Umar through another chain of transmitters. And Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:A woman was tormented because of a cat which she had tied and thus allowed it neither to eat or drink nor set it free so that it might eat the vermin of the earth}}
\hadithdefcmd{muslim}{6678}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ عُبَيْدِ اللَّهِ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{6678}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{6679}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دَخَلَتِ امْرَأَةٌ النَّارَ مِنْ جَرَّاءِ هِرَّةٍ لَهَا - أَوْ هِرٍّ - رَبَطَتْهَا فَلاَ هِيَ أَطْعَمَتْهَا وَلاَ هِيَ أَرْسَلَتْهَا تُرَمِّمُ مِنْ خَشَاشِ الأَرْضِ حَتَّى مَاتَتْ هَزْلاً ‏"‏ ‏.‏\hadithno{6679}\hadithtrans{Abu Huraira reported from Allah's Messenger (ﷺ) A hadith out of which one was this that Allah's Messenger (ﷺ) said:A woman got into Hell-Fire because of a cat whom she had tied, and thus it could not eat, and she did not let it free so that it could devour the vermin of the earth, until it died}}
\hadithdefcmd{muslim}{6680}{حَدَّثَنَا أَحْمَدُ بْنُ يُوسُفَ الأَزْدِيُّ، حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ أَبِي مُسْلِمٍ الأَغَرِّ، أَنَّهُ حَدَّثَهُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَأَبِي، هُرَيْرَةَ قَالاَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْعِزُّ إِزَارُهُ وَالْكِبْرِيَاءُ رِدَاؤُهُ فَمَنْ يُنَازِعُنِي عَذَّبْتُهُ ‏"‏ ‏.‏\hadithno{6680}\hadithtrans{Abu Sa'id Khudri and Abu Huraira reported Allah's Messenger (ﷺ) as saying:Allah, the Exalted and Glorious, said: Glory is His lower garment and Majesty is His cloak and (Allah says, ) He who contends with Me in regard to them I shall torment him}}
\hadithdefcmd{muslim}{6681}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، عَنْ مُعْتَمِرِ بْنِ سُلَيْمَانَ، عَنْ أَبِيهِ، حَدَّثَنَا أَبُو عِمْرَانَ الْجَوْنِيُّ، عَنْ جُنْدَبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَدَّثَ ‏ "‏ أَنَّ رَجُلاً قَالَ وَاللَّهِ لاَ يَغْفِرُ اللَّهُ لِفُلاَنٍ وَإِنَّ اللَّهَ تَعَالَى قَالَ مَنْ ذَا الَّذِي يَتَأَلَّى عَلَىَّ أَنْ لاَ أَغْفِرَ لِفُلاَنٍ فَإِنِّي قَدْ غَفَرْتُ لِفُلاَنٍ وَأَحْبَطْتُ عَمَلَكَ ‏"‏ ‏.‏ أَوْ كَمَا قَالَ ‏.‏\hadithno{6681}\hadithtrans{Jundub reported that Allah's Messenger (ﷺ) stated that a person said:Allah would not forgive such and such (person). Thereupon Allah the Exalted and Glorious, said: Who is he who adjures about Me that I would not grant pardon to so and so; I have granted pardon to so and so and blotted out his deeds (who took an oath that I would not grant pardon to him)}}
\hadithdefcmd{muslim}{6682}{حَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنِي حَفْصُ بْنُ مَيْسَرَةَ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رُبَّ أَشْعَثَ مَدْفُوعٍ بِالأَبْوَابِ لَوْ أَقْسَمَ عَلَى اللَّهِ لأَبَرَّهُ ‏"‏ ‏.‏\hadithno{6682}\hadithtrans{Abu Huraira reported Allah's Messenger (may peace he upon him) as saying:Many a person with disheveled hair and covered with dust is turned away from the doors (whereas he is held in such a high esteem by Allah) that if he were to adjure in the name of Allah (about anything) Allah would fulfil that}}
\hadithdefcmd{muslim}{6683}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ سُهَيْلِ بْنِ أَبِي، صَالِحٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَالَ الرَّجُلُ هَلَكَ النَّاسُ ‏.‏ فَهُوَ أَهْلَكُهُمْ ‏"‏ ‏.‏ قَالَ أَبُو إِسْحَاقَ لاَ أَدْرِي أَهْلَكَهُمْ بِالنَّصْبِ أَوْ أَهْلَكُهُمْ بِالرَّفْعِ ‏.‏\hadithno{6683}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When a person says that people are ruined he is himself ruined. Abu Ishaq said: I do not know whether he said" ahlakahum or ahlakuhum}}
\hadithdefcmd{muslim}{6684}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ رَوْحِ بْنِ الْقَاسِمِ، ح وَحَدَّثَنِي أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، جَمِيعًا عَنْ سُهَيْلٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{6684}\hadithtrans{This hadith has been narrated on the authority of Suhail with the same chain of transmitters}}
\hadithdefcmd{muslim}{6685}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، ح وَحَدَّثَنَا قُتَيْبَةُ، وَمُحَمَّدُ بْنُ رُمْحٍ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، وَيَزِيدُ بْنُ هَارُونَ، كُلُّهُمْ عَنْ يَحْيَى بْنِ سَعِيدٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي الثَّقَفِيَّ - سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، أَخْبَرَنِي أَبُو بَكْرٍ، - وَهُوَ ابْنُ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ - أَنَّ عَمْرَةَ، حَدَّثَتْهُ أَنَّهَا، سَمِعَتْ عَائِشَةَ، تَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا زَالَ جِبْرِيلُ يُوصِينِي بِالْجَارِ حَتَّى ظَنَنْتُ أَنَّهُ لَيُوَرِّثَنَّهُ ‏"‏ ‏.‏\hadithno{6685}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) as saying:Gabriel impressed upon me (kind treatment) towards the neighbour (so much) that I thought as if he would confer upon him the (right) of inheritance}}
\hadithdefcmd{muslim}{6686}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، حَدَّثَنِي هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{6686}\hadithtrans{This hadith has been narrated on the authority of 'A'isha through another chain of transmitters}}
\hadithdefcmd{muslim}{6687}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ عُمَرَ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا زَالَ جِبْرِيلُ يُوصِينِي بِالْجَارِ حَتَّى ظَنَنْتُ أَنَّهُ سَيُوَرِّثُهُ ‏"‏ ‏.‏\hadithno{6687}\hadithtrans{Ibn Umar reported Allah's Messenger (ﷺ) as saying:Gabriel impressed upon me (the kind treatment) towards the neighbour (so much) that I thought as if he would soon confer upon him the (right) of inheritance}}
\hadithdefcmd{muslim}{6688}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لإِسْحَاقَ - قَالَ أَبُو كَامِلٍ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ الصَّمَدِ الْعَمِّيُّ، حَدَّثَنَا أَبُو عِمْرَانَ، الْجَوْنِيُّ عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا أَبَا ذَرٍّ إِذَا طَبَخْتَ مَرَقَةً فَأَكْثِرْ مَاءَهَا وَتَعَاهَدْ جِيرَانَكَ ‏"‏ ‏.‏\hadithno{6688}\hadithtrans{Abu Dharr reported Allah's Messenger (ﷺ) as saying:Abu Dharr, when you prepare the broth, add water to that and give that (as a present) to your neighbour}}
\hadithdefcmd{muslim}{6689}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ إِدْرِيسَ، أَخْبَرَنَا شُعْبَةُ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ حَدَّثَنَا ابْنُ إِدْرِيسَ، أَخْبَرَنَا شُعْبَةُ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ إِنَّ خَلِيلِي صلى الله عليه وسلم أَوْصَانِي ‏ "‏ إِذَا طَبَخْتَ مَرَقًا فَأَكْثِرْ مَاءَهُ ثُمَّ انْظُرْ أَهْلَ بَيْتٍ مِنْ جِيرَانِكَ فَأَصِبْهُمْ مِنْهَا بِمَعْرُوفٍ ‏"‏ ‏.‏\hadithno{6689}\hadithtrans{Abu Dharr reported Allah's Messenger (ﷺ) commanded me thus:Whenever you prepare a broth, add water to it, and have in your mind the members of the household of your neighbours and then give them out of this with courtesy}}
\hadithdefcmd{muslim}{6690}{حَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا أَبُو عَامِرٍ، - يَعْنِي الْخَزَّازَ - عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ لِيَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَحْقِرَنَّ مِنَ الْمَعْرُوفِ شَيْئًا وَلَوْ أَنْ تَلْقَى أَخَاكَ بِوَجْهٍ طَلْقٍ ‏"‏ ‏.‏\hadithno{6690}\hadithtrans{Abu Dharr reported:Allah's Apostle (ﷺ) said to me: Don't consider anything insignificant out of good things even if it is that you meet your brother with a cheerful countenance}}
\hadithdefcmd{muslim}{6691}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، وَحَفْصُ بْنُ غِيَاثٍ، عَنْ بُرَيْدِ، بْنِ عَبْدِ اللَّهِ عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَتَاهُ طَالِبُ حَاجَةٍ أَقْبَلَ عَلَى جُلَسَائِهِ فَقَالَ ‏ "‏ اشْفَعُوا فَلْتُؤْجَرُوا وَلْيَقْضِ اللَّهُ عَلَى لِسَانِ نَبِيِّهِ مَا أَحَبَّ ‏"‏ ‏.‏\hadithno{6691}\hadithtrans{Abu Musa reported that when any needy (person) came to Allah's Messenger (ﷺ) with a need he commanded him to his Companions, saying:Make a recommendation for him, and you would get the reward. Allah, however, gives the verdict through the tongue of His Apostle what He likes most}}
\hadithdefcmd{muslim}{6692}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ، عَنْ جَدِّهِ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا مَثَلُ الْجَلِيسِ الصَّالِحِ وَالْجَلِيسِ السَّوْءِ كَحَامِلِ الْمِسْكِ وَنَافِخِ الْكِيرِ فَحَامِلُ الْمِسْكِ إِمَّا أَنْ يُحْذِيَكَ وَإِمَّا أَنْ تَبْتَاعَ مِنْهُ وَإِمَّا أَنْ تَجِدَ مِنْهُ رِيحًا طَيِّبَةً وَنَافِخُ الْكِيرِ إِمَّا أَنْ يُحْرِقَ ثِيَابَكَ وَإِمَّا أَنْ تَجِدَ رِيحًا خَبِيثَةً ‏"‏ ‏.‏\hadithno{6692}\hadithtrans{Abu Musa reported Allah's Messenger (ﷺ) as saying:The similitude of good company and that of bad company is that of the owner of musk and of the one (iron-smith) blowing bellows, and the owner of musk would either offer you free of charge or you would buy it from him or you would. smell its pleasant odour, and so far as one who blows the. bellows is concerned, he would either burn your clothes or you shall have to smell its repugnant smell}}
\hadithdefcmd{muslim}{6693}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ قُهْزَاذَ، حَدَّثَنَا سَلَمَةُ بْنُ سُلَيْمَانَ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي بَكْرِ بْنِ حَزْمٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، ح وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ بَهْرَامَ، وَأَبُو بَكْرِ بْنُ إِسْحَاقَ - وَاللَّفْظُ لَهُمَا - قَالاَ أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ، أَنَّأَخْبَرَهُ أَنَّ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ جَاءَتْنِي امْرَأَةٌ وَمَعَهَا ابْنَتَانِ لَهَا فَسَأَلَتْنِي فَلَمْ تَجِدْ عِنْدِي شَيْئًا غَيْرَ تَمْرَةٍ وَاحِدَةٍ فَأَعْطَيْتُهَا إِيَّاهَا فَأَخَذَتْهَا فَقَسَمَتْهَا بَيْنَ ابْنَتَيْهَا وَلَمْ تَأْكُلْ مِنْهَا شَيْئًا ثُمَّ قَامَتْ فَخَرَجَتْ وَابْنَتَاهَا فَدَخَلَ عَلَىَّ النَّبِيُّ صلى الله عليه وسلم فَحَدَّثْتُهُ حَدِيثَهَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنِ ابْتُلِيَ مِنَ الْبَنَاتِ بِشَىْءٍ فَأَحْسَنَ إِلَيْهِنَّ كُنَّ لَهُ سِتْرًا مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{6693}\hadithtrans{A'isha, the wife of Allah's Apostle (ﷺ), said:A woman came to me along with her two daughters. She asked me for (charity) but she found nothing with me except one date, so I gave her that. She accepted it and then divided it between her two daughters and herself ate nothing out of that. She then got up and went out, and so did her two daughters. (In the meanwhile) Allah's Apostle (ﷺ) visited me and I narrated to him her story. Thereupon Allah's Apostle (ﷺ) said: He who is involved (in the responsibility) of (bringing up) daughters, and he accords benevolent treatment towards them, there would be protection for him against Hell-Fire}}
\hadithdefcmd{muslim}{6694}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا بَكْرٌ، - يَعْنِي ابْنَ مُضَرَ - عَنِ ابْنِ الْهَادِ، أَنَّ زِيَادَ، بْنَ أَبِي زِيَادٍ مَوْلَى ابْنِ عَيَّاشٍ حَدَّثَهُ عَنْ عِرَاكِ بْنِ مَالِكٍ، سَمِعْتُهُ يُحَدِّثُ، عُمَرَ بْنَ عَبْدِ الْعَزِيزِ عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ جَاءَتْنِي مِسْكِينَةٌ تَحْمِلُ ابْنَتَيْنِ لَهَا فَأَطْعَمْتُهَا ثَلاَثَ تَمَرَاتٍ فَأَعْطَتْ كُلَّ وَاحِدَةٍ مِنْهُمَا تَمْرَةً وَرَفَعَتْ إِلَى فِيهَا تَمْرَةً لِتَأْكُلَهَا فَاسْتَطْعَمَتْهَا ابْنَتَاهَا فَشَقَّتِ التَّمْرَةَ الَّتِي كَانَتْ تُرِيدُ أَنْ تَأْكُلَهَا بَيْنَهُمَا فَأَعْجَبَنِي شَأْنُهَا فَذَكَرْتُ الَّذِي صَنَعَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ إِنَّ اللَّهَ قَدْ أَوْجَبَ لَهَا بِهَا الْجَنَّةَ أَوْ أَعْتَقَهَا بِهَا مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{6694}\hadithtrans{A'isha reported:A poor woman came to me along with her daughters. I gave her three dates. She gave a date to each of them and then she took up one date and brought that to her mouth in order to eat that, but her daughters expressed desire to eat it. She then divided the date that she intended to eat between them. This (kind) treatment of her impressed me and I mentioned that which she did to Allah's Messenger (ﷺ). Thereupon he said: Verily Allah has assured Paradise for her, because of (this act) of her, or He has rescued her from Hell-Fire}}
\hadithdefcmd{muslim}{6695}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ عَالَ جَارِيَتَيْنِ حَتَّى تَبْلُغَا جَاءَ يَوْمَ الْقِيَامَةِ أَنَا وَهُوَ ‏"‏ ‏.‏ وَضَمَّ أَصَابِعَهُ ‏.‏\hadithno{6695}\hadithtrans{Malik reported Allah's Messenger (ﷺ) as saying:He, who brought up two girls properly till they grew up, he and I would come (together) (very closely) on the Day of Resurrection, and he interlaced his fingers (for explaining the point of nearness between him and that person)}}
\hadithdefcmd{muslim}{6696}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمُوتُ لأَحَدٍ مِنَ الْمُسْلِمِينَ ثَلاَثَةٌ مِنَ الْوَلَدِ فَتَمَسَّهُ النَّارُ إِلاَّ تَحِلَّةَ الْقَسَمِ ‏"‏ ‏.‏\hadithno{6696}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:Anyone amongst the Muslims, three of whose children die, and he resigns himself calmly to the will of God, Fire will not touch him but for the fulfilment of the oath}}
\hadithdefcmd{muslim}{6697}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالُوا حَدَّثَنَا سُفْيَانُ، بْنُ عُيَيْنَةَ ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، وَابْنُ، رَافِعٍ عَنْ عَبْدِ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، ‏.‏ بِإِسْنَادِ مَالِكٍ وَبِمَعْنَى حَدِيثِهِ إِلاَّ أَنَّ فِي حَدِيثِ سُفْيَانَ ‏ "‏ فَيَلِجَ النَّارَ إِلاَّ تَحِلَّةَ الْقَسَمِ ‏"‏ ‏.‏\hadithno{6697}\hadithtrans{This hadith has been reported by Zuhri on the authority of Malik, and in the hadith transmitted on the authority of Sufyan (the words are):" He would enter into Fire, except for the fulfilment of the oath}}
\hadithdefcmd{muslim}{6698}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِنِسْوَةٍ مِنَ الأَنْصَارِ ‏"‏ لاَ يَمُوتُ لإِحْدَاكُنَّ ثَلاَثَةٌ مِنَ الْوَلَدِ فَتَحْتَسِبَهُ إِلاَّ دَخَلَتِ الْجَنَّةَ ‏"‏ ‏.‏ فَقَالَتِ امْرَأَةٌ مِنْهُنَّ أَوِ اثْنَيْنِ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أَوِ اثْنَيْنِ ‏"‏ ‏.‏\hadithno{6698}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said to a woman of the Ansar:In case anyone amongst you sees the sad demise of three children of (hers) and she resigns herself to the will of God hoping to get reward, she would be admitted to Paradise. A woman from amongst them said: Allah's Messenger, even if they (the children who die) are two. Thereupon, he (the Holy Prophet, ) said: Even if they are two}}
\hadithdefcmd{muslim}{6699}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، فُضَيْلُ بْنُ حُسَيْنٍ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ الأَصْبَهَانِيِّ عَنْ أَبِي صَالِحٍ، ذَكْوَانَ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ جَاءَتِ امْرَأَةٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ ذَهَبَ الرِّجَالُ بِحَدِيثِكَ فَاجْعَلْ لَنَا مِنْ نَفْسِكَ يَوْمًا نَأْتِيكَ فِيهِ تُعَلِّمُنَا مِمَّا عَلَّمَكَ اللَّهُ ‏.‏ قَالَ ‏"‏ اجْتَمِعْنَ يَوْمَ كَذَا وَكَذَا ‏"‏ ‏.‏ فَاجْتَمَعْنَ فَأَتَاهُنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَعَلَّمَهُنَّ مِمَّا عَلَّمَهُ اللَّهُ ثُمَّ قَالَ ‏"‏ مَا مِنْكُنَّ مِنِ امْرَأَةٍ تُقَدِّمُ بَيْنَ يَدَيْهَا مِنْ وَلَدِهَا ثَلاَثَةً إِلاَّ كَانُوا لَهَا حِجَابًا مِنَ النَّارِ ‏"‏ ‏.‏ فَقَالَتِ امْرَأَةٌ وَاثْنَيْنِ وَاثْنَيْنِ وَاثْنَيْنِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَاثْنَيْنِ وَاثْنَيْنِ وَاثْنَيْنِ ‏"‏ ‏.‏\hadithno{6699}\hadithtrans{Abu Sa'id Khudri reported that a woman came to Allah's Messenger (ﷺ) and said:Allah's Messenger, men receive your instructions; kindly allocate at your convenience a day for us also, on which we would come to you and you would teach us what Allah has taught you. He said: You assemble on such and such a day. They assembled and Allah's Messenger (ﷺ) came to them and taught them what Allah had taught him and he then said: No woman amongst you who sends her three children as her forerunners (in the Hereafter) but they would serve him as a protection against Hell-Fire. A woman said: What about two and two and two? Thereupon Allah's Messenger (ﷺ) said: Even if they are two and two and two}}
\hadithdefcmd{muslim}{6700}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا عُبَيْدُ، اللَّهِ بْنُ مُعَاذٍ حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَصْبَهَانِيِّ، فِي هَذَا الإِسْنَادِ ‏.‏ بِمِثْلِ مَعْنَاهُ وَزَادَا جَمِيعًا عَنْ شُعْبَةَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ الأَصْبَهَانِيِّ قَالَ سَمِعْتُ أَبَا حَازِمٍ يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ قَالَ ‏ "‏ ثَلاَثَةً لَمْ يَبْلُغُوا الْحِنْثَ ‏"‏ ‏.‏\hadithno{6700}\hadithtrans{Abu Huraira reported that he (the Holy Prophet) said:Three (children) who die in childhood}}
\hadithdefcmd{muslim}{6703}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَأَبُو سَعِيدٍ الأَشَجُّ - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالُوا حَدَّثَنَا حَفْصٌ، - يَعْنُونَ ابْنَ غِيَاثٍ ح وَحَدَّثَنَا عُمَرُ بْنُ حَفْصِ، بْنِ غِيَاثٍ حَدَّثَنَا أَبِي، عَنْ جَدِّهِ، طَلْقِ بْنِ مُعَاوِيَةَ عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَتَتِ امْرَأَةٌ النَّبِيَّ صلى الله عليه وسلم بِصَبِيٍّ لَهَا فَقَالَتْ يَا نَبِيَّ اللَّهِ ادْعُ اللَّهَ لَهُ فَلَقَدْ دَفَنْتُ ثَلاَثَةً قَالَ ‏"‏ دَفَنْتِ ثَلاَثَةً ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ لَقَدِ احْتَظَرْتِ بِحِظَارٍ شَدِيدٍ مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ عُمَرُ مِنْ بَيْنِهِمْ عَنْ جَدِّهِ ‏.‏ وَقَالَ الْبَاقُونَ عَنْ طَلْقٍ ‏.‏ وَلَمْ يَذْكُرُوا الْجَدَّ ‏.‏\hadithno{6703}\hadithtrans{Abu Huraira reported that a woman came to Allah's Apostle (ﷺ) with her child and said:Allah's Apostle, invoke Allah's blessing upon him for I have already buried three. He said: You have buried three! She said: Yes. Thereupon he (the Holy Prophet) said: You have, indeed, safeguarded yourself against the torment of Hell with a strong safeguard. 'Umar has made a mention of his father, whereas others have not made a mention of his father}}
\hadithdefcmd{muslim}{6704}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا جَرِيرٌ، عَنْ طَلْقِ بْنِ مُعَاوِيَةَ، النَّخَعِيِّ أَبِي غِيَاثٍ عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم بِابْنٍ لَهَا فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّهُ يَشْتَكِي وَإِنِّي أَخَافُ عَلَيْهِ قَدْ دَفَنْتُ ثَلاَثَةً ‏.‏ قَالَ ‏ "‏ لَقَدِ احْتَظَرْتِ بِحِظَارٍ شَدِيدٍ مِنَ النَّارِ ‏"‏ ‏.‏ قَالَ زُهَيْرٌ عَنْ طَلْقٍ ‏.‏ وَلَمْ يَذْكُرِ الْكُنْيَةَ ‏.‏\hadithno{6704}\hadithtrans{Abu Huraira reported that a woman came to Allah's Apostle (ﷺ) with her child and said:Allah's Messenger, he is ailing, and I am afraid (that he may die), as I have already buried three. Thereupon he said: It (their sad demise) would be a protection against Hell-Fire for you. Zuhair has not mentioned the kunya of Abu Ghiyath; he has mentioned his name}}
\hadithdefcmd{muslim}{6705}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ إِذَا أَحَبَّ عَبْدًا دَعَا جِبْرِيلَ فَقَالَ إِنِّي أُحِبُّ فُلاَنًا فَأَحِبَّهُ - قَالَ - فَيُحِبُّهُ جِبْرِيلُ ثُمَّ يُنَادِي فِي السَّمَاءِ فَيَقُولُ إِنَّ اللَّهَ يُحِبُّ فُلاَنًا فَأَحِبُّوهُ ‏.‏ فَيُحِبُّهُ أَهْلُ السَّمَاءِ - قَالَ - ثُمَّ يُوضَعُ لَهُ الْقَبُولُ فِي الأَرْضِ ‏.‏ وَإِذَا أَبْغَضَ عَبْدًا دَعَا جِبْرِيلَ فَيَقُولُ إِنِّي أُبْغِضُ فُلاَنًا فَأَبْغِضْهُ - قَالَ - فَيُبْغِضُهُ جِبْرِيلُ ثُمَّ يُنَادِي فِي أَهْلِ السَّمَاءِ إِنَّ اللَّهَ يُبْغِضُ فُلاَنًا فَأَبْغِضُوهُ - قَالَ - فَيُبْغِضُونَهُ ثُمَّ تُوضَعُ لَهُ الْبَغْضَاءُ فِي الأَرْضِ ‏"‏ ‏.‏\hadithno{6705}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said:When Allah loves a servant, He calls Gabriel and says: Verily, I so and so; you should also love him, and then Gabriel begins to love him. Then he makes an announcement in the heaven saying: Allah loves so and so and you also love him, and then the inhabitants of the Heaven (the Angels) also begin to love him and then there is conferred honour upon him in the earth; and when Allah is angry with any servant He calls Gabriel and says: I am angry with such and such and you also become angry with him, and then Gabriel also becomes angry and then makes an announcement amongst the inhabitants of heaven: Verily Allah is angry with so-and so, so you also become angry with him, and thus they also become angry with him. Then he becomes the object of wrath on the earth also}}
\hadithdefcmd{muslim}{6706}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - وَقَالَ قُتَيْبَةُ حَدَّثَنَا عَبْدُ الْعَزِيزِ يَعْنِي الدَّرَاوَرْدِيَّ، ح وَحَدَّثَنَاهُ سَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، أَخْبَرَنَا عَبْثَرٌ، عَنِ الْعَلاَءِ بْنِ الْمُسَيَّبِ، ح وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي مَالِكٌ، - وَهُوَ ابْنُ أَنَسٍ - كُلُّهُمْ عَنْ سُهَيْلٍ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّ حَدِيثَ، الْعَلاَءِ بْنِ الْمُسَيَّبِ لَيْسَ فِيهِ ذِكْرُ الْبُغْضِ ‏.‏\hadithno{6706}\hadithtrans{This hadith has been reported on the authority of Suhail with the same chain of transmitters except with this variation that in the hadith transmitted on the authority of 'Ali' b. Musayyib, there is no mention of (the word)" Anger}}
\hadithdefcmd{muslim}{6707}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، بْنِ أَبِي سَلَمَةَ الْمَاجِشُونُ عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، قَالَ كُنَّا بِعَرَفَةَ فَمَرَّ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ وَهُوَ عَلَى الْمَوْسِمِ فَقَامَ النَّاسُ يَنْظُرُونَ إِلَيْهِ فَقُلْتُ لأَبِي يَا أَبَتِ إِنِّي أَرَى اللَّهَ يُحِبُّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ ‏.‏ قَالَ وَمَا ذَاكَ قُلْتُ لِمَا لَهُ مِنَ الْحُبِّ فِي قُلُوبِ النَّاسِ ‏.‏ فَقَالَ بِأَبِيكَ أَنْتَ سَمِعْتَ أَبَا هُرَيْرَةَ يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ جَرِيرٍ عَنْ سُهَيْلٍ ‏.‏\hadithno{6707}\hadithtrans{Suhail b. Abi Salih, reported:We were in Arafa that there happened to pass Umar b. Abd al-'Aziz and he was the Amir of Hajj. People stood up in order to catch a glimpse of him. I said to my father: Father, I think that Allah loves Umar b. Abd al- 'Aziz. He said: How is it? I said: It is because of the love in people's heart for him. Thereupon he said: By One Who created your father, I heard Abu Huraira narrating from Allah's Messenger (ﷺ) a hadith like one transmitted on the authority of Suhail}}
\hadithdefcmd{muslim}{6708}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الأَرْوَاحُ جُنُودٌ مُجَنَّدَةٌ فَمَا تَعَارَفَ مِنْهَا ائْتَلَفَ وَمَا تَنَاكَرَ مِنْهَا اخْتَلَفَ ‏"‏ ‏.‏\hadithno{6708}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) Saying:Souls are troops collected together and those who familiarised with each other (in the heaven from where these come) would have affinity, with one another (in the world) and those amongst them who opposed each other (in the Heaven) would also be divergent (in the world)}}
\hadithdefcmd{muslim}{6709}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا كَثِيرُ بْنُ هِشَامٍ، حَدَّثَنَا جَعْفَرُ بْنُ بُرْقَانَ، حَدَّثَنَا يَزِيدُ بْنُ الأَصَمِّ، عَنْ أَبِي هُرَيْرَةَ، بِحَدِيثٍ يَرْفَعُهُ قَالَ ‏ "‏ النَّاسُ مَعَادِنُ كَمَعَادِنِ الْفِضَّةِ وَالذَّهَبِ خِيَارُهُمْ فِي الْجَاهِلِيَّةِ خِيَارُهُمْ فِي الإِسْلاَمِ إِذَا فَقُهُوا وَالأَرْوَاحُ جُنُودٌ مُجَنَّدَةٌ فَمَا تَعَارَفَ مِنْهَا ائْتَلَفَ وَمَا تَنَاكَرَ مِنْهَا اخْتَلَفَ ‏"‏ ‏.‏\hadithno{6709}\hadithtrans{Abu Huraira narrated directly from Allah's Messenger (ﷺ) that he said:People are like mines of gold and silver; those who were excellent in Jahiliya (during the days of ignorance) are excellent In Islam, when they have, an understanding, and the souls are troops collected together and those who had a mutual familiarity amongst themselves in the store of prenatal existence would have affinity amongst them, (in this world also) and those who opposed one of them, would be at variance with one another}}
\hadithdefcmd{muslim}{6710}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ، أَبِي طَلْحَةَ عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ أَعْرَابِيًّا، قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم مَتَى السَّاعَةُ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا أَعْدَدْتَ لَهَا ‏"‏ ‏.‏ قَالَ حُبَّ اللَّهِ وَرَسُولِهِ ‏.‏ قَالَ ‏"‏ أَنْتَ مَعَ مَنْ أَحْبَبْتَ ‏"‏ ‏.‏\hadithno{6710}\hadithtrans{Anas b. Malik reported that a desert Arab said to Allah's Messenger (ﷺ):When would be the Last Hour? Allah's Messenger (ﷺ) said: What preparation have you made for that? Thereupon he said: The love of Allah and of His Messenger (that is my preparation for the Last Hour) (for the Day of Resurrection). Thereupon he (the Holy Prophet) said: You would be along with one whom you love}}
\hadithdefcmd{muslim}{6713}{حَدَّثَنِي أَبُو الرَّبِيعِ الْعَتَكِيُّ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ مَتَى السَّاعَةُ قَالَ ‏"‏ وَمَا أَعْدَدْتَ لِلسَّاعَةِ ‏"‏ ‏.‏ قَالَ حُبَّ اللَّهِ وَرَسُولِهِ قَالَ ‏"‏ فَإِنَّكَ مَعَ مَنْ أَحْبَبْتَ ‏"‏ ‏.‏ قَالَ أَنَسٌ فَمَا فَرِحْنَا بَعْدَ الإِسْلاَمِ فَرَحًا أَشَدَّ مِنْ قَوْلِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ فَإِنَّكَ مَعَ مَنْ أَحْبَبْتَ ‏"‏ ‏.‏ قَالَ أَنَسٌ فَأَنَا أُحِبُّ اللَّهَ وَرَسُولَهُ وَأَبَا بَكْرٍ وَعُمَرَ فَأَرْجُو أَنْ أَكُونَ مَعَهُمْ وَإِنْ لَمْ أَعْمَلْ بِأَعْمَالِهِمْ ‏.‏\hadithno{6713}\hadithtrans{Anas b. Malik reported that a person came to Allah's Messenger (ﷺ) and said to Allah's Messenger:When would be the Last Hour? Thereupon he (the Holy Prophet) said: What preparation have you made for the Last Hour? He said: The love of Allah and of His Messenger (is my only preparation). Thereupon he (the Holy Prophet) said: You would be along with one whom you love. Anas said: Nothing pleased us more after accepting Islam than the words of Allah's Apostle: You would be along with one whom you love. And Anas said. I love Allah and His Messenger and Abu Bakr and Umar, and I hope that I would be along with them although I have not acted like them}}
\hadithdefcmd{muslim}{6714}{حَدَّثَنَاهُ مُحَمَّدُ بْنُ عُبَيْدٍ الْغُبَرِيُّ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَذْكُرْ قَوْلَ أَنَسٍ فَأَنَا أُحِبُّ ‏.‏ وَمَا بَعْدَهُ ‏.‏\hadithno{6714}\hadithtrans{Anas b. Malik reported Allah's Apostle (ﷺ) this hadith through another chain of transmitters but he did not make mention of the words of Anas:I love, and what follows subsequently}}
\hadithdefcmd{muslim}{6715}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، عُثْمَانُ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ بَيْنَمَا أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم خَارِجَيْنِ مِنَ الْمَسْجِدِ فَلَقِينَا رَجُلاً عِنْدَ سُدَّةِ الْمَسْجِدِ فَقَالَ يَا رَسُولَ اللَّهِ مَتَى السَّاعَةُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا أَعْدَدْتَ لَهَا ‏"‏ ‏.‏ قَالَ فَكَأَنَّ الرَّجُلَ اسْتَكَانَ ثُمَّ قَالَ يَا رَسُولَ اللَّهِ مَا أَعْدَدْتُ لَهَا كَبِيرَ صَلاَةٍ وَلاَ صِيَامٍ وَلاَ صَدَقَةٍ وَلَكِنِّي أُحِبُّ اللَّهَ وَرَسُولَهُ ‏.‏ قَالَ ‏"‏ فَأَنْتَ مَعَ مَنْ أَحْبَبْتَ ‏"‏ ‏.‏\hadithno{6715}\hadithtrans{Anas b. Malik reported:Allah's Messenger (ﷺ) and I were coming out of the mosque that we met a person on the threshold of the mosque and he said to Allah's Messenger (ﷺ): When would be the Last Hour? Allah's Messenger (ﷺ) said: What preparation have you made for that? The man became silent and then said: Allah's Messenger, I have made no significant preparation with prayer and fasting and charity but I, however, love Allah and His Messenger. Thereupon (the Holy Prophet) said: You would be along with one whom you love}}
\hadithdefcmd{muslim}{6716}{حَدَّثَنِي مُحَمَّدُ بْنُ يَحْيَى بْنِ عَبْدِ الْعَزِيزِ الْيَشْكُرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ، جَبَلَةَ أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ ‏.‏\hadithno{6716}\hadithtrans{This hadith has been narrated on the authority of Anas through another chain of transmitters}}
\hadithdefcmd{muslim}{6717}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، سَمِعْتُ أَنَسًا، ح وَحَدَّثَنَا أَبُو غَسَّانَ الْمِسْمَعِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا مُعَاذٌ، - يَعْنِي ابْنَ هِشَامٍ - حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏.‏\hadithno{6717}\hadithtrans{This hadith has been reported on the authority of Anas with different chains of transmitters}}
\hadithdefcmd{muslim}{6718}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، عُثْمَانُ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ تَرَى فِي رَجُلٍ أَحَبَّ قَوْمًا وَلَمَّا يَلْحَقْ بِهِمْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَرْءُ مَعَ مَنْ أَحَبَّ ‏"‏ ‏.‏\hadithno{6718}\hadithtrans{Abdullah reported that a person came to Allah's Messenger (ﷺ) and said to Allah's Messenger (ﷺ):What is your opinion about the person who loves the people but his (acts or deeds are not identical to theirs)? Thereupon Allah's Messenger (ﷺ) said: A person would be along with one whom he loves}}
\hadithdefcmd{muslim}{6719}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، ح وَحَدَّثَنِيهِ بِشْرُ، بْنُ خَالِدٍ أَخْبَرَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - كِلاَهُمَا عَنْ شُعْبَةَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبُو الْجَوَّابِ، حَدَّثَنَا سُلَيْمَانُ بْنُ قَرْمٍ، جَمِيعًا عَنْ سُلَيْمَانَ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{6719}\hadithtrans{A hadith like this has been transmitted on the authority of 'Abdullah}}
\hadithdefcmd{muslim}{6720}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا ابْنُ، نُمَيْرٍ حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَمُحَمَّدُ بْنُ عُبَيْدٍ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ أَبِي مُوسَى، قَالَ أَتَى النَّبِيَّ صلى الله عليه وسلم رَجُلٌ ‏.‏ فَذَكَرَ بِمِثْلِ حَدِيثِ جَرِيرٍ عَنِ الأَعْمَشِ ‏.‏\hadithno{6720}\hadithtrans{Abu Musa, reported that a person came to Allah's Messenger (ﷺ) ; the rest of the hadith is the same}}
\hadithdefcmd{muslim}{6721}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَأَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ فُضَيْلُ بْنُ حُسَيْنٍ - وَاللَّفْظُ لِيَحْيَى - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قِيلَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَرَأَيْتَ الرَّجُلَ يَعْمَلُ الْعَمَلَ مِنَ الْخَيْرِ وَيَحْمَدُهُ النَّاسُ عَلَيْهِ قَالَ ‏ "‏ تِلْكَ عَاجِلُ بُشْرَى الْمُؤْمِنِ ‏"‏ ‏.‏\hadithno{6721}\hadithtrans{Abu Dharr reported:It was said to Allah's Messenger (ﷺ): What is your opinion about the person who has done good deeds and the people praise him? He said: It is glad tidings for a believer (which he has received in this mortal world)}}
\hadithdefcmd{muslim}{6722}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنْ وَكِيعٍ، ح وَحَدَّثَنَا مُحَمَّدُ، بْنُ بَشَّارٍ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي عَبْدُ الصَّمَدِ، ح وَحَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا النَّضْرُ، كُلُّهُمْ عَنْ شُعْبَةَ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، بِإِسْنَادِ حَمَّادِ بْنِ زَيْدٍ ‏.‏ بِمِثْلِ حَدِيثِهِ غَيْرَ أَنَّ فِي، حَدِيثِهِمْ عَنْ شُعْبَةَ غَيْرَ عَبْدِ الصَّمَدِ وَيُحِبُّهُ النَّاسُ عَلَيْهِ ‏.‏ وَفِي حَدِيثِ عَبْدِ الصَّمَدِ وَيَحْمَدُهُ النَّاسُ ‏.‏ كَمَا قَالَ حَمَّادٌ ‏.‏\hadithno{6722}\hadithtrans{This hadith has been narrated through another chain of transmitters also and the one transmitted on the authority of Shu'ba (the words are):" People love him." In the hadith transmitted on the authority of 'Abd-us-Samad (the words are):" People praise him as stated by Hammad}}
