% Auto-generated chapter 48 for tirmidhi
% Hadiths in this chapter: 244

\hadithdefcmd{tirmidhi}{3370}{حَدَّثَنَا عَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا عِمْرَانُ الْقَطَّانُ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ أَبِي الْحَسَنِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ شَيْءٌ أَكْرَمَ عَلَى اللَّهِ تَعَالَى مِنَ الدُّعَاءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ حَدِيثِ عِمْرَانَ الْقَطَّانِ وَعِمْرَانُ الْقَطَّانُ هُوَ ابْنُ دَاوَرَ وَيُكْنَى أَبَا الْعَوَّامِ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ عِمْرَانَ الْقَطَّانِ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{3370}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that:The Prophet said: “There is nothing more honorable with Allah [Most High] than supplication.”}}
\hadithdefcmd{tirmidhi}{3371}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ ابْنِ لَهِيعَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ أَبَانَ بْنِ صَالِحٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الدُّعَاءُ مُخُّ الْعِبَادَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ابْنِ لَهِيعَةَ ‏.‏\hadithno{3371}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that :the Prophet said: “The supplication is the essence of worship.”}}
\hadithdefcmd{tirmidhi}{3372}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ ذَرٍّ، عَنْ يُسَيْعٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الدُّعَاءُ هُوَ الْعِبَادَةُ ‏"‏ ‏.‏ ثُمَّ قَرَأََ ‏:‏ ‏(‏وقالَ رَبُّكُمُ ادْعُونِي أَسْتَجِبْ لَكُمْ إِنَّ الَّذِينَ يَسْتَكْبِرُونَ عَنْ عِبَادَتِي سَيَدْخُلُونَ جَهَنَّمَ دَاخِرِينَ ‏)‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ مَنْصُورٌ وَالأَعْمَشُ عَنْ ذَرٍّ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ذَرٍّ ‏.‏ هُوَ ذَرُّ بْنُ عَبْدِ اللَّهِ الْهَمْدَانِيُّ ثِقَةٌ وَالِدُ عُمَرَ بْنِ ذَرٍّ ‏.‏\hadithno{3372}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{An-Nu`man bin Bashir narrated that:The Prophet said: “The supplication, is worship.” Then he recited: And Your Lord said: “Call upon me, I will respond to you. Verily, those who scorn My worship, they will surely enter Hell humiliated}}
\hadithdefcmd{tirmidhi}{3373}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنْ أَبِي الْمَلِيحِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لَمْ يَسْأَلِ اللَّهَ يَغْضَبْ عَلَيْهِ ‏"‏ ‏.‏ قَالَ وَرَوَى وَكِيعٌ وَغَيْرُ وَاحِدٍ عَنْ أَبِي الْمَلِيحِ هَذَا الْحَدِيثَ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَأَبُو الْمَلِيحِ اسْمُهُ صَبِيحٌ سَمِعْتُ مُحَمَّدًا يَقُولُهُ وَقَالَ يُقَالُ لَهُ الْفَارِسِيُّ ‏.‏\hadithno{3373}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah (ra) narrated that :the Messenger of Allah (ﷺ) said: “Indeed, he who does not ask Allah, he gets angry with him.”}}
\hadithdefcmd{tirmidhi}{3374}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا مَرْحُومُ بْنُ عَبْدِ الْعَزِيزِ الْعَطَّارُ حَدَّثَنَا أَبُو نَعَامَةَ السَّعْدِيُّ عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ عَنْ أَبِي مُوسَى الْأَشْعَرِيِّ رَضِيَ اللَّهُ عَنْهُ قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ فِي غَزَاةٍ فَلَمَّا قَفَلْنَا أَشْرَفْنَا عَلَى الْمَدِينَةِ فَكَبَّرَ النَّاسُ تَكْبِيرَةً وَرَفَعُوا بِهَا أَصْوَاتَهُمْ فَقَالَ رَسُولُ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ إِنَّ رَبَّكُمْ لَيْسَ بِأَصَمَّ وَلَا غَائِبٍ هُوَ بَيْنَكُمْ وَبَيْنَ رُءُوسِ رِحَالِكُمْ ثُمَّ قَالَ يَا عَبْدَ اللَّهِ بْنَ قَيْسٍ أَلَا أُعَلِّمُكَ كَنْزًا مِنْ كُنُوزِ الْجَنَّةِ لَا حَوْلَ وَلَا قُوَّةَ إِلَّا بِاللَّهِ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَأَبُو عُثْمَانَ النَّهْدِيُّ اسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ مُلٍّ وَأَبُو نَعَامَةَ السَّعْدِيُّ اسْمُهُ عَمْرُو بْنُ عِيسَى. حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ حُمَيْدٍ أَبِي الْمَلِيحِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{3374}\hadithtrans{Abu Musa Al-Ash`ari (ra) said:“We were with the Messenger of Allah (ﷺ) on a military expedition. When we returned, we overlooked Al-Madinah, and the people were pronouncing the Takbīr, and they raised their voices with it. The Messenger of Allah (ﷺ) said: ‘Verily, your Lord is not deaf nor absent, He is between you and between the heads of your mounts.’ Then he said: ‘O `Abdullah bin Qais, should I not inform you of a treasure from the treasures of Paradise: Lā ḥawla wa lā quwwata illā billāh (There is no might or power except by Allah).’”}}
\hadithdefcmd{tirmidhi}{3375}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ عَمْرِو بْنِ قَيْسٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ، رضى الله عنه أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ إِنَّ شَرَائِعَ الإِسْلاَمِ قَدْ كَثُرَتْ عَلَىَّ فَأَخْبِرْنِي بِشَيْءٍ أَتَشَبَّثُ بِهِ ‏.‏ قَالَ ‏ "‏ لاَ يَزَالُ لِسَانُكَ رَطْبًا مِنْ ذِكْرِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3375}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Busr (ra) narrated that:A man said: “O Messenger of Allah (ﷺ), indeed, the legislated acts of Islam have become too much for me, so inform me of a thing that I should stick to.” He (ﷺ) said: “Let not your tongue cease to be moist with the remembrance of Allah.”}}
\hadithdefcmd{tirmidhi}{3376}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ دَرَّاجٍ، عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ أَىُّ الْعِبَادِ أَفْضَلُ دَرَجَةً عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ قَالَ ‏"‏ الذَّاكِرُونَ اللَّهَ كَثِيرًا وَالذَّاكِرَاتُ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ وَمِنَ الْغَازِي فِي سَبِيلِ اللَّهِ قَالَ ‏"‏ لَوْ ضَرَبَ بِسَيْفِهِ فِي الْكُفَّارِ وَالْمُشْرِكِينَ حَتَّى يَنْكَسِرَ وَيَخْتَضِبَ دَمًا لَكَانَ الذَّاكِرُونَ اللَّهَ كَثِيرًا أَفْضَلَ مِنْهُ دَرَجَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ دَرَّاجٍ ‏.‏\hadithno{3376}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa’eed Al-Khudri narrated that:The Messenger of Allah was asked: “Which of the worshippers is superior in rank with Allah on the Day of Judgment?” He said: “Those men who remember Allah much [and women].” He said: “I said: ‘O Messenger of Allah! What about the fighter in the cause of Allah?’ He said: ‘If he were to strike with his sword among the disbelievers and the idolater, until it breaks, and he (or it) is dyed with blood, those who remember Allah much would still be superior in rank.”}}
\hadithdefcmd{tirmidhi}{3377}{حَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدٍ، هُوَ ابْنُ أَبِي هِنْدٍ عَنْ زِيَادٍ، مَوْلَى ابْنِ عَيَّاشٍ عَنْ أَبِي بَحْرِيَّةَ، عَنْ أَبِي الدَّرْدَاءِ، رَضِيَ اللَّهُ عَنْهُ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَلاَ أُنَبِّئُكُمْ بِخَيْرِ أَعْمَالِكُمْ وَأَزْكَاهَا عِنْدَ مَلِيكِكُمْ وَأَرْفَعِهَا فِي دَرَجَاتِكُمْ وَخَيْرٌ لَكُمْ مِنْ إِنْفَاقِ الذَّهَبِ وَالْوَرِقِ وَخَيْرٌ لَكُمْ مِنْ أَنْ تَلْقَوْا عَدُوَّكُمْ فَتَضْرِبُوا أَعْنَاقَهُمْ وَيَضْرِبُوا أَعْنَاقَكُمْ ‏"‏ ‏.‏ قَالُوا بَلَى ‏.‏ قَالَ ‏"‏ ذِكْرُ اللَّهِ تَعَالَى ‏"‏ ‏.‏ فَقَالَ مُعَاذُ بْنُ جَبَلٍ رضى الله عنه مَا شَيْءٌ أَنْجَى مِنْ عَذَابِ اللَّهِ مِنْ ذِكْرِ اللَّهِ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدٍ مِثْلَ هَذَا بِهَذَا الإِسْنَادِ وَرَوَى بَعْضُهُمْ عَنْهُ فَأَرْسَلَهُ ‏.‏\hadithno{3377}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{Abu Ad-Darda [may Allah be pleased with him] narrated that :the Prophet said: “Should I not inform you of the best of your deed, and the purest of them with your Master, and the highest of them in your ranks, and what is better for you than spending gold and silver, and better for you than meeting your enemy and striking their necks, and they strike your necks?” They said: “Of course.” He said, “The remembrance of Allah [Most High].” [Then] Mu’adh bin Jabal [may Allah be pleased with him] said: “There is nothing that brings more salvation from the punishment of Allah than the remembrance of Allah.”}}
\hadithdefcmd{tirmidhi}{3378}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَغَرِّ أَبِي مُسْلِمٍ، أَنَّهُ شَهِدَ عَلَى أَبِي هُرَيْرَةَ وَأَبِي سَعِيدٍ الْخُدْرِيِّ أَنَّهُمَا شَهِدَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَا مِنْ قَوْمٍ يَذْكُرُونَ اللَّهَ إِلاَّ حَفَّتْ بِهِمُ الْمَلاَئِكَةُ وَغَشِيَتْهُمُ الرَّحْمَةُ وَنَزَلَتْ عَلَيْهِمُ السَّكِينَةُ وَذَكَرَهُمُ اللَّهُ فِيمَنْ عِنْدَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ حَدَّثَنَا يُوسُفُ بْنُ يَعْقُوبَ، حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الأَغَرَّ أَبَا مُسْلِمٍ، قَالَ أَشْهَدُ عَلَى أَبِي سَعِيدٍ وَأَبِي هُرَيْرَةَ رضى الله عنهما أَنَّهُمَا شَهِدَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ مِثْلَهُ ‏.‏\hadithno{3378}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Al-Agharr Abu Muslim narrated that:He bears witness, from Abu Hurairah and Abu Sa’eed Al-Khudri, that they bear witness, from the Messenger of Allah, that he said: “There is no group that remembers Allah, except that the angels encompass them, mercy covers them, and tranquility descends upon them: and Allah remembers (mentions) them before those who are with Him.”}}
\hadithdefcmd{tirmidhi}{3379}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مَرْحُومُ بْنُ عَبْدِ الْعَزِيزِ الْعَطَّارُ، حَدَّثَنَا أَبُو نَعَامَةَ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ خَرَجَ مُعَاوِيَةُ إِلَى الْمَسْجِدِ فَقَالَ مَا يُجْلِسُكُمْ قَالُوا جَلَسْنَا نَذْكُرُ اللَّهَ قَالَ آللَّهِ مَا أَجْلَسَكُمْ إِلاَّ ذَاكَ قَالُوا وَاللَّهِ مَا أَجْلَسَنَا إِلاَّ ذَاكَ ‏.‏ قَالَ أَمَا إِنِّي مَا أَسْتَحْلِفُكُمْ تُهْمَةً لَكُمْ وَمَا كَانَ أَحَدٌ بِمَنْزِلَتِي مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَقَلَّ حَدِيثًا عَنْهُ مِنِّي إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ عَلَى حَلْقَةٍ مِنْ أَصْحَابِهِ فَقَالَ ‏"‏ مَا يُجْلِسُكُمْ ‏"‏ ‏.‏ قَالُوا جَلَسْنَا نَذْكُرُ اللَّهَ وَنَحْمَدُهُ لِمَا هَدَانَا لِلإِسْلاَمِ وَمَنَّ عَلَيْنَا بِهِ ‏.‏ فَقَالَ ‏"‏ آللَّهِ مَا أَجْلَسَكُمْ إِلاَّ ذَاكَ ‏"‏ ‏.‏ قَالُوا آللَّهِ مَا أَجْلَسَنَا إِلاَّ ذَاكَ ‏.‏ قَالَ ‏"‏ أَمَا إِنِّي لَمْ أَسْتَحْلِفْكُمْ لِتُهْمَةٍ لَكُمْ إِنَّهُ أَتَانِي جِبْرِيلُ فَأَخْبَرَنِي أَنَّ اللَّهَ يُبَاهِي بِكُمُ الْمَلاَئِكَةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَأَبُو نَعَامَةَ السَّعْدِيُّ اسْمُهُ عَمْرُو بْنُ عِيسَى وَأَبُو عُثْمَانَ النَّهْدِيُّ اسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ مَلٍّ ‏.‏\hadithno{3379}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Sa’eed Al Khudri narrated the:Mu’awiyah came out to the Masjid and said: “What has caused you to gather for this sitting.” They said: “We gathered so that we may remember Allah.” He said, “By Allah, nothing caused you to gather for this sitting except for that?” They said, “By Allah, nothing caused us to gather for this sitting except for that.” He said: “Indeed, I did not ask you out of suspicion, and there was no one in the position I was from the Messenger of Allah who narrates less Ahadith from him than me. Indeed the Messenger of Allah came out upon a circle of his Companions and said: ‘what has caused you to gather for this sitting?’ They said: ‘We have gathered for this sitting to remember Allah, and praise Him for His having guided us to Islam, and having bestowed blessings upon us.’ So he said: ‘By Allah, nothing caused you to gather for this sitting except for that?’ He said: ‘Indeed, I did not ask you out of suspicion, verily Jibra’il came to me and informed me that Allah boasts of you to the angels.’”}}
\hadithdefcmd{tirmidhi}{3380}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ صَالِحٍ، مَوْلَى التَّوْأَمَةِ عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا جَلَسَ قَوْمٌ مَجْلِسًا لَمْ يَذْكُرُوا اللَّهَ فِيهِ وَلَمْ يُصَلُّوا عَلَى نَبِيِّهِمْ إِلاَّ كَانَ عَلَيْهِمْ تِرَةً فَإِنْ شَاءَ عَذَّبَهُمْ وَإِنْ شَاءَ غَفَرَ لَهُمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَمَعْنَى قَوْلِهِ تِرَةً يَعْنِي حَسْرَةً وَنَدَامَةً ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْمَعْرِفَةِ بِالْعَرَبِيَّةِ: التِّرَةُ هُوَ الثَّأْرُ\hadithno{3380}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah [may Allah be pleased with him] narrated that :the Prophet said: “No group gather in a sitting in which they do not remember Allah, nor sent Salat upon their Prophet, except it will be a source of remorse for them. If He wills, He will punish them, and if He wills, He will forgive them.”}}
\hadithdefcmd{tirmidhi}{3381}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ أَحَدٍ يَدْعُو بِدُعَاءٍ إِلاَّ آتَاهُ اللَّهُ مَا سَأَلَ أَوْ كَفَّ عَنْهُ مِنَ السُّوءِ مِثْلَهُ مَا لَمْ يَدْعُ بِإِثْمٍ أَوْ قَطِيعَةِ رَحِمٍ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَعُبَادَةَ بْنِ الصَّامِتِ ‏.‏\hadithno{3381}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Jabir narrated that :the Messenger of Allah said: “There is none who utters a supplication, except that Allah gives him what he asked, or prevents evil from him that is equal to it – as long as he does not supplicate for something evil, or the cutting of ties of the womb.”}}
\hadithdefcmd{tirmidhi}{3382}{حَدَّثَنَا مُحَمَّدُ بْنُ مَرْزُوقٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ وَاقِدٍ، حَدَّثَنَا سَعِيدُ بْنُ عَطِيَّةَ اللَّيْثِيُّ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَرَّهُ أَنْ يَسْتَجِيبَ اللَّهُ لَهُ عِنْدَ الشَّدَائِدِ وَالْكُرَبِ فَلْيُكْثِرِ الدُّعَاءَ فِي الرَّخَاءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{3382}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah [may Allah be pleased with him] narrated that:The Messenger of Allah said: “Whoever wishes that Allah would respond to him during hardship and grief, then let him supplicate plentifully when at ease.”}}
\hadithdefcmd{tirmidhi}{3383}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبِ بْنِ عَرَبِيٍّ، حَدَّثَنَا مُوسَى بْنُ إِبْرَاهِيمَ بْنِ كَثِيرٍ الأَنْصَارِيُّ، قَالَ سَمِعْتُ طَلْحَةَ بْنَ خِرَاشٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، رضى الله عنهما يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَفْضَلُ الذِّكْرِ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَفْضَلُ الدُّعَاءِ الْحَمْدُ لِلَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مُوسَى بْنِ إِبْرَاهِيمَ ‏.‏ وَقَدْ رَوَى عَلِيُّ بْنُ الْمَدِينِيِّ وَغَيْرُ وَاحِدٍ عَنْ مُوسَى بْنِ إِبْرَاهِيمَ هَذَا الْحَدِيثَ ‏.‏\hadithno{3383}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Jabir bin `Abdullah (ra) narrated that :the Messenger of Allah (ﷺ) said: “The best remembrance is: ‘there is none worthy of worship except Allah (Lā ilāha illallāh)’ and the best supplication is: ‘All praise is due to Allah (Al-ḥamdulillāh).’”}}
\hadithdefcmd{tirmidhi}{3384}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَمُحَمَّدُ بْنُ عُبَيْدٍ الْمُحَارِبِيُّ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنْ أَبِيهِ، عَنْ خَالِدِ بْنِ سَلَمَةَ، عَنِ الْبَهِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَذْكُرُ اللَّهَ عَلَى كُلِّ أَحْيَانِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ يَحْيَى بْنِ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ وَالْبَهِيُّ اسْمُهُ عَبْدُ اللَّهِ ‏.‏\hadithno{3384}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{A'ishah (ra) narrated that :the Messenger of Allah (ﷺ) used to remember Allah in all of his affairs}}
\hadithdefcmd{tirmidhi}{3385}{حَدَّثَنَا نَصْرُ بْنُ عَبْدِ الرَّحْمَنِ الْكُوفِيُّ، حَدَّثَنَا أَبُو قَطَنٍ، عَنْ حَمْزَةَ الزَّيَّاتِ، عَنْ أَبِي إِسْحَاقَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا ذَكَرَ أَحَدًا فَدَعَا لَهُ بَدَأَ بِنَفْسِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ وَأَبُو قَطَنٍ اسْمُهُ عَمْرُو بْنُ الْهَيْثَمِ ‏.‏\hadithno{3385}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn `Abbas narrated from Ubayy bin Ka`b that :whenever the Messenger of Allah (ﷺ) would mention someone and supplicate for him, he would begin with himself (ﷺ)}}
\hadithdefcmd{tirmidhi}{3386}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى وَإِبْرَاهِيمُ بْنُ يَعْقُوبَ وَغَيْرُ وَاحِدٍ قَالُوا حَدَّثَنَا حَمَّادُ بْنُ عِيسَى الْجُهَنِيُّ، عَنْ حَنْظَلَةَ بْنِ أَبِي سُفْيَانَ الْجُمَحِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، رَضِيَ اللَّهُ عَنْهُ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا رَفَعَ يَدَيْهِ فِي الدُّعَاءِ لَمْ يَحُطَّهُمَا حَتَّى يَمْسَحَ بِهِمَا وَجْهَهُ ‏.‏ قَالَ مُحَمَّدُ بْنُ الْمُثَنَّى فِي حَدِيثِهِ لَمْ يَرُدَّهُمَا حَتَّى يَمْسَحَ بِهِمَا وَجْهَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ حَمَّادِ بْنِ عِيسَى ‏.‏ وَقَدْ تَفَرَّدَ بِهِ وَهُوَ قَلِيلُ الْحَدِيثِ وَقَدْ حَدَّثَ عَنْهُ النَّاسُ حَنْظَلَةُ بْنُ أَبِي سُفْيَانَ ثِقَةٌ وَثَّقَهُ يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ ‏.‏\hadithno{3386}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Umar bin Al-Khattab [may Allah be pleased with him] narrated:“Whenever the Messenger of Allah would raise his hands in supplication, he would not lower them until he had wiped his face with them.”}}
\hadithdefcmd{tirmidhi}{3387}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى ابْنِ أَزْهَرَ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يُسْتَجَابُ لأَحَدِكُمْ مَا لَمْ يَعْجَلْ يَقُولُ دَعَوْتُ فَلَمْ يُسْتَجَبْ لِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَأَبُو عُبَيْدٍ اسْمُهُ سَعْدٌ وَهُوَ مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ أَزْهَرَ وَيُقَالُ مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَعَبْدُ الرَّحْمَنِ بْنُ أَزْهَرَ هُوَ ابْنُ عَمِّ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ رضى الله عنه ‏.‏\hadithno{3387}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :the Prophet said: “One of you will be responded to, so long as he is not hasty, saying: ‘I supplicated, and I was not responded to.’”}}
\hadithdefcmd{tirmidhi}{3388}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، - وَهُوَ الطَّيَالِسِيُّ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، عَنْ أَبِيهِ، عَنْ أَبَانَ بْنِ عُثْمَانَ، قَالَ سَمِعْتُ عُثْمَانَ بْنَ عَفَّانَ، رضى الله عنه يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ عَبْدٍ يَقُولُ فِي صَبَاحِ كُلِّ يَوْمٍ وَمَسَاءِ كُلِّ لَيْلَةٍ بِسْمِ اللَّهِ الَّذِي لاَ يَضُرُّ مَعَ اسْمِهِ شَيْءٌ فِي الأَرْضِ وَلاَ فِي السَّمَاءِ وَهُوَ السَّمِيعُ الْعَلِيمُ ثَلاَثَ مَرَّاتٍ فَيَضُرُّهُ شَيْءٌ ‏"‏ ‏.‏ وَكَانَ أَبَانُ قَدْ أَصَابَهُ طَرَفُ فَالَجِ فَجَعَلَ الرَّجُلُ يَنْظُرُ إِلَيْهِ فَقَالَ لَهُ أَبَانُ مَا تَنْظُرُ أَمَا إِنَّ الْحَدِيثَ كَمَا حَدَّثْتُكَ وَلَكِنِّي لَمْ أَقُلْهُ يَوْمَئِذٍ لِيُمْضِيَ اللَّهُ عَلَىَّ قَدَرَهُ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3388}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Aban bin `Uthman said:“I heard `Uthman bin `Affan (ra) saying: ‘The Messenger of Allah (ﷺ) said: “There is no worshiper who says, in the morning of every day, and the evening of every night: ‘In the Name of Allah, who with His Name, nothing in the earth or the heavens can cause harm, and He is the Hearing, the Knowing (Bismillāh, alladhi lā yaḍurru ma`a ismihi shai'un fil-arḍi wa lā fis-samā', wa huwas-Samī`ul `Alīm)’ – three times, (except that) nothing shall harm him.” And Aban had been stricken with a type of semi-paralysis, so a man began to look at him, so Aban said to him, “What are you looking at? Indeed the Hadith is as I reported it to you, but I did not say it one day, so Allah brought about His decree upon me.”}}
\hadithdefcmd{tirmidhi}{3389}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، عَنْ أَبِي سَعْدٍ، سَعِيدِ بْنِ الْمَرْزُبَانِ عَنْ أَبِي سَلَمَةَ، عَنْ ثَوْبَانَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَالَ حِينَ يُمْسِي رَضِيتُ بِاللَّهِ رَبًّا وَبِالإِسْلاَمِ دِينًا وَبِمُحَمَّدٍ نَبِيًّا كَانَ حَقًّا عَلَى اللَّهِ أَنْ يُرْضِيَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3389}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Thawban (ra) said:“The Messenger of Allah (ﷺ) said: ‘Whoever says when he reaches the evening: “I am pleased with Allah as (my) Lord, with Islam as (my) religion, and with Muhammad (ﷺ) as (my) Prophet (Raḍītu billāhi rabban wabil-Islāmi dīnan wa bi-Muḥammadin nabiyyan) it is a duty upon Allah to please him.’” (Hasan Gharib)}}
\hadithdefcmd{tirmidhi}{3390}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، عَنْ إِبْرَاهِيمَ بْنِ سُوَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَمْسَى قَالَ ‏"‏ أَمْسَيْنَا وَأَمْسَى الْمُلْكُ لِلَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ أُرَاهُ قَالَ فِيهَا لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَيْءٍ قَدِيرٌ أَسْأَلُكَ خَيْرَ مَا فِي هَذِهِ اللَّيْلَةِ وَخَيْرَ مَا بَعْدَهَا وَأَعُوذُ بِكَ مِنْ شَرِّ هَذِهِ اللَّيْلَةِ وَشَرِّ مَا بَعْدَهَا وَأَعُوذُ بِكَ مِنَ الْكَسَلِ وَسُوءِ الْكِبَرِ وَأَعُوذُ بِكَ مِنْ عَذَابِ النَّارِ وَعَذَابِ الْقَبْرِ ‏"‏ ‏.‏ وَإِذَا أَصْبَحَ قَالَ ذَلِكَ أَيْضًا ‏"‏ أَصْبَحْنَا وَأَصْبَحَ الْمُلْكُ لِلَّهِ وَالْحَمْدُ لِلَّهِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَاهُ شُعْبَةُ بِهَذَا الإِسْنَادِ عَنِ ابْنِ مَسْعُودٍ لَمْ يَرْفَعْهُ ‏.‏\hadithno{3390}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah said:“When he reached the evening, the Prophet (ﷺ) used to say, ‘We have reached the evening, and the Dominion has reached the evening, while belonging to Allah. And all praise belongs to Allah. None has the right to be worshiped but Allah, alone, without partner. (Amsaina wa amsal-mulku lillāh, wal-ḥamdullilāh, wa lā ilāha illallāh, waḥdahu lā sharīka lahu)’ – I think he said [in it]: - ‘To Him belongs the Dominion, and to Him is the praise, and He is capable of all things. I ask You for the good that is in this night, and the good of what is after it, and I seek refuge in You from the evil of this night, and the evil of what is after it, and I seek refuge in You from laziness and helpless old age. And I seek refuge in You from the punishment of the Fire and the punishment of the grave (Lahul-mulku wa lahul-ḥamdu, wa huwa `alā kulli shai'in qadīr. Asa'luka khaira mā fī hādhihil-lailah, wa khaira mā ba`dahā, wa a`ūdhu bika min sharri hādhihil-lailati wa sharri mā ba`dahā, wa a`ūdhu bika minal-kasali wa sū'il-kibar, wa a`ūdhu bika min `adhābin-nāri wa `adhābil-qabr).’ And when he reached the morning, he (ﷺ) used to say, ‘We have reached the morning, and the Dominion has reached the morning, while belonging to Allah. And all praise belongs to Allah (Aṣbaḥnā wa aṣbaḥal-mulku lillāh, wal-ḥamdulillāh).’”}}
\hadithdefcmd{tirmidhi}{3391}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، أَخْبَرَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُ أَصْحَابَهُ يَقُولُ ‏ "‏ إِذَا أَصْبَحَ أَحَدُكُمْ فَلْيَقُلِ اللَّهُمَّ بِكَ أَصْبَحْنَا وَبِكَ أَمْسَيْنَا وَبِكَ نَحْيَا وَبِكَ نَمُوتُ وَإِلَيْكَ الْمَصِيرُ ‏.‏ وَإِذَا أَمْسَى فَلْيَقُلِ اللَّهُمَّ بِكَ أَمْسَيْنَا وَبِكَ أَصْبَحْنَا وَبِكَ نَحْيَا وَبِكَ نَمُوتُ وَإِلَيْكَ النُّشُورُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{3391}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah (ra) said:The Messenger of Allah (ﷺ) used to teach his Companions, saying: “When one of you reached the morning, then let him say: ‘O Allah, by You we enter the morning, and by You we enter the evening, and be You we live, and by You we died, and to You is the Return (Allāhumma bika aṣbaḥnā wa bika amsainā wa bika naḥyā wa bika namūtu wa ilaikal-maṣīr). And when he reaches the evening let him say: ‘O Allah, by You we enter the evening, and by You we enter the morning, and by You we live, and by You we die, and to You is the Resurrection (Allāhumma bika amsainā wa bika aṣbaḥnā wa bika naḥyā wa bika namūtu wa ilaikan-nushūr).’”}}
\hadithdefcmd{tirmidhi}{3392}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ يَعْلَى بْنِ عَطَاءٍ، قَالَ سَمِعْتُ عَمْرَو بْنَ عَاصِمٍ الثَّقَفِيَّ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ أَبُو بَكْرٍ يَا رَسُولَ اللَّهِ مُرْنِي بِشَيْءٍ أَقُولُهُ إِذَا أَصْبَحْتُ وَإِذَا أَمْسَيْتُ قَالَ ‏ "‏ قُلِ اللَّهُمَّ عَالِمَ الْغَيْبِ وَالشَّهَادَةِ فَاطِرَ السَّمَوَاتِ وَالأَرْضِ رَبَّ كُلِّ شَيْءٍ وَمَلِيكَهُ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ أَنْتَ أَعُوذُ بِكَ مِنْ شَرِّ نَفْسِي وَمِنْ شَرِّ الشَّيْطَانِ وَشِرْكِهِ قَالَ قُلْهُ إِذَا أَصْبَحْتَ وَإِذَا أَمْسَيْتَ وَإِذَا أَخَذْتَ مَضْجَعَكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3392}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah, may Allah be pleased with him, said:“Abu Bakr said: ‘O Messenger of Allah, command me with something that I may say when I reach morning and evening.’ He said: ‘Say: “O Allah Knower of the Unseen and the Seen, Originator of the heavens and the earth, Lord of everything and its Possessor, I bear witness that there is none worthy of worship except You, I seek refuge from You from the evil of my soul and from the evil of Shaitan and his Shirk (Allāhumma `ālimal-ghaibi wash-shahādati fāṭiras-samāwāti wal-arḍ, rabba kulli shai’in wa malīkahu, ash-hadu an lā ilāha illā anta, a`ūdhu bika min sharri nafsī wa min sharrish-shaiṭāni washirkihi).’” He said: ‘Say it when you reach morning, and evening, and when you go to bed.’”}}
\hadithdefcmd{tirmidhi}{3393}{حَدَّثَنَا الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ كَثِيرِ بْنِ زَيْدٍ، عَنْ عُثْمَانَ بْنِ رَبِيعَةَ، عَنْ شَدَّادِ بْنِ أَوْسٍ، رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ ‏ "‏ أَلاَ أَدُلُّكَ عَلَى سَيِّدِ الاِسْتِغْفَارِ اللَّهُمَّ أَنْتَ رَبِّي لاَ إِلَهَ إِلاَّ أَنْتَ خَلَقْتَنِي وَأَنَا عَبْدُكَ وَأَنَا عَلَى عَهْدِكَ وَوَعْدِكَ مَا اسْتَطَعْتُ أَعُوذُ بِكَ مِنْ شَرِّ مَا صَنَعْتُ وَأَبُوءُ إِلَيْكَ بِنِعْمَتِكَ عَلَىَّ وَأَعْتَرِفُ بِذُنُوبِي فَاغْفِرْ لِي ذُنُوبِي إِنَّهُ لاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ ‏.‏ لاَ يَقُولُهَا أَحَدُكُمْ حِينَ يُمْسِي فَيَأْتِي عَلَيْهِ قَدَرٌ قَبْلَ أَنْ يُصْبِحَ إِلاَّ وَجَبَتْ لَهُ الْجَنَّةُ وَلاَ يَقُولُهَا حِينَ يُصْبِحُ فَيَأْتِي عَلَيْهِ قَدَرٌ قَبْلَ أَنْ يُمْسِيَ إِلاَّ وَجَبَتْ لَهُ الْجَنَّةُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَابْنِ عُمَرَ وَابْنِ مَسْعُودٍ وَابْنِ أَبْزَى وَبُرَيْدَةَ رضى الله عنهم ‏.‏ قَالَ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَعَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ هُوَ ابْنُ أَبِي حَازِمٍ الزَّاهِدِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ شَدَّادِ بْنِ أَوْسٍ رضى الله عنه ‏.‏\hadithno{3393}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Shaddad bin Aws narrated that:The Prophet (ﷺ) said to him: “Should I not direct you to the chief of supplications for forgiveness? ‘O Allah, You are my Lord, there is none worthy of worship except You, You created me and I am Your slave. I am adhering to Your covenant and Your promise as much as I am able to, I seek refuge in You from the evil of what I have done. I admit to You your blessings upon me, and I admit to my sins. So forgive me, for there is none who can forgive sins except You (Allāhumma anta rabbī lā ilāha illā anta, khalaqtanī wa ana `abduka, wa ana `alā `ahdika wa wa`dika ma-staṭa`tu. A`ūdhu bika min sharri ma ṣana`tu, wa abū'u ilayka bini`matika `alayya wa a`tarifu bidhunūbī faghfirlī dhunūbī innahu lā yaghfirudh-dhunūba illā ant).’ None of you says it when he reaches the evening, and a decree comes upon him before he reaches morning, except that Paradise becomes obligatory upon him. And none says it when he reaches the morning, and a decree comes upon him before he reaches evening, except that Paradise becomes obligatory for him.”}}
\hadithdefcmd{tirmidhi}{3394}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي إِسْحَاقَ الْهَمْدَانِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ ‏"‏ أَلاَ أُعَلِّمُكَ كَلِمَاتٍ تَقُولُهَا إِذَا أَوَيْتَ إِلَى فِرَاشِكَ فَإِنْ مُتَّ مِنْ لَيْلَتِكَ مُتَّ عَلَى الْفِطْرَةِ وَإِنْ أَصْبَحْتَ أَصْبَحْتَ وَقَدْ أَصَبْتَ خَيْرًا تَقُولُ اللَّهُمَّ إِنِّي أَسْلَمْتُ نَفْسِي إِلَيْكَ وَوَجَّهْتُ وَجْهِي إِلَيْكَ وَفَوَّضْتُ أَمْرِي إِلَيْكَ رَغْبَةً وَرَهْبَةً إِلَيْكَ وَأَلْجَأْتُ ظَهْرِي إِلَيْكَ لاَ مَلْجَأَ وَلاَ مَنْجَا مِنْكَ إِلاَّ إِلَيْكَ آمَنْتُ بِكِتَابِكَ الَّذِي أَنْزَلْتَ وَبِنَبِيِّكَ الَّذِي أَرْسَلْتَ ‏"‏ ‏.‏ قَالَ الْبَرَاءُ فَقُلْتُ وَبِرَسُولِكَ الَّذِي أَرْسَلْتَ ‏.‏ قَالَ فَطَعَنَ بِيَدِهِ فِي صَدْرِي ثُمَّ قَالَ ‏"‏ وَبِنَبِيِّكَ الَّذِي أَرْسَلْتَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنِ الْبَرَاءِ ‏.‏ وَرَوَاهُ مَنْصُورُ بْنُ الْمُعْتَمِرِ عَنْ سَعْدِ بْنِ عُبَيْدَةَ عَنِ الْبَرَاءِ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ إِلاَّ أَنَّهُ قَالَ إِذَا أَوَيْتَ إِلَى فِرَاشِكَ وَأَنْتَ عَلَى وُضُوءٍ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ رَافِعِ بْنِ خَدِيجٍ رضى الله عنه ‏.‏\hadithno{3394}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Al-Bara' bin `Azib narrated that:The Prophet (ﷺ) said to him: “Should I not teach you some words to say when you go to your bed, so if you died, you will die upon the Fitrah, and if you reach the morning, you will reach it in good? You say: ‘O Allah, verily, I submit myself to You, and I turn my face to You, and I entrust my affair to You, hoping in You and fearing in You. And I lay myself down depending upon You, there is no refuge [nor escape] from You except to You. I believe in Your Book which You have revealed, and in Your Prophet whom You have sent (Allāhumma innī aslamtu nafsī ilaika wa wajjahtu wajhī ilaika, wa fawwaḍtu amrī ilaika, raghbatan wa rahbatan ilaika wa alja'tu ẓahrī ilaika, lā malja'a [wa lā manjā] minka illā ilaik. Āmantu bikitābikal-ladhī anzalta wa binabiyyikal-ladhī arsalt).’” Al-Bara' said: “So I said: ‘And in Your Messenger whom you have sent.’” He said: “So he (ﷺ) struck his hand upon my chest, then said: “And in Your Prophet whom You have sent. (Wa binabiyyikal-ladhī arsalt).”}}
\hadithdefcmd{tirmidhi}{3395}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ يَحْيَى بْنِ إِسْحَاقَ ابْنِ أَخِي، رَافِعِ بْنِ خَدِيجٍ عَنْ رَافِعِ بْنِ خَدِيجٍ، رضى الله عنه أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اضْطَجَعَ أَحَدُكُمْ عَلَى جَنْبِهِ الأَيْمَنِ ثُمَّ قَالَ اللَّهُمَّ إِنِّي أَسْلَمْتُ نَفْسِي إِلَيْكَ وَوَجَّهْتُ وَجْهِي إِلَيْكَ وَأَلْجَأْتُ ظَهْرِي إِلَيْكَ وَفَوَّضْتُ أَمْرِي إِلَيْكَ لاَ مَلْجَأَ وَلاَ مَنْجَا مِنْكَ إِلاَّ إِلَيْكَ أُومِنُ بِكِتَابِكَ وَبِرُسُلِكَ ‏.‏ فَإِنْ مَاتَ مِنْ لَيْلَتِهِ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ رَافِعِ بْنِ خَدِيجٍ رضى الله عنه ‏.‏\hadithno{3395}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Rafi` bin Khadij narrated that:The Prophet said: “When one of you lies down on his right side, then says: ‘O Allah, I have submitted myself to You, and I have turned my face to You, and I lay myself down relying upon You, and I have entrusted my affair to You, there is no refuge [nor escape] from You except to You. I believe in Your Book and Your Messengers (Allāhumma innī aslamtu nafsī ilaika wa wajjahtu wajhī ilaika, wa alja’tu ẓahrī ilaika, wa fawwaḍtu amrī ilaika, lā malja'a [wa lā manjā] minka illā ilaik, ūminu bikitābika wa birusulika)’ – then if he dies that night, he shall enter Paradise.”}}
\hadithdefcmd{tirmidhi}{3396}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَوَى إِلَى فِرَاشِهِ قَالَ ‏ "‏ الْحَمْدُ لِلَّهِ الَّذِي أَطْعَمَنَا وَسَقَانَا وَكَفَانَا وَآوَانَا وَكَمْ مِمَّنْ لاَ كَافِيَ لَهُ وَلاَ مُؤْوِيَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3396}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Anas bin Malik (ra) narrated that :when he went to his bed, the Messenger of Allah (ﷺ) used to say: “All praise is due to Allah, who has fed us and given us to drink, and has sufficed and granted us refuge, and how many are they who have none to suffice them and none to grant them refuge (Al-ḥamdulillāhi alladhi aṭ`amanā wa saqānā wa kafānā wa āwānā, wakam mimman lā kāfiya lahu wa lā mu'wiy).”}}
\hadithdefcmd{tirmidhi}{3397}{حَدَّثَنَا صَالِحُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الْوَصَّافِيِّ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، رضى الله عنه عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ حِينَ يَأْوِي إِلَى فِرَاشِهِ أَسْتَغْفِرُ اللَّهَ الْعَظِيمَ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ الْحَىَّ الْقَيُّومَ وَأَتُوبُ إِلَيْهِ ‏.‏ ثَلاَثَ مَرَّاتٍ غَفَرَ اللَّهُ ذُنُوبَهُ وَإِنْ كَانَتْ مِثْلَ زَبَدِ الْبَحْرِ وَإِنْ كَانَتْ عَدَدَ وَرَقِ الشَّجَرِ وَإِنْ كَانَتْ عَدَدَ رَمْلِ عَالِجٍ وَإِنْ كَانَتْ عَدَدَ أَيَّامِ الدُّنْيَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ الْوَصَّافِيِّ عُبَيْدِ اللَّهِ بْنِ الْوَلِيدِ ‏.‏\hadithno{3397}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa`eed (ra) narrated that :the Prophet (ﷺ) said: “Whoever says, when he goes to his bed: ‘I seek forgiveness from Allah, [the Magnificent] the One whom there is none worthy of worship except for Him, the Living, the Sustainer, and I repent to Him (Astaghfirullāha [al-`Aẓim] alladhi lā ilāha illā huw, al-Ḥayyul-Qayyūm, wa atūbu ilaihi)’ three times, Allah shall forgive him his sins if they were like the foam of the sea, even if they were the number of leaves of the trees, even if they were the number of sand particles of `Alij, even if they were the number of the days of the world.”}}
\hadithdefcmd{tirmidhi}{3398}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، رضى الله عنهما أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ أَنْ يَنَامَ وَضَعَ يَدَهُ تَحْتَ رَأْسِهِ ثُمَّ قَالَ ‏ "‏ اللَّهُمَّ قِنِي عَذَابَكَ يَوْمَ تَجْمَعُ عِبَادَكَ أَوْ تَبْعَثُ عِبَادَكَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3398}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Hudhaifah bin Al-Yaman (ra) narrated that:When the Prophet (ﷺ) would sleep, he would put his hand under his head then say: “O Allah, safeguard me from Your Punishment the Day You gather [Your slaves] (Allāhumma qinī `adhābaka yawma tajma`u [`ibādak])” or “you resurrect your slaves (tab`athu `ibādak).”}}
\hadithdefcmd{tirmidhi}{3399}{حَدَّثَنَا أَبُو كُرَيْبٍ، أَخْبَرَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، - هُوَ السَّلُولِيُّ عَنْ إِبْرَاهِيمَ بْنِ يُوسُفَ بْنِ أَبِي إِسْحَاقَ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي بُرْدَةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، رضى الله عنهما قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَوَسَّدُ يَمِينَهُ عِنْدَ الْمَنَامِ ثُمَّ يَقُولُ ‏ "‏ رَبِّ قِنِي عَذَابَكَ يَوْمَ تَبْعَثُ عِبَادَكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَرَوَى الثَّوْرِيُّ هَذَا الْحَدِيثَ عَنْ أَبِي إِسْحَاقَ عَنِ الْبَرَاءِ لَمْ يَذْكُرْ بَيْنَهُمَا أَحَدًا وَرَوَى شُعْبَةُ عَنْ أَبِي إِسْحَاقَ عَنْ أَبِي عُبَيْدَةَ وَرَجُلٍ آخَرَ عَنِ الْبَرَاءِ ‏.‏ وَرَوَى إِسْرَائِيلُ عَنْ أَبِي إِسْحَاقَ عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ عَنِ الْبَرَاءِ وَعَنْ أَبِي إِسْحَاقَ عَنْ أَبِي عُبَيْدَةَ عَنْ عَبْدِ اللَّهِ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{3399}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-Bara' bin `Azib (ra) narrated that:The Messenger of Allah (ﷺ) used to lay his head upon his right hand when going to sleep, then say: “My Lord, safeguard me from Your punishment the Day You resurrect Your slaves (Rabbi qinī `adhābaka yawma tab`athu `ibādak).”}}
\hadithdefcmd{tirmidhi}{3400}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُنَا إِذَا أَخَذَ أَحَدُنَا مَضْجَعَهُ أَنْ يَقُولَ ‏ "‏ اللَّهُمَّ رَبَّ السَّمَوَاتِ وَرَبَّ الأَرَضِينَ وَرَبَّنَا وَرَبَّ كُلِّ شَيْءٍ وَفَالِقَ الْحَبِّ وَالنَّوَى وَمُنْزِلَ التَّوْرَاةِ وَالإِنْجِيلِ وَالْقُرْآنِ أَعُوذُ بِكَ مِنْ شَرِّ كُلِّ ذِي شَرٍّ أَنْتَ آخِذٌ بِنَاصِيَتِهِ أَنْتَ الأَوَّلُ فَلَيْسَ قَبْلَكَ شَيْءٌ وَأَنْتَ الآخِرُ فَلَيْسَ بَعْدَكَ شَيْءٌ وَالظَّاهِرُ فَلَيْسَ فَوْقَكَ شَيْءٌ وَالْبَاطِنُ فَلَيْسَ دُونَكَ شَيْءٌ اقْضِ عَنِّي الدَّيْنَ وَأَغْنِنِي مِنَ الْفَقْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3400}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah (ra) said:“The Messenger of Allah (ﷺ) used to order that when one of us went to sleep, he should say: ‘O Allah, Lord of the heavens and Lord of the earths, and our Lord, and the Lord of everything, splitter of the seed-grain and date-stone, and Revealer of the Tawrah and the Injil and the Qur’an. I seek refuge in You from the evil of every evil that You are holding by the forelock. You are the First, there is nothing before You, You are the Last, there is nothing after You, and Az-Zahir, there is nothing above you, and Al-Batin, there is nothing below You. Relieve me of my debt, and enrich me from poverty (Allāhumma rabbas-samāwati wa rabbal-arḍīna wa rabbanā, wa rabba kulli shai’in, fāliqal-ḥabbi wan-nawā, wa munzilat-Tawrāti wal-Injīli wal-Qur’ān. A`ūdhu bika sharri kulli dhi sharrin anta ākhidhun bināṣiyatihi, antal-Awwalu falaisa qablaka shai’un, wa antal-Ākhiru falaisa ba`daka shai’un, waẓ-Ẓāhiru falaisa fauqaka shai'un wal-Bātinu falaisa dūnaka shai’un, iqḍi `annid-daina wa aghninī minal-faqr).’”}}
\hadithdefcmd{tirmidhi}{3401}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، رضى اللَّهُ عَنْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَامَ أَحَدُكُمْ عَنْ فِرَاشِهِ ثُمَّ رَجَعَ إِلَيْهِ فَلْيَنْفُضْهُ بِصَنِفَةِ إِزَارِهِ ثَلاَثَ مَرَّاتٍ فَإِنَّهُ لاَ يَدْرِي مَا خَلَفَهُ عَلَيْهِ بَعْدَهُ فَإِذَا اضْطَجَعَ فَلْيَقُلْ بِاسْمِكَ رَبِّي وَضَعْتُ جَنْبِي وَبِكَ أَرْفَعُهُ فَإِنْ أَمْسَكْتَ نَفْسِي فَارْحَمْهَا وَإِنْ أَرْسَلْتَهَا فَاحْفَظْهَا بِمَا تَحْفَظُ بِهِ عِبَادَكَ الصَّالِحِينَ ‏.‏ فَإِذَا اسْتَيْقَظَ فَلْيَقُلِ الْحَمْدُ لِلَّهِ الَّذِي عَافَانِي فِي جَسَدِي وَرَدَّ عَلَىَّ رُوحِي وَأَذِنَ لِي بِذِكْرِهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَعَائِشَةَ ‏.‏ قَالَ حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَرَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ وَقَالَ فَلْيَنْفُضْهُ بِدَاخِلَةِ إِزَارِهِ ‏.‏\hadithno{3401}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah (ra) narrated that :the Messenger of Allah (ﷺ) said: “When one of you leaves his bed then returns to it, then let him brush it off with the edge of his Izar three times, for indeed, he does not know what succeeded him upon it after him. When he lies down, let him say: ‘In Your Name, my Lord, I lay my side down, and in Your Name I raise it. And if You take my soul, then have mercy upon it, and if You release it, then protect it with that which You protect Your righteous worshipers (Bismika rabbī waḍa`tu janbī wa bika arfa`uhu, fa’in amsakta nafsī farḥamhā wa in arsaltahā faḥfaẓhā bimā taḥfaẓu bihī `ibādakaṣ-ṣāliḥīn)’ And when he awakens, let him say: All praise is due to Allah, Who healed me in my body, and returned to me my soul, and permitted me to remember Him (Al-ḥamdulillāh alladhī `āfānī fī jasadī wa radda `alayya rūḥī wa adhina lī bidhikrih).’”}}
\hadithdefcmd{tirmidhi}{3402}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا الْمُفَضَّلُ بْنُ فَضَالَةَ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَوَى إِلَى فِرَاشِهِ كُلَّ لَيْلَةٍ جَمَعَ كَفَّيْهِ ثُمَّ نَفَثَ فِيهِمَا فَقَرَأَ فِيهِمَا ‏:‏ ‏(‏ قلْ هُوَ اللَّهُ أَحَدٌ ‏)‏ وَ ‏:‏ ‏(‏ قلْ أَعُوذُ بِرَبِّ الْفَلَقِ ‏)‏ وَ ‏:‏ ‏(‏ قلْ أَعُوذُ بِرَبِّ النَّاسِ ‏)‏ ثُمَّ يَمْسَحُ بِهِمَا مَا اسْتَطَاعَ مِنْ جَسَدِهِ يَبْدَأُ بِهِمَا عَلَى رَأْسِهِ وَوَجْهِهِ وَمَا أَقْبَلَ مِنْ جَسَدِهِ يَفْعَلُ ذَلِكَ ثَلاَثَ مَرَّاتٍ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{3402}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Aishah narrated that:Every night, when the Prophet (ﷺ) would go to his bed, he would join his hands, then blow in them, as he recited in them: “Say: He is Allah, the One.” And “Say: I seek refuge in the Lord of Al-Falaq” and “Say: I seek refuge in the Lord of mankind.” Then he would wipe as much as he was able to of his body with them, beginning with them first of his head and face, and the front of his body. He would do this three times}}
\hadithdefcmd{tirmidhi}{3403}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَخْبَرَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ رَجُلٍ، عَنْ فَرْوَةَ بْنِ نَوْفَلٍ، رضى الله عنه أَنَّهُ أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ عَلِّمْنِي شَيْئًا أَقُولُهُ إِذَا أَوَيْتُ إِلَى فِرَاشِي قَالَ ‏"‏ اقْرَأْْ ‏:‏ ‏(‏ قلْ يَا أَيُّهَا الْكَافِرُونَ ‏)‏ فَإِنَّهَا بَرَاءَةٌ مِنَ الشِّرْكِ ‏"‏ ‏.‏ قَالَ شُعْبَةُ أَحْيَانًا يَقُولُ مَرَّةً وَأَحْيَانًا لاَ يَقُولُهَا ‏.‏ حَدَّثَنَا مُوسَى بْنُ حِزَامٍ، أَخْبَرَنَا يَحْيَى بْنُ آدَمَ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ فَرْوَةَ بْنِ نَوْفَلٍ، عَنْ أَبِيهِ، أَنَّهُ أَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ نَحْوَهُ بِمَعْنَاهُ وَهَذَا أَصَحُّ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى زُهَيْرٌ هَذَا الْحَدِيثَ عَنْ أَبِي إِسْحَاقَ عَنْ فَرْوَةَ بْنِ نَوْفَلٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَهَذَا أَشْبَهُ وَأَصَحُّ مِنْ حَدِيثِ شُعْبَةَ ‏.‏ وَقَدِ اضْطَرَبَ أَصْحَابُ أَبِي إِسْحَاقَ فِي هَذَا الْحَدِيثِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ قَدْ رَوَاهُ عَبْدُ الرَّحْمَنِ بْنُ نَوْفَلٍ عَنْ أَبِيهِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَعَبْدُ الرَّحْمَنِ هُوَ أَخُو فَرْوَةَ بْنِ نَوْفَلٍ ‏.‏\hadithno{3403}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Farwah bin Nawfal (ra) narrated that:He came to the Prophet (ﷺ) and said: “O Messenger of Allah, teach me something that I may say when I go to my bed.” So he said: “Recite: Say: ‘O you disbelievers’ for verily it is a disavowal of Shirk.” Shu`bah said: “Sometimes he would say: ‘One time’ and sometime he would not say it.” (Another chain) from Farwah bin Nawfal, from his father: "That he came to the Prophet (ﷺ)" then he mentioned similar in meaning. And this is more correct. [Abu `Eisa said:] And Zubair reported this hadith from Ishaq, from Farwah bin Nawfal, from his father from the Prophet (ﷺ), with similar wording. This is more appropriate and more correct than the narration of Shu`bah. The companions of Abu Ishaq were confused in the narration of this hadith. This hadith has been reported through routes other than this. `Abdur-Rahman is the brother of Farwah bin Nawfal}}
\hadithdefcmd{tirmidhi}{3404}{حَدَّثَنَا هِشَامُ بْنُ يُونُسَ الْكُوفِيُّ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنْ لَيْثٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، رضى الله عنه قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم لاَ يَنَامُ حَتَّى يَقْرَأَ بِتَنْزِيلَ السَّجْدَةِ وَبِتَبَارَكَ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رَوَى سُفْيَانُ وَغَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ لَيْثٍ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ وَرَوَى زُهَيْرٌ هَذَا الْحَدِيثَ عَنْ أَبِي الزُّبَيْرِ قَالَ قُلْتُ لَهُ سَمِعْتَهُ مِنْ جَابِرٍ قَالَ لَمْ أَسْمَعْهُ مِنْ جَابِرٍ إِنَّمَا سَمِعْتُهُ مِنْ صَفْوَانَ أَوِ ابْنِ صَفْوَانَ ‏.‏ وَرَوَى شَبَابَةُ عَنْ مُغِيرَةَ بْنِ مُسْلِمٍ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ نَحْوَ حَدِيثِ لَيْثٍ ‏.‏\hadithno{3404}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Jabir said:“The Prophet would not sleep until he reached Tanzil as-Sajdah and Tabarak.”}}
\hadithdefcmd{tirmidhi}{3405}{حَدَّثَنَا صَالِحُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَبِي لُبَابَةَ، قَالَ قَالَتْ عَائِشَةُ رضى الله عنها كَانَ النَّبِيُّ صلى الله عليه وسلم لاَ يَنَامُ حَتَّى يَقْرَأَ الزُّمَرَ وَبَنِي إِسْرَائِيلَ ‏.‏ أَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ قَالَ أَبُو لُبَابَةَ هَذَا اسْمُهُ مَرْوَانُ مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ زِيَادٍ وَسَمِعَ مِنْ عَائِشَةَ سَمِعَ مِنْهُ حَمَّادُ بْنُ زَيْدٍ ‏.‏\hadithno{3405}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{A'isha (ra) said:“The Prophet (ﷺ) would not sleep until he recited Az-Zumar and Banu Isra’il.” Muhammad bin Ismail informed me: “This Abu Lubabah’s (a narrator in the chain) name is Marwan, the freed slave of Abdur-Rahman bin Ziyad. He heard from Aisha, and Hammad bin Zaid heard from him.”}}
\hadithdefcmd{tirmidhi}{3406}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بِلاَلٍ، عَنِ الْعِرْبَاضِ بْنِ سَارِيَةَ، رضى الله عَنْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ لاَ يَنَامُ حَتَّى يَقْرَأَ الْمُسَبِّحَاتِ وَيَقُولُ ‏ "‏ فِيهَا آيَةٌ خَيْرٌ مِنْ أَلْفِ آيَةٍ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3406}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ar-Irbad bin Sariyah (ra) narrated that:The Prophet (ﷺ) would not sleep until he had recited Al-Musabbihat, and he would say: “In them is an Ayah that is better than a thousand Ayah.”}}
\hadithdefcmd{tirmidhi}{3407}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي الْعَلاَءِ بْنِ الشِّخِّيرِ، عَنْ رَجُلٍ، مِنْ بَنِي حَنْظَلَةَ قَالَ صَحِبْتُ شَدَّادَ بْنَ أَوْسٍ رضى الله عنه فِي سَفَرٍ فَقَالَ أَلاَ أُعَلِّمُكَ مَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُنَا أَنْ نَقُولَ اللَّهُمَّ إِنِّي أَسْأَلُكَ الثَّبَاتَ فِي الأَمْرِ وَأَسْأَلُكَ عَزِيمَةَ الرُّشْدِ وَأَسْأَلُكَ شُكْرَ نِعْمَتِكَ وَحُسْنَ عِبَادَتِكَ وَأَسْأَلُكَ لِسَانًا صَادِقًا وَقَلْبًا سَلِيمًا وَأَعُوذُ بِكَ مِنْ شَرِّ مَا تَعْلَمُ وَأَسْأَلُكَ مِنْ خَيْرِ مَا تَعْلَمُ وَأَسْتَغْفِرُكَ مِمَّا تَعْلَمُ إِنَّكَ أَنْتَ عَلاَّمُ الْغُيُوبِ ‏.‏ قَالَ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ مُسْلِمٍ يَأْخُذُ مَضْجَعَهُ يَقْرَأُ سُورَةً مِنْ كِتَابِ اللَّهِ إِلاَّ وَكَّلَ اللَّهُ بِهِ مَلَكًا فَلاَ يَقْرَبُهُ شَيْءٌ يُؤْذِيهِ حَتَّى يَهُبَّ مَتَى هَبَّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ إِنَّمَا نَعْرِفُهُ مِنْ هَذَا الْوَجْهِ وَالْجُرَيْرِيُّ هُوَ سَعِيدُ بْنُ إِيَاسٍ أَبُو مَسْعُودٍ الْجُرَيْرِيُّ وَأَبُو الْعَلاَءِ اسْمُهُ يَزِيدُ بْنُ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ ‏.‏\hadithno{3407}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{A man from Banu Hanzalah said:“I accompanied Shaddad bin Aws [may Allah be pleased with him] on a journey, so he said: ‘Should I not teach you what the Messenger of Allah used to teach us? That you say: “O Allah, I ask You for steadfastness in the affair and I ask You for determination upon guidance, and I ask You to make me grateful for Your favor, and excellence in worshiping You, and I ask You for a truthful tongue and a sound heart, and I seek refuge in You from the evil of what You know, and I ask You for the good of what You know, and I seek Your forgiveness for that which You know. Verily, You are the Knower of all that is hidden (Allāhumma innī as’alukath-thabāta fil-amri, wa as’aluka `azīmatar-rushdi, wa as’aluka shukra ni`matika, wa ḥusna `ibādatika, wa as’aluka lisānan ṣādiqan wa qalban salīman, wa a`ūdhu bika min sharri mā ta`lamu, wa as’aluka min khairi mā ta`lamu, wa astaghfiruka mimmā ta`lamu innaka anta `allāmul-ghuyūb).’” He said: ‘The Messenger of Allah (ﷺ) said: “There is no Muslim who lays down to sleep while reciting a Surat from Allah’s Book, except that Allah entrusts an angel, so that nothing approaches him to harm him until he awakens, whenever he awakens.”}}
\hadithdefcmd{tirmidhi}{3408}{حَدَّثَنَا أَبُو الْخَطَّابِ، زِيَادُ بْنُ يَحْيَى الْبَصْرِيُّ حَدَّثَنَا أَزْهَرُ السَّمَّانُ، عَنِ ابْنِ عَوْنٍ، عَنِ ابْنِ سِيرِينَ، عَنْ عَبِيدَةَ، عَنْ عَلِيٍّ، رضى الله عنه قَالَ شَكَتْ إِلَىَّ فَاطِمَةُ مَجَلَ يَدَيْهَا مِنَ الطَّحِينِ فَقُلْتُ لَوْ أَتَيْتِ أَبَاكِ فَسَأَلْتِيهِ خَادِمًا فَقَالَ ‏ "‏ أَلاَ أَدُلُّكُمَا عَلَى مَا هُوَ خَيْرٌ لَكُمَا مِنَ الْخَادِمِ إِذَا أَخَذْتُمَا مَضْجَعَكُمَا تَقُولاَنِ ثَلاَثًا وَثَلاَثِينَ وَثَلاَثًا وَثَلاَثِينَ وَأَرْبَعًا وَثَلاَثِينَ مِنْ تَحْمِيدٍ وَتَسْبِيحٍ وَتَكْبِيرٍ ‏"‏ ‏.‏ وَفِي الْحَدِيثِ قِصَّةٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ ابْنِ عَوْنٍ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ عَلِيٍّ ‏.‏\hadithno{3408}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ali [may Allah be pleased with him] said:“Fatimah complained to me about her hands blistering from grinding flour. So I said: ‘If you were to approach your father and ask him for a servant?’ So he (the Prophet) said: ‘Should I not direct the two of you, to that which is better for you than a servant? When the two of you lay down to sleep, say thirty-three, thirty-three, thirty-four, of At-Taḥmīd, At-Tasbīḥ, and At-Takbīr.”}}
\hadithdefcmd{tirmidhi}{3409}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَزْهَرُ السَّمَّانُ، عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنْ عَبِيدَةَ، عَنْ عَلِيٍّ، رضى الله عنه قَالَ جَاءَتْ فَاطِمَةُ إِلَى النَّبِيِّ صلى الله عليه وسلم تَشْكُو مَجَلاً بِيَدَيْهَا فَأَمَرَهَا بِالتَّسْبِيحِ وَالتَّكْبِيرِ وَالتَّحْمِيدِ ‏.‏\hadithno{3409}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ali [may Allah be pleased with him] said:“Fatimah went to the Prophet complaining of her hands blistering, so he ordered her to say At-Tasbīḥ, At-Takbīr, and At-Taḥmīd.”}}
\hadithdefcmd{tirmidhi}{3410}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، حَدَّثَنَا عَطَاءُ بْنُ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، رضى الله عنهما قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَلَّتَانِ لاَ يُحْصِيهِمَا رَجُلٌ مُسْلِمٌ إِلاَّ دَخَلَ الْجَنَّةَ أَلاَ وَهُمَا يَسِيرٌ وَمَنْ يَعْمَلُ بِهِمَا قَلِيلٌ يُسَبِّحُ اللَّهَ فِي دُبُرِ كُلِّ صَلاَةٍ عَشْرًا وَيَحْمَدُهُ عَشْرًا وَيُكَبِّرُهُ عَشْرًا ‏"‏ ‏.‏ قَالَ فَأَنَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَعْقِدُهَا بِيَدِهِ قَالَ ‏"‏ فَتِلْكَ خَمْسُونَ وَمِائَةٌ بِاللِّسَانِ وَأَلْفٌ وَخَمْسُمِائَةٍ فِي الْمِيزَانِ وَإِذَا أَخَذْتَ مَضْجَعَكَ تُسَبِّحُهُ وَتُكَبِّرُهُ وَتَحْمَدُهُ مِائَةً فَتِلْكَ مِائَةٌ بِاللِّسَانِ وَأَلْفٌ فِي الْمِيزَانِ فَأَيُّكُمْ يَعْمَلُ فِي الْيَوْمِ وَاللَّيْلَةِ أَلْفَيْنِ وَخَمْسَمِائَةِ سَيِّئَةٍ ‏"‏ ‏.‏ قَالُوا وَكَيْفَ لاَ يُحْصِيهَا قَالَ ‏"‏ يَأْتِي أَحَدَكُمُ الشَّيْطَانُ وَهُوَ فِي صَلاَتِهِ فَيَقُولُ اذْكُرْ كَذَا اذْكُرْ كَذَا ‏.‏ حَتَّى يَنْفَتِلَ فَلَعَلَّهُ أَنْ لاَ يَفْعَلَ وَيَأْتِيهِ وَهُوَ فِي مَضْجَعِهِ فَلاَ يَزَالُ يُنَوِّمُهُ حَتَّى يَنَامَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى شُعْبَةُ وَالثَّوْرِيُّ عَنْ عَطَاءِ بْنِ السَّائِبِ هَذَا الْحَدِيثَ ‏.‏ وَرَوَى الأَعْمَشُ هَذَا الْحَدِيثَ عَنْ عَطَاءِ بْنِ السَّائِبِ مُخْتَصَرًا ‏.‏ وَفِي الْبَابِ عَنْ زَيْدِ بْنِ ثَابِتٍ وَأَنَسٍ وَابْنِ عَبَّاسٍ رضى الله عنهم ‏.‏\hadithno{3410}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin `Amr [may Allah be pleased with both of them] said:“The Messenger of Allah said: ‘There are two characteristics over which a Muslim man does not guard, except that he enters Paradise. And indeed, they are easy, and those who act upon them are few: He glorifies Allah at the end of every prayer ten times (saying Subḥān Allāh) and praises Him ten times saying (Al-Ḥamdulillāh) and extols His greatness ten times (saying Allāhu Akbar).’”He said: “And I have seen the Messenger of Allah counting them with his hand. He said: ‘So this is one hundred and fifty with the tongue, and one thousand and five hundred on the Scale. When you go to bed, you glorify Him, extol His greatness, and praise Him a hundred times, so this is one hundred with the tongue and one thousand on the Scale. Which of you perform two thousand and five hundred evil deeds in a single day and night?’ They said: ‘How could we not guard over them?’ He said: ‘Shaitan comes to one of you when he is in his Salat and says: “Remember such and such, remember such and such” until he turns perhaps he will not do it. And he comes to him and he is lying down and makes him sleepy until he falls asleep.’”}}
\hadithdefcmd{tirmidhi}{3411}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا عَثَّامُ بْنُ عَلِيٍّ، عَنِ الأَعْمَشِ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، رضى الله عنهما قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَعْقِدُ التَّسْبِيحَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ الأَعْمَشِ ‏.‏\hadithno{3411}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin Amr [may Allah be pleased with him] said:“I saw the Messenger of Allah counting At-Tasbīḥ.”}}
\hadithdefcmd{tirmidhi}{3412}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ سَمُرَةَ الأَحْمَسِيُّ الْكُوفِيُّ، حَدَّثَنَا أَسْبَاطُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَمْرُو بْنُ قَيْسٍ الْمُلاَئِيُّ، عَنِ الْحَكَمِ بْنِ عُتَيْبَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ كَعْبِ بْنِ عُجْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مُعَقِّبَاتٌ لاَ يَخِيبُ قَائِلُهُنَّ يُسَبِّحُ اللَّهَ فِي دُبُرِ كُلِّ صَلاَةٍ ثَلاَثًا وَثَلاَثِينَ وَيَحْمَدُهُ ثَلاَثًا وَثَلاَثِينَ وَيُكَبِّرُهُ أَرْبَعًا وَثَلاَثِينَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَعَمْرُو بْنُ قَيْسٍ الْمُلاَئِيُّ ثِقَةٌ حَافِظٌ ‏.‏ وَرَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنِ الْحَكَمِ وَلَمْ يَرْفَعْهُ ‏.‏ وَرَوَاهُ مَنْصُورُ بْنُ الْمُعْتَمِرِ عَنِ الْحَكَمِ وَرَفَعَهُ ‏.‏\hadithno{3412}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ka’b bin Ujrah narrated that:The Prophet said: “There are Mu’aqqibat, he who says them shall not be miserable. Glorify Allah at the end of every prayer thirty-three times, and praise him thirty-three times, and extol His greatness thirty-four times.”}}
\hadithdefcmd{tirmidhi}{3413}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ كَثِيرِ بْنِ أَفْلَحَ، عَنْ زَيْدِ بْنِ ثَابِتٍ، رضى الله عنه قَالَ أُمِرْنَا أَنْ نُسَبِّحَ دُبُرَ كُلِّ صَلاَةٍ ثَلاَثًا وَثَلاَثِينَ وَنَحْمَدَهُ ثَلاَثًا وَثَلاَثِينَ وَنُكَبِّرَهُ أَرْبَعًا وَثَلاَثِينَ ‏.‏ قَالَ فَرَأَى رَجُلٌ مِنَ الأَنْصَارِ فِي الْمَنَامِ فَقَالَ أَمَرَكُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تُسَبِّحُوا فِي دُبُرِ كُلِّ صَلاَةٍ ثَلاَثًا وَثَلاَثِينَ وَتَحْمَدُوا اللَّهَ ثَلاَثًا وَثَلاَثِينَ وَتُكَبِّرُوا أَرْبَعًا وَثَلاَثِينَ قَالَ نَعَمْ ‏.‏ قَالَ فَاجْعَلُوا خَمْسًا وَعِشْرِينَ وَاجْعَلُوا التَّهْلِيلَ مَعَهُنَّ فَغَدَا عَلَى النَّبِيِّ صلى الله عليه وسلم فَحَدَّثَهُ فَقَالَ ‏ "‏ افْعَلُوا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{3413}\hadithgrade{Zubair Ali Zai: Hasan}\hadithtrans{Zaid bin Thabit (ra) said:“We were ordered to say the Tasbīḥ at the end of every Salat thirty-three times, and to say the Takbīr thirty-four times.” He said: “Then a man from the Ansar had a dream in which someone said: ‘The Messenger of Allah (ﷺ) ordered you to say the Tasbīḥ at the end of every Salat thirty-three times, and to say the Taḥmīd thirty-three times, and to say the Takbīr thirty-four times?’ He said: ‘Yes.’ He said: ‘Then make them twenty-five and add the Tahlīl (saying Lā ilāha illallāh) to them.’ The next day he went to the Prophet (ﷺ) and informed him, so he said: “Do it.”}}
\hadithdefcmd{tirmidhi}{3414}{حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي عُمَيْرُ بْنُ هَانِئٍ، قَالَ حَدَّثَنِي جُنَادَةُ بْنُ أَبِي أُمَيَّةَ، حَدَّثَنِي عُبَادَةُ بْنُ الصَّامِتِ، رضى الله عنه عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَعَارَّ مِنَ اللَّيْلِ فَقَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَيْءٍ قَدِيرٌ وَسُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ثُمَّ قَالَ رَبِّ اغْفِرْ لِي أَوْ قَالَ ثُمَّ دَعَا اسْتُجِيبَ لَهُ فَإِنْ عَزَمَ فَتَوَضَّأَ ثُمَّ صَلَّى قُبِلَتْ صَلاَتُهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3414}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Ubadah bin As-Samit, may Allah be pleased with him, narrated that:The Messenger of Allah (ﷺ) said: “Whoever wakes up in the night and says, ‘None has the right to be worshiped but Allah, alone, without partner, to Him belongs the Dominion, and to Him is the praise, and He has power over all things. And Glory is to Allah, and all the praise is to Allah, and ‘None has the right to be worshiped but Allah, and Allah is the greatest, and there is no might nor power except by Allah (Lā ilāha illallāh, waḥdahu lā sharīka lahu, lahul-mulku wa lahul-ḥamdu, wa huwa `alā kulli shai'in qadīr. Wa subḥān Allah, walḥamdulillāh, wa lā ilāha illallāh, wa Allāhu akbar, wa lā ḥawla wa lā quwwata illā billāh.)’ – then he said: ‘O my Lord, forgive me (Rabbighfirlī)’ – or he said – ‘then he supplicates, he shall be responded to. So he makes a firm determination, then performs Wudu', then he performs Salat, his Salat shall be accepted.”}}
\hadithdefcmd{tirmidhi}{3415}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ حَدَّثَنَا مَسْلَمَةُ بْنُ عَمْرٍو قَالَ كَانَ عُمَيْرُ بْنُ هَانِئٍ يُصَلِّي كُلَّ يَوْمٍ أَلْفَ سَجْدَةٍ وَيُسَبِّحُ مِائَةَ أَلْفِ تَسْبِيحَةٍ ‏.‏\hadithno{3415}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad Maqtu; Al-Albani: Daif Isnaad Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Maslamah bin `Amr said:“`Umair bin Hani used to perform a thousand prostrations every day and recite a hundred thousand Tasbīḥs every day.”}}
\hadithdefcmd{tirmidhi}{3416}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، وَوَهْبُ بْنُ جَرِيرٍ، وَأَبُو عَامِرٍ الْعَقَدِيُّ وَعَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ قَالُوا حَدَّثَنَا هِشَامٌ الدَّسْتَوَائِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، حَدَّثَنِي رَبِيعَةُ بْنُ كَعْبٍ الأَسْلَمِيُّ، قَالَ كُنْتُ أَبِيتُ عِنْدَ بَابِ النَّبِيِّ صلى الله عليه وسلم فَأُعْطِيهِ وَضُوءَهُ فَأَسْمَعُهُ الْهَوِيَّ مِنَ اللَّيْلِ يَقُولُ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ وَأَسْمَعُهُ الْهَوِيَّ مِنَ اللَّيْلِ يَقُولُ ‏"‏ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3416}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Rabi`ah bin Ka`b Al-Aslami said:“I used to spend the night at the door of the Prophet (ﷺ), so that I may give him his water for Wudu', and I would hear him, for a long period of the night, saying: ‘Allah hears the one who praise Him (Sami` Allāhu liman ḥamidah).’ And I would hear him, for a long period saying: ‘All praise is due to Allah, Lord of the all that exists. (Al-ḥamdulillāhi rabbil-`ālamīn).’”}}
\hadithdefcmd{tirmidhi}{3417}{حَدَّثَنَا عُمَرُ بْنُ إِسْمَاعِيلَ بْنِ مُجَالِدِ بْنِ سَعِيدٍ، حَدَّثَنَا أَبِي، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ رِبْعِيٍّ، عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ أَنْ يَنَامَ قَالَ ‏"‏ اللَّهُمَّ بِاسْمِكَ أَمُوتُ وَأَحْيَا ‏"‏ ‏.‏ وَإِذَا اسْتَيْقَظَ قَالَ ‏"‏ الْحَمْدُ لِلَّهِ الَّذِي أَحْيَا نَفْسِي بَعْدَ مَا أَمَاتَهَا وَإِلَيْهِ النُّشُورُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3417}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Hudhaifah bin Al-Yaman [may Allah be pleased with him] narrated that when the Prophet (ﷺ) wanted to sleep, he would say:“O Allah, in Your Name I die and I live (Allāhumma bismika amūtu wa aḥyā).” And when he would wake, he would say: “Allah praise is due to Allah who revived my soul after causing its death and to Him is the resurrection (Al-ḥamdulillāh, alladhī aḥyā nafsī ba`da mā amātahā wa ilaihin-nushūr).”}}
\hadithdefcmd{tirmidhi}{3418}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ طَاوُسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَامَ إِلَى الصَّلاَةِ مِنْ جَوْفِ اللَّيْلِ يَقُولُ ‏ "‏ اللَّهُمَّ لَكَ الْحَمْدُ أَنْتَ نُورُ السَّمَوَاتِ وَالأَرْضِ وَلَكَ الْحَمْدُ أَنْتَ قَيَّامُ السَّمَوَاتِ وَالأَرْضِ وَلَكَ الْحَمْدُ أَنْتَ رَبُّ السَّمَوَاتِ وَالأَرْضِ وَمَنْ فِيهِنَّ أَنْتَ الْحَقُّ وَوَعْدُكَ الْحَقُّ وَلِقَاؤُكَ حَقٌّ وَالْجَنَّةُ حَقٌّ وَالنَّارُ حَقٌّ وَالسَّاعَةُ حَقٌّ اللَّهُمَّ لَكَ أَسْلَمْتُ وَبِكَ آمَنْتُ وَعَلَيْكَ تَوَكَّلْتُ وَإِلَيْكَ أَنَبْتُ وَبِكَ خَاصَمْتُ وَإِلَيْكَ حَاكَمْتُ فَاغْفِرْ لِي مَا قَدَّمْتُ وَمَا أَخَّرْتُ وَمَا أَسْرَرْتُ وَمَا أَعْلَنْتُ أَنْتَ إِلَهِي لاَ إِلَهَ إِلاَّ أَنْتَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3418}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin `Abbas [may Allah be pleased with them] narrated, :that when the Messenger of Allah (ﷺ) would stand for prayer during the middle of the night, he would say: “O Allah, to You is the Praise, You are the Light of the heavens and the earth, and to You is the Praise, You are the Sustainer of the heavens and the earth, and to You is the praise, You are the Lord of the heavens and the earth, and those in them, You are the truth, and Your Promise is the truth, and Your meeting is true, and Paradise is true, and the Fire is true, and the Hour is true, O Allah, to You have I submitted, and in You have I believed , and in You have I relied, and to You have I turned, and by You have I argued, and to You have I referred for judgment. So forgive me what I have done before and after, and that which I have hidden and that which I have done openly. You are my Deity, no has the right to be worshiped but You (Allāhumma lakal-ḥamd, anta nūrus-samāwāti wal-arḍ, wa lakal-ḥamd, anta qayyāmus-samāwāti wal-arḍ, wa lakal-ḥamd, anta rabbus-samāwāti wal-arḍ, wa man fīhinn, antal-ḥaqq, wa wa`dukal-ḥaqq, wa liqā'uka ḥaqq, wal-jannatu ḥaqq, wan-nāru ḥaqq, was-sā`atu ḥaqq. Allāhumma laka aslamtu, wa bika āmantu, wa `alaika tawakkaltu, wa ilaika anabtu, wa bika khāṣamtu, wa ilaika ḥākamtu, faghfirlī mā qaddamtu wa mā akhartu, wa mā asrartu wa mā a`lant. Anta ilāhī lā ilāha illā ant).”}}
\hadithdefcmd{tirmidhi}{3419}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا مُحَمَّدُ بْنُ عِمْرَانَ بْنِ أَبِي لَيْلَى، حَدَّثَنِي أَبِي، حَدَّثَنِي ابْنُ أَبِي لَيْلَى، عَنْ دَاوُدَ بْنِ عَلِيٍّ، هُوَ ابْنُ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ عَنْ أَبِيهِ، عَنْ جَدِّهِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ نَبِيَّ اللَّهِ صلى الله عليه وسلم يَقُولُ لَيْلَةً حِينَ فَرَغَ مِنْ صَلاَتِهِ ‏ "‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ رَحْمَةً مِنْ عِنْدِكَ تَهْدِي بِهَا قَلْبِي وَتَجْمَعُ بِهَا أَمْرِي وَتَلُمُّ بِهَا شَعَثِي وَتُصْلِحُ بِهَا غَائِبِي وَتَرْفَعُ بِهَا شَاهِدِي وَتُزَكِّي بِهَا عَمَلِي وَتُلْهِمُنِي بِهَا رَشَدِي وَتَرُدُّ بِهَا أُلْفَتِي وَتَعْصِمُنِي بِهَا مِنْ كُلِّ سُوءٍ اللَّهُمَّ أَعْطِنِي إِيمَانًا وَيَقِينًا لَيْسَ بَعْدَهُ كُفْرٌ وَرَحْمَةً أَنَالُ بِهَا شَرَفَ كَرَامَتِكَ فِي الدُّنْيَا وَالآخِرَةِ اللَّهُمَّ إِنِّي أَسْأَلُكَ الْفَوْزَ فِي الْعَطَاءِ وَيُرْوَى فِي الْقَضَاءِ وَنُزُلَ الشُّهَدَاءِ وَعَيْشَ السُّعَدَاءِ وَالنَّصْرَ عَلَى الأَعْدَاءِ اللَّهُمَّ إِنِّي أُنْزِلُ بِكَ حَاجَتِي وَإِنْ قَصَّرَ رَأْيِي وَضَعُفَ عَمَلِي افْتَقَرْتُ إِلَى رَحْمَتِكَ فَأَسْأَلُكَ يَا قَاضِيَ الأُمُورِ وَيَا شَافِيَ الصُّدُورِ كَمَا تُجِيرُ بَيْنَ الْبُحُورِ أَنْ تُجِيرَنِي مِنْ عَذَابِ السَّعِيرِ وَمِنْ دَعْوَةِ الثُّبُورِ وَمِنْ فِتْنَةِ الْقُبُورِ اللَّهُمَّ مَا قَصَّرَ عَنْهُ رَأْيِي وَلَمْ تَبْلُغْهُ نِيَّتِي وَلَمْ تَبْلُغْهُ مَسْأَلَتِي مِنْ خَيْرٍ وَعَدْتَهُ أَحَدًا مِنْ خَلْقِكَ أَوْ خَيْرٍ أَنْتَ مُعْطِيهِ أَحَدًا مِنْ عِبَادِكَ فَإِنِّي أَرْغَبُ إِلَيْكَ فِيهِ وَأَسْأَلُكَهُ بِرَحْمَتِكَ رَبَّ الْعَالَمِينَ اللَّهُمَّ ذَا الْحَبْلِ الشَّدِيدِ وَالأَمْرِ الرَّشِيدِ أَسْأَلُكَ الأَمْنَ يَوْمَ الْوَعِيدِ وَالْجَنَّةَ يَوْمَ الْخُلُودِ مَعَ الْمُقَرَّبِينَ الشُّهُودِ الرُّكَّعِ السُّجُودِ الْمُوفِينَ بِالْعُهُودِ إِنَّكَ رَحِيمٌ وَدُودٌ وَأَنْتَ تَفْعَلُ مَا تُرِيدُ اللَّهُمَّ اجْعَلْنَا هَادِينَ مُهْتَدِينَ غَيْرَ ضَالِّينَ وَلاَ مُضِلِّينَ سِلْمًا لأَوْلِيَائِكَ وَعَدُوًّا لأَعْدَائِكَ نُحِبُّ بِحُبِّكَ مَنْ أَحَبَّكَ وَنُعَادِي بِعَدَاوَتِكَ مَنْ خَالَفَكَ اللَّهُمَّ هَذَا الدُّعَاءُ وَعَلَيْكَ الاِسْتِجَابَةُ وَهَذَا الْجَهْدُ وَعَلَيْكَ التُّكْلاَنُ اللَّهُمَّ اجْعَلْ لِي نُورًا فِي قَبْرِي وَنُورًا فِي قَلْبِي وَنُورًا مِنْ بَيْنِ يَدَىَّ وَنُورًا مِنْ خَلْفِي وَنُورًا عَنْ يَمِينِي وَنُورًا عَنْ شِمَالِي وَنُورًا مِنْ فَوْقِي وَنُورًا مِنْ تَحْتِي وَنُورًا فِي سَمْعِي وَنُورًا فِي بَصَرِي وَنُورًا فِي شَعْرِي وَنُورًا فِي بَشَرِي وَنُورًا فِي لَحْمِي وَنُورًا فِي دَمِي وَنُورًا فِي عِظَامِي اللَّهُمَّ أَعْظِمْ لِي نُورًا وَأَعْطِنِي نُورًا وَاجْعَلْ لِي نُورًا سُبْحَانَ الَّذِي تَعَطَّفَ الْعِزَّ وَقَالَ بِهِ سُبْحَانَ الَّذِي لَبِسَ الْمَجْدَ وَتَكَرَّمَ بِهِ سُبْحَانَ الَّذِي لاَ يَنْبَغِي التَّسْبِيحُ إِلاَّ لَهُ سُبْحَانَ ذِي الْفَضْلِ وَالنِّعَمِ سُبْحَانَ ذِي الْمَجْدِ وَالْكَرَمِ سُبْحَانَ ذِي الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ابْنِ أَبِي لَيْلَى مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رَوَى شُعْبَةُ وَسُفْيَانُ الثَّوْرِيُّ عَنْ سَلَمَةَ بْنِ كُهَيْلٍ عَنْ كُرَيْبٍ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم بَعْضَ هَذَا الْحَدِيثِ وَلَمْ يَذْكُرْهُ بِطُولِهِ ‏.‏\hadithno{3419}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas said:“One night, when he (ﷺ) exited his Salat, I heard the Messenger of Allah saying: ‘O Allah, I ask You of Your mercy, that You guide by it my heart, and gather by it my affair, and bring together that which has been scattered of my affairs, and correct with it that which is hidden from me, and raise by it that which is apparent from me, and purify by it my actions, and inspire me by it with that which contains my guidance, and protect me by it from that which I seek protection, and protect me by it from every evil. O Allah give me faith and certainty after which there is no disbelief, and mercy, by which I may attain the high level of Your generosity in the world and the Hereafter. O Allah, I ask You for success [in that which You grant, and relief] in the Judgment, and the positions of the martyrs, and the provision of the successful, and aid against the enemies. O Allah, I leave to You my need, and my actions are weak, I am in need of Your mercy, so I ask You, O Decider of the affairs, and O Healer of the chests, as You separate me from the punishment of the blazing flame, and from seeking destruction, and from the trial of the graves. O Allah, whatever my opinion has fallen short of, and my intention has not reached it, and my request has not encompassed it, of good that You have promised to anyone from Your creation, or any good You are going to give to any of Your slaves, then indeed, I seek it from You and I ask You for it, by Your mercy, O Lord of the Worlds. O Allah, Possessor of the strong rope, and the guided affair, I ask You for security on the Day of the Threat, and Paradise on the Day of Immortality along with the witnesses, brought-close, who bow and prostrate, who fulfill the covenants, You are Merciful, Loving, and indeed, You do what You wish. O Allah, make us guided guiders and not misguided misguiders, an ally to Your friends, an enemy to Your enemies. We love due to Your love, those who love You, and hate, due to Your enmity those who oppose You. O Allah, this is the supplication (that we are capable of), and it is upon You to respond, and this is the effort (that we are capable of), and upon You is the reliance. O Allah, appoint a light in my heart for me, and a light in my grave, and light in front of me, and light behind me, and light on my right, and light on my left, and light above me, and light below me, and light in my hearing, and light in my vision, and light in my hair, and light in my skin, and light in my flesh, and light in my blood, and light in my bones. O Allah, magnify for me light, and appoint for me a light. Glory is to the One who wears Glory and grants by it. Glory is to the One for Whom glorification is not fitting except for Him, the Possessor of Honor and Bounties, Glory is to the Possessor of Glory and Generosity, Glory is to the Possessor of Majesty and Honor’ (Allāhumma innī as'aluka raḥmatan min `indika tahdī bihā qalbī, wa tajma`u bihā amrī, wa talummu bihā sha`athī, wa tuṣliḥu bihā ghā'ibī, wa tarfa`u bihā shāhidī, wa tuzakkī bihā `amalī, wa tulhimunī bihā rushdī, wa taruddu bihā ulfatī, wa ta`ṣimunī bihā min kulli sū'in. Allāhumma a`ṭinī īmānan wa yaqīnan laisa ba`adahu kufr, wa raḥmatan anālu bihā sharafa karāmatika fid-dunyā wal-ākhira. Allāhumma innī as'alukal-fawza [fil-`atā'i wa yurwa] fil-qaḍā'i, wa nuzulash-shuhadā'i wa `aishas-su`adā'i, wan-naṣra `alal-a`dā'. Allāhumma innī unzilu bika ḥājatī, wa in qaṣura ra'yī wa ḍa`ufa `amalī iftaqartu ilā raḥmatik, fa as'aluka yā qāḍiyal-umūr, wa yā shāfiyas-ṣudūr, kamā tujīru bainal-buḥūr, an tujīranī min `adhābis-sa`īr, wa min da`watith-thubūr, wa min fitnatil-qubūr. Allāhumma mā qaṣṣara `anhu ra'yī wa lam tablughhu niyyatī wa lam tablughhu mas'alatī min khairin wa`adtahu aḥadan min khalqika aw khairin anta mu`ṭīhi aḥadan min `ibādika fa innī arghabu ilaika fīhi, wa as'alukahu bi-raḥmatika rabbal-`ālamīn. Allāhumma dhal-ḥablish-shadīd, wal-amrir-rashīd, as'aluka al-amna yawm al-wa`īd, wal-jannata yawmal-khulūd ma`al-muqarrabīnash-shuhūd, ar-rukka`is-sujūd, al-mūfīna bil-`uhūd, anta rahīmun wadūd, wa innaka taf`alu ma turīd. Allāhummaj`alnā hādīna muhtadīna, ghaira ḍallīna wa la muḍillīna, silman li-awliyā'ika wa `aduwwan li a`dā'ika, nuḥibbu biḥubbika man aḥabbaka wa nu`ādī bi`adāwatika man khālafak. Allāhumma hādhad-du`ā'u wa `alaikal-ijābatu, wa hādhal-juhdu wa `alaikat-tuklān. Allāhummaj`allī nūran fi qalbī wa nūran fi qabrī, wa nūran min baini yadayya, wa nūran min khalfī, wa nūran `an yamīnī, wa nūran `an shimālī, wa nūran min fawqī, wa nūran min taḥtī, wa nūran fi sam`ī, wa nūran fi baṣarī, wa nūran fi sha`rī, wa nūran fi basharī, wa nūran fi laḥmī, wa nūran fi damī, wa nūran fi `iẓamī. Allāhumma a`ẓim lī nūran, wa a`ṭinī nūran, waj`allī nūran. Subḥānal-ladhī ta`aṭṭafal-`izza wa qāla bihi, subḥānal-ladhī labisal-majda wa takarrama bihi, subḥānal-ladhī lā yanbaghit-tasbīḥu illā lahu, subḥāna dhil-faḍli wan-ni`am, subḥāna dhil-majdi wal-karam, subḥāna dhil-jalāli wal-ikrām.).”}}
\hadithdefcmd{tirmidhi}{3420}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، وَغَيْرُ، وَاحِدٍ، قَالُوا أَخْبَرَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنَا أَبُو سَلَمَةَ، قَالَ سَأَلْتُ عَائِشَةَ رضى الله عنها بِأَىِّ شَيْءٍ كَانَ النَّبِيُّ صلى الله عليه وسلم يَفْتَتِحُ صَلاَتَهُ إِذَا قَامَ مِنَ اللَّيْلِ قَالَتْ كَانَ إِذَا قَامَ مِنَ اللَّيْلِ افْتَتَحَ صَلاَتَهُ فَقَالَ ‏ "‏ اللَّهُمَّ رَبَّ جِبْرِيلَ وَمِيكَائِيلَ وَإِسْرَافِيلَ فَاطِرَ السَّمَوَاتِ وَالأَرْضِ وَعَالِمَ الْغَيْبِ وَالشَّهَادَةِ أَنْتَ تَحْكُمُ بَيْنَ عِبَادِكَ فِيمَا كَانُوا فِيهِ يَخْتَلِفُونَ اهْدِنِي لِمَا اخْتُلِفَ فِيهِ مِنَ الْحَقِّ بِإِذْنِكَ إِنَّكَ تَهْدِي مَنْ تَشَاءُ إِلَى صِرَاطٍ مُسْتَقِيمٍ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3420}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Salamah said:“I asked Aishah [may Allah be pleased with her]: ‘With what did the Prophet used to open his Salat when he stood up in the night?’ She said: ‘When he stood up in the night, he would open his Salat by saying: “O Allah, Lord of Jibra’il, Mika’il, and Israfil; Originator of the heavens and the earth, [and] Knower of the hidden and the seen; You judge between Your slaves concerning that which they used to differ, guide me through that which there has been difference concerning the truth, verily, You are upon a straight path (Allāhumma rabba Jibrīla wa Mīkā'ila wa Isrāfīl, fāṭira-samāwāti wal-arḍi [wa] `ālimal-ghaibi wash-shahādati anta taḥkumu baina `ibādika fīmā kānū fīhi yakhtalifūn, ihdini limakhtulifa fīhi minal-ḥaqqi bi'idhnika innaka tahdī man tashā'u ilā ṣirātin mustaqīm).”}}
\hadithdefcmd{tirmidhi}{3421}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا يُوسُفُ بْنُ الْمَاجِشُونَ، حَدَّثَنِي أَبِي، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَامَ إِلَى الصَّلاَةِ قَالَ ‏"‏ وَجَّهْتُ وَجْهِيَ لِلَّذِي فَطَرَ السَّمَوَاتِ وَالأَرْضَ حَنِيفًا وَمَا أَنَا مِنَ الْمُشْرِكِينَ إِنَّ صَلاَتِي وَنُسُكِي وَمَحْيَاىَ وَمَمَاتِي لِلَّهِ رَبِّ الْعَالَمِينَ لاَ شَرِيكَ لَهُ وَبِذَلِكَ أُمِرْتُ وَأَنَا مِنَ الْمُسْلِمِينَ اللَّهُمَّ أَنْتَ الْمَلِكُ لاَ إِلَهَ إِلاَّ أَنْتَ أَنْتَ رَبِّي وَأَنَا عَبْدُكَ ظَلَمْتُ نَفْسِي وَاعْتَرَفْتُ بِذَنْبِي فَاغْفِرْ لِي ذُنُوبِي جَمِيعًا إِنَّهُ لاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ وَاهْدِنِي لأَحْسَنِ الأَخْلاَقِ لاَ يَهْدِي لأَحْسَنِهَا إِلاَّ أَنْتَ وَاصْرِفْ عَنِّي سَيِّئَهَا إِنَّهُ لاَ يَصْرِفُ عَنِّي سَيِّئَهَا إِلاَّ أَنْتَ آمَنْتُ بِكَ تَبَارَكْتَ وَتَعَالَيْتَ أَسْتَغْفِرُكَ وَأَتُوبُ إِلَيْكَ ‏"‏ ‏.‏ فَإِذَا رَكَعَ قَالَ ‏"‏ اللَّهُمَّ لَكَ رَكَعْتُ وَبِكَ آمَنْتُ وَلَكَ أَسْلَمْتُ خَشَعَ لَكَ سَمْعِي وَبَصَرِي وَمُخِّي وَعِظَامِي وَعَصَبِي ‏"‏ ‏.‏ فَإِذَا رَفَعَ رَأْسَهُ قَالَ ‏"‏ اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ مِلْءَ السَّمَوَاتِ وَالأَرَضِينَ وَمِلْءَ مَا بَيْنَهُمَا وَمِلْءَ مَا شِئْتَ مِنْ شَيْءٍ بَعْدُ ‏"‏ ‏.‏ فَإِذَا سَجَدَ قَالَ ‏"‏ اللَّهُمَّ لَكَ سَجَدْتُ وَبِكَ آمَنْتُ وَلَكَ أَسْلَمْتُ سَجَدَ وَجْهِيَ لِلَّذِي خَلَقَهُ فَصَوَّرَهُ وَشَقَّ سَمْعَهُ وَبَصَرَهُ فَتَبَارَكَ اللَّهُ أَحْسَنُ الْخَالِقِينَ ‏"‏ ‏.‏ ثُمَّ يَكُونُ آخِرَ مَا يَقُولُ بَيْنَ التَّشَهُّدِ وَالسَّلاَمِ ‏"‏ اللَّهُمَّ اغْفِرْ لِي مَا قَدَّمْتُ وَمَا أَخَّرْتُ وَمَا أَسْرَرْتُ وَمَا أَعْلَنْتُ وَمَا أَنْتَ أَعْلَمُ بِهِ مِنِّي أَنْتَ الْمُقَدِّمُ وَأَنْتَ الْمُؤَخِّرُ لاَ إِلَهَ إِلاَّ أَنْتَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3421}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ali bin Abi Talib narrated that whenever the Messenger of Allah would stand for Salat, he would say:“I have directed my face towards the One who created the Heavens and the earth, as a Hanif, and I am not of the idolaters. Indeed, my Salat, my sacrifice, my living, and my dying is for Allah, the Lord of all that exists, there is no partner for Him, and with this have I been ordered, and I am among the Muslims. O Allah, You are the King, there is none worthy of worship except You. You are My Lord, and I am Your slave, I have wronged myself, and I admit to my sin, so forgive me all my sins, verily, there is none who forgives sins but You. And guide me to the best of the manners, none guides to the best of them except You, and turn the evil of them away from me, [verily,] none can turn the evil of them away from me except You. I have believed in You. Blessed are You and Exalted are You, I seek Your forgiveness and I repent to you (Wajjahtu wajhiya lilladhī faṭaras-samāwāti wal-arḍa ḥanīfan wa mā ana min al-mushrikīn, inna ṣalātī wa nusukī wa maḥyāya wa mamātī lillāhi rabbil-`ālamīn, lā sharīka lahū wa bidhālika umirtu wa ana min al-muslimīn. Allāhumma antal-maliku lā ilāha illā ant, anta rabbī, wa ana `abduka ẓalamtu nafsī wa`taraftu bidhanbī faghfirlī dhunūbī jamī`an, innahū lā yaghfir adh-dhunūba illā ant. Wahdinī li-aḥsanil-akhlāqi lā yahdī li-aḥsanihā illā ant. Waṣrif `annī sayyi’ahā [innahū] lā yaṣrifu `annī sayyi’aha illā ant. Āmantu bika tabārakta wa ta`ālaita astaghfiruka wa atūbu ilaik).” And when he would bow in Ruku`, he would say: “O Allah, to You I have bowed, and in You I believe, and to You have I submitted. My hearing, my sight, my brain, my bones and my sinew are humbled to you (Allāhumma laka raka`tu wa bika āmantu wa laka aslamtu. Khasha`a laka sam`ī wa baṣarī wa mukhkhī wa `iẓāmī, wa `aṣabī)” Then when he would raise his head, he would say: “O Allah, our Lord, to You is praise the fill of the Heavens and the earths and the fill of whatever You will of things. (Allāhumma rabbanā lakal-ḥamdu mil’as-samāwāti wal-arḍīna wa mā bainahumā, wa mil’a mā shi’ta min shay’in ba`d).” Then, when he prostrated, he would say: “O Allah, to You have I prostrated, and in You have I believed, and to You have I submitted, my face has prostrated to the One Who created it and fashioned it, and gave it its hearing and its sight. So Blessed is Allah, the Best of creators (Allāhumma laka sajadtu wa bika āmantu wa laka aslamtu, sajada wajhi lilladhī khalaqahū fa ṣuwwarahū wa shaqqa sam`ahū wa baṣarahū fatabārak Allāhu ahsanul-khāliqīn).” Then the last of what he would say between At-Tashah-hud and As-Salam would be: “O Allah, forgive me what I have done before and after, and what I have hidden and what I have done openly, and what You know more of it than I, You are the One who sends forth and the One who delays, there is none worthy of worship except You. (Allāhummaghfirlī mā qaddamtu wa mā akhkhartu wa mā asrartu wa mā a`lantu wa mā anta a`lamu bihī minnī antal-Muqaddimu wa antal-Mu’akhkhiru, lā ilāha illā ant).”}}
\hadithdefcmd{tirmidhi}{3422}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ، وَيُوسُفُ بْنُ الْمَاجِشُونِ، قَالَ عَبْدُ الْعَزِيزِ حَدَّثَنِي عَمِّي، وَقَالَ، يُوسُفُ أَخْبَرَنِي أَبِي، حَدَّثَنِي الأَعْرَجُ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا قَامَ إِلَى الصَّلاَةِ قَالَ ‏"‏ وَجَّهْتُ وَجْهِيَ لِلَّذِي فَطَرَ السَّمَوَاتِ وَالأَرْضَ حَنِيفًا وَمَا أَنَا مِنَ الْمُشْرِكِينَ إِنَّ صَلاَتِي وَنُسُكِي وَمَحْيَاىَ وَمَمَاتِي لِلَّهِ رَبِّ الْعَالَمِينَ لاَ شَرِيكَ لَهُ وَبِذَلِكَ أُمِرْتُ وَأَنَا مِنَ الْمُسْلِمِينَ اللَّهُمَّ أَنْتَ الْمَلِكُ لاَ إِلَهَ إِلاَّ أَنْتَ أَنْتَ رَبِّي وَأَنَا عَبْدُكَ ظَلَمْتُ نَفْسِي وَاعْتَرَفْتُ بِذَنْبِي فَاغْفِرْ لِي ذُنُوبِي جَمِيعًا إِنَّهُ لاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ وَاهْدِنِي لأَحْسَنِ الأَخْلاَقِ لاَ يَهْدِي لأَحْسَنِهَا إِلاَّ أَنْتَ وَاصْرِفْ عَنِّي سَيِّئَهَا لاَ يَصْرِفُ عَنِّي سَيِّئَهَا إِلاَّ أَنْتَ لَبَّيْكَ وَسَعْدَيْكَ وَالْخَيْرُ كُلُّهُ فِي يَدَيْكَ وَالشَّرُّ لَيْسَ إِلَيْكَ أَنَا بِكَ وَإِلَيْكَ تَبَارَكْتَ وَتَعَالَيْتَ أَسْتَغْفِرُكَ وَأَتُوبُ إِلَيْكَ ‏"‏ ‏.‏ فَإِذَا رَكَعَ قَالَ ‏"‏ اللَّهُمَّ لَكَ رَكَعْتُ وَبِكَ آمَنْتُ وَلَكَ أَسْلَمْتُ خَشَعَ لَكَ سَمْعِي وَبَصَرِي وَعِظَامِي وَعَصَبِي ‏"‏ ‏.‏ فَإِذَا رَفَعَ قَالَ ‏"‏ اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ مِلْءَ السَّمَاءِ وَمِلْءَ الأَرْضِ وَمِلْءَ مَا بَيْنَهُمَا وَمِلْءَ مَا شِئْتَ مِنْ شَيْءٍ بَعْدُ ‏"‏ ‏.‏ فَإِذَا سَجَدَ قَالَ ‏"‏ اللَّهُمَّ لَكَ سَجَدْتُ وَبِكَ آمَنْتُ وَلَكَ أَسْلَمْتُ سَجَدَ وَجْهِي لِلَّذِي خَلَقَهُ فَصَوَّرَهُ وَشَقَّ سَمْعَهُ وَبَصَرَهُ فَتَبَارَكَ اللَّهُ أَحْسَنُ الْخَالِقِينَ ‏"‏ ‏.‏ ثُمَّ يَقُولُ مِنْ آخِرِ مَا يَقُولُ بَيْنَ التَّشَهُّدِ وَالتَّسْلِيمِ ‏"‏ اللَّهُمَّ اغْفِرْ لِي مَا قَدَّمْتُ وَمَا أَخَّرْتُ وَمَا أَسْرَرْتُ وَمَا أَعْلَنْتُ وَمَا أَسْرَفْتُ وَمَا أَنْتَ أَعْلَمُ بِهِ مِنِّي أَنْتَ الْمُقَدِّمُ وَأَنْتَ الْمُؤَخِّرُ لاَ إِلَهَ إِلاَّ أَنْتَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3422}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ali bin Abi Talib narrated that whenever the Messenger of Allah would stand for Salat, he would say:“I have directed my face towards the One who has created the heavens and the earth, as a Hanif, and I am not of the idolaters. Indeed, my Salat, my sacrifice, my living, my dying, is for Allah, the Lord of all that exists, without partner, and with this have I been ordered and I am of the Muslims. O Allah, You are the King, there is none worthy of worship except You. You are My Lord, and I am Your slave, I have wronged myself and I admit to my sin, so forgive me all my sins, verily, there is none who forgives sins but You, and guide me to the best of manners, none guides to the best of them except You, and turn away from me the evil of them, none can turn away from me the evil of them except You. Here I am in obedience to You, and in aiding Your cause, and the good, all of it is in Your Hands, and the evil is not attributed to You, I am reliant upon You and ever-turning towards You, Blessed are You and Exalted are You. I seek Your forgiveness and I repent to you (Wajjahtu wajhiya lilladhī faṭaras-samāwāti wal-arḍa ḥanīfan wa mā ana min al-mushrikīn, inna ṣalātī wa nusukī wa maḥyāya wa mamātī lillāhi rabbil-`ālamīn, lā sharīka lahū wa bidhālika umirtu wa ana min al-muslimīn. Allāhumma antal-maliku lā ilāha illā ant, anta rabbī, wa ana `abduka ẓalamtu nafsī wa`taraftu bidhanbī faghfirlī dhunūbī jamī`an, innahū lā yaghfir adh-dhunūba illā ant. Wahdinī li-aḥsanil-akhlāqi lā yahdī li-aḥsanihā illā ant. Waṣrif `annī sayyi’ahā lā yaṣrifu `annī sayyi’aha illā ant. Labaika wa sa`daika wal-khairu kulluhū fī yadaika, wash-sharru laisa ilaik, tabārakta wa ta`ālaita astaghfiruka wa atūbu ilaik).” And when he would bow in Ruku he would say: “O Allah, to You have I bowed, and in You have I believed, and to You have I submitted. My hearing, my sight, my bones, and my sinew are humbled to you (Allāhumma laka raka`tu wa bika āmantu wa laka aslamtu. Khasha`a laka sam`ī wa baṣarī wa `iẓāmī, wa `aṣabī).” And when he would rise he would say: “O Allah, our Lord, to You is praise filling the heaven and filling the earth, and filling what is between them, and filling whatever You have wished of things afterward (Allāhumma rabbanā lakal-ḥamdu mil’as-samāwāti wa mil’al-arḍ wa mil’a mā bainahumā, wa mil’a mā shi’ta min shay’in ba`d).” Then, when he prostrated, he would say: “O Allah, to You have I prostrated, and in You have I believed, and to You have I submitted (in Islam), my face has prostrated to the One Who created it, and fashioned it, and gave it its hearing and sight, [so] Blessed is Allah, the Best of Creators (Allāhumma laka sajadtu wa bika āmantu wa laka aslamtu, sajada wajhi lilladhī khalaqahū fa ṣuwwarahū wa shaqqa sam`ahū wa baṣarahū fatabārak Allāhu ahsanul-khāliqīn).” Then the last of what he would say between At-Tashahud and At-Taslim was: “O Allah, forgive me what I have done, before and after, and what I have hidden, and what I have done openly, and what I have transgressed the limit in, and what You know about more than me, You are the One Who sends forth and the One Who delays, there is none worthy of worship except You (Allāhummaghfirlī mā qaddamtu wa mā akhkhartu wa mā asrartu wa mā a`lantu wa mā asraftu wa mā anta a`lamu bihī minnī antal-Muqaddimu wa antal-Mu’akhkhiru, lā ilāha illā ant).”}}
\hadithdefcmd{tirmidhi}{3423}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْهَاشِمِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الزِّنَادِ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ كَانَ إِذَا قَامَ إِلَى الصَّلاَةِ الْمَكْتُوبَةِ رَفَعَ يَدَيْهِ حَذْوَ مَنْكِبَيْهِ وَيَصْنَعُ ذَلِكَ أَيْضًا إِذَا قَضَى قِرَاءَتَهُ وَأَرَادَ أَنْ يَرْكَعَ وَيَصْنَعُهَا إِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ وَلاَ يَرْفَعُ يَدَيْهِ فِي شَيْءٍ مِنْ صَلاَتِهِ وَهُوَ قَاعِدٌ وَإِذَا قَامَ مِنْ سَجْدَتَيْنِ رَفَعَ يَدَيْهِ كَذَلِكَ فَكَبَّرَ وَيَقُولُ حِينَ يَفْتَتِحُ الصَّلاَةَ بَعْدَ التَّكْبِيرِ ‏"‏ وَجَّهْتُ وَجْهِيَ لِلَّذِي فَطَرَ السَّمَوَاتِ وَالأَرْضَ حَنِيفًا وَمَا أَنَا مِنَ الْمُشْرِكِينَ إِنَّ صَلاَتِي وَنُسُكِي وَمَحْيَاىَ وَمَمَاتِي لِلَّهِ رَبِّ الْعَالَمِينَ لاَ شَرِيكَ لَهُ وَبِذَلِكَ أُمِرْتُ وَأَنَا مِنَ الْمُسْلِمِينَ اللَّهُمَّ أَنْتَ الْمَلِكُ لاَ إِلَهَ إِلاَّ أَنْتَ سُبْحَانَكَ أَنْتَ رَبِّي وَأَنَا عَبْدُكَ ظَلَمْتُ نَفْسِي وَاعْتَرَفْتُ بِذَنْبِي فَاغْفِرْ لِي ذُنُوبِي جَمِيعًا إِنَّهُ لاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ وَاهْدِنِي لأَحْسَنِ الأَخْلاَقِ لاَ يَهْدِي لأَحْسَنِهَا إِلاَّ أَنْتَ وَاصْرِفْ عَنِّي سَيِّئَهَا لاَ يَصْرِفُ عَنِّي سَيِّئَهَا إِلاَّ أَنْتَ لَبَّيْكَ وَسَعْدَيْكَ وَأَنَا بِكَ وَإِلَيْكَ وَلاَ مَنْجَا مِنْكَ وَلاَ مَلْجَأَ إِلاَّ إِلَيْكَ أَسْتَغْفِرُكَ وَأَتُوبُ إِلَيْكَ ‏"‏ ‏.‏ ثُمَّ يَقْرَأُ فَإِذَا رَكَعَ كَانَ كَلاَمُهُ فِي رُكُوعِهِ أَنْ يَقُولَ ‏"‏ اللَّهُمَّ لَكَ رَكَعْتُ وَبِكَ آمَنْتُ وَلَكَ أَسْلَمْتُ وَأَنْتَ رَبِّي خَشَعَ سَمْعِي وَبَصَرِي وَمُخِّي وَعَظْمِي لِلَّهِ رَبِّ الْعَالَمِينَ ‏"‏ ‏.‏ فَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ ثُمَّ يُتْبِعُهَا ‏"‏ اللَّهُمَّ رَبَّنَا وَلَكَ الْحَمْدُ مِلْءَ السَّمَوَاتِ وَالأَرْضِ وَمِلْءَ مَا شِئْتَ مِنْ شَيْءٍ بَعْدُ ‏"‏ ‏.‏ وَإِذَا سَجَدَ قَالَ فِي سُجُودِهِ ‏"‏ اللَّهُمَّ لَكَ سَجَدْتُ وَبِكَ آمَنْتُ وَلَكَ أَسْلَمْتُ وَأَنْتَ رَبِّي سَجَدَ وَجْهِي لِلَّذِي خَلَقَهُ وَشَقَّ سَمْعَهُ وَبَصَرَهُ تَبَارَكَ اللَّهُ أَحْسَنُ الْخَالِقِينَ ‏"‏ ‏.‏ وَيَقُولُ عِنْدَ انْصِرَافِهِ مِنَ الصَّلاَةِ ‏"‏ اللَّهُمَّ اغْفِرْ لِي مَا قَدَّمْتُ وَمَا أَخَّرْتُ وَمَا أَسْرَرْتُ وَمَا أَعْلَنْتُ أَنْتَ إِلَهِي لاَ إِلَهَ إِلاَّ أَنْتَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ الشَّافِعِيِّ وَبَعْضِ أَصْحَابِنَا ‏.‏ قَالَ أَبُو عِيسَى وَأَحْمَدُ لاَ يَرَاهُ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَهْلِ الْكُوفَةِ وَغَيْرِهِمْ يَقُولُ هَذَا فِي صَلاَةِ التَّطَوُّعِ وَلاَ يَقُولُهُ فِي الْمَكْتُوبَةِ ‏.‏ سَمِعْتُ أَبَا إِسْمَاعِيلَ التِّرْمِذِيَّ مُحَمَّدَ بْنَ إِسْمَاعِيلَ بْنِ يُوسُفَ يَقُولُ سَمِعْتُ سُلَيْمَانَ بْنَ دَاوُدَ الْهَاشِمِيَّ يَقُولُ وَذَكَرَ هَذَا الْحَدِيثَ فَقَالَ هَذَا عِنْدَنَا مِثْلُ حَدِيثِ الزُّهْرِيِّ عَنْ سَالِمٍ عَنْ أَبِيهِ ‏.‏\hadithno{3423}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ali bin Abi Talib narrated that :when the Messenger of Allah would stand for the obligatory prayer, he would raise his hands to the level of his shoulder, and he would do this [also] when he finished his recitation and intended to bow, and he would do it when he raised his head from Ruku`, and he would not raise his hands in any of his prayers while he was seated. When he would rise from the two prostrations, he would likewise raise his hands, and say the Takbir, and when he opened his Salat after the Takbir, he would say: “I have directed my face towards the One who has created the heavens and the earth, as a Hanif, and I am not of the idolaters. Indeed, my Salat, my sacrifice, my living, my dying, is for Allah, the Lord of all that exists, without partner, and with this have I been ordered and I am of the Muslims. O Allah, You are the King, there is none worthy of worship except You. Glorified are You, You are My Lord, and I am Your slave, I have wronged myself and I admit to my sin, so forgive me all my sins, verily, there is none who forgives sins but You, and guide me to the best of manners, none guides to the best of them except You, and turn away from me the evil of them, none turns away from me the evil of them except You, I am here in Your obedience and aiding Your cause, and I am reliant upon You and ever-turning towards You, [and] there is no refuge from You nor hiding place from You except (going) to You, I seek Your forgiveness, and I repent to you (Wajjahtu wajhiya lilladhī faṭaras-samāwāti wal-arḍa ḥanīfan wa mā ana min al-mushrikīn, inna ṣalātī wa nusukī wa maḥyāya wa mamātī lillāhi rabbil-`ālamīn, lā sharīka lahū wa bidhālika umirtu wa ana min al-muslimīn. Allāhumma antal-maliku lā ilāha illā ant, subḥānaka anta rabbī, wa ana `abduka ẓalamtu nafsī wa`taraftu bidhanbī faghfirlī dhunūbī jamī`an, innahū lā yaghfir adh-dhunūba illā ant. Wahdinī li-aḥsanil-akhlāqi lā yahdī li-aḥsanihā illā ant. Waṣrif `annī sayyi’ahā lā yaṣrifu `annī sayyi’aha illā ant. Labaika wa sa`daika, wa ana bika wa ilaika, [wa] lā manjā minka wa lā malja’a illā ilaik, astaghfiruka wa atūbu ilaik).” Then he would recite, then when he would bow, his speech in his Ruku`, would be to say: “O Allah, to You have I bowed, and in You have I believed, and to You have I submitted (in Islam), and You are my Lord. My hearing, my sight, my brain and my bones are humbled to Allah, the Lord of the Worlds all that exists (Allāhumma laka raka`tu wa bika āmantu wa laka aslamtu wa anta rabb ī. Khasha`a sam`ī wa baṣarī wa mukhkhī wa `aẓmī lillāhi, rabbil-`ālamīn).” Then, when he raised his head from Ruku he would say: “Allah hears the one who praises him (Sami`a Allāhu liman ḥamidah).” Then he would follow it with: “O Allah, our Lord, to You is praise filling the heavens and the earth and filling whatever You wish of things afterward (Allāhumma rabbanā wa lakal-ḥamdu mil’as-samāwāti wal-arḍi, wa mil’a mā shi’ta min shay’in ba`d.).” Then, when prostrated he would say in his prostration: “O Allah, to You have I prostrated, and in You have I believed, and to You have I submitted (in Islam), and You are my Lord, my face has prostrated to the One that created it, and granted its hearing and sight, Blessed is Allah, the Best of Creators (Allāhumma laka sajadtu wa bika āmantu wa laka aslamtu wa anta rabbī, sajada wajhi lilladhī khalaqahū wa shaqqa sam`ahū wa baṣarahū, tabārak Allāhu ahsanul-khāliqīn).” When he was finished with his Salat, we would say: “O Allah, forgive me what I have done, before and after, and what I have hidden, and what I have done openly, and You are my Deity, there is none worthy of worship except You (Allāhummaghfirlī mā qaddamtu wa mā akhkhartu wa mā asrartu wa mā a`lantu, wa anta ilāhī lā ilāha illā ant).”}}
\hadithdefcmd{tirmidhi}{3424}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مُحَمَّدُ بْنُ يَزِيدَ بْنِ خُنَيْسٍ، حَدَّثَنَا الْحَسَنُ بْنُ مُحَمَّدِ بْنِ عُبَيْدِ اللَّهِ بْنِ أَبِي يَزِيدَ، قَالَ قَالَ لِي ابْنُ جُرَيْجٍ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ أَبِي يَزِيدَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ رَأَيْتُنِي اللَّيْلَةَ وَأَنَا نَائِمٌ كَأَنِّي أُصَلِّي خَلْفَ شَجَرَةٍ فَسَجَدَتِ الشَّجَرَةُ لِسُجُودِي وَسَمِعْتُهَا وَهِيَ تَقُولُ اللَّهُمَّ اكْتُبْ لِي بِهَا عِنْدَكَ أَجْرًا وَضَعْ عَنِّي بِهَا وِزْرًا وَاجْعَلْهَا لِي عِنْدَكَ ذُخْرًا وَتَقَبَّلْهَا مِنِّي كَمَا تَقَبَّلْتَهَا مِنْ عَبْدِكَ دَاوُدَ ‏.‏ قَالَ ابْنُ جُرَيْجٍ قَالَ لِي جَدُّكَ قَالَ ابْنُ عَبَّاسٍ فَقَرَأَ النَّبِيُّ صلى الله عليه وسلم سَجْدَةً ثُمَّ سَجَدَ ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَسَمِعْتُهُ وَهُوَ يَقُولُ مِثْلَ مَا أَخْبَرَ الرَّجُلُ عَنْ قَوْلِ الشَّجَرَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ ‏.‏\hadithno{3424}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Al-Hasan bin Muhammad bin Ubaidullah bin Abi Yazid said:“Ibn Juraij said to me: “Ubaidullah bin Abi Yazid informed me that Ibn Abbas said: “A man came to the Prophet and said: ‘O Messenger of Allah! I had a dream at night while I was sleeping, in which I was praying behind a tree, when I prostrated, the tree prostrated along with me. Then I heard it saying: “O Allah! Record for me a reward with You for it, remove a sin from me by it, and store it away for me with You for it, and accept it from me as You accepted it from Your worshipper Dawud (Allāhumma uktub lī bihā `indaka ajran, waḍa` `annī bihā wizran, waj`alhā lī `indaka dhukhran, wa taqabbalhā minnī kamā taqabbalta min `abdika Dāwūd).” Al-Hasan said: “Ibn Juraij said to me: ‘Your grandfather said to me: “Ibn Abbas said: ‘So the Prophet recited (an Ayah of) prostration, then prostrated.’” [He said] “So Ibn Abbas said: ‘I listened to him, and he was saying the same as the man informed that the tree had said.’”}}
\hadithdefcmd{tirmidhi}{3425}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي الْعَالِيَةِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ فِي سُجُودِ الْقُرْآنِ بِاللَّيْلِ ‏ "‏ سَجَدَ وَجْهِي لِلَّذِي خَلَقَهُ وَشَقَّ سَمْعَهُ وَبَصَرَهُ بِحَوْلِهِ وَقُوَّتِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3425}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:“When the Messenger of Allah would prostrate (for recitation of) the Qur’an, he would say: ‘I have prostrated my face to the One Who created it, and made its hearing and vision, through His ability and power (Sajada wajhī lilladhī khalaqahū wa shaqqa sam`ahū wa baṣarahū bi ḥawlihī wa quwwatih).’”}}
\hadithdefcmd{tirmidhi}{3426}{حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى بْنِ سَعِيدٍ الأُمَوِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَالَ - يَعْنِي إِذَا خَرَجَ مِنْ بَيْتِهِ - بِسْمِ اللَّهِ تَوَكَّلْتُ عَلَى اللَّهِ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏.‏ يُقَالُ لَهُ كُفِيتَ وَوُقِيتَ ‏.‏ وَتَنَحَّى عَنْهُ الشَّيْطَانُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3426}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah (ﷺ) said:“Whoever says – that is: when he leaves his house – ‘In the Name of Allah, I place my trust in Allah, there is no might or power except by Allah (Bismillāh, tawakkaltu `alallāh, lā ḥawla wa lā quwwata illā billāh)’ it will be said to him: ‘You have been sufficed and protected,’ and Shaitan will become distant from him.”}}
\hadithdefcmd{tirmidhi}{3427}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ عَامِرٍ الشَّعْبِيِّ، عَنْ أُمِّ سَلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا خَرَجَ مِنْ بَيْتِهِ قَالَ ‏ "‏ بِسْمِ اللَّهِ تَوَكَّلْتُ عَلَى اللَّهِ اللَّهُمَّ إِنَّا نَعُوذُ بِكَ مِنْ أَنْ نَزِلَّ أَوْ نَضِلَّ أَوْ نَظْلِمَ أَوْ نُظْلَمَ أَوْ نَجْهَلَ أَوْ يُجْهَلَ عَلَيْنَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3427}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Umm Salamah narrated that :When the Prophet (ﷺ) would leave his house, he would say: “In the Name of Allah, I place my trust in Allah. O Allah! We seek refuge in You from slipping unintentionally or becoming misguided, or committing oppression or being oppressed, or acting ignorantly or being treated ignorantly (Bismillāh, tawakkaltu `alallāh. Allāhumma, innā na`ūdhu bika min an nazilla aw naḍilla, aw naẓlima aw nuẓlam, aw najhala aw yujhala alainā).”}}
\hadithdefcmd{tirmidhi}{3428}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا أَزْهَرُ بْنُ سِنَانٍ، حَدَّثَنَا مُحَمَّدُ بْنُ وَاسِعٍ، قَالَ قَدِمْتُ مَكَّةَ فَلَقِيَنِي أَخِي سَالِمُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ فَحَدَّثَنِي عَنْ أَبِيهِ عَنْ جَدِّهِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ دَخَلَ السُّوقَ فَقَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكُ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ يُحْيِي وَيُمِيتُ وَهُوَ حَىٌّ لاَ يَمُوتُ بِيَدِهِ الْخَيْرُ وَهُوَ عَلَى كُلِّ شَيْءٍ قَدِيرٌ كَتَبَ اللَّهُ لَهُ أَلْفَ أَلْفِ حَسَنَةٍ وَمَحَا عَنْهُ أَلْفَ أَلْفِ سَيِّئَةٍ وَرَفَعَ لَهُ أَلْفَ أَلْفِ دَرَجَةٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَاهُ عَمْرُو بْنُ دِينَارٍ - وَهُوَ قَهْرَمَانُ آلِ الزُّبَيْرِ عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، هَذَا الْحَدِيثَ نَحْوَهُ\hadithno{3428}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Salim bin Abdullah bin Umar narrated from his father, from his grandfather, that :the Messenger of Allah (ﷺ) said: “Whoever enters the marketplace and says: ‘There is none worthy of worship except Allah, Alone, without partner, to Him belongs the dominion, and to Him is all the praise, He gives life and causes death, He is Living and does not die, in His Hand is the good, and He has power over all things, (Lā ilāha illallāh, waḥdahu lā sharīka lahu, lahul-mulku wa lahul-ḥamdu, yuḥyī wa yumītu, wa huwa ḥayyun lā yamūtu, biyadihil-khairu, wa huwa `alā kulli shay’in qadīr)’ Allah shall record a million good deeds for him, wipe a million evil deeds away from him, and raise a million ranks for him.”}}
\hadithdefcmd{tirmidhi}{3429}{حَدَّثَنَا بِذَلِكَ، أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، وَالْمُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالاَ حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، وَهُوَ قَهْرَمَانُ آلِ الزُّبَيْرِ عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ فِي السُّوقِ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ يُحْيِي وَيُمِيتُ وَهُوَ حَىٌّ لاَ يَمُوتُ بِيَدِهِ الْخَيْرُ وَهُوَ عَلَى كُلِّ شَيْءٍ قَدِيرٌ كَتَبَ اللَّهُ لَهُ أَلْفَ أَلْفِ حَسَنَةٍ وَمَحَا عَنْهُ أَلْفَ أَلْفِ سَيِّئَةٍ وَبَنَى لَهُ بَيْتًا فِي الْجَنَّةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَعَمْرُو بْنُ دِينَارٍ هَذَا هُوَ شَيْخٌ بَصْرِيٌّ وَقَدْ تَكَلَّمَ فِيهِ بَعْضُ أَصْحَابِ الْحَدِيثِ وَقَدْ رَوَى عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ أَحَادِيثَ لاَ يُتَابَعُ عَلَيْهَا وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏ وَرَوَاهُ يَحْيَى بْنُ سُلَيْمٍ الطَّائِفِيُّ عَنْ عِمْرَانَ بْنِ مُسْلِمٍ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَذْكُرْ فِيهِ عَنْ عُمَرَ رضى الله عنه ‏.‏\hadithno{3429}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Salim bin Abdullah bin Umar narrates from his father, from his grandfather, that :the Messenger of Allah (ﷺ) said: “Whoever states in the marketplace: ‘There is none worthy of worship except Allah, Alone, without partner, to Him belongs the dominion, and to Him is all the praise, He gives life and causes death, and He is Living and does not die, in His Hand is the good, and He has power over all things, (Lā ilāha illallāh, waḥdahu lā sharīka lahu, lahul-mulku wa lahul-ḥamdu, yuḥyī wa yumītu, wa huwa ḥayyun lā yamūtu, biyadihil-khairu, wa huwa `alā kulli shay’in qadīr)’ Allah shall record a million good deeds for him, wipe a million evil deeds away from him, and build a house in Paradise for him}}
\hadithdefcmd{tirmidhi}{3430}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُحَمَّدِ بْنِ جُحَادَةَ، حَدَّثَنَا عَبْدُ الْجَبَّارِ بْنُ عَبَّاسٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَغَرِّ أَبِي مُسْلِمٍ، قَالَ أَشْهَدُ عَلَى أَبِي سَعِيدٍ وَأَبِي هُرَيْرَةَ أَنَّهُمَا شَهِدَا عَلَى النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ ‏.‏ صَدَّقَهُ رَبُّهُ فَقَالَ لاَ إِلَهَ إِلاَّ أَنَا وَأَنَا أَكْبَرُ ‏.‏ وَإِذَا قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ ‏.‏ قَالَ يَقُولُ اللَّهُ لاَ إِلَهَ إِلاَّ أَنَا وَأَنَا وَحْدِي ‏.‏ وَإِذَا قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ ‏.‏ قَالَ اللَّهُ لاَ إِلَهَ إِلاَّ أَنَا وَحْدِي لاَ شَرِيكَ لِي ‏.‏ وَإِذَا قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ ‏.‏ قَالَ اللَّهُ لاَ إِلَهَ إِلاَّ أَنَا لِيَ الْمُلْكُ وَلِيَ الْحَمْدُ ‏.‏ وَإِذَا قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏.‏ قَالَ اللَّهُ لاَ إِلَهَ إِلاَّ أَنَا وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِي ‏.‏ وَكَانَ يَقُولُ مَنْ قَالَهَا فِي مَرَضِهِ ثُمَّ مَاتَ لَمْ تَطْعَمْهُ النَّارُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَاهُ شُعْبَةُ عَنْ أَبِي إِسْحَاقَ، عَنِ الأَغَرِّ أَبِي مُسْلِمٍ، عَنْ أَبِي هُرَيْرَةَ، وَأَبِي، سَعِيدٍ بِنَحْوِ هَذَا الْحَدِيثِ بِمَعْنَاهُ وَلَمَ يَرْفَعْهُ شُعْبَةُ ‏.‏ حَدَّثَنَا بِذَلِكَ، بُنْدَارٌ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، بِهَذَا ‏.‏\hadithno{3430}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Al-Agharr Abu Muslim narrated that he bears witness from Abu Sa’eed Al-Khudri and Abu Hurairah, that they bear witness that :the Prophet (ﷺ) said: “Whoever says: ‘There is none worthy of worship except Allah, and Allah is the Greatest, (Lā ilāha illallāh, wa Allāhu akbar)’ His Lord affirms his statement and says: ‘There is none worthy of worship except Me, and I am the Greatest,’ and when he say: ‘There is none worthy of worship except for Allah, Alone, (Lā ilāha illallāh, waḥdahu)’ Allah says: ‘There is none worthy of worship except for Me and I am Alone.’ And when he say: ‘There is none worthy of worship except for Allah, Alone, without partner, (Lā ilāha illallāh, waḥdahu lā sharīka lahu)’ Allah says: ‘There is none worthy of worship except Me, Alone, I have no partner.’ And when he say: ‘There is none worthy of worship except for Allah, to Him belongs all that exists, and to Him is the praise, (Lā ilāha illallāh, lahul-mulku wa lahul-ḥamdu)’ Allah says: ‘There is none worthy of worship except Me, to Me belongs all that exists, and to Me is the praise.’ And when he says: ‘There is none worthy of worship except Allah, and there is no might or power except by Allah, (Lā ilāha illallāh, wa lā ḥawla wa lā quwwata illā billāh)’ Allah says: ‘There is none worthy of worship except Me, and there is no might or power except by Me.’” And he used to say: “Whoever says it in his illness, then dies, the Fire shall not consume him.”}}
\hadithdefcmd{tirmidhi}{3431}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، مَوْلَى آلِ الزُّبَيْرِ عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ رَأَى صَاحِبَ بَلاَءٍ فَقَالَ الْحَمْدُ لِلَّهِ الَّذِي عَافَانِي مِمَّا ابْتَلاَكَ بِهِ وَفَضَّلَنِي عَلَى كَثِيرٍ مِمَّنْ خَلَقَ تَفْضِيلاً إِلاَّ عُوفِيَ مِنْ ذَلِكَ الْبَلاَءِ كَائِنًا مَا كَانَ مَا عَاشَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَعَمْرُو بْنُ دِينَارٍ قَهْرَمَانُ آلِ الزُّبَيْرِ هُوَ شَيْخٌ بَصْرِيٌ وَلَيْسَ هُوَ بِالْقَوِيِّ فِي الْحَدِيثِ ‏.‏ وَقَدْ تَفَرَّدَ بِأَحَادِيثَ عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي جَعْفَرٍ مُحَمَّدِ بْنِ عَلِيٍّ أَنَّهُ قَالَ إِذَا رَأَى صَاحِبَ بَلاَءٍ فَتَعَوَّذَ مِنْهُ يَقُولُ ذَلِكَ فِي نَفْسِهِ وَلاَ يُسْمِعُ صَاحِبَ الْبَلاَءِ ‏.‏\hadithno{3431}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Umar narrated that:The Messenger of Allah (ﷺ) said: “Whoever sees a person afflicted and say: ‘All praise is due to Allah Who saved me from that which He has afflicted you with, and blessed me greatly over many of those whom He has created, (Al-ḥamdulillāhi alladhī `āfānī mimmabtalāka bihī wa faḍḍalanī `alā kathīrin mimman khalaqa tafḍīla)’ then he shall be saved from that affliction for as long as he lives.”}}
\hadithdefcmd{tirmidhi}{3432}{حَدَّثَنَا أَبُو جَعْفَرٍ السِّمْنَانِيُّ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا مُطَرِّفُ بْنُ عَبْدِ اللَّهِ الْمَدَنِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ الْعُمَرِيُّ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ رَأَى مُبْتَلًى فَقَالَ الْحَمْدُ لِلَّهِ الَّذِي عَافَانِي مِمَّا ابْتَلاَكَ بِهِ وَفَضَّلَنِي عَلَى كَثِيرٍ مِمَّنْ خَلَقَ تَفْضِيلاً لَمْ يُصِبْهُ ذَلِكَ الْبَلاَءُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3432}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah (ﷺ) said: “Whoever sees an afflicted person then says: ‘All praise is due to Allah who saved me from that which He has afflicted you with, and blessed me greatly over many of those whom He has created, (Al-ḥamdulillāhi alladhī `āfānī mimmabtalāka bihī wa faḍḍalanī `alā kathīrin mimman khalaqa tafḍīla)’ he shall not be struck by that affliction.”}}
\hadithdefcmd{tirmidhi}{3433}{حَدَّثَنَا أَبُو عُبَيْدَةَ بْنُ أَبِي السَّفَرِ الْكُوفِيُّ، - وَاسْمُهُ أَحْمَدُ بْنُ عَبْدِ اللَّهِ الْهَمْدَانِيُّ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي مُوسَى بْنُ عُقْبَةَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ جَلَسَ فِي مَجْلِسٍ فَكَثُرَ فِيهِ لَغَطُهُ فَقَالَ قَبْلَ أَنْ يَقُومَ مِنْ مَجْلِسِهِ ذَلِكَ سُبْحَانَكَ اللَّهُمَّ وَبِحَمْدِكَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ أَنْتَ أَسْتَغْفِرُكَ وَأَتُوبُ إِلَيْكَ ‏.‏ إِلاَّ غُفِرَ لَهُ مَا كَانَ فِي مَجْلِسِهِ ذَلِكَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَرْزَةَ وَعَائِشَةَ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ مِنْ هَذَا الْوَجْهِ لاَ نَعْرِفُهُ مِنْ حَدِيثِ سُهَيْلٍ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3433}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah (ﷺ) said: “Whoever sits in a sitting and engages in much empty, meaningless speech and then says before getting from that sitting of his: ‘Glory is to You, O Allah, and praise, I bear witness that there is none worthy of worship except You, I seek You forgiveness, and I repent to You, (Subḥānaka Allāhumma wa biḥamdika, ashhadu an lā ilāha illā anta, astaghfiruka wa atūbu ilaik)’ whatever occurred in that sitting would be forgiven to him.”}}
\hadithdefcmd{tirmidhi}{3434}{حَدَّثَنَا نَصْرُ بْنُ عَبْدِ الرَّحْمَنِ الْكُوفِيُّ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنْ مَالِكِ بْنِ مِغْوَلٍ، عَنْ مُحَمَّدِ بْنِ سُوقَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ يُعَدُّ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْمَجْلِسِ الْوَاحِدِ مِائَةُ مَرَّةٍ مِنْ قَبْلِ أَنْ يَقُومَ ‏ "‏ رَبِّ اغْفِرْ لِي وَتُبْ عَلَىَّ إِنَّكَ أَنْتَ التَّوَّابُ الْغَفُورُ ‏"‏ ‏.‏ حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ سُوقَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ بِمَعْنَاهُ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3434}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Umar said:“In one sitting of the Messenger of Allah (ﷺ), one could count that he said a hundred time, before he would get up: ‘O my Lord, forgive me, and accept my repentance. Verily, You are the Oft-Returning, the Most Forgiving (Rabbighfirlī watub `alayya innaka antat-Tawwābul-Ghafūr).’”}}
\hadithdefcmd{tirmidhi}{3435}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَدْعُو عِنْدَ الْكَرْبِ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ الْعَلِيُّ الْحَلِيمُ لاَ إِلَهَ إِلاَّ اللَّهُ رَبُّ الْعَرْشِ الْعَظِيمِ لاَ إِلَهَ إِلاَّ اللَّهُ رَبُّ السَّمَوَاتِ وَالأَرْضِ وَرَبُّ الْعَرْشِ الْكَرِيمِ ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ هِشَامٍ، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ ‏.‏ قَالَ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3435}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated that :when he was in distress, the Prophet of Allah (ﷺ) would supplicate: “There is none worthy of worship except Allah, the Forbearing, the Wise, there is none worthy of worship except Allah, the Lord of the Magnificent Throne, there is none worthy of worship except Allah, the Lord of the heavens and the earth, and the Lord of the Noble Throne (Lā ilāha illallāh al-`aliyyul ḥalīm, lā ilāha illallāh, rabbul-`arshil-`aẓīm, lā ilāha illallāh, rabbus-samāwāti wal-arḍi wa rabbul-`arshil-karīm).”}}
\hadithdefcmd{tirmidhi}{3436}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ الْمُغِيرَةِ الْمَخْزُومِيُّ الْمَدَنِيُّ وَغَيْرُ وَاحِدٍ قَالُوا حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ إِبْرَاهِيمَ بْنِ الْفَضْلِ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَهَمَّهُ الأَمْرُ رَفَعَ رَأْسَهُ إِلَى السَّمَاءِ فَقَالَ ‏"‏ سُبْحَانَ اللَّهِ الْعَظِيمِ ‏"‏ ‏.‏ وَإِذَا اجْتَهَدَ فِي الدُّعَاءِ قَالَ ‏"‏ يَا حَىُّ يَا قَيُّومُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3436}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that:When a matter would worry the Prophet (ﷺ), he would raise his head up toward the sky and say: “Glory is to Allah, the Magnificent (Subḥān Allāhil-`Aẓīm).” And when he would strive in supplication; he would say: “O the Living, O Sustainer (Yā Ḥayyu yā Qayyūm).”}}
\hadithdefcmd{tirmidhi}{3437}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنِ الْحَارِثِ بْنِ يَعْقُوبَ، عَنْ يَعْقُوبَ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ خَوْلَةَ بِنْتِ حَكِيمٍ السُّلَمِيَّةِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ نَزَلَ مَنْزِلاً ثُمَّ قَالَ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّاتِ مِنْ شَرِّ مَا خَلَقَ لَمْ يَضُرَّهُ شَيْءٌ حَتَّى يَرْتَحِلَ مِنْ مَنْزِلِهِ ذَلِكَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَرَوَى مَالِكُ بْنُ أَنَسٍ هَذَا الْحَدِيثَ أَنَّهُ بَلَغَهُ عَنْ يَعْقُوبَ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ فَذَكَرَ نَحْوَ هَذَا الْحَدِيثِ ‏.‏ وَرُوِيَ عَنِ ابْنِ عَجْلاَنَ هَذَا الْحَدِيثُ عَنْ يَعْقُوبَ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ وَيَقُولُ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ عَنْ خَوْلَةَ ‏.‏ قَالَ وَحَدِيثُ اللَّيْثِ أَصَحُّ مِنْ رِوَايَةِ ابْنِ عَجْلاَنَ ‏.‏\hadithno{3437}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Sa`d bin Abi Waqqas narrated:From Khawlah bint Al Hakim As-Sulamiyyah, that the Messenger of Allah (ﷺ) said: “Whoever stops at a stopping place and then says: ‘I seek refuge in Allah’s Perfect Words from the evil of what He has created, (A`ūdhu bi-kalimātillāhit-tāmmāti min sharri mā khalaq)’ nothing shall harm him until he departs from that stopping place of his.”}}
\hadithdefcmd{tirmidhi}{3438}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ عَلِيٍّ الْمُقَدَّمِيُّ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ بِشْرٍ الْخَثْعَمِيِّ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَافَرَ فَرَكِبَ رَاحِلَتَهُ قَالَ بِأُصْبُعِهِ وَمَدَّ شُعْبَةُ بِأُصْبُعِهِ قَالَ ‏ "‏ اللَّهُمَّ أَنْتَ الصَّاحِبُ فِي السَّفَرِ وَالْخَلِيفَةُ فِي الأَهْلِ اللَّهُمَّ اصْحَبْنَا بِنُصْحِكَ وَاقْلِبْنَا بِذِمَّةٍ ‏.‏ اللَّهُمَّ ازْوِ لَنَا الأَرْضَ وَهَوِّنْ عَلَيْنَا السَّفَرَ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ وَعْثَاءِ السَّفَرِ وَكَآبَةِ الْمُنْقَلَبِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى كُنْتُ لاَ أَعْرِفُ هَذَا إِلاَّ مِنْ حَدِيثِ ابْنِ أَبِي عَدِيٍّ حَتَّى حَدَّثَنِي بِهِ سُوَيْدٌ ‏.‏ حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ نَحْوَهُ بِمَعْنَاهُ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ أَبِي هُرَيْرَةَ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ ابْنِ أَبِي عَدِيٍّ عَنْ شُعْبَةَ ‏.‏\hadithno{3438}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated:“When the Prophet (ﷺ) would travel, and he would mount his riding camel, he would gesture with his finger” – and Shu`bah stretched out his finger – “and say: ‘O Allah You are the companion on the journey, and the caretaker for the family, O Allah, accompany us with Your protection, and return us in security, O Allah, I seek refuge in You from the difficulties of the journey, and from returning in great sadness (Allāhumma antaṣ-ṣāḥibu fis safari wal-khalīfatu fil-ahli, Allāhumma aṣḥabnā bi nuṣḥika waqlibnā bi-dhimmah, Allāhummazwi lanal-arḍa wa hawwin `alainas-safar, Allāhumma innī a’ūdhu bika min wa`thā’is-safari wa ka’ābatil-munqalab).’”}}
\hadithdefcmd{tirmidhi}{3439}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا سَافَرَ يَقُولُ ‏ "‏ اللَّهُمَّ أَنْتَ الصَّاحِبُ فِي السَّفَرِ وَالْخَلِيفَةُ فِي الأَهْلِ اللَّهُمَّ اصْحَبْنَا فِي سَفَرِنَا وَاخْلُفْنَا فِي أَهْلِنَا اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ وَعْثَاءِ السَّفَرِ وَكَآبَةِ الْمُنْقَلَبِ وَمِنَ الْحَوْرِ بَعْدَ الْكَوْنِ وَمِنْ دَعْوَةِ الْمَظْلُومِ وَمِنْ سُوءِ الْمَنْظَرِ فِي الأَهْلِ وَالْمَالِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَيُرْوَى الْحَوْرِ بَعْدَ الْكَوْرِ أَيْضًا قَالَ وَمَعْنَى قَوْلِهِ الْحَوْرِ بَعْدَ الْكَوْنِ أَوِ الْكَوْرِ وَكِلاَهُمَا لَهُ وَجْهٌ يُقَالُ إِنَّمَا هُوَ الرُّجُوعُ مِنَ الإِيمَانِ إِلَى الْكُفْرِ أَوْ مِنَ الطَّاعَةِ إِلَى الْمَعْصِيَةِ إِنَّمَا يَعْنِي الرُّجُوعَ مِنْ شَيْءٍ إِلَى شَيْءٍ مِنَ الشَّرِّ ‏.‏\hadithno{3439}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin Sarjis narrated that:When the Prophet (ﷺ) wanted to travel, he would say: “O Allah, You are the companion on the journey, and the caretaker for the family, O Allah, accompany us in our journey, and watch over our families, O Allah, I seek refuge in You from the difficulties of the journey, and from returning in great sadness, and from loss after increase, and from the supplication of the oppressed, and from someone looking with evil at our families and wealth (Allāhumma antaṣ-ṣāḥibu fis safari wal-khalīfatu fil-ahli, allāhumma aṣḥabnā fī safarinā wakhlufnā fī ahlinā. Allāhumma innī a’ūdhu bika min wa`thā’is-safari wa ka’ābatil-munqalab, wa minal-ḥawri ba`dal-kawni, wa min da`watil-maẓlūm, wa min sū’il-manẓari fil-ahli wal-māl).”}}
\hadithdefcmd{tirmidhi}{3440}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَنْبَأَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الرَّبِيعَ بْنَ الْبَرَاءِ بْنِ عَازِبٍ، يُحَدِّثُ عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا قَدِمَ مِنْ سَفَرٍ قَالَ ‏ "‏ آيِبُونَ تَائِبُونَ عَابِدُونَ لِرَبِّنَا حَامِدُونَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَرَوَى الثَّوْرِيُّ هَذَا الْحَدِيثَ عَنْ أَبِي إِسْحَاقَ عَنِ الْبَرَاءِ وَلَمْ يَذْكُرْ فِيهِ عَنِ الرَّبِيعِ بْنِ الْبَرَاءِ وَرِوَايَةُ شُعْبَةَ أَصَحُّ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَنَسٍ وَجَابِرِ بْنِ عَبْدِ اللَّهِ ‏.‏\hadithno{3440}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ar-Rabi` bin Al-Bara’ bin `Azib reported from, his father:That whenever the Prophet (ﷺ) would return from a trip, he would say: “(We are) Returning, repenting, worshipping, and to our Lord directing the praise (Ā’ibūna tā’būna `ābidūna lirabbinā ḥāmidūn).”}}
\hadithdefcmd{tirmidhi}{3441}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا قَدِمَ مِنْ سَفَرٍ فَنَظَرَ إِلَى جُدُرَاتِ الْمَدِينَةِ أَوْضَعَ رَاحِلَتَهُ وَإِنْ كَانَ عَلَى دَابَّةٍ حَرَّكَهَا مِنْ حُبِّهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3441}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Anas narrated that:When the Prophet would return from a trip and see the walls of Al-Madinah, he would speed up his riding camel, and if he was upon a beast, he would agitate it, out of his love for Al-Madinah}}
\hadithdefcmd{tirmidhi}{3442}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي عُبَيْدِ اللَّهِ السُّلَيْمِيُّ الْبَصْرِيُّ، حَدَّثَنَا أَبُو قُتَيْبَةَ، سَلْمُ بْنُ قُتَيْبَةَ عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ أُمَيَّةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا وَدَّعَ رَجُلاً أَخَذَ بِيَدِهِ فَلاَ يَدَعُهَا حَتَّى يَكُونَ الرَّجُلُ هُوَ يَدَعُ يَدَ النَّبِيِّ صلى الله عليه وسلم وَيَقُولُ ‏ "‏ أَسْتَوْدِعُ اللَّهَ دِينَكَ وَأَمَانَتَكَ وَآخِرَ عَمَلِكَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَرُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنِ ابْنِ عُمَرَ ‏.‏\hadithno{3442}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated, saying:“When the Prophet (ﷺ) would bid farewell to a man, he would take his hand, and not let it go until the man let go of the hand, of the Prophet, and he would say: ‘I entrust to Allah your religion, your trusts, and the last of your deeds (Astawdi`ullāha dīnaka wa amānataka wa ākhira `amalik).’”}}
\hadithdefcmd{tirmidhi}{3443}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى الْفَزَارِيُّ، حَدَّثَنَا سَعِيدُ بْنُ خُثَيْمٍ، عَنْ حَنْظَلَةَ، عَنْ سَالِمٍ، أَنَّ ابْنَ عُمَرَ، كَانَ يَقُولُ لِلرَّجُلِ إِذَا أَرَادَ سَفَرًا ادْنُ مِنِّي أُوَدِّعْكَ كَمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُوَدِّعُنَا ‏.‏ فَيَقُولُ ‏ "‏ أَسْتَوْدِعُ اللَّهَ دِينَكَ وَأَمَانَتَكَ وَخَوَاتِيمَ عَمَلِكَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ سَالِمِ بْنِ عَبْدِ اللَّهِ ‏.‏\hadithno{3443}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Salim narrated that :when he intended to undertake a journey, Ibn `Umar used to say to a person to “Come close to me so that I may bid you farewell as the Messenger of Allah (ﷺ) used to bid us farewell.” Then he would say: “I entrust to Allah your religion, and your trusts, and the last of your deeds (Astawdi`ullāha dīnaka wa amānataka wa khawātīma `amalik).”}}
\hadithdefcmd{tirmidhi}{3444}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، حَدَّثَنَا سَيَّارٌ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أُرِيدُ سَفَرًا فَزَوِّدْنِي ‏.‏ قَالَ ‏"‏ زَوَّدَكَ اللَّهُ التَّقْوَى ‏"‏ ‏.‏ قَالَ زِدْنِي ‏.‏ قَالَ ‏"‏ وَغَفَرَ ذَنْبَكَ ‏"‏ ‏.‏ قَالَ زِدْنِي بِأَبِي أَنْتَ وَأُمِّي ‏.‏ قَالَ ‏"‏ وَيَسَّرَ لَكَ الْخَيْرَ حَيْثُمَا كُنْتَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3444}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Anas said:“A man came to the Messenger of Allah (ﷺ) and said: ‘I intend to undertake a journey, so give me provision. He said: ‘May Allah grant you Taqwa as your provision (Zawwadak Allāhut-taqwā).’ He said: ‘Give me more.’ He said: ‘And may He forgive your sin (Wa ghafara dhanbak).’ He said: ‘Give me more, may my father be ransomed for you, and my mother.’ He said: ‘And may He make goodness easy for you wherever you are (Wa yassara lakal-khaira ḥaithu mā kunt).’”}}
\hadithdefcmd{tirmidhi}{3445}{حَدَّثَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ الْكِنْدِيُّ الْكُوفِيُّ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ إِنِّي أُرِيدُ أَنْ أُسَافِرَ فَأَوْصِنِي ‏.‏ قَالَ ‏"‏ عَلَيْكَ بِتَقْوَى اللَّهِ وَالتَّكْبِيرِ عَلَى كُلِّ شَرَفٍ ‏"‏ ‏.‏ فَلَمَّا أَنْ وَلَّى الرَّجُلُ قَالَ ‏"‏ اللَّهُمَّ اطْوِ لَهُ الأَرْضَ وَهَوِّنْ عَلَيْهِ السَّفَرَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{3445}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah [may Allah be pleased with him] narrated that :a man said: “O Messenger of Allah (ﷺ), I intend to travel, so advise me.” He said, “Hold fast to the Taqwa of Allah, and (say the) Takbir upon every elevated place.” So when the man turned away he said: “O Allah make near for him the distance, and ease for him the journey (Allāhummaṭwi lahul-arḍa wa hawwin `alaihis-safar).”}}
\hadithdefcmd{tirmidhi}{3446}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَلِيِّ بْنِ رَبِيعَةَ، قَالَ شَهِدْتُ عَلِيًّا أُتِيَ بِدَابَّةٍ لِيَرْكَبَهَا فَلَمَّا وَضَعَ رِجْلَهُ فِي الرِّكَابِ قَالَ بِسْمِ اللَّهِ ثَلاَثًا فَلَمَّا اسْتَوَى عَلَى ظَهْرِهَا قَالَ الْحَمْدُ لِلَّهِ ثُمَّ قَالَ ‏:‏ ‏(‏ سبْحَانَ الَّذِي سَخَّرَ لَنَا هَذَا وَمَا كُنَّا لَهُ مُقْرِنِينَ * وَإِنَّا إِلَى رَبِّنَا لَمُنْقَلِبُونَ ‏)‏ ثُمَّ قَالَ الْحَمْدُ لِلَّهِ ثَلاَثًا وَاللَّهُ أَكْبَرُ ثَلاَثًا سُبْحَانَكَ إِنِّي قَدْ ظَلَمْتُ نَفْسِي فَاغْفِرْ لِي فَإِنَّهُ لاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ ‏.‏ ثُمَّ ضَحِكَ ‏.‏ فَقُلْتُ مِنْ أَىِّ شَيْءٍ ضَحِكْتَ يَا أَمِيرَ الْمُؤْمِنِينَ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم صَنَعَ كَمَا صَنَعْتُ ثُمَّ ضَحِكَ فَقُلْتُ مِنْ أَىِّ شَيْءٍ ضَحِكْتَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ إِنَّ رَبَّكَ لَيَعْجَبُ مِنْ عَبْدِهِ إِذَا قَالَ رَبِّ اغْفِرْ لِي ذُنُوبِي إِنَّهُ لاَ يَغْفِرُ الذُّنُوبَ غَيْرُكَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ رضى الله عنهما ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3446}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ali bin Rabi’ah said:“I witnessed Ali having an animal brought to him to ride. When he placed his foot in the stirrup he said: ‘In the Name of Allah,’ (Bismillāh) [three times]. So then, once he had ascended upon its back, he said: ‘All praise is due to Allah.’ (Al-ḥamdulillāh) then he said: Glory is to Him Who has subjected this to us, and we were not able to do it. And, surely, to our Lord are we returning (Subḥān alladhī sakh-khara lanā hādhā wa mā kunnā lahū muqrinīn. Wa innā ilā rabbinā lamunqalibūn). Then he said: ‘All praise is due to Allah (Al-ḥamdulillāh)’ – three times – and ‘Allah is the Greatest (Allāhu Akbar)’ – three times – ‘Glory is to You, indeed I have wronged myself, so forgive me, for indeed none forgives sins except You (Subḥānaka innī qad ẓalamtu nafsī faghfirlī fa-innahū lā yaghfirudh-dhunūba illā ant).’ Then he laughed. So I said: ‘O Commander of the Believer! What caused you to laugh?’ He said: ‘I saw the Messenger of Allah do as I did, then he (ﷺ) laughed, so I said, ‘What cause you to laugh?’ He said: ‘Indeed, your Lord is very pleased with His worshipper when he says: “O my Lord, forgive me my sins, indeed, no one other than You forgives sins.”}}
\hadithdefcmd{tirmidhi}{3447}{حَدَّثَنَا سُوَيْدُ بْنُ نَصْرٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ عَلِيِّ بْنِ عَبْدِ اللَّهِ الْبَارِقِيِّ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا سَافَرَ فَرَكِبَ رَاحِلَتَهُ كَبَّرَ ثَلاَثًا وَيَقُولُ ‏:‏ ‏(‏ سبْحَانَ الَّذِي سَخَّرَ لَنَا هَذَا وَمَا كُنَّا لَهُ مُقْرِنِينَ * وَإِنَّا إِلَى رَبِّنَا لَمُنْقَلِبُونَ ‏)‏ ثُمَّ يَقُولُ ‏"‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ فِي سَفَرِي هَذَا مِنَ الْبِرِّ وَالتَّقْوَى وَمِنَ الْعَمَلِ مَا تَرْضَى اللَّهُمَّ هَوِّنْ عَلَيْنَا الْمَسِيرَ وَاطْوِ عَنَّا بُعْدَ الأَرْضِ اللَّهُمَّ أَنْتَ الصَّاحِبُ فِي السَّفَرِ وَالْخَلِيفَةُ فِي الأَهْلِ اللَّهُمَّ اصْحَبْنَا فِي سَفَرِنَا وَاخْلُفْنَا فِي أَهْلِنَا ‏"‏ ‏.‏ وَكَانَ يَقُولُ إِذَا رَجَعَ إِلَى أَهْلِهِ ‏"‏ آيِبُونُ إِنْ شَاءَ اللَّهُ تَائِبُونَ عَابِدُونَ لِرَبِّنَا حَامِدُونَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3447}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn `Umar narrated that:When the Prophet (ﷺ) wanted to travel, when he mounted his riding camel, he would say the Takbir three times and say: Glory is to Him Who has subjected this to us, and we were not able to do it. And, surely, to our Lord are we returning (Subḥān alladhī sakh-khara lanā hādhā wa mā kunnā lahū muqrinīn. Wa innā ilā rabbinā lamunqalibūn). Then he would say: “O Allah, I ask You in this journey of mine from the righteousness and piety and actions that which you are pleased with. O Allah, ease for us the path, and make near for us the distance of the land. O Allah, You are the companion in the journey, and the caretaker for the family. O Allah, accompany us in our journey, and take care of our families (Allāhumma innī as’aluka fī safarī hādhā minal-birri wat-taqwā, wa minal-`amali mā tarḍā. Allāhumma hawwin `alainal-masīra, waṭwi `annā bu`dal-arḍ. Allāhumma antaṣ-ṣāḥibu fis safari wal-khalīfatu fil-ahli. Allāhumma aṣḥabnā fī safarinā wakhlufnā fī ahlinā).” And when he would return to his family, he would say: “(We are) Returning, if Allah wills, repenting, worshipping, and to our Lord directing the praise (Ā’ibūna in shā’ Allāh, tā’ibūna `ābidūna lirabbinā hāmidūn).”}}
\hadithdefcmd{tirmidhi}{3448}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا الْحَجَّاجُ الصَّوَّافُ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي جَعْفَرٍ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثُ دَعَوَاتٍ مُسْتَجَابَاتٌ دَعْوَةُ الْمَظْلُومِ وَدَعْوَةُ الْمُسَافِرِ وَدَعْوَةُ الْوَالِدِ عَلَى وَلَدِهِ ‏"‏ ‏.‏ حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ وَزَادَ فِيهِ مُسْتَجَابَاتٌ لاَ شَكَّ فِيهِنَّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَأَبُو جَعْفَرٍ الرَّازِيُّ هَذَا الَّذِي رَوَى عَنْهُ يَحْيَى بْنُ أَبِي كَثِيرٍ يُقَالُ لَهُ أَبُو جَعْفَرٍ الْمُؤَذِّنُ وَقَدْ رَوَى عَنْهُ يَحْيَى بْنُ أَبِي كَثِيرٍ غَيْرَ حَدِيثٍ وَلاَ نَعْرِفُ اسْمَهُ ‏.‏\hadithno{3448}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah [may Allah be pleased with him] narrated :that the Messenger of Allah said: “Three supplications are responded to: The supplication of the oppressed, the supplication of the traveler, and the supplication of the parent against his child.” Ali bin Hujr narrated to us (he said): Ismail bin Ibrahim reported to us from Hisham Ad-Dastawa’i, from Yahya bin Abu Kathir with this chain, narrating similar to it, but he added to it: “responded to, there is no doubt in them.”}}
\hadithdefcmd{tirmidhi}{3449}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الأَسْوَدِ أَبُو عَمْرٍو الْبَصْرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ رَبِيعَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا رَأَى الرِّيحَ قَالَ ‏ "‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ مِنْ خَيْرِهَا وَخَيْرِ مَا فِيهَا وَخَيْرِ مَا أُرْسِلَتْ بِهِ وَأَعُوذُ بِكَ مِنْ شَرِّهَا وَشَرِّ مَا فِيهَا وَشَرِّ مَا أُرْسِلَتْ بِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أُبَىِّ بْنِ كَعْبٍ رضى الله عنه وَهَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{3449}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah [may Allah be pleased with her] narrates, saying:“When the Prophet (ﷺ) would see the wind he would say: ‘O Allah, indeed, I ask You for its good, the good of what is in it, and the good of what it has been sent with. And I seek refuge in You from its evil, the evil of what is in it, and the evil of what it has been sent with (Allāhumma innī as’aluka min khairihā wa khairi mā fīhā, wa khairi mā ursilat bihī, wa a`ūdhu bika min sharrihā wa sharri mā fīhā, wa sharri mā ursilat bih).’”}}
\hadithdefcmd{tirmidhi}{3450}{حَدَّثَنَا ��ُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، عَنِ الْحَجَّاجِ بْنِ أَرْطَاةَ، عَنْ أَبِي مَطَرٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا سَمِعَ صَوْتَ الرَّعْدِ وَالصَّوَاعِقِ قَالَ ‏ "‏ اللَّهُمَّ لاَ تَقْتُلْنَا بِغَضَبِكَ وَلاَ تُهْلِكْنَا بِعَذَابِكَ وَعَافِنَا قَبْلَ ذَلِكَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3450}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Salim bin Abdullah bin Umar narrated :from his father, that when the Messenger of Allah (ﷺ) would hear the sound of thunder and lightning bolts, he would say: “O Allah, do not kill us with Your wrath, and do not destroy us with Your punishment, and pardon us before that (Allāhumma lā taqtulnā bi-ghaḍabika wa lā tuhliknā bi-`adhābika wa `āfinā qabla dhālik).”}}
\hadithdefcmd{tirmidhi}{3451}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ سُفْيَانَ الْمَدَنِيُّ، حَدَّثَنِي بِلاَلُ بْنُ يَحْيَى بْنِ طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، طَلْحَةَ بْنِ عُبَيْدِ اللَّهِ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا رَأَى الْهِلاَلَ قَالَ ‏ "‏ اللَّهُمَّ أَهْلِلْهُ عَلَيْنَا بِالْيُمْنِ وَالإِيمَانِ وَالسَّلاَمَةِ وَالإِسْلاَمِ رَبِّي وَرَبُّكَ اللَّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3451}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Bilal bin Yahya bin Talhah bin `Ubaidullah narrated :from his father, from his grandfather Talhah bin `Ubaidullah that when the Prophet (ﷺ) would see a crescent moon, he would say: “O Allah, bring it over us with blessing and faith, and security and Islam. My Lord and your Lord is Allah (Allāhumma ahlilhu `alainā bil-yumni wal-Īmān, was-salāmati wal-Islām, rabbī wa rabbuk Allāh).”}}
\hadithdefcmd{tirmidhi}{3452}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا قَبِيصَةُ، أَخْبَرَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ مُعَاذِ بْنِ جَبَلٍ، رضى الله عنه قَالَ اسْتَبَّ رَجُلاَنِ عِنْدَ النَّبِيِّ صلى الله عليه وسلم حَتَّى عُرِفَ الْغَضَبُ فِي وَجْهِ أَحَدِهِمَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنِّي لأَعْلَمُ كَلِمَةً لَوْ قَالَهَا لَذَهَبَ غَضَبُهُ أَعُوذُ بِاللَّهِ مِنَ الشَّيْطَانِ الرَّجِيمِ ‏"‏ ‏.‏ حَدَّثَنَا بُنْدَارٌ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سُلَيْمَانَ بْنِ صُرَدٍ قَالَ وَهَذَا حَدِيثٌ مُرْسَلٌ ‏.‏ عَبْدُ الرَّحْمَنِ بْنُ أَبِي لَيْلَى لَمْ يَسْمَعْ مِنْ مُعَاذِ بْنِ جَبَلٍ مَاتَ مُعَاذٌ فِي خِلاَفَةِ عُمَرَ بْنِ الْخَطَّابِ وَقُتِلَ عُمَرُ بْنُ الْخَطَّابِ وَعَبْدُ الرَّحْمَنِ بْنُ أَبِي لَيْلَى غُلاَمٌ ابْنُ سِتِّ سِنِينَ وَهَكَذَا رَوَى شُعْبَةُ عَنِ الْحَكَمِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى وَقَدْ رَوَى عَبْدُ الرَّحْمَنِ بْنُ أَبِي لَيْلَى عَنْ عُمَرَ بْنِ الْخَطَّابِ وَرَآهُ وَعَبْدُ الرَّحْمَنِ بْنُ أَبِي لَيْلَى يُكْنَى أَبَا عِيسَى وَأَبُو لَيْلَى اسْمُهُ يَسَارٌ وَرُوِيَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى قَالَ أَدْرَكْتُ عِشْرِينَ وَمِائَةً مِنَ الأَنْصَارِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3452}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Mu`adh bin Jabal narrated :that one of the two men cursed the other next to the Prophet (ﷺ), until anger could be recognized in the face of one of them. So the Prophet (ﷺ) said: “Verily, I know a statement, that if he were to say it, his anger would leave: ‘I seek refuge in Allah from Shaitan, the rejected (A`ūdhu billāhi minash-shaiṭānir-rajīm).’”}}
\hadithdefcmd{tirmidhi}{3453}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا بَكْرُ بْنُ مُضَرَ، عَنِ ابْنِ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ خَبَّابٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا رَأَى أَحَدُكُمُ الرُّؤْيَا يُحِبُّهَا فَإِنَّمَا هِيَ مِنَ اللَّهِ فَلْيَحْمَدِ اللَّهَ عَلَيْهَا وَلْيُحَدِّثْ بِمَا رَأَى وَإِذَا رَأَى غَيْرَ ذَلِكَ مِمَّا يَكْرَهُ فَإِنَّمَا هِيَ مِنَ الشَّيْطَانِ فَلْيَسْتَعِذْ بِاللَّهِ مِنْ شَرِّهَا وَلاَ يَذْكُرْهَا لأَحَدٍ فَإِنَّهَا لاَ تَضُرُّهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي قَتَادَةَ ‏.‏ قَالَ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَابْنُ الْهَادِ اسْمُهُ يَزِيدُ بْنُ عَبْدِ اللَّهِ بْنِ أُسَامَةَ بْنِ الْهَادِ الْمَدَنِيُّ وَهُوَ ثِقَةٌ رَوَى عَنْهُ مَالِكٌ وَالنَّاسُ ‏.‏\hadithno{3453}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Sa’eed Al-Khudri narrated that:He heard the Prophet saying: “When one of you sees a dream that he likes, then it is from Allah, so let him praise Allah for it, and speak concerning what he saw. And when he sees other than that of what he dislikes, then it is from Shaitan, so let him seek refuge in Allah from its evil, and not mention it to anyone for, surely, it shall not harm him.”}}
\hadithdefcmd{tirmidhi}{3454}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، وَأَخْبَرَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ كَانَ النَّاسُ إِذَا رَأَوْا أَوَّلَ الثَّمَرِ جَاءُوا بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِذَا أَخَذَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ بَارِكْ لَنَا فِي ثِمَارِنَا وَبَارِكْ لَنَا فِي مَدِينَتِنَا وَبَارِكْ لَنَا فِي صَاعِنَا وَمُدِّنَا اللَّهُمَّ إِنَّ إِبْرَاهِيمَ عَبْدُكَ وَخَلِيلُكَ وَنَبِيُّكَ وَإِنِّي عَبْدُكَ وَنَبِيُّكَ وَإِنَّهُ دَعَاكَ لِمَكَّةَ وَأَنَا أَدْعُوكَ لِلْمَدِينَةِ بِمِثْلِ مَا دَعَاكَ بِهِ لِمَكَّةَ وَمِثْلِهِ مَعَهُ ‏"‏ ‏.‏ ثُمَّ يَدْعُو أَصْغَرَ وَلِيدٍ يَرَاهُ فَيُعْطِيهِ ذَلِكَ الثَّمَرَ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3454}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah [may Allah be pleased with him] narrates, saying:“When the people would see the first fruit, they would bring it to the Messenger of Allah (ﷺ). When the Messenger of Allah (ﷺ) would take it, he would say: ‘O Allah, bless for us our fruits, and bless for us our city, and bless for us our Sa` and our Mudd, O Allah, verily, Ibrahim is Your worshipper and Your friend and Your Prophet, and verily I am Your slave and Your Prophet, and indeed, he (i.e., Ibrahim AS) supplicated to You for Makkah, and I supplicate to You for Al-Madinah with the like of that with which he supplicated to You for Makkah, and the like of it with it.’ He said: Then he would call the smallest young child he saw and give him that fruit}}
\hadithdefcmd{tirmidhi}{3455}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَلِيُّ بْنُ زَيْدٍ، عَنْ عُمَرَ، وَهُوَ ابْنُ أَبِي حَرْمَلَةَ عَنِ ابْنِ عَبَّاسٍ، قَالَ دَخَلْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَا وَخَالِدُ بْنُ الْوَلِيدِ عَلَى مَيْمُونَةَ فَجَاءَتْنَا بِإِنَاءٍ مِنْ لَبَنٍ فَشَرِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا عَلَى يَمِينِهِ وَخَالِدٌ عَلَى شِمَالِهِ فَقَالَ لِي ‏"‏ الشَّرْبَةُ لَكَ فَإِنْ شِئْتَ آثَرْتَ بِهَا خَالِدًا ‏"‏ ‏.‏ فَقُلْتُ مَا كُنْتُ أُوثِرُ عَلَى سُؤْرِكَ أَحَدًا ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَطْعَمَهُ اللَّهُ الطَّعَامَ فَلْيَقُلِ اللَّهُمَّ بَارِكْ لَنَا فِيهِ وَأَطْعِمْنَا خَيْرًا مِنْهُ ‏.‏ وَمَنْ سَقَاهُ اللَّهُ لَبَنًا فَلْيَقُلِ اللَّهُمَّ بَارِكْ لَنَا فِيهِ وَزِدْنَا مِنْهُ ‏"‏ ‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَيْسَ شَيْءٌ يَجْزِي مَكَانَ الطَّعَامِ وَالشَّرَابِ غَيْرُ اللَّبَنِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ عَلِيِّ بْنِ زَيْدٍ فَقَالَ عَنْ عُمَرَ بْنِ حَرْمَلَةَ ‏.‏ وَقَالَ بَعْضُهُمْ عَمْرُو بْنُ حَرْمَلَةَ وَلاَ يَصِحُّ ‏.‏\hadithno{3455}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:“I entered with the Messenger of Allah (ﷺ), I and Khalid bin Al-Walid, upon Maimunah so she brought us a vessel of milk. The Messenger of Allah (ﷺ) drank from it. I was upon his right and Khalid was upon left, so he said to me: ‘The (turn to) drink is for you, so if you wish, you could choose to grant it to Khalid.’ So I said: ‘I would not prefer anyone (above myself) for your leftovers.’ Then the Messenger of Allah (ﷺ) said: ‘Whoever Allah feeds some food, then let him say: “O Allah, bless it for us, and feed us better than it, (Allāhumma bārik lanā fīhi wa aṭ`imnā khairan minhu)” and whomsoever Allah gives milk to drink, then let him say: “O Allah bless it for us, and grant us increase in it (Allāhumma bārik lanā fīhi wa zidnā minhu).” And the Messenger of Allah (ﷺ) said, ‘There is nothing that suffices in the place of food and drink except for milk.’”}}
\hadithdefcmd{tirmidhi}{3456}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا ثَوْرُ بْنُ يَزِيدَ، حَدَّثَنَا خَالِدُ بْنُ مَعْدَانَ، عَنْ أَبِي أُمَامَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا رُفِعَتِ الْمَائِدَةُ مِنْ بَيْنِ يَدَيْهِ يَقُولُ ‏ "‏ الْحَمْدُ لِلَّهِ حَمْدًا كَثِيرًا طَيِّبًا مُبَارَكًا فِيهِ غَيْرَ مُوَدَّعٍ وَلاَ مُسْتَغْنًى عَنْهُ رَبُّنَا ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3456}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Umamah narrated that :when the table spread would be lifted from in front of him, the Messenger of Allah (ﷺ) would say: “All praise is due to Allah, abundant, good, blessed praise, without being left off, nor being without need of it, O our Lord (Al-ḥamdulillāhi ḥamdan kathīran ṭayyiban mubārakan fīhi, ghaira muwadda`in, wa lā mustaghnan `anhu rabbanā).”}}
\hadithdefcmd{tirmidhi}{3457}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، وَأَبُو خَالِدٍ الأَحْمَرُ عَنْ حَجَّاجِ بْنِ أَرْطَاةَ، عَنْ رِيَاحِ بْنِ عَبِيدَةَ، قَالَ حَفْصٌ عَنِ ابْنِ أَخِي أَبِي سَعِيدٍ، وَقَالَ أَبُو خَالِدٍ، عَنْ مَوْلًى، لأَبِي سَعِيدٍ عَنْ أَبِي سَعِيدٍ، رضى الله عنه قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَكَلَ أَوْ شَرِبَ قَالَ ‏ "‏ الْحَمْدُ لِلَّهِ الَّذِي أَطْعَمَنَا وَسَقَانَا وَجَعَلَنَا مُسْلِمِينَ ‏"‏ ‏.‏\hadithno{3457}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa`eed [may Allah be pleased with him] narrated that:When the Prophet (ﷺ) used to eat or drink, he would say: “All praise is due to Allah who fed us and gave us drink, and made us Muslims (Al-ḥamdulillāh, alladhī aṭ`amanā, wa saqānā, wa ja`alanā muslimīn).”}}
\hadithdefcmd{tirmidhi}{3458}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، حَدَّثَنِي أَبُو مَرْحُومٍ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَكَلَ طَعَامًا فَقَالَ الْحَمْدُ لِلَّهِ الَّذِي أَطْعَمَنِي هَذَا وَرَزَقَنِيهِ مِنْ غَيْرِ حَوْلٍ مِنِّي وَلاَ قُوَّةٍ ‏.‏ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَأَبُو مَرْحُومٍ اسْمُهُ عَبْدُ الرَّحِيمِ بْنُ مَيْمُونٍ ‏.‏\hadithno{3458}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sahl bin Mu`adh bin Anas narrated from his father that:The Messenger of Allah (ﷺ) said: “Whoever eats food and then says: ‘All praise is due to Allah who fed me this and granted it as provision to me, without any effort from me nor power, (Al-ḥamdulillāh, alladhī aṭ`amanī hādha wa razaqanīhi min ghairi ḥawlin minnī, wa lā quwwatin)’ his past sins shall be forgiven.”}}
\hadithdefcmd{tirmidhi}{3459}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عَنْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَمِعْتُمْ صِيَاحَ الدِّيَكَةِ فَاسْأَلُوا اللَّهَ مِنْ فَضْلِهِ فَإِنَّهَا رَأَتْ مَلَكًا وَإِذَا سَمِعْتُمْ نَهِيقَ الْحِمَارِ فَتَعَوَّذُوا بِاللَّهِ مِنَ الشَّيْطَانِ الرَّجِيمِ فَإِنَّهُ رَأَى شَيْطَانًا ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3459}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah [may Allah be pleased with him] narrated that:The Prophet said: “when you hear the crowing of the roosters, then ask Allah of His bounty, for verily they have seen an angel. When you hear the braying of a donkey, then seek refuge in Allah from Shaitan, [the rejected] for, verily, it has seen a Shaitan.”}}
\hadithdefcmd{tirmidhi}{3460}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ الْكُوفِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ السَّهْمِيُّ، عَنْ حَاتِمِ بْنِ أَبِي صَغِيرَةَ، عَنْ أَبِي بَلْجٍ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا عَلَى الأَرْضِ أَحَدٌ يَقُولُ لاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏.‏ إِلاَّ كُفِّرَتْ عَنْهُ خَطَايَاهُ وَلَوْ كَانَتْ مِثْلَ زَبَدِ الْبَحْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَرَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ أَبِي بَلْجٍ بِهَذَا الإِسْنَادِ نَحْوَهُ وَلَمْ يَرْفَعْهُ وَأَبُو بَلْجٍ اسْمُهُ يَحْيَى بْنُ أَبِي سُلَيْمٍ وَيُقَالُ أَيْضًا يَحْيَى بْنُ سُلَيْمٍ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ حَاتِمِ بْنِ أَبِي صَغِيرَةَ، عَنْ أَبِي بَلْجٍ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَحَاتِمٌ يُكْنَى أَبَا يُونُسَ الْقُشَيْرِيَّ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ أَبِي بَلْجٍ، نَحْوَهُ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{3460}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Amr narrated that :the Messenger of Allah (ﷺ) said: “there is not anyone upon the earth who says: ‘None has the right to be worshipped but Allah, and Allah is the Greatest, and there is no might nor power except by Allah, (Lā ilāha illallāh, wa Allāhu akbar, wa lā ḥawla wa lā quwwata illā billāh) except that his sins shall be pardoned, even if they were like the foam of the sea.”}}
\hadithdefcmd{tirmidhi}{3461}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مَرْحُومُ بْنُ عَبْدِ الْعَزِيزِ الْعَطَّارُ، حَدَّثَنَا أَبُو نَعَامَةَ السَّعْدِيُّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي غَزَاةٍ فَلَمَّا قَفَلْنَا أَشْرَفْنَا عَلَى الْمَدِينَةِ فَكَبَّرَ النَّاسُ تَكْبِيرَةً وَرَفَعُوا بِهَا أَصْوَاتَهُمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ رَبَّكُمْ لَيْسَ بِأَصَمَّ وَلاَ غَائِبٍ هُوَ بَيْنَكُمْ وَبَيْنَ رُءُوسِ رِحَالِكُمْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ يَا عَبْدَ اللَّهِ بْنَ قَيْسِ أَلاَ أُعَلِّمُكَ كَنْزًا مِنْ كُنُوزِ الْجَنَّةِ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَأَبُو عُثْمَانَ النَّهْدِيُّ اسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ مَلٍّ وَأَبُو نَعَامَةَ اسْمُهُ عَمْرُو بْنُ عِيسَى ‏.‏ وَمَعْنَى قَوْلِهِ بَيْنَكُمْ وَبَيْنَ رُءُوسِ رِحَالِكُمْ يَعْنِي عِلْمَهُ وَقُدْرَتَهُ ‏.‏\hadithno{3461}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Musa Al-Ash`ari said:“We were with the Messenger of Allah (ﷺ) on a military expedition. When we returned, we overlooked Al-Madinah, and the people were pronouncing the Takbir, and they raised their voices with it. The Messenger of Allah (ﷺ) said: ‘Verily, your Lord is not deaf nor absent, [and] He is between you and between the heads of your mounts.’ Then he said: ‘O `Abdullah bin Qais, should I not inform you of a treasure from the treasures of Paradise: Lā ḥawla wa lā quwwata illā billāh (There is no might or power except by Allah).’”}}
\hadithdefcmd{tirmidhi}{3462}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي زِيَادٍ، حَدَّثَنَا سَيَّارٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنِ الْقَاسِمِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنِ ابْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَقِيتُ إِبْرَاهِيمَ لَيْلَةَ أُسْرِيَ بِي فَقَالَ يَا مُحَمَّدُ أَقْرِئْ أُمَّتَكَ مِنِّي السَّلاَمَ وَأَخْبِرْهُمْ أَنَّ الْجَنَّةَ طَيِّبَةُ التُّرْبَةِ عَذْبَةُ الْمَاءِ وَأَنَّهَا قِيعَانٌ وَأَنَّ غِرَاسَهَا سُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي أَيُّوبَ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ ابْنِ مَسْعُودٍ ‏.‏\hadithno{3462}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ibn Mas`ud narrated that:The Messenger of Allah (ﷺ) said: “I met Ibrahim on the night of my ascent, so he said: ‘O Muhammad, recite Salam from me to your nation, and inform them that Paradise has pure soil and delicious water, and that it is a flat treeless plain, and that its seeds are: “Glory is to Allah (Subḥān Allāh) [and] all praise is due to Allah (Al-ḥamdulillāh) and ‘none has the right to be worshipped but Allah’ (Lā ilāha illallāh), and Allah is the greatest (Allāhu Akbar).”}}
\hadithdefcmd{tirmidhi}{3463}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا مُوسَى الْجُهَنِيُّ، حَدَّثَنِي مُصْعَبُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِجُلَسَائِهِ ‏"‏ أَيَعْجِزُ أَحَدُكُمْ أَنْ يَكْسِبَ أَلْفَ حَسَنَةٍ ‏"‏ ‏.‏ فَسَأَلَهُ سَائِلٌ مِنْ جُلَسَائِهِ كَيْفَ يَكْسِبُ أَحَدُنَا أَلْفَ حَسَنَةٍ قَالَ ‏"‏ يُسَبِّحُ أَحَدُكُمْ مِائَةَ تَسْبِيحَةٍ تُكْتَبُ لَهُ أَلْفُ حَسَنَةٍ وَتُحَطُّ عَنْهُ أَلْفُ سَيِّئَةٍ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3463}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Mus`ab bin Sa`d narrated from his father, that :the Messenger of Allah (ﷺ) said to those sitting with him: “Is one of you incapable of attaining a thousand good deeds?” So a questioner among those seated with him asked him: “How can one of us earn a thousand good deeds?” He said: “(When) one of you recites a hundred Tasbīḥāt a thousand good deeds are written for him, and a thousand evil deeds are wiped away from him.”}}
\hadithdefcmd{tirmidhi}{3464}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، عَنْ حَجَّاجٍ الصَّوَّافِ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ سُبْحَانَ اللَّهِ الْعَظِيمِ وَبِحَمْدِهِ ‏.‏ غُرِسَتْ لَهُ نَخْلَةٌ فِي الْجَنَّةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ ‏.‏\hadithno{3464}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Jabir narrated that:The Prophet (ﷺ) said: “Whoever says: ‘Glory is to Allah, the Magnificent, and with His Praise (Subḥān Allāhil-Aẓīm, wa biḥamdih)’ a date-palm tree is planted for him in Paradise.”}}
\hadithdefcmd{tirmidhi}{3465}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا الْمُؤَمِّلُ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ سُبْحَانَ اللَّهِ الْعَظِيمِ وَبِحَمْدِهِ غُرِسَتْ لَهُ نَخْلَةٌ فِي الْجَنَّةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3465}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Jabir narrated that :The Prophet (ﷺ) said: “Whoever says: ‘Glory is to Allah, the Magnificent, and with His Praise (Subḥān Allāhil-Aẓīm, wa biḥamdih)’ a date-palm tree is planted for him in Paradise.”}}
\hadithdefcmd{tirmidhi}{3466}{حَدَّثَنَا نَصْرُ بْنُ عَبْدِ الرَّحْمَنِ الْكُوفِيُّ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ مِائَةَ مَرَّةٍ غُفِرَتْ لَهُ ذُنُوبُهُ وَإِنْ كَانَتْ مِثْلَ زَبَدِ الْبَحْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3466}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah (ﷺ) said: “Whoever says: ‘Glory is to Allah, and with His Praise (Subḥān Allāh, wa biḥamdih)’ a hundred times, his sins are forgiven, even if they were like the foam of the sea.”}}
\hadithdefcmd{tirmidhi}{3467}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا مُحَمَّدُ بْنُ الْفُضَيْلِ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَلِمَتَانِ خَفِيفَتَانِ عَلَى اللِّسَانِ ثَقِيلَتَانِ فِي الْمِيزَانِ حَبِيبَتَانِ إِلَى الرَّحْمَنِ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ سُبْحَانَ اللَّهِ الْعَظِيمِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{3467}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah (ﷺ) said: “There are two statements that are light on the tongue, heavy on the Scale, and beloved to Ar-Raḥmān: “Glory is to Allah and the praise; Glory is to Allah, the Magnificent. (Subḥān Allāhi wa biḥamdih, Subḥān Allāhil-Aẓīm)”}}
\hadithdefcmd{tirmidhi}{3468}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ يُحْيِي وَيُمِيتُ وَهُوَ عَلَى كُلِّ شَيْءٍ قَدِيرٌ فِي يَوْمٍ مِائَةَ مَرَّةٍ كَانَتْ لَهُ عِدْلَ عَشْرِ رِقَابٍ وَكُتِبَتْ لَهُ مِائَةُ حَسَنَةٍ وَمُحِيَتْ عَنْهُ مِائَةُ سَيِّئَةٍ وَكَانَ لَهُ حِرْزًا مِنَ الشَّيْطَانِ يَوْمَهُ ذَلِكَ حَتَّى يُمْسِيَ وَلَمْ يَأْتِ أَحَدٌ بِأَفْضَلَ مِمَّا جَاءَ بِهِ إِلاَّ أَحَدٌ عَمِلَ أَكْثَرَ مِنْ ذَلِكَ ‏"‏ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ قَالَ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ مِائَةَ مَرَّةٍ حُطَّتْ خَطَايَاهُ وَإِنْ كَانَتْ أَكْثَرَ مِنْ زَبَدِ الْبَحْرِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ\hadithno{3468}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrates that:The Mesenger of Allah (ﷺ) said: “Whoever says: ‘There is none worthy of worship except Allah, Alone, without partner, to Him belongs all that exists and to Him belongs the praise, He gives life and causes death, and He is Powerful over all things, (Lā ilāha illallāh, waḥdahu lā sharīka lahu, lahul-mulku wa lahul-ḥamdu, yuḥyī wa yumītu, wa huwa `alā kulli shay’in qadīr)’ a hundred times in a day, it will be for him the equivalent of freeing ten slaves, and there shall be written for him a hundred good deeds, and a hundred bad deeds shall be wiped out for him, and it will be a protection for him from Shaitan on that day, until he reaches the evening. And none has brought better than it, except for one who has done more than that.” And with this chain, from the Prophet (ﷺ), that he said: “Whoever says: ‘Glory is to Allah, and with His Praise (Subḥān Allāh, wa biḥamdih)’ a hundred times, his sins are forgiven, even if they were more than the foam of the sea.”}}
\hadithdefcmd{tirmidhi}{3469}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ حِينَ يُصْبِحُ وَحِينَ يُمْسِي سُبْحَانَ اللَّهِ وَبِحَمْدِهِ مِائَةَ مَرَّةٍ لَمْ يَأْتِ أَحَدٌ يَوْمَ الْقِيَامَةِ بِأَفْضَلَ مِمَّا جَاءَ بِهِ إِلاَّ أَحَدٌ قَالَ مِثْلَ مَا قَالَ أَوْ زَادَ عَلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3469}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that:The Prophet (ﷺ) said: “Whoever says in the morning and in the evening ‘Glory is to Allah and with His Praise (Subḥān Allāh, wa biḥamdih)’ a hundred times, none shall bring better than him on the Day of Judgment except one who did the same as him, or increased upon it.”}}
\hadithdefcmd{tirmidhi}{3470}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى الْكُوفِيُّ، حَدَّثَنَا دَاوُدُ بْنُ الزِّبْرِقَانِ، عَنْ مَطَرٍ الْوَرَّاقِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ لأَصْحَابِهِ ‏ "‏ قُولُوا سُبْحَانَ اللَّهِ وَبِحَمْدِهِ مِائَةَ مَرَّةٍ مَنْ قَالَهَا مَرَّةً كُتِبَتْ لَهُ عَشْرًا وَمَنْ قَالَهَا عَشْرًا كُتِبَتْ لَهُ مِائَةً وَمَنْ قَالَهَا مِائَةً كُتِبَتْ لَهُ أَلْفًا وَمَنْ زَادَ زَادَهُ اللَّهُ وَمَنِ اسْتَغْفَرَ غَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3470}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ibn `Umar narrated that one day, :The Messenger of Allah (ﷺ) said to his Companions: “Say ‘Glory is to Allah and with His Praise (Subḥān Allāh, wa biḥamdih)’ a hundred times. Whoever says [it] one time, it is written for him ten, and whoever says it ten (times), it is written for him a hundred, and whoever says it a hundred (times), it is written for him a thousand, and whoever increases, Allah will increase for him, and whoever seeks Allah’s forgiveness, [Allah] will forgive him.”}}
\hadithdefcmd{tirmidhi}{3471}{حَدَّثَنَا مُحَمَّدُ بْنُ وَزِيرٍ الْوَاسِطِيُّ، حَدَّثَنَا أَبُو سُفْيَانَ الْحِمْيَرِيُّ، هُوَ سَعِيدُ بْنُ يَحْيَى الْوَاسِطِيُّ عَنِ الضَّحَّاكِ بْنِ حُمْرَةَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَبَّحَ اللَّهَ مِائَةً بِالْغَدَاةِ وَمِائَةً بِالْعَشِيِّ كَانَ كَمَنْ حَجَّ مِائَةَ مَرَّةٍ وَمَنْ حَمِدَ اللَّهَ مِائَةً بِالْغَدَاةِ وَمِائَةً بِالْعَشِيِّ كَانَ كَمَنْ حَمَلَ عَلَى مِائَةِ فَرَسٍ فِي سَبِيلِ اللَّهِ أَوْ قَالَ غَزَا مِائَةَ غَزْوَةٍ وَمَنْ هَلَّلَ اللَّهَ مِائَةً بِالْغَدَاةِ وَمِائَةً بِالْعَشِيِّ كَانَ كَمَنْ أَعْتَقَ مِائَةَ رَقَبَةٍ مِنْ وَلَدِ إِسْمَاعِيلَ وَمَنْ كَبَّرَ اللَّهَ مِائَةً بِالْغَدَاةِ وَمِائَةً بِالْعَشِيِّ لَمْ يَأْتِ فِي ذَلِكَ الْيَوْمِ أَحَدٌ بِأَكْثَرَ مِمَّا أَتَى بِهِ إِلاَّ مَنْ قَالَ مِثْلَ مَا قَالَ أَوْ زَادَ عَلَى مَا قَالَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3471}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Amr bin Shu`aib narrated from his father, from his grandfather, that :The Messenger of Allah (ﷺ) said: “Whoever glorifies Allah a hundred times in the morning and a hundred in the night, he is like one who performs Hajj a hundred times. And whoever praises Allah a hundred times in the morning and a hundred in the night, he is like one who provides a hundred horses in the cause of Allah.” – or he said – “went out on a hundred military expeditions. And whoever pronounced At-Tahlil of Allah a hundred times in the night, he is like the one who freed a hundred slaves from the offspring of Isma`il, and whoever extols Allah’s greatness a hundred times in the day and a hundred in the night, none shall bring on that day, more than what he brought, except one who said similar to what he said, or increased upon it.”}}
\hadithdefcmd{tirmidhi}{3472}{حَدَّثَنَا الْحُسَيْنُ بْنُ الأَسْوَدِ الْعِجْلِيُّ الْبَغْدَادِيُّ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنِ الْحَسَنِ بْنِ صَالِحٍ، عَنْ أَبِي بِشْرٍ، عَنِ الزُّهْرِيِّ، قَالَ تَسْبِيحَةٌ فِي رَمَضَانَ أَفْضَلُ مِنْ أَلْفِ تَسْبِيحَةٍ فِي غَيْرِهِ ‏.‏\hadithno{3472}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad Maqtu; Al-Albani: Daif Isnaad Maqtu; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Az-Zuhri said:“A Tasbihah in Ramadan is better than a thousand Tasbihah in other that it.”}}
\hadithdefcmd{tirmidhi}{3473}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنِ الْخَلِيلِ بْنِ مُرَّةَ، عَنِ الأَزْهَرِ بْنِ عَبْدِ اللَّهِ، عَنْ تَمِيمٍ الدَّارِيِّ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ قَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ إِلَهًا وَاحِدًا أَحَدًا صَمَدًا لَمْ يَتَّخِذْ صَاحِبَةً وَلاَ وَلَدًا وَلَمْ يَكُنْ لَهُ كُفُوًا أَحَدٌ عَشْرَ مَرَّاتٍ كَتَبَ اللَّهُ لَهُ أَرْبَعِينَ أَلْفَ أَلْفِ حَسَنَةٍ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالْخَلِيلُ بْنُ مُرَّةَ لَيْسَ بِالْقَوِيِّ عِنْدَ أَصْحَابِ الْحَدِيثِ ‏.‏ قَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ هُوَ مُنْكَرُ الْحَدِيثِ ‏.‏\hadithno{3473}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Tamim Ad-Dari narrated that:The Messsenger of Allah (ﷺ) said: “Whoever says ten times: ‘I bear witness that none has the right to be worshipped but Allah. Alone, without partner, One Deity, the One, As-Samad, He did not take a wife, nor a child, nor is there anyone like Him, (Ash-hadu an lā ilāha illallāh, waḥdahu lā sharīka lahu, ilahan wahidan, aḥadan ṣamadan lam yattakhidh ṣāḥibatan wa lā waladan wa lam yakun lahu kufuwan aḥad)’ Allah will write for him forty million good deeds.”}}
\hadithdefcmd{tirmidhi}{3474}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَلِيُّ بْنُ مَعْبَدٍ الْمِصْرِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو الرَّقِّيُّ، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ، عَنْ أَبِي ذَرٍّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ فِي دُبُرِ صَلاَةِ الْفَجْرِ وَهُوَ ثَانِي رِجْلَيْهِ قَبْلَ أَنْ يَتَكَلَّمَ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ يُحْيِي وَيُمِيتُ وَهُوَ عَلَى كُلِّ شَيْءٍ قَدِيرٌ عَشْرَ مَرَّاتٍ كُتِبَ لَهُ عَشْرُ حَسَنَاتٍ وَمُحِيَ عَنْهُ عَشْرُ سَيِّئَاتٍ وَرُفِعَ لَهُ عَشْرُ دَرَجَاتٍ وَكَانَ يَوْمَهُ ذَلِكَ فِي حِرْزٍ مِنْ كُلِّ مَكْرُوهٍ وَحَرْسٍ مِنَ الشَّيْطَانِ وَلَمْ يَنْبَغِ لِذَنْبٍ أَنْ يُدْرِكَهُ فِي ذَلِكَ الْيَوْمِ إِلاَّ الشِّرْكَ بِاللَّهِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏\hadithno{3474}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Dharr narrated that:The Messenger of Allah (ﷺ) said: “Whoever says at the end of every Fajr prayer, while his feet are still folded, before speaking: ‘None has the right to be worshipped but Allah, Alone without partner, to Him belongs all that exists, and to Him is the praise, He gives life and causes death, and He is powerful over all things, (Lā ilāha illallāh, waḥdahu lā sharīka lahu, lahul-mulku wa lahul-ḥamdu, yuḥyī wa yumītu, wa huwa `alā kulli shay’in qadīr)’ ten times, then ten good deeds shall be written for him, ten evil deeds shall be wiped away from him, ten degrees shall be raised up for him, and he shall be in security all that day from every disliked thing, and he shall be in protection from Shaitan, and no sin will meet him or destroy him that day, except for associating partners with Allah.”}}
\hadithdefcmd{tirmidhi}{3475}{حَدَّثَنَا جَعْفَرُ بْنُ مُحَمَّدِ بْنِ عِمْرَانَ الثَّعْلَبِيُّ الْكُوفِيُّ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، عَنْ مَالِكِ بْنِ مِغْوَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ الأَسْلَمِيِّ، عَنْ أَبِيهِ، قَالَ سَمِعَ النَّبِيُّ صلى الله عليه وسلم رَجُلاً يَدْعُو وَهُوَ يَقُولُ اللَّهُمَّ إِنِّي أَسْأَلُكَ بِأَنِّي أَشْهَدُ أَنَّكَ أَنْتَ اللَّهُ لاَ إِلَهَ إِلاَّ أَنْتَ الأَحَدُ الصَّمَدُ الَّذِي لَمْ يَلِدْ وَلَمْ يُولَدْ وَلَمْ يَكُنْ لَهُ كُفُوًا أَحَدٌ ‏.‏ قَالَ فَقَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَقَدْ سَأَلَ اللَّهَ بِاسْمِهِ الأَعْظَمِ الَّذِي إِذَا دُعِيَ بِهِ أَجَابَ وَإِذَا سُئِلَ بِهِ أَعْطَى ‏"‏ ‏.‏ قَالَ زَيْدٌ فَذَكَرْتُهُ لِزُهَيْرِ بْنِ مُعَاوِيَةَ بَعْدَ ذَلِكَ بِسِنِينَ فَقَالَ حَدَّثَنِي أَبُو إِسْحَاقَ عَنْ مَالِكِ بْنِ مِغْوَلٍ ‏.‏ قَالَ زَيْدٌ ثُمَّ ذَكَرْتُهُ لِسُفْيَانَ الثَّوْرِيِّ فَحَدَّثَنِي عَنْ مَالِكٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَرَوَى شَرِيكٌ هَذَا الْحَدِيثَ عَنْ أَبِي إِسْحَاقَ عَنِ ابْنِ بُرَيْدَةَ عَنْ أَبِيهِ وَإِنَّمَا أَخَذَهُ أَبُو إِسْحَاقَ الْهَمْدَانِيُّ عَنْ مَالِكِ بْنِ مِغْوَلٍ وَإِنَّمَا دَلَّسَهُ ‏.‏ وَرَوَى شَرِيكٌ هَذَا الْحَدِيثَ عَنْ أَبِي إِسْحَاقَ ‏.‏\hadithno{3475}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Buraidah Al Aslami narrated from his father, who said:“The Prophet (ﷺ) heard a man supplicating, and he was saying: ‘O Allah, indeed, I ask you by my testifying that You are Allah, there is none worthy of worship except You, the One, As-Samad, the one who does not beget, nor was begotten, and there is none who is like Him (Allāhumma innī as’aluka bi annī ashhadu annaka antallāh, lā ilāha illā ant, al-aḥaduṣ-ṣamad, alladhī lam yalid wa lam yūlad, wa lam yakun lahu kufuwan aḥad).” He said: “So he said: ‘By the One in Whose Hand is my soul, he has asked Allah by His Greatest Name, the one which if He is called upon by it, He responds, and when He is asked by it, He gives.’”(One of the narrators) Zaid said: “So I mentioned it to Zuhair bin Mu`awiyah years after that, and he said: Abu Ishaq reported to me from Malik bin Mighwal.’” Zaid said: “Then I mentioned it to Sufyan, so he reported it to me from Malik.”}}
\hadithdefcmd{tirmidhi}{3476}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا رِشْدِينُ بْنُ سَعْدٍ، عَنْ أَبِي هَانِئٍ الْخَوْلاَنِيِّ، عَنْ أَبِي عَلِيٍّ الْجَنْبِيِّ، عَنْ فَضَالَةَ بْنِ عُبَيْدٍ، قَالَ بَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَاعِدًا إِذْ دَخَلَ رَجُلٌ فَصَلَّى فَقَالَ اللَّهُمَّ اغْفِرْ لِي وَارْحَمْنِي ‏.‏ فَقَالَ رَسُولُ اللَّهَ صلى الله عليه وسلم ‏"‏ عَجِلْتَ أَيُّهَا الْمُصَلِّي إِذَا صَلَّيْتَ فَقَعَدْتَ فَاحْمَدِ اللَّهَ بِمَا هُوَ أَهْلُهُ وَصَلِّ عَلَىَّ ثُمَّ ادْعُهُ ‏"‏ ‏.‏ قَالَ ثُمَّ صَلَّى رَجُلٌ آخَرُ بَعْدَ ذَلِكَ فَحَمِدَ اللَّهَ وَصَلَّى عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَيُّهَا الْمُصَلِّي ادْعُ تُجَبْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ رَوَاهُ حَيْوَةُ بْنُ شُرَيْحٍ عَنْ أَبِي هَانِئٍ الْخَوْلاَنِيِّ وَأَبُو هَانِئٍ اسْمُهُ حُمَيْدُ بْنُ هَانِئٍ وَأَبُو عَلِيٍّ الْجَنْبِيُّ اسْمُهُ عَمْرُو بْنُ مَالِكٍ ‏.‏\hadithno{3476}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Fadalah bin `Ubaid narrated:“While the Messenger of Allah (ﷺ) was seated, a man entered and performed Salat, and he said: ‘O Allah, forgive me, and have mercy upon me.’ The Messenger of Allah (ﷺ) said: ‘You have rushed, O praying person. When you perform Salat and then sit, then praise Allah with what He is deserving of, and send Salat upon me, then call upon Him.’” He said: “Then another man performed Salat after that, so he praised Allah and sent Salat upon the Prophet (ﷺ). The Prophet (ﷺ) said to him: ‘O praying person! Supplicate, and you shall be answered.’”}}
\hadithdefcmd{tirmidhi}{3477}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، حَدَّثَنِي أَبُو هَانِئٍ الْخَوْلاَنِيُّ، أَنَّ عَمْرَو بْنَ مَالِكٍ الْجَنْبِيَّ، أَخْبَرَهُ أَنَّهُ، سَمِعَ فَضَالَةَ بْنَ عُبَيْدٍ، يَقُولُ سَمِعَ النَّبِيُّ صلى الله عليه وسلم رَجُلاً يَدْعُو فِي صَلاَتِهِ فَلَمْ يُصَلِّ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَجِلَ هَذَا ‏"‏ ‏.‏ ثُمَّ دَعَاهُ فَقَالَ لَهُ أَوْ لِغَيْرِهِ ‏"‏ إِذَا صَلَّى أَحَدُكُمْ فَلْيَبْدَأْ بِتَحْمِيدِ اللَّهِ وَالثَّنَاءِ عَلَيْهِ ثُمَّ لِيُصَلِّ عَلَى النَّبِيِّ صلى الله عليه وسلم ثُمَّ لِيَدْعُ بَعْدُ بِمَا شَاءَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3477}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr bin Malik Al-Janbi narrated that he heard Fadalah bin `Ubaid saying:“The Prophet (ﷺ) heard a man supplicating in his Salat but he did not send Salat upon the Prophet (ﷺ), so the Prophet (ﷺ) said: ‘This one has rushed.’ Then he called him and said to him, or to someone other than him: ‘When one of you performs Salat, then let him begin by expressing gratitude to Allah and praising Him. Then, let him send Salat upon the Prophet (ﷺ), then let him supplicate after that, whatever he wishes.’”}}
\hadithdefcmd{tirmidhi}{3478}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي زِيَادٍ الْقَدَّاحِ، كَذَا قَالَ عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ اسْمُ اللَّهِ الأَعْظَمُ فِي هَاتَيْنِ الآيَتَيْنِِ ‏:‏ ‏(‏ وإلَهُكُمْ إِلَهٌ وَاحِدٌ لاَ إِلَهَ إِلاَّ هُوَ الرَّحْمَنُ الرَّحِيمُ ‏)‏ وَفَاتِحَةِ آلِ عِمْرَانَ ‏(‏الم * اللَّهُ لاَ إِلَهَ إِلاَّ هُوَ الْحَىُّ الْقَيُّومُ ‏)‏ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3478}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Asma bint Yazid narrated that the Prophet (ﷺ) said:“Allah's greatest name is in these two Ayah: ‘And your deity is One deity, there is none who has the right to be worshipped but He, Ar-Raḥmān, Ar-Raḥīm.’ And the Opening of Al-`Imrān: ‘Alif. Lām. Mīm. Allah, None has the right to be worshipped but He, the Ever living, the Sustainer.’”}}
\hadithdefcmd{tirmidhi}{3479}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ، - وَهُوَ رَجُلٌ صَالِحٌ حَدَّثَنَا صَالِحٌ الْمُرِّيُّ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ادْعُوا اللَّهَ وَأَنْتُمْ مُوقِنُونَ بِالإِجَابَةِ وَاعْلَمُوا أَنَّ اللَّهَ لاَ يَسْتَجِيبُ دُعَاءً مِنْ قَلْبٍ غَافِلٍ لاَهٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ سَمِعْتُ عَبَّاسًا الْعَنْبَرِيَّ يَقُولُ اكْتُبُوا عَنْ عَبْدِ اللَّهِ بْنِ مُعَاوِيَةَ الْجُمَحِيِّ فَإِنَّهُ ثِقَةٌ ‏.‏\hadithno{3479}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“Call upon Allah while being certain of being answered, and know that Allah does not respond to a supplication from the heart of one heedless and occupied by play.”}}
\hadithdefcmd{tirmidhi}{3480}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ حَمْزَةَ الزَّيَّاتِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ عَافِنِي فِي جَسَدِي وَعَافِنِي فِي بَصَرِي وَاجْعَلْهُ الْوَارِثَ مِنِّي لاَ إِلَهَ إِلاَّ اللَّهُ الْحَلِيمُ الْكَرِيمُ سُبْحَانَ اللَّهِ رَبِّ الْعَرْشِ الْعَظِيمِ وَالْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ قَالَ سَمِعْتُ مُحَمَّدًا يَقُولُ حَبِيبُ بْنُ أَبِي ثَابِتٍ لَمْ يَسْمَعْ مِنْ عُرْوَةَ بْنِ الزُّبَيْرِ شَيْئًا وَحَبِيبُ بْنُ أَبِي ثَابِتٍ هُوَ حَبِيبُ بْنُ قَيْسِ بْنِ دِينَارٍ وَقَدْ أَدْرَكَ عُمَرَ وَابْنَ عَبَّاسٍ وَاللَّهُ أَعْلَمُ ‏.‏\hadithno{3480}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated that the Messenger of Allah (ﷺ) used to say:“O Allah, grant me health in my body, and grant me health in my sight, and make it the inheritor from me, there is none has the right to be worshipped but Allah, the Forbearing, the Generous, Glory is to Allah, the Lord of the Magnificent Throne, and all praise is due to Allah, the Lord of all that exists (Allāhumma `āfinī fī jasadi, wa `āfinī fī baṣarī, waj`alhul-wāritha minnī, lā ilāha illāllah, al-ḥalīmul-karīm, subḥān Allāhi rabbil-`arshil-aẓīm, wal-ḥamdulillāhi rabbil-`alamīn).”}}
\hadithdefcmd{tirmidhi}{3481}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَتْ فَاطِمَةُ إِلَى النَّبِيِّ صلى الله عليه وسلم تَسْأَلُهُ خَادِمًا فَقَالَ لَهَا ‏ "‏ قُولِي اللَّهُمَّ رَبَّ السَّمَوَاتِ السَّبْعِ وَرَبَّ الْعَرْشِ الْعَظِيمِ رَبَّنَا وَرَبَّ كُلِّ شَيْءٍ مُنْزِلَ التَّوْرَاةِ وَالإِنْجِيلِ وَالْقُرْآنِ فَالِقَ الْحَبِّ وَالنَّوَى أَعُوذُ بِكَ مِنْ شَرِّ كُلِّ شَيْءٍ أَنْتَ آخِذٌ بِنَاصِيَتِهِ أَنْتَ الأَوَّلُ فَلَيْسَ قَبْلَكَ شَيْءٌ وَأَنْتَ الآخِرُ فَلَيْسَ بَعْدَكَ شَيْءٌ وَأَنْتَ الظَّاهِرُ فَلَيْسَ فَوْقَكَ شَيْءٌ وَأَنْتَ الْبَاطِنُ فَلَيْسَ دُونَكَ شَيْءٌ اقْضِ عَنِّي الدَّيْنَ وَأَغْنِنِي مِنَ الْفَقْرِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَهَكَذَا رَوَى بَعْضُ أَصْحَابِ الأَعْمَشِ عَنِ الأَعْمَشِ نَحْوَ هَذَا ‏.‏ وَرَوَى بَعْضُهُمْ عَنِ الأَعْمَشِ عَنْ أَبِي صَالِحٍ مُرْسَلٌ وَلَمْ يَذْكُرْ فِيهِ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{3481}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that:Fatimah came to the Prophet (ﷺ), asking him for a servant. So he (ﷺ) said to her: “Say: ‘O Allah, Lord of the Seven Heavens and the Lord of the Magnificent Throne, our Lord, and the Lord of everything, Revealer of the Tawrah, the Injil, and the Quran, Splitter of the seed-grain and the date-stone, I seek refuge in You from the evil of everything that You are holding by the forelock, You are the First, for there is nothing above You, and You are the Last, for there is nothing after you. And you are az-Zahir, for there is nothing above you. And you are Al-Batin, for there is nothing below You. Relieve me from debt, and enrich me from poverty (Allāhumma rabbas samāwātis-sab`i wa rabbal-`arshil-`aẓīm, rabbana, wa rabba kulli shai’in, munzilat-Tawrāti wal-Injīli wal-Qur’ān, fāliqal-habbi wan-nawā, a`ūdhu bika min sharri kulli shai’in anta ākhidhun bināṣiyatihi, antal-awwalu falaisa qablaka shai’un, wa antal-ākhiru falaisa ba`daka shai’un, wa antaẓ-ẓāhiru falaisa fawqaka shai’un, wa antal-bāṭinu falaisa dūnaka shai’un, iqḍi `anni-daina wa aghnini minal-faqr).”}}
\hadithdefcmd{tirmidhi}{3482}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ أَبِي بَكْرِ بْنِ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ زُهَيْرِ بْنِ الأَقْمَرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ قَلْبٍ لاَ يَخْشَعُ وَدُعَاءٍ لاَ يُسْمَعُ وَمِنْ نَفْسٍ لاَ تَشْبَعُ وَمِنْ عِلْمٍ لاَ يَنْفَعُ أَعُوذُ بِكَ مِنْ هَؤُلاَءِ الأَرْبَعِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَأَبِي هُرَيْرَةَ وَابْنِ مَسْعُودٍ ‏.‏ قَالَ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ عَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏\hadithno{3482}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin `Amr narrated that:The Messenger of Allah (ﷺ) used to say: “O Allah, I seek refuge in You from a heart that does not humble itself, and from a supplication that is not heard, and from a soul that is never satisfied, and from knowledge that does not benefit, I seek refuge in You from these four (Allāhumma innī a`ūdhu bika min qalbin lā yakhsha`u, wa min du`ā’in lā yusma`u, wa min nafsin lā tashba`u, wa min `ilmin lā yanfa`u, a`ūdhu bika min hā’ula’il-arba`).”}}
\hadithdefcmd{tirmidhi}{3483}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ شَبِيبِ بْنِ شَيْبَةَ، عَنِ الْحَسَنِ الْبَصْرِيِّ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم لأَبِي ‏"‏ يَا حُصَيْنُ كَمْ تَعْبُدُ الْيَوْمَ إِلَهًا ‏"‏ ‏.‏ قَالَ أَبِي سَبْعَةً سِتًّا فِي الأَرْضِ وَوَاحِدًا فِي السَّمَاءِ ‏.‏ قَالَ ‏"‏ فَأَيُّهُمْ تَعُدُّ لِرَغْبَتِكَ وَرَهْبَتِكَ ‏"‏ ‏.‏ قَالَ الَّذِي فِي السَّمَاءِ ‏.‏ قَالَ ‏"‏ يَا حُصَيْنُ أَمَا إِنَّكَ لَوْ أَسْلَمْتَ عَلَّمْتُكَ كَلِمَتَيْنِ تَنْفَعَانِكَ ‏"‏ ‏.‏ قَالَ فَلَمَّا أَسْلَمَ حُصَيْنٌ قَالَ يَا رَسُولَ اللَّهِ عَلِّمْنِي الْكَلِمَتَيْنِ اللَّتَيْنِ وَعَدْتَنِي ‏.‏ فَقَالَ ‏"‏ قُلِ اللَّهُمَّ أَلْهِمْنِي رُشْدِي وَأَعِذْنِي مِنْ شَرِّ نَفْسِي ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏\hadithno{3483}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Imran bin Husain narrated:“The Prophet (ﷺ) said to my father: ‘O Husain, how many deities do you worship now?‘ He said: ‘Seven. Six in the earth, and one above the heavens.’ He said: ‘So which of them do you take for your ardent requests and fears?’ He said: ‘The one above the heavens.’ He said: ‘O Husain, if you would but accept Islam, I would teach you two phrases that would benefit you.’” He said: “So when Husain accepted Islam, he said: ‘O Messenger of Allah, teach me the two phrases you promised me.’ So he (ﷺ) said: “Say: O Allah, inspire me with my guidance, and protect me from the evil of my soul (Allāhumma alhimnī rushdī, wa a`idhnī min sharri nafsī).’”}}
\hadithdefcmd{tirmidhi}{3484}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا أَبُو مُصْعَبٍ الْمَدَنِيُّ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، مَوْلَى الْمُطَّلِبِ عَنْ أَنَسِ بْنِ مَالِكٍ، رضى الله عنه قَالَ كَثِيرًا مَا كُنْتُ أَسْمَعُ النَّبِيَّ صلى الله عليه وسلم يَدْعُو بِهَؤُلاَءِ الْكَلِمَاتِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْهَمِّ وَالْحَزَنِ وَالْعَجْزِ وَالْكَسَلِ وَالْبُخْلِ وَضَلَعِ الدَّيْنِ وَغَلَبَةِ الرِّجَالِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ عَمْرِو بْنِ أَبِي عَمْرٍو ‏.‏\hadithno{3484}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Anas bin Mallik [may Allah be pleased with him] narrates, saying:“I used to often hear the Prophet (ﷺ) supplicating with these words: ‘O Allah, I seek refuge in You from sadness, grief, helplessness, laziness, being stingy, overwhelming debt, and the overpowering of men (Allāhumma innī a`ūdhu bika minal-hammi wal-ḥazani wal-`ajzi wal-kasali wal-bukhli wa ḍala`id-dain wa ghalabatir-rijāl).’”}}
\hadithdefcmd{tirmidhi}{3485}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم كَانَ يَدْعُو يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْهَرَمِ وَالْجُبْنِ وَالْبُخْلِ وَفِتْنَةِ الْمَسِيحِ وَعَذَابِ الْقَبْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3485}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas narrated that :The Prophet (ﷺ) used to supplicate, saying: “O Allah, indeed, I seek refuge in You from laziness, weakness of old age, cowardice, stinginess, the trial of Al-Masih, and the punishment of the grave (Allāhumma innī a`ūdhu bika minal-kasali wal-harami wal-jubni wal-bukhli wa fitnatil-masīḥi wa `adhabil-qabr).”}}
\hadithdefcmd{tirmidhi}{3486}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، - بَصْرِيٌّ - حَدَّثَنَا عَثَّامُ بْنُ عَلِيٍّ، عَنِ الأَعْمَشِ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَعْقِدُ التَّسْبِيحَ ‏.‏ وَقَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ الأَعْمَشِ عَنْ عَطَاءِ بْنِ السَّائِبِ ‏.‏ وَرَوَى شُعْبَةُ وَالثَّوْرِيُّ هَذَا الْحَدِيثَ عَنْ عَطَاءِ بْنِ السَّائِبِ بِطُولِهِ ‏.‏ وَفِي الْبَابِ عَنْ يُسَيْرَةَ بِنْتِ يَاسِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا مَعْشَرَ النِّسَاءِ اعْقِدْنَ بِالأَنَامِلِ فَإِنَّهُنَّ مَسْئُولاَتٌ مُسْتَنْطَقَاتٌ ‏"‏ ‏.‏\hadithno{3486}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Amr narrated:“I saw the Prophet counting the Tasbih on his hand.”}}
\hadithdefcmd{tirmidhi}{3487}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا سَهْلُ بْنُ يُوسُفَ، حَدَّثَنَا حُمَيْدٌ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم عَادَ رَجُلاً قَدْ جُهِدَ حَتَّى صَارَ مِثْلَ الْفَرْخِ فَقَالَ لَهُ ‏"‏ أَمَا كُنْتَ تَدْعُو أَمَا كُنْتَ تَسْأَلُ رَبَّكَ الْعَافِيَةَ ‏"‏ ‏.‏ قَالَ كُنْتُ أَقُولُ اللَّهُمَّ مَا كُنْتَ مُعَاقِبِي بِهِ فِي الآخِرَةِ فَعَجِّلْهُ لِي فِي الدُّنْيَا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ سُبْحَانَ اللَّهِ إِنَّكَ لاَ تُطِيقُهُ - أَوْ لاَ تَسْتَطِيعُهُ أَفَلاَ كُنْتَ تَقُولُ اللَّهُمَّ آتِنَا فِي الدُّنْيَا حَسَنَةً وَفِي الآخِرَةِ حَسَنَةً وَقِنَا عَذَابَ النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3487}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Anas bin Malik narrated that:The Prophet (ﷺ) visited a man who was so emaciated that he had become like a baby bird. He (ﷺ) said to him: “And did you not used to supplicate? Did you not used to ask Your Lord for sound health?” He said: “I used to say: “O Allah, whatever You are going to punish me with in the Hereafter, then hasten it for me in this world.” So the Prophet (ﷺ) said: “Glory is to Allah, you are not capable of that” – or – “you are not able to stand that. Would you not say: ‘O Allah, give us good in this world, and good in the Hereafter, and spare us the punishment of the Fire (Allāhumma ātinā fid-dunyā ḥasanatan wa fil ākhirati ḥasanatan wa qinā `adhāban-nār).’”}}
\hadithdefcmd{tirmidhi}{3488}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ الْبَزَّازُ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنِ الْحَسَنِ، فِي قَوْلِهِ ‏:‏ ‏(‏ ربَّنَا آتِنَا فِي الدُّنْيَا حَسَنَةً وَفِي الآخِرَةِ حَسَنَةً ‏)‏ قَالَ فِي الدُّنْيَا الْعِلْمَ وَالْعِبَادَةَ وَفِي الآخِرَةِ الْجَنَّةَ ‏.‏\hadithno{3488}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Hisham bin Hassan narrated from Al-Hasan :concerning the saying of Allah: O our Lord, give us good in this world, and good in the Hereafter. He said: “Knowledge and worship in this world, and Paradise in the Hereafter.”}}
\hadithdefcmd{tirmidhi}{3489}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ أَبَا الأَحْوَصِ، يُحَدِّثُ عَنْ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَدْعُو ‏ "‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ الْهُدَى وَالتُّقَى وَالْعَفَافَ وَالْغِنَى ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3489}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah narrated that :the Prophet (ﷺ) used to supplicate: “O Allah, indeed, I ask You for guidance, piety, chastity, and sufficiency (Allāhumma innī as’alukal-hudā wat-tuqā, wal-`afāfa wal-ghinā).”}}
\hadithdefcmd{tirmidhi}{3490}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ مُحَمَّدِ بْنِ سَعْدٍ الأَنْصَارِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ رَبِيعَةَ الدِّمَشْقِيِّ، حَدَّثَنَا عَائِذُ اللَّهِ أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَانَ مِنْ دُعَاءِ دَاوُدَ يَقُولُ اللَّهُمَّ إِنِّي أَسْأَلُكَ حُبَّكَ وَحُبَّ مَنْ يُحِبُّكَ وَالْعَمَلَ الَّذِي يُبَلِّغُنِي حُبَّكَ اللَّهُمَّ اجْعَلْ حُبَّكَ أَحَبَّ إِلَىَّ مِنْ نَفْسِي وَأَهْلِي وَمِنَ الْمَاءِ الْبَارِدِ ‏"‏ ‏.‏ قَالَ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا ذَكَرَ دَاوُدَ يُحَدِّثُ عَنْهُ قَالَ ‏"‏ كَانَ أَعْبَدَ الْبَشَرِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3490}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Ad-Darda’ narrated that :the Messenger of Allah (ﷺ) said: “It used to be from the supplication of Dawud that he would say: ‘O Allah, indeed, I ask You for Your love and the love of those who love You, and for the action that will cause me to attain Your love, O Allah, make Your love more beloved to me than myself, my family and cold water (Allāhumma innī as’aluka ḥubbaka wa ḥubba man yuḥibbuka wal-`amalalladhī yuballighunī ḥubbak. Allāhummaj`al ḥubbaka aḥabba ilaiyya min nafsī, wa ahlī wa minal-mā’il-bārid) He said: “And when the Prophet (ﷺ) would mention Dawud, he would narrate about him, saying: “He was the best in worship out of all men.”}}
\hadithdefcmd{tirmidhi}{3491}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ أَبِي جَعْفَرٍ الْخَطْمِيِّ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ الْقُرَظِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْخَطْمِيِّ الأَنْصَارِيِّ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ كَانَ يَقُولُ فِي دُعَائِهِ ‏ "‏ اللَّهُمَّ ارْزُقْنِي حُبَّكَ وَحُبَّ مَنْ يَنْفَعُنِي حُبُّهُ عِنْدَكَ اللَّهُمَّ مَا رَزَقْتَنِي مِمَّا أُحِبُّ فَاجْعَلْهُ قُوَّةً لِي فِيمَا تُحِبُّ اللَّهُمَّ وَمَا زَوَيْتَ عَنِّي مِمَّا أُحِبُّ فَاجْعَلْهُ لِي فَرَاغًا فِيمَا تُحِبُّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَأَبُو جَعْفَرٍ الْخَطْمِيُّ اسْمُهُ عُمَيْرُ بْنُ يَزِيدَ بْنِ خُمَاشَةَ ‏.‏\hadithno{3491}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Yazid Al-Khatmi Al-Ansari narrated that the Messenger of Allah (ﷺ) used to say in his supplication:“O Allah grant me Your love and the love of those whose love will benefit me with You. O Allah, whatever you have provided me of that which I love, then make it strength for me for that which You love. O Allah, and what you have kept from me of that which I love, then make it for me a period of rest in that which You love. (Allāhummarzuqnī ḥubbuka, wa ḥubba man yanfa`unī ḥubbuhū `indak. Allāhumma mā razaqtanī mimmā uḥibbu faj`alhu quwwatan lī fīmā tuḥibb. Allāhumma wa mā zawaita `annī mimmā uḥibbu faj`alhu farāghan lī fīmā tuḥibb). “}}
\hadithdefcmd{tirmidhi}{3492}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا سَعْدُ بْنُ أَوْسٍ، عَنْ بِلاَلِ بْنِ يَحْيَى الْعَبْسِيِّ، عَنْ شُتَيْرِ بْنِ شَكَلٍ، عَنْ أَبِيهِ، شَكَلِ بْنِ حُمَيْدٍ قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ عَلِّمْنِي تَعَوُّذًا أَتَعَوَّذُ بِهِ ‏.‏ قَالَ فَأَخَذَ بِكَتِفِي فَقَالَ ‏ "‏ قُلِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ شَرِّ سَمْعِي وَمِنْ شَرِّ بَصَرِي وَمِنْ شَرِّ لِسَانِي وَمِنْ شَرِّ قَلْبِي وَمِنْ شَرِّ مَنِيِّي ‏"‏ ‏.‏ يَعْنِي فَرْجَهُ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ سَعْدِ بْنِ أَوْسٍ عَنْ بِلاَلِ بْنِ يَحْيَى ‏.‏\hadithno{3492}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Shakal bin Humaid said:"I came to the Prophet and said: 'O Messenger of Allah, teach me a way of seeking refuge so that I may seek refuge by it." He said: "So he took my hand and said: 'Say: O Allah, indeed I seek refuge in You from the evil of my hearing and the evil of my sight, and the evil of my tongue and the evil of my heart, and the evil of my semen (Allāhumma innī a`ūdhu bika min sharri sam`ī wa min sharri baṣarī, wa min sharri lisānī, wa min sharri qalbī, wa min sharri maniyyī)}}
\hadithdefcmd{tirmidhi}{3493}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، أَنَّ عَائِشَةَ، قَالَتْ كُنْتُ نَائِمَةً إِلَى جَنْبِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَفَقَدْتُهُ مِنَ اللَّيْلِ فَلَمَسْتُهُ فَوَقَعَتْ يَدِي عَلَى قَدَمَيْهِ وَهُوَ سَاجِدٌ وَهُوَ يَقُولُ ‏"‏ أَعُوذُ بِرِضَاكَ مِنْ سَخَطِكَ وَبِمُعَافَاتِكَ مِنْ عُقُوبَتِكَ لاَ أُحْصِي ثَنَاءً عَلَيْكَ أَنْتَ كَمَا أَثْنَيْتَ عَلَى نَفْسِكَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ قَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ عَائِشَةَ ‏.‏ حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ وَزَادَ فِيهِ ‏"‏ وَأَعُوذُ بِكَ مِنْكَ لاَ أُحْصِي ثَنَاءً عَلَيْكَ ‏"‏ ‏.‏\hadithno{3493}\hadithgrade{Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated:“I was sleeping at the side of the Messenger of Allah (ﷺ), then I lost him during the night. So I felt around for him, and my hand fell upon his feet while he was prostrating, and he was saying: ‘I seek refuge in Your pleasure from Your anger, and in Your pardon from Your punishment. I cannot count Your praises. You are as You have praised Yourself (A`ūdhu biriḍāka min sakhaṭika wa bi mu`āfātika min `uqūbatika, lā uḥṣi thanā’an `alaika anta kamā athnaita `alā nafsik).’”}}
\hadithdefcmd{tirmidhi}{3494}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي الزُّبَيْرِ الْمَكِّيِّ، عَنْ طَاوُسٍ الْيَمَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُعَلِّمُهُمْ هَذَا الدُّعَاءَ كَمَا يُعَلِّمُهُمُ السُّورَةَ مِنَ الْقُرْآنِ ‏"‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ جَهَنَّمَ وَمِنْ عَذَابِ الْقَبْرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ [غَرِيبٌ] ‏.‏\hadithno{3494}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin `Abbas narrated:that the Messenger of Allah (ﷺ) used [to teach them this supplication as he used] to teach them a Surat of the Quran: “O Allah, indeed, I seek refuge in you from the punishment of Hell, and from the punishment of the grave, and I seek refuge in You from the trial of the false Masih, and I seek refuge in You from the trial of living and dying. (Allāhumma innī a`ūdhu bika min `adhābi jahannam, wa min `adhābil-qabr, wa a`ūdhu bika min fitnatil-masīḥid-dajjāl, wa a`ūdhu bika min fitnatil-maḥyā wal-mamāt)”}}
\hadithdefcmd{tirmidhi}{3495}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُو بِهَؤُلاَءِ الْكَلِمَاتِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ فِتْنَةِ النَّارِ وَعَذَابِ النَّارِ وَعَذَابِ الْقَبْرِ وَفِتْنَةِ الْقَبْرِ وَمِنْ شَرِّ فِتْنَةِ الْغِنَى وَمِنْ شَرِّ فِتْنَةِ الْفَقْرِ وَمِنْ شَرِّ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ اللَّهُمَّ اغْسِلْ خَطَايَاىَ بِمَاءِ الثَّلْجِ وَالْبَرَدِ وَأَنْقِ قَلْبِي مِنَ الْخَطَايَا كَمَا أَنْقَيْتَ الثَّوْبَ الأَبْيَضَ مِنَ الدَّنَسِ وَبَاعِدْ بَيْنِي وَبَيْنَ خَطَايَاىَ كَمَا بَاعَدْتَ بَيْنَ الْمَشْرِقِ وَالْمَغْرِبِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْهَرَمِ وَالْمَأْثَمِ وَالْمَغْرَمِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3495}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated that the Messenger of Allah (ﷺ) used to supplicate with these words:“O Allah, indeed, I seek refuge in You from the trial of the Fire, and the punishment of the Fire, and the punishment of the grave, and the trial of the grave, and from the evil of the trial of the grave, and from the evil of the trials of riches, and from the evils of the trials of poverty, and from the evil of the trial of the false Masih. O Allah, wash my sins with water of ice and hail, and cleanse my heart of sins, as You cleansed a white garment of filth, and distance me and my sins as You distanced between the east and the west. O Allah, indeed, I seek refuge in You from laziness, senility, sin and debt. (Allāhumma innī a`ūdhu bika min fitnatin-nār, wa `adhābin-nār, wa `adhābil-qabr, wa fitnatil-qabr, wa min sharri fitnatil-ghinā, wa min sharri fitnatil-faqr, wa min sharri fitnatil- masīḥid-dajjāl. Allāhummaghsil khaṭāyāya bi-mā’ith-thalji wal-bardi, wa anqi qalbī minal-khaṭāyā kamā anqaitath-thawbal-abyaḍa minad-danas, wa bā`id bainī wa baina khaṭāyāya kama bā`adta bainal-mashriqi wal maghrib, Allāhumma innī a`ūdhu bika min al-kasali wal-harami wal-ma’thami wal-maghram).”}}
\hadithdefcmd{tirmidhi}{3496}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ عِنْدَ وَفَاتِهِ ‏ "‏ اللَّهُمَّ اغْفِرْ لِي وَارْحَمْنِي وَأَلْحِقْنِي بِالرَّفِيقِ الأَعْلَى ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3496}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah said:“I heard the Messenger of Allah (ﷺ) saying at his death: ‘O Allah, forgive me and have mercy on me, and join me with the Highest Company (Allāhummaghfirlī warḥamnī wa alḥiqnī bir-rafīqil a`lā).’”}}
\hadithdefcmd{tirmidhi}{3497}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقُولُ أَحَدُكُمُ اللَّهُمَّ اغْفِرْ لِي إِنْ شِئْتَ اللَّهُمَّ ارْحَمْنِي إِنْ شِئْتَ لِيَعْزِمِ الْمَسْأَلَةَ فَإِنَّهُ لاَ مُكْرِهَ لَهُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3497}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:“None of you should say: ‘O Allah forgive me if You wish. O Allah have mercy on me if You wish.’ Let him be firm in asking, for there is none that can compel Him to do things.”}}
\hadithdefcmd{tirmidhi}{3498}{حَدَّثَنَا الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عَبْدِ اللَّهِ الأَغَرِّ، وَعَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَنْزِلُ رَبُّنَا كُلَّ لَيْلَةٍ إِلَى السَّمَاءِ الدُّنْيَا حِينَ يَبْقَى ثُلُثُ اللَّيْلِ الآخِرُ فَيَقُولُ مَنْ يَدْعُونِي فَأَسْتَجِيبَ لَهُ وَمَنْ يَسْأَلُنِي فَأُعْطِيَهُ وَمَنْ يَسْتَغْفِرُنِي فَأَغْفِرَ لَهُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو عَبْدِ اللَّهِ الأَغَرُّ اسْمُهُ سَلْمَانُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَأَبِي سَعِيدٍ وَجُبَيْرِ بْنِ مُطْعِمٍ وَرِفَاعَةَ الْجُهَنِيِّ وَأَبِي الدَّرْدَاءِ وَعُثْمَانَ بْنِ أَبِي الْعَاصِي ‏.‏\hadithno{3498}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:“Our Lord descends every night to the nearest heaven, until the last third of the night remains, so He says: ‘Who is calling upon Me so that I may answer him? Who is asking from Me so that I may give him? And who is seeking forgiveness from Me, so that I may forgive him.’”}}
\hadithdefcmd{tirmidhi}{3499}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الثَّقَفِيُّ الْمَرْوَزِيُّ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَابِطٍ، عَنْ أَبِي أُمَامَةَ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ أَىُّ الدُّعَاءِ أَسْمَعُ قَالَ ‏"‏ جَوْفُ اللَّيْلِ الآخِرُ وَدُبُرَ الصَّلَوَاتِ الْمَكْتُوبَاتِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي ذَرٍّ وَابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ جَوْفُ اللَّيْلِ الآخِرُ الدُّعَاءُ فِيهِ أَفْضَلُ أَوْ أَرْجَى ‏"‏ ‏.‏ أَوْ نَحْوَ هَذَا ‏.‏\hadithno{3499}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Umamah narrated:“It was said: ‘O Messenger of Allah, which supplication is most likely to be listened to?’ He said: ‘(During) the last part of the night, and at the end of the obligatory prayers.’”}}
\hadithdefcmd{tirmidhi}{3500}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ عُمَرَ الْهِلاَلِيُّ، عَنْ سَعِيدِ بْنِ إِيَاسٍ الْجُرَيْرِيِّ، عَنْ أَبِي السَّلِيلِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ سَمِعْتُ دُعَاءَكَ اللَّيْلَةَ فَكَانَ الَّذِي وَصَلَ إِلَىَّ مِنْهُ أَنَّكَ تَقُولُ ‏"‏ اللَّهُمَّ اغْفِرْ لِي ذَنْبِي وَوَسِّعْ لِي فِي رِزْقِي وَبَارِكْ لِي فِيمَا رَزَقْتَنِي ‏"‏ ‏.‏ قَالَ ‏"‏ فَهَلْ تَرَاهُنَّ تَرَكْنَ شَيْئًا ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَأَبُو السَّلِيلِ اسْمُهُ ضُرَيْبُ بْنُ نُفَيْرٍ وَيُقَالُ ابْنُ نُقَيْرٍ ‏.‏\hadithno{3500}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that a man said:“O Messenger of Allah, I heard your supplication last night, and the part of it that reached me of it, was that you said: ‘O Allah, forgive me my sin, and expand for me my abode, and bless for me that which You have provided me’ (Allāhummaghfirlī dhanbī, wa wassi` lī fī dārī, wa bārik lī fīmā razaqtanī). He said: ‘Do you see that they leave off anything?’”}}
\hadithdefcmd{tirmidhi}{3501}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا حَيْوَةُ بْنُ شُرَيْحٍ، وَهُوَ ابْنُ يَزِيدَ الْحِمْصِيُّ عَنْ بَقِيَّةَ بْنِ الْوَلِيدِ، عَنْ مُسْلِمِ بْنِ زِيَادٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ حِينَ يُصْبِحُ اللَّهُمَّ أَصْبَحْنَا نُشْهِدُكَ وَنُشْهِدُ حَمَلَةَ عَرْشِكَ وَمَلاَئِكَتَكَ وَجَمِيعَ خَلْقِكَ بِأَنَّكَ الله لاَ إِلَهَ إِلاَّ أَنْتَ وَحْدَكَ لاَ شَرِيكَ لَكَ وَأَنَّ مُحَمَّدًا عَبْدُكَ وَرَسُولُكَ ‏.‏ إِلاَّ غَفَرَ اللَّهُ لَهُ مَا أَصَابَ فِي يَوْمِهِ ذَلِكَ وَإِنْ قَالَهَا حِينَ يُمْسِي غَفَرَ اللَّهُ لَهُ مَا أَصَابَ فِي تِلْكَ اللَّيْلَةِ مِنْ ذَنْبٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{3501}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Anas narrated that the Messenger of Allah (ﷺ) said:“Whoever says in the morning: ‘O Allah we have reached morning, calling You to witness, and calling the carriers of Your Throne to witness, and Your angels, and all of Your creation, that You are Allah, none has the right to be worshipped but You, Alone, without partner, and that Muhammad (ﷺ) is Your slave and Your Messenger. (Allāhumma aṣbaḥnā nush-hiduka wa nush-hidu ḥamalata `arshika wa malā’ikataka wa jamī`a khalqika bi-annaka Allāh, lā ilāha illā anta, waḥdaka lā sharīka laka, wa anna Muḥammadan `abduka wa rasūluk)’ Allah will forgive him for whatever he does that day, and if he says it in the evening, Allah will forgive him for whatever sin he commits that night.”}}
\hadithdefcmd{tirmidhi}{3502}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ، عَنْ عُبَيْدِ اللَّهِ بْنِ زَحْرٍ، عَنْ خَالِدِ بْنِ أَبِي عِمْرَانَ، أَنَّ ابْنَ عُمَرَ، قَالَ قَلَّمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُومُ مِنْ مَجْلِسٍ حَتَّى يَدْعُوَ بِهَؤُلاَءِ الْكَلِمَاتِ لأَصْحَابِهِ ‏ "‏ اللَّهُمَّ اقْسِمْ لَنَا مِنْ خَشْيَتِكَ مَا يَحُولُ بَيْنَنَا وَبَيْنَ مَعَاصِيكَ وَمِنْ طَاعَتِكَ مَا تُبَلِّغُنَا بِهِ جَنَّتَكَ وَمِنَ الْيَقِينِ مَا تُهَوِّنُ بِهِ عَلَيْنَا مُصِيبَاتِ الدُّنْيَا وَمَتِّعْنَا بِأَسْمَاعِنَا وَأَبْصَارِنَا وَقُوَّتِنَا مَا أَحْيَيْتَنَا وَاجْعَلْهُ الْوَارِثَ مِنَّا وَاجْعَلْ ثَأْرَنَا عَلَى مَنْ ظَلَمَنَا وَانْصُرْنَا عَلَى مَنْ عَادَانَا وَلاَ تَجْعَلْ مُصِيبَتَنَا فِي دِينِنَا وَلاَ تَجْعَلِ الدُّنْيَا أَكْبَرَ هَمِّنَا وَلاَ مَبْلَغَ عِلْمِنَا وَلاَ تُسَلِّطْ عَلَيْنَا مَنْ لاَ يَرْحَمُنَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَى بَعْضُهُمْ هَذَا الْحَدِيثَ عَنْ خَالِدِ بْنِ أَبِي عِمْرَانَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ ‏.‏\hadithno{3502}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ibn `Umar said:“Rarely would the Messenger of Allah (ﷺ) stand from a sitting until he supplicated with these words for his Companions: ‘O Allah, apportion for us, fear of You, that shall come between us and disobedience of You, and of obedience to You, which shall cause us to obtain Your Paradise, and of certainty, which shall make the afflictions of the world easy for us, and enjoyment of our hearing, and our seeing, and our strength as long as You keep us alive, and make it the inheritor of us. And let our vengeance be upon those who have wronged us, and aid us against those who show enmity towards us, and do not make our affliction in our religion, and do not make this world our greatest concern, nor the limit of our knowledge, and do not give power over us to those who will not have mercy on us. (Allāhumma-qsim lanā min khashyatika mā yaḥūlu, bainanā wa baina ma`āṣīka wa min ṭā`atika mā tuballighuna bihī jannatak, wa minal-yaqīni mā tuhawwinu bihī `alainā muṣībatid-dunyā, wa matti`na bi-asmā`inā wa abṣārina wa quwwatina mā aḥyaytanā, waj`alhul-wāritha minnā, waj`al tha’ranā `alā man ẓalamanā, wanṣurna `alā man `ādānā, wa lā taj`al muṣībatanā fī dīninā, wa lā taj`alid-dunyā akbara hamminā wa lā mablagha `ilminā, wa lā tusalliṭ `alainā man lā yarḥamunā).’”}}
\hadithdefcmd{tirmidhi}{3503}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا عُثْمَانُ الشَّحَّامُ، حَدَّثَنِي مُسْلِمُ بْنُ أَبِي بَكْرَةَ، قَالَ سَمِعَنِي أَبِي، وَأَنَا أَقُولُ اللَّهُمَّ، إِنِّي أَعُوذُ بِكَ مِنَ الْهَمِّ وَالْكَسَلِ وَعَذَابِ الْقَبْرِ ‏.‏ قَالَ يَا بُنَىَّ مِمَّنْ سَمِعْتَ هَذَا قَالَ قُلْتُ سَمِعْتُكَ تَقُولُهُنَّ ‏.‏ قَالَ الْزَمْهُنَّ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُهُنَّ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ [صَحِيحٌ][غَرِيبٌ] ‏.‏\hadithno{3503}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Muslim bin Abi Bakrah said:“My father heard me while I was saying: “O Allah, I seek refuge in You from sadness and laziness and the punishment of the grave (Allāhumma, innī a`ūdhu bika minal-hammi wal-kasali wa `adhābil-qabr).’ He said: ‘O my son, from who did you hear this?’” He said: “I said: ‘I heard you saying them.’ He said: ‘Stick to them, for indeed, I heard the Messenger of Allah (ﷺ) saying them.’”}}
\hadithdefcmd{tirmidhi}{3504}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الْحُسَيْنِ بْنِ وَاقِدٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، رضى الله عنه قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ أُعَلِّمُكَ كَلِمَاتٍ إِذَا قُلْتَهُنَّ غَفَرَ اللَّهُ لَكَ وَإِنْ كُنْتَ مَغْفُورًا لَكَ ‏"‏ ‏.‏ قَالَ ‏"‏ قُلْ لاَ إِلَهَ إِلاَّ اللَّهُ الْعَلِيُّ الْعَظِيمُ لاَ إِلَهَ إِلاَّ اللَّهُ الْحَلِيمُ الْكَرِيمُ لاَ إِلَهَ إِلاَّ اللَّهُ سُبْحَانَ اللَّهِ رَبِّ الْعَرْشِ الْعَظِيمِ ‏"‏ ‏.‏ قَالَ عَلِيُّ بْنُ خَشْرَمٍ وَأَخْبَرَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، عَنْ أَبِيهِ، بِمِثْلِ ذَلِكَ إِلاَّ أَنَّهُ قَالَ فِي آخِرِهَا ‏"‏ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ أَبِي إِسْحَاقَ عَنِ الْحَارِثِ عَنْ عَلِيٍّ ‏.‏\hadithno{3504}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ali [may Allah be pleased with him] said:“The Messenger of Allah (ﷺ) said to me: ‘Should I not teach you some words that if you say them, Allah will forgive you, even if you were already forgiven?’ He said: ‘Say: None has the right to be worshipped by Allah, the Most High, the Magnificent. None has the right to be worshipped by Allah, the Forbearing, the Generous. None has the right to be worshipped but Allah. Glory to Allah, the Lord of the Magnificent Throne. (Lā ilāha illallāhul-`aliyul-`aẓīm, lā ilāha illallāhul-ḥalīmul-karīm, lā ilāha illallāh, subḥān Allāhi rabbil-`arshil-`aẓīm.)’”}}
\hadithdefcmd{tirmidhi}{3505}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا يُونُسُ بْنُ أَبِي إِسْحَاقَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، عَنْ سَعْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دَعْوَةُ ذِي النُّونِ إِذْ دَعَا وَهُوَ فِي بَطْنِ الْحُوتِ لاَ إِلَهَ إِلاَّ أَنْتَ سُبْحَانَكَ إِنِّي كُنْتُ مِنَ الظَّالِمِينَ ‏.‏ فَإِنَّهُ لَمْ يَدْعُ بِهَا رَجُلٌ مُسْلِمٌ فِي شَيْءٍ قَطُّ إِلاَّ اسْتَجَابَ اللَّهُ لَهُ ‏"‏ ‏.‏ قَالَ مُحَمَّدُ بْنُ يَحْيَى قَالَ مُحَمَّدُ بْنُ يُوسُفَ مَرَّةً عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ سَعْدٍ، عَنْ سَعْدٍ، ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى غَيْرُ، وَاحِدٍ، هَذَا الْحَدِيثَ عَنْ يُونُسَ بْنِ أَبِي إِسْحَاقَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ سَعْدٍ، عَنْ سَعْدٍ، وَلَمْ يَذْكُرُوا فِيهِ عَنْ أَبِيهِ، ‏.‏ وَرَوَى بَعْضُهُمْ، عَنْ يُونُسَ بْنِ أَبِي إِسْحَاقَ، فَقَالُوا عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، عَنْ سَعْدٍ، وَكَانَ، يُونُسُ بْنُ أَبِي إِسْحَاقَ رُبَّمَا ذَكَرَ فِي هَذَا الْحَدِيثِ عَنْ أَبِيهِ، وَرُبَّمَا، لَمْ يَذْكُرْهُ ‏.‏\hadithno{3505}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibrahim bin Muhammad bin Sa`d narrated from his father, from Sa`d that the Messenger of Allah (ﷺ) said:“The supplication of Dhun-Nun (Prophet Yunus) when he supplicated, while in the belly of the whale was: ‘There is none worthy of worship except You, Glory to You, Indeed, I have been of the transgressors. (Lā ilāha illā anta subḥānaka innī kuntu minaẓ-ẓālimīn)’ So indeed, no Muslim man supplicates with it for anything, ever, except Allah responds to him.”}}
\hadithdefcmd{tirmidhi}{3506}{حَدَّثَنَا يُوسُفُ بْنُ حَمَّادٍ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، رَضِيَ اللَّهُ عَنْهُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ لِلَّهِ تِسْعَةً وَتِسْعِينَ اسْمًا مِائَةً غَيْرَ وَاحِدٍ مَنْ أَحْصَاهَا دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏ قَالَ يُوسُفُ وَحَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم\hadithno{3506}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah [may Allah be pleased with him] narrated the the Prophet said:“Indeed Allah has ninety-nine Names, one hundred less one, whoever counts them shall enter Paradise.”}}
\hadithdefcmd{tirmidhi}{3507}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ الْجُوزَجَانِيُّ، حَدَّثَنِي صَفْوَانُ بْنُ صَالِحٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا شُعَيْبُ بْنُ أَبِي حَمْزَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ لِلَّهِ تَعَالَى تِسْعَةً وَتِسْعِينَ اسْمًا مِائَةً غَيْرَ وَاحِدَةٍ مَنْ أَحْصَاهَا دَخَلَ الْجَنَّةَ هُوَ اللَّهُ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ الرَّحْمَنُ الرَّحِيمُ الْمَلِكُ الْقُدُّوسُ السَّلاَمُ الْمُؤْمِنُ الْمُهَيْمِنُ الْعَزِيزُ الْجَبَّارُ الْمُتَكَبِّرُ الْخَالِقُ الْبَارِئُ الْمُصَوِّرُ الْغَفَّارُ الْقَهَّارُ الْوَهَّابُ الرَّزَّاقُ الْفَتَّاحُ الْعَلِيمُ الْقَابِضُ الْبَاسِطُ الْخَافِضُ الرَّافِعُ الْمُعِزُّ الْمُذِلُّ السَّمِيعُ الْبَصِيرُ الْحَكَمُ الْعَدْلُ اللَّطِيفُ الْخَبِيرُ الْحَلِيمُ الْعَظِيمُ الْغَفُورُ الشَّكُورُ الْعَلِيُّ الْكَبِيرُ الْحَفِيظُ الْمُقِيتُ الْحَسِيبُ الْجَلِيلُ الْكَرِيمُ الرَّقِيبُ الْمُجِيبُ الْوَاسِعُ الْحَكِيمُ الْوَدُودُ الْمَجِيدُ الْبَاعِثُ الشَّهِيدُ الْحَقُّ الْوَكِيلُ الْقَوِيُّ الْمَتِينُ الْوَلِيُّ الْحَمِيدُ الْمُحْصِي الْمُبْدِئُ الْمُعِيدُ الْمُحْيِي الْمُمِيتُ الْحَىُّ الْقَيُّومُ الْوَاجِدُ الْمَاجِدُ الْوَاحِدُ الصَّمَدُ الْقَادِرُ الْمُقْتَدِرُ الْمُقَدِّمُ الْمُؤَخِّرُ الأَوَّلُ الآخِرُ الظَّاهِرُ الْبَاطِنُ الْوَالِي الْمُتَعَالِي الْبَرُّ التَّوَّابُ الْمُنْتَقِمُ الْعَفُوُّ الرَّءُوفُ مَالِكُ الْمُلْكِ ذُو الْجَلاَلِ وَالإِكْرَامِ الْمُقْسِطُ الْجَامِعُ الْغَنِيُّ الْمُغْنِي الْمَانِعُ الضَّارُّ النَّافِعُ النُّورُ الْهَادِي الْبَدِيعُ الْبَاقِي الْوَارِثُ الرَّشِيدُ الصَّبُورُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ حَدَّثَنَا بِهِ غَيْرُ وَاحِدٍ عَنْ صَفْوَانَ بْنِ صَالِحٍ ‏.‏ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ صَفْوَانَ بْنِ صَالِحٍ وَهُوَ ثِقَةٌ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلاَ نَعْلَمُ - فِي كَبِيرِ شَيْءٍ مِنَ الرِّوَايَاتِ لَهُ إِسْنَادٌ صَحِيحٌ ذِكْرَ الأَسْمَاءِ إِلاَّ فِي هَذَا الْحَدِيثِ ‏.‏ وَقَدْ رَوَى آدَمُ بْنُ أَبِي إِيَاسٍ هَذَا الْحَدِيثَ بِإِسْنَادٍ غَيْرِ هَذَا عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَذَكَرَ فِيهِ الأَسْمَاءَ وَلَيْسَ لَهُ إِسْنَادٌ صَحِيحٌ ‏.‏\hadithno{3507}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“Indeed, Allah has ninety-nine Names, one hundred less one, whoever counts them shall enter Paradise. He is Allah, the one whom there is none worthy of worship except for Him (Allāhu Lā Ilāha Illā Huwa), the Most Merciful (to the creation) (Ar-Raḥmān), the Most Beneficent (to the believers) (Ar-Raḥīm), the King (Al-Malik), the Free of Deficiencies (Al-Quddūs), the Granter of Safety (As-Salām), the Granter of Security (Al-Mu’min), the Watcher (Al-Muhaimin), the Mighty (Al-`Azīz), the Compeller (Al-Jabbār), the Supreme (Al-Mutakabbir), the Creator (Al-Khāliq), the Originator (Al-Bāri’), the Fashioner (Al-Muṣawwir), the Pardoner (Al-Ghaffār), the Overwhelming (Al-Qahhār), the Giving (Al-Wahhāb), the Provider (Ar-Razzāq), the Opener (Al-Fattāḥ), the Knowing (Al-`Alīm), the Taker (Al-Qābiḍ), the Giver (Al-Bāsiṭ), the Abaser (Al-Khāfiḍ), the Exalter (Ar-Rāfi`), the One who grants honor (Al-Mu`izz), the One who humiliates (Al-Mudhil), the Hearing (As-Samī`), the Seeing (Al-Baṣīr), the Judge (Al-Ḥakam), the Just (Al-`Adl), the Kind (Al-Laṭīf), the Aware (Al-Khabīr), the Forbearing (Al-Ḥalīm), the Magnificent (Al-`Aẓīm), the Oft-Forgiving (Al-Ghafūr), the Grateful (Ash-Shakūr), the Most High (Al-`Aliyy), the Great (Al-Kabīr), the Guardian (Al-Ḥafīẓ), the Powerful (Al-Muqīt), the Reckoner (Al-Ḥasīb), the Glorious (Al-Jalīl), the Generous (Al-Karīm), the Watcher (Ar-Raqīb), the Responder (Al-Mujīb), the Liberal Giver (Al-Wāsi`), the Wise (Al-Ḥakīm), the Loving (Al-Wadūd), the Majestic (Al-Majīd), the Reviver (Al-Bā`ith), the Witness (Ash-Shahīd), the Truth (Al-Ḥaqq), the Guarantor (Al-Wakīl), the Strong (Al-Qawiyy), the Firm (Al-Matīn), the One Who Aids (Al-Waliyy), the Praiseworthy (Al-Ḥamīd), the Encompasser (Al-Muḥṣi), the One Who Begins things (Al-Mubdi’), the One Who brings things back (Al-Mu`īd), the One Who gives life (Al-Muḥyi), the One Who causes death (Al-Mumīt), the Living (Al-Ḥayyu), the Self-Sufficient (Al-Qayyūm), the One Who brings into existence (Al-Wājid), the Illustrious (Al-Mājid), the One (Al-Wāḥid), the Master (Aṣ-Ṣamad), the Able (Al-Qādir), the Powerful (Al-Muqtadir), the One who hastens (Al-Muqaddim), the One who delays (Al-Mu’akhkhir), the First (Al-Awwal), the Last (Al-Ākhir), the Apparent (Aẓ-Ẓāhir), the Inner (Al-Bāṭin), the Owner (Al-Wāli), the Exalted (Al-Muta`āli), the Doer of Good (Al-Barr), the Acceptor of repentance (At-Tawwāb), the Avenger (Al-Muntaqim), the Pardoning (Al-`Afuww), the Kind (Ar-Ra’ūf), the Owner of Dominion (Mālikul-Mulk), the Possessor of Glory and Generosity (Dhul Jalāli wal Ikrām), the One who does justice (Al-Muqsiṭ), the Gatherer (Al-Jāmi`), the Rich (Al-Ghaniyy), the Enricher (Al-Mughni), the Preventer (Al-Māni`), the Harmer (Aḍ-Ḍār), the One who benefits (An-Nāfi`), the Light (An-Nūr), the Guide (Al-Hādi), the Originator (Al-Badī`), the Lasting (Al-Bāqi), the Inheritor (Al-Wārith), the Guide (Ar-Rashīd), the Tolerant (Aṣ-Ṣabūr).”}}
\hadithdefcmd{tirmidhi}{3508}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ لِلَّهِ تِسْعَةً وَتِسْعِينَ اسْمًا مَنْ أَحْصَاهَا دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏ قَالَ وَلَيْسَ فِي هَذَا الْحَدِيثِ ذِكْرُ الأَسْمَاءِ ‏.‏ قَالَ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ رَوَاهُ أَبُو الْيَمَانِ عَنْ شُعَيْبِ بْنِ أَبِي حَمْزَةَ عَنْ أَبِي الزِّنَادِ وَلَمْ يَذْكُرْ فِيهِ الأَسْمَاءَ ‏.‏\hadithno{3508}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Hurairah narrated that the Prophet said:“Indeed, Allah has ninety-nine Names, whoever counts them shall enter Paradise.”}}
\hadithdefcmd{tirmidhi}{3509}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، أَنَّ حُمَيْدًا الْمَكِّيَّ، مَوْلَى ابْنِ عَلْقَمَةَ حَدَّثَهُ أَنَّ عَطَاءَ بْنَ أَبِي رَبَاحٍ حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا مَرَرْتُمْ بِرِيَاضِ الْجَنَّةِ فَارْتَعُوا ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ وَمَا رِيَاضُ الْجَنَّةِ قَالَ ‏"‏ الْمَسَاجِدُ ‏"‏ ‏.‏ قُلْتُ وَمَا الرَّتْعُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ سُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3509}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“When you pass by the gardens of Paradise, then feast.” I said: “O Messenger of Allah, and what are the gardens of Paradise?” He said, “The Masajid.” I said: “And what is feasting, O Messenger of Allah?” He said: “‘Glory is to Allah, (Subḥān Allāh)’ and ‘All praise is due to Allah, (Al-Ḥamdulillāh)’ and ‘None has the right to be worshipped but Allah, (Lā Ilāha Illallāh)’ and ‘Allah is the Greatest (Allāhu Akbar).’”}}
\hadithdefcmd{tirmidhi}{3510}{حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ بْنِ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنِي أَبِي قَالَ، حَدَّثَنَا مُحَمَّدُ بْنُ ثَابِتٍ الْبُنَانِيُّ، قَالَ حَدَّثَنِي أَبِي، عَنْ أَنَسِ بْنِ مَالِكٍ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا مَرَرْتُمْ بِرِيَاضِ الْجَنَّةِ فَارْتَعُوا ‏"‏ ‏.‏ قَالَ وَمَا رِيَاضُ الْجَنَّةِ قَالَ ‏"‏ حِلَقُ الذِّكْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ ثَابِتٍ عَنْ أَنَسٍ ‏.‏\hadithno{3510}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik [may Allah be pleased with him] narrated that the Messenger of Allah said:“When you pass by the gardens of Paradise, them feast.” They said: “And what are the gardens of Paradise?” He said: “The circles of remembrance.”}}
\hadithdefcmd{tirmidhi}{3511}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ عَمْرِو بْنِ أَبِي سَلَمَةَ، عَنْ أُمِّهِ أُمِّ سَلَمَةَ، عَنْ أَبِي سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا أَصَابَ أَحَدَكُمْ مُصِيبَةٌ فَلْيَقُلْ ‏:‏ ‏(‏ إنَّا لِلَّهِ وَإِنَّا إِلَيْهِ رَاجِعُونَ ‏)‏ اللَّهُمَّ عِنْدَكَ احْتَسَبْتُ مُصِيبَتِي فَأْجُرْنِي فِيهَا وَأَبْدِلْنِي مِنْهَا خَيْرًا ‏"‏ ‏.‏ فَلَمَّا احْتُضِرَ أَبُو سَلَمَةَ قَالَ اللَّهُمَّ اخْلُفْ فِي أَهْلِي خَيْرًا مِنِّي فَلَمَّا قُبِضَ قَالَتْ أُمُّ سَلَمَةَ ‏:‏ ‏(‏ إنَّا لِلَّهِ وَإِنَّا إِلَيْهِ رَاجِعُونَ ‏)‏ عِنْدَ اللَّهِ احْتَسَبْتُ مُصِيبَتِي فَأْجُرْنِي فِيهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَرُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ أُمِّ سَلَمَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَأَبُو سَلَمَةَ اسْمُهُ عَبْدُ اللَّهِ بْنُ عَبْدِ الأَسَدِ ‏.‏\hadithno{3511}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Umar bin Abu Salamah narrated from his mother, Umm Salamah, that the Messenger of Allah (ﷺ) said:“When a calamity strikes one of you, then let him say: ‘Indeed, to Allah we belong and to Him we shall return. O Allah, I seek reward with You for my affliction, so reward me for it, and replace it for me with something better (Innā lillāhi wa innā ilaihi rāji`ūn, Allāhumma `indaka aḥtasibu muṣībatī fa’jurnī fīhā wa abdilnī minhā khair).’” When the time of death was near Abu Salamah, he said: ‘O Allah, replace me for my wife, with better than me.” So when he died, Umm Salamah said: “Indeed, to Allah we belong and to Him we shall return. I seek reward with Allah for my affliction, so reward me for it.”}}
\hadithdefcmd{tirmidhi}{3512}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، حَدَّثَنَا سَلَمَةُ بْنُ وَرْدَانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَىُّ الدُّعَاءِ أَفْضَلُ قَالَ ‏"‏ سَلْ رَبَّكَ الْعَافِيَةَ وَالْمُعَافَاةَ فِي الدُّنْيَا وَالآخِرَةِ ‏"‏ ‏.‏ ثُمَّ أَتَاهُ فِي الْيَوْمِ الثَّانِي فَقَالَ يَا رَسُولَ اللَّهِ أَىُّ الدُّعَاءِ أَفْضَلُ فَقَالَ لَهُ مِثْلَ ذَلِكَ ثُمَّ أَتَاهُ فِي الْيَوْمِ الثَّالِثِ فَقَالَ لَهُ مِثْلَ ذَلِكَ ‏.‏ قَالَ ‏"‏ فَإِذَا أُعْطِيتَ الْعَافِيَةَ فِي الدُّنْيَا وَأُعْطِيتَهَا فِي الآخِرَةِ فَقَدْ أَفْلَحْتَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ سَلَمَةَ بْنِ وَرْدَانَ ‏.‏\hadithno{3512}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that a man came to the Prophet (ﷺ) and said:“O Messenger of Allah, which supplication is the best?” He (ﷺ) said: “Ask Your Lord For Al-`Āfiyah and Al-Mu`āfāh in this world and in the Hereafter.” Then he came to him on the second day and said: “O Messenger of Allah, which supplication is the best?” So he (ﷺ) said to him similar to that. Then he came to him on the third day, so he (ﷺ) said to him similar to that. He (ﷺ) said: “So when you have been given Al-`Āfiyah in this world, and you have been given it in the Hereafter, then you have succeeded.”}}
\hadithdefcmd{tirmidhi}{3513}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ الضُّبَعِيُّ، عَنْ كَهْمَسِ بْنِ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ عَائِشَةَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ عَلِمْتُ أَىُّ لَيْلَةٍ لَيْلَةُ الْقَدْرِ مَا أَقُولُ فِيهَا قَالَ ‏ "‏ قُولِي اللَّهُمَّ إِنَّكَ عَفُوٌّ كَرِيمٌ تُحِبُّ الْعَفْوَ فَاعْفُ عَنِّي ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3513}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:“I said: ‘O Messenger of Allah, what is your view if I know when the Night of Al-Qadr is, then what should I say in it?” He said: ‘Say: “O Allah, indeed You are Pardoning, [Generous,] You love pardon, so pardon me (Allāhumma innaka `Afuwwun [Karīmun], tuḥibbul-`afwa fa`fu `annī).’”}}
\hadithdefcmd{tirmidhi}{3514}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ عَلِّمْنِي شَيْئًا أَسْأَلُهُ اللَّهَ عَزَّ وَجَلَّ ‏.‏ قَالَ ‏"‏ سَلِ اللَّهَ الْعَافِيَةَ ‏"‏ ‏.‏ فَمَكَثْتُ أَيَّامًا ثُمَّ جِئْتُ فَقُلْتُ يَا رَسُولَ اللَّهِ عَلِّمْنِي شَيْئًا أَسْأَلُهُ اللَّهَ ‏.‏ فَقَالَ لِي ‏"‏ يَا عَبَّاسُ يَا عَمَّ رَسُولِ اللَّهِ سَلِ اللَّهَ الْعَافِيَةَ فِي الدُّنْيَا وَالآخِرَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَعَبْدُ اللَّهِ بْنُ الْحَارِثِ بْنِ نَوْفَلٍ قَدْ سَمِعَ مِنَ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ ‏.‏\hadithno{3514}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Al-`Abbas bin `Abdul-Muttalib said:“I said: ‘O Messenger of Allah, teach me something that I may ask Allah, [Mighty and Sublime] for.’ He (ﷺ) said: ‘Ask Allah for Al-`Āfiyah.’ Then I remained for a day, then I came and said: ‘O Messenger of Allah, teach me something that I may ask Allah for.’ So he (ﷺ) said to me: “O Abbas, O uncle of the Messenger of Allah! Ask Allah for Al-`Āfiyah in the world and in the Hereafter.”}}
\hadithdefcmd{tirmidhi}{3515}{حَدَّثَنَا الْقَاسِمُ بْنُ دِينَارٍ الْكُوفِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ الْكُوفِيُّ، عَنْ إِسْرَائِيلَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ، وَهُوَ الْمُلَيْكِيُّ عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا سُئِلَ اللَّهُ شَيْئًا أَحَبَّ إِلَيْهِ مِنْ أَنْ يُسْأَلَ الْعَافِيَةَ ‏"‏ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ الْمُلَيْكِيِّ ‏.‏\hadithno{3515}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated that the Messenger of Allah said (ﷺ):“Allah has not been asked for anything more beloved to Him than being asked for Al-`Āfiyah}}
\hadithdefcmd{tirmidhi}{3516}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عُمَرَ بْنِ أَبِي الْوَزِيرِ، حَدَّثَنَا زَنْفَلُ بْنُ عَبْدِ اللَّهِ أَبُو عَبْدِ اللَّهِ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، عَنْ أَبِي بَكْرٍ الصِّدِّيقِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ أَمْرًا قَالَ ‏ "‏ اللَّهُمَّ خِرْ لِي وَاخْتَرْ لِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ زَنْفَلٍ ‏.‏ وَهُوَ ضَعِيفٌ عِنْدَ أَهْلِ الْحَدِيثِ وَيُقَالُ لَهُ زَنْفَلٌ الْعَرَفِيُّ وَكَانَ سَكَنَ عَرَفَاتٍ وَتَفَرَّدَ بِهَذَا الْحَدِيثِ وَلاَ يُتَابَعُ عَلَيْهِ ‏.‏\hadithno{3516}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated from Abu Bakr As-Siddiq,:that whenever the Prophet (ﷺ) wanted to do a matter, he would say: “O Allah, make it good for me and choose for me. (Allāhumma khir lī wakhtar lī)”}}
\hadithdefcmd{tirmidhi}{3517}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا أَبَانُ، هُوَ ابْنُ يَزِيدَ الْعَطَّارُ حَدَّثَنَا يَحْيَى، أَنَّ زَيْدَ بْنَ سَلاَّمٍ، حَدَّثَهُ أَنَّ أَبَا سَلاَّمٍ حَدَّثَهُ عَنْ أَبِي مَالِكٍ الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْوُضُوءُ شَطْرُ الإِيمَانِ وَالْحَمْدُ لِلَّهِ تَمْلأُ الْمِيزَانَ وَسُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ تَمْلآنِ أَوْ تَمْلأُ مَا بَيْنَ السَّمَوَاتِ وَالأَرْضِ وَالصَّلاَةُ نُورٌ وَالصَّدَقَةُ بُرْهَانٌ وَالصَّبْرُ ضِيَاءٌ وَالْقُرْآنُ حُجَّةٌ لَكَ أَوْ عَلَيْكَ كُلُّ النَّاسِ يَغْدُو فَبَائِعٌ نَفْسَهُ فَمُعْتِقُهَا أَوْ مُوبِقُهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3517}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Malik Al-Ash`ari narrated that the Messenger of Allah said:“Al-Wudu is half of faith, and All praise is due to Allah (Al-Ḥamdulillāh) fills the Scale, and Glory is to Allah and all praise is to Allah (Subḥān Allāh wal-Ḥamdulillāh)’ fill” - or - “fills what is between the heavens and the earth, and Salat is light and charity is an evidence, and patience is an illumination, and the Quran is a proof for you or against you. And all people shall come to the morning selling their souls, either setting it free or destroying it.”}}
\hadithdefcmd{tirmidhi}{3518}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ زِيَادِ بْنِ أَنْعُمٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ التَّسْبِيحُ نِصْفُ الْمِيزَانِ وَالْحَمْدُ لِلَّهِ يَمْلَؤُهُ وَلاَ إِلَهَ إِلاَّ اللَّهُ لَيْسَ لَهَا دُونَ اللَّهِ حِجَابٌ حَتَّى تَخْلُصَ إِلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَلَيْسَ إِسْنَادُهُ بِالْقَوِيِّ ‏.‏ وَعَبْدُ الرَّحْمَنِ بْنُ زِيَادِ بْنِ أَنْعُمٍ هُوَ الإِفْرِيقِيُّ وَقَدْ ضَعَّفَهُ أَحْمَدُ بْنُ حَنْبَلٍ وَيَحْيَى بْنُ مَعِينٍ وَعَبْدُ اللَّهِ بْنُ يَزِيدَ هُوَ أَبُو عَبْدِ الرَّحْمَنِ الْحُبُلِيُّ ‏.‏\hadithno{3518}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Amr narrated that the Messenger of Allah said:“At-Tasbīḥ is half of the Scale, and All praise is due to Allah (Al-Ḥamdulillāh)’ fills it, and (as for) None has the right to be worshipped but Allah (Lā Ilāha Illallāh)’ - there is no barrier to it from Allah until it reaches Him.”}}
\hadithdefcmd{tirmidhi}{3519}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ جُرَىٍّ النَّهْدِيِّ، عَنْ رَجُلٍ، مِنْ بَنِي سُلَيْمٍ قَالَ عَدَّهُنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي يَدِي أَوْ فِي يَدِهِ ‏ "‏ التَّسْبِيحُ نِصْفُ الْمِيزَانِ وَالْحَمْدُ يَمْلَؤُهُ وَالتَّكْبِيرُ يَمْلأُ مَا بَيْنَ السَّمَاءِ وَالأَرْضِ وَالصَّوْمُ نِصْفُ الصَّبْرِ وَالطُّهُورُ نِصْفُ الإِيمَانِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَقَدْ رَوَاهُ شُعْبَةُ وَسُفْيَانُ الثَّوْرِيُّ عَنْ أَبِي إِسْحَاقَ ‏.‏\hadithno{3519}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{A man from Banu Sulaim narrated:“The Messenger of Allah (ﷺ) counted them out in my hand” - or - “in his hand: ‘At-Tasbīḥ is half of the Scale, and “All praise is due to Allah (Al-Ḥamdulillāh)” fills it, and At-Takbīr (Allāhu Akbar) fills what is between the sky and the earth, and fasting is half of patience, and purification is half of faith.”}}
\hadithdefcmd{tirmidhi}{3520}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ الْمُؤَدِّبُ، حَدَّثَنَا عَلِيُّ بْنُ ثَابِتٍ، حَدَّثَنِي قَيْسُ بْنُ الرَّبِيعِ، وَكَانَ، مِنْ بَنِي أَسَدٍ عَنِ الأَغَرِّ بْنِ الصَّبَّاحِ، عَنْ خَلِيفَةَ بْنِ حُصَيْنٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ أَكْثَرُ مَا دَعَا بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم عَشِيَّةَ عَرَفَةَ فِي الْمَوْقِفِ ‏ "‏ اللَّهُمَّ لَكَ الْحَمْدُ كَالَّذِي تَقُولُ وَخَيْرًا مِمَّا نَقُولُ اللَّهُمَّ لَكَ صَلاَتِي وَنُسُكِي وَمَحْيَاىَ وَمَمَاتِي وَإِلَيْكَ مَآبِي وَلَكَ رَبِّ تُرَاثِي اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ عَذَابِ الْقَبْرِ وَوَسْوَسَةِ الصَّدْرِ وَشَتَاتِ الأَمْرِ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ شَرِّ مَا تَجِيءُ بِهِ الرِّيحُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَلَيْسَ إِسْنَادُهُ بِالْقَوِيِّ ‏.‏\hadithno{3520}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ali bin Abi Talib said:“The most of what the Messenger of Allah (ﷺ) supplicated with during the afternoon at Arafat while standing was: ‘O Allah to You is the praise like the one You say, and better than what we say. O Allah, for You is all my Salat, my sacrifice, my living and my dying. And to You is my return, and to You, my Lord, belongs my inheritance. O Allah, indeed, I seek refuge in You from the punishment of the grave, the whispering of the chest, and the dividing of the affair. O Allah, indeed, I seek refuge in You from the evil of what the wind brings (Allāhumma lakal-ḥamdu, kalladhī taqūlu, wa khairan mimmā naqūl. Allāhumma laka ṣalātī wa nusukī, wa maḥyāya wa mamātī, ilaika ma’ābī, wa laka, rabbi, turāthī. Allāhumma innī a`ūdhu bika min `adhābil-qabri, wa waswasatiṣ-ṣadri, wa shatātil-amr. Allāhumma innī a`ūdhu bika min sharri mā tajī’u bihir-rīḥ).”}}
\hadithdefcmd{tirmidhi}{3521}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ الْمُؤَدِّبُ، حَدَّثَنَا عَمَّارُ بْنُ مُحَمَّدٍ ابْنُ أُخْتِ، سُفْيَانَ الثَّوْرِيِّ حَدَّثَنَا اللَّيْثُ بْنُ أَبِي سُلَيْمٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَابِطٍ، عَنْ أَبِي أُمَامَةَ، قَالَ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِدُعَاءٍ كَثِيرٍ لَمْ نَحْفَظْ مِنْهُ شَيْئًا قُلْنَا يَا رَسُولَ اللَّهِ دَعَوْتَ بِدُعَاءٍ كَثِيرٍ لَمْ نَحْفَظْ مِنْهُ شَيْئًا ‏.‏ فَقَالَ ‏ "‏ أَلاَ أَدُلُّكُمْ عَلَى مَا يَجْمَعُ ذَلِكَ كُلَّهُ تَقُولُ اللَّهُمَّ إِنَّا نَسْأَلُكَ مِنْ خَيْرِ مَا سَأَلَكَ مِنْهُ نَبِيُّكَ مُحَمَّدٌ وَنَعُوذُ بِكَ مِنْ شَرِّ مَا اسْتَعَاذَ بِكَ مِنْهُ نَبِيُّكَ مُحَمَّدٌ وَأَنْتَ الْمُسْتَعَانُ وَعَلَيْكَ الْبَلاَغُ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3521}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Umamah narrated:“The Messenger of Allah (ﷺ) supplicated with many supplications of which we did not preserve a thing. We said: ‘O Messenger of Allah, you supplicated with many supplications of which we did not preserve a thing.’ He (ﷺ) said: ‘Should I not direct you to what will include all of that? That you say: O Allah, we ask You from the good of what Your Prophet Muhammad (ﷺ) asked You for, and we seek refuge in You from the evil of that which Your Prophet Muhammad (ﷺ) sought refuge in You from, and You are the one from Whom aid is sought, and it is for You to fulfill, and there is no might or power except by Allah (Allāhumma innā nas’aluka min khairi mā sa’alaka minhu nabiyyuka Muḥammad, ṣallallāhu `alaihi wa sallam, wa na`ūdhu bika min sharri masta`ādha minhu nabiyyuka Muḥammad, ṣallallāhu `alaihi wa sallam, wa antal-musta`ānu wa `alaikal-balāgh, wa lā ḥawla wa lā quwwata illā billāh).’”}}
\hadithdefcmd{tirmidhi}{3522}{حَدَّثَنَا أَبُو مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، عَنْ أَبِي كَعْبٍ، صَاحِبِ الْحَرِيرِ حَدَّثَنِي شَهْرُ بْنُ حَوْشَبٍ، قَالَ قُلْتُ لأُمِّ سَلَمَةَ يَا أُمَّ الْمُؤْمِنِينَ مَا كَانَ أَكْثَرُ دُعَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذَا كَانَ عِنْدَكِ قَالَتْ كَانَ أَكْثَرُ دُعَائِهِ ‏"‏ يَا مُقَلِّبَ الْقُلُوبِ ثَبِّتْ قَلْبِي عَلَى دِينِكَ ‏"‏ ‏.‏ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ مَا لأَكْثَرِ دُعَائِكَ يَا مُقَلِّبَ الْقُلُوبِ ثَبِّتْ قَلْبِي عَلَى دِينِكَ قَالَ ‏"‏ يَا أُمَّ سَلَمَةَ إِنَّهُ لَيْسَ آدَمِيٌّ إِلاَّ وَقَلْبُهُ بَيْنَ أُصْبُعَيْنِ مِنْ أَصَابِعِ اللَّهِ فَمَنْ شَاءَ أَقَامَ وَمَنْ شَاءَ أَزَاغَ ‏"‏ ‏.‏ فَتَلاَ مُعَاذٌ ‏:‏ ‏(‏ ربَّنَا لاَ تُزِغْ قُلُوبَنَا بَعْدَ إِذْ هَدَيْتَنَا ‏)‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَالنَّوَّاسِ بْنِ سَمْعَانَ وَأَنَسٍ وَجَابِرٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَنُعَيْمِ بْنِ هَمَّارٍ ‏.‏ قَالَ وَهَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{3522}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Shahr bin Hawshab said:“I said to Umm Salamah: ‘O Mother of the Believers! What was the supplication that the Messenger of Allah (ﷺ) said most frequently when he was with you?” She said: ‘The supplication he said most frequently was: “O Changer of the hearts, make my heart firm upon Your religion (Yā Muqallibal-qulūb, thabbit qalbī `alā dīnik).’” She said: ‘So I said: “O Messenger of Allah, why do you supplicate so frequently: ‘O Changer of the hearts, make my heart firm upon Your religion.’ He said: ‘O Umm Salamah! Verily, there is no human being except that his heart is between Two Fingers of the Fingers of Allah, so whomsoever He wills He makes steadfast, and whomever He wills He causes to deviate.’”}}
\hadithdefcmd{tirmidhi}{3523}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ الْمُؤَدِّبُ، حَدَّثَنَا الْحَكَمُ بْنُ ظُهَيْرٍ، حَدَّثَنَا عَلْقَمَةُ بْنُ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ شَكَا خَالِدُ بْنُ الْوَلِيدِ الْمَخْزُومِيُّ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ مَا أَنَامُ اللَّيْلَ مِنَ الأَرَقِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِذَا أَوَيْتَ إِلَى فِرَاشِكَ فَقُلِ اللَّهُمَّ رَبَّ السَّمَوَاتِ السَّبْعِ وَمَا أَظَلَّتْ وَرَبَّ الأَرَضِينَ وَمَا أَقَلَّتْ وَرَبَّ الشَّيَاطِينِ وَمَا أَضَلَّتْ كُنْ لِي جَارًا مِنْ شَرِّ خَلْقِكَ كُلِّهِمْ جَمِيعًا أَنْ يَفْرُطَ عَلَىَّ أَحَدٌ مِنْهُمْ أَوْ أَنْ يَبْغِيَ عَلَىَّ عَزَّ جَارُكَ وَجَلَّ ثَنَاؤُكَ وَلاَ إِلَهَ غَيْرُكَ وَلاَ إِلَهَ إِلاَّ أَنْتَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ لَيْسَ إِسْنَادُهُ بِالْقَوِيِّ ‏.‏ وَالْحَكَمُ بْنُ ظُهَيْرٍ قَدْ تَرَكَ حَدِيثَهُ بَعْضُ أَهْلِ الْحَدِيثِ وَيُرْوَى هَذَا الْحَدِيثُ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏\hadithno{3523}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Sulaiman bin Buraidah narrated that his father said:“Khalid bin Al-Walid al Makhzumi complained to the Prophet (ﷺ) saying: ‘O Messenger of Allah, I do not sleep at night due to insomnia.’ So Allah’s Prophet (ﷺ) said: ‘When you go to your bed, say: O Allah, Lord of the Seven Heavens and what they have shaded, Lord of the earths and what they carry, Lord of the Shayatin and those they have misguided, be for me a Protector against the evil of Your creation, all of them together, so that none of them should transgress against me, or oppress me, mighty is the one who seeks protection in You, and glorified is Your praise, and there is none worthy of worship other than You, and there is none worthy of worship except You. (Allāhumma rabbas-samāwātis-sab`i wa mā aẓallat, wa rabbal-arḍīna wa mā aqallat, wa rabbash-shayāṭīni wa mā aḍallat, kun lī jāran min sharri khalqika kullihim jamī`an an yafruṭa `alayya aḥadun minhum, aw an yabghiya `alayya, `azza jāruka wa jalla thanā’uka, wa lā ilāha ghairuka wa lā ilāha illā anta).”}}
\hadithdefcmd{tirmidhi}{3524}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ الْمُكْتِبُ، حَدَّثَنَا أَبُو بَدْرٍ، شُجَاعُ بْنُ الْوَلِيدِ عَنِ الرُّحَيْلِ بْنِ مُعَاوِيَةَ، أَخِي زُهَيْرِ بْنِ مُعَاوِيَةَ عَنِ الرَّقَاشِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا كَرَبَهُ أَمْرٌ قَالَ ‏"‏ يَا حَىُّ يَا قَيُّومُ بِرَحْمَتِكَ أَسْتَغِيثُ ‏"‏ ‏.‏ وَبِإِسْنَادِهِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلِظُّوا بِيَا ذَا الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ أَنَسٍ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏\hadithno{3524}\hadithgrade{Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Anas bin Malik said:“Whenever a matter would distress him, the Prophet (ﷺ) would say: ‘O Living, O Self-Sustaining Sustainer! In Your Mercy do I seek relief (Yā Ḥayyu yā Qayyūm, bi-raḥmatika astaghīth).’” And with this chain, that he said: “The Messenger of Allah (ﷺ) said: ‘Be constant with: “O Possessor of Majesty and Honor (Yā Dhal-Jalāli wal-Ikrām).’”}}
\hadithdefcmd{tirmidhi}{3525}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا الْمُؤَمِّلُ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَلِظُّوا بِيَا ذَا الْجَلاَلِ وَالإِكْرَامِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ وَلَيْسَ بِمَحْفُوظٍ ‏.‏ وَإِنَّمَا يُرْوَى هَذَا عَنْ حَمَّادِ بْنِ سَلَمَةَ عَنْ حُمَيْدٍ عَنِ الْحَسَنِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَهَذَا أَصَحُّ وَمُؤَمِّلٌ غَلِطَ فِيهِ فَقَالَ عَنْ حَمَّادٍ عَنْ حُمَيْدٍ عَنْ أَنَسٍ وَلاَ يُتَابَعُ فِيهِ ‏.‏\hadithno{3525}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas narrated that the Prophet (ﷺ) said:“Be constant with: ‘O Possessor of Majesty and Honor (Yā Dhal-Jalāli wal-Ikrām).’”}}
\hadithdefcmd{tirmidhi}{3526}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي حُسَيْنٍ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي أُمَامَةَ الْبَاهِلِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَوَى إِلَى فِرَاشِهِ طَاهِرًا يَذْكُرُ اللَّهَ حَتَّى يُدْرِكَهُ النُّعَاسُ لَمْ يَنْقَلِبْ سَاعَةً مِنَ اللَّيْلِ يَسْأَلُ اللَّهَ شَيْئًا مِنْ خَيْرِ الدُّنْيَا وَالآخِرَةِ إِلاَّ أَعْطَاهُ اللَّهُ إِيَّاهُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رُوِيَ هَذَا أَيْضًا عَنْ شَهْرِ بْنِ حَوْشَبٍ عَنْ أَبِي ظَبْيَةَ عَنْ عَمْرِو بْنِ عَبَسَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3526}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Umamah Al-Bahili said:“I heard the Messenger of Allah (ﷺ) saying: “Whoever goes to his bed while in a state of purity and remembering Allah, until slumber overtakes him, he shall not get up at any hour of the night and ask Allah for something from the good of the world and the Hereafter except that Allah shall grant it to him.’”}}
\hadithdefcmd{tirmidhi}{3527}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي الْوَرْدِ، عَنِ اللَّجْلاَجِ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ سَمِعَ النَّبِيُّ صلى الله عليه وسلم رَجُلاً يَدْعُو يَقُولُ اللَّهُمَّ إِنِّي أَسْأَلُكَ تَمَامَ النِّعْمَةِ ‏.‏ فَقَالَ ‏"‏ أَىُّ شَيْءٍ تَمَامُ النِّعْمَةِ ‏"‏ ‏.‏ قَالَ دَعْوَةٌ دَعَوْتُ بِهَا أَرْجُو بِهَا الْخَيْرَ ‏.‏ قَالَ ‏"‏ فَإِنَّ مِنْ تَمَامِ النِّعْمَةِ دُخُولَ الْجَنَّةِ وَالْفَوْزَ مِنَ النَّارِ ‏"‏ ‏.‏ وَسَمِعَ رَجُلاً وَهُوَ يَقُولُ يَا ذَا الْجَلاَلِ وَالإِكْرَامِ فَقَالَ ‏"‏ قَدِ اسْتُجِيبَ لَكَ فَسَلْ ‏"‏ ‏.‏ وَسَمِعَ النَّبِيُّ صلى الله عليه وسلم رَجُلاً وَهُوَ يَقُولُ اللَّهُمَّ إِنِّي أَسْأَلُكَ الصَّبْرَ ‏.‏ فَقَالَ ‏"‏ سَأَلْتَ اللَّهَ الْبَلاَءَ فَسَلْهُ الْعَافِيَةَ ‏"‏ ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنِ الْجُرَيْرِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{3527}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Mu`adh bin Jabal narrated that the Prophet (ﷺ) heard a man supplicating, saying:"O Allah! Verily, I ask You for the bounty's completion (Allāhumma, innī as'aluka tamāman-ni`mah)." So he (ﷺ) said: "What thing is the bounty's completion?" He said: "A supplication that I made, that I hope for good by it." He (ﷺ) said: "Indeed, part of the bounty's completion is the entrance into Paradise, and salvation from the Fire." And he (ﷺ) heard a man while he was saying: "O Possessor of Majesty and Honor (Yā Dhal-Jalāli wal-Ikrām)" So he (ﷺ) said: "You have been responded to, so ask." And the Prophet (ﷺ) heard a man while he was saying: "O Allah, indeed, I ask You for patience (Allāhumma, innī as'alukaṣ-ṣabr)" He (ﷺ) said: "You have asked Allah for trial, so ask him for Al-`Āfiyah}}
\hadithdefcmd{tirmidhi}{3528}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا فَزِعَ أَحَدُكُمْ فِي النَّوْمِ فَلْيَقُلْ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّةِ مِنْ غَضَبِهِ وَعِقَابِهِ وَشَرِّ عِبَادِهِ وَمِنْ هَمَزَاتِ الشَّيَاطِينِ وَأَنْ يَحْضُرُونِ ‏.‏ فَإِنَّهَا لَنْ تَضُرَّهُ ‏"‏ ‏.‏ قَالَ وَكَانَ عَبْدُ اللَّهِ بْنُ عَمْرٍو يُلَقِّنُهَا مَنْ بَلَغَ مِنْ وَلَدِهِ وَمَنْ لَمْ يَبْلُغْ مِنْهُمْ كَتَبَهَا فِي صَكٍّ ثُمَّ عَلَّقَهَا فِي عُنُقِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3528}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Amr bin Shu`aib narrated from his father, from his grandfather, that the Messenger of Allah (ﷺ) said:“When one of you becomes frightened during sleep, then let him say: ‘I seek refuge in Allah’s Perfect Words from His anger, His punishment, and the evil of His creatures, from the whisperings of the Shayatin, and that they should come (A`ūdhu bikalimātillāhit-tāmmati min ghaḍabihī wa `iqābihī wa sharri `ibādih, wa min hamazātish-shayāṭīni wa an yaḥḍurūn).’ For verily, they shall not harm him.” He said: “So `Abdullah bin `Amr used to teach it to those of his children who attained maturity, and those of them who did not, he would write it on a sheet and then hang it around his neck.”}}
\hadithdefcmd{tirmidhi}{3529}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي رَاشِدٍ الْحُبْرَانِيِّ، قَالَ أَتَيْتُ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِي فَقُلْتُ لَهُ حَدِّثْنَا مِمَّا، سَمِعْتَ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَأَلْقَى إِلَىَّ صَحِيفَةً فَقَالَ هَذَا مَا كَتَبَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ فَنَظَرْتُ فِيهَا فَإِذَا فِيهَا إِنَّ أَبَا بَكْرٍ الصِّدِّيقَ رضى الله عنه قَالَ يَا رَسُولَ اللَّهِ عَلِّمْنِي مَا أَقُولُ إِذَا أَصْبَحْتُ وَإِذَا أَمْسَيْتُ ‏.‏ فَقَالَ ‏ "‏ يَا أَبَا بَكْرٍ قُلِ اللَّهُمَّ فَاطِرَ السَّمَوَاتِ وَالأَرْضِ عَالِمَ الْغَيْبِ وَالشَّهَادَةِ لاَ إِلَهَ إِلاَّ أَنْتَ رَبَّ كُلِّ شَيْءٍ وَمَلِيكَهُ أَعُوذُ بِكَ مِنْ شَرِّ نَفْسِي وَمِنْ شَرِّ الشَّيْطَانِ وَشَرَكِهِ وَأَنْ أَقْتَرِفَ عَلَى نَفْسِي سُوءًا أَوْ أَجُرَّهُ إِلَى مُسْلِمٍ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3529}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Rashid Al-Hubrani said:“I came to `Abdullah bin `Amr and said to him: ‘Report something to me that you heard from the Messenger of Allah (ﷺ).’ So he set forth before me a scroll and said: ‘This is what the Messenger of Allah (ﷺ) wrote for me.’” He said: “So I looked in it and found in it: ‘Indeed, Abu Bakr As-Siddiq, may Allah be pleased with him, said: “O Messenger of Allah, teach me what to say at morning and afternoon.” He said: “O Abu Bakr, say: ‘O Allah, Creator of the heavens and the earth, Knower of the unseen and the seen, there is none worthy of worship except You, Lord of everything and its Owner, I seek refuge in You from the evil of my soul and from the evil of Shaitan and his Shirk, or that I should do some evil to myself or bring it upon a Muslim (Allāhumma fāṭiras-samāwāti wal-arḍi, `ālimal-ghaibi wash-shahādati, lā ilāha illā anta, rabba kulli shai’in wa malīkahu, a`ūdhu bika min sharri nafsī wa min sharrish-shaiṭāni wa sharakihi, wa an aqtarifa `alā nafsī sū’an, aw ajurrahu ilā muslim).’”}}
\hadithdefcmd{tirmidhi}{3530}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، يَقُولُ قُلْتُ لَهُ أَأَنْتَ سَمِعْتَهُ مِنْ عَبْدِ اللَّهِ، قَالَ نَعَمْ ‏.‏ وَرَفَعَهُ أَنَّهُ قَالَ ‏ "‏ لاَ أَحَدَ أَغْيَرُ مِنَ اللَّهِ وَلِذَلِكَ حَرَّمَ الْفَوَاحِشَ مَا ظَهَرَ مِنْهَا وَمَا بَطَنَ وَلاَ أَحَدَ أَحَبُّ إِلَيْهِ الْمَدْحُ مِنَ اللَّهِ وَلِذَلِكَ مَدَحَ نَفْسَهُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3530}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Amr bin Murrah said:“I heard Abu Wa’il say: ‘`Abdullah bin Mas`ud said’ and I said to him: ‘Did you hear it from `Abdullah?’ He said: ‘Yes.’ And he narrated it in Marfu` form that he said: ‘There is none with more Ghirah than Allah, and due to this He prohibited the lewd sins, that which is apparent of them and that which is hidden. And there is none to whom praise is more beloved than Allah, and due to this, He praised Himself.’”}}
\hadithdefcmd{tirmidhi}{3531}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، عَنْ أَبِي بَكْرٍ الصِّدِّيقِ، أَنَّهُ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم عَلِّمْنِي دُعَاءً أَدْعُو بِهِ فِي صَلاَتِي قَالَ ‏ "‏ قُلِ اللَّهُمَّ إِنِّي ظَلَمْتُ نَفْسِي ظُلْمًا كَثِيرًا وَلاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ فَاغْفِرْ لِي مَغْفِرَةً مِنْ عِنْدِكَ وَارْحَمْنِي إِنَّكَ أَنْتَ الْغَفُورُ الرَّحِيمُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ وَهُوَ حَدِيثُ لَيْثِ بْنِ سَعْدٍ وَأَبُو الْخَيْرِ اسْمُهُ مَرْثَدُ بْنُ عَبْدِ اللَّهِ الْيَزَنِيُّ ‏.‏\hadithno{3531}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdullah bin `Amr narrated from Abu Bakr As-Siddiq that he said:“O Messenger of Allah, teach me a supplication that I may supplicate with in my Salat.” He (ﷺ) said: “Say: ‘O Allah, I have wronged myself much, and none forgives sins except You. So forgive me with forgiveness from You, and have mercy upon me, indeed, You are the Forgiving, the Merciful (Allāhumma innī ẓalamtu nafsī ẓulman kathīran wa lā yaghfirudh-dhunūba illā anta faghfirlī maghfiratan min `indika warḥamnī innaka antal-Ghafūrur-Raḥīm).’”}}
\hadithdefcmd{tirmidhi}{3532}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلَانَ حَدَّثَنَا أَبُو أَحْمَدَ حَدَّثَنَا سُفْيَانُ عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ عَنْ الْمُطَّلِبِ بْنِ أَبِي وَدَاعَةَ قَالَ جَاءَ الْعَبَّاسُ إِلَى رَسُولِ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ فَكَأَنَّهُ سَمِعَ شَيْئًا فَقَامَ النَّبِيُّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ عَلَى الْمِنْبَرِ فَقَالَ مَنْ أَنَا فَقَالُوا أَنْتَ رَسُولُ اللَّهِ عَلَيْكَ السَّلَامُ قَالَ أَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عَبْدِ الْمُطَّلِبِ إِنَّ اللَّهَ خَلَقَ الْخَلْقَ فَجَعَلَنِي فِي خَيْرِهِمْ فِرْقَةً ثُمَّ جَعَلَهُمْ فِرْقَتَيْنِ فَجَعَلَنِي فِي خَيْرِهِمْ فِرْقَةً ثُمَّ جَعَلَهُمْ قَبَائِلَ فَجَعَلَنِي فِي خَيْرِهِمْ قَبِيلَةً ثُمَّ جَعَلَهُمْ بُيُوتًا فَجَعَلَنِي فِي خَيْرِهِمْ بَيْتًا وَخَيْرِهِمْ نَسَبًا قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ\hadithno{3532}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Al-Muttalib bin Abi Wada`ah said:“Al-`Abbas came to the Messenger of Allah (ﷺ) and it is as if he heard something, so the Prophet (ﷺ) stood upon the Minbar and said: ‘Who am I?’ They said: ‘You are the Messenger of Allah, upon you be peace.’ He said: ‘I am Muhammad bin `Abdullah bin `Abdul-Muttalib, indeed Allah created the creation, and He put me in the best group of them, then He made them into two groups, so He put me in the best group of them, the He made them into tribes, so He put me in the best of tribes, then He made them into houses, so He put me in the best of them in tribe and lineage.’”}}
\hadithdefcmd{tirmidhi}{3533}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ الرَّازِيُّ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الأَعْمَشِ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِشَجَرَةٍ يَابِسَةِ الْوَرَقِ فَضَرَبَهَا بِعَصَاهُ فَتَنَاثَرَ الْوَرَقُ فَقَالَ ‏ "‏ إِنَّ الْحَمْدَ لِلَّهِ وَسُبْحَانَ اللَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ لَتُسَاقِطُ مِنْ ذُنُوبِ الْعَبْدِ كَمَا تَسَاقَطَ وَرَقُ هَذِهِ الشَّجَرَةِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَلاَ نَعْرِفُ لِلأَعْمَشِ سَمَاعًا مِنْ أَنَسٍ إِلاَّ أَنَّهُ قَدْ رَآهُ وَنَظَرَ إِلَيْهِ ‏.‏\hadithno{3533}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Anas bin Malik narrated that:the Prophet (ﷺ) passed by a tree with dry leaves, so he struck it with his staff, making the leaves fall. Then he said: “Indeed, ‘all praise is due to Allah, (Al-Ḥamdulillāhh)’ ‘glory to Allah, (Subḥān Allāh)’ ‘none has the right to be worshipped by Allah, (Lā Ilāha Illallāh)’ and ‘Allah is the greatest (Allāhu Akbar)’ cause the sins to fall from the worshipper, just as the leaves of this tree fall.”}}
\hadithdefcmd{tirmidhi}{3534}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ الْجُلاَحِ أَبِي كَثِيرٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ عُمَارَةَ بْنِ شَبِيبٍ السَّبَئِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ يُحْيِي وَيُمِيتُ وَهُوَ عَلَى كُلِّ شَيْءٍ قَدِيرٌ ‏.‏ عَشْرَ مَرَّاتٍ عَلَى إِثْرِ الْمَغْرِبِ بَعَثَ اللَّهُ لَهُ مَسْلَحَةً يَحْفَظُونَهُ مِنَ الشَّيْطَانِ حَتَّى يُصْبِحَ وَكَتَبَ اللَّهُ لَهُ بِهَا عَشْرَ حَسَنَاتٍ مُوجِبَاتٍ وَمَحَا عَنْهُ عَشْرَ سَيِّئَاتٍ مُوبِقَاتٍ وَكَانَتْ لَهُ بِعَدْلِ عَشْرِ رِقَابٍ مُؤْمِنَاتٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ لَيْثِ بْنِ سَعْدٍ ‏.‏ وَلاَ نَعْرِفُ لِعُمَارَةَ بْنِ شَبِيبٍ سَمَاعًا عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3534}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Umarah bin Shabib As-Saba’i narrated that the Messenger of Allah (ﷺ) said:“Whoever says: none has the right to be worshipped but Allah, Alone, without partner, to Him belongs all that exists, and to Him belongs the praise, He gives life and causes death, and He is powerful over all things, (Lā ilāha illallāh, waḥdahu lā sharīka lahu, lahul-mulku wa lahul-ḥamdu, yuḥyī wa yumītu, wa huwa `alā kulli shai’in qadīr)’ ten times at the end of Al-Maghrib - Allah shall send for him protectors to guard him from Shaitan until he reaches morning, and Allah writes for him ten good deeds, Mujibat, and He wipes from him ten of the destructive evil deeds, and it shall be for him the equal of freeing ten believing slaves.”}}
\hadithdefcmd{tirmidhi}{3535}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ أَبِي النَّجُودِ، عَنْ زِرِّ بْنِ حُبَيْشٍ، قَالَ أَتَيْتُ صَفْوَانَ بْنَ عَسَّالٍ الْمُرَادِيَّ أَسْأَلُهُ عَنِ الْمَسْحِ، عَلَى الْخُفَّيْنِ فَقَالَ مَا جَاءَ بِكَ يَا زِرُّ فَقُلْتُ ابْتِغَاءَ الْعِلْمِ فَقَالَ إِنَّ الْمَلاَئِكَةَ تَضَعُ أَجْنِحَتَهَا لِطَالِبِ الْعِلْمِ رِضًا بِمَا يَطْلُبُ ‏.‏ قُلْتُ إِنَّهُ حَكَّ فِي صَدْرِي الْمَسْحُ عَلَى الْخُفَّيْنِ بَعْدَ الْغَائِطِ وَالْبَوْلِ وَكُنْتَ امْرَأً مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فَجِئْتُ أَسْأَلُكَ هَلْ سَمِعْتَهُ يَذْكُرُ فِي ذَلِكَ شَيْئًا قَالَ نَعَمْ كَانَ يَأْمُرُنَا إِذَا كُنَّا سَفَرًا أَوْ مُسَافِرِيِنَ أَنْ لاَ نَنْزِعَ خِفَافَنَا ثَلاَثَةَ أَيَّامٍ وَلَيَالِيَهُنَّ إِلاَّ مِنْ جَنَابَةٍ لَكِنْ مِنْ غَائِطٍ وَبَوْلٍ وَنَوْمٍ ‏.‏ فَقُلْتُ هَلْ سَمِعْتَهُ يَذْكُرُ فِي الْهَوَى شَيْئًا قَالَ نَعَمْ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ فَبَيْنَا نَحْنُ عِنْدَهُ إِذْ نَادَاهُ أَعْرَابِيٌّ بِصَوْتٍ لَهُ جَهْوَرِيٍّ يَا مُحَمَّدُ ‏.‏ فَأَجَابَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى نَحْوٍ مِنْ صَوْتِهِ هَاؤُمُ وَقُلْنَا لَهُ وَيْحَكَ اغْضُضْ مِنْ صَوْتِكَ فَإِنَّكَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم وَقَدْ نُهِيتَ عَنْ هَذَا ‏.‏ فَقَالَ وَاللَّهِ لاَ أَغْضُضُ ‏.‏ قَالَ الأَعْرَابِيُّ الْمَرْءُ يُحِبُّ الْقَوْمَ وَلَمَّا يَلْحَقْ بِهِمْ ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ الْمَرْءُ مَعَ مَنْ أَحَبَّ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ فَمَازَالَ يُحَدِّثُنَا حَتَّى ذَكَرَ بَابًا مِنْ قِبَلِ الْمَغْرِبِ مَسِيرَةُ عَرْضِهِ أَوْ يَسِيرُ الرَّاكِبُ فِي عَرْضِهِ أَرْبَعِينَ أَوْ سَبْعِينَ عَامًا قَالَ سُفْيَانُ قِبَلَ الشَّامِ خَلَقَهُ اللَّهُ يَوْمَ خَلَقَ السَّمَوَاتِ وَالأَرْضَ مَفْتُوحًا يَعْنِي لِلتَّوْبَةِ لاَ يُغْلَقُ حَتَّى تَطْلُعَ الشَّمْسُ مِنْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3535}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Zirr bin Hubaish said:“I came to Safwan bin `Assal Al Muradi to ask him about wiping over the Khuff, so he said: ‘What has brought you, O Zirr?’ So I said: ‘The desire for knowledge.’ So he said: ‘Indeed, the angels lower their wings for the seeker of knowledge, out of pleasure with what he is seeking.’ So I said: ‘Indeed there is some doubt in my chest concerning wiping over the Khuff after defecation and urination, and you were a man from the Companions of the Prophet (ﷺ), so I came to you to ask you: Have you heard him (ﷺ) mention anything concerning that?’ He said: ‘Yes, he (ﷺ) used to order us, that when we were travelers’ - or - ‘in travel, to not remove our Khuff for three days and nights except, from sexual impurity, but not from defecation, urination, and sleep.’” He said: “Have you heard him (ﷺ) mention anything concerning love?” He said: “Yes. We were with the Messenger of Allah (ﷺ) on a journey when a Bedouin with a loud voice called upon him (saying): ‘O Muhammad!’ So the Messenger of Allah (ﷺ) responded to him with a voice similar to him (saying): ‘Come.’ So we said to him: ‘Lower your voice for you are with the Prophet (ﷺ), and you have been prohibited from this.’ He said: ‘By Allah, I will not lower (my voice).’ The Bedouin said: ‘A man loves a people but he is not with them (in terms of deeds)?’ He (ﷺ) said: ‘A man is with whomever he loves on the Day of Judgement.’” So he did not cease talking with us, until he mentioned a gate in the direction of the west with the width of seventy years journey - or a rider would travel its width - for forty or seventy years.” Sufyan (one of the narrators) said: “In the direction of Ash-Sham, Allah created it the Day He created the heavens and the earth, open - that is, for repentance. It shall not be locked until the sun rises through it.”}}
\hadithdefcmd{tirmidhi}{3536}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَاصِمٍ، عَنْ زِرِّ بْنِ حُبَيْشٍ، قَالَ أَتَيْتُ صَفْوَانَ بْنَ عَسَّالٍ الْمُرَادِيَّ فَقَالَ لِي مَا جَاءَ بِكَ قُلْتُ ابْتِغَاءَ الْعِلْمِ ‏.‏ قَالَ بَلَغَنِي أَنَّ الْمَلاَئِكَةَ تَضَعُ أَجْنِحَتَهَا لِطَالِبِ الْعِلْمِ رِضًا بِمَا يَفْعَلُ ‏.‏ قَالَ قُلْتُ إِنَّهُ حَاكَ أَوْ قَالَ حَكَّ فِي نَفْسِي شَيْءٌ مِنَ الْمَسْحِ عَلَى الْخُفَّيْنِ فَهَلْ حَفِظْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِيهِ شَيْئًا قَالَ نَعَمْ كُنَّا إِذَا كُنَّا سَفَرًا أَوْ مُسَافِرِينَ أُمِرْنَا أَنْ لاَ نَخْلَعَ خِفَافَنَا ثَلاَثًا إِلاَّ مِنْ جَنَابَةٍ وَلَكِنْ مِنْ غَائِطٍ وَبَوْلٍ وَنَوْمٍ ‏.‏ قَالَ فَقُلْتُ فَهَلْ حَفِظْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْهَوَى شَيْئًا قَالَ نَعَمْ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ أَسْفَارِهِ فَنَادَاهُ رَجُلٌ كَانَ فِي آخِرِ الْقَوْمِ بِصَوْتٍ جَهْوَرِيٍّ أَعْرَابِيٌّ جِلْفٌ جَافٍ فَقَالَ يَا مُحَمَّدُ يَا مُحَمَّدُ ‏.‏ فَقَالَ لَهُ الْقَوْمُ مَهْ إِنَّكَ قَدْ نُهِيتَ عَنْ هَذَا ‏.‏ فَأَجَابَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم نَحْوًا مِنْ صَوْتِهِ هَاؤُمُ فَقَالَ الرَّجُلُ يُحِبُّ الْقَوْمَ وَلَمَّا يَلْحَقْ بِهِمْ ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْمَرْءُ مَعَ مَنْ أَحَبَّ ‏"‏ ‏.‏ قَالَ زِرٌّ فَمَا بَرِحَ يُحَدِّثُنِي حَتَّى حَدَّثَنِي أَنَّ اللَّهَ جَعَلَ بِالْمَغْرِبِ بَابًا عَرْضُهُ مَسِيرَةُ سَبْعِينَ عَامًا لِلتَّوْبَةِ لاَ يُغْلَقُ حَتَّى تَطْلُعَ الشَّمْسُ مِنْ قِبَلِهِ وَذَلِكَ قَوْلُ اللَّهِ عَزَّ وَجَلَّْ ‏:‏ ‏(‏ يومَ يَأْتِي بَعْضُ آيَاتِ رَبِّكَ لاَ يَنْفَعُ نَفْسًا إِيمَانُهَا ‏)‏ الآيَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3536}\hadithgrade{Ahmad Muhammad Shakir: Hasan Isnaad; Al-Albani: Hasan Isnaad; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Zirr bin Hubaish said:“I came to Safwan bin `Assal Al-Muradi so he said to me: ‘What has brought you, O Zirr?’ So I said: ‘The desire for knowledge.’ So he said: ‘It has been conveyed to me that the angels lower their wings for the seeker of knowledge, out of pleasure with what he is doing.’” He said: “So I said to him: ‘Indeed there is something wavering’ - or - ‘some doubt in my chest concerning wiping over the Khuff after defecation. So have you retained anything from the Messenger of Allah (ﷺ) concerning that?’ He said: ‘Yes, when we were travelers, he (ﷺ) used to order us not to remove our Khuff for three days and nights, except from sexual impurity, but not from defecation, urination, and sleep.’” He said: “So I said: ‘So have you memorized anything from the Messenger of Allah (ﷺ) concerning love?’ He said: ‘Yes, we were in one of our journeys with the Messenger of Allah (ﷺ) when a man, a harsh, foolish Bedouin, who had been at the end of the group, called him with a loud voice, saying: “O Muhammad! O Muhammad!” So the people said to him “Mah! Indeed, you have been prohibited from this.” So the Messenger of Allah (ﷺ) responded to him with similar to his voice: “Come.” So he said: “A man loves a people but he has not reached them?” He said: ‘So the Messenger of Allah (ﷺ) said: “A man is with whomever he loves.”’ Zirr said: “He did not cease reporting to me until he had reported that Allah, the Mighty and Sublime, has appointed a gate in the west - its width is the distance of a seventy-year journey - for repentance: it shall not be locked until the sun rises from its direction, and that is the Statement of Allah, Blessed be He and Most High, of the Ayah: The Day some of the signs of your Lord come, no soul shall be benefited by its believing.”}}
\hadithdefcmd{tirmidhi}{3537}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ يَعْقُوبَ، حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ ثَابِتِ بْنِ ثَوْبَانَ، عَنْ أَبِيهِ، عَنْ مَكْحُولٍ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ يَقْبَلُ تَوْبَةَ الْعَبْدِ مَا لَمْ يُغَرْغِرْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ ثَابِتِ بْنِ ثَوْبَانَ، عَنْ أَبِيهِ، عَنْ مَكْحُولٍ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِمَعْنَاهُ ‏.‏\hadithno{3537}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ibn `Umar narrated that the Prophet (ﷺ) said:“Indeed Allah accepts the repentance of a slave as long as (his soul does not reach his throat).”}}
\hadithdefcmd{tirmidhi}{3538}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَلَّهُ أَفْرَحُ بِتَوْبَةِ أَحَدِكُمْ مِنْ أَحَدِكُمْ بِضَالَّتِهِ إِذَا وَجَدَهَا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَالنُّعْمَانِ بْنِ بَشِيرٍ وَأَنَسٍ ‏.‏ قَالَ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ أَبِي الزِّنَادِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيث�� عَنْ مَكْحُولٍ بِإِسْنَادٍ لَهُ عَنْ أَبِي ذَرٍّ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا ‏.‏\hadithno{3538}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“Allah is more delighted with the repentance of one of you, than one of you is, when finding his lost animal.”}}
\hadithdefcmd{tirmidhi}{3539}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ مُحَمَّدِ بْنِ قَيْسٍ، قَاصِّ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ عَنْ أَبِي صِرْمَةَ، عَنْ أَبِي أَيُّوبَ، أَنَّهُ قَالَ حِينَ حَضَرَتْهُ الْوَفَاةُ قَدْ كَتَمْتُ عَنْكُمْ شَيْئًا سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَوْلاَ أَنَّكُمْ تُذْنِبُونَ لَخَلَقَ اللَّهُ خَلْقًا يُذْنِبُونَ وَيَغْفِرُ لَهُمْ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رُوِيَ هَذَا، عَنْ مُحَمَّدِ بْنِ كَعْبٍ، عَنْ أَبِي أَيُّوبَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ حَدَّثَنَا بِذَلِكَ، قُتَيْبَةُ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي الرِّجَالِ، عَنْ عُمَرَ، مَوْلَى غَفْرَةَ عَنْ مُحَمَّدِ بْنِ كَعْبٍ، عَنْ أَبِي أَيُّوبَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{3539}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Sirmah narrated from Abu Ayyub, that:when death reached him, he said: “I have concealed something I heard from the Messenger of Allah (ﷺ) from you. I heard the Messenger of Allah (ﷺ) saying: ‘If you did not sin, Allah would create a creation that would sin, so He will forgive them.’”}}
\hadithdefcmd{tirmidhi}{3540}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِسْحَاقَ الْجَوْهَرِيُّ الْبَصْرِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا كَثِيرُ بْنُ فَائِدٍ، حَدَّثَنَا سَعِيدُ بْنُ عُبَيْدٍ، قَالَ سَمِعْتُ بَكْرَ بْنَ عَبْدِ اللَّهِ الْمُزَنِيَّ، يَقُولُ حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ قَالَ اللَّهُ يَا ابْنَ آدَمَ إِنَّكَ مَا دَعَوْتَنِي وَرَجَوْتَنِي غَفَرْتُ لَكَ عَلَى مَا كَانَ فِيكَ وَلاَ أُبَالِي يَا ابْنَ آدَمَ لَوْ بَلَغَتْ ذُنُوبُكَ عَنَانَ السَّمَاءِ ثُمَّ اسْتَغْفَرْتَنِي غَفَرْتُ لَكَ وَلاَ أُبَالِي يَا ابْنَ آدَمَ إِنَّكَ لَوْ أَتَيْتَنِي بِقُرَابِ الأَرْضِ خَطَايَا ثُمَّ لَقِيتَنِي لاَ تُشْرِكُ بِي شَيْئًا لأَتَيْتُكَ بِقُرَابِهَا مَغْفِرَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3540}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah (ﷺ) said:“Allah, Blessed is He and Most High, said: ‘O son of Adam! Verily as long as you called upon Me and hoped in Me, I forgave you, despite whatever may have occurred from you, and I did not mind. O son of Adam! Were your sins to reach the clouds of the sky, then you sought forgiveness from Me, I would forgive you, and I would not mind. So son of Adam! If you came to me with sins nearly as great as the earth, and then you met Me not associating anything with Me, I would come to you with forgiveness nearly as great as it.’”}}
\hadithdefcmd{tirmidhi}{3541}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَلَقَ اللَّهُ مِائَةَ رَحْمَةٍ فَوَضَعَ رَحْمَةً وَاحِدَةً بَيْنَ خَلْقِهِ يَتَرَاحَمُونَ بِهَا وَعِنْدَ اللَّهِ تِسْعَةٌ وَتِسْعُونَ رَحْمَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ سَلْمَانَ وَجُنْدَبِ بْنِ عَبْدِ اللَّهِ بْنِ سُفْيَانَ الْبَجَلِيِّ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3541}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“Allah created a hundred mercies, and He placed one mercy among his creation, they show mercy to one another by it, and there are ninety-nine mercies with Allah.”}}
\hadithdefcmd{tirmidhi}{3542}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ يَعْلَمُ الْمُؤْمِنُ مَا عِنْدَ اللَّهِ مِنَ الْعُقُوبَةِ مَا طَمِعَ فِي الْجَنَّةِ أَحَدٌ وَلَوْ يَعْلَمُ الْكَافِرُ مَا عِنْدَ اللَّهِ مِنَ الرَّحْمَةِ مَا قَنَطَ مِنَ الْجَنَّةِ أَحَدٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{3542}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“If the believer knew what is with Allah of punishment, none would hope for Paradise, and if the disbeliever knew what is with Allah of mercy, none would despair of (attaining) Paradise.”}}
\hadithdefcmd{tirmidhi}{3543}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ حِينَ خَلَقَ الْخَلْقَ كَتَبَ بِيَدِهِ عَلَى نَفْسِهِ إِنَّ رَحْمَتِي تَغْلِبُ غَضَبِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3543}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“Verily, Allah when He created the creation, He wrote with His Hand concerning Himself, that: ‘My mercy prevails over My wrath.’”}}
\hadithdefcmd{tirmidhi}{3544}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي الثَّلْجِ، - رَجُلٌ مِنْ أَهْلِ بَغْدَادَ أَبُو عَبْدِ اللَّهِ صَاحِبُ أَحْمَدَ بْنِ حَنْبَلٍ حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا سَعِيدُ بْنُ زَرْبِيٍّ، عَنْ عَاصِمٍ الأَحْوَلِ، وَثَابِتٍ، عَنْ أَنَسٍ، قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم الْمَسْجِدَ وَرَجُلٌ قَدْ صَلَّى وَهُوَ يَدْعُو وَيَقُولُ فِي دُعَائِهِ اللَّهُمَّ لاَ إِلَهَ إِلاَّ أَنْتَ الْمَنَّانُ بَدِيعُ السَّمَوَاتِ وَالأَرْضِ ذَا الْجَلاَلِ وَالإِكْرَامِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ تَدْرُونَ بِمَ دَعَا اللَّهَ دَعَا اللَّهَ بِاسْمِهِ الأَعْظَمِ الَّذِي إِذَا دُعِيَ بِهِ أَجَابَ وَإِذَا سُئِلَ بِهِ أَعْطَى ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ ثَابِتٍ عَنْ أَنَسٍ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ أَنَسٍ ‏.‏\hadithno{3544}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas said that:The Prophet (ﷺ) entered the Masjid and there was a man who had performed Salat and was supplicating. He was saying in his supplication: “O Allah, none has the right to be worshipped but Allah, You are the One Who gives blessings, Originator of the heavens and the earth, Possessor of glory and generosity (Allāhumma lā ilāha illā ant, al-Mannān, Badī`us-samāwāti wal-arḍ, Dhal-Jalāli wal Ikrām).” So the Prophet (ﷺ) said: “Do you know what he has supplicated Allah with? He has supplicated to Allah by His Greatest Name, the one which if He Is called upon by it, He responds, and when He is asked by it, He gives.”}}
\hadithdefcmd{tirmidhi}{3545}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا رِبْعِيُّ بْنُ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَغِمَ أَنْفُ رَجُلٍ ذُكِرْتُ عِنْدَهُ فَلَمْ يُصَلِّ عَلَىَّ وَرَغِمَ أَنْفُ رَجُلٍ دَخَلَ عَلَيْهِ رَمَضَانُ ثُمَّ انْسَلَخَ قَبْلَ أَنْ يُغْفَرَ لَهُ وَرَغِمَ أَنْفُ رَجُلٍ أَدْرَكَ عِنْدَهُ أَبَوَاهُ الْكِبَرَ فَلَمْ يُدْخِلاَهُ الْجَنَّةَ ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ وَأَظُنُّهُ قَالَ أَوْ أَحَدُهُمَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَأَنَسٍ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَرِبْعِيُّ بْنُ إِبْرَاهِيمَ هُوَ أَخُو إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ وَهُوَ ثِقَةٌ وَهُوَ ابْنُ عُلَيَّةَ ‏.‏ وَيُرْوَى عَنْ بَعْضِ أَهْلِ الْعِلْمِ قَالَ إِذَا صَلَّى الرَّجُلُ عَلَى النَّبِيِّ صلى الله عليه وسلم مَرَّةً فِي الْمَجْلِسِ أَجْزَأَ عَنْهُ مَا كَانَ فِي ذَلِكَ الْمَجْلِسِ ‏.‏\hadithno{3545}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“May the man before whom I am mentioned - and he does not send Salat upon me - be humiliated. And may a man upon whom Ramadan enters and then passes, before he is forgiven, be humiliated. And may a man whose parents reached old age in his presence, and they were not a cause for his entrance to Paradise, be humiliated.”}}
\hadithdefcmd{tirmidhi}{3546}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، وَزِيَادُ بْنُ أَيُّوبَ، قَالاَ حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَلِيِّ بْنِ حُسَيْنِ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَنْ أَبِيهِ، عَنْ حُسَيْنِ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبَخِيلُ الَّذِي مَنْ ذُكِرْتُ عِنْدَهُ فَلَمْ يُصَلِّ عَلَىَّ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3546}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ali bin Abi Talib narrated that the Messenger of Allah (ﷺ) said:“The stingy person is the one before whom I am mentioned, and he does not send Salat upon me.”}}
\hadithdefcmd{tirmidhi}{3547}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ بَرِّدْ قَلْبِي بِالثَّلْجِ وَالْبَرَدِ وَالْمَاءِ الْبَارِدِ اللَّهُمَّ نَقِّ قَلْبِي مِنَ الْخَطَايَا كَمَا نَقَّيْتَ الثَّوْبَ الأَبْيَضَ مِنَ الدَّنَسِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{3547}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Abdullah bin [Abi] Awfa narrated that the Messenger of Allah (ﷺ) used to say:“O Allah, cool my heart with snow and hail and cold water. O Allah, cleanse my heart of sins as You cleanse a white garment of filth (Allāhumma barrid qalbī bith-thalji wal-baradi wal-mā’il-bārid. Allāhumma naqqi qalbī min al-khaṭāyā kamā naqqaitath-thawbal-abyaḍa min ad-dannas).”}}
\hadithdefcmd{tirmidhi}{3548}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ الْقُرَشِيِّ الْمُلَيْكِيِّ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ فُتِحَ لَهُ مِنْكُمْ بَابُ الدُّعَاءِ فُتِحَتْ لَهُ أَبْوَابُ الرَّحْمَةِ وَمَا سُئِلَ اللَّهُ شَيْئًا يَعْنِي أَحَبَّ إِلَيْهِ مِنْ أَنْ يُسْأَلَ الْعَافِيَةَ ‏"‏ ‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الدُّعَاءَ يَنْفَعُ مِمَّا نَزَلَ وَمِمَّا لَمْ يَنْزِلْ فَعَلَيْكُمْ عِبَادَ اللَّهِ بِالدُّعَاءِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ الْقُرَشِيِّ وَهُوَ الْمَكِّيُّ الْمُلَيْكِيُّ وَهُوَ ضَعِيفٌ فِي الْحَدِيثِ ضَعَّفَهُ بَعْضُ أَهْلِ الْعِلْمِ مِنْ قِبَلِ حِفْظِهِ ‏.‏ وَقَدْ رَوَى إِسْرَائِيلُ، هَذَا الْحَدِيثَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَا سُئِلَ اللَّهُ شَيْئًا أَحَبَّ إِلَيْهِ مِنَ الْعَافِيَةِ ‏"‏\hadithno{3548}\hadithgrade{Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn `Umar narrated that the Messenger of Allah (ﷺ) said:“Whomsoever of you the door of supplication is opened for, the doors of mercy have been opened for him. And Allah is not asked for anything - meaning - more beloved to Him, than being asked for Al-`Āfiyah.” And the Messenger of Allah (ﷺ) said: “The supplication benefits against that which strikes and that which does not strike, so hold fast, O worshippers of Allah, to supplication.”}}
\hadithdefcmd{tirmidhi}{3549}{حَدَّثَنَا بِذَلِكَ الْقَاسِمُ بْنُ دِينَارٍ الْكُوفِيُّ حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ الْكُوفِيُّ عَنْ إِسْرَائِيلَ بِهَذَا ‏.‏ حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو النَّضْرِ، حَدَّثَنَا بَكْرُ بْنُ خُنَيْسٍ، عَنْ مُحَمَّدٍ الْقُرَشِيِّ، عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ بِلاَلٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ عَلَيْكُمْ بِقِيَامِ اللَّيْلِ فَإِنَّهُ دَأْبُ الصَّالِحِينَ قَبْلَكُمْ وَإِنَّ قِيَامَ اللَّيْلِ قُرْبَةٌ إِلَى اللَّهِ وَمَنْهَاةٌ عَنِ الإِثْمِ وَتَكْفِيرٌ لِلسَّيِّئَاتِ وَمَطْرَدَةٌ لِلدَّاءِ عَنِ الْجَسَدِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ بِلاَلٍ إِلاَّ مِنْ هَذَا الْوَجْهِ وَلاَ يَصِحُّ مِنْ قِبَلِ إِسْنَادِهِ ‏.‏ قَالَ سَمِعْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ يَقُولُ مُحَمَّدٌ الْقُرَشِيُّ هُوَ مُحَمَّدُ بْنُ سَعِيدٍ الشَّامِيُّ وَهُوَ ابْنُ أَبِي قَيْسٍ وَهُوَ مُحَمَّدُ بْنُ حَسَّانَ وَقَدْ تُرِكَ حَدِيثُهُ ‏.‏ وَقَدْ رَوَى هَذَا الْحَدِيثَ مُعَاوِيَةُ بْنُ صَالِحٍ عَنْ رَبِيعَةَ بْنِ يَزِيدَ عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ عَنْ أَبِي أُمَامَةَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ عَلَيْكُمْ بِقِيَامِ اللَّيْلِ فَإِنَّهُ دَأْبُ الصَّالِحِينَ قَبْلَكُمْ وَهُوَ قُرْبَةٌ إِلَى رَبِّكُمْ وَمَكْفَرَةٌ لِلسَّيِّئَاتِ وَمَنْهَاةٌ لِلإِثْمِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا أَصَحُّ مِنْ حَدِيثِ أَبِي إِدْرِيسَ عَنْ بِلاَلٍ ‏.‏\hadithno{3549}\hadithgrade{Al-Albani: Daif}\hadithtrans{That was narrated to us by Al-Qasim bin Dinar Al-Kufi (who said):“Ishaq bin Mansur narrated to us, from Isra’il” with this (Another chain) Bilal narrated that the Messenger of Allah (ﷺ) said: “Hold fast to Qiyam al-Lail, for it is the practice of the righteous before you, and indeed Qiyam al-Lail is a means of nearness to Allah, a means of prevention from sin, an expiation for bad deeds, and a barrier for the body against disease.”}}
\hadithdefcmd{tirmidhi}{3550}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ مُحَمَّدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَعْمَارُ أُمَّتِي مَا بَيْنَ سِتِّينَ إِلَى سَبْعِينَ وَأَقَلُّهُمْ مَنْ يَجُوزُ ذَلِكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ مُحَمَّدِ بْنِ عَمْرٍو عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي هُرَيْرَةَ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏\hadithno{3550}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Abu Hurairah narrates, saying:The Messenger of Allah (ﷺ) said: “The lifespan of my nation is between sixty to seventy, and the least of them are those who surpass that.”}}
\hadithdefcmd{tirmidhi}{3551}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ طُلَيْقِ بْنِ قَيْسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَدْعُو يَقُولُ ‏ "‏ رَبِّ أَعِنِّي وَلاَ تُعِنْ عَلَىَّ وَانْصُرْنِي وَلاَ تَنْصُرْ عَلَىَّ وَامْكُرْ لِي وَلاَ تَمْكُرْ عَلَىَّ وَاهْدِنِي وَيَسِّرِ الْهُدَى لِي وَانْصُرْنِي عَلَى مَنْ بَغَى عَلَىَّ رَبِّ اجْعَلْنِي لَكَ شَكَّارًا لَكَ ذَكَّارًا لَكَ رَهَّابًا لَكَ مِطْوَاعًا لَكَ مُخْبِتًا إِلَيْكَ أَوَّاهًا مُنِيبًا رَبِّ تَقَبَّلْ تَوْبَتِي وَاغْسِلْ حَوْبَتِي وَأَجِبْ دَعْوَتِي وَثَبِّتْ حُجَّتِي وَسَدِّدْ لِسَانِي وَاهْدِ قَلْبِي وَاسْلُلْ سَخِيمَةَ صَدْرِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ مَحْمُودُ بْنُ غَيْلاَنَ وَحَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ الْعَبْدِيُّ، عَنْ سُفْيَانَ الثَّوْرِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{3551}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn `Abbas said:“The Prophet (ﷺ) used to supplicate, saying: “My Lord, aid me and do not aid against me, and grant me victory and do not grant victory over me, plot for me and do not plot against me, guide me and facilitate guidance for me, grant me victory over those who transgress against me. My Lord, make me ever-grateful to You, ever-remembering of You, ever-fearful of You, ever-obedient to You, ever-humble to You, oft-turning and returning to You. My Lord, accept my repentance, wash my sin, answer my call, make firm my proof, make firm my tongue, guide my heart, and remove the treachery of my chest (Rabbi a`innī wa lā tu`in `alayya, wanṣurnī wa lā tanṣur `alayya, wamkur lī wa lā tamkur `alayya, wahdinī wa yassiril-huda lī, wanṣurnī `alā man baghā `alayya. Rabbij`alnī laka shakkāran, laka dhakkāran, laka rahhāban, laka miṭwā`an, laka mukhbitan, ilaika awwāhan munība. Rabbi taqabbal tawbatī, waghsil ḥawbatī, wa ajib da`watī, wa thabbit ḥujjatī, wa saddid lisānī, wahdi qalbī, waslul sakhīmata ṣadrī).”}}
\hadithdefcmd{tirmidhi}{3552}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي حَمْزَةَ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ دَعَا عَلَى مَنْ ظَلَمَهُ فَقَدِ انْتَصَرَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ أَبِي حَمْزَةَ ‏.‏ وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْعِلْمِ فِي أَبِي حَمْزَةَ مِنْ قِبَلِ حِفْظِهِ وَهُوَ مَيْمُونٌ الأَعْوَرُ ‏.‏ حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ الرُّؤَاسِيُّ، عَنْ أَبِي الأَحْوَصِ، عَنْ أَبِي حَمْزَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{3552}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated, saying:The Messenger of Allah (ﷺ) said: “Whoever supplicates against the one who wronged him has triumphed.”}}
\hadithdefcmd{tirmidhi}{3553}{حَدَّثَنَا مُوسَى بْنُ عَبْدِ الرَّحْمَنِ الْكِنْدِيُّ الْكُوفِيُّ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، قَالَ وَأَخْبَرَنِي سُفْيَانُ الثَّوْرِيُّ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ الشَّعْبِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَالَ عَشْرَ مَرَّاتٍ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ يُحْيِي وَيُمِيتُ وَهُوَ عَلَى كُلِّ شَيْءٍ قَدِيرٌ ‏.‏ كَانَتْ لَهُ عِدْلَ أَرْبَعِ رِقَابٍ مِنْ وَلَدِ إِسْمَاعِيلَ ‏"‏ ‏.‏ قَالَ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ أَبِي أَيُّوبَ مَوْقُوفًا ‏.‏\hadithno{3553}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Daif; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Ayyub Al-Ansari narrated that the Messenger of Allah (ﷺ) said:“Whoever says ten times: ‘None has the right to be worshipped by Allah, Alone, without partner, to Him belongs all that exists, and to Him belongs the praise, [He gives life and causes death,] and He has power over all things, (Lā ilāha illallāh, waḥdahu lā sharīka lahu, lahul-mulku wa lahul-ḥamdu, [yuḥyī wa yumītu,] wa huwa `alā kulli shai’in qadīr)’ it is for him equal to freeing four slaves among the offspring of Isma`il.”}}
\hadithdefcmd{tirmidhi}{3554}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا هَاشِمٌ، وَهُوَ ابْنُ سَعِيدٍ الْكُوفِيُّ حَدَّثَنِي كِنَانَةُ، مَوْلَى صَفِيَّةَ قَالَ سَمِعْتُ صَفِيَّةَ، تَقُولُ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَبَيْنَ يَدَىَّ أَرْبَعَةُ آلاَفِ نَوَاةٍ أُسَبِّحُ بِهَا فَقُلْتُ لَقَدْ سَبَّحْتُ بِهَذِهِ ‏.‏ فَقَالَ ‏"‏ أَلاَ أُعَلِّمُكِ بِأَكْثَرَ مِمَّا سَبَّحْتِ بِهِ ‏"‏ ‏.‏ فَقُلْتُ بَلَى عَلِّمْنِي ‏.‏ فَقَالَ ‏"‏ قُولِي سُبْحَانَ اللَّهِ عَدَدَ خَلْقِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ صَفِيَّةَ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ هَاشِمِ بْنِ سَعِيدٍ الْكُوفِيِّ وَلَيْسَ إِسْنَادُهُ بِمَعْرُوفٍ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{3554}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Saffiyah narrated:“The Messenger of Allah (ﷺ) entered upon me and before me were four thousand date pits, I was making Tasbih with them. He said: ‘You have made Tasbih with these? Should I not teach you that which is more than what you have made Tasbih with?’ So I said: ‘Indeed, teach me.’ So he said: ‘Say: glory is to Allah according to the number of His creation (Subḥān Allāhi `adada khalqihi).’”}}
\hadithdefcmd{tirmidhi}{3555}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ كُرَيْبًا، يُحَدِّثُ عَنِ ابْنِ عَبَّاسٍ، عَنْ جُوَيْرِيَةَ بِنْتِ الْحَارِثِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم مَرَّ عَلَيْهَا وَهِيَ فِي مَسْجِدٍ ثُمَّ مَرَّ النَّبِيُّ صلى الله عليه وسلم بِهَا قَرِيبًا مِنْ نِصْفِ النَّهَارِ فَقَالَ لَهَا ‏"‏ مَا زِلْتِ عَلَى حَالِكِ ‏"‏ ‏.‏ فَقَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ أَلاَ أُعَلِّمُكِ كَلِمَاتٍ تَقُولِينَهَا سُبْحَانَ اللَّهِ عَدَدَ خَلْقِهِ سُبْحَانَ اللَّهِ عَدَدَ خَلْقِهِ سُبْحَانَ اللَّهِ عَدَدَ خَلْقِهِ سُبْحَانَ اللَّهِ رِضَا نَفْسِهِ سُبْحَانَ اللَّهِ رِضَا نَفْسِهِ سُبْحَانَ اللَّهِ رِضَا نَفْسِهِ سُبْحَانَ اللَّهِ زِنَةَ عَرْشِهِ سُبْحَانَ اللَّهِ زِنَةَ عَرْشِهِ سُبْحَانَ اللَّهِ زِنَةَ عَرْشِهِ سُبْحَانَ اللَّهِ مِدَادَ كَلِمَاتِهِ سُبْحَانَ اللَّهِ مِدَادَ كَلِمَاتِهِ سُبْحَانَ اللَّهِ مِدَادَ كَلِمَاتِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَمُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ هُوَ مَوْلَى آلِ طَلْحَةَ وَهُوَ شَيْخٌ مَدَنِيٌّ ثِقَةٌ وَقَدْ رَوَى عَنْهُ الْمَسْعُودِيُّ وَسُفْيَانُ الثَّوْرِيُّ هَذَا الْحَدِيثَ ‏.‏\hadithno{3555}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn Abbas narrated from Juwairiyyah bint Al-Harith, that:The Prophet (ﷺ) passed by her while she was in her place of prayer, then the Prophet (ﷺ) passed by her near midday, so he (ﷺ) said to her: “You have not ceased to be in this state?” She said: “Yes.” He said: “Should I not teach you words to say: ‘Glory to Allah according to the number of His creation, Glory to Allah according to the number of His creation, Glory to Allah according to the number of His creation (Subḥān Allāhi `adada khalqihi, Subḥān Allāhi `adada khalqihi, Subḥān Allāhi `adada khalqihi). Glory to Allah accord to what pleases Him, Glory to Allah accord to what pleases Him, Glory to Allah accord to what pleases Him (Subḥān Allāhi riḍā nafsihi, Subḥān Allāhi riḍā nafsihi, SSubḥān Allāhi riḍā nafsihii). Glory to Allah according to the weight of His Throne, Glory to Allah according to the weight of His Throne, Glory to Allah according to the weight of His Throne (Subḥān Allāhi zinata `Arshihi, Subḥān Allāhi zinata `Arshihi, Subḥān Allāhi zinata `Arshihi). Glory to Allah according to the amount of His Words, Glory to Allah according to the amount of His Words, Glory to Allah according to the amount of His Words (Subḥān Allāhi midāda kalimātihi, Subḥān Allāhi midāda kalimātihi, Subḥān Allāhi midāda kalimātihi).’”}}
\hadithdefcmd{tirmidhi}{3556}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، قَالَ أَنْبَأَنَا جَعْفَرُ بْنُ مَيْمُونٍ، صَاحِبُ الأَنْمَاطِ عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ سَلْمَانَ الْفَارِسِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ حَيِيٌّ كَرِيمٌ يَسْتَحِي إِذَا رَفَعَ الرَّجُلُ إِلَيْهِ يَدَيْهِ أَنْ يَرُدَّهُمَا صِفْرًا خَائِبَتَيْنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَرَوَاهُ بَعْضُهُمْ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{3556}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Salman Al-Farsi narrated that the Prophet (ﷺ) said:“Indeed, Allah, is Hayy, Generous, when a man raises his hands to Him, He feels too shy to return them to him empty and rejected.”}}
\hadithdefcmd{tirmidhi}{3557}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، حَدَّثَنَا مُحَمَّدُ بْنُ عَجْلاَنَ، عَنِ الْقَعْقَاعِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، كَانَ يَدْعُو بِأُصْبُعَيْهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَحِّدْ أَحِّدْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَمَعْنَى هَذَا الْحَدِيثِ إِذَا أَشَارَ الرَّجُلُ بِأُصْبُعَيْهِ فِي الدُّعَاءِ عِنْدَ الشَّهَادَةِ لاَ يُشِيرُ إِلاَّ بِأُصْبُعٍ وَاحِدَةٍ ‏.‏\hadithno{3557}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that:A man was supplicating with his two fingers so the Messenger of Allah (ﷺ) said: “Make it one, make it one.”}}
\hadithdefcmd{tirmidhi}{3558}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا زُهَيْرٌ، وَهُوَ ابْنُ مُحَمَّدٍ عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، أَنَّ مُعَاذَ بْنَ رِفَاعَةَ، أَخْبَرَهُ عَنْ أَبِيهِ، قَالَ قَامَ أَبُو بَكْرٍ الصِّدِّيقُ عَلَى الْمِنْبَرِ ثُمَّ بَكَى فَقَالَ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَامَ الأَوَّلِ عَلَى الْمِنْبَرِ ثُمَّ بَكَى فَقَالَ ‏ "‏ سَلُوا اللَّهَ الْعَفْوَ وَالْعَافِيَةَ فَإِنَّ أَحَدًا لَمْ يُعْطَ بَعْدَ الْيَقِينِ خَيْرًا مِنَ الْعَافِيَةِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ عَنْ أَبِي بَكْرٍ رضى الله عنه ‏.‏\hadithno{3558}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Mu`adh bin Rifa`ah narrated from his father, that he said:“Abu Bakr stood upon the Minbar, then wept, and said: ‘The Messenger of Allah (ﷺ) stood upon the Minbar the first year (of Hijrah), then wept, and said: “Ask Allah for pardon and Al-`Āfiyah, for verily, none has been given anything better than Al-`Āfiyah.’”}}
\hadithdefcmd{tirmidhi}{3559}{حَدَّثَنَا حُسَيْنُ بْنُ يَزِيدَ الْكُوفِيُّ، حَدَّثَنَا أَبُو يَحْيَى الْحِمَّانِيُّ، حَدَّثَنَا عُثْمَانُ بْنُ وَاقِدٍ، عَنْ أَبِي نُصَيْرَةَ، عَنْ مَوْلًى، لأَبِي بَكْرٍ عَنْ أَبِي بَكْرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أَصَرَّ مَنِ اسْتَغْفَرَ وَلَوْ فَعَلَهُ فِي الْيَوْمِ سَبْعِينَ مَرَّةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ أَبِي نُصَيْرَةَ وَلَيْسَ إِسْنَادُهُ بِالْقَوِيِّ ‏.‏\hadithno{3559}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Abu Bakr narrated:That the Messenger of Allah (ﷺ) said: “He who seeks forgiveness has not been persistent in sin, even if he does it seventy times in a day.”}}
\hadithdefcmd{tirmidhi}{3560}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، وَسُفْيَانُ بْنُ وَكِيعٍ، - الْمَعْنَى وَاحِدٌ قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا الأَصْبَغُ بْنُ زَيْدٍ، حَدَّثَنَا أَبُو الْعَلاَءِ، عَنْ أَبِي أُمَامَةَ، قَالَ لَبِسَ عُمَرُ بْنُ الْخَطَّابِ رضى الله عنه ثَوْبًا جَدِيدًا فَقَالَ الْحَمْدُ لِلَّهِ الَّذِي كَسَانِي مَا أُوَارِي بِهِ عَوْرَتِي وَأَتَجَمَّلُ بِهِ فِي حَيَاتِي ‏.‏ ثُمَّ عَمَدَ إِلَى الثَّوْبِ الَّذِي أَخْلَقَ فَتَصَدَّقَ بِهِ ثُمَّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ لَبِسَ ثَوْبًا جَدِيدًا فَقَالَ الْحَمْدُ لِلَّهِ الَّذِي كَسَانِي مَا أُوَارِي بِهِ عَوْرَتِي وَأَتَجَمَّلُ بِهِ فِي حَيَاتِي ثُمَّ عَمَدَ إِلَى الثَّوْبِ الَّذِي أَخْلَقَ فَتَصَدَّقَ بِهِ كَانَ فِي كَنَفِ اللَّهِ وَفِي حِفْظِ اللَّهِ وَفِي سَتْرِ اللَّهِ حَيًّا وَمَيِّتًا ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَقَدْ رَوَاهُ يَحْيَى بْنُ أَيُّوبَ عَنْ عُبَيْدِ اللَّهِ بْنِ زَحْرٍ عَنْ عَلِيِّ بْنِ يَزِيدَ عَنِ الْقَاسِمِ عَنْ أَبِي أُمَامَةَ ‏.‏\hadithno{3560}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Umamah narrated:That `Umar bin Al-Khattab [may Allah be pleased with him] wore a new garment and said: “All praise is due to Allah who clothed me with what I may cover my `Awrah, and what I may beautify myself with in my life (Al-ḥamdulillāh, alladhī kasānī mā uwārī bihī `awratī, wa atajammalu bihī fī ḥayātī).” Then he said: “I heard the Messenger of Allah (ﷺ) saying: ‘Whoever wears a new garment and then says: “Allah praise is due to Allah who clothed me with what I may cover my `Awrah and what I may beautify myself with in my life (Al-ḥamdulillāh, alladhī kasānī mā uwārī bihī `awratī, wa atajammalu bihī fī ḥayātī)” and then he takes the garment that has worn out and gives it in charity, he shall be under Allah’s guard, Allah’s protection, and Allah’s covering, alive and dead.’”}}
\hadithdefcmd{tirmidhi}{3561}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ الصَّائِغُ، قِرَاءَةً عَلَيْهِ عَنْ حَمَّادِ بْنِ أَبِي حُمَيْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَ بَعْثًا قِبَلَ نَجْدٍ فَغَنِمُوا غَنَائِمَ كَثِيرَةً وَأَسْرَعُوا الرَّجْعَةَ فَقَالَ رَجُلٌ مِمَّنْ لَمْ يَخْرُجْ مَا رَأَيْنَا بَعْثًا أَسْرَعَ رَجْعَةً وَلاَ أَفْضَلَ غَنِيمَةً مِنْ هَذَا الْبَعْثِ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَلاَ أَدُلُّكُمْ عَلَى قَوْمٍ أَفْضَلُ غَنِيمَةً وَأَسْرَعُ رَجْعَةً قَوْمٌ شَهِدُوا صَلاَةَ الصُّبْحِ ثُمَّ جَلَسُوا يَذْكُرُونَ اللَّهَ حَتَّى طَلَعَتْ عَلَيْهِمُ الشَّمْسُ فَأُولَئِكَ أَسْرَعُ رَجْعَةً وَأَفْضَلُ غَنِيمَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَحَمَّادُ بْنُ أَبِي حُمَيْدٍ هُوَ أَبُو إِبْرَاهِيمَ الأَنْصَارِيُّ الْمُزَنِيُّ وَهُوَ مُحَمَّدُ بْنُ أَبِي حُمَيْدٍ الْمَدَنِيُّ وَهُوَ ضَعِيفٌ فِي الْحَدِيثِ ‏.‏\hadithno{3561}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Umar bin Al-Khattab narrated:That the Prophet (ﷺ) sent an expedition in the direction of Najd. They gained many spoils of war and returned quickly. A man among those who did not go out said: “We have not seen an expedition quicker in return or greater in spoils than this expedition.” So the Messenger of Allah (ﷺ) said: “Should I not direct you to a group greater in spoils and quicker in return? A group who attended Salat As-Subh, then sat remembering Allah until the sun rose, for these are quicker in return and greater in spoils.”}}
\hadithdefcmd{tirmidhi}{3562}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبِي، عَنْ سُفْيَانَ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ، أَنَّهُ اسْتَأْذَنَ النَّبِيَّ صلى الله عليه وسلم فِي الْعُمْرَةِ فَقَالَ ‏ "‏ أَىْ أُخَىَّ أَشْرِكْنَا فِي دُعَائِكَ وَلاَ تَنْسَنَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3562}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn `Umar narrated from `Umar:that he sought permission from the Prophet (ﷺ) concerning `Umrah, so he said: “O my little brother, include us in your supplication and do not forget us.”}}
\hadithdefcmd{tirmidhi}{3563}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنْ سَيَّارٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَلِيٍّ، رضى الله عنه أَنَّ مُكَاتَبًا، جَاءَهُ فَقَالَ إِنِّي قَدْ عَجَزْتُ عَنْ كِتَابَتِي فَأَعِنِّي ‏.‏ قَالَ أَلاَ أُعَلِّمُكَ كَلِمَاتٍ عَلَّمَنِيهِنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم لَوْ كَانَ عَلَيْكَ مِثْلُ جَبَلِ صِيرٍ دَيْنًا أَدَّاهُ اللَّهُ عَنْكَ قَالَ ‏ "‏ قُلِ اللَّهُمَّ اكْفِنِي بِحَلاَلِكَ عَنْ حَرَامِكَ وَأَغْنِنِي بِفَضْلِكَ عَمَّنْ سِوَاكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3563}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Ali [may Allah be pleased with him] narrated:that a Mukatib came to him and said: “Indeed I am not capable of my Kitabah so aid me.” He said: “Should I not teach you words that the Messenger of Allah (ﷺ) taught me? If you had a debt upon you similar to the mountain of Sir, Allah would fulfill it for you. He said: ‘Say: O Allah, suffice me with Your lawful against Your prohibited, and make me independent of all those besides You (Allāhummakfinī biḥalālika `an ḥarāmika, wa aghninī bi faḍlika `amman siwāka).’”}}
\hadithdefcmd{tirmidhi}{3564}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ اللَّهِ بْنِ سَلِمَةَ، عَنْ عَلِيٍّ، قَالَ كُنْتُ شَاكِيًا فَمَرَّ بِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا أَقُولُ اللَّهُمَّ إِنْ كَانَ أَجَلِي قَدْ حَضَرَ فَأَرِحْنِي وَإِنْ كَانَ مُتَأَخِّرًا فَأَرْفِغْنِي وَإِنْ كَانَ بَلاَءً فَصَبِّرْنِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَيْفَ قُلْتَ ‏"‏ ‏.‏ قَالَ فَأَعَادَ عَلَيْهِ مَا قَالَ قَالَ فَضَرَبَهُ بِرِجْلِهِ فَقَالَ ‏"‏ اللَّهُمَّ عَافِهِ أَوِ اشْفِهِ ‏"‏ ‏.‏ شُعْبَةُ الشَّاكُّ ‏.‏ فَمَا اشْتَكَيْتُ وَجَعِي بَعْدُ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3564}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ali said:“I was ill and the Messenger of Allah (ﷺ) passed by me while I was saying: ‘O Allah, if my term has come, then give me relief, and if it is coming later, then make my life more bountiful, and if it is a trial then make me patient (Allāhumma, in kāna ajalī qad ḥaḍara fa ariḥnī, wa in kāna muta’akh-khiran fa arfighnī, wa in kāna balā’an fa ṣabbirnī).’ So the Messenger of Allah (ﷺ) said: ‘What did you say?’” He said: “So he repeated to him what he said.” He (one of the narrators) said: So he struck him with his foot and said: “O Allah, grant him health (Allāhumma `āfihi)” – or – “heal him (ishfihi).” – Shu`ba is the one who doubted. He said: “So I did not suffer from my ailment again.”}}
\hadithdefcmd{tirmidhi}{3565}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، رضى الله عنه قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا عَادَ مَرِيضًا قَالَ ‏ "‏ اللَّهُمَّ أَذْهِبِ الْبَأْسَ رَبَّ النَّاسِ وَاشْفِ فَأَنْتَ الشَّافِي لاَ شِفَاءَ إِلاَّ شِفَاؤُكَ شِفَاءً لاَ يُغَادِرُ سَقَمًا ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{3565}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ali narrated, saying:“Whenever the Prophet (ﷺ) would visit an ill person, he would said:‘[O Allah,] make the harm go away, Lord of mankind, and heal him, You are the Healer, there is no healing except your healing, a healing that does not leave any sickness ([Allāhumma] adh-hibil-ba’sa rabban-nās, washfi antash-shāfi, lā shifā’a illā shifā’uka shifā’an lā yughādiru saqama).’”}}
\hadithdefcmd{tirmidhi}{3566}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ هِشَامِ بْنِ عَمْرٍو الْفَزَارِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ فِي وِتْرِهِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِرِضَاكَ مِنْ سَخَطِكَ وَأَعُوذُ بِمُعَافَاتِكَ مِنْ عُقُوبَتِكَ وَأَعُوذُ بِكَ مِنْكَ لاَ أُحْصِي ثَنَاءً عَلَيْكَ أَنْتَ كَمَا أَثْنَيْتَ عَلَى نَفْسِكَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ عَلِيٍّ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ حَمَّادِ بْنِ سَلَمَةَ ‏.‏\hadithno{3566}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ali bin Abi Talib narrated:that the Prophet (ﷺ) used to say in his Witr: “O Allah, I seek refuge in your pardon from Your Punishment, and I seek refuge in You from You, I am not capable of extolling You as You have extolled Yourself (Allāhumma innī a`ūdhu bi-riḍāka min sakhaṭika, wa a`ūdhu bi-mu`āfātika min `uqūbatika, wa a`ūdhu bika minka, lā uḥsī thanā’an `alaika, anta kamā athnaita `alā nafsik).”}}
\hadithdefcmd{tirmidhi}{3567}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا زَكَرِيَّا بْنُ عَدِيٍّ، حَدَّثَنَا عُبَيْدُ اللَّهِ، هُوَ ابْنُ عَمْرٍو الرَّقِّيُّ عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، وَعَمْرِو بْنِ مَيْمُونٍ، قَالَ كَانَ سَعْدٌ يُعَلِّمُ بَنِيهِ هَؤُلاَءِ الْكَلِمَاتِ كَمَا يُعَلِّمُ الْمُكْتِبُ الْغِلْمَانَ وَيَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَتَعَوَّذُ بِهِنَّ دُبُرَ الصَّلاَةِ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْجُبْنِ وَأَعُوذُ بِكَ مِنَ الْبُخْلِ وَأَعُوذُ بِكَ مِنْ أَرْذَلِ الْعُمُرِ وَأَعُوذُ بِكَ مِنْ فِتْنَةِ الدُّنْيَا وَعَذَابِ الْقَبْرِ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ أَبُو إِسْحَاقَ الْهَمْدَانِيُّ مُضْطَرِبٌ فِي هَذَا الْحَدِيثِ يَقُولُ عَنْ عَمْرِو بْنِ مَيْمُونٍ عَنْ عُمَرَ وَيَقُولُ عَنْ غَيْرِهِ وَيَضْطَرِبُ فِيهِ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3567}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Mus`ab bin Sa`d and `Amr bin Maimun narrated:“Sa`d used to teach his children these words just as the Muktib teaches children, he would say: ‘Indeed, the Messenger of Allah (ﷺ) used to seek refuge by saying them at the end of (every) Salat: O Allah I seek refuge in You from cowardliness, I seek refuge in You from miserliness, I seek refuge in You from feeble old age, and I seek refuge in You from the trial of the world, and the punishment of the grave (Allāhumma innī a`ūdhu bika minal-jubn, wa a`ūdhu bika minal-bukhl, wa a`ūdhu bika min ardhalil-`umur, wa a`ūdhu bika min fitnatid-dunyā wa `adhābil qabr).’”}}
\hadithdefcmd{tirmidhi}{3568}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ، حَدَّثَنَا أَصْبَغُ بْنُ الْفَرَجِ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، أَنَّهُ أَخْبَرَهُ عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ خُزَيْمَةَ، عَنْ عَائِشَةَ بِنْتِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ أَبِيهَا، أَنَّهُ دَخَلَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى امْرَأَةٍ وَبَيْنَ يَدَيْهَا نَوًى أَوْ قَالَ حَصًى تُسَبِّحُ بِهِ فَقَالَ ‏ "‏ أَلاَ أُخْبِرُكِ بِمَا هُوَ أَيْسَرُ عَلَيْكِ مِنْ هَذَا أَوْ أَفْضَلُ سُبْحَانَ اللَّهِ عَدَدَ مَا خَلَقَ فِي السَّمَاءِ وَسُبْحَانَ اللَّهِ عَدَدَ مَا خَلَقَ فِي الأَرْضِ وَسُبْحَانَ اللَّهِ عَدَدَ مَا بَيْنَ ذَلِكَ وَسُبْحَانَ اللَّهِ عَدَدَ مَا هُوَ خَالِقٌ وَاللَّهُ أَكْبَرُ مِثْلَ ذَلِكَ وَالْحَمْدُ لِلَّهِ مِثْلَ ذَلِكَ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ مِثْلَ ذَلِكَ ‏"‏ ‏.‏ قَالَ وَهَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ حَدِيثِ سَعْدٍ ‏.‏\hadithno{3568}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Aishah bint Sa`d bin Abi Waqqas narrated from her father,:that he entered with the Messenger of Allah (ﷺ) upon a women, before her was a date-seed – or he said – stone – that she would make Tasbih with. So he (ﷺ) said: “Should I not inform you of what is easier for you then this, and better? Glory to Allah according to the number of what He created in the sky, and glory to Allah according to the number of what He created in the earth, and glory to Allah according to the number of what is between that, and glory to Allah according to the number of what He is going to create, and Allah is great, in similar amount to that, and all praise is due to Allah, in similar amount to that, and there is no might or power except by Allah, in similar amount to that (Subḥān Allāhi `adada mā khalaqa fis-samā’ wa subḥān Allāhi `adada mā khalaqa fil-arḍ, wa subḥān Allāhi `adada mā baina dhālik, wa subḥān Allāhi `adada mā huwa khalaq, wa Allāhu akbaru mithla dhālik, wal ḥamdu lillāhi mithla dhālik, wa lā ḥawla wa lā quwwata illā billāhi mithla dhālik).”}}
\hadithdefcmd{tirmidhi}{3569}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَزَيْدُ بْنُ حُبَابٍ، عَنْ مُوسَى بْنِ عُبَيْدَةَ، عَنْ مُحَمَّدِ بْنِ ثَابِتٍ، عَنْ أَبِي حُكَيْمٍ، خَطْمِيٌّ مَوْلَى الزُّبَيْرِ عَنِ الزُّبَيْرِ بْنِ الْعَوَّامِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ صَبَاحٍ يُصْبِحُ الْعِبَادُ فِيهِ إِلاَّ وَمُنَادٍ يُنَادِي سَبِّحُوا الْمَلِكَ الْقُدُّوسَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{3569}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Az-Zubair bin `Awwam narrated:that the Prophet (ﷺ) said: “There is not a morning that the slave of Allah reached except that a caller calls out: ‘Glorify the King, the Free of Deficiencies. (Sabbiḥul Malikal-Quddūs)’”}}
\hadithdefcmd{tirmidhi}{3570}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَسَنِ، حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، وَعِكْرِمَةَ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ بَيْنَمَا نَحْنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ جَاءَهُ عَلِيُّ بْنُ أَبِي طَالِبٍ فَقَالَ بِأَبِي أَنْتَ وَأُمِّي تَفَلَّتَ هَذَا الْقُرْآنُ مِنْ صَدْرِي فَمَا أَجِدُنِي أَقْدِرُ عَلَيْهِ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَبَا الْحَسَنِ أَفَلاَ أُعَلِّمُكَ كَلِمَاتٍ يَنْفَعُكَ اللَّهُ بِهِنَّ وَيَنْفَعُ بِهِنَّ مَنْ عَلَّمْتَهُ وَيُثَبِّتُ مَا تَعَلَّمْتَ فِي صَدْرِكَ ‏"‏ ‏.‏ قَالَ أَجَلْ يَا رَسُولَ اللَّهِ فَعَلِّمْنِي ‏.‏ قَالَ ‏"‏ إِذَا كَانَ لَيْلَةُ الْجُمُعَةِ فَإِنِ اسْتَطَعْتَ أَنْ تَقُومَ فِي ثُلُثِ اللَّيْلِ الآخِرِ فَإِنَّهَا سَاعَةٌ مَشْهُودَةٌ وَالدُّعَاءُ فِيهَا مُسْتَجَابٌ وَقَدْ قَالَ أَخِي يَعْقُوبُ لِبَنِيهِ ‏:‏ ‏(‏سوْفَ أَسْتَغْفِرُ لَكُمْ رَبِّي ‏)‏ يَقُولُ حَتَّى تَأْتِيَ لَيْلَةُ الْجُمُعَةِ فَإِنْ لَمْ تَسْتَطِعْ فَقُمْ فِي وَسَطِهَا فَإِنْ لَمْ تَسْتَطِعْ فَقُمْ فِي أَوَّلِهَا فَصَلِّ أَرْبَعَ رَكَعَاتٍ تَقْرَأُ فِي الرَّكْعَةِ الأُولَى بِفَاتِحَةِ الْكِتَابِ وَسُورَةِ يس وَفِي الرَّكْعَةِ الثَّانِيَةِ بِفَاتِحَةِ الْكِتَابِ وَ‏(‏ حم ‏)‏ الدُّخَانَ وَفِي الرَّكْعَةِ الثَّالِثَةِ بِفَاتِحَةِ الْكِتَابِ وَالم تَنْزِيلُ السَّجْدَةَ وَفِي الرَّكْعَةِ الرَّابِعَةِ بِفَاتِحَةِ الْكِتَابِ وَتَبَارَكَ الْمُفَصَّلَ فَإِذَا فَرَغْتَ مِنَ التَّشَهُّدِ فَاحْمَدِ اللَّهَ وَأَحْسِنِ الثَّنَاءَ عَلَى اللَّهِ وَصَلِّ عَلَىَّ وَأَحْسِنْ وَعَلَى سَائِرِ النَّبِيِّينَ وَاسْتَغْفِرْ لِلْمُؤْمِنِينَ وَالْمُؤْمِنَاتِ وَلإِخْوَانِكَ الَّذِينَ سَبَقُوكَ بِالإِيمَانِ ثُمَّ قُلْ فِي آخِرِ ذَلِكَ اللَّهُمَّ ارْحَمْنِي بِتَرْكِ الْمَعَاصِي أَبَدًا مَا أَبْقَيْتَنِي وَارْحَمْنِي أَنْ أَتَكَلَّفَ مَا لاَ يَعْنِينِي وَارْزُقْنِي حُسْنَ النَّظَرِ فِيمَا يُرْضِيكَ عَنِّي اللَّهُمَّ بَدِيعَ السَّمَوَاتِ وَالأَرْضِ ذَا الْجَلاَلِ وَالإِكْرَامِ وَالْعِزَّةِ الَّتِي لاَ تُرَامُ أَسْأَلُكَ يَا اللَّهُ يَا رَحْمَنُ بِجَلاَلِكَ وَنُورِ وَجْهِكَ أَنْ تُلْزِمَ قَلْبِي حِفْظَ كِتَابِكَ كَمَا عَلَّمْتَنِي وَارْزُقْنِي أَنْ أَتْلُوَهُ عَلَى النَّحْوِ الَّذِي يُرْضِيكَ عَنِّي اللَّهُمَّ بَدِيعَ السَّمَوَاتِ وَالأَرْضِ ذَا الْجَلاَلِ وَالإِكْرَامِ وَالْعِزَّةِ الَّتِي لاَ تُرَامُ أَسْأَلُكَ يَا اللَّهُ يَا رَحْمَنُ بِجَلاَلِكَ وَنُورِ وَجْهِكَ أَنْ تُنَوِّرَ بِكِتَابِكَ بَصَرِي وَأَنْ تُطْلِقَ بِهِ لِسَانِي وَأَنْ تُفَرِّجَ بِهِ عَنْ قَلْبِي وَأَنْ تَشْرَحَ بِهِ صَدْرِي وَأَنْ تَغْسِلَ بِهِ بَدَنِي لأَنَّهُ لاَ يُعِينُنِي عَلَى الْحَقِّ غَيْرُكَ وَلاَ يُؤْتِيهِ إِلاَّ أَنْتَ وَلاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ الْعَلِيِّ الْعَظِيمِ يَا أَبَا الْحَسَنِ تَفْعَلُ ذَلِكَ ثَلاَثَ جُمَعٍ أَوْ خَمْسَ أَوْ سَبْعَ تُجَابُ بِإِذْنِ اللَّهِ وَالَّذِي بَعَثَنِي بِالْحَقِّ مَا أَخْطَأَ مُؤْمِنًا قَطُّ ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عَبَّاسٍ فَوَاللَّهِ مَا لَبِثَ عَلِيٌّ إِلاَّ خَمْسًا أَوْ سَبْعًا حَتَّى جَاءَ عَلِيٌّ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي مِثْلِ ذَلِكَ الْمَجْلِسِ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ فِيمَا خَلاَ لاَ آخُذُ إِلاَّ أَرْبَعَ آيَاتٍ أَوْ نَحْوَهُنَّ وَإِذَا قَرَأْتُهُنَّ عَلَى نَفْسِي تَفَلَّتْنَ وَأَنَا أَتَعَلَّمُ الْيَوْمَ أَرْبَعِينَ آيَةً أَوْ نَحْوَهَا وَإِذَا قَرَأْتُهَا عَلَى نَفْسِي فَكَأَنَّمَا كِتَابُ اللَّهِ بَيْنَ عَيْنَىَّ وَلَقَدْ كُنْتُ أَسْمَعُ الْحَدِيثَ فَإِذَا رَدَّدْتُهُ تَفَلَّتَ وَأَنَا الْيَوْمَ أَسْمَعُ الأَحَادِيثَ فَإِذَا تَحَدَّثْتُ بِهَا لَمْ أَخْرِمْ مِنْهَا حَرْفًا ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ ذَلِكَ ‏"‏ مُؤْمِنٌ وَرَبِّ الْكَعْبَةِ يَا أَبَا الْحَسَنِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الْوَلِيدِ بْنِ مُسْلِمٍ ‏.‏\hadithno{3570}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ikrimah, the freed slave of Ibn `Abbas, narrated that:Ibn `Abbas said: “We were with the Messenger of Allah (ﷺ) when `Ali bin Abi Talib came to him, and he said: ‘May my father and mother be ransomed for you! This Qur’an has suddenly left my heart, and I do not find myself capable of it.’ So the Messenger of Allah (ﷺ) said to him: ‘O Abul-Hasan! Should I not teach you words that Allah shall benefit you with, and benefit whomever you teach, and they will make whatever you have learned in your chest firm?’ He said: ‘Of course, O Messenger of Allah (ﷺ), so teach me.’ He (ﷺ) said: ‘When it is the night of (before) Friday, then if you are able to stand in the last third of the night, then verily it is a witnessed hour, and supplication is answered in it. And my brother Ya`qub (as) did say to his sons: I shall seek forgiveness for you from my Lord. He said: “Until the night of Friday comes.” So if you are not able, then stand in the middle of it, and if you are not able then stand in the first of it. And pray four Rak`ah. Recite Fatihatul-Kitab (the Opening of the Book) and Surat Ya-Sin in the first Rak`ah, and Fatihatul-Kitab and Ha-Mim Ad-Dukhan in the second Rak`ah, and Fatihatul-Kitab and Alif Lam Mim Tanzil As-Sajdah in the third Rak`ah, and Fatihatul-Kitab and Tabarak Al-Mufassal in the fourth Rak`ah. So when you have finished with the Tasha-hud, then praise Allah and mention Allah’s greatness in an excellent manner, and send Salat upon me - and be excellent in it - and upon the rest of the Prophets. And seek forgiveness for the believing men and the believing women, and for your brothers who have preceded you in faith. Then say in the end of that: “O Allah, have mercy on me by abandonment of sins forever, so long as You keep me remaining. And have mercy on me from taking upon myself what does not concern me, and provide me good sight for what will make You pleased with me. O Allah, Originator of the heavens and the earth, Possessor of glory, and generosity, and honor that is not exceeded. I ask you, O Allah, O Rahman, by Your glory and the light of Your Face, to make my heart constant in remembering Your Book as You taught me, and grant me that I recite it in the manner that will make You pleased with me. O Allah, Originator of the heavens and the earth, Possessor of glory, and generosity, and honor that is not exceeded. I ask you, O Allah, O Rahman, by Your glory and the light of Your Face, to enlighten my sight with Your Book, and make my tongue free with it, and to relieve my heart with it, and to expand my chest with it, and to wash my body with it. For indeed, none aids me upon the truth other than You, and none gives it except You, and there is no might or power except by Allah, the High, the Magnificent. (Allāhummarḥamnī bitarkil-ma`āṣī abadan mā abqaitanī, warḥamnī an atakallafa mā lā ya`nīnī, warzuqnī ḥusnan-naẓari fī mā yurḍīka `annī. Allāhumma badī`as-samāwāti wal-arḍi dhal-jalāli wal-ikrāmi wal-`izzatil-latī lā turāmu, as’aluka yā Allāhu yā Raḥmānu bi-jalālika wa nūri wajhika, an tulzima qalbī ḥifẓa kitābika kamā `allamtanī, warzuqnī an atluwahū `alan-naḥwil-ladhī yurḍīka `annī. Allāhumma badī`as-samāwāti wal arḍi dhal-jalāli wal-ikrāmi wal `izzati-llatī lā turāmu, as’aluka yā Allāhu, yā Raḥmānu bi-jalālika wa nūri wajhika, an tunawwira bi-kitābika baṣarī, wa an tuṭliqa bihī lisānī, wa an tufarrija bihī `an qalbī, wa an tashraḥa bihī ṣadrī, wa an taghsila bihī badanī, fa innahu lā yu`īnunī `alal-ḥaqqi ghairuka wa lā yu’tīhi illā anta wa lā ḥawla wa lā quwwata illā billāhil-`Aliyyil-`Aẓīm).” O Abul-Hasan! So do this three Fridays, or five, or seven, you will be answered - by the will of Allah - by the One Who sent me with the Truth, it has not failed a believer once.’” `Abdullah bin `Abbas said: “So, by Allah, `Ali did not wait but five or seven until [`Ali] came to the Messenger of Allah (ﷺ) in a gathering similar to that and said: ‘O Messenger of Allah (ﷺ), indeed I was [a man] in the time that passed, who used to not take except four Ayat or about that much, so when I would recite them to myself they would suddenly depart from me, and today I learn forty Ayat or about that much, and when I recite them to myself, then it is as if the Book of Allah is before my eyes. I used to hear a Hadith and when I would repeat it, it would suddenly depart from me, and today I hear Ahadith, and when I report them, I do not err in a single letter.’ So the Messenger of Allah (ﷺ) said at that point: ‘A believer, by the Lord of the Ka`bah, O Abul-Hasan.’”}}
\hadithdefcmd{tirmidhi}{3571}{حَدَّثَنَا بِشْرُ بْنُ مُعَاذٍ الْعَقَدِيُّ الْبَصْرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ وَاقِدٍ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سَلُوا اللَّهَ مِنْ فَضْلِهِ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ يُحِبُّ أَنْ يُسْأَلَ وَأَفْضَلُ الْعِبَادَةِ انْتِظَارُ الْفَرَجِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رَوَى حَمَّادُ بْنُ وَاقِدٍ هَذَا الْحَدِيثَ وَقَدْ خُولِفَ فِي رِوَايَتِهِ ‏.‏ وَحَمَّادُ بْنُ وَاقِدٍ هَذَا هُوَ الصَّفَّارُ لَيْسَ بِالْحَافِظِ وَهُوَ عِنْدَنَا شَيْخٌ بَصْرِيٌّ ‏.‏ وَرَوَى أَبُو نُعَيْمٍ هَذَا الْحَدِيثَ عَنْ إِسْرَائِيلَ عَنْ حَكِيمِ بْنِ جُبَيْرٍ عَنْ رَجُلٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلٌ وَحَدِيثُ أَبِي نُعَيْمٍ أَشْبَهُ أَنْ يَكُونَ أَصَحَّ ‏.‏\hadithno{3571}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah narrated that the Messenger of Allah (ﷺ) said:“Ask Allah of His Bounty. For verily, Allah the Mighty and Sublime, loves to be asked, and the best of worship is awaiting relief.”}}
\hadithdefcmd{tirmidhi}{3572}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ أَبِي عُثْمَانَ، عَنْ زَيْدِ بْنِ أَرْقَمَ، رضى الله عنه قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنَ الْكَسَلِ وَالْعَجْزِ وَالْبُخْلِ ‏"‏ ‏.‏ وَبِهَذَا الإِسْنَادِ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَتَعَوَّذُ مِنَ الْهَرَمِ وَعَذَابِ الْقَبْرِ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3572}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Zaid bin Arqam [may Allah be pleased with him] said that the Prophet (ﷺ) used to say:“O Allah, indeed I seek refuge in You from laziness, helpless old age, and stinginess (Allāhumma innī a`ūdhu bika minal-kasali wal-`ajzi wal-bukhl).” And with this chain, from the Prophet (ﷺ), that he used to seek refuge from senility and the punishment of the grave}}
\hadithdefcmd{tirmidhi}{3573}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنِ ابْنِ ثَوْبَانَ، عَنْ أَبِيهِ، عَنْ مَكْحُولٍ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، أَنَّ عُبَادَةَ بْنَ الصَّامِتِ، حَدَّثَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا عَلَى الأَرْضِ مُسْلِمٌ يَدْعُو اللَّهَ بِدَعْوَةٍ إِلاَّ آتَاهُ اللَّهُ إِيَّاهَا أَوْ صَرَفَ عَنْهُ مِنَ السُّوءِ مِثْلَهَا مَا لَمْ يَدْعُ بِمَأْثَمٍ أَوْ قَطِيعَةِ رَحِمٍ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ إِذًا نُكْثِرَ ‏.‏ قَالَ ‏"‏ اللَّهُ أَكْثَرُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَابْنُ ثَوْبَانَ هُوَ عَبْدُ الرَّحْمَنِ بْنُ ثَابِتِ بْنِ ثَوْبَانَ الْعَابِدُ الشَّامِيُّ ‏.‏\hadithno{3573}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Jubair bin Nufair narrated that `Ubadah bin As-Samit narrated to them that, the Messenger of Allah (ﷺ) said:“There is not a Muslim upon the earth who calls upon Allah with any supplication, except that Allah grants it to him, or he turns away from him the like of it in evil; as long as he does not supplicate for something sinful, or the severing of the ties of kinship.” So a man from the people said: “What if we should increase (in it)” He (ﷺ) said: “(With) Allah is more.”}}
\hadithdefcmd{tirmidhi}{3574}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، حَدَّثَنِي الْبَرَاءُ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا أَخَذْتَ مَضْجَعَكَ فَتَوَضَّأْ وُضُوءَكَ لِلصَّلاَةِ ثُمَّ اضْطَجِعْ عَلَى شِقِّكَ الأَيْمَنِ ثُمَّ قُلِ اللَّهُمَّ أَسْلَمْتُ وَجْهِي إِلَيْكَ وَفَوَّضْتُ أَمْرِي إِلَيْكَ وَأَلْجَأْتُ ظَهْرِي إِلَيْكَ رَهْبَةً وَرَغْبَةً إِلَيْكَ لاَ مَلْجَأَ وَلاَ مَنْجَا مِنْكَ إِلاَّ إِلَيْكَ آمَنْتُ بِكِتَابِكَ الَّذِي أَنْزَلْتَ وَبِنَبِيِّكَ الَّذِي أَرْسَلْتَ ‏.‏ فَإِنْ مُتَّ فِي لَيْلَتِكَ مُتَّ عَلَى الْفِطْرَةِ ‏"‏ ‏.‏ قَالَ فَرَدَّدْتُهُنَّ لأَسْتَذْكِرَهُ فَقُلْتُ آمَنْتُ بِرَسُولِكَ الَّذِي أَرْسَلْتَ فَقَالَ ‏"‏ قُلْ آمَنْتُ بِنَبِيِّكَ الَّذِي أَرْسَلْتَ ‏"‏ ‏.‏ قَالَ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنِ الْبَرَاءِ وَلاَ نَعْلَمُ فِي شَيْءٍ مِنَ الرِّوَايَاتِ ذُكِرَ الْوُضُوءُ إِلاَّ فِي هَذَا الْحَدِيثِ ‏.‏\hadithno{3574}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Al-Bara’ bin `Azib narrated that the Prophet (ﷺ) said:“When you go to your bed, perform the Wudu’ as you would perform for Salat. Then lie on your right side, then say: ‘O Allah, I submit my face to You, and I entrust my affair to You, and I lay myself down relying upon You, hoping in You and fearing You. There is no refuge nor escape from You except to You. I believe in Your Book which You have revealed, and in Your Prophet whom You have sent (Allāhumma aslamtu wajhī ilaika wa fawwaḍtu amrī ilaika, wa alja’tu ẓahrī ilaika, raghbatan wa rahbatan ilaika, lā malja’a wa lā manjā minka illā ilaika, āmantu bikitābikalladhī anzalta wa bi-nabiyykalladhī arsalt).’ And if you die that night, you shall die upon the Fitrah” - Al-Bara’ said: I repeated it to retain it in memory, “So I said: ‘I believe in Your Messenger whom You have sent.’” He said: “So he (ﷺ) struck with his hand upon my chest, then said: ‘And in Your Prophet whom You have sent.’”}}
\hadithdefcmd{tirmidhi}{3575}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ أَبِي فُدَيْكٍ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ أَبِي سَعِيدٍ الْبَرَّادِ، عَنْ مُعَاذِ بْنِ عَبْدِ اللَّهِ بْنِ خُبَيْبٍ، عَنْ أَبِيهِ، قَالَ خَرَجْنَا فِي لَيْلَةٍ مَطِيرَةٍ وَظُلْمَةٍ شَدِيدَةٍ نَطْلُبُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي لَنَا - قَالَ - فَأَدْرَكْتُهُ فَقَالَ ‏"‏ قُلْ ‏"‏ ‏.‏ فَلَمْ أَقُلْ شَيْئًا ثُمَّ قَالَ ‏"‏ قُلْ ‏"‏ ‏.‏ فَلَمْ أَقُلْ شَيْئًا ‏.‏ قَالَ ‏"‏ قُلْ ‏"‏ ‏.‏ قُلْتُ مَا أَقُولُ قَالَ ‏"‏ قُلْ ‏:‏ ‏(‏ هوَ اللَّهُ أَحَدٌ ‏)‏ وَالْمُعَوِّذَتَيْنِ حِينَ تُمْسِي وَتُصْبِحُ ثَلاَثَ مَرَّاتٍ تَكْفِيكَ مِنْ كُلِّ شَيْءٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَأَبُو سَعِيدٍ الْبَرَّادُ هُوَ أَسِيدُ بْنُ أَبِي أَسِيدٍ مَدَنِيٌّ ‏.‏\hadithno{3575}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Mu`adh bin `Abdullah bin Khubaib, narrated from his father, who said:“We went out on a rainy and extremely dark night, looking for the Messenger of Allah (ﷺ), so that he could lead us in Salat.” He said: “So I met him and he (ﷺ) said: ‘Speak’ but I did not say anything. Then he (ﷺ) said: ‘Speak.’ But I did not say anything. He (ﷺ) said: ‘Speak.’ So I said: ‘What should I say?’ He (ﷺ) said: ‘Say: “Say: He is Allah, the One” and Al-Mu`awwidhatain, when you reach evening, and when you reach morning, three times, they will suffice you against everything.’”}}
\hadithdefcmd{tirmidhi}{3576}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ يَزِيدَ بْنِ خُمَيْرٍ الشَّامِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ، قَالَ نَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى أَبِي فَقَرَّبْنَا إِلَيْهِ طَعَامًا فَأَكَلَ مِنْهُ ثُمَّ أُتِيَ بِتَمْرٍ فَكَانَ يَأْكُلُ وَيُلْقِي النَّوَى بِأُصْبُعَيْهِ جَمَعَ السَّبَّابَةَ وَالْوُسْطَى قَالَ شُعْبَةُ وَهُوَ ظَنِّي فِيهِ إِنْ شَاءَ اللَّهُ فَأَلْقَى النَّوَى بَيْنَ أُصْبُعَيْنِ ثُمَّ أُتِيَ بِشَرَابٍ فَشَرِبَهُ ثُمَّ نَاوَلَهُ الَّذِي عَنْ يَمِينِهِ قَالَ فَقَالَ أَبِي وَأَخَذَ بِلِجَامِ دَابَّتِهِ ادْعُ لَنَا ‏.‏ فَقَالَ ‏ "‏ اللَّهُمَّ بَارِكْ لَهُمْ فِيمَا رَزَقْتَهُمْ وَاغْفِرْ لَهُمْ وَارْحَمْهُمْ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ أَيْضًا مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ ‏.‏\hadithno{3576}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abdullah bin Busr narrated:“The Messenger of Allah (ﷺ) stayed with my father.” So he said: “We brought some food near him, so he ate from it, then he was brought dates, so he would eat it and cast the pit with his two fingers” - he joined between his forefinger and middle finger - Shu`bah said: “And that is what I think concerning it, if Allah wills.” - “and he cast the pit between two fingers, then he was brought drink, so he drank it and then passed it to the one on his right.” He said: “So my father said - as he took hold of the rein of his beast: ‘Supplicate for us.’ So he said: ‘O Allah, bless for them what You have provided them, and forgive them, and have mercy on them (Allāhumma bārik lahum fī mā razaqtahum waghfir lahum warḥamhum).’”}}
\hadithdefcmd{tirmidhi}{3577}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَفْصُ بْنُ عُمَرَ الشَّنِّيُّ، حَدَّثَنِي أَبِي عُمَرُ بْنُ مُرَّةَ، قَالَ سَمِعْتُ بِلاَلَ بْنَ يَسَارِ بْنِ زَيْدٍ، مَوْلَى النَّبِيِّ صلى الله عليه وسلم حَدَّثَنِي أَبِي عَنْ جَدِّي سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ قَالَ أَسْتَغْفِرُ اللَّهَ الْعَظِيمَ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ الْحَىَّ الْقَيُّومَ وَأَتُوبُ إِلَيْهِ ‏.‏ غُفِرَ لَهُ وَإِنْ كَانَ فَرَّ مِنَ الزَّحْفِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3577}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Bilal bin Yasar bin Zaid [the freed slave of the Prophet(ﷺ)] narrated:“My father narrated to me, from my grandfather, that he heard the Prophet (ﷺ) say: ‘Whoever says: “I seek forgiveness from Allah, the Magnificent, whom there is none worthy of worship but Him, the Living, Al-Qayyum, and I repent to him,” (Astaghfirullāhal-`Aẓīm alladhī lā ilāha illā huwal-Ḥayyul-Qayyūmu wa atūbu ilaih) then Allah will forgive him, even if he fled from battle.’”}}
\hadithdefcmd{tirmidhi}{3578}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي جَعْفَرٍ، عَنْ عُمَارَةَ بْنِ خُزَيْمَةَ بْنِ ثَابِتٍ، عَنْ عُثْمَانَ بْنِ حُنَيْفٍ، أَنَّ رَجُلاً، ضَرِيرَ الْبَصَرِ أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ ادْعُ اللَّهَ أَنْ يُعَافِيَنِي ‏.‏ قَالَ ‏"‏ إِنْ شِئْتَ دَعَوْتُ وَإِنْ شِئْتَ صَبَرْتَ فَهُوَ خَيْرٌ لَكَ ‏"‏ ‏.‏ قَالَ فَادْعُهُ ‏.‏ قَالَ فَأَمَرَهُ أَنْ يَتَوَضَّأَ فَيُحْسِنَ وُضُوءَهُ وَيَدْعُوَ بِهَذَا الدُّعَاءِ ‏"‏ اللَّهُمَّ إِنِّي أَسْأَلُكَ وَأَتَوَجَّهُ إِلَيْكَ بِنَبِيِّكَ مُحَمَّدٍ نَبِيِّ الرَّحْمَةِ إِنِّي تَوَجَّهْتُ بِكَ إِلَى رَبِّي فِي حَاجَتِي هَذِهِ لِتُقْضَى لِي اللَّهُمَّ فَشَفِّعْهُ فِيَّ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ أَبِي جَعْفَرٍ وَهُوَ غَيْرُ الْخَطْمِيِّ وَعُثْمَانُ بْنُ حُنَيْفٍ هُوَ أَخُو سَهْلِ بْنِ حُنَيْفٍ ‏.‏\hadithno{3578}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Uthman bin Hunaif narrated that a blind man came to the Prophet (ﷺ) and said:“Supplicate to Allah to heal me.” He (ﷺ) said: “If you wish I will supplicate for you, and if you wish, you can be patient, for that is better for you.” He said: “Then supplicate to Him.” He said: “So he ordered him to perform Wudu’ and to make his Wudu’ complete, and to supplicate with this supplication: ‘O Allah, I ask You and turn towards You by Your Prophet Muhammad (ﷺ), the Prophet of Mercy. Indeed, I have turned to my Lord, by means of You, concerning this need of mine, so that it can be resolved, so O Allah so accept his intercession for me (Allāhumma innī as’aluka wa atawajjahu ilaika binabiyyka Muḥammadin nabi-ir-raḥmati, innī tawajjahtu bika ila rabbī fī ḥājatī hādhihī lituqḍā lī, Allāhumma fashaffi`hu fīyya).’”}}
\hadithdefcmd{tirmidhi}{3579}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا إِسْحَاقُ بْنُ عِيسَى، حَدَّثَنِي مَعْنٌ، حَدَّثَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ ضَمْرَةَ بْنِ حَبِيبٍ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ، رَضِيَ اللَّهُ عَنْهُ يَقُولُ حَدَّثَنِي عَمْرُو بْنُ عَبَسَةَ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَقْرَبُ مَا يَكُونُ الرَّبُّ مِنَ الْعَبْدِ فِي جَوْفِ اللَّيْلِ الآخِرِ فَإِنِ اسْتَطَعْتَ أَنْ تَكُونَ مِمَّنْ يَذْكُرُ اللَّهَ فِي تِلْكَ السَّاعَةِ فَكُنْ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3579}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Umamah [may Allah be pleased with him] said:`Amr bin `Abasah reported to me that he heard the Prophet (ﷺ) say: “The closest that the Lord is to a worshipper is during the last part of the night, so if you are able to be of those who remember Allah in that hour, then do so.”}}
\hadithdefcmd{tirmidhi}{3580}{حَدَّثَنَا أَبُو الْوَلِيدِ الدِّمَشْقِيُّ، أَحْمَدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ بَكَّارٍ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عُفَيْرُ بْنُ مَعْدَانَ، أَنَّهُ سَمِعَ أَبَا دَوْسٍ الْيَحْصُبِيَّ، يُحَدِّثُ عَنِ ابْنِ عَائِذٍ الْيَحْصُبِيِّ، عَنْ عُمَارَةَ بْنِ زَعْكَرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَقُولُ إِنَّ عَبْدِي كُلَّ عَبْدِي الَّذِي يَذْكُرُنِي وَهُوَ مُلاَقٍ قِرْنَهُ ‏"‏ ‏.‏ يَعْنِي عِنْدَ الْقِتَالِ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ لَيْسَ إِسْنَادُهُ بِالْقَوِيِّ ‏.‏ - وَلاَ نَعْرِفُ لِعُمَارَةَ بْنِ زَعْكَرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ هَذَا الْحَدِيثَ الْوَاحِدَ ‏.‏ وَمَعْنَى قَوْلِهِ وَهُوَ مُلاَقٍ قِرْنَهُ ‏.‏ إِنَّمَا يَعْنِي عِنْدَ الْقِتَالِ يَعْنِي أَنْ يَذْكُرَ اللَّهَ فِي تِلْكَ السَّاعَةِ ‏.‏\hadithno{3580}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Umarah bin Za`karah said:“I heard the Messenger of Allah (ﷺ) saying; ‘Indeed, Allah, the Mighty and Sublime, says: “Indeed My worshipper who is entirely My slave is the one who remembers Me when he is about to meet his enemy.” That is: “At the time of fighting.”}}
\hadithdefcmd{tirmidhi}{3581}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ مَنْصُورَ بْنَ زَاذَانَ، يُحَدِّثُ عَنْ مَيْمُونِ بْنِ أَبِي شَبِيبٍ، عَنْ قَيْسِ بْنِ سَعْدِ بْنِ عُبَادَةَ، أَنَّ أَبَاهُ، دَفَعَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم يَخْدُمُهُ ‏.‏ قَالَ فَمَرَّ بِيَ النَّبِيُّ صلى الله عليه وسلم وَقَدْ صَلَّيْتُ فَضَرَبَنِي بِرِجْلِهِ وَقَالَ ‏"‏ أَلاَ أَدُلُّكَ عَلَى بَابٍ مِنْ أَبْوَابِ الْجَنَّةِ ‏"‏ ‏.‏ قُلْتُ بَلَى ‏.‏ قَالَ ‏"‏ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3581}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Qais bin Sa`d bin `Ubadah narrated, :that his father offered him to the Prophet (ﷺ) to serve him. He said: “So the Prophet (ﷺ) passed by me, and I had just performed Salat, so he poked me with his foot and said: ‘Should I not direct you to a gate from the gates of Paradise?’ I said: ‘Of course.’ He (ﷺ) said: ‘There is no might or power except with Allah (Lā ḥawla wa lā quwwata illā billāh).’”}}
\hadithdefcmd{tirmidhi}{3582}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، قَالَ مَا نَهَضَ مَلَكٌ مِنَ الأَرْضِ حَتَّى قَالَ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏.‏\hadithno{3582}\hadithgrade{Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Safwan bin Sulaim said:“No angel has risen from the earth until he said: ‘There is no might or power except with Allah (Lā ḥawla wa lā quwwata illā billāh).’”}}
\hadithdefcmd{tirmidhi}{3583}{حَدَّثَنَا مُوسَى بْنُ حِزَامٍ، وَعَبْدُ بْنُ حُمَيْدٍ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، فَقَالَ سَمِعْتُ هَانِئَ بْنَ عُثْمَانَ، عَنْ أُمِّهِ، حُمَيْضَةَ بِنْتِ يَاسِرٍ عَنْ جَدَّتِهَا، يُسَيْرَةَ وَكَانَتْ مِنَ الْمُهَاجِرَاتِ قَالَتْ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلَيْكُنَّ بِالتَّسْبِيحِ وَالتَّهْلِيلِ وَالتَّقْدِيسِ وَاعْقِدْنَ بِالأَنَامِلِ فَإِنَّهُنَّ مَسْئُولاَتٌ مُسْتَنْطَقَاتٌ وَلاَ تَغْفُلْنَ فَتَنْسَيْنَ الرَّحْمَةَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ هَانِئِ بْنِ عُثْمَانَ وَقَدْ رَوَى مُحَمَّدُ بْنُ رَبِيعَةَ عَنْ هَانِئِ بْنِ عُثْمَانَ ‏.‏\hadithno{3583}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Humaidah bint Yasir narrated from her grandmother Yusairah - and she was one of those who emigrated - she said:“The Messenger of Allah (ﷺ) said to us: ‘Hold fast to At-Tasbih, At-Tahlil, and At-Taqdis, and count them upon the fingertips, for indeed they shall be questioned, and they will be made to speak. And do not become heedless, so that you forget about the Mercy (of Allah).’”}}
\hadithdefcmd{tirmidhi}{3584}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، أَخْبَرَنِي أَبِي، عَنِ الْمُثَنَّى بْنِ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا غَزَا قَالَ ‏ "‏ اللَّهُمَّ أَنْتَ عَضُدِي وَأَنْتَ نَصِيرِي وَبِكَ أُقَاتِلُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَمَعْنَى قَوْلِهِ عَضُدِي ‏.‏ يَعْنِي عَوْنِي ‏.‏\hadithno{3584}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Anas narrated that when the Prophet (ﷺ) would go out for an expedition, he would say:“O Allah, You are my `Aḍud and You are my Helper, and by You do I fight (Allāhumma anta `aḍudī, wa anta naṣīrī, wa bika uqātil).”}}
\hadithdefcmd{tirmidhi}{3585}{حَدَّثَنَا أَبُو عَمْرٍو، مُسْلِمُ بْنُ عَمْرٍو الْحَذَّاءُ الْمَدِينِيُّ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ نَافِعٍ، عَنْ حَمَّادِ بْنِ أَبِي حُمَيْدٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ الدُّعَاءِ دُعَاءُ يَوْمِ عَرَفَةَ وَخَيْرُ مَا قُلْتُ أَنَا وَالنَّبِيُّونَ مِنْ قَبْلِي لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ لَهُ الْمُلْكُ وَلَهُ الْحَمْدُ وَهُوَ عَلَى كُلِّ شَيْءٍ قَدِيرٌ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَحَمَّادُ بْنُ أَبِي حُمَيْدٍ هُوَ مُحَمَّدُ بْنُ أَبِي حُمَيْدٍ وَهُوَ أَبُو إِبْرَاهِيمَ الأَنْصَارِيُّ الْمَدَنِيُّ وَلَيْسَ هُوَ بِالْقَوِيِّ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏\hadithno{3585}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Amr bin Shu`aib narrated from his father, from his grandfather, that the Prophet (ﷺ) said:“The best of supplication is the supplication of the Day of `Arafah. And the best of what I and the Prophets before me have said is: None has the right to be worshipped but Allah, Alone, without partner, to Him belongs all that exists, and to Him belongs the Praise, and He is powerful over all things. (Lā ilāha illallāh, waḥdahu lā sharīka lahu, lahul-mulku wa lahul-ḥamdu, wa huwa `alā kulli shai’in qadīr).’”}}
\hadithdefcmd{tirmidhi}{3586}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَلِيُّ بْنُ أَبِي بَكْرٍ، عَنِ الْجَرَّاحِ بْنِ الضَّحَّاكِ الْكِنْدِيِّ، عَنْ أَبِي شَيْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُكَيْمٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ عَلَّمَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قُلِ اللَّهُمَّ اجْعَلْ سَرِيرَتِي خَيْرًا مِنْ عَلاَنِيَتِي وَاجْعَلْ عَلاَنِيَتِي صَالِحَةً اللَّهُمَّ إِنِّي أَسْأَلُكَ مِنْ صَالِحِ مَا تُؤْتِي النَّاسَ مِنَ الْمَالِ وَالأَهْلِ وَالْوَلَدِ غَيْرِ الضَّالِّ وَلاَ الْمُضِلِّ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ وَلَيْسَ إِسْنَادُهُ بِالْقَوِيِّ ‏.‏\hadithno{3586}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Umar bin Al-Khattab said:“The Messenger of Allah (ﷺ) taught me, saying: ‘Say: “O Allah, make my secret better than my apparent condition, and make my apparent condition righteous. O Allah, I ask You for the righteous of what you give to the people, of wealth, wives, and children, not (to be) misguided, nor misguiding. (Allāhummaj`al sarīratī khairan min `alāniyatī waj`al `alāniyatī ṣāliha. Allāhumma innī as’aluka min ṣālihi mā tu’tin-nāsa minal-māli wal-ahli wal waladi, ghairaḍ-ḍāli wa lal-muḍil).”}}
\hadithdefcmd{tirmidhi}{3587}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ، حَدَّثَنَا سَعِيدُ بْنُ سُفْيَانَ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَعْدَانَ، أَخْبَرَنِي عَاصِمُ بْنُ كُلَيْبٍ الْجَرْمِيُّ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ دَخَلْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يُصَلِّي وَقَدْ وَضَعَ يَدَهُ الْيُسْرَى عَلَى فَخِذِهِ الْيُسْرَى وَوَضَعَ يَدَهُ الْيُمْنَى عَلَى فَخِذِهِ الْيُمْنَى وَقَبَضَ أَصَابِعَهُ وَبَسَطَ السَّبَّابَةَ وَهُوَ يَقُولُ ‏ "‏ يَا مُقَلِّبَ الْقُلُوبِ ثَبِّتْ قَلْبِي عَلَى دِينِكَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3587}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Asim bin Kulaib Al-Jarmi narrated from his father, from his grandfather, who said:“I entered upon the Prophet (ﷺ) while he was praying and he had placed his left hand on his left thigh, and he had placed his right hand on his right thigh, and clasped his fingers, and extended his index finger, and he was saying: ‘O changer of the hearts, make my heart firm upon Your religion (Yā muqallibal-qulūbi thabbit qalbī `alā dīnik).’”}}
\hadithdefcmd{tirmidhi}{3588}{حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ، حَدَّثَنِي أَبِي، حَدَّثَنَا مُحَمَّدُ بْنُ سَالِمٍ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، قَالَ قَالَ لِي يَا مُحَمَّدُ إِذَا اشْتَكَيْتَ فَضَعْ يَدَكَ حَيْثُ تَشْتَكِي وَقُلْ بِسْمِ اللَّهِ أَعُوذُ بِعِزَّةِ اللَّهِ وَقُدْرَتِهِ مِنْ شَرِّ مَا أَجِدُ مِنْ وَجَعِي هَذَا ثُمَّ ارْفَعْ يَدَكَ ثُمَّ أَعِدْ ذَلِكَ وِتْرًا فَإِنَّ أَنَسَ بْنَ مَالِكٍ حَدَّثَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَدَّثَهُ بِذَلِكَ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَمُحَمَّدُ بْنُ سَالِمٍ هَذَا شَيْخٌ بَصْرِيٌّ ‏.‏\hadithno{3588}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Muhammad bin Sulaim narrated:“Thabit Al-Bunani narrated to me, he said to me: ‘O Muhammad, when you suffer from some ailment, then place your hand at the place of the ailment, then say: “In the Name of Allah, I seek refuge in Allah’s might and power from the evil of this pain I feel (Bismillāh, a`ūdhu bi-`izzatillāhi wa qudratihī min sharri mā ajidu min waja`ī hādhā).” Then lift your hand and repeat that an odd number of times. For indeed, Anas bin Malik narrated to me, that the Messenger of Allah (ﷺ) narrated that to him.’”}}
\hadithdefcmd{tirmidhi}{3589}{حَدَّثَنَا حُسَيْنُ بْنُ عَلِيِّ بْنِ الأَسْوَدِ الْبَغْدَادِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنْ حَفْصَةَ بِنْتِ أَبِي كَثِيرٍ، عَنْ أَبِيهَا أَبِي كَثِيرٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ عَلَّمَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قُولِي اللَّهُمَّ هَذَا اسْتِقْبَالُ لَيْلِكَ وَإِدْبَارُ نَهَارِكَ وَأَصْوَاتُ دُعَاتِكَ وَحُضُورُ صَلَوَاتِكَ أَسْأَلُكَ أَنْ تَغْفِرَ لِي ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ غَرِيبٌ إِنَّمَا نَعْرِفُهُ مِنْ هَذَا الْوَجْهِ ‏.‏ وَحَفْصَةُ بِنْتُ أَبِي كَثِيرٍ لاَ نَعْرِفُهَا وَلاَ أَبَاهَا ‏.‏\hadithno{3589}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Umm Salamah said:“The Messenger of Allah (ﷺ) taught me, saying: ‘Say: “O Allah, this is the coming of Your night, and the departing of Your day, the voices of those calling to You, and the time of prayers to You, I ask You to forgive me (Allāhumma hādhastiqbālu lailika, wastidbāru nahārika, wa aṣwātu du`ātika wa ḥuḍūru ṣalawātika, as’aluka an taghfira lī).”}}
\hadithdefcmd{tirmidhi}{3590}{حَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيِّ بْنِ يَزِيدَ الصُّدَائِيُّ الْبَغْدَادِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ الْقَاسِمِ بْنِ الْوَلِيدِ الْهَمْدَانِيُّ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا قَالَ عَبْدٌ لاَ إِلَهَ إِلاَّ اللَّهُ قَطُّ مُخْلِصًا إِلاَّ فُتِحَتْ لَهُ أَبْوَابُ السَّمَاءِ حَتَّى تُفْضِيَ إِلَى الْعَرْشِ مَا اجْتَنَبَ الْكَبَائِرَ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3590}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah [may Allah be pleased with him] narrated that the Messenger of Allah (ﷺ) said:“No worshipper has ever said: None has the right to be worshipped but Allah (Lā ilāha illallāh)’ sincerely, except that the gates of heaven are opened for it, until it reaches to the Throne, so long as he avoids the major sins.”}}
\hadithdefcmd{tirmidhi}{3591}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَحْمَدُ بْنُ بَشِيرٍ، وَأَبُو أُسَامَةَ عَنْ مِسْعَرٍ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ عَمِّهِ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنِّي أَعُوذُ بِكَ مِنْ مُنْكَرَاتِ الأَخْلاَقِ وَالأَعْمَالِ وَالأَهْوَاءِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَعَمُّ زِيَادِ بْنِ عِلاَقَةَ هُوَ قُطْبَةُ بْنُ مَالِكٍ صَاحِبُ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{3591}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ziyad bin `Ilaqah narrated from his uncle, that he said:“[The Prophet (ﷺ)] used to say: ‘O Allah, I seek refuge in You from evil character, evil actions, and evil desires (Allāhumma innī a`ūdhu bika min munkarātil-akhlāqi wal-a`māli wal-ahwā’).’”}}
\hadithdefcmd{tirmidhi}{3592}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْحَجَّاجُ بْنُ أَبِي عُثْمَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ عَوْنِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عُمَرَ، رضى الله عنهما قَالَ بَيْنَمَا نَحْنُ نُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ قَالَ رَجُلٌ مِنَ الْقَوْمِ اللَّهُ أَكْبَرُ كَبِيرًا وَالْحَمْدُ لِلَّهِ كَثِيرًا وَسُبْحَانَ اللَّهِ بُكْرَةً وَأَصِيلاً ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنِ الْقَائِلُ كَذَا وَكَذَا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ أَنَا يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ عَجِبْتُ لَهَا فُتِحَتْ لَهَا أَبْوَابُ السَّمَاءِ ‏"‏ ‏.‏ قَالَ ابْنُ عُمَرَ مَا تَرَكْتُهُنَّ مُنْذُ سَمِعْتُهُنَّ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَحَجَّاجُ بْنُ أَبِي عُثْمَانَ هُوَ حَجَّاجُ بْنُ مَيْسَرَةَ الصَّوَّافُ وَيُكْنَى أَبَا الصَّلْتِ وَهُوَ ثِقَةٌ عِنْدَ أَهْلِ الْحَدِيثِ ‏.‏\hadithno{3592}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Ibn `Umar [may Allah be pleased with him] said:“We were with the Messenger of Allah (ﷺ) when a man among the people said: ‘Allah is most exceedingly great, and praise is due to Allah, abundantly, and glory to Allah morning and night (Allāhu akbaru kabīran wal-ḥamdulillāhi kathīran wa subḥānallāhi bukratan wa aṣīlā).’ So the Messenger of Allah (ﷺ) said: ‘Who is the one who said such and such?’ So a man among the people said: ‘Me, O Messenger of Allah (ﷺ).’ He said: ‘I was amazed at it. The gates of heaven opened up for it.’” Ibn `Umar said: “I have not abandoned them since I heard [them] from the Messenger of Allah (ﷺ).”}}
\hadithdefcmd{tirmidhi}{3593}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْجُرَيْرِيُّ، عَنْ أَبِي عَبْدِ اللَّهِ الْجَسْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عَادَهُ أَوْ أَنَّ أَبَا ذَرٍّ عَادَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ بِأَبِي أَنْتَ يَا رَسُولَ اللَّهِ أَىُّ الْكَلاَمِ أَحَبُّ إِلَى اللَّهِ عَزَّ وَجَلَّ قَالَ ‏ "‏ مَا اصْطَفَى اللَّهُ لِمَلاَئِكَتِهِ سُبْحَانَ رَبِّي وَبِحَمْدِهِ سُبْحَانَ رَبِّي وَبِحَمْدِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3593}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Dharr narrated that the Messenger of Allah (ﷺ) visited him, or that Abu Dharr visited the Messenger of Allah (ﷺ), and said:“May my father and my mother be ransomed for you, O Messenger of Allah (ﷺ)! Which speech is most beloved to Allah [the Mighty and Sublime]?” So he said: “That which Allah selected for His angels (to say): ‘Glory to my Lord, and with His praise. Glory to my Lord, and with His praise (Subḥāna rabbī wa biḥamdihi, subḥāna rabbī wa biḥamdihi).’”}}
\hadithdefcmd{tirmidhi}{3594}{حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، مُحَمَّدُ بْنُ يَزِيدَ الْكُوفِيُّ حَدَّثَنَا يَحْيَى بْنُ الْيَمَانِ، حَدَّثَنَا سُفْيَانُ، عَنْ زَيْدٍ الْعَمِّيِّ، عَنْ أَبِي إِيَاسٍ، مُعَاوِيَةَ بْنِ قُرَّةَ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الدُّعَاءُ لاَ يُرَدُّ بَيْنَ الأَذَانِ وَالإِقَامَةِ ‏"‏ ‏.‏ قَالُوا فَمَاذَا نَقُولُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ سَلُوا اللَّهَ الْعَافِيَةَ فِي الدُّنْيَا وَالآخِرَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ زَادَ يَحْيَى بْنُ الْيَمَانِ فِي هَذَا الْحَدِيثِ هَذَا الْحَرْفَ قَالُوا فَمَاذَا نَقُولُ قَالَ ‏"‏ سَلُوا اللَّهَ الْعَافِيَةَ فِي الدُّنْيَا وَالآخِرَةِ ‏"‏ ‏.‏\hadithno{3594}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that the Messenger of Allah (ﷺ) said:“The supplication is not rejected between the Adhan and the Iqamah.” They said: “So what should we say, O Messenger of Allah (ﷺ)?” He said: “Ask Allah for Al-`Afiyah in the world and in the Hereafter.”}}
\hadithdefcmd{tirmidhi}{3595}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، وَعَبْدُ الرَّزَّاقِ، وَأَبُو أَحْمَدَ وَأَبُو نُعَيْمٍ عَنْ سُفْيَانَ، عَنْ زَيْدٍ الْعَمِّيِّ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الدُّعَاءُ لاَ يُرَدُّ بَيْنَ الأَذَانِ وَالإِقَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَكَذَا رَوَى أَبُو إِسْحَاقَ الْهَمْدَانِيُّ هَذَا الْحَدِيثَ عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ الْكُوفِيِّ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا وَهَذَا أَصَحُّ ‏.‏\hadithno{3595}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas [bin Malik] narrated that the Prophet (ﷺ) said:“The supplication is not rejected between the Adhan and the Iqamah.”}}
\hadithdefcmd{tirmidhi}{3596}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ عُمَرَ بْنِ رَاشِدٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَبَقَ الْمُفْرِدُونَ ‏"‏ ‏.‏ قَالُوا وَمَا الْمُفْرِدُونَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الْمُسْتَهْتَرُونَ فِي ذِكْرِ اللَّهِ يَضَعُ الذِّكْرُ عَنْهُمْ أَثْقَالَهُمْ فَيَأْتُونَ يَوْمَ الْقِيَامَةِ خِفَافًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{3596}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“The Mufarridun have preceded.” They said: “And who are the Mufarridun, O Messenger of Allah (ﷺ)?” He said: “Those who absorb themselves in the remembrance of Allah, and remembrance removed their heavy burdens from them, until they will come on the Day of Judgement being light (in weight of their burdens).”}}
\hadithdefcmd{tirmidhi}{3597}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ أَقُولَ سُبْحَانَ اللَّهِ وَالْحَمْدُ لِلَّهِ وَلاَ إِلَهَ إِلاَّ اللَّهُ وَاللَّهُ أَكْبَرُ أَحَبُّ إِلَىَّ مِمَّا طَلَعَتْ عَلَيْهِ الشَّمْسُ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3597}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah [may Allah be pleased with him] narrated that the Messenger of Allah (ﷺ) said:“That I should say: ‘Glory is to Allah (Subḥān Allāh).’ ‘All praise is due to Allah (Al-ḥamdulillāh),’ ‘None has the right to be worshipped by Allah (Lā ilāha illallāh),’ and ‘Allah is the greatest (Allāhu akbar)’ is more beloved to me than all that the sun has risen over.”}}
\hadithdefcmd{tirmidhi}{3598}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ سَعْدَانَ الْقُبِّيِّ، عَنْ أَبِي مُجَاهِدٍ، عَنْ أَبِي مُدِلَّةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ لاَ تُرَدُّ دَعْوَتُهُمُ الصَّائِمُ حَتَّى يُفْطِرَ وَالإِمَامُ الْعَادِلُ وَدَعْوَةُ الْمَظْلُومِ يَرْفَعُهَا اللَّهُ فَوْقَ الْغَمَامِ وَيَفْتَحُ لَهَا أَبْوَابَ السَّمَاءِ وَيَقُولُ الرَّبُّ وَعِزَّتِي لأَنْصُرَنَّكَ وَلَوْ بَعْدَ حِينٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ وَسَعْدَانُ الْقُبِّيُّ هُوَ سَعْدَانُ بْنُ بِشْرٍ ‏.‏ وَقَدْ رَوَى عَنْهُ عِيسَى بْنُ يُونُسَ وَأَبُو عَاصِمٍ وَغَيْرُ وَاحِدٍ مِنْ كِبَارِ أَهْلِ الْحَدِيثِ وَأَبُو مُجَاهِدٍ هُوَ سَعْدٌ الطَّائِيُّ وَأَبُو مُدِلَّةَ هُوَ مَوْلَى أُمِّ الْمُؤْمِنِينَ عَائِشَةَ وَإِنَّمَا نَعْرِفُهُ بِهَذَا الْحَدِيثِ وَيُرْوَى عَنْهُ هَذَا الْحَدِيثُ أَتَمَّ مِنْ هَذَا وَأَطْوَلَ ‏.‏\hadithno{3598}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“There are three whose supplication is not rejected: The fasting person when he breaks his fast, the just leader, and the supplication of the oppressed person; Allah raises it up above the clouds and opens the gates of heaven to it. And the Lord says: ‘By My might, I shall surely aid you, even if it should be after a while.’”}}
\hadithdefcmd{tirmidhi}{3599}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ مُوسَى بْنِ عُبَيْدَةَ، عَنْ مُحَمَّدِ بْنِ ثَابِتٍ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ انْفَعْنِي بِمَا عَلَّمْتَنِي وَعَلِّمْنِي مَا يَنْفَعُنِي وَزِدْنِي عِلْمًا الْحَمْدُ لِلَّهِ عَلَى كُلِّ حَالٍ وَأَعُوذُ بِاللَّهِ مِنْ حَالِ أَهْلِ النَّارِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3599}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah, may Allah be pleased with him, narrated that the Messenger of Allah (ﷺ) said:“O Allah, benefit me with that which You have taught me, and teach me that which will benefit me, and increase me in knowledge. All praise is due to Allah in every condition, and I seek refuge in Allah from the condition of the people of the Fire (Allāhummanfa`nī bimā `allamtanī wa `allimnī mā yanfa`unī, wa zidnī `ilma, al-ḥamdulillāhi `alā kulli ḥālin, wa a`ūdhu billāhi min ḥāli ahlin-nār).”}}
\hadithdefcmd{tirmidhi}{3600}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَوْ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالاَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ لِلَّهِ مَلاَئِكَةً سَيَّاحِينَ فِي الأَرْضِ فَضْلاً عَنْ كُتَّابِ النَّاسِ فَإِذَا وَجَدُوا أَقْوَامًا يَذْكُرُونَ اللَّهَ تَنَادَوْا هَلُمُّوا إِلَى بُغْيَتِكُمْ فَيَجِيئُونَ فَيَحُفُّونَ بِهِمْ إِلَى سَمَاءِ الدُّنْيَا فَيَقُولُ اللَّهُ عَلَى أَىِّ شَيْءٍ تَرَكْتُمْ عِبَادِي يَصْنَعُونَ فَيَقُولُونَ تَرَكْنَاهُمْ يَحْمَدُونَكَ وَيُمَجِّدُونَكَ وَيَذْكُرُونَكَ ‏.‏ قَالَ فَيَقُولُ فَهَلْ رَأَوْنِي فَيَقُولُونَ لاَ ‏.‏ قَالَ فَيَقُولُ فَكَيْفَ لَوْ رَأَوْنِي قَالَ فَيَقُولُونَ لَوْ رَأَوْكَ لَكَانُوا أَشَدَّ تَحْمِيدًا وَأَشَدَّ تَمْجِيدًا وَأَشَدَّ لَكَ ذِكْرًا ‏.‏ قَالَ فَيَقُولُ وَأَىُّ شَيْءٍ يَطْلُبُونَ قَالَ فَيَقُولُونَ يَطْلُبُونَ الْجَنَّةَ ‏.‏ قَالَ فَيَقُولُ وَهَلْ رَأَوْهَا قَالَ فَيَقُولُونَ لاَ ‏.‏ قَالَ فَيَقُولُ فَكَيْفَ لَوْ رَأَوْهَا قَالَ فَيَقُولُونَ لَوْ رَأَوْهَا كَانُوا لَهَا أَشَدَّ طَلَبًا وَأَشَدَّ عَلَيْهَا حِرْصًا ‏.‏ قَالَ فَيَقُولُ مِنْ أَىِّ شَيْءٍ يَتَعَوَّذُونَ قَالُوا يَتَعَوَّذُونَ مِنَ النَّارِ ‏.‏ قَالَ فَيَقُولُ وَهَلْ رَأَوْهَا فَيَقُولُونَ لاَ ‏.‏ فَيَقُولُ فَكَيْفَ لَوَ رَأَوْهَا فَيَقُولُونَ لَوْ رَأَوْهَا كَانُوا مِنْهَا أَشَدَّ هَرَبًا وَأَشَدَّ مِنْهَا خَوْفًا وَأَشَدَّ مِنْهَا تَعَوُّذًا ‏.‏ قَالَ فَيَقُولُ فَإِنِّي أُشْهِدُكُمْ أَنِّي قَدْ غَفَرْتُ لَهُمْ ‏.‏ فَيَقُولُونَ إِنَّ فِيهِمْ فُلاَنًا الْخَطَّاءَ لَمْ يُرِدْهُمْ إِنَّمَا جَاءَهُمْ لِحَاجَةٍ ‏.‏ فَيَقُولُ هُمُ الْقَوْمُ لاَ يَشْقَى لَهُمْ جَلِيسٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ عَنْ أَبِي هُرَيْرَةَ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏\hadithno{3600}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah or Abu Sa`eed Al-Khudri narrated that the Messenger of Allah (ﷺ) said:“Indeed, Allah has angels who go about on the earth in addition to the Kuttab of people. So when they find groups of people remembering Allah, they call to one another: ‘Come to that which you have been seeking.’ They will come and cover them up to the lowest heaven. Allah will say: ‘What were My worshippers doing when you left them?’ They will say: ‘We left them as they were praising You, glorifying You, and remembering You.’” He (ﷺ) said: “So He will say: ‘Have they seen Me?’ They say: ‘No.’” He (ﷺ) said: “So He will say: ‘How would it be had they seen Me?’ They will say: ‘Had they seen You, they would have been more ardent in praise of You, more ardent in glorification of You, more ardent in remembrance of You.’” He (ﷺ) said: “So He will say: ‘And what do they seek?’” He (ﷺ) said: “They will say: ‘They seek Paradise.’” He (ﷺ) said: “So He will say: ‘So have they seen it?’” He (ﷺ) said: “So they will say: ‘No.’” He (ﷺ) said: “So He will say: ‘So how would it be had they seen it?’” He (ﷺ) said: “They will say: ‘Had they seen it, they would be more ardent in seeking it, and more eager for it.’” He (ﷺ) said: “So He will say: ‘So from what thing do they seek refuge?’ They will say: ‘They seek refuge from the Fire.’” He (ﷺ) said: “So He will say: ‘And have they seen it?’ So they will say: ‘No.’” He (ﷺ) said: “So He will say: ‘So how would it be had they seen it?’ So they will say: ‘Had they seen it, they would be more ardent in fear of it, and more ardent in seeking refuge from it.’” He (ﷺ) said: “So He will say: ‘So I do call You to witness that I have forgiven them.’ So they will say: ‘Indeed among them is so-and-so, a sinner, he did not intend them, he only came to them for some need.’ So He will say: ‘They are the people, that none who sits with them shall be miserable.’”}}
\hadithdefcmd{tirmidhi}{3601}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ هِشَامِ بْنِ الْغَازِ، عَنْ مَكْحُولٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَكْثِرْ مِنْ قَوْلِ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ فَإِنَّهَا كَنْزٌ مِنْ كُنُوزِ الْجَنَّةِ ‏"‏ ‏.‏ قَالَ مَكْحُولٌ فَمَنْ قَالَ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ وَلاَ مَنْجَا مِنَ اللَّهِ إِلاَّ إِلَيْهِ ‏.‏ كَشَفَ عَنْهُ سَبْعِينَ بَابًا مِنَ الضُّرِّ أَدْنَاهُنَّ الْفَقْرُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ لَيْسَ إِسْنَادُهُ بِمُتَّصِلٍ ‏.‏ مَكْحُولٌ لَمْ يَسْمَعْ مِنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{3601}\hadithgrade{Ahmad Muhammad Shakir: Maqtu; Al-Albani: Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah said:“The Messenger of Allah (ﷺ) said to me: ‘Be frequent in saying: “There is no might or power except by Allah, (Lā ḥawla wa lā quwwata illā billāh).” For verily, it is a treasure from the treasures of Paradise.’”}}
\hadithdefcmd{tirmidhi}{3602}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِكُلِّ نَبِيٍّ دَعْوَةٌ مُسْتَجَابَةٌ وَإِنِّي اخْتَبَأْتُ دَعْوَتِي شَفَاعَةً لأُمَّتِي وَهِيَ نَائِلَةٌ إِنْ شَاءَ اللَّهُ مَنْ مَاتَ مِنْهُمْ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3602}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“Every Prophet has a (special) supplication which is answered. Verily, I have reserved mine as intercession for my nation, and it shall reach, if Allah wills, those of them who die, not associating anything with Allah.”}}
\hadithdefcmd{tirmidhi}{3603}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ نُمَيْرٍ، وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ أَنَا عِنْدَ ظَنِّ عَبْدِي بِي وَأَنَا مَعَهُ حِينَ يَذْكُرُنِي فَإِنْ ذَكَرَنِي فِي نَفْسِهِ ذَكَرْتُهُ فِي نَفْسِي وَإِنْ ذَكَرَنِي فِي مَلإٍ ذَكَرْتُهُ فِي مَلإٍ خَيْرٍ مِنْهُمْ وَإِنِ اقْتَرَبَ إِلَىَّ شِبْرًا اقْتَرَبْتُ مِنْهُ ذِرَاعًا وَإِنِ اقْتَرَبَ إِلَىَّ ذِرَاعًا اقْتَرَبْتُ إِلَيْهِ بَاعًا وَإِنْ أَتَانِي يَمْشِي أَتَيْتُهُ هَرْوَلَةً ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَيُرْوَى عَنِ الأَعْمَشِ فِي تَفْسِيرِ هَذَا الْحَدِيثِ مَنْ تَقَرَّبَ مِنِّي شِبْرًا تَقَرَّبْتُ مِنْهُ ذِرَاعًا يَعْنِي بِالْمَغْفِرَةِ وَالرَّحْمَةِ وَهَكَذَا فَسَّرَ بَعْضُ أَهْلِ الْعِلْمِ هَذَا الْحَدِيثَ ‏.‏ قَالُوا إِنَّمَا مَعْنَاهُ يَقُولُ إِذَا تَقَرَّبَ إِلَىَّ الْعَبْدُ بِطَاعَتِي وَمَا أَمَرْتُ أُسْرِعُ إِلَيْهِ بِمَغْفِرَتِي وَرَحْمَتِي ‏.‏ وَرُوِيَ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، أَنَّهُ قَالَ فِي هَذِهِ الآيَةِ ‏:‏ ‏(‏ فاذكُرُونِي أَذْكُرْكُمْ ‏)‏ قَالَ اذْكُرُونِي بِطَاعَتِي أَذْكُرْكُمْ بِمَغْفِرَتِي ‏.‏ حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ قَالَ حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى وَعَمْرُو بْنُ هَاشِمٍ الرَّمْلِيُّ عَنِ ابْنِ لَهِيعَةَ عَنْ عَطَاءِ بْنِ يَسَارٍ عَنْ سَعِيدِ بْنِ جُبَيْرٍ بِهَذَا ‏.‏\hadithno{3603}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah [may Allah be pleased with him] narrated that the Messenger of Allah (ﷺ) said:“Allah, the Most High said: ‘I am as My slave thinks of Me, and I am with him when he remembers Me. If he remembers Me to himself, I remember him to Myself, and if he remembers Me in a gathering, I remember him in a gathering better than that. And if he seeks to draw nearer to Me by a hand span, I draw nearer to him by a forearm’s length, and if he comes to Me by a forearm’s length, I draw nearer to him by an arm’s length. And if he comes to Me walking, I come to him quickly.’”}}
\hadithdefcmd{tirmidhi}{3604}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اسْتَعِيذُوا بِاللَّهِ مِنْ عَذَابِ جَهَنَّمَ اسْتَعِيذُوا بِاللَّهِ مِنْ عَذَابِ الْقَبْرِ اسْتَعِيذُوا بِاللَّهِ مِنْ فِتْنَةِ الْمَسِيحِ الدَّجَّالِ وَاسْتَعِيذُوا بِاللَّهِ مِنْ فِتْنَةِ الْمَحْيَا وَالْمَمَاتِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{3604}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“Seek refuge with Allah from the punishment of Hell, and seek refuge in Allah from the punishment of the grave. Seek refuge in Allah from the trial of Al-Masihid-Dajjal, and seek refuge in Allah from the trials of life and death.”}}
\hadithdefcmd{tirmidhi}{3604p02}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، أَخْبَرَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَالَ حِينَ يُمْسِي ثَلاَثَ مَرَّاتٍ أَعُوذُ بِكَلِمَاتِ اللَّهِ التَّامَّاتِ مِنْ شَرِّ مَا خَلَقَ لَمْ يَضُرَّهُ حُمَةٌ تِلْكَ اللَّيْلَةَ ‏"‏ ‏.‏ قَالَ سُهَيْلٌ فَكَانَ أَهْلُنَا تَعَلَّمُوهَا فَكَانُوا يَقُولُونَهَا كُلَّ لَيْلَةٍ فَلُدِغَتْ جَارِيَةٌ مِنْهُمْ فَلَمْ تَجِدْ لَهَا وَجَعًا ‏.‏ هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَرَوَى مَالِكُ بْنُ أَنَسٍ هَذَا الْحَدِيثَ عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَرَوَى عُبَيْدُ اللَّهِ بْنُ عُمَرَ وَغَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ سُهَيْلٍ وَلَمْ يَذْكُرُوا فِيهِ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{3604.02}\hadithtrans{Abu Hurairah narrated that the Prophet (ﷺ) said:“Whoever says three times when he reaches the evening: ‘I seek refuge in Allah’s Perfect Words from the evil of what he created, (A`ūdhu bikalimātillāhit-tāmmāti min sharri mā khalaq)’ no poisonous sting shall harm him that night.” (One of the narrators) Suhail said: “So our family used to learn it and they used to say it every night. A girl among them was stung, and she did not feel any pain.”}}
\hadithdefcmd{tirmidhi}{3604p03}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، أَخْبَرَنَا وَكِيعٌ، أَخْبَرَنَا أَبُو فَضَالَةَ الْفَرَجُ بْنُ فَضَالَةَ، عَنْ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ دُعَاءٌ حَفِظْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ أَدَعُهُ ‏ "‏ اللَّهُمَّ اجْعَلْنِي أُعَظِّمُ شُكْرَكَ وَأُكْثِرُ ذِكْرَكَ وَأَتَّبِعُ نَصِيحَتَكَ وَأَحْفَظُ وَصِيَّتَكَ ‏"‏ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ ‏.‏\hadithno{3604.03}\hadithtrans{Abu Hurairah said:“There is a supplication that I memorized from the Messenger of Allah which I do not leave off: ‘O Allah, make me revere gratitude to You, make me increase in remembrance to You, make me follow Your advice, and (make me) guard over that which you have commanded (Allāhummaj`alnī u`aẓẓimu shuraka wa ukthiru dhikraka wa attabi`u naṣīḥataka wa aḥfaẓu waṣīyatak).’”This Hadith is Gharib}}
\hadithdefcmd{tirmidhi}{3604p04}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، أَخْبَرَنَا اللَّيْثُ، وَهُوَ ابْنُ أَبِي سُلَيْمٍ عَنْ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ رَجُلٍ يَدْعُو اللَّهَ بِدُعَاءٍ إِلاَّ اسْتُجِيبَ لَهُ فَإِمَّا أَنْ يُعَجَّلَ لَهُ فِي الدُّنْيَا وَإِمَّا أَنْ يُدَّخَرَ لَهُ فِي الآخِرَةِ وَإِمَّا أَنْ يُكَفَّرَ عَنْهُ مِنْ ذُنُوبِهِ بِقَدْرِ مَا دَعَا مَا لَمْ يَدْعُ بِإِثْمٍ أَوْ قَطِيعَةِ رَحِمٍ أَوْ يَسْتَعْجِلُ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَكَيْفَ يَسْتَعْجِلُ قَالَ ‏"‏ يَقُولُ دَعَوْتُ رَبِّي فَمَا اسْتَجَابَ لِي ‏"‏ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3604.04}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“There is not a man who calls upon Allah with a supplication, except that he is answered. Either it shall be granted to him in the world, or reserved for him in the Hereafter, or, his sins shall be expiated for it according to the extent that he supplicated - as long as he does not supplicate for some sin, or for the severing of the ties of kinship, and he does not become hasty.” They said: “O Messenger of Allah, and how would he be hasty?” He (ﷺ) said: “He says: ‘I called upon my Lord, but He did not answer me.’”}}
\hadithdefcmd{tirmidhi}{3604p05}{حَدَّثَنَا يَحْيَى، أَخْبَرَنَا يَعْلَى بْنُ عُبَيْدٍ، قَالَ أَخْبَرَنَا يَحْيَى بْنُ عُبَيْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ عَبْدٍ يَرْفَعُ يَدَيْهِ حَتَّى يَبْدُوَ إِبْطُهُ يَسْأَلُ اللَّهَ مَسْأَلَةً إِلاَّ آتَاهَا إِيَّاهُ مَا لَمْ يَعْجَلْ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَكَيْفَ عَجَلَتُهُ قَالَ ‏"‏ يَقُولُ قَدْ سَأَلْتُ وَسَأَلْتُ وَلَمْ أُعْطَ شَيْئًا ‏"‏ ‏.‏ وَرَوَى هَذَا الْحَدِيثَ الزُّهْرِيُّ عَنْ أَبِي عُبَيْدٍ مَوْلَى ابْنِ أَزْهَرَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يُسْتَجَابُ لأَحَدِكُمْ مَا لَمْ يَعْجَلْ يَقُولُ دَعَوْتُ فَلَمْ يُسْتَجَبْ لِي ‏"‏ ‏.‏\hadithno{3604.05}\hadithtrans{Abu Hurairah narrated the the Messenger of Allah (ﷺ) said:“There is not a worshipper who raises his hands, such that his armpit becomes visible, asking Allah for something, except that He shall grant it to him - as long as he does not become hasty.” They said: “O Messenger of Allah, and how is haste made concerning it?” He (ﷺ) said: “He says: ‘I did ask and ask, and I was not given a thing.’”}}
\hadithdefcmd{tirmidhi}{3604p06}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، أَخْبَرَنَا أَبُو دَاوُدَ، أَخْبَرَنَا صَدَقَةُ بْنُ مُوسَى، أَخْبَرَنَا مُحَمَّدُ بْنُ وَاسِعٍ، عَنْ سُمَيْرِ بْنِ نَهَارٍ الْعَبْدِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ حُسْنَ الظَّنِّ بِاللَّهِ مِنْ حُسْنِ عِبَادَةِ اللَّهِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3604.06}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) said:“Indeed, having good thoughts concerning Allah is from the perfection of the worship of Allah.”}}
\hadithdefcmd{tirmidhi}{3604p07}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، أَخْبَرَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِيَنْظُرَنَّ أَحَدُكُمْ مَا الَّذِي يَتَمَنَّى فَإِنَّهُ لاَ يَدْرِي مَا يُكْتَبُ لَهُ مِنْ أُمْنِيَّتِهِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{3604.07}\hadithtrans{Umar bin Abi Salamah narrated from his father, who said:“The Messenger of Allah (ﷺ) said: ‘Let one of you look at what it is that he wishes for. For verily, he does not know what of his wish shall be recorded.’”}}
\hadithdefcmd{tirmidhi}{3604p08}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، أَخْبَرَنَا جَابِرُ بْنُ نُوحٍ، قَالَ أَخْبَرَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُو فَيَقُولُ ‏ "‏ اللَّهُمَّ مَتِّعْنِي بِسَمْعِي وَبَصَرِي وَاجْعَلْهُمَا الْوَارِثَ مِنِّي وَانْصُرْنِي عَلَى مَنْ يَظْلِمُنِي وَخُذْ مِنْهُ بِثَأْرِي ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{3604.08}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah (ﷺ) used to supplicate, saying:“O Allah, give me pleasure in my hearing and my sight, and make it the inheritor from me, and aid me against whoever oppresses me, and take vengeance from him for me (Allāhumma matti`nī bisam`ī wa baṣarī waj`alhumal-wāritha minnī, wanṣurnī `alā man yaẓlimunī, wa khudh minhu bitha’rī)”}}
\hadithdefcmd{tirmidhi}{3604p09}{حَدَّثَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ الأَشْعَثِ السِّجْزِيُّ حَدَّثَنَا قَطَنٌ الْبَصْرِيُّ، أَخْبَرَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِيَسْأَلْ أَحَدُكُمْ رَبَّهُ حَاجَتَهُ كُلَّهَا حَتَّى يَسْأَلَ شِسْعَ نَعْلِهِ إِذَا انْقَطَعَ ‏"‏ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَرَوَى غَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ جَعْفَرِ بْنِ سُلَيْمَانَ عَنْ ثَابِتٍ الْبُنَانِيِّ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَلَمْ يَذْكُرُوا فِيهِ عَنْ أَنَسٍ ‏.‏\hadithno{3604.09}\hadithtrans{Thabit narrated from Anas, who said “The Messenger of Allah (ﷺ) said:‘Let one of you ask his Lord for his every need, even until he asks Him for the strap of his sandal when it breaks.’”}}
\hadithdefcmd{tirmidhi}{3604p1}{حَدَّثَنَا صَالِحُ بْنُ عَبْدِ اللَّهِ، أَخْبَرَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لِيَسْأَلْ أَحَدُكُمْ رَبَّهُ حَاجَتَهُ حَتَّى يَسْأَلَهُ الْمِلْحَ وَحَتَّى يَسْأَلَهُ شِسْعَ نَعْلِهِ إِذَا انْقَطَعَ ‏"‏ ‏.‏ وَهَذَا أَصَحُّ مِنْ حَدِيثِ قَطَنٍ عَنْ جَعْفَرِ بْنِ سُلَيْمَانَ ‏.‏\hadithno{3604.1}\hadithtrans{Thabit Al-Bunani narrated that the Messenger of Allah (ﷺ) said:“Let one of you ask his Lord for his every need, until he asks Him for salt, and asks Him for the strap of his sandal when it breaks.”}}
