% Auto-generated chapter 4 for muslim
% Hadiths in this chapter: 321

\hadithdefcmd{muslim}{837}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالاَ أَخْبَرَنَا ابْنُ جُرَيْجٍ، ح وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي نَافِعٌ، مَوْلَى ابْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ كَانَ الْمُسْلِمُونَ حِينَ قَدِمُوا الْمَدِينَةَ يَجْتَمِعُونَ فَيَتَحَيَّنُونَ الصَّلَوَاتِ وَلَيْسَ يُنَادِي بِهَا أَحَدٌ فَتَكَلَّمُوا يَوْمًا فِي ذَلِكَ فَقَالَ بَعْضُهُمُ اتَّخِذُوا نَاقُوسًا مِثْلَ نَاقُوسِ النَّصَارَى وَقَالَ بَعْضُهُمْ قَرْنًا مِثْلَ قَرْنِ الْيَهُودِ فَقَالَ عُمَرُ أَوَلاَ تَبْعَثُونَ رَجُلاً يُنَادِي بِالصَّلاَةِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا بِلاَلُ قُمْ فَنَادِ بِالصَّلاَةِ ‏"‏ ‏.‏\hadithno{837}\hadithtrans{Ibn Umar reported:When the Muslims came to Medina, they gathered and sought to know the time of prayer but no one summoned them. One day they discussed the matter, and some of them said: Use something like the bell of the Christians and some of them said: Use horn like that of the Jews. Umar said: Why may not a be appointed who should call (people) to prayer? The Messenger of Allah (ﷺ) said: O Bilal, get up and summon (the people) to prayer}}
\hadithdefcmd{muslim}{838}{حَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، جَمِيعًا عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، قَالَ أُمِرَ بِلاَلٌ أَنْ يَشْفَعَ، الأَذَانَ وَيُوتِرَ الإِقَامَةَ ‏.‏ زَادَ يَحْيَى فِي حَدِيثِهِ عَنِ ابْنِ عُلَيَّةَ فَحَدَّثْتُ بِهِ أَيُّوبَ فَقَالَ إِلاَّ الإِقَامَةَ ‏.‏\hadithno{838}\hadithtrans{Anas reported:Bilal was commanded (by the Messenger of Allah) to repeat (the phrases of) Adhan twice and once in Iqama. The narrator said: I made a mention of it before Ayyub who said: Except for saying: Qamat-is-Salat [the time for prayer has come]}}
\hadithdefcmd{muslim}{839}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ ذَكَرُوا أَنْ يُعْلِمُوا، وَقْتَ الصَّلاَةِ بِشَىْءٍ يَعْرِفُونَهُ فَذَكَرُوا أَنْ يُنَوِّرُوا نَارًا أَوْ يَضْرِبُوا نَاقُوسًا فَأُمِرَ بِلاَلٌ أَنْ يَشْفَعَ الأَذَانَ وَيُوتِرَ الإِقَامَةَ ‏.‏\hadithno{839}\hadithtrans{Anas b. Malik reported:They (the Companions) discussed that they should know the timings of prayer by means of something recognized by all. Some of them said that fire should be lighted or a bell should be rung. But Bilal was ordered to repeat the phrases twice in Adhan, and once in Iqama}}
\hadithdefcmd{muslim}{840}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، بِهَذَا الإِسْنَادِ لَمَّا كَثُرَ النَّاسُ ذَكَرُوا أَنْ يُعْلِمُوا ‏.‏ بِمِثْلِ حَدِيثِ الثَّقَفِيِّ غَيْرَ أَنَّهُ قَالَ أَنْ يُورُوا نَارًا ‏.‏\hadithno{840}\hadithtrans{This hadith is transmitted by Khalid Hadhdha with the same chain of transmitters (and the words are):When the majority of the people discussed they should know, like the hadith narrated by al-Thaqafi (mentioned above) except for the words:" They (the people) should kindle fire}}
\hadithdefcmd{muslim}{841}{وَحَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، وَعَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْمَجِيدِ، قَالاَ حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، قَالَ أُمِرَ بِلاَلٌ أَنْ يَشْفَعَ، الأَذَانَ وَيُوتِرَ الإِقَامَةَ ‏.‏\hadithno{841}\hadithtrans{Anas reported:Bilal was commanded (by the Holy Prophet) to repeat the phrases twice in Adhan, and once in lqama}}
\hadithdefcmd{muslim}{842}{حَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، مَالِكُ بْنُ عَبْدِ الْوَاحِدِ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ قَالَ أَبُو غَسَّانَ حَدَّثَنَا مُعَاذٌ، وَقَالَ، إِسْحَاقُ أَخْبَرَنَا مُعَاذُ بْنُ هِشَامٍ، صَاحِبِ الدَّسْتَوَائِيِّ وَحَدَّثَنِي أَبِي، عَنْ عَامِرٍ الأَحْوَلِ، عَنْ مَكْحُولٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَيْرِيزٍ، عَنْ أَبِي مَحْذُورَةَ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم عَلَّمَهُ هَذَا الأَذَانَ ‏"‏ اللَّهُ أَكْبَرُ اللَّهُ أَكْبَرُ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ أَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ أَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ - ثُمَّ يَعُودُ فَيَقُولُ - أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ أَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ أَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ حَىَّ عَلَى الصَّلاَةِ - مَرَّتَيْنِ - حَىَّ عَلَى الْفَلاَحِ - مَرَّتَيْنِ ‏"‏ ‏.‏ زَادَ إِسْحَاقُ ‏"‏ اللَّهُ أَكْبَرُ اللَّهُ أَكْبَرُ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏\hadithno{842}\hadithtrans{Abu Mahdhura said that the Messenger of Allah (ﷺ) taught him Adhan like this:Allah is the Greatest, Allah is the Greatest; I testify that there is no god but Allah, I testify that there is no god but Allah; I testify that Muhammad Is the Messenger of Allah, I testify that Muhammad is the Messenger of Allah, and it should be again repeated: I testify that there is no god but Allah, I testify that there is no god but Allah; I testify that Muhammad Is the Messenger of Allah, I testify that Muhammad is the Messenger of Allah. Come to the prayer (twice). Come to success (twice). Ishaq added: Allah is the Greatest, Allah is the Greatest; there Is no god but Allah}}
\hadithdefcmd{muslim}{843}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم مُؤَذِّنَانِ بِلاَلٌ وَابْنُ أُمِّ مَكْتُومٍ الأَعْمَى ‏.‏\hadithno{843}\hadithtrans{Ibn Umar reported:The Messenger of Allah (ﷺ) had two Mu'adhdhins, Bilal and 'Abdullah b. Umm Maktum, who (latter) was blind}}
\hadithdefcmd{muslim}{844}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، حَدَّثَنَا الْقَاسِمُ، عَنْ عَائِشَةَ، مِثْلَهُ ‏.‏\hadithno{844}\hadithtrans{This hadith has been narrated on the authority of 'A'isha by another chain of transmitters}}
\hadithdefcmd{muslim}{845}{حَدَّثَنِي أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ مَخْلَدٍ - عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ ابْنُ أُمِّ مَكْتُومٍ يُؤَذِّنُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ أَعْمَى ‏.‏\hadithno{845}\hadithtrans{A'isha reported:Ibn Umm Maktum used to pronounce Adhan at the behest of the Messenger of Allah (ﷺ) (despite the fact) that he was blind}}
\hadithdefcmd{muslim}{846}{وَحَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ، وَسَعِيدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{846}\hadithtrans{A hadith like this has been transmitted by Hisham}}
\hadithdefcmd{muslim}{847}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - عَنْ حَمَّادِ بْنِ سَلَمَةَ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُغِيرُ إِذَا طَلَعَ الْفَجْرُ وَكَانَ يَسْتَمِعُ الأَذَانَ فَإِنْ سَمِعَ أَذَانًا أَمْسَكَ وَإِلاَّ أَغَارَ فَسَمِعَ رَجُلاً يَقُولُ اللَّهُ أَكْبَرُ اللَّهُ أَكْبَرُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ عَلَى الْفِطْرَةِ ‏"‏ ‏.‏ ثُمَّ قَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَرَجْتَ مِنَ النَّارِ ‏"‏ ‏.‏ فَنَظَرُوا فَإِذَا هُوَ رَاعِي مِعْزًى ‏.‏\hadithno{847}\hadithtrans{Anas b. Malik reported:The Messenger of Allah (ﷺ) used to attack the enemy when it was dawn. He would listen to the Adhan; so if he heard an Adhan, he stopped, otherwise made an attack. Once on hearing a man say: Allah is the Greatest, Allah is the Greatest, the Messenger of Allah (ﷺ) remarked: He is following al-Fitra (al-Islam). Then hearing him say: I testify that there is no god but Allah. there is no god but Allah, the Messenger of Allah (ﷺ) said: You have come out of the Fire (of Hell). They looked at him and found that he was a goat herd}}
\hadithdefcmd{muslim}{848}{حَدَّثَنِي يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَمِعْتُمُ النِّدَاءَ فَقُولُوا مِثْلَ مَا يَقُولُ الْمُؤَذِّنُ ‏"‏ ‏.‏\hadithno{848}\hadithtrans{Abu Sa'id al-Khudri reported:When you hear the call (to prayer), repeat what the Mu'adhdhin pronounces}}
\hadithdefcmd{muslim}{849}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ حَيْوَةَ، وَسَعِيدِ بْنِ أَبِي أَيُّوبَ، وَغَيْرِهِمَا، عَنْ كَعْبِ بْنِ عَلْقَمَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا سَمِعْتُمُ الْمُؤَذِّنَ فَقُولُوا مِثْلَ مَا يَقُولُ ثُمَّ صَلُّوا عَلَىَّ فَإِنَّهُ مَنْ صَلَّى عَلَىَّ صَلاَةً صَلَّى اللَّهُ عَلَيْهِ بِهَا عَشْرًا ثُمَّ سَلُوا اللَّهَ لِيَ الْوَسِيلَةَ فَإِنَّهَا مَنْزِلَةٌ فِي الْجَنَّةِ لاَ تَنْبَغِي إِلاَّ لِعَبْدٍ مِنْ عِبَادِ اللَّهِ وَأَرْجُو أَنْ أَكُونَ أَنَا هُوَ فَمَنْ سَأَلَ لِيَ الْوَسِيلَةَ حَلَّتْ لَهُ الشَّفَاعَةُ ‏"‏ ‏.‏\hadithno{849}\hadithtrans{Abdullah b. Amr b. al-As reported Allah's Messenger (ﷺ) as saying:When you hear the Mu'adhdhin, repeat what he says, then invoke a blessing on me, for everyone who invokes a blessing on me will receive ten blessings from Allah; then beg from Allah al-Wasila for me, which is a rank in Paradise fitting for only one of Allah's servants, and I hope that I may be that one. If anyone who asks that I be given the Wasila, he will be assured of my intercession}}
\hadithdefcmd{muslim}{850}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو جَعْفَرٍ، مُحَمَّدُ بْنُ جَهْضَمٍ الثَّقَفِيُّ حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ إِسَافٍ، عَنْ حَفْصِ بْنِ عَاصِمِ بْنِ عُمَرَ بْنِ الْخَطَّابِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عُمَرَ بْنِ الْخَطَّابِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا قَالَ الْمُؤَذِّنُ اللَّهُ أَكْبَرُ اللَّهُ أَكْبَرُ ‏.‏ فَقَالَ أَحَدُكُمُ اللَّهُ أَكْبَرُ اللَّهُ أَكْبَرُ ‏.‏ ثُمَّ قَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏.‏ قَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ ثُمَّ قَالَ أَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ ‏.‏ قَالَ أَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ ‏.‏ ثُمَّ قَالَ حَىَّ عَلَى الصَّلاَةِ ‏.‏ قَالَ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏.‏ ثُمَّ قَالَ حَىَّ عَلَى الْفَلاَحِ ‏.‏ قَالَ لاَ حَوْلَ وَلاَ قُوَّةَ إِلاَّ بِاللَّهِ ‏.‏ ثُمَّ قَالَ اللَّهُ أَكْبَرُ اللَّهُ أَكْبَرُ ‏.‏ قَالَ اللَّهُ أَكْبَرُ اللَّهُ أَكْبَرُ ‏.‏ ثُمَّ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ ‏.‏ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ ‏.‏ مِنْ قَلْبِهِ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{850}\hadithtrans{Umar b. al-Khattab reported:The Messenger of Allah (ﷺ) said: When the Mu'adhdhin says: Allah is the Greatest, Allah is the Greatest, and one of you should make this response: Allah is the Greatest, Allah is the Greatest; (and when the Mu'adhdhin) says: I testify that there is no god but Allah, one should respond: I testify that there is no god but Allah, and when he says: I testify that Muhammad is the Messenger of Allah, one should make a response: I testify that Muhammad is Allah's Messenger. When he (the Mu'adhdhin) says: Come to prayer, one should make a response: There is no might and no power except with Allah. When he (the Mu'adhdhin) says: Come to salvation, one should respond: There is no might and no power except with Allah, and when he (the Mu'adhdhin) says: Allah is the Greatest, Allah is the Greatest, then make a response: Allah is the Greatest, Allah is the Greatest. When he (the Mu'adhdhin) says: There is no god but Allah, and he who makes a re- sponse from the heart: There is no god but Allah, he will enter Paradise}}
\hadithdefcmd{muslim}{851}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنِ الْحُكَيْمِ بْنِ عَبْدِ اللَّهِ بْنِ قَيْسٍ الْقُرَشِيِّ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ الْحُكَيْمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ مَنْ قَالَ حِينَ يَسْمَعُ الْمُؤَذِّنَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَحْدَهُ لاَ شَرِيكَ لَهُ وَأَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ رَضِيتُ بِاللَّهِ رَبًّا وَبِمُحَمَّدٍ رَسُولاً وَبِالإِسْلاَمِ دِينًا ‏.‏ غُفِرَ لَهُ ذَنْبُهُ ‏"‏ ‏.‏ قَالَ ابْنُ رُمْحٍ فِي رِوَايَتِهِ ‏"‏ مَنْ قَالَ حِينَ يَسْمَعُ الْمُؤَذِّنَ وَأَنَا أَشْهَدُ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ قُتَيْبَةُ قَوْلَهُ وَأَنَا ‏.‏\hadithno{851}\hadithtrans{Sa'd b. Abu Waqqas reported:The Messenger of Allah (ﷺ) said: If anyone says on hearing the Mu'adhdhin: I testify that there is no god but Allah alone. Who has no partner, and that Muhammad is His servant and His Messenger, (and that) I am satisfied with Allah as my Lord, with Muhammad as Messenger. and with Islam as din (code of life), his sins would be forgiven. In the narration transmitted by Ibn Rumh the words are:" He who said on hearing the Mu'adhdhin and verity I testify." ' Qutaiba has not mentioned his words:" And I}}
\hadithdefcmd{muslim}{854}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ الشَّيْطَانَ إِذَا سَمِعَ النِّدَاءَ بِالصَّلاَةِ ذَهَبَ حَتَّى يَكُونَ مَكَانَ الرَّوْحَاءِ ‏"‏ ‏.‏ قَالَ سُلَيْمَانُ فَسَأَلْتُهُ عَنِ الرَّوْحَاءِ ‏.‏ فَقَالَ هِيَ مِنَ الْمَدِينَةِ سِتَّةٌ وَثَلاَثُونَ مِيلاً ‏.‏\hadithno{854}\hadithtrans{Abu Sufyan reported it on the authority of Jabir that he had heard the Messenger of Allah (ﷺ) say:When Satan hears the call to prayer, he runs away to a distance like that of Rauha. Sulaimin said: I asked him about Rauha. He replied: It is at a distance of thirty-six miles from Medina}}
\hadithdefcmd{muslim}{855}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{855}\hadithtrans{Abu Mu'awiya narrated it on the authority of A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{856}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِقُتَيْبَةَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الشَّيْطَانَ إِذَا سَمِعَ النِّدَاءَ بِالصَّلاَةِ أَحَالَ لَهُ ضُرَاطٌ حَتَّى لاَ يَسْمَعَ صَوْتَهُ فَإِذَا سَكَتَ رَجَعَ فَوَسْوَسَ فَإِذَا سَمِعَ الإِقَامَةَ ذَهَبَ حَتَّى لاَ يَسْمَعَ صَوْتَهُ فَإِذَا سَكَتَ رَجَعَ فَوَسْوَسَ ‏"‏ ‏.‏\hadithno{856}\hadithtrans{Abu Huraira reported the Messenger of Allah (ﷺ) as saying:When Satan hears the call to prayer, he turns back and breaks the wind so as not to hear the call being made, but when the call is finished he turns round and distracts (the minds of those who pray), and when he hears the Iqama, he again runs away so as not to hear its voice and when it subsides, he comes back and distracts (the minds of those who stand for prayer)}}
\hadithdefcmd{muslim}{857}{حَدَّثَنِي عَبْدُ الْحَمِيدِ بْنُ بَيَانٍ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ عَبْدِ اللَّهِ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَذَّنَ الْمُؤَذِّنُ أَدْبَرَ الشَّيْطَانُ وَلَهُ حُصَاصٌ ‏"‏ ‏.‏\hadithno{857}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: When the Mu'adhdhin calls to prayer, Satan runs back vehemently}}
\hadithdefcmd{muslim}{858}{حَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامَ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا رَوْحٌ، عَنْ سُهَيْلٍ، قَالَ أَرْسَلَنِي أَبِي إِلَى بَنِي حَارِثَةَ - قَالَ - وَمَعِي غُلاَمٌ لَنَا - أَوْ صَاحِبٌ لَنَا - فَنَادَاهُ مُنَادٍ مِنْ حَائِطٍ بِاسْمِهِ - قَالَ - وَأَشْرَفَ الَّذِي مَعِي عَلَى الْحَائِطِ فَلَمْ يَرَ شَيْئًا فَذَكَرْتُ ذَلِكَ لأَبِي فَقَالَ لَوْ شَعَرْتُ أَنَّكَ تَلْقَى هَذَا لَمْ أُرْسِلْكَ وَلَكِنْ إِذَا سَمِعْتَ صَوْتًا فَنَادِ بِالصَّلاَةِ فَإِنِّي سَمِعْتُ أَبَا هُرَيْرَةَ يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّ الشَّيْطَانَ إِذَا نُودِيَ بِالصَّلاَةِ وَلَّى وَلَهُ حُصَاصٌ ‏"‏ ‏.‏\hadithno{858}\hadithtrans{Suhail reported that his father sent him to Banu Haritha along with a boy or a man. Someone called him by his name from an enclosure. He (thenarrator) said:The person with me looked towards the enclosure, but saw nothing. I made a mention of that to my father. He said: If I knew that you would meet such a situation I would have never sent you (there), but (bear in wind) whenever you hear such a call (from the evil spirits) pronounce the Adhan. for I have heard Abu Huraira say that the Messenger of Allah (may peace be upbn him) said: Whenever Adhan is proclaimed, Satan runs back vehemently}}
\hadithdefcmd{muslim}{859}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نُودِيَ لِلصَّلاَةِ أَدْبَرَ الشَّيْطَانُ لَهُ ضُرَاطٌ حَتَّى لاَ يَسْمَعَ التَّأْذِينَ فَإِذَا قُضِيَ التَّأْذِينُ أَقْبَلَ حَتَّى إِذَا ثُوِّبَ بِالصَّلاَةِ أَدْبَرَ حَتَّى إِذَا قُضِيَ التَّثْوِيبُ أَقْبَلَ حَتَّى يَخْطِرَ بَيْنَ الْمَرْءِ وَنَفْسِهِ يَقُولُ لَهُ اذْكُرْ كَذَا وَاذْكُرْ كَذَا لِمَا لَمْ يَكُنْ يَذْكُرُ مِنْ قَبْلُ حَتَّى يَظَلَّ الرَّجُلُ مَا يَدْرِي كَمْ صَلَّى ‏"‏ ‏.‏\hadithno{859}\hadithtrans{Abu Huraira reported:The Apostle (ﷺ) said When the call to prayer is made, Satan runs back and breaks wind so as not to hear the call being made, and when the call is finished. he turns round. When Iqama is proclaimed he turns his back, and when it is finished he turns round to distract a man, saying: Re- member such and such; remember such and such, referring to something the man did not have in his mind, with the result that he does not know how much he has prayed}}
\hadithdefcmd{muslim}{860}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ حَتَّى يَظَلَّ الرَّجُلُ إِنْ يَدْرِي كَيْفَ صَلَّى ‏"‏ ‏.‏\hadithno{860}\hadithtrans{A hadith like it has been narrated by Abu Huraira but for these words:" He (the man saying the prayer) does not know how much he has prayed}}
\hadithdefcmd{muslim}{861}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَسَعِيدُ بْنُ مَنْصُورٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَزُهَيْرُ بْنُ حَرْبٍ وَابْنُ نُمَيْرٍ كُلُّهُمْ عَنْ سُفْيَانَ بْنِ عُيَيْنَةَ، - وَاللَّفْظُ لِيَحْيَى قَالَ أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا افْتَتَحَ الصَّلاَةَ رَفَعَ يَدَيْهِ حَتَّى يُحَاذِيَ مَنْكِبَيْهِ وَقَبْلَ أَنْ يَرْكَعَ وَإِذَا رَفَعَ مِنَ الرُّكُوعِ وَلاَ يَرْفَعُهُمَا بَيْنَ السَّجْدَتَيْنِ ‏.‏\hadithno{861}\hadithtrans{Salim narrated it on the authority of his father who reported:I saw the Messenger of Allah (ﷺ) raising his hands apposite the shoulders at the time of beginning the prayer and before bowing down and after coming back to the position after bowing. but he did not raise them between two prostrations}}
\hadithdefcmd{muslim}{862}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ ابْنَ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَامَ لِلصَّلاَةِ رَفَعَ يَدَيْهِ حَتَّى تَكُونَا حَذْوَ مَنْكِبَيْهِ ثُمَّ كَبَّرَ فَإِذَا أَرَادَ أَنْ يَرْكَعَ فَعَلَ مِثْلَ ذَلِكَ وَإِذَا رَفَعَ مِنَ الرُّكُوعِ فَعَلَ مِثْلَ ذَلِكَ وَلاَ يَفْعَلُهُ حِينَ يَرْفَعُ رَأْسَهُ مِنَ السُّجُودِ ‏.‏\hadithno{862}\hadithtrans{Ibn Umar reported that the Messenger of Allah (ﷺ), when he stood up for prayer, used to raise his hands apposite the shoulders and then recited takbir (Allah-o-Akbar), and when he was about to bow he again did like it and when he raised himself from the ruku' (bowing posture) he again did like it, but he did not do it at the time of raising his head from prostration}}
\hadithdefcmd{muslim}{863}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا حُجَيْنٌ، - وَهُوَ ابْنُ الْمُثَنَّى - حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ قُهْزَاذَ، حَدَّثَنَا سَلَمَةُ بْنُ سُلَيْمَانَ، أَخْبَرَنَا يُونُسُ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ كَمَا قَالَ ابْنُ جُرَيْجٍ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَامَ لِلصَّلاَةِ رَفَعَ يَدَيْهِ حَتَّى تَكُونَا حَذْوَ مَنْكِبَيْهِ ثُمَّ كَبَّرَ ‏.‏\hadithno{863}\hadithtrans{This hadith has been transmitted with the same chain of transmitters by al. Zuhri as narrated by Ibn Juraij (who) said. When the Messenger of Allah (ﷺ) stood up for prayer, he raised hands (to the height) apposite the shoulders and then recited takbir}}
\hadithdefcmd{muslim}{864}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ خَالِدٍ، عَنْ أَبِي قِلاَبَةَ، أَنَّهُ رَأَى مَالِكَ بْنَ الْحُوَيْرِثِ إِذَا صَلَّى كَبَّرَ ثُمَّ رَفَعَ يَدَيْهِ وَإِذَا أَرَادَ أَنْ يَرْكَعَ رَفَعَ يَدَيْهِ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ رَفَعَ يَدَيْهِ وَحَدَّثَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَفْعَلُ هَكَذَا ‏.‏\hadithno{864}\hadithtrans{Abu Qilaba reported that he saw Malik b. Huwairith raising his hands at the beginning of prayer and raising his hands before kneeling down, and raising his hands after lifting his head from the state of kneeling, and he narrated that the Messenger of Allah (ﷺ) used to do like this}}
\hadithdefcmd{muslim}{865}{حَدَّثَنِي أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ نَصْرِ بْنِ عَاصِمٍ، عَنْ مَالِكِ بْنِ الْحُوَيْرِثِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا كَبَّرَ رَفَعَ يَدَيْهِ حَتَّى يُحَاذِيَ بِهِمَا أُذُنَيْهِ وَإِذَا رَكَعَ رَفَعَ يَدَيْهِ حَتَّى يُحَاذِيَ بِهِمَا أُذُنَيْهِ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ فَقَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ فَعَلَ مِثْلَ ذَلِكَ ‏.‏\hadithno{865}\hadithtrans{Malik b. Huwairith reported:The Messenger of Allah (ﷺ) raised his hands apposite his ears at the time of reciting the takbir (i. e. at the time of beginning the prayer) and then again raised his hands apposite the ears at the time of bowing and when he lifted his head after bowing he said: Allah listened to him who praised Him, and did like it (raised his hands up to the ears)}}
\hadithdefcmd{muslim}{866}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ أَنَّهُ رَأَى نَبِيَّ اللَّهِ صلى الله عليه وسلم وَقَالَ حَتَّى يُحَاذِيَ بِهِمَا فُرُوعَ أُذُنَيْهِ ‏.‏\hadithno{866}\hadithtrans{This hadith has been transmitted by Qatada with the same chain of transmitters that he saw the Messenger of Allah (ﷺ) doing this (i.e. raising his hands) till they were opposite the lobes of ears}}
\hadithdefcmd{muslim}{867}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، كَانَ يُصَلِّي لَهُمْ فَيُكَبِّرُ كُلَّمَا خَفَضَ وَرَفَعَ فَلَمَّا انْصَرَفَ قَالَ وَاللَّهِ إِنِّي لأَشْبَهُكُمْ صَلاَةً بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{867}\hadithtrans{Abu Salama reported:Abu Huraira led prayer for them and recited takbir when he bent and raised himself (in ruku' and sujud) and after completing (the prayer) he said: By Allah I say prayer which has the best resemblance with the prayer of the Prophet (ﷺ) amongst you}}
\hadithdefcmd{muslim}{868}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي ابْنُ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَامَ إِلَى الصَّلاَةِ يُكَبِّرُ حِينَ يَقُومُ ثُمَّ يُكَبِّرُ حِينَ يَرْكَعُ ثُمَّ يَقُولُ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ حِينَ يَرْفَعُ صُلْبَهُ مِنَ الرُّكُوعِ ثُمَّ يَقُولُ وَهُوَ قَائِمٌ ‏"‏ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏ ثُمَّ يُكَبِّرُ حِينَ يَهْوِي سَاجِدًا ثُمَّ يُكَبِّرُ حِينَ يَرْفَعُ رَأْسَهُ ثُمَّ يُكَبِّرُ حِينَ يَسْجُدُ ثُمَّ يُكَبِّرُ حِينَ يَرْفَعُ رَأْسَهُ ثُمَّ يَفْعَلُ مِثْلَ ذَلِكَ فِي الصَّلاَةِ كُلِّهَا حَتَّى يَقْضِيَهَا وَيُكَبِّرُ حِينَ يَقُومُ مِنَ الْمَثْنَى بَعْدَ الْجُلُوسِ ثُمَّ يَقُولُ أَبُو هُرَيْرَةَ إِنِّي لأَشْبَهُكُمْ صَلاَةً بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{868}\hadithtrans{Abu Huraira reported:When the Messenger of Allah (ﷺ) got up for prayer, he would say the takbir (Allah-o-Akbar) when standing, then say the takbir when bowing. then say:" Allah listened to him who praised him," when coming to the erect position after bowing, then say while standing:" To Thee, our Lord, be the praise", then recite the takbir when getting down for prostration, then say the takbir on raising his head, then say the takbir on prostrating himself, then say the takbir on raising his head. He would do that throughout the whole prayer till he would complete it, and he would say the takbir when he would get up at the end of two rak'as after adopting the sitting posture. Abu Huraira said: My prayer has the best resemblance amongst you with the prayer of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{869}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا حُجَيْنٌ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَامَ إِلَى الصَّلاَةِ يُكَبِّرُ حِينَ يَقُومُ بِمِثْلِ حَدِيثِ ابْنِ جُرَيْجٍ وَلَمْ يَذْكُرْ قَوْلَ أَبِي هُرَيْرَةَ ‏.‏ إِنِّي أَشْبَهُكُمْ صَلاَةً بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{869}\hadithtrans{Ibn al-Harith reported:He had heard Abu Huraira say: The Messenger of Allah (ﷺ) recited takbir on standing for prayer, and the rest of the hadith is like that transmitted by Ibn Juraij (recorded above), but he did not mention Abu Huraira as saying:" My prayer has the best resemblance amongst you with the prayer of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{870}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، كَانَ - حِينَ يَسْتَخْلِفُهُ مَرْوَانُ عَلَى الْمَدِينَةِ - إِذَا قَامَ لِلصَّلاَةِ الْمَكْتُوبَةِ كَبَّرَ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ ابْنِ جُرَيْجٍ وَفِي حَدِيثِهِ فَإِذَا قَضَاهَا وَسَلَّمَ أَقْبَلَ عَلَى أَهْلِ الْمَسْجِدِ قَالَ وَالَّذِي نَفْسِي بِيَدِهِ إِنِّي لأَشْبَهُكُمْ صَلاَةً بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{870}\hadithtrans{Abu Salama b. 'Abd al-Rahman reported.. When Marwan appointed Abu Huraira as his deputy in Medina, he recited takbir whenever he got up for obligatory prayer, and the rest of the hadith is the same as transmitted by Ibn Juraij (but with the addition of these words):On completing the prayer with salutation, and he turned to the people in the mosque and said}}
\hadithdefcmd{muslim}{871}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ، كَانَ يُكَبِّرُ فِي الصَّلاَةِ كُلَّمَا رَفَعَ وَوَضَعَ ‏.‏ فَقُلْنَا يَا أَبَا هُرَيْرَةَ مَا هَذَا التَّكْبِيرُ قَالَ إِنَّهَا لَصَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{871}\hadithtrans{Abu Salama reported that Abu Huraira recited takbir in prayer on all occasions of rising and kneeling. We said:O Abu Huraira, what is this takbir? He said: Verily it is the prayer of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{872}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ كَانَ يُكَبِّرُ كُلَّمَا خَفَضَ وَرَفَعَ وَيُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{872}\hadithtrans{Suhail reported on the authority of his father that Abu Huraira used to recite takbir on all occasions of rising and bending (in prayer) and narrated that the Messenger of Allah (ﷺ) used to do like that}}
\hadithdefcmd{muslim}{873}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَخَلَفُ بْنُ هِشَامٍ، جَمِيعًا عَنْ حَمَّادٍ، - قَالَ يَحْيَى أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، - عَنْ غَيْلاَنَ، عَنْ مُطَرِّفٍ، قَالَ صَلَّيْتُ أَنَا وَعِمْرَانُ بْنُ حُصَيْنٍ، خَلْفَ عَلِيِّ بْنِ أَبِي طَالِبٍ فَكَانَ إِذَا سَجَدَ كَبَّرَ وَإِذَا رَفَعَ رَأْسَهُ كَبَّرَ وَإِذَا نَهَضَ مِنَ الرَّكْعَتَيْنِ كَبَّرَ فَلَمَّا انْصَرَفْنَا مِنَ الصَّلاَةِ - قَالَ - أَخَذَ عِمْرَانُ بِيَدِي ثُمَّ قَالَ لَقَدْ صَلَّى بِنَا هَذَا صَلاَةَ مُحَمَّدٍ صلى الله عليه وسلم ‏.‏ أَوْ قَالَ قَدْ ذَكَّرَنِي هَذَا صَلاَةَ مُحَمَّدٍ صلى الله عليه وسلم ‏.‏\hadithno{873}\hadithtrans{Mutarrif reported:I and 'Imran b. Husain said prayer behind 'Ali b. Abu, Talib. He recited takbir when he prostrated, and he recited takbir when he raised his head and he recited takbir while rising up (from the sitting position at the end of two rak'ahs). When we had finished our prayer, 'Imran caught hold of my hand and said: He (Hadrat Ali) has led prayer like Muhammad (ﷺ) or he said: He in fact recalled to my mind the prayer of Muhammad (may peace be upon him)}}
\hadithdefcmd{muslim}{874}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنْ سُفْيَانَ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنِ الزُّهْرِيِّ، عَنْ مَحْمُودِ بْنِ الرَّبِيعِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم ‏ "‏ لاَ صَلاَةَ لِمَنْ لَمْ يَقْرَأْ بِفَاتِحَةِ الْكِتَابِ ‏"‏ ‏.‏\hadithno{874}\hadithtrans{Ubada b. as-Samit reported from the Messenger of Allah (may peace be upon him ):He who does not recite Fatihat al-Kitab is not credited with having observed the prayer}}
\hadithdefcmd{muslim}{875}{حَدَّثَنِي أَبُو الطَّاهِرِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، ح وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي مَحْمُودُ بْنُ الرَّبِيعِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ صَلاَةَ لِمَنْ لَمْ يَقْتَرِئْ بِأُمِّ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{875}\hadithtrans{Ubada b. as-Samit reported:The Messenger of Allah (ﷺ) said: He who does not recite Umm al-Qur'an is not credited with having observed the prayer}}
\hadithdefcmd{muslim}{876}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ مَحْمُودَ بْنَ الرَّبِيعِ الَّذِي، مَجَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي وَجْهِهِ مِنْ بِئْرِهِمْ أَخْبَرَهُ أَنَّ عُبَادَةَ بْنَ الصَّامِتِ أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ صَلاَةَ لِمَنْ لَمْ يَقْرَأْ بِأُمِّ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{876}\hadithtrans{Mahmud b. al-Rabi', on whose face the Messenger of Allah (ﷺ) squirted water from the well, reported on the authority of 'Ubada b. as- Samit that the Messenger of Allah (ﷺ) said:He who does not recite Umm al-Qur'an is not credited with having observed prayer}}
\hadithdefcmd{muslim}{877}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ مِثْلَهُ وَزَادَ فَصَاعِدًا ‏.‏\hadithno{877}\hadithtrans{This hadith has also been transmitted by Ma'mar from al-Zuhri with the same chain of transmitters with the addition of these words:" and something more}}
\hadithdefcmd{muslim}{878}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ صَلَّى صَلاَةً لَمْ يَقْرَأْ فِيهَا بِأُمِّ الْقُرْآنِ فَهْىَ خِدَاجٌ - ثَلاَثًا - غَيْرُ تَمَامٍ ‏"‏ ‏.‏ فَقِيلَ لأَبِي هُرَيْرَةَ إِنَّا نَكُونُ وَرَاءَ الإِمَامِ ‏.‏ فَقَالَ اقْرَأْ بِهَا فِي نَفْسِكَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ قَالَ اللَّهُ تَعَالَى قَسَمْتُ الصَّلاَةَ بَيْنِي وَبَيْنَ عَبْدِي نِصْفَيْنِ وَلِعَبْدِي مَا سَأَلَ فَإِذَا قَالَ الْعَبْدُ ‏\{‏ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ‏\}‏ ‏.‏ قَالَ اللَّهُ تَعَالَى حَمِدَنِي عَبْدِي وَإِذَا قَالَ ‏\{‏ الرَّحْمَنِ الرَّحِيمِ‏\}‏ ‏.‏ قَالَ اللَّهُ تَعَالَى أَثْنَى عَلَىَّ عَبْدِي ‏.‏ وَإِذَا قَالَ ‏\{‏ مَالِكِ يَوْمِ الدِّينِ‏\}‏ ‏.‏ قَالَ مَجَّدَنِي عَبْدِي - وَقَالَ مَرَّةً فَوَّضَ إِلَىَّ عَبْدِي - فَإِذَا قَالَ ‏\{‏ إِيَّاكَ نَعْبُدُ وَإِيَّاكَ نَسْتَعِينُ‏\}‏ ‏.‏ قَالَ هَذَا بَيْنِي وَبَيْنَ عَبْدِي وَلِعَبْدِي مَا سَأَلَ ‏.‏ فَإِذَا قَالَ ‏\{‏ اهْدِنَا الصِّرَاطَ الْمُسْتَقِيمَ * صِرَاطَ الَّذِينَ أَنْعَمْتَ عَلَيْهِمْ غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ‏\}‏ ‏.‏ قَالَ هَذَا لِعَبْدِي وَلِعَبْدِي مَا سَأَلَ ‏"‏ ‏.‏ قَالَ سُفْيَانُ حَدَّثَنِي بِهِ الْعَلاَءُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ يَعْقُوبَ دَخَلْتُ عَلَيْهِ وَهُوَ مَرِيضٌ فِي بَيْتِهِ فَسَأَلْتُهُ أَنَا عَنْهُ ‏.‏\hadithno{878}\hadithtrans{Abu Huraira reported:The Apostle of Allah (ﷺ) said: If anyone observes prayer in which he does not recite Umm al-Qur'an, It is deficient [he said this three times] and not complete. It was said to Abu Huraira: At times we are behind the Imam. He said: Recite it inwardly, for he had heard the Messenger of Allah (ﷺ) declare that Allah the Exalted had said: I have divided the prayer into two halves between Me and My servant, and My servant will receive what he asks. When the servant says: Praise be to Allah, the Lord of the universe, Allah the Most High says: My servant has praised Me. And when he (the servant) says: The Most Compassionate, the Merciful, Allah the Most High says: My servant has lauded Me. And when he (the servant) says: Master of the Day of judg- ment, He remarks: My servant has glorified Me. and sometimes He would say: My servant entrusted (his affairs) to Me. And when he (the worshipper) says: Thee do we worship and of Thee do we ask help, He (Allah) says: This is between Me and My servant, and My servant will receive what he asks for. Then, when he (the worshipper) says: Guide us to the straight path, the path of those to whom Thou hast been Gracious not of those who have incurred Thy displeasure, nor of those who have gone astray, He (Allah) says: This is for My servant, and My servant will receive what he asks for. Sufyan said: 'Ala b. 'Abd al-Rahman b. Ya'qub narrated it to me when I went to him and he was confined to his home on account of illness, and I asked him about it}}
\hadithdefcmd{muslim}{879}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَبَا السَّائِبِ، مَوْلَى هِشَامِ بْنِ زُهْرَةَ يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي الْعَلاَءُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ يَعْقُوبَ، أَنَّ أَبَا السَّائِبِ، مَوْلَى بَنِي عَبْدِ اللَّهِ بْنِ هِشَامِ بْنِ زُهْرَةَ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ صَلَّى صَلاَةً فَلَمْ يَقْرَأْ فِيهَا بِأُمِّ الْقُرْآنِ ‏"‏ ‏.‏ بِمِثْلِ حَدِيثِ سُفْيَانَ وَفِي حَدِيثِهِمَا ‏"‏ قَالَ اللَّهُ تَعَالَى قَسَمْتُ الصَّلاَةَ بَيْنِي وَبَيْنَ عَبْدِي نِصْفَيْنِ فَنِصْفُهَا لِي وَنِصْفُهَا لِعَبْدِي ‏"‏ ‏.‏\hadithno{879}\hadithtrans{It is naratted on the authority of Abu Huraira that he had heard the Messenger of Allah (ﷺ) say:He who observed prayer but he did not recite the Umm al-Qur'an in it, and the rest of the hadith is the same as transmitted by Sufyan, and in this hadith the words are:" Allah the Most High said: the prayer is divided into two halves between Me and My servant. The half of it is for Me and the half of it is for My servant}}
\hadithdefcmd{muslim}{880}{حَدَّثَنِي أَحْمَدُ بْنُ جَعْفَرٍ الْمَعْقِرِيُّ، حَدَّثَنَا النَّضْرُ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُوَيْسٍ، أَخْبَرَنِي الْعَلاَءُ، قَالَ سَمِعْتُ مِنْ أَبِي وَمِنْ أَبِي السَّائِبِ، وَكَانَا، جَلِيسَىْ أَبِي هُرَيْرَةَ قَالاَ قَالَ أَبُو هُرَيْرَةَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى صَلاَةً لَمْ يَقْرَأْ فِيهَا بِفَاتِحَةِ الْكِتَابِ فَهْىَ خِدَاجٌ ‏"‏ ‏.‏ يَقُولُهَا ثَلاَثًا بِمِثْلِ حَدِيثِهِمْ ‏.‏\hadithno{880}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: He who said his prayer, but did not recite the opening chapter of al-Kitab, his prayer is incomplete. He repeated it thrice}}
\hadithdefcmd{muslim}{882}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، قَالَ سَمِعْتُ عَطَاءً، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ صَلاَةَ إِلاَّ بِقِرَاءَةٍ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَمَا أَعْلَنَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَعْلَنَّاهُ لَكُمْ وَمَا أَخْفَاهُ أَخْفَيْنَاهُ لَكُمْ ‏.‏\hadithno{882}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: One is not credited with having observed the prayer without the recitation (of al-Fatiha). So said Abu Huraira: (The prayer in which) the Messenger of Allah (ﷺ) recited in a loud voice, we also recited that loudly for you (and the prayer in which) he recited inwardly we also recited inwardly for you (to give you a practical example of the prayer of the Holy Prophet)}}
\hadithdefcmd{muslim}{883}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لِعَمْرٍو - قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ عَطَاءٍ، قَالَ قَالَ أَبُو هُرَيْرَةَ فِي كُلِّ الصَّلاَةِ يَقْرَأُ فَمَا أَسْمَعَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَسْمَعْنَاكُمْ وَمَا أَخْفَى مِنَّا أَخْفَيْنَا مِنْكُمْ ‏.‏ فَقَالَ لَهُ رَجُلٌ إِنْ لَمْ أَزِدْ عَلَى أُمِّ الْقُرْآنِ فَقَالَ إِنْ زِدْتَ عَلَيْهَا فَهُوَ خَيْرٌ وَإِنِ انْتَهَيْتَ إِلَيْهَا أَجْزَأَتْ عَنْكَ ‏.‏\hadithno{883}\hadithtrans{Ata' narrated on the authority of Abu Huraira who said that one should recite (al-Fatiha) in every (rak'ah of) prayer. What we heard (i. e. recitation) from the Messenger of Allah (ﷺ), we made you listen to that. And that which he (recited) inwardly, we (recited) inwardly for you. A person said to him:If I add nothing to the (recitation) of the Umm al Qur'an (Surat al-Fatiha), would it make the prayer incomplete? He (AbuHuraira) said: If you add to that (if you recite some of verses of the Qur'an along with Surat at-Fatiha) that is better for you. But if you are contented with it (Surat al-Fatiha) only, it is sufficient for you}}
\hadithdefcmd{muslim}{884}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - عَنْ حَبِيبٍ الْمُعَلِّمِ، عَنْ عَطَاءٍ، قَالَ قَالَ أَبُو هُرَيْرَةَ فِي كُلِّ صَلاَةٍ قِرَاءَةٌ فَمَا أَسْمَعَنَا النَّبِيُّ صلى الله عليه وسلم أَسْمَعْنَاكُمْ وَمَا أَخْفَى مِنَّا أَخْفَيْنَاهُ مِنْكُمْ وَمَنْ قَرَأَ بِأُمِّ الْكِتَابِ فَقَدْ أَجْزَأَتْ عَنْهُ وَمَنْ زَادَ فَهُوَ أَفْضَلُ ‏.‏\hadithno{884}\hadithtrans{Ata' reported it on the authority of Abu Huraira who said:Recitation (of Surat al-Fatiha) in every (rak'ah) of prayer in essential. (The recitation) that we listened to from the Messenger of Allah (ﷺ) we made you listen to it. And that which he recited inwardly to us, we recited it inwardly for you. And he who recites Umm al-Qur'an, it is enough for him (to complete the prayer), and he who adds to it (recites some other verses of the Holy Qur'an along with Surat al-Fatiha), it is preferable for him}}
\hadithdefcmd{muslim}{885}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ الْمَسْجِدَ فَدَخَلَ رَجُلٌ فَصَلَّى ثُمَّ جَاءَ فَسَلَّمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم السَّلاَمَ قَالَ ‏"‏ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ فَرَجَعَ الرَّجُلُ فَصَلَّى كَمَا كَانَ صَلَّى ثُمَّ جَاءَ إِلَى النَّبِيِّ صلى الله عليه وسلم فَسَلَّمَ عَلَيْهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَعَلَيْكَ السَّلاَمُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ ارْجِعْ فَصَلِّ فَإِنَّكَ لَمْ تُصَلِّ ‏"‏ ‏.‏ حَتَّى فَعَلَ ذَلِكَ ثَلاَثَ مَرَّاتٍ فَقَالَ الرَّجُلُ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا أُحْسِنُ غَيْرَ هَذَا عَلِّمْنِي ‏.‏ قَالَ ‏"‏ إِذَا قُمْتَ إِلَى الصَّلاَةِ فَكَبِّرْ ثُمَّ اقْرَأْ مَا تَيَسَّرَ مَعَكَ مِنَ الْقُرْآنِ ثُمَّ ارْكَعْ حَتَّى تَطْمَئِنَّ رَاكِعًا ثُمَّ ارْفَعْ حَتَّى تَعْتَدِلَ قَائِمًا ثُمَّ اسْجُدْ حَتَّى تَطْمَئِنَّ سَاجِدًا ثُمَّ ارْفَعْ حَتَّى تَطْمَئِنَّ جَالِسًا ثُمَّ افْعَلْ ذَلِكَ فِي صَلاَتِكَ كُلِّهَا ‏"‏ ‏.‏\hadithno{885}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) entered the mosque and a person also entered therein and offered prayer, and then came and paid salutation to the Messenger of Allah (ﷺ). The Mes- senger of Allah (ﷺ) returned his salutation and said: Go back and pray, for you have not offered the prayer. He again prayed as he had prayed before, and came to the Messenger of Allah (may peace be upon. him) and saluted him. The Messenger of Allah (ﷺ) returned the salutation and said: Go back and say prayer, for you have not offered the prayer. This (act of repeating the prayer) was done three times. Upon this the person said: By Him Who hast sent you with Truth, whatever better I can do than this, please teach me. He (the Holy Prophet) said: When you get up to pray, recite takbir, and then recite whatever you conveniently can from the Qur'an, then bow down and remain quietly in that position, then raise your- self and stand erect; then prostrate yourself and remain quietly in that attitude; then raise yourself and sit quietly; and do that throughout all your prayers}}
\hadithdefcmd{muslim}{886}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي قَالاَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، دَخَلَ الْمَسْجِدَ فَصَلَّى وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي نَاحِيَةٍ وَسَاقَا الْحَدِيثَ بِمِثْلِ هَذِهِ الْقِصَّةِ وَزَادَا فِيهِ ‏ "‏ إِذَا قُمْتَ إِلَى الصَّلاَةِ فَأَسْبِغِ الْوُضُوءَ ثُمَّ اسْتَقْبِلِ الْقِبْلَةَ فَكَبِّرْ ‏"‏ ‏.‏\hadithno{886}\hadithtrans{Abu Huraira reported:A person entered the mosque and said prayer while the Messenger of Allah (ﷺ) was sitting in a nook (of the mosque), and the rest of the hadith is the same as mentioned above, but with this addition:" When you get up to pray, perform the ablution completely, and then turn towards the Qibla and recite takbir (Allah o Akbar =Allah is the Most Great)}}
\hadithdefcmd{muslim}{887}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، كِلاَهُمَا عَنْ أَبِي عَوَانَةَ، قَالَ سَعِيدٌ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الظُّهْرِ - أَوِ الْعَصْرِ - فَقَالَ ‏"‏ أَيُّكُمْ قَرَأَ خَلْفِي بِسَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏"‏ ‏.‏ فَقَالَ رَجُلٌ أَنَا وَلَمْ أُرِدْ بِهَا إِلاَّ الْخَيْرَ ‏.‏ قَالَ ‏"‏ قَدْ عَلِمْتُ أَنَّ بَعْضَكُمْ خَالَجَنِيهَا ‏"‏ ‏.‏\hadithno{887}\hadithtrans{lmrin b. Husain reported:The Messenger of Allah (may peace beupon him) led us In Zuhr or 'Asr prayer (noon or the afternoon prayer). (On concluding it) he said: Who recited behind me (the verses): Sabbih Isma Rabbik al-a'la (Glorify the name of thy Lord, the Most High)? There upon a person said: It was I, but I in- tended nothing but goodness. I felt that some one of you was disputing with me in it (or he was taking out from my tongue what I was reciting), said the Prophet (ﷺ)}}
\hadithdefcmd{muslim}{888}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ زُرَارَةَ بْنَ أَوْفَى، يُحَدِّثُ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الظُّهْرَ فَجَعَلَ رَجُلٌ يَقْرَأُ خَلْفَهُ بِسَبِّحِ اسْمَ رَبِّكَ الأَعْلَى فَلَمَّا انْصَرَفَ قَالَ ‏"‏ أَيُّكُمْ قَرَأَ ‏"‏ أَوْ ‏"‏ أَيُّكُمُ الْقَارِئُ ‏"‏ فَقَالَ رَجُلٌ أَنَا ‏.‏ فَقَالَ ‏"‏ قَدْ ظَنَنْتُ أَنَّ بَعْضَكُمْ خَالَجَنِيهَا ‏"‏ ‏.‏\hadithno{888}\hadithtrans{Imran b. Husain reported:The Messenger of Allah (ﷺ) observed the Zuhr prayer and a person recited Sabbih Isma Rabbik al-a'la (Glorify the name of thy Lord, the Most High) behind him. When he (the Holy Pro- phet) concluded the prayer he said: Who amongst you recited (the above-mentioned verse) or who amongst you was the reciter? A person said: It was I. Upon this he (the Holy Prophet) observed: I thought as if someone amongst you was disputing with me (in what I was reciting)}}
\hadithdefcmd{muslim}{889}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، كِلاَهُمَا عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الظُّهْرَ وَقَالَ ‏ "‏ قَدْ عَلِمْتُ أَنَّ بَعْضَكُمْ خَالَجَنِيهَا ‏"‏ ‏.‏\hadithno{889}\hadithtrans{This hadith has been narrated by Qatada with the same chain of transmitters that the Messenger of Allah (ﷺ) observed Zuhr prayer and said:I felt that someone amongst you was disputing with me (in what I was reciting)}}
\hadithdefcmd{muslim}{890}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ كِلاَهُمَا عَنْ غُنْدَرٍ، قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسٍ، قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ فَلَمْ أَسْمَعْ أَحَدًا مِنْهُمْ يَقْرَأُ ‏\{‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ‏\}‏ ‏.‏\hadithno{890}\hadithtrans{Anas reported:I observed prayer along with the Messenger of Allah (ﷺ) and with Abu Bakr, Umar and Uthman (may Allah be pleased with all of them), but I never heard any one of them reciting Bismillah-ir-Rahman-ir-Rahim loudly}}
\hadithdefcmd{muslim}{891}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، فِي هَذَا الإِسْنَادِ ‏.‏ وَزَادَ قَالَ شُعْبَةُ فَقُلْتُ لِقَتَادَةَ أَسَمِعْتَهُ مِنْ أَنَسٍ قَالَ نَعَمْ نَحْنُ سَأَلْنَاهُ عَنْهُ ‏.‏\hadithno{891}\hadithtrans{Shu'ba reported it with the same chain of transmitters. with she addition of these words:" I said to Qatada: Did you hear it from Anas? He replied in the affir- mative and added: We had inquired of him about it}}
\hadithdefcmd{muslim}{892}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ عَبْدَةَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، كَانَ يَجْهَرُ بِهَؤُلاَءِ الْكَلِمَاتِ يَقُولُ سُبْحَانَكَ اللَّهُمَّ وَبِحَمْدِكَ تَبَارَكَ اسْمُكَ وَتَعَالَى جَدُّكَ وَلاَ إِلَهَ غَيْرُكَ ‏.‏ وَعَنْ قَتَادَةَ أَنَّهُ كَتَبَ إِلَيْهِ يُخْبِرُهُ عَنْ أَنَسِ بْنِ مَالِكٍ أَنَّهُ حَدَّثَهُ قَالَ صَلَّيْتُ خَلْفَ النَّبِيِّ صلى الله عليه وسلم وَأَبِي بَكْرٍ وَعُمَرَ وَعُثْمَانَ فَكَانُوا يَسْتَفْتِحُونَ بِـ ‏\{‏ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ‏\}‏ لاَ يَذْكُرُونَ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ فِي أَوَّلِ قِرَاءَةٍ وَلاَ فِي آخِرِهَا ‏.‏\hadithno{892}\hadithtrans{Abda reported:'Umar b. al-Khattab used to recite loudly these words: Subhanak Allahumma wa bi hamdika wa tabarakasmuka wa ta'ala jadduka wa la ilaha ghairuka [Glory to Thee,0 Allah, and Thine is the Praise, and Blessed is Thy Name. and Exalted is Thy Majesty. and there is no other object of worship beside Thee]. Qatada informed in writing that Anas b. Malik had narrated to him: I observed prayer behind the Messenger of Allah (ﷺ) and Abu Bakr and Umar and 'Uthman. They started (loud recitation) with: AI-hamdu lillahi Rabb al-'Alamin [All Praise is due to Allah, the Lord of the worlds] and did not recite Bismillah ir- Rahman-ir-Rahim (loudly) at the beginning of the recitation or at the end of it}}
\hadithdefcmd{muslim}{893}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، أَخْبَرَنِي إِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَذْكُرُ ذَلِكَ ‏.‏\hadithno{893}\hadithtrans{It is reported on the authority of Abu Talha that he had heard Anas b. Malik narrating this}}
\hadithdefcmd{muslim}{894}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، أَخْبَرَنَا الْمُخْتَارُ بْنُ فُلْفُلٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الْمُخْتَارِ، عَنْ أَنَسٍ، قَالَ بَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ بَيْنَ أَظْهُرِنَا إِذْ أَغْفَى إِغْفَاءَةً ثُمَّ رَفَعَ رَأْسَهُ مُتَبَسِّمًا فَقُلْنَا مَا أَضْحَكَكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ أُنْزِلَتْ عَلَىَّ آنِفًا سُورَةٌ ‏"‏ ‏.‏ فَقَرَأَ ‏"‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏\{‏ إِنَّا أَعْطَيْنَاكَ الْكَوْثَرَ * فَصَلِّ لِرَبِّكَ وَانْحَرْ * إِنَّ شَانِئَكَ هُوَ الأَبْتَرُ‏\}‏ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَتَدْرُونَ مَا الْكَوْثَرُ ‏"‏ ‏.‏ فَقُلْنَا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ فَإِنَّهُ نَهْرٌ وَعَدَنِيهِ رَبِّي عَزَّ وَجَلَّ عَلَيْهِ خَيْرٌ كَثِيرٌ هُوَ حَوْضٌ تَرِدُ عَلَيْهِ أُمَّتِي يَوْمَ الْقِيَامَةِ آنِيَتُهُ عَدَدُ النُّجُومِ فَيُخْتَلَجُ الْعَبْدُ مِنْهُمْ فَأَقُولُ رَبِّ إِنَّهُ مِنْ أُمَّتِي ‏.‏ فَيَقُولُ مَا تَدْرِي مَا أَحْدَثَتْ بَعْدَكَ ‏"‏ ‏.‏ زَادَ ابْنُ حُجْرٍ فِي حَدِيثِهِ بَيْنَ أَظْهُرِنَا فِي الْمَسْجِدِ ‏.‏ وَقَالَ ‏"‏ مَا أَحْدَثَ بَعْدَكَ ‏"‏ ‏.‏\hadithno{894}\hadithtrans{Anas reported:One day the Messenger of Allah (ﷺ) was sitting amongst us that he dozed off. He then raised his head smilingly. We said: What makes you smile. Messenger of Allah? He said: A Sura has just been revealed to me, and then recited: In the name of Allah, the Compassionate, the Merciful. Verily We have given thee Kauthar (fount of abundance). Therefore turn to thy Lord for prayer and offer sacrifice, and surely thy enemy is cut off (from the good). Then he (the Holy Prophet) said: Do you know what Kauthar is? We said: Allah and His Messenger know best. The Prophet (ﷺ) said: It (Kauthar) is a canal which my Lord, the Exalted and Glorious has promised me, and there is an abundance of good in it. It is a cistern and my people would come to it on the Day of Resurrection, and tumblers there would be equal to the number of stars. A servant would be turned away from (among the people gathered there). Upon this I would say: My Lord, he is one of my people, and He (the Lord) would say: You do not know that he innovated new things (in Islam) after you. Ibn Hujr made this addition in the hadith:" He (the Holy Prophet) was sitting amongst us in the mosque, and He (Allah) said: (You don't know) what he innovated after you}}
\hadithdefcmd{muslim}{895}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ أَخْبَرَنَا ابْنُ فُضَيْلٍ، عَنْ مُخْتَارِ بْنِ فُلْفُلٍ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ أَغْفَى رَسُولُ اللَّهِ صلى الله عليه وسلم إِغْفَاءَةً ‏.‏ بِنَحْوِ حَدِيثِ ابْنِ مُسْهِرٍ غَيْرَ أَنَّهُ قَالَ ‏"‏ نَهْرٌ وَعَدَنِيهِ رَبِّي عَزَّ وَجَلَّ فِي الْجَنَّةِ عَلَيْهِ حَوْضٌ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ ‏"‏ آنِيَتُهُ عَدَدُ النُّجُومِ ‏"‏ ‏.‏\hadithno{895}\hadithtrans{Mukhtar b. Fulful reported that he had heard Anas b. Malik say that the Messenger of Allah (ﷺ) dozed off, and the rest of the hadith is the same as transmitted by Mus-hir except for the words that he (the Holy Prophet) said:It (Kauthar) is a canal which my Lord the Exalted and the Glorious has promised me in Paradise. There is a tank over it, but he made no mention of the tumblers like the number of the stars}}
\hadithdefcmd{muslim}{896}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا مُحَمَّدُ بْنُ جُحَادَةَ، حَدَّثَنِي عَبْدُ الْجَبَّارِ بْنُ وَائِلٍ، عَنْ عَلْقَمَةَ بْنِ وَائِلٍ، وَمَوْلًى، لَهُمْ أَنَّهُمَا حَدَّثَاهُ عَنْ أَبِيهِ، وَائِلِ بْنِ حُجْرٍ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم رَفَعَ يَدَيْهِ حِينَ دَخَلَ فِي الصَّلاَةِ كَبَّرَ - وَصَفَ هَمَّامٌ حِيَالَ أُذُنَيْهِ - ثُمَّ الْتَحَفَ بِثَوْبِهِ ثُمَّ وَضَعَ يَدَهُ الْيُمْنَى عَلَى الْيُسْرَى فَلَمَّا أَرَادَ أَنْ يَرْكَعَ أَخْرَجَ يَدَيْهِ مِنَ الثَّوْبِ ثُمَّ رَفَعَهُمَا ثُمَّ كَبَّرَ فَرَكَعَ فَلَمَّا قَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ رَفَعَ يَدَيْهِ فَلَمَّا سَجَدَ سَجَدَ بَيْنَ كَفَّيْهِ ‏.‏\hadithno{896}\hadithtrans{Wa'il b. Hujr reported:He saw the Messenger of Allah (ﷺ) raising his hands at the time of beginning the prayer and reciting takbir, and according to Hammam (the narrator), the hands were lifted opposite to ears. He (the Holy Prophet) then wrapped his hands in his cloth and placed his right hand over his left hand. And when he was about to bow down, he brought out his hands from the cloth, and then lifted them, and then recited takbir and bowed down, and when (he came back to the erect position) he recited:" Allah listened to him who praised Him." And when he prostrated, he prostrated between his two palms}}
\hadithdefcmd{muslim}{897}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا نَقُولُ فِي الصَّلاَةِ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم السَّلاَمُ عَلَى اللَّهِ السَّلاَمُ عَلَى فُلاَنٍ ‏.‏ فَقَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ ‏ "‏ إِنَّ اللَّهَ هُوَ السَّلاَمُ فَإِذَا قَعَدَ أَحَدُكُمْ فِي الصَّلاَةِ فَلْيَقُلِ التَّحِيَّاتُ لِلَّهِ وَالصَّلَوَاتُ وَالطَّيِّبَاتُ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ فَإِذَا قَالَهَا أَصَابَتْ كُلَّ عَبْدٍ لِلَّهِ صَالِحٍ فِي السَّمَاءِ وَالأَرْضِ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ثُمَّ يَتَخَيَّرُ مِنَ الْمَسْأَلَةِ مَا شَاءَ ‏"‏ ‏.‏\hadithno{897}\hadithtrans{Abdullah (b. Mas`ud) said:While observing prayer behind the Messenger of Allah (ﷺ) we used to recite: Peace be upon Allah, peace be upon so and so. One day the Messenger of Allah (ﷺ) said to us: Verily Allah is Himself Peace. When any one of you sits during the prayer, he should say: All services rendered by words, by acts of worship, and all good things are due to Allah. Peace be upon you, O Prophet, and Allah's mercy and blessings. Peace be upon us and upon Allah's upright servants, for when he says this it reaches every upright servant in the heavens and the earth. (And say further): I testify that there is no god but Allah and I testify that Muhammad is His servant and Messenger. Then he may choose any supplication which pleases him and offer it}}
\hadithdefcmd{muslim}{898}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ وَلَمْ يَذْكُرْ ‏ "‏ ثُمَّ يَتَخَيَّرُ مِنَ الْمَسْأَلَةِ مَا شَاءَ ‏"‏ ‏.‏\hadithno{898}\hadithtrans{Shu'ba has narrated this on the authority of Mansur with the same chain of transmitters, but he made no mention of this:" Then he may choose any supplication which pleases him}}
\hadithdefcmd{muslim}{899}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا حُسَيْنٌ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ مِثْلَ حَدِيثِهِمَا وَذَكَرَ فِي الْحَدِيثِ ‏ "‏ ثُمَّ لْيَتَخَيَّرْ بَعْدُ مِنَ الْمَسْأَلَةِ مَا شَاءَ أَوْ مَا أَحَبَّ ‏"‏ ‏.‏\hadithno{899}\hadithtrans{This hadith has been narrated on the authority of Mansur with the same chain of transmitters and he made a mention of this:" Then he may choose any supplication which pleases him or which he likes}}
\hadithdefcmd{muslim}{900}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ كُنَّا إِذَا جَلَسْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي الصَّلاَةِ ‏.‏ بِمِثْلِ حَدِيثِ مَنْصُورٍ وَقَالَ ‏ "‏ ثُمَّ يَتَخَيَّرُ بَعْدُ مِنَ الدُّعَاءِ ‏"‏ ‏.‏\hadithno{900}\hadithtrans{Abdullah b. Mas'ud reported:We were sitting with the Apostle (ﷺ) in prayer, and the rest of the hadith is the same as narrated by Mansur He (also said): After (reciting tashahud) he may choose any prayer}}
\hadithdefcmd{muslim}{901}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سَيْفُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ مُجَاهِدًا، يَقُولُ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ سَخْبَرَةَ، قَالَ سَمِعْتُ ابْنَ مَسْعُودٍ، يَقُولُ عَلَّمَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم التَّشَهُّدَ كَفِّي بَيْنَ كَفَّيْهِ كَمَا يُعَلِّمُنِي السُّورَةَ مِنَ الْقُرْآنِ ‏.‏ وَاقْتَصَّ التَّشَهُّدَ بِمِثْلِ مَا اقْتَصُّوا ‏.‏\hadithno{901}\hadithtrans{Ibn Mas'ud is reported to have said:The Messenger of Allah (ﷺ) taught me tashahhud taking my hand within his palms, in the same way as he taught me a Sura of the Qur'an, and he narrated it as narrated above}}
\hadithdefcmd{muslim}{902}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، وَعَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُنَا التَّشَهُّدَ كَمَا يُعَلِّمُنَا السُّورَةَ مِنَ الْقُرْآنِ فَكَانَ يَقُولُ ‏ "‏ التَّحِيَّاتُ الْمُبَارَكَاتُ الصَّلَوَاتُ الطَّيِّبَاتُ لِلَّهِ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ رُمْحٍ كَمَا يُعَلِّمُنَا الْقُرْآنَ ‏.‏\hadithno{902}\hadithtrans{Ibn `Abbas reported:The Messenger of Allah (ﷺ) used to teach us tashahhud just as he used to teach us a Surah of the Qur'an, and he would say: All services rendered by words, acts of worship, and all good things are due to Allah. Peace be upon you, O Prophet, and Allah's mercy and blessings. Peace be upon us and upon Allah's upright servants. I testify that there is no god but Allah, and I testify that Muhammad is the Messenger of Allah. In the narration of Ibn Rumh (the words are): "As he would teach us the Qur'an}}
\hadithdefcmd{muslim}{903}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ حُمَيْدٍ، حَدَّثَنِي أَبُو الزُّبَيْرِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُنَا التَّشَهُّدَ كَمَا يُعَلِّمُنَا السُّورَةَ مِنَ الْقُرْآنِ ‏.‏\hadithno{903}\hadithtrans{Tawus narrated it on the authority of Ibn 'Abbas that he said:The Messenger of Allah (ﷺ) used to teach us tashahhud as he would teach us a Sura of the Qur'an}}
\hadithdefcmd{muslim}{904}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ وَمُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ الأُمَوِيُّ - وَاللَّفْظُ لأَبِي كَامِلٍ - قَالُوا حَدَّثَنَا أَبُو عَوَانَةَ عَنْ قَتَادَةَ عَنْ يُونُسَ بْنِ جُبَيْرٍ عَنْ حِطَّانَ بْنِ عَبْدِ اللَّهِ الرَّقَاشِيِّ قَالَ صَلَّيْتُ مَعَ أَبِي مُوسَى الأَشْعَرِيِّ صَلاَةً فَلَمَّا كَانَ عِنْدَ الْقَعْدَةِ قَالَ رَجُلٌ مِنَ الْقَوْمِ أُقِرَّتِ الصَّلاَةُ بِالْبِرِّ وَالزَّكَاةِ - قَالَ - فَلَمَّا قَضَى أَبُو مُوسَى الصَّلاَةَ وَسَلَّمَ انْصَرَفَ فَقَالَ أَيُّكُمُ الْقَائِلُ كَلِمَةَ كَذَا وَكَذَا قَالَ فَأَرَمَّ الْقَوْمُ ثُمَّ قَالَ أَيُّكُمُ الْقَائِلُ كَلِمَةَ كَذَا وَكَذَا فَأَرَمَّ الْقَوْمُ فَقَالَ لَعَلَّكَ يَا حِطَّانُ قُلْتَهَا قَالَ مَا قُلْتُهَا وَلَقَدْ رَهِبْتُ أَنْ تَبْكَعَنِي بِهَا ‏.‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ أَنَا قُلْتُهَا وَلَمْ أُرِدْ بِهَا إِلاَّ الْخَيْرَ ‏.‏ فَقَالَ أَبُو مُوسَى أَمَا تَعْلَمُونَ كَيْفَ تَقُولُونَ فِي صَلاَتِكُمْ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَطَبَنَا فَبَيَّنَ لَنَا سُنَّتَنَا وَعَلَّمَنَا صَلاَتَنَا فَقَالَ ‏"‏ إِذَا صَلَّيْتُمْ فَأَقِيمُوا صُفُوفَكُمْ ثُمَّ لْيَؤُمَّكُمْ أَحَدُكُمْ فَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا قَالَ غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ فَقُولُوا آمِينَ ‏.‏ يُجِبْكُمُ اللَّهُ فَإِذَا كَبَّرَ وَرَكَعَ فَكَبِّرُوا وَارْكَعُوا فَإِنَّ الإِمَامَ يَرْكَعُ قَبْلَكُمْ وَيَرْفَعُ قَبْلَكُمْ ‏"‏ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَتِلْكَ بِتِلْكَ وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏.‏ فَقُولُوا اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ ‏.‏ يَسْمَعُ اللَّهُ لَكُمْ فَإِنَّ اللَّهَ تَبَارَكَ وَتَعَالَى قَالَ عَلَى لِسَانِ نَبِيِّهِ صلى الله عليه وسلم سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏.‏ وَإِذَا كَبَّرَ وَسَجَدَ فَكَبِّرُوا وَاسْجُدُوا فَإِنَّ الإِمَامَ يَسْجُدُ قَبْلَكُمْ وَيَرْفَعُ قَبْلَكُمْ ‏"‏ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَتِلْكَ بِتِلْكَ ‏.‏ وَإِذَا كَانَ عِنْدَ الْقَعْدَةِ فَلْيَكُنْ مِنْ أَوَّلِ قَوْلِ أَحَدِكُمُ التَّحِيَّاتُ الطَّيِّبَاتُ الصَّلَوَاتُ لِلَّهِ السَّلاَمُ عَلَيْكَ أَيُّهَا النَّبِيُّ وَرَحْمَةُ اللَّهِ وَبَرَكَاتُهُ السَّلاَمُ عَلَيْنَا وَعَلَى عِبَادِ اللَّهِ الصَّالِحِينَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏"‏ ‏.‏\hadithno{904}\hadithtrans{Hattan b. `Abdullah al-Raqashi reported:I observed prayer with Abu Musa al-Ash`ari and when he was in the qa`dah, one among the people said: The prayer has been made obligatory along with piety and Zakat. He (the narrator) said: When Abu Musa had finished the prayer after salutation he turned (towards the people) and said: Who amongst you said such and such a thing? A hush fell on the people. He again said: Who amongst you has said such and such a thing? A hush fell on the people. He (Abu Musa) said: Hattan, it is perhaps you that have uttered it. He (Hattan) said No. I have not uttered it. I was afraid that you might be annoyed with me on account of this. A person amongst the people said: It was I who said it, and in this I intended nothing but good. Abu Musa said: Don't you know what you have to recite in your prayers? Verily the Messenger of Allah (ﷺ) addressed us and explained to us all its aspects and taught us how to observe prayer (properly). He (the Holy Prophet) said: When you pray make your rows straight and let anyone amongst you act as your Imam. Recite the takbir when he recites it and when he recites: Not of those with whom Thou art angry, nor of those who go astray, say: Amin. Allah would respond you. And when he (the Imam) recites the takbir, you may also recite the takbir, for the Imam bows before you and raises himself before you. Then the Messenger of Allah (ﷺ) said: The one is equivalent to the other. And when he says: Allah listens to him who praises Him, you should say: O Allah, our Lord, to Thee be the praise, for Allah, the Exalted and Glorious, has vouchsafed (us) through the tongue of His Apostle (ﷺ) that Allah listens to him who praises Him. And when he (the Imam) recites the takbir and prostrates, you should also recite the takbir and prostrate, for the Imam prostrates before you and raises himself before you. The Messenger of Allah (ﷺ) said: The one is equivalent to the other. And when he (the Imam) sits for Qa`da (for tashahhud) the first words of every one amongst you should be: All services rendered by words, acts of worship and all good things are due to Allah. Peace be upon you, O Apostle, and Allah's mercy and blessings. Peace be upon us and upon the upright servants of Allah. I testify that there is no god but Allah, and I testify that Muhammad is His servant and His Messenger}}
\hadithdefcmd{muslim}{905}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، ح وَحَدَّثَنَا أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، كُلُّ هَؤُلاَءِ عَنْ قَتَادَةَ، فِي هَذَا الإِسْنَادِ بِمِثْلِهِ ‏.‏ وَفِي حَدِيثِ جَرِيرٍ عَنْ سُلَيْمَانَ عَنْ قَتَادَةَ مِنَ الزِّيَادَةِ ‏"‏ وَإِذَا قَرَأَ فَأَنْصِتُوا ‏"‏ ‏.‏ وَلَيْسَ فِي حَدِيثِ أَحَدٍ مِنْهُمْ ‏"‏ فَإِنَّ اللَّهَ قَالَ عَلَى لِسَانِ نَبِيِّهِ صلى الله عليه وسلم سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ إِلاَّ فِي رِوَايَةِ أَبِي كَامِلٍ وَحْدَهُ عَنْ أَبِي عَوَانَةَ ‏.‏ قَالَ أَبُو إِسْحَاقَ قَالَ أَبُو بَكْرِ ابْنُ أُخْتِ أَبِي النَّضْرِ فِي هَذَا الْحَدِيثِ فَقَالَ مُسْلِمٌ تُرِيدُ أَحْفَظَ مِنْ سُلَيْمَانَ فَقَالَ لَهُ أَبُو بَكْرٍ فَحَدِيثُ أَبِي هُرَيْرَةَ فَقَالَ هُوَ صَحِيحٌ يَعْنِي وَإِذَا قَرَأَ فَأَنْصِتُوا ‏.‏ فَقَالَ هُوَ عِنْدِي صَحِيحٌ ‏.‏ فَقَالَ لِمَ لَمْ تَضَعْهُ هَا هُنَا قَالَ لَيْسَ كُلُّ شَىْءٍ عِنْدِي صَحِيحٍ وَضَعْتُهُ هَا هُنَا ‏.‏ إِنَّمَا وَضَعْتُ هَا هُنَا مَا أَجْمَعُوا عَلَيْهِ ‏.‏\hadithno{905}\hadithtrans{Qatada has narrated a hadith like this with another chain of transmitters. In the hadith transmitted by Jarir on the authority of Sulaiman, Qatada's further words are:When (the Qur'an) is recited (in prayer), you should observe silence, and (the following words are) not found in the hadith narrated by anyone except by Abu Kamil who heard it from Abu 'Awina (and the words are): Verily Allah vouchsafed through the tongue of the Messenger of Allah (ﷺ) this: Allah listens to him who praises Him. Abu Ishaq (a student of Imam Muslim) said: Abu Bakr the son of Abu Nadr's sister has (critically) discussed this hadith. Imam Muslim said: Whom can you find a more authentic transmitter of hadith than Sulaiman? Abu Bakr said to him (Imam Muslim): What about the hadith narrated by Abu Huraira, i.e. the hadith that when the Qur'an is recited (in prayer) observe silence? He (Abu Bakr again) said: Then, why have you not included it (in your compilation)? He (Imam Muslim) said: I have not included in this every hadith which I deem authentic; I have recorded only such ahadith on which there is an agreement (amongst the Muhaddithin apart from their being authentic)}}
\hadithdefcmd{muslim}{906}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، عَنْ عَبْدِ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ وَقَالَ فِي الْحَدِيثِ ‏ "‏ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ قَضَى عَلَى لِسَانِ نَبِيِّهِ صلى الله عليه وسلم سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏\hadithno{906}\hadithtrans{This hadith has been transmitted by Qatida with the same chain of transmitters (and the words are):" Allah, the Exalted and the Glorious, commanded it through the tongue of His Apostle (may peace be upon-him): Allah listens to him who praises Him}}
\hadithdefcmd{muslim}{907}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نُعَيْمِ بْنِ عَبْدِ اللَّهِ الْمُجْمِرِ، أَنَّ مُحَمَّدَ بْنَ عَبْدِ اللَّهِ بْنِ زَيْدٍ الأَنْصَارِيَّ، - وَعَبْدُ اللَّهِ بْنُ زَيْدٍ هُوَ الَّذِي كَانَ أُرِيَ النِّدَاءَ بِالصَّلاَةِ - أَخْبَرَهُ عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ قَالَ أَتَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ فِي مَجْلِسِ سَعْدِ بْنِ عُبَادَةَ فَقَالَ لَهُ بَشِيرُ بْنُ سَعْدٍ أَمَرَنَا اللَّهُ تَعَالَى أَنْ نُصَلِّيَ عَلَيْكَ يَا رَسُولَ اللَّهِ فَكَيْفَ نُصَلِّي عَلَيْكَ قَالَ فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى تَمَنَّيْنَا أَنَّهُ لَمْ يَسْأَلْهُ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم قُولُوا ‏ "‏ اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا صَلَّيْتَ عَلَى آلِ إِبْرَاهِيمَ وَبَارِكْ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ فِي الْعَالَمِينَ إِنَّكَ حَمِيدٌ مَجِيدٌ ‏.‏ وَالسَّلاَمُ كَمَا قَدْ عَلِمْتُمْ ‏"‏ ‏.‏\hadithno{907}\hadithtrans{Abdullah b. Zaid-he who was shown the call (for prayer in a dream) narrated it on the authority of Abu Mas'ud al-Ansari who said:We were sitting in the company of Sa'id b. 'Ubida when the Messenger of Allah (ﷺ) came to us. Bashir b. S'ad said: Allah has commanded us to bless you. Messenger of Allah! But how should we bless you? He (the narrator) said: The Messenger of Allah (ﷺ) kept quiet (and we were so much perturbed over his silence) that we wished we had not asked him. The Messenger of Allah (ﷺ) then said: (For blessing me) say:" 0 Allah, bless Muhammad and the members of his household as Thou didst bless the mernbers of Ibrahim's household. Grant favours to Muhammad and the members of his household as Thou didst grant favours to the members of the household of Ibrahim in the world. Thou art indeed Praiseworthy and Glorious" ; and salutation as you know}}
\hadithdefcmd{muslim}{908}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ سَمِعْتُ ابْنَ أَبِي لَيْلَى، قَالَ لَقِيَنِي كَعْبُ بْنُ عُجْرَةَ فَقَالَ أَلاَ أُهْدِي لَكَ هَدِيَّةً خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْنَا قَدْ عَرَفْنَا كَيْفَ نُسَلِّمُ عَلَيْكَ فَكَيْفَ نُصَلِّي عَلَيْكَ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا صَلَّيْتَ عَلَى آلِ إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ اللَّهُمَّ بَارِكْ عَلَى مُحَمَّدٍ وَعَلَى آلِ مُحَمَّدٍ كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏ ‏.‏\hadithno{908}\hadithtrans{Ibn Abi Laila reported:Ka'b b. 'Ujra met me and said: Should I not offer you a present (and added): The Messenger of Allah (ﷺ) came to us and we said: We have learnt how to invoke peace upon you; (kindly tell us) how we should bless you. He (the Holy Prophet) said: Say:" O Allah: bless Muhammad and his family as Thou didst bless the family of Ibrahim. Verily Thou art Praiseworthy and Glorious, O Allah}}
\hadithdefcmd{muslim}{909}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، وَمِسْعَرٍ، عَنِ الْحَكَمِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏ وَلَيْسَ فِي حَدِيثِ مِسْعَرٍ أَلاَ أُهْدِي لَكَ هَدِيَّةً\hadithno{909}\hadithtrans{A hadith like this has been narrated by Mis'ar on the authority of al-Hakam, but in the hadith transmitted by Mis'ar these words are not found:" Should I not offer you a present?}}
\hadithdefcmd{muslim}{910}{حَدَّثَنَا مُحَمَّدُ بْنُ بَكَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ، عَنِ الأَعْمَشِ، وَعَنْ مِسْعَرٍ، وَعَنْ مَالِكِ بْنِ مِغْوَلٍ، كُلُّهُمْ عَنِ الْحَكَمِ، بِهَذَا الإِسْنَادِ مِثْلَهُ غَيْرَ أَنَّهُ قَالَ ‏ "‏ وَبَارِكْ عَلَى مُحَمَّدٍ ‏"‏ ‏.‏ وَلَمْ يَقُلِ اللَّهُمَّ ‏.‏\hadithno{910}\hadithtrans{A hadith like this has been narrated by al-Hakam except that he said:" Bless Muhammad (ﷺ)" and he did not say:" O Allah I}}
\hadithdefcmd{muslim}{911}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا رَوْحٌ، وَعَبْدُ اللَّهِ بْنُ نَافِعٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لَهُ - قَالَ أَخْبَرَنَا رَوْحٌ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ، أَخْبَرَنِي أَبُو حُمَيْدٍ السَّاعِدِيُّ، أَنَّهُمْ قَالُوا يَا رَسُولَ اللَّهِ كَيْفَ نُصَلِّي عَلَيْكَ قَالَ ‏ "‏ قُولُوا اللَّهُمَّ صَلِّ عَلَى مُحَمَّدٍ وَعَلَى أَزْوَاجِهِ وَذُرِّيَّتِهِ كَمَا صَلَّيْتَ عَلَى آلِ إِبْرَاهِيمَ وَبَارِكْ عَلَى مُحَمَّدٍ وَعَلَى أَزْوَاجِهِ وَذُرِّيَّتِهِ كَمَا بَارَكْتَ عَلَى آلِ إِبْرَاهِيمَ إِنَّكَ حَمِيدٌ مَجِيدٌ ‏"‏ ‏.‏\hadithno{911}\hadithtrans{Abu Humaid as-Sa'idi reported:They (the Companions of the Holy Prophet) said: Apostle of Allah, how should we bless you? He (the Holy Prophet) observed: Say:" O Allah! bless Muhammad, his wives and his offspring as Thou didst bless Ibrahim, and grant favours to Muhammad, and his wives and his offspring as Thou didst grant favours to the family of Ibrahim; Thou art Praiseworthy and Glorious}}
\hadithdefcmd{muslim}{912}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَلَّى عَلَىَّ وَاحِدَةً صَلَّى اللَّهُ عَلَيْهِ عَشْرًا ‏"‏ ‏.‏\hadithno{912}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: He who blesses me once, Allah would bless him ten times}}
\hadithdefcmd{muslim}{913}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَالَ الإِمَامُ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏.‏ فَقُولُوا اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ ‏.‏ فَإِنَّهُ مَنْ وَافَقَ قَوْلُهُ قَوْلَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{913}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: When the Imam says:" Allah listens to him who praises Him." you should say:" O Allah, our Lord for Thee is the praise." for if what anyone says synchronises with what the angels say, his past sins will be forgiven}}
\hadithdefcmd{muslim}{914}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ سُمَىٍّ ‏.‏\hadithno{914}\hadithtrans{A hadith like this is narrated by Abu Huraira by another chain of transmitters}}
\hadithdefcmd{muslim}{915}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ أَنَّهُمَا أَخْبَرَاهُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا أَمَّنَ الإِمَامُ فَأَمِّنُوا فَإِنَّهُ مَنْ وَافَقَ تَأْمِينُهُ تَأْمِينَ الْمَلاَئِكَةِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ آمِينَ ‏"‏ ‏.‏\hadithno{915}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: SayAmin when the Imam says Amin, for it anyone's utterance of Amin synchronises with that of the angels, he will be forgiven his past sins}}
\hadithdefcmd{muslim}{916}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي ابْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ مَالِكٍ وَلَمْ يَذْكُرْ قَوْلَ ابْنِ شِهَابٍ ‏.‏\hadithno{916}\hadithtrans{Abu Huraira said:I heard from the Messenger of Allah (ﷺ) the hadith like one transmitted by Malik, but he made no mention of the words of Shihab}}
\hadithdefcmd{muslim}{917}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، أَنَّ أَبَا يُونُسَ، حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَالَ أَحَدُكُمْ فِي الصَّلاَةِ آمِينَ ‏.‏ وَالْمَلاَئِكَةُ فِي السَّمَاءِ آمِينَ ‏.‏ فَوَافَقَ إِحْدَاهُمَا الأُخْرَى غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{917}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: When anyone amongst you utters Amin in prayer and the angels in the sky also utter Amin, and this (utterance of the one) synchronises with (that of) the other, all his previous sins are pardoned}}
\hadithdefcmd{muslim}{918}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا الْمُغِيرَةُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا قَالَ أَحَدُكُمْ آمِينَ ‏.‏ وَالْمَلاَئِكَةُ فِي السَّمَاءِ آمِينَ ‏.‏ فَوَافَقَتْ إِحْدَاهُمَا الأُخْرَى غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{918}\hadithtrans{Abu Harare reported:The Messenger of Allah (ﷺ) said: When anyone amongst you utters Amin and the angels In the heaven also utter Amin and (the Amin) of the one synchronises with (that of) the other, all his previous sins are pardoned}}
\hadithdefcmd{muslim}{919}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{919}\hadithtrans{A hadith like this is transmitted by Ma'mar from Hammam b. Munabbih on the authority of Abu Huraira who reported it from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{920}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا قَالَ الْقَارِئُ غَيْرِ الْمَغْضُوبِ عَلَيْهِمْ وَلاَ الضَّالِّينَ ‏.‏ فَقَالَ مَنْ خَلْفَهُ آمِينَ ‏.‏ فَوَافَقَ قَوْلُهُ قَوْلَ أَهْلِ السَّمَاءِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{920}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: When the reciter (Imam) utters:" Not of those on whom (is Thine) wrath and not the erring ones," and (the person) behind him utters Amin and his utterance synchronises with that of the dwellers of heavens, all his previous sins would be pardoned}}
\hadithdefcmd{muslim}{921}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَزُهَيْرُ بْنُ حَرْبٍ وَأَبُو كُرَيْبٍ جَمِيعًا عَنْ سُفْيَانَ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنِ الزُّهْرِيِّ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ سَقَطَ النَّبِيُّ صلى الله عليه وسلم عَنْ فَرَسٍ فَجُحِشَ شِقُّهُ الأَيْمَنُ فَدَخَلْنَا عَلَيْهِ نَعُودُهُ فَحَضَرَتِ الصَّلاَةُ فَصَلَّى بِنَا قَاعِدًا فَصَلَّيْنَا وَرَاءَهُ قُعُودًا فَلَمَّا قَضَى الصَّلاَةَ قَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ فَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا سَجَدَ فَاسْجُدُوا وَإِذَا رَفَعَ فَارْفَعُوا وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏.‏ فَقُولُوا رَبَّنَا وَلَكَ الْحَمْدُ ‏.‏ وَإِذَا صَلَّى قَاعِدًا فَصَلُّوا قُعُودًا أَجْمَعُونَ ‏"‏ ‏.‏\hadithno{921}\hadithtrans{Anas b. Malik reported:The Apostle of Allah (ﷺ) fell down from a horse and his right side was grazed. We went to him to inquire after his health when the time of prayer came. He led us in prayer in a sitting posture and we said prayer behind him sitting, and when he finished the prayer hesaid: The Imam is appointed only to be followed; so when he recites takbir, you should also recite that; when he prostrates, you should also prostrate; when he rises up, you should also rise up, and when he said" God listens to him who praises Him," you should say:" Our Lord, to Thee be the praise," and when he prays sitting, all of you should pray sitting}}
\hadithdefcmd{muslim}{922}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ خَرَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ فَرَسٍ فَجُحِشَ فَصَلَّى لَنَا قَاعِدًا ‏.‏ ثُمَّ ذَكَرَ نَحْوَهُ ‏.‏\hadithno{922}\hadithtrans{Anas b. Malik reported:The Messenger of Allah (ﷺ) fell down from a horse and he was grazed and he led the prayer for us sitting, and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{923}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صُرِعَ عَنْ فَرَسٍ فَجُحِشَ شِقُّهُ الأَيْمَنُ بِنَحْوِ حَدِيثِهِمَا وَزَادَ ‏ "‏ فَإِذَا صَلَّى قَائِمًا فَصَلُّوا قِيَامًا ‏"‏ ‏.‏\hadithno{923}\hadithtrans{Anas b. Malik reported:The Messenger of Allah (ﷺ) fell down from a horse and his right side was grazed, and the rest of the hadith is the same with the addition of these words:" When he (the Imam) says prayer standing, you should also do so}}
\hadithdefcmd{muslim}{924}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَكِبَ فَرَسًا فَصُرِعَ عَنْهُ فَجُحِشَ شِقُّهُ الأَيْمَنُ ‏.‏ بِنَحْوِ حَدِيثِهِمْ وَفِيهِ ‏ "‏ إِذَا صَلَّى قَائِمًا فَصَلُّوا قِيَامًا ‏"‏ ‏.‏\hadithno{924}\hadithtrans{Anas reported:The Messenger of Allah (ﷺ) rode a horse and fell down from it and his right side was grazed, and the rest of the hadith is the same, and (these words) are found in it:" When he (the Imam) says prayer in an erect posture, you should also say it in an erect posture}}
\hadithdefcmd{muslim}{925}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي أَنَسٌ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سَقَطَ مِنْ فَرَسِهِ فَجُحِشَ شِقُّهُ الأَيْمَنُ ‏.‏ وَسَاقَ الْحَدِيثَ وَلَيْسَ فِيهِ زِيَادَةُ يُونُسَ وَمَالِكٍ ‏.‏\hadithno{925}\hadithtrans{Anas b. Malik reported:The Messenger of Allah (ﷺ) fell down from his horse and his right side was grazed, and the rest of the hadith is the same. In this hadith there are no additions (of words) as transmitted by Yunus and Malik}}
\hadithdefcmd{muslim}{926}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتِ اشْتَكَى رَسُولُ اللَّهِ صلى الله عليه وسلم فَدَخَلَ عَلَيْهِ نَاسٌ مِنْ أَصْحَابِهِ يَعُودُونَهُ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسًا فَصَلَّوْا بِصَلاَتِهِ قِيَامًا فَأَشَارَ إِلَيْهِمْ أَنِ اجْلِسُوا ‏.‏ فَجَلَسُوا فَلَمَّا انْصَرَفَ قَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ فَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا رَفَعَ فَارْفَعُوا وَإِذَا صَلَّى جَالِسًا فَصَلُّوا جُلُوسًا ‏"‏ ‏.‏\hadithno{926}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) fell ill and some of his Companions came to inquire after his health. The Messenger of Allah (ﷺ) said prayer sitting, while (his Companions) said it (behind him) standing. He (the Holy Prophet) directed them by his gesture to sit down, and they sat down (in prayer). After finishing the (prayer) he (the Holy Prophet) said: The Imam is appointed so that he should be followed, so bow down when he bows down, and rise upp when he rises up and say (prayer) sitting when he (the Imam) says (it) sitting}}
\hadithdefcmd{muslim}{927}{حَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ يَعْنِي ابْنَ زَيْدٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا ابْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، قَالَ حَدَّثَنَا أَبِي جَمِيعًا، عَنْ هِشَامِ بْنِ عُرْوَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{927}\hadithtrans{This hadith is narrated with the same chain of transmitters by Hisham b. 'Urwa}}
\hadithdefcmd{muslim}{928}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ اشْتَكَى رَسُولُ اللَّهِ صلى الله عليه وسلم فَصَلَّيْنَا وَرَاءَهُ وَهُوَ قَاعِدٌ وَأَبُو بَكْرٍ يُسْمِعُ النَّاسَ تَكْبِيرَهُ فَالْتَفَتَ إِلَيْنَا فَرَآنَا قِيَامًا فَأَشَارَ إِلَيْنَا فَقَعَدْنَا فَصَلَّيْنَا بِصَلاَتِهِ قُعُودًا فَلَمَّا سَلَّمَ قَالَ ‏ "‏ إِنْ كِدْتُمْ آنِفًِا لَتَفْعَلُونَ فِعْلَ فَارِسَ وَالرُّومِ يَقُومُونَ عَلَى مُلُوكِهِمْ وَهُمْ قُعُودٌ فَلاَ تَفْعَلُوا ائْتَمُّوا بِأَئِمَّتِكُمْ إِنْ صَلَّى قَائِمًا فَصَلُّوا قِيَامًا وَإِنْ صَلَّى قَاعِدًا فَصَلُّوا قُعُودًا ‏"‏ ‏.‏\hadithno{928}\hadithtrans{Jabir reported:The Messenger of Allah (ﷺ) was ill and we said prayer behind him and he was sitting. And Abu Bakr was making audible to the people his takbir. As he paid his attention towards us he saw us standing and (directed us to sit down) with a gesture. So we sat down and said our prayer with his prayer in a sitting posture. After uttering salutation he said: You were at this time about to do an act like that of the Persians and the Romans. They stand before their kings while they sit, so don't do that; follow your Imams. If they say prayer standing, you should also do so, and if they say prayer sitting, you should also say prayer sitting}}
\hadithdefcmd{muslim}{929}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ الرُّؤَاسِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ خَلْفَهُ فَإِذَا كَبَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم كَبَّرَ أَبُو بَكْرٍ لِيُسْمِعَنَا ‏.‏ ثُمَّ ذَكَرَ نَحْوَ حَدِيثِ اللَّيْثِ ‏.‏\hadithno{929}\hadithtrans{Jabir said:The Messenger of Allah (ﷺ) led the prayer and Abu Bakr was behind him. When the Messenger of Allah (ﷺ) recited the takbir, Abu Bakr also recited (it) in order to make it audible to us. And the rest of the hadith is like one transmitted by Laith}}
\hadithdefcmd{muslim}{930}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا الإِمَامُ لِيُؤْتَمَّ بِهِ فَلاَ تَخْتَلِفُوا عَلَيْهِ فَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏.‏ فَقُولُوا اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ ‏.‏ وَإِذَا سَجَدَ فَاسْجُدُوا وَإِذَا صَلَّى جَالِسًا فَصَلُّوا جُلُوسًا أَجْمَعُونَ ‏"‏ ‏.‏\hadithno{930}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: The Imam is appointed, so that he should be followed, so don't be at variance with him. Recite takbir when he recites it; bow down when he bows down and when he says:" Allah listens to him who praises Him," say:" O Allah, our Lord, to Thee be the Praise." And when he (the Imam) prostrates, you should also prostrate, and when he says prayer sitting, you should all observe prayer sitting}}
\hadithdefcmd{muslim}{931}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{931}\hadithtrans{A hadith like this has been transmitted by Hammam b. Munabbih from the Messenger of Allah (ﷺ) on the authority of Abu Huraira}}
\hadithdefcmd{muslim}{932}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ، خَشْرَمٍ قَالاَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعَلِّمُنَا يَقُولُ ‏ "‏ لاَ تُبَادِرُوا الإِمَامَ إِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا قَالَ وَلاَ الضَّالِّينَ ‏.‏ فَقُولُوا آمِينَ ‏.‏ وَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏.‏ فَقُولُوا اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ ‏"‏ ‏.‏\hadithno{932}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) while teaching us (the principles of faith), said: Do not try to go ahead of the Imam, recite takbir when he recites it, and when he says: "Nor of those who err" you should say Amin, bow down when he bows down, and when he says: "Allah listens to him who praises Him" say: "O Allah, our Lord, to Thee be the praise}}
\hadithdefcmd{muslim}{933}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ إِلاَّ قَوْلَهُ ‏"‏ وَلاَ الضَّالِّينَ ‏.‏ فَقُولُوا آمِينَ ‏"‏ ‏.‏ وَزَادَ ‏"‏ وَلاَ تَرْفَعُوا قَبْلَهُ ‏"‏ ‏.‏\hadithno{933}\hadithtrans{Abu Huraira reported from the Messenger of Allah (ﷺ) (a hadith) like it, except the words:" Nor of those who err, say Amin" and added:" And don't rise up ahead of him}}
\hadithdefcmd{muslim}{934}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ يَعْلَى، - وَهُوَ ابْنُ عَطَاءٍ - سَمِعَ أَبَا عَلْقَمَةَ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الإِمَامُ جُنَّةٌ فَإِذَا صَلَّى قَاعِدًا فَصَلُّوا قُعُودًا وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏.‏ فَقُولُوا اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ ‏.‏ فَإِذَا وَافَقَ قَوْلُ أَهْلِ الأَرْضِ قَوْلَ أَهْلِ السَّمَاءِ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{934}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: Verily the Imam is a shield, say prayer sitting when he says prayer sitting. And when he says:" Allah listens to him who praises Him," say:" O Allah, our Lord, to Thee be the praise." and when the utterance of the people of the earth synchronises with that of the beings of heaven (angels), all the previous sins would be pardoned}}
\hadithdefcmd{muslim}{935}{حَدَّثَنِي أَبُو الطَّاهِرِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ حَيْوَةَ، أَنَّ أَبَا يُونُسَ، مَوْلَى أَبِي هُرَيْرَةَ حَدَّثَهُ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّمَا جُعِلَ الإِمَامُ لِيُؤْتَمَّ بِهِ فَإِذَا كَبَّرَ فَكَبِّرُوا وَإِذَا رَكَعَ فَارْكَعُوا وَإِذَا قَالَ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏.‏ فَقُولُوا اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ ‏.‏ وَإِذَا صَلَّى قَائِمًا فَصَلُّوا قِيَامًا وَإِذَا صَلَّى قَاعِدًا فَصَلُّوا قُعُودًا أَجْمَعُونَ ‏"‏ ‏.‏\hadithno{935}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) saying:The Imam is appointed to be followed. So recite takbir when he recites it, and bow down when he bows down and when he utters:" Allah listens to him who praises Him," say" O Allah, our Lord, for Thee be the praise." And when he prays, standing, you should pray standing. And when he prays sitting, all of you should pray sitting}}
\hadithdefcmd{muslim}{936}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زَائِدَةُ، حَدَّثَنَا مُوسَى بْنُ أَبِي عَائِشَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ فَقُلْتُ لَهَا أَلاَ تُحَدِّثِينِي عَنْ مَرَضِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ بَلَى ثَقُلَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَصَلَّى النَّاسُ ‏"‏ ‏.‏ قُلْنَا لاَ وَهُمْ يَنْتَظِرُونَكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ ضَعُوا لِي مَاءً فِي الْمِخْضَبِ ‏"‏ ‏.‏ فَفَعَلْنَا فَاغْتَسَلَ ثُمَّ ذَهَبَ لِيَنُوءَ فَأُغْمِيَ عَلَيْهِ ثُمَّ أَفَاقَ فَقَالَ ‏"‏ أَصَلَّى النَّاسُ ‏"‏ ‏.‏ قُلْنَا لاَ وَهُمْ يَنْتَظِرُونَكَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ ضَعُوا لِي مَاءً فِي الْمِخْضَبِ ‏"‏ ‏.‏ فَفَعَلْنَا فَاغْتَسَلَ ثُمَّ ذَهَبَ لِيَنُوءَ فَأُغْمِيَ عَلَيْهِ ثُمَّ أَفَاقَ فَقَالَ ‏"‏ أَصَلَّى النَّاسُ ‏"‏ ‏.‏ قُلْنَا لاَ وَهُمْ يَنْتَظِرُونَكَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ ضَعُوا لِي مَاءً فِي الْمِخْضَبِ ‏"‏ ‏.‏ فَفَعَلْنَا فَاغْتَسَلَ ثُمَّ ذَهَبَ لِيَنُوءَ فَأُغْمِيَ عَلَيْهِ ثُمَّ أَفَاقَ فَقَالَ ‏"‏ أَصَلَّى النَّاسُ ‏"‏ ‏.‏ فَقُلْنَا لاَ وَهُمْ يَنْتَظِرُونَكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَتْ وَالنَّاسُ عُكُوفٌ فِي الْمَسْجِدِ يَنْتَظِرُونَ رَسُولَ اللَّهِ صلى الله عليه وسلم لِصَلاَةِ الْعِشَاءِ الآخِرَةِ - قَالَتْ - فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى أَبِي بَكْرٍ أَنْ يُصَلِّيَ بِالنَّاسِ فَأَتَاهُ الرَّسُولُ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُكَ أَنْ تُصَلِّيَ بِالنَّاسِ ‏.‏ فَقَالَ أَبُو بَكْرٍ وَكَانَ رَجُلاً رَقِيقًا يَا عُمَرُ صَلِّ بِالنَّاسِ ‏.‏ قَالَ فَقَالَ عُمَرُ أَنْتَ أَحَقُّ بِذَلِكَ ‏.‏ قَالَتْ فَصَلَّى بِهِمْ أَبُو بَكْرٍ تِلْكَ الأَيَّامَ ثُمَّ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَجَدَ مِنْ نَفْسِهِ خِفَّةً فَخَرَجَ بَيْنَ رَجُلَيْنِ أَحَدُهُمَا الْعَبَّاسُ لِصَلاَةِ الظُّهْرِ وَأَبُو بَكْرٍ يُصَلِّي بِالنَّاسِ فَلَمَّا رَآهُ أَبُو بَكْرٍ ذَهَبَ لِيَتَأَخَّرَ فَأَوْمَأَ إِلَيْهِ النَّبِيُّ صلى الله عليه وسلم أَنْ لاَ يَتَأَخَّرَ وَقَالَ لَهُمَا ‏"‏ أَجْلِسَانِي إِلَى جَنْبِهِ ‏"‏ ‏.‏ فَأَجْلَسَاهُ إِلَى جَنْبِ أَبِي بَكْرٍ وَكَانَ أَبُو بَكْرٍ يُصَلِّي وَهُوَ قَائِمٌ بِصَلاَةِ النَّبِيِّ صلى الله عليه وسلم وَالنَّاسُ يُصَلُّونَ بِصَلاَةِ أَبِي بَكْرٍ وَالنَّبِيُّ صلى الله عليه وسلم قَاعِدٌ ‏.‏ قَالَ عُبَيْدُ اللَّهِ فَدَخَلْتُ عَلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ فَقُلْتُ لَهُ أَلاَ أَعْرِضُ عَلَيْكَ مَا حَدَّثَتْنِي عَائِشَةُ عَنْ مَرَضِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ هَاتِ ‏.‏ فَعَرَضْتُ حَدِيثَهَا عَلَيْهِ فَمَا أَنْكَرَ مِنْهُ شِيْئًا غَيْرَ أَنَّهُ قَالَ أَسَمَّتْ لَكَ الرَّجُلَ الَّذِي كَانَ مَعَ الْعَبَّاسِ قُلْتُ لاَ ‏.‏ قَالَ هُوَ عَلِيٌّ ‏.‏\hadithno{936}\hadithtrans{Ubaidullah b. Abdullah reported:I visited 'A'isha and asked her to tell about the illness of the Messenger of Allah (ﷺ). She agreed and said: The Apostle (ﷺ) was seriously ill and he asked whether the people had prayed. We said: No, they are waiting for you, Messenger of Allah. He (the Holy Prophet) said: Put some water in the tub for me. We did accordingly and he (the Holy Prophet) took a bath;and, when he was about to move with difficulty, he fainted. When he came round, he again said: Have the people said prayer? We said: No, they are waiting for you, Messenger of Allah. He (the Holy Prophet) again said: Put some water for me in the tub. We did accordingly and he took a bag, but when he was about to move with difficultyhe fainted. When he came round, he asked whether the people had prayed. We said: No, they are waiting for you, Messenger of Allah. He said: Put some water for me in the tub. We did accordingly and he took a bath and he was about to move with difficulty when he fainted. When he came roundhe said: Have the people saidprayer? We said: No, they are waiting for you, Messenger of Allah. She ('A'isha) said: The people were staying in the mosque and waiting for the Messenger of Allah (ﷺ) to lead the last (night) prayer. She ('A'isha) said: The Messenger of Allah (ﷺ) sent (instructions) to Abu Bakr to lead the people in prayer. When the messenger came, he told him (Abd Bakr): The Messenger of Allah (ﷺ) has ordered you to lead the people in prayer. Abu Bakr who was a man of very tenderly feelings asked Umar to lead the prayer. 'Umar said: You are more entitled to that. Abu Bakr led the prayers during those days. Afterwards the Messenger of Allah (ﷺ) felt some relief and he went out supported by two men, one of them was al-'Abbas, to the noon prayer. Abu Bakr was leading the people in prayer. When Abu Bakr saw him. he began to withdraw, but the Messenger of Allah (ﷺ) told him not to withdraw. He told his two (companions) to seat him down beside him (Abu Bakr). They seated him by the side of Abu Bakr. Abu Bakr said the prayer standing while following the prayer of the Apostle (ﷺ) and the people Bald prayer (standing) while following the prayer of Abu Bakr. The Apostle (ﷺ) was seated. Ubaidullah said: I visited 'Abdullah b. 'Abbas, and said: Should I submit to you what 'A'isha had told about the illness of the Apostle (ﷺ)? He said: Go ahead. I submitted to him what had been transmitted by her ('A'isha). He objected to none of it, only asking whether she had named to him the man who accompanied al-'Abbas. I said: No. He said: It was 'Ali}}
\hadithdefcmd{muslim}{937}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَاللَّفْظُ لاِبْنِ رَافِعٍ - قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، قَالَ قَالَ الزُّهْرِيُّ وَأَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ قَالَتْ، أَوَّلُ مَا اشْتَكَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَيْتِ مَيْمُونَةَ فَاسْـتَأْذَنَ أَزْوَاجَهُ أَنْ يُمَرَّضَ فِي بَيْتِهَا وَأَذِنَّ لَهُ - قَالَتْ - فَخَرَجَ وَيَدٌ لَهُ عَلَى الْفَضْلِ بْنِ عَبَّاسٍ وَيَدٌ لَهُ عَلَى رَجُلٍ آخَرَ وَهُوَ يَخُطُّ بِرِجْلَيْهِ فِي الأَرْضِ ‏.‏ فَقَالَ عُبَيْدُ اللَّهِ فَحَدَّثْتُ بِهِ ابْنَ عَبَّاسٍ فَقَالَ أَتَدْرِي مَنِ الرَّجُلُ الَّذِي لَمْ تُسَمِّ عَائِشَةُ هُوَ عَلِيٌّ ‏.‏\hadithno{937}\hadithtrans{A'isha reported:It was in the house ofMaimuna that the Messenger of Allah (ﷺ) first fell ill. He asked permission from his wives to stay in her ('A'isha's) house during his illness. They granted him permission. She ('A'isha) narrated: He (the Holy Prophet) went out (for prayer) with his hand over al-Fadl b. 'Abbas and on the other hand there was another person and (due to weakness) his feet dragged on the earth. 'Ubaidullah said: I narrated this hadith to the son of 'Abbas ('Abdullah b. 'Abbas) and he said: Do you know who the man was whose name 'A'isha did not mention? It was 'Ali}}
\hadithdefcmd{muslim}{938}{حَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ حَدَّثَنِي عُقَيْلُ بْنُ خَالِدٍ، قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ لَمَّا ثَقُلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَاشْتَدَّ بِهِ وَجَعُهُ اسْتَأْذَنَ أَزْوَاجَهُ أَنْ يُمَرَّضَ فِي بَيْتِي فَأَذِنَّ لَهُ فَخَرَجَ بَيْنَ رَجُلَيْنِ تَخُطُّ رِجْلاَهُ فِي الأَرْضِ بَيْنَ عَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ وَبَيْنَ رَجُلٍ آخَرَ ‏.‏ قَالَ عُبَيْدُ اللَّهِ فَأَخْبَرْتُ عَبْدَ اللَّهِ بِالَّذِي قَالَتْ عَائِشَةُ فَقَالَ لِي عَبْدُ اللَّهِ بْنُ عَبَّاسٍ هَلْ تَدْرِي مَنِ الرَّجُلُ الآخَرُ الَّذِي لَمْ تُسَمِّ عَائِشَةُ قَالَ قُلْتُ لاَ ‏.‏ قَالَ ابْنُ عَبَّاسٍ هُوَ عَلِيٌّ ‏.‏\hadithno{938}\hadithtrans{A'isha, the wife of the Apostle (ﷺ), said:When the Messenger of Allah (ﷺ) fell ill and his illness became serious, he asked permission from his wives to stay in my house during his illness. They gave him permission to do so. He stepped out (of'A'isha's apartment for prayer) supported by two persons. (He was so much weak) that his feet dragged on the ground and he was being supported by 'Abbas b. 'Abd al-Muttalib and another person. 'Ubaidullah said: I informed 'Abdullah (b. 'Abbas) about that which 'A'isha had said. 'Abdullah b. 'Abbas said: Do you know the man whose name 'A'isha did not mention? He said: No. Ibn 'Abbas said: It was 'Ali}}
\hadithdefcmd{muslim}{939}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ خَالِدٍ، قَالَ قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ لَقَدْ رَاجَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي ذَلِكَ وَمَا حَمَلَنِي عَلَى كَثْرَةِ مُرَاجَعَتِهِ إِلاَّ أَنَّهُ لَمْ يَقَعْ فِي قَلْبِي أَنْ يُحِبَّ النَّاسُ بَعْدَهُ رَجُلاً قَامَ مَقَامَهُ أَبَدًا وَإِلاَّ أَنِّي كُنْتُ أَرَى أَنَّهُ لَنْ يَقُومَ مَقَامَهُ أَحَدٌ إِلاَّ تَشَاءَمَ النَّاسُ بِهِ فَأَرَدْتُ أَنْ يَعْدِلَ ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ أَبِي بَكْرٍ ‏.‏\hadithno{939}\hadithtrans{A'isha, the wife of the Messenger of Allah (ﷺ), said:I tried to dissuade the Messenger of Allah (ﷺ) from it (i. e. from appointing Abu Bakr as the Imam.) and my insistence upon it was not due to the fact that I entertained any apprehension in my mind that the people would not love the man who would occupy his (Prophet's) place (i. e. who would be appointed as his caliph) and I feared that the people would be superstitious about one who would occupy his place. I, therefore, desired that the Messenger of Allah (ﷺ) should leave Abu Bakr aside in this matter}}
\hadithdefcmd{muslim}{940}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَاللَّفْظُ لاِبْنِ رَافِعٍ - قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، - أَخْبَرَنَا مَعْمَرٌ، قَالَ الزُّهْرِيُّ وَأَخْبَرَنِي حَمْزَةُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْتِي قَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أَبَا بَكْرٍ رَجُلٌ رَقِيقٌ إِذَا قَرَأَ الْقُرْآنَ لاَ يَمْلِكُ دَمْعَهُ فَلَوْ أَمَرْتَ غَيْرَ أَبِي بَكْرٍ ‏.‏ قَالَتْ وَاللَّهِ مَا بِي إِلاَّ كَرَاهِيَةُ أَنْ يَتَشَاءَمَ النَّاسُ بِأَوَّلِ مَنْ يَقُومُ فِي مَقَامِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ فَرَاجَعْتُهُ مَرَّتَيْنِ أَوْ ثَلاَثًا فَقَالَ ‏"‏ لِيُصَلِّ بِالنَّاسِ أَبُو بَكْرٍ فَإِنَّكُنَّ صَوَاحِبُ يُوسُفَ ‏"‏ ‏.‏\hadithno{940}\hadithtrans{A'isha reported:When the Messenger of Allah (ﷺ) came to my house, he said: Ask Abu Bakr to lead people in prayer. 'A'isha narrated: I said, Messenger of Allah, Abu Bakr is a man of tenderly feelings; as he recites the Qur'an, he cannot help shedding tears: so better command anyone else to lead the prayer. By Allah, there is nothing disturbing in it for me but the idea that the people may not takeevil omen with regard to one who is the first to occupy the place of the Messenger of Allah (ﷺ). I tried to dissuade him (the Holy Prophet) twice or thrice (from appointing my father as an Imam in prayer), but he ordered Abu Bakr to lead the people in prayer and said: You women are like those (who had) surrounded Yusuf}}
\hadithdefcmd{muslim}{941}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - قَالَ أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا ثَقُلَ رَسُولُ اللَّهِ صلى الله عليه وسلم جَاءَ بِلاَلٌ يُؤْذِنُهُ بِالصَّلاَةِ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أَبَا بَكْرٍ رَجُلٌ أَسِيفٌ إِنَّهُ مَتَى يَقُمْ مَقَامَكَ لاَ يُسْمِعِ النَّاسَ فَلَوْ أَمَرْتَ عُمَرَ ‏.‏ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ لِحَفْصَةَ قُولِي لَهُ إِنَّ أَبَا بَكْرٍ رَجُلٌ أَسِيفٌ وَإِنَّهُ مَتَى يَقُمْ مَقَامَكَ لاَ يُسْمِعِ النَّاسَ فَلَوْ أَمَرْتَ عُمَرَ ‏.‏ فَقَالَتْ لَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّكُنَّ لأَنْتُنَّ صَوَاحِبُ يُوسُفَ ‏.‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ قَالَتْ فَأَمَرُوا أَبَا بَكْرٍ يُصَلِّي بِالنَّاسِ - قَالَتْ - فَلَمَّا دَخَلَ فِي الصَّلاَةِ وَجَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ نَفْسِهِ خِفَّةً فَقَامَ يُهَادَى بَيْنَ رَجُلَيْنِ وَرِجْلاَهُ تَخُطَّانِ فِي الأَرْضِ - قَالَتْ - فَلَمَّا دَخَلَ الْمَسْجِدَ سَمِعَ أَبُو بَكْرٍ حِسَّهُ ذَهَبَ يَتَأَخَّرُ فَأَوْمَأَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم قُمْ مَكَانَكَ ‏.‏ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى جَلَسَ عَنْ يَسَارِ أَبِي بَكْرٍ - قَالَتْ - فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِالنَّاسِ جَالِسًا وَأَبُو بَكْرٍ قَائِمًا يَقْتَدِي أَبُو بَكْرٍ بِصَلاَةِ النَّبِيِّ صلى الله عليه وسلم وَيَقْتَدِي النَّاسُ بِصَلاَةِ أَبِي بَكْرٍ ‏.‏\hadithno{941}\hadithtrans{A'isha reported:When the Messenger of Allah (ﷺ) was confined to bed, Bilal came to him to summon him to prayer. He (the Holy Prophet) said: Ask Abu Bakr to lead the people in prayer. She ('A'isha) reported: I said: Messenger of Allah, Abu Bakr is a tenderhearted man, when he would stand at your place (he would be so overwhelmed by feelings) that he would not be able to make the people hear anything (his recitation would not be audible to the followers in prayer). You should better order Umar (to lead the prayer). He (the Holy Prophet) said: Ask Abu Bakr to lead people in prayer. She ('A'isha) said: I asked Hafsa to (convey) my impression to him (the Holy Prophet) that Abu Bakr was a tenderhearted man, so when he would stand at his place, he would not be able to make the people bear anything. He better order Umar. Hafsa conveyed this (message of Hadrat 'A'isha) to him (the Holy Prophet). The Messenger of Allah (ﷺ) said: (You are behaving) as if you are the females who had gathered around Yusuf. Order Abu Bakr to lead the people in prayer. She ('A'isha) reported: So Abu Bakr was ordered to lead the people in prayer. As the prayer began, the Messenger of Allah (may peace he upon him) felt some relief; he got up and moved supported by two persons and his feet dragged on earth (due to excessive weakness). 'A'isha reported: As he (the Holy Prophet) entered the mosque. Abu Bakr perceived his (arrival). He was about to withdraw, but the Messenger of Allah (ﷺ) by the gesture (of his hand) told him to keep standing at his place. The Messenger of Allah (ﷺ) came and seated himself on the left side of Abu Bakr. She ('A'isha) reported: The Messenger of Allah (ﷺ) was leading people in prayer sitting. Abu Bakr was following the prayer of the Apostle (ﷺ) in a standing posture and the people were following the prayer of Abu Bakr}}
\hadithdefcmd{muslim}{942}{حَدَّثَنَا مِنْجَابُ بْنُ الْحَارِثِ التَّمِيمِيُّ، أَخْبَرَنَا ابْنُ مُسْهِرٍ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ نَحْوَهُ وَفِي حَدِيثِهِمَا لَمَّا مَرِضَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَرَضَهُ الَّذِي تُوُفِّيَ فِيهِ ‏.‏ وَفِي حَدِيثِ ابْنِ مُسْهِرٍ فَأُتِيَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى أُجْلِسَ إِلَى جَنْبِهِ وَكَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي بِالنَّاسِ وَأَبُو بَكْرٍ يُسْمِعُهُمُ التَّكْبِيرَ ‏.‏ وَفِي حَدِيثِ عِيسَى فَجَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي وَأَبُو بَكْرٍ إِلَى جَنْبِهِ وَأَبُو بَكْرٍ يُسْمِعُ النَّاسَ ‏.‏\hadithno{942}\hadithtrans{A'mash reported:When the Messenger of Allah (ﷺ) suffered from illness of which he died, and in the hadith transmitted by Ibn Mus-hir, the words are: The Messenger of Allah (ﷺ) was brought till he was seated by his (Abu Bakr's) side and the Apostle (ﷺ) led the people in prayer and Abu Bakr was making takbir audible to them, and in the hadith transmitted by 'Isa the (words are):" The Messenger of Allah (ﷺ) sat and led the people in prayer and Abu Bakr was by his side and he was making (takbir) audible to the people}}
\hadithdefcmd{muslim}{943}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ هِشَامٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، - وَأَلْفَاظُهُمْ مُتَقَارِبَةٌ - قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَا بَكْرٍ أَنْ يُصَلِّيَ بِالنَّاسِ فِي مَرَضِهِ فَكَانَ يُصَلِّي بِهِمْ ‏.‏ قَالَ عُرْوَةُ فَوَجَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ نَفْسِهِ خِفَّةً فَخَرَجَ وَإِذَا أَبُو بَكْرٍ يَؤُمُّ النَّاسَ فَلَمَّا رَآهُ أَبُو بَكْرٍ اسْتَأْخَرَ فَأَشَارَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَىْ كَمَا أَنْتَ فَجَلَسَ رَسُولُ اللَّهِ حِذَاءَ أَبِي بَكْرٍ إِلَى جَنْبِهِ ‏.‏ فَكَانَ أَبُو بَكْرٍ يُصَلِّي بِصَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ يُصَلُّونَ بِصَلاَةِ أَبِي بَكْرٍ ‏.‏\hadithno{943}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) ordered Abu Bakr that he should lead people in prayer during his illness, and he led them in prayer. `Urwa said: The Messenger of Allah (ﷺ) felt relief and went (to the mosque) and Abu Bakr was leading the people in prayer. When Abu Bakr saw him he began to withdraw, but the Messenger of Allah (ﷺ) signaled him to remain where he was. The Messenger of Allah (ﷺ) sat opposite to Abu Bakr by his side. Abu Bakr said prayer following the prayer of the Messenger of Allah (ﷺ), and the people said prayer following the prayer of Abu Bakr}}
\hadithdefcmd{muslim}{944}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَحَسَنٌ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، - قَالَ عَبْدٌ أَخْبَرَنِي وَقَالَ الآخَرَانِ، حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - وَحَدَّثَنِي أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ أَبَا بَكْرٍ، كَانَ يُصَلِّي لَهُمْ فِي وَجَعِ رَسُولِ اللَّهِ صلى الله عليه وسلم الَّذِي تُوُفِّيَ فِيهِ حَتَّى إِذَا كَانَ يَوْمُ الاِثْنَيْنِ - وَهُمْ صُفُوفٌ فِي الصَّلاَةِ - كَشَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم سِتْرَ الْحُجْرَةِ فَنَظَرَ إِلَيْنَا وَهُوَ قَائِمٌ كَأَنَّ وَجْهَهُ وَرَقَةُ مُصْحَفٍ ‏.‏ ثُمَّ تَبَسَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم ضَاحِكًا - قَالَ - فَبُهِتْنَا وَنَحْنُ فِي الصَّلاَةِ مِنْ فَرَحٍ بِخُرُوجِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَنَكَصَ أَبُو بَكْرٍ عَلَى عَقِبَيْهِ لِيَصِلَ الصَّفَّ وَظَنَّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَارِجٌ لِلصَّلاَةِ فَأَشَارَ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ أَنْ أَتِمُّوا صَلاَتَكُمْ - قَالَ - ثُمَّ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَرْخَى السِّتْرَ - قَالَ - فَتُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ يَوْمِهِ ذَلِكَ ‏.‏\hadithno{944}\hadithtrans{Anas b. Malik reported, Abu Bakr led them in prayer due to the illness of the Messenger of Allah (ﷺ) of which be died. It was a Monday and they stood in rows for prayer. The Messenger of Allah (ﷺ) drew aside the curtain of ('A'isha's) apartment and looked at us while he was standing, and his (Prophet's) face was (as bright) as the paper of the Holy Book. The Messenger of Allah (ﷺ) felt happy and smiled. And we were confounded with joy while in prayer due to the arrival (among our midst) of the Messenger of Allah (ﷺ), Abu Bakr stepped back upon his heels to say prayer in a row perceiving that the Messenger of Allah (ﷺ) had come out for prayer. The Messenger of Allah (ﷺ) with the help of his hand signed to them to complete their prayer. The Messenger of Allah (ﷺ) went back (to his apartment) and drew the curtain. He (the narrator) said:The Messenger of Allah (ﷺ) breathed his last on that very day}}
\hadithdefcmd{muslim}{945}{وَحَدَّثَنِيهِ عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، قَالَ آخِرُ نَظْرَةٍ نَظَرْتُهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم كَشَفَ السِّتَارَةَ يَوْمَ الاِثْنَيْنِ بِهَذِهِ الْقِصَّةِ وَحَدِيثُ صَالِحٍ أَتَمُّ وَأَشْبَعُ ‏.‏\hadithno{945}\hadithtrans{Anas reported:The last glance that I have had of the Messenger of Allah (ﷺ) (before his death) was that when he on Monday drew the curtain aside. The hadith transmitted by Salih is perfect and complete}}
\hadithdefcmd{muslim}{946}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ عَبْدِ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، قَالَ لَمَّا كَانَ يَوْمُ الاِثْنَيْنِ ‏.‏ بِنَحْوِ حَدِيثِهِمَا ‏.‏\hadithno{946}\hadithtrans{This hadith is narrated on the authority of Anas b. Malik by another chain of transmitters}}
\hadithdefcmd{muslim}{947}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا عَبْدُ الصَّمَدِ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ، قَالَ لَمْ يَخْرُجْ إِلَيْنَا نَبِيُّ اللَّهِ صلى الله عليه وسلم ثَلاَثًا فَأُقِيمَتِ الصَّلاَةُ فَذَهَبَ أَبُو بَكْرٍ يَتَقَدَّمُ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم بِالْحِجَابِ فَرَفَعَهُ فَلَمَّا وَضَحَ لَنَا وَجْهُ نَبِيِّ اللَّهِ صلى الله عليه وسلم مَا نَظَرْنَا مَنْظَرًا قَطُّ كَانَ أَعْجَبَ إِلَيْنَا مِنْ وَجْهِ النَّبِيِّ صلى الله عليه وسلم حِينَ وَضَحَ لَنَا - قَالَ - فَأَوْمَأَ نَبِيُّ اللَّهِ صلى الله عليه وسلم بِيَدِهِ إِلَى أَبِي بَكْرٍ أَنْ يَتَقَدَّمَ وَأَرْخَى نَبِيُّ اللَّهِ صلى الله عليه وسلم الْحِجَابَ فَلَمْ نَقْدِرْ عَلَيْهِ حَتَّى مَاتَ ‏.‏\hadithno{947}\hadithtrans{Anas reported:The Apostle of Allah (ﷺ) did not come to us for three days. When the prayer was about to start. Abu Bakr stepped forward (to lead the prayer), and the Messenger of Allah (ﷺ) lifted the curtain. When the face of the Messenger of Allah (ﷺ) became visible to us, we (found) that no sight was more endearing to us than the face of the Messenger of Allah (ﷺ) as it appeared to us. The Apostle of Allah (ﷺ) with the gesture of his hand directed Abu Bakr to step forward (and lead the prayer). The Apostle of Allah (ﷺ) then drew the curtain, and we could not see him till he died}}
\hadithdefcmd{muslim}{948}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ مَرِضَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاشْتَدَّ مَرَضُهُ فَقَالَ ‏"‏ مُرُوا أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ ‏"‏ ‏.‏ فَقَالَتْ عَائِشَةُ يَا رَسُولَ اللَّهِ إِنَّ أَبَا بَكْرٍ رَجُلٌ رَقِيقٌ مَتَى يَقُمْ مَقَامَكَ لاَ يَسْتَطِعْ أَنْ يُصَلِّيَ بِالنَّاسِ فَقَالَ ‏"‏ مُرِي أَبَا بَكْرٍ فَلْيُصَلِّ بِالنَّاسِ فَإِنَّكُنَّ صَوَاحِبُ يُوسُفَ ‏"‏ ‏.‏ قَالَ فَصَلَّى بِهِمْ أَبُو بَكْرٍ حَيَاةَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{948}\hadithtrans{Abu Musa reported:When the Messenger of Allah (ﷺ) became ill and illness became serious he ordered Abu Bakr to lead the people in prayer. Upon this 'A'isha said: Messenger of Allah, Abd Bakr is a man of tenderly feelings: when he would stand in your place (he would be so much overwhelmed -by grief that) he would not be able to lead the people in prayer. He (the Holy Prophet) said: You order Abu Bakr to lead the people in prayer, and added: You are like the female companions of Yusuf. So Abu Bakr led the prayer (during this period of illness) in the life of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{949}{حَدَّثَنِي يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَهَبَ إِلَى بَنِي عَمْرِو بْنِ عَوْفٍ لِيُصْلِحَ بَيْنَهُمْ فَحَانَتِ الصَّلاَةُ فَجَاءَ الْمُؤَذِّنُ إِلَى أَبِي بَكْرٍ فَقَالَ أَتُصَلِّي بِالنَّاسِ فَأُقِيمُ قَالَ نَعَمْ ‏.‏ قَالَ فَصَلَّى أَبُو بَكْرٍ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ فِي الصَّلاَةِ فَتَخَلَّصَ حَتَّى وَقَفَ فِي الصَّفِّ فَصَفَّقَ النَّاسُ - وَكَانَ أَبُو بَكْرٍ لاَ يَلْتَفِتُ فِي الصَّلاَةِ - فَلَمَّا أَكْثَرَ النَّاسُ التَّصْفِيقَ الْتَفَتَ فَرَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَشَارَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنِ امْكُثْ مَكَانَكَ فَرَفَعَ أَبُو بَكْرٍ يَدَيْهِ فَحَمِدَ اللَّهَ عَزَّ وَجَلَّ عَلَى مَا أَمَرَهُ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ ذَلِكَ ثُمَّ اسْتَأْخَرَ أَبُو بَكْرٍ حَتَّى اسْتَوَى فِي الصَّفِّ وَتَقَدَّمَ النَّبِيُّ صلى الله عليه وسلم فَصَلَّى ثُمَّ انْصَرَفَ فَقَالَ ‏"‏ يَا أَبَا بَكْرٍ مَا مَنَعَكَ أَنْ تَثْبُتَ إِذْ أَمَرْتُكَ ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ مَا كَانَ لاِبْنِ أَبِي قُحَافَةَ أَنْ يُصَلِّيَ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا لِي رَأَيْتُكُمْ أَكْثَرْتُمُ التَّصْفِيقَ مَنْ نَابَهُ شَىْءٌ فِي صَلاَتِهِ فَلْيُسَبِّحْ فَإِنَّهُ إِذَا سَبَّحَ الْتُفِتَ إِلَيْهِ وَإِنَّمَا التَّصْفِيحُ لِلنِّسَاءِ ‏"‏ ‏.‏\hadithno{949}\hadithtrans{Sahl b. Sa'd al-Sa'idi reported:The Messenger of Allah (ﷺ) went to the tribe of Bani Amr b. Auf in order to bring reconciliation amongst (its members), and It was a time of prayer. The Mu'adhdhin came to Abu Bakr and said: Would you lead the prayer in case I recite takbir (tahrima, with which the prayer begins)? He (Abu Bakr) said: Yes. He (the narrator) said: He (Abu Bakr) started (leading) the prayer. The people were engaged in observing prayer when the Messenger of Allah (ﷺ) happened to come there and made his way (through the people) till he stood in a row. The people began to clap (their hands), but Abu Bakr paid no heed (to it) in prayer. When the people clapped more vigorously, he (Abu Bakr) then paid heed and saw the Messenger of Allah (ﷺ) there. (He was about to withdraw when) the Messenger of Allah (ﷺ) signed to him to keep standing at his place. Abu Bakr lifted his hands and praised Allah for what the Messenger of Allah (ﷺ) had commanded him and then Abu Bakr withdrew himself till he stood in the midst of the row and the Messenger of Allah (ﷺ) stepped forward and led the prayer. When (the prayer) was over, he (the Holy Prophet) said: 0 Abu Bakr, what prevented you from standing (at that place) as I ordered you to do? Abu Bakr said: It does not become the son of Abu Quhafa to lead prayer before the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) said (to the people) around him: What is it that I saw you clapping so vigorously? (Behold) when anything happens in prayer, say: Subha Allah, for when you would utter it, it would attract the attention, while clapping of hands is meant for women}}
\hadithdefcmd{muslim}{950}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ أَبِي حَازِمٍ - وَقَالَ قُتَيْبَةُ حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ عَبْدِ الرَّحْمَنِ الْقَارِيُّ - كِلاَهُمَا عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، بِمِثْلِ حَدِيثِ مَالِكٍ ‏.‏ وَفِي حَدِيثِهِمَا فَرَفَعَ أَبُو بَكْرٍ يَدَيْهِ فَحَمِدَ اللَّهَ وَرَجَعَ الْقَهْقَرَى وَرَاءَهُ حَتَّى قَامَ فِي الصَّفِّ ‏.‏\hadithno{950}\hadithtrans{This hadith is transmitted by Sahl b. Sa'd in the same way as narrated by Malik, with the exception of these words:" Abu Bakr lifted his hands and praised Allah and retraced his (steps) till he stood in a row}}
\hadithdefcmd{muslim}{951}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، أَخْبَرَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ ذَهَبَ نَبِيُّ اللَّهِ صلى الله عليه وسلم يُصْلِحُ بَيْنَ بَنِي عَمْرِو بْنِ عَوْفٍ ‏.‏ بِمِثْلِ حَدِيثِهِمْ وَزَادَ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَخَرَقَ الصُّفُوفَ حَتَّى قَامَ عِنْدَ الصَّفِّ الْمُقَدَّمِ ‏.‏ وَفِيهِ أَنَّ أَبَا بَكْرٍ رَجَعَ الْقَهْقَرَى ‏.‏\hadithno{951}\hadithtrans{Sahl b. Sa'd al-Sa'idi reported:The Apostle of Allah (ﷺ) went to Bani Amr b. 'Auf in order to bring about reconciliation amongst them. The rest of the hadith is the same but with (the addition of these words):" The Messenger of Allah (ﷺ) came and made his way through the rows till he came to the first row and Abu Bakr retraced his steps}}
\hadithdefcmd{muslim}{952}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، جَمِيعًا عَنْ عَبْدِ الرَّزَّاقِ، قَالَ ابْنُ رَافِعٍ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ حَدِيثِ، عَبَّادِ بْنِ زِيَادٍ أَنَّ عُرْوَةَ بْنَ الْمُغِيرَةِ بْنِ شُعْبَةَ، أَخْبَرَهُ أَنَّ الْمُغِيرَةَ بْنَ شُعْبَةَ أَخْبَرَهُ أَنَّهُ، غَزَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم تَبُوكَ - قَالَ الْمُغِيرَةُ - فَتَبَرَّزَ رَسُولُ اللَّهِ صلى الله عليه وسلم قِبَلَ الْغَائِطِ فَحَمَلْتُ مَعَهُ إِدَاوَةً قَبْلَ صَلاَةِ الْفَجْرِ فَلَمَّا رَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَىَّ أَخَذْتُ أُهَرِيقُ عَلَى يَدَيْهِ مِنَ الإِدَاوَةِ وَغَسَلَ يَدَيْهِ ثَلاَثَ مَرَّاتٍ ثُمَّ غَسَلَ وَجْهَهُ ثُمَّ ذَهَبَ يُخْرِجُ جُبَّتَهُ عَنْ ذِرَاعَيْهِ فَضَاقَ كُمَّا جُبَّتِهِ فَأَدْخَلَ يَدَيْهِ فِي الْجُبَّةِ حَتَّى أَخْرَجَ ذِرَاعَيْهِ مِنْ أَسْفَلِ الْجُبَّةِ ‏.‏ وَغَسَلَ ذِرَاعَيْهِ إِلَى الْمِرْفَقَيْنِ ثُمَّ تَوَضَّأَ عَلَى خُفَّيْهِ ثُمَّ أَقْبَلَ - قَالَ الْمُغِيرَةُ - فَأَقْبَلْتُ مَعَهُ حَتَّى نَجِدُ النَّاسَ قَدْ قَدَّمُوا عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ فَصَلَّى لَهُمْ فَأَدْرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِحْدَى الرَّكْعَتَيْنِ فَصَلَّى مَعَ النَّاسِ الرَّكْعَةَ الآخِرَةَ فَلَمَّا سَلَّمَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُتِمُّ صَلاَتَهُ فَأَفْزَعَ ذَلِكَ الْمُسْلِمِينَ فَأَكْثَرُوا التَّسْبِيحَ فَلَمَّا قَضَى النَّبِيُّ صلى الله عليه وسلم صَلاَتَهُ أَقْبَلَ عَلَيْهِمْ ثُمَّ قَالَ ‏"‏ أَحْسَنْتُمْ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ قَدْ أَصَبْتُمْ ‏"‏ ‏.‏ يَغْبِطُهُمْ أَنْ صَلَّوُا الصَّلاَةَ لِوَقْتِهَا ‏.‏\hadithno{952}\hadithtrans{Mughira b. Shu'ba reported that he participated In the expedition of Tabuk along with the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) went out to answer the call of nature before the morning prayer. and I carried along with him a jar (full of water). When the Messenger of Allah (ﷺ) came back to me (after relieving himself). I began to pour water upon his hands out of the jar and he washed his hands three times, then washed his face three times. He then tried to tuck up the sleeves of his cloak upon his forearms but since the sleeves were tight he inserted his hands in the cloak and then brought out his forearms up to the elbow below the cloak, and then wiped over his shoes and then moved on. Mughira said:I also moved along with him till he came to the people and (he found) that they had been saying their prayer under the Imamah of 'Abd al-Rahman b. 'Auf. The Messenger of Allah (ﷺ) could get one rak ah out of two and said (this) last rak'ah along with the people. When Abd al-Rahman b. 'Auf pronounced the salutation, the Messenger of Allah (ﷺ) got up to complete the prayer. This made the Muslims terrified and most of them began to recite the glory of the Lord. When the Messenger of Allah (ﷺ) finished his prayer, he turned towards them and then said: You did well, or said with a sense of joy: You did the right thing that you said prayer at the appointed hour}}
\hadithdefcmd{muslim}{953}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَالْحُلْوَانِيُّ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنِ ابْنِ جُرَيْجٍ، حَدَّثَنِي ابْنُ شِهَابٍ، عَنْ إِسْمَاعِيلَ بْنِ مُحَمَّدِ بْنِ سَعْدٍ، عَنْ حَمْزَةَ بْنِ الْمُغِيرَةِ، نَحْوَ حَدِيثِ عَبَّادٍ قَالَ الْمُغِيرَةُ فَأَرَدْتُ تَأْخِيرَ عَبْدِ الرَّحْمَنِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ دَعْهُ ‏"‏ ‏.‏\hadithno{953}\hadithtrans{This hadith is narrated by Hamza b. Mughira by another chain of trans- mitters (but with the addition of these words):I made up my mind to hold Abd al-Rahman b. 'Auf back, but the Messenger of Allah (ﷺ) said: Leave him}}
\hadithdefcmd{muslim}{954}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّهُمَا سَمِعَا أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ التَّسْبِيحُ لِلرِّجَالِ وَالتَّصْفِيقُ لِلنِّسَاءِ ‏"‏ ‏.‏ زَادَ حَرْمَلَةُ فِي رِوَايَتِهِ قَالَ ابْنُ شِهَابٍ وَقَدْ رَأَيْتُ رِجَالاً مِنْ أَهْلِ الْعِلْمِ يُسَبِّحُونَ وَيُشِيرُونَ ‏.‏\hadithno{954}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: Glorification of Allah is for men and clapping of hands is meant for women (if something happens in prayer). Harmala added in his narration that Ibn Shihab told him: I saw some of the scholars glorifying Allah and making a gesture}}
\hadithdefcmd{muslim}{955}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْفُضَيْلُ يَعْنِي ابْنَ عِيَاضٍ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كُلُّهُمْ عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{955}\hadithtrans{This hadith is narrated on the authority of Abu Huraira by another chain of transmitters}}
\hadithdefcmd{muslim}{956}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ وَزَادَ ‏ "‏ فِي الصَّلاَةِ ‏"‏ ‏.‏\hadithno{956}\hadithtrans{This hadith is transmitted by Muhammad b. Rafi', Abu'I-Razzaq. Ma'mar, Hammam on the authority of Abu Huraira with the addition of (the word)" prayer}}
\hadithdefcmd{muslim}{957}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ، - يَعْنِي ابْنَ كَثِيرٍ - حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ الْمَقْبُرِيُّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا ثُمَّ انْصَرَفَ فَقَالَ ‏ "‏ يَا فُلاَنُ أَلاَ تُحْسِنُ صَلاَتَكَ أَلاَ يَنْظُرُ الْمُصَلِّي إِذَا صَلَّى كَيْفَ يُصَلِّي فَإِنَّمَا يُصَلِّي لِنَفْسِهِ إِنِّي وَاللَّهِ لأُبْصِرُ مَنْ وَرَائِي كَمَا أُبْصِرُ مَنْ بَيْنَ يَدَىَّ ‏"‏ ‏.‏\hadithno{957}\hadithtrans{Abu Huraira reported:One day the Messenger of Allah (ﷺ) led the prayer. Then turning (towards his Companions) he said: O you man, why don't you say your prayer well? Does the observer of prayer not see how he is performing the prayer, for he performs it for himself? By Allah, I see behind me as I see in front of me}}
\hadithdefcmd{muslim}{958}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ هَلْ تَرَوْنَ قِبْلَتِي هَا هُنَا فَوَاللَّهِ مَا يَخْفَى عَلَىَّ رُكُوعُكُمْ وَلاَ سُجُودُكُمْ إِنِّي لأَرَاكُمْ وَرَاءَ ظَهْرِي ‏"‏ ‏.‏\hadithno{958}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: Do you find me seeing towards the Qibla only? By Allah, your bowing and your prostrating are not hidden from my view. Verily I see them behind my back}}
\hadithdefcmd{muslim}{959}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَقِيمُوا الرُّكُوعَ وَالسُّجُودَ فَوَاللَّهِ إِنِّي لأَرَاكُمْ مِنْ بَعْدِي - وَرُبَّمَا قَالَ مِنْ بَعْدِ ظَهْرِي - إِذَا رَكَعْتُمْ وَسَجَدْتُمْ ‏"‏ ‏.‏\hadithno{959}\hadithtrans{Anas b. Malik reported. The Messenger of Allah (ﷺ) said:Perform bowing and prostration well. By Allah, I see you even if you are behind me, or he said: (I see you) behind my back when you bow or prostrate}}
\hadithdefcmd{muslim}{960}{حَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا مُعَاذٌ، - يَعْنِي ابْنَ هِشَامٍ - حَدَّثَنِي أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، كِلاَهُمَا عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَتِمُّوا الرُّكُوعَ وَالسُّجُودَ فَوَاللَّهِ إِنِّي لأَرَاكُمْ مِنْ بَعْدِ ظَهْرِي إِذَا مَا رَكَعْتُمْ وَإِذَا مَا سَجَدْتُمْ ‏"‏ ‏.‏ وَفِي حَدِيثِ سَعِيدٍ ‏"‏ إِذَا رَكَعْتُمْ وَإِذَا سَجَدْتُمْ ‏"‏ ‏.‏\hadithno{960}\hadithtrans{Anas reported:The Apostle of Allah (ﷺ) said: Complete the bowing and prostration well. By Allah, I see you behind my back as to how you bow and prostrate or when you bow and prostrate}}
\hadithdefcmd{muslim}{961}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ حُجْرٍ، وَاللَّفْظُ، لأَبِي بَكْرٍ قَالَ ابْنُ حُجْرٍ أَخْبَرَنَا وَقَالَ أَبُو بَكْرٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الْمُخْتَارِ بْنِ فُلْفُلٍ، عَنْ أَنَسٍ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ فَلَمَّا قَضَى الصَّلاَةَ أَقْبَلَ عَلَيْنَا بِوَجْهِهِ فَقَالَ ‏"‏ أَيُّهَا النَّاسُ إِنِّي إِمَامُكُمْ فَلاَ تَسْبِقُونِي بِالرُّكُوعِ وَلاَ بِالسُّجُودِ وَلاَ بِالْقِيَامِ وَلاَ بِالاِنْصِرَافِ فَإِنِّي أَرَاكُمْ أَمَامِي وَمِنْ خَلْفِي - ثُمَّ قَالَ - وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَوْ رَأَيْتُمْ مَا رَأَيْتُ لَضَحِكْتُمْ قَلِيلاً وَلَبَكَيْتُمْ كَثِيرًا ‏"‏ ‏.‏ قَالُوا وَمَا رَأَيْتَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ رَأَيْتُ الْجَنَّةَ وَالنَّارَ ‏"‏ ‏.‏\hadithno{961}\hadithtrans{Anas reported:The Messenger of Allah (ﷺ) one day led us in the prayer. and when he completed the Prayer he turned his face towards us and said: 0 People, I am your Imam, so do not precede me in bowing and prostration and in standing and turning (faces, i. e. In pronouncing salutation), for I see you in front of me and behind me, and then said: By Him in Whose hand Is the life of Muhammad, if you could see what I see, you would have laughed little and wept much more. They said: What did you see, Messenger of Allah? He replied: (I saw) Paradise and Hell}}
\hadithdefcmd{muslim}{962}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ فُضَيْلٍ، جَمِيعًا عَنِ الْمُخْتَارِ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ وَلَيْسَ فِي حَدِيثِ جَرِيرٍ ‏ "‏ وَلاَ بِالاِنْصِرَافِ ‏"‏ ‏.‏\hadithno{962}\hadithtrans{This hadith is narrated by Anas with another chain of transmitters, and in the hadith transmitted by Jarir there is no mention of" turning (faces)}}
\hadithdefcmd{muslim}{963}{حَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، وَأَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، كُلُّهُمْ عَنْ حَمَّادٍ، - قَالَ خَلَفٌ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، - عَنْ مُحَمَّدِ بْنِ زِيَادٍ، حَدَّثَنَا أَبُو هُرَيْرَةَ، قَالَ قَالَ مُحَمَّدٌ صلى الله عليه وسلم ‏ "‏ أَمَا يَخْشَى الَّذِي يَرْفَعُ رَأْسَهُ قَبْلَ الإِمَامِ أَنْ يُحَوِّلَ اللَّهُ رَأْسَهُ رَأْسَ حِمَارٍ ‏"‏ ‏.‏\hadithno{963}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: Does the man who lifts his head ahead of the Imam (from prostration) not fear that Allah may change his head into the head of an ass?}}
\hadithdefcmd{muslim}{964}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ يُونُسَ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا يَأْمَنُ الَّذِي يَرْفَعُ رَأْسَهُ فِي صَلاَتِهِ قَبْلَ الإِمَامِ أَنْ يُحَوِّلَ اللَّهُ صُورَتَهُ فِي صُورَةِ حِمَارٍ ‏"‏ ‏.‏\hadithno{964}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: Does the man who lifts his head before the Imam not fear that Allah may change his face into that of an ass?}}
\hadithdefcmd{muslim}{965}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَلاَّمٍ الْجُمَحِيُّ، وَعَبْدُ الرَّحْمَنِ بْنُ الرَّبِيعِ بْنِ مُسْلِمٍ، جَمِيعًا عَنِ الرَّبِيعِ بْنِ مُسْلِمٍ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، كُلُّهُمْ عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا غَيْرَ أَنَّ فِي حَدِيثِ الرَّبِيعِ بْنِ مُسْلِمٍ ‏ "‏ أَنْ يَجْعَلَ اللَّهُ وَجْهَهُ وَجْهَ حِمَارٍ ‏"‏ ‏.‏\hadithno{965}\hadithtrans{This hadith has been narrated by Abu Huraira by another chain of transmitters except for the words narrated by Rabi' b. Muslim:" Allah may make his face like the face of an ass}}
\hadithdefcmd{muslim}{966}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنِ الْمُسَيَّبِ، عَنْ تَمِيمِ بْنِ طَرَفَةَ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيَنْتَهِيَنَّ أَقْوَامٌ يَرْفَعُونَ أَبْصَارَهُمْ إِلَى السَّمَاءِ فِي الصَّلاَةِ أَوْ لاَ تَرْجِعُ إِلَيْهِمْ ‏"‏ ‏.‏\hadithno{966}\hadithtrans{Jabir b. Samura reported:The Messenger of Allah (ﷺ) said: The people who lift their eyes towards the sky in Prayer should avoid it or they would lose their eyesight}}
\hadithdefcmd{muslim}{967}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَعَمْرُو بْنُ سَوَّادٍ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي اللَّيْثُ بْنُ سَعْدٍ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيَنْتَهِيَنَّ أَقْوَامٌ عَنْ رَفْعِهِمْ أَبْصَارَهُمْ عِنْدَ الدُّعَاءِ فِي الصَّلاَةِ إِلَى السَّمَاءِ أَوْ لَتُخْطَفَنَّ أَبْصَارُهُمْ ‏"‏ ‏.‏\hadithno{967}\hadithtrans{Abu Huraira reported:People should avoid lifting their eyes towards the sky while supplicating in prayer, otherwise their eyes would be snatched away}}
\hadithdefcmd{muslim}{968}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنِ الْمُسَيَّبِ بْنِ رَافِعٍ، عَنْ تَمِيمِ بْنِ طَرَفَةَ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ خَرَجَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا لِي أَرَاكُمْ رَافِعِي أَيْدِيكُمْ كَأَنَّهَا أَذْنَابُ خَيْلٍ شُمْسٍ اسْكُنُوا فِي الصَّلاَةِ ‏"‏ ‏.‏ قَالَ ثُمَّ خَرَجَ عَلَيْنَا فَرَآنَا حَلَقًا فَقَالَ ‏"‏ مَا لِي أَرَاكُمْ عِزِينَ ‏"‏ ‏.‏ قَالَ ثُمَّ خَرَجَ عَلَيْنَا فَقَالَ ‏"‏ أَلاَ تَصُفُّونَ كَمَا تَصُفُّ الْمَلاَئِكَةُ عِنْدَ رَبِّهَا ‏"‏ ‏.‏ فَقُلْنَا يَا رَسُولَ اللَّهِ وَكَيْفَ تَصُفُّ الْمَلاَئِكَةُ عِنْدَ رَبِّهَا قَالَ ‏"‏ يُتِمُّونَ الصُّفُوفَ الأُوَلَ وَيَتَرَاصُّونَ فِي الصَّفِّ ‏"‏ ‏.‏\hadithno{968}\hadithtrans{Jabir b. Samura reported:The Messenger of Allah (ﷺ) came to us and said: "How is it that I see you lifting your hands like the tails of headstrong horses? Be calm in prayer." He (the narrator) said: He then again came to us and saw us (sitting) in circles. He said: "How is it that I see you in separate groups?" He (the narrator) said: He again came to us and said: "Why don't you draw yourselves up in rows as angels do in the presence of their Lord?" We said: Messenger of Allah, how do the angels draw themselves up in rows in the presence of their Lord? He (the Holy Prophet) said: "They make the first rows complete and keep close together in the row}}
\hadithdefcmd{muslim}{969}{وَحَدَّثَنِي أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، قَالاَ جَمِيعًا حَدَّثَنَا الأَعْمَشُ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{969}\hadithtrans{This hadith has been narrated by A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{970}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، - وَاللَّفْظُ لَهُ - قَالَ أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ مِسْعَرٍ، حَدَّثَنِي عُبَيْدُ اللَّهِ ابْنُ الْقِبْطِيَّةِ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كُنَّا إِذَا صَلَّيْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قُلْنَا السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ السَّلاَمُ عَلَيْكُمْ وَرَحْمَةُ اللَّهِ ‏.‏ وَأَشَارَ بِيَدِهِ إِلَى الْجَانِبَيْنِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلاَمَ تُومِئُونَ بِأَيْدِيكُمْ كَأَنَّهَا أَذْنَابُ خَيْلٍ شُمُسٍ إِنَّمَا يَكْفِي أَحَدَكُمْ أَنْ يَضَعَ يَدَهُ عَلَى فَخِذِهِ ثُمَّ يُسَلِّمُ عَلَى أَخِيهِ مَنْ عَلَى يَمِينِهِ وَشِمَالِهِ ‏"‏ ‏.‏\hadithno{970}\hadithtrans{Jabir b. Samura reported:When we said prayer with the Messenger of Allah (ﷺ), we pronounced: Peace be upon you and Mercy of Allah, peace be upon you and Mercy of Allah, and made gesture with the hand on both the sides. Upon this the Messenger of Allah (may peace be upon him said: What do you point out with your hands as if they are the tails of headstrong horses? This is enough for you that one should place one's hand on one's thigh and then pronounce salutation upon one's brother on the right side and then on the left)}}
\hadithdefcmd{muslim}{971}{وَحَدَّثَنَا الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ فُرَاتٍ، - يَعْنِي الْقَزَّازَ - عَنْ عُبَيْدِ اللَّهِ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَكُنَّا إِذَا سَلَّمْنَا قُلْنَا بِأَيْدِينَا السَّلاَمُ عَلَيْكُمْ السَّلاَمُ عَلَيْكُمْ فَنَظَرَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ مَا شَأْنُكُمْ تُشِيرُونَ بِأَيْدِيكُمْ كَأَنَّهَا أَذْنَابُ خَيْلٍ شُمُسٍ إِذَا سَلَّمَ أَحَدُكُمْ فَلْيَلْتَفِتْ إِلَى صَاحِبِهِ وَلاَ يُومِئْ بِيَدِهِ ‏"‏ ‏.‏\hadithno{971}\hadithtrans{Jabir b. Samura reported:We said our prayer with the Messenger of Allah (ﷺ) and, while pronouncing salutations, we made gestures with our hands (indicating)" Peace be upon you, peace be upon you." The Messenger of Allah (ﷺ) looked towards us and said: Why is it that you make gestures with your hands like the tails of headstrong horses? When any one of you pro- nounces salutation (in prayer) he should only turn his face towards his companion and should not make a gesture with his hand}}
\hadithdefcmd{muslim}{972}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، وَأَبُو مُعَاوِيَةَ وَوَكِيعٌ عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ التَّيْمِيِّ، عَنْ أَبِي مَعْمَرٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْسَحُ مَنَاكِبَنَا فِي الصَّلاَةِ وَيَقُولُ ‏ "‏ اسْتَوُوا وَلاَ تَخْتَلِفُوا فَتَخْتَلِفَ قُلُوبُكُمْ لِيَلِنِي مِنْكُمْ أُولُو الأَحْلاَمِ وَالنُّهَى ثُمَّ الَّذِينَ يَلُونَهُمْ ثُمَّ الَّذِينَ يَلُونَهُمْ ‏"‏ ‏.‏ قَالَ أَبُو مَسْعُودٍ فَأَنْتُمُ الْيَوْمَ أَشَدُّ اخْتِلاَفًا ‏.‏\hadithno{972}\hadithtrans{Abu Mas'ud reported:The Messenger of Allah (may peace he upon him) used to touch our shoulders in prayer and say: Keep straight, don't be irregular, for there would be dissension in your hearts. Let those of you who are sedate and prudent be near me, then those who are next to them, then those who are next to them. Abu Mas'ud said: Now-a-days there is much dissension amongst you}}
\hadithdefcmd{muslim}{973}{وَحَدَّثَنَاهُ إِسْحَاقُ، أَخْبَرَنَا جَرِيرٌ، ح قَالَ وَحَدَّثَنَا ابْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى يَعْنِي ابْنَ يُونُسَ، ح قَالَ وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{973}\hadithtrans{This hadith is narrated by Ibn Uyaina with the same chain of transmitters}}
\hadithdefcmd{muslim}{974}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، وَصَالِحُ بْنُ حَاتِمِ بْنِ وَرْدَانَ، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنِي خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي مَعْشَرٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِيَلِنِي مِنْكُمْ أُولُو الأَحْلاَمِ وَالنُّهَى ثُمَّ الَّذِينَ يَلُونَهُمْ - ثَلاَثًا - وَإِيَّاكُمْ وَهَيْشَاتِ الأَسْوَاقِ ‏"‏ ‏.‏\hadithno{974}\hadithtrans{Abdullah b. Mas'ud reported:The Messenger of Allah (ﷺ) said: Let those who are sedate and prudent be near me, then those who are next to them (saying it tliree tinies), and beware of the tumult of the markets}}
\hadithdefcmd{muslim}{975}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سَوُّوا صُفُوفَكُمْ فَإِنَّ تَسْوِيَةَ الصَّفِّ مِنْ تَمَامِ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{975}\hadithtrans{Anas b. Malik reported:The Messenger of Allah (ﷺ) said: Straighten your rows. for the straightening of a row is a part of the perfection of prayer}}
\hadithdefcmd{muslim}{976}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ، - وَهُوَ ابْنُ صُهَيْبٍ - عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَتِمُّوا الصُّفُوفَ فَإِنِّي أَرَاكُمْ خَلْفَ ظَهْرِي ‏"‏ ‏.‏\hadithno{976}\hadithtrans{Anas b. Malik reported:The Messenger of Allah (ﷺ) said: Complete the rows, for I can see you behind my back}}
\hadithdefcmd{muslim}{977}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ ‏ "‏ أَقِيمُوا الصَّفَّ فِي الصَّلاَةِ فَإِنَّ إِقَامَةَ الصَّفِّ مِنْ حُسْنِ الصَّلاَةِ ‏"‏ ‏.‏\hadithno{977}\hadithtrans{Hammam b. Munabbih reported:This is what was transmitted to us by Abu Huraira from the Messenger of Allah (ﷺ) and, while making a mention of a few ahadith, said: (The Messengerof Allah directed us thus): Establish rows in prayer, for the making of a row (straight) is one of the merits of prayer}}
\hadithdefcmd{muslim}{978}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ سَالِمَ بْنَ أَبِي الْجَعْدِ الْغَطَفَانِيَّ، قَالَ سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَتُسَوُّنَّ صُفُوفَكُمْ أَوْ لَيُخَالِفَنَّ اللَّهُ بَيْنَ وُجُوهِكُمْ ‏"‏ ‏.‏\hadithno{978}\hadithtrans{Nu'man b. Bashir reported:I heard the Messenger of Allah (ﷺ) say: Straighten your rows, or Allah would create dissension amongst you}}
\hadithdefcmd{muslim}{979}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُسَوِّي صُفُوفَنَا حَتَّى كَأَنَّمَا يُسَوِّي بِهَا الْقِدَاحَ حَتَّى رَأَى أَنَّا قَدْ عَقَلْنَا عَنْهُ ثُمَّ خَرَجَ يَوْمًا فَقَامَ حَتَّى كَادَ يُكَبِّرُ فَرَأَى رَجُلاً بَادِيًا صَدْرُهُ مِنَ الصَّفِّ فَقَالَ ‏ "‏ عِبَادَ اللَّهِ لَتُسَوُّنَّ صُفُوفَكُمْ أَوْ لَيُخَالِفَنَّ اللَّهُ بَيْنَ وُجُوهِكُمْ ‏"‏ ‏.‏\hadithno{979}\hadithtrans{Nu'man b. Bashir reported:The Messenger of Allah (may peace-be upon him) used to straighten our rows as it lie were straightening an arrow with their help until be saw that we had learnt it from him. One day he came out, stood up (for prayer) and was about to say: Allah is the Greatest, when he saw a man, whose chest was bulging out from the row, so he said: Servants of Allah, you hint straighten your rows or Allah would create dissension amongst you}}
\hadithdefcmd{muslim}{980}{حَدَّثَنَا حَسَنُ بْنُ الرَّبِيعِ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{980}\hadithtrans{Abu 'Awana reported this hadith with the same chain of transmitters}}
\hadithdefcmd{muslim}{981}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ يَعْلَمُ النَّاسُ مَا فِي النِّدَاءِ وَالصَّفِّ الأَوَّلِ ثُمَّ لَمْ يَجِدُوا إِلاَّ أَنْ يَسْتَهِمُوا عَلَيْهِ لاَسْتَهَمُوا وَلَوْ يَعْلَمُونَ مَا فِي التَّهْجِيرِ لاَسْتَبَقُوا إِلَيْهِ وَلَوْ يَعْلَمُونَ مَا فِي الْعَتَمَةِ وَالصُّبْحِ لأَتَوْهُمَا وَلَوْ حَبْوًا ‏"‏ ‏.‏\hadithno{981}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: If the people were to know what excellence is there in the Adhan and in the first row, and they could not (get these opportunities) except by drawing lots, they would have definitely done that. And if they were to know what excellence lies in joining the prayer in the first takbir (prayer), they would have vied with one another. And if they were to know what excellence lies in the night prayer and morning prayer, they would have definitely come even if crawling (on their knees)}}
\hadithdefcmd{muslim}{982}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا أَبُو الأَشْهَبِ، عَنْ أَبِي نَضْرَةَ الْعَبْدِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى فِي أَصْحَابِهِ تَأَخُّرًا فَقَالَ لَهُمْ ‏ "‏ تَقَدَّمُوا فَائْتَمُّوا بِي وَلْيَأْتَمَّ بِكُمْ مَنْ بَعْدَكُمْ لاَ يَزَالُ قَوْمٌ يَتَأَخَّرُونَ حَتَّى يُؤَخِّرَهُمُ اللَّهُ ‏"‏ ‏.‏\hadithno{982}\hadithtrans{Abu Sa'id al-Khudri reported:The Messenger of Allah (ﷺ) saw (a tendency ) among his Companions to go to the back, so he said to them: Come forward and follow my lead, and let those who come after you follow your lead. People will continue to keep back till Allah will put them at the back}}
\hadithdefcmd{muslim}{983}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الرَّقَاشِيُّ، حَدَّثَنَا بِشْرُ بْنُ مَنْصُورٍ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم قَوْمًا فِي مُؤَخَّرِ الْمَسْجِدِ ‏.‏ فَذَكَرَ مِثْلَهُ ‏.‏\hadithno{983}\hadithtrans{Abu Sa'id al-Khudri reported:The Messenger of Allah (ﷺ) saw people at the end of the mosque, and then the (above-mentioned hadith) was narrated}}
\hadithdefcmd{muslim}{984}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ دِينَارٍ، وَمُحَمَّدُ بْنُ حَرْبٍ الْوَاسِطِيُّ، قَالاَ حَدَّثَنَا عَمْرُو بْنُ الْهَيْثَمِ أَبُو قَطَنٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ خِلاَسٍ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لَوْ تَعْلَمُونَ - أَوْ يَعْلَمُونَ - مَا فِي الصَّفِّ الْمُقَدَّمِ لَكَانَتْ قُرْعَةً ‏"‏ ‏.‏ وَقَالَ ابْنُ حَرْبٍ ‏"‏ الصَّفِّ الأَوَّلِ مَا كَانَتْ إِلاَّ قُرْعَةً ‏"‏ ‏.‏\hadithno{984}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: If you were to know, or if they were to know, what (excellence) lies in the first rows, there would have been drawing of lots (for filling them) ; and Ibn Harb said: For (occupying) the first row there would have been drawing of lots}}
\hadithdefcmd{muslim}{985}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ صُفُوفِ الرِّجَالِ أَوَّلُهَا وَشَرُّهَا آخِرُهَا وَخَيْرُ صُفُوفِ النِّسَاءِ آخِرُهَا وَشَرُّهَا أَوَّلُهَا ‏"‏ ‏.‏\hadithno{985}\hadithtrans{It was narrated from Abu Huraira that the Messenger of Allah (ﷺ) said:The best rows for men are the first rows, and the worst ones the last ones, and the best rows for women are the last ones and the worst ones for them are the first ones}}
\hadithdefcmd{muslim}{986}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنْ سُهَيْلٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{986}\hadithtrans{This hadith is narrated by Suhail with the same chain of transmitters}}
\hadithdefcmd{muslim}{987}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ لَقَدْ رَأَيْتُ الرِّجَالَ عَاقِدِي أُزُرِهِمْ فِي أَعْنَاقِهِمْ مِثْلَ الصِّبْيَانِ مِنْ ضِيقِ الأُزُرِ خَلْفَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ قَائِلٌ يَا مَعْشَرَ النِّسَاءِ لاَ تَرْفَعْنَ رُءُوسَكُنَّ حَتَّى يَرْفَعَ الرِّجَالُ ‏.‏\hadithno{987}\hadithtrans{Sahl b. Sa'd reported:I saw men having tied (the ends) of their lower garments around their necks, like children, due to shortage of cloth and offering their prayers behind the Messenger of Allah (ﷺ). One of the proclaimers said: O womenfolk, do not lift your heads till men raise (them)}}
\hadithdefcmd{muslim}{988}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، - قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنِ الزُّهْرِيِّ، سَمِعَ سَالِمًا، يُحَدِّثُ عَنْ أَبِيهِ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتَأْذَنَتْ أَحَدَكُمُ امْرَأَتُهُ إِلَى الْمَسْجِدِ فَلاَ يَمْنَعْهَا ‏"‏ ‏.‏\hadithno{988}\hadithtrans{Salim narrated it from his father ('Abdullah b. Umar) that the Messenger of Allah (ﷺ) said:When women ask permission for going to the mosque, do not prevent them}}
\hadithdefcmd{muslim}{989}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَمْنَعُوا نِسَاءَكُمُ الْمَسَاجِدَ إِذَا اسْتَأْذَنَّكُمْ إِلَيْهَا ‏"‏ ‏.‏ قَالَ فَقَالَ بِلاَلُ بْنُ عَبْدِ اللَّهِ وَاللَّهِ لَنَمْنَعُهُنَّ ‏.‏ قَالَ فَأَقْبَلَ عَلَيْهِ عَبْدُ اللَّهِ فَسَبَّهُ سَبًّا سَيِّئًا مَا سَمِعْتُهُ سَبَّهُ مِثْلَهُ قَطُّ وَقَالَ أُخْبِرُكَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَتَقُولُ وَاللَّهِ لَنَمْنَعُهُنَّ ‏.‏\hadithno{989}\hadithtrans{Abdullah b. Umar reported:I heard Allah's Messenger (ﷺ) say: Don't prevent your women from going to the mosque when they seek your permission. Bilal b. 'Abdullah said: By Allah, we shall certainly prevent them. On this'Abdullah b. Umar turned towards him and reprimanded him to harshly as I had never heard him do before. He ('Abdullah b. Umar) said: I am narrating to you that which comes from the Messenger of Allah (ﷺ) and you (have the audicity) to say: By Allah, we shall certainly prevent them}}
\hadithdefcmd{muslim}{990}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي وَابْنُ، إِدْرِيسَ قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَمْنَعُوا إِمَاءَ اللَّهِ مَسَاجِدَ اللَّهِ ‏"‏ ‏.‏\hadithno{990}\hadithtrans{Ibn 'Umar reported:'The Messenger of Allah (ﷺ) said: Do not prevent the maid-servants of Allah from going to the mosque}}
\hadithdefcmd{muslim}{991}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا حَنْظَلَةُ، قَالَ سَمِعْتُ سَالِمًا، يَقُولُ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا اسْتَأْذَنَكُمْ نِسَاؤُكُمْ إِلَى الْمَسَاجِدِ فَأْذَنُوا لَهُنَّ ‏"‏ ‏.‏\hadithno{991}\hadithtrans{lbn Umar reported:I heard the Messeinger of Allah (ﷺ) say: When your women seek your permission for going to the mosque, you grant them (permission)}}
\hadithdefcmd{muslim}{992}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَمْنَعُوا النِّسَاءَ مِنَ الْخُرُوجِ إِلَى الْمَسَاجِدِ بِاللَّيْلِ ‏"‏ ‏.‏ فَقَالَ ابْنٌ لِعَبْدِ اللَّهِ بْنِ عُمَرَ لاَ نَدَعُهُنَّ يَخْرُجْنَ فَيَتَّخِذْنَهُ دَغَلاً ‏.‏ قَالَ فَزَبَرَهُ ابْنُ عُمَرَ وَقَالَ أَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَتَقُولُ لاَ نَدَعُهُنَّ ‏.‏\hadithno{992}\hadithtrans{Ibn 'Umar reported:The Messenger of Allah (ﷺ) said: Do not prevent women from going to the mosque at night. A boy said to 'Abdullah b. Umar: We would never let them go out, that they may not be caught in evil. He (the narrator) said: Ibn Umar reprimanded him and said.. I am saying that the Messenger of Allah (ﷺ) said this, but you say: We would not allow}}
\hadithdefcmd{muslim}{993}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏\hadithno{993}\hadithtrans{A hadith like this has been narrated by A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{994}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ، وَابْنُ، رَافِعٍ قَالاَ حَدَّثَنَا شَبَابَةُ، حَدَّثَنِي وَرْقَاءُ، عَنْ عَمْرٍو، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ائْذَنُوا لِلنِّسَاءِ بِاللَّيْلِ إِلَى الْمَسَاجِدِ ‏"‏ ‏.‏ فَقَالَ ابْنٌ لَهُ يُقَالُ لَهُ وَاقِدٌ إِذًا يَتَّخِذْنَهُ دَغَلاً ‏.‏ قَالَ فَضَرَبَ فِي صَدْرِهِ وَقَالَ أُحَدِّثُكَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَتَقُولُ لاَ ‏.‏\hadithno{994}\hadithtrans{Ibn 'Umar reported:Grant permission to women for going to the mosque in the night. His son who was called Waqid said: Then they would make mischief. He (the narrator) said: He thumped his (son's) chest and said: I am narrating to you the hadith of the Messenger of Allah (ﷺ), and you say: No}}
\hadithdefcmd{muslim}{995}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، حَدَّثَنَا سَعِيدٌ، - يَعْنِي ابْنَ أَبِي أَيُّوبَ - حَدَّثَنَا كَعْبُ بْنُ عَلْقَمَةَ، عَنْ بِلاَلِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَمْنَعُوا النِّسَاءَ حُظُوظَهُنَّ مِنَ الْمَسَاجِدِ إِذَا اسْتَأْذَنُوكُمْ ‏"‏ فَقَالَ بِلاَلٌ وَاللَّهِ لَنَمْنَعُهُنَّ ‏.‏ فَقَالَ لَهُ عَبْدُ اللَّهِ أَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَتَقُولُ أَنْتَ لَنَمْنَعُهُنَّ ‏.‏\hadithno{995}\hadithtrans{Ibn Umar reported:The Messenger of Allah (ﷺ) said: Do not deprive women of their share of the mosques, when they seek permission from you. Bilal said: By Allah, we would certainly prevent them. 'Abdullah said: I say that the Messenger of Allah (ﷺ) said it and you say: We would certainly prevent them}}
\hadithdefcmd{muslim}{996}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَخْرَمَةُ، عَنْ أَبِيهِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، أَنَّ زَيْنَبَ الثَّقَفِيَّةَ، كَانَتْ تُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا شَهِدَتْ إِحْدَاكُنَّ الْعِشَاءَ فَلاَ تَطَيَّبْ تِلْكَ اللَّيْلَةَ ‏"‏ ‏.‏\hadithno{996}\hadithtrans{Zainab Thaqafiya reported:The Messenger of Allah (ﷺ) said: When any one of you (women) participates in the 'Isha' prayer, she should not perfume herself that night}}
\hadithdefcmd{muslim}{997}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، عَنْ مُحَمَّدِ بْنِ عَجْلاَنَ، حَدَّثَنِي بُكَيْرُ بْنُ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْنَبَ، امْرَأَةِ عَبْدِ اللَّهِ قَالَتْ قَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا شَهِدَتْ إِحْدَاكُنَّ الْمَسْجِدَ فَلاَ تَمَسَّ طِيبًا ‏"‏ ‏.‏\hadithno{997}\hadithtrans{Zainab, the wife of Abdullah (b. 'Umar), reported:The Messenger of Allah (ﷺ) said to us: When any one of you comes to the mosque, she should not apply perfume}}
\hadithdefcmd{muslim}{998}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ يَحْيَى أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي فَرْوَةَ، عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا امْرَأَةٍ أَصَابَتْ بَخُورًا فَلاَ تَشْهَدْ مَعَنَا الْعِشَاءَ الآخِرَةَ ‏"‏ ‏.‏\hadithno{998}\hadithtrans{Abu Huraira said:The Messenger of Allah (ﷺ) said: Whoever (woman) fumigates herself with perfume should not join us in the 'Isha' prayer}}
\hadithdefcmd{muslim}{999}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ - عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، أَنَّهَا سَمِعَتْ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ لَوْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى مَا أَحْدَثَ النِّسَاءُ لَمَنَعَهُنَّ الْمَسْجِدَ كَمَا مُنِعَتْ نِسَاءُ بَنِي إِسْرَائِيلَ ‏.‏ قَالَ فَقُلْتُ لِعَمْرَةَ أَنِسَاءُ بَنِي إِسْرَائِيلَ مُنِعْنَ الْمَسْجِدَ قَالَتْ نَعَمْ ‏.‏\hadithno{999}\hadithtrans{Amra, daughter of Abd al-Rahmin, reported:I heard 'A'isha, the wife of the Messenger of Allah (ﷺ). say: If the Messenger of Allah (ﷺ) had seen what new things the women have introduced (in their way of life) he would have definitely prevented them from going to the mosque, as the women of BaniIsra'il were prevented}}
\hadithdefcmd{muslim}{1000}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ يَعْنِي الثَّقَفِيَّ، ح قَالَ وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، ح قَالَ وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، ح قَالَ وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كُلُّهُمْ عَنْ يَحْيَى بْنِ سَعِيدٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏\hadithno{1000}\hadithtrans{This hadith has been narrated by Yahya b. Sa'id with the same chain of transmitters}}
\hadithdefcmd{muslim}{1001}{حَدَّثَنَا أَبُو جَعْفَرٍ، مُحَمَّدُ بْنُ الصَّبَّاحِ وَعَمْرٌو النَّاقِدُ جَمِيعًا عَنْ هُشَيْمٍ، - قَالَ ابْنُ الصَّبَّاحِ حَدَّثَنَا هُشَيْمٌ، - أَخْبَرَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ وَلاَ تَجْهَرْ بِصَلاَتِكَ وَلاَ تُخَافِتْ بِهَا‏\}‏ قَالَ نَزَلَتْ وَرَسُولُ اللَّهِ صلى الله عليه وسلم مُتَوَارٍ بِمَكَّةَ فَكَانَ إِذَا صَلَّى بِأَصْحَابِهِ رَفَعَ صَوْتَهُ بِالْقُرْآنِ فَإِذَا سَمِعَ ذَلِكَ الْمُشْرِكُونَ سَبُّوا الْقُرْآنَ وَمَنْ أَنْزَلَهُ وَمَنْ جَاءَ بِهِ فَقَالَ اللَّهُ تَعَالَى لِنَبِيِّهِ صلى الله عليه وسلم ‏\{‏ وَلاَ تَجْهَرْ بِصَلاَتِكَ‏\}‏ فَيَسْمَعَ الْمُشْرِكُونَ قِرَاءَتَكَ ‏\{‏ وَلاَ تُخَافِتْ بِهَا‏\}‏ عَنْ أَصْحَابِكَ أَسْمِعْهُمُ الْقُرْآنَ وَلاَ تَجْهَرْ ذَلِكَ الْجَهْرَ وَابْتَغِ بَيْنَ ذَلِكَ سَبِيلاً يَقُولُ بَيْنَ الْجَهْرِ وَالْمُخَافَتَةِ ‏.‏\hadithno{1001}\hadithtrans{Ibn 'Abbas reported:The word of (Allah) Great and Glorious: 'And utter not thy prayer loudly, nor be low in it" (xvii. 110) was revealed as the Messenger of Allah (may peace beupon him) was hiding himself in Mecca. When he led his Companions in prayer he raised his voice (while reciting the) Qur'an. And when the polytheists heard that, they reviled the Qur'an and Him Who revealed it and him who brought it. Upon this Allah, the Exalted, said to His Apostle (ﷺ): Utter not thy prayer so loudly that the polytheists may hear thy recitation and (recite it) not so low that it may be inaudible to your Companions. Make them hear the Qur'an, but do not recite it loudly and seek a (middle) way between these. Recite between loud and low tone}}
\hadithdefcmd{muslim}{1002}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَحْيَى بْنُ زَكَرِيَّاءَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ وَلاَ تَجْهَرْ بِصَلاَتِكَ وَلاَ تُخَافِتْ بِهَا‏\}‏ قَالَتْ أُنْزِلَ هَذَا فِي الدُّعَاءِ ‏.‏\hadithno{1002}\hadithtrans{A'isha reported that so far as these words of (Allah) Glorious and High are concerned:" And utter not thy prayer loudly, not be low in it" (xvii. 110) relate to supplication (du'a)}}
\hadithdefcmd{muslim}{1003}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادٌ يَعْنِي ابْنَ زَيْدٍ، ح قَالَ وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، وَوَكِيعٌ، ح قَالَ وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، كُلُّهُمْ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏\hadithno{1003}\hadithtrans{A hadith like this has been narrated by Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{1004}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ كُلُّهُمْ عَنْ جَرِيرٍ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، - عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ عَزَّ وَجَلَّ ‏\{‏ لاَ تُحَرِّكْ بِهِ لِسَانَكَ‏\}‏ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا نَزَلَ عَلَيْهِ جِبْرِيلُ بِالْوَحْىِ كَانَ مِمَّا يُحَرِّكُ بِهِ لِسَانَهُ وَشَفَتَيْهِ فَيَشْتَدُّ عَلَيْهِ فَكَانَ ذَلِكَ يُعْرَفُ مِنْهُ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏ لاَ تُحَرِّكْ بِهِ لِسَانَكَ لِتَعْجَلَ بِهِ‏\}‏ أَخْذَهُ ‏\{‏ إِنَّ عَلَيْنَا جَمْعَهُ وَقُرْآنَهُ‏\}‏ إِنَّ عَلَيْنَا أَنْ نَجْمَعَهُ فِي صَدْرِكَ ‏.‏ وَقُرْآنَهُ فَتَقْرَأُهُ ‏\{‏ فَإِذَا قَرَأْنَاهُ فَاتَّبِعْ قُرْآنَهُ‏\}‏ قَالَ أَنْزَلْنَاهُ فَاسْتَمِعْ لَهُ ‏\{‏ إِنَّ عَلَيْنَا بَيَانَهُ‏\}‏ أَنْ نُبَيِّنَهُ بِلِسَانِكَ فَكَانَ إِذَا أَتَاهُ جِبْرِيلُ أَطْرَقَ فَإِذَا ذَهَبَ قَرَأَهُ كَمَا وَعَدَهُ اللَّهُ ‏.‏\hadithno{1004}\hadithtrans{Ibn 'Abbas reported with regard to the words of Allah, Great and Glorious:" Move not thy tongue therewith" (Ixxv. 16) that when Gabriel brought revelation to him (the Holy Prophet) he moved his tongue and lips (with a view to committing it to memory instantly). This was something hard for him and it was visible (from his face). Then Allah, the Exalted. revealed this a" Move not thy tongue therewith to make haste (in memorising it). Surely on us rests the collecting of it and the reciting of it" (ixxv. 16), i. e. Verily it rests with Us that We would preserve it in your heart and (enable you) to recite it You would recite it when We would recite it and so follow its recitation, and He (Allah) said:" We revealed it, so listen to it attentively. Verily its exposition rests with Us. i. e. We would make it deliver by your tongue." So when Gabriel came to him (to the Holy Prophet), he kept silence, and when he went away he recited as Allah had promised him}}
\hadithdefcmd{muslim}{1005}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، فِي قَوْلِهِ ‏\{‏ لاَ تُحَرِّكْ بِهِ لِسَانَكَ لِتَعْجَلَ بِهِ‏\}‏ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُعَالِجُ مِنَ التَّنْزِيلِ شِدَّةً كَانَ يُحَرِّكُ شَفَتَيْهِ - فَقَالَ لِيَ ابْنُ عَبَّاسٍ أَنَا أُحَرِّكُهُمَا كَمَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُحَرِّكُهُمَا ‏.‏ فَقَالَ سَعِيدٌ أَنَا أُحَرِّكُهُمَا كَمَا كَانَ ابْنُ عَبَّاسٍ يُحَرِّكُهُمَا ‏.‏ فَحَرَّكَ شَفَتَيْهِ - فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏ لاَ تُحَرِّكْ بِهِ لِسَانَكَ لِتَعْجَلَ بِهِ * إِنَّ عَلَيْنَا جَمْعَهُ وَقُرْآنَهُ‏\}‏ قَالَ جَمْعَهُ فِي صَدْرِكَ ثُمَّ تَقْرَأُهُ ‏\{‏ فَإِذَا قَرَأْنَاهُ فَاتَّبِعْ قُرْآنَهُ‏\}‏ قَالَ فَاسْتَمِعْ وَأَنْصِتْ ثُمَّ إِنَّ عَلَيْنَا أَنْ تَقْرَأَهُ قَالَ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَتَاهُ جِبْرِيلُ اسْتَمَعَ فَإِذَا انْطَلَقَ جِبْرِيلُ قَرَأَهُ النَّبِيُّ صلى الله عليه وسلم كَمَا أَقْرَأَهُ ‏.‏\hadithno{1005}\hadithtrans{Ibn Abbas reported with regard to the words:" Do not move thy tongue there with to make haste," that the Messenger of Allah (ﷺ) felt it hard and he moved his lips. Ibn 'Abbas said to me (Sa'id b. Jubair): I move them just as the Messenger of Allah (ﷺ) moved them. Then said Sa'id: I move them just as Ibn 'Abbas moved them, and he moved his lips. Allah, the Exalted, revealed this:" Do not move your tongue therewith to make haste. It is with US that its collection rests and its recital" (al-Qur'an, ixxv. 16). He said: Its preservation in your heart and then your recital. So when We recite it, follow its recital. He said: Listen to it, and be silent and then it rests with Us that you recite it. So when Gabriel came to the Messenger of Allah (ﷺ), he listened to him attentively, and when Gabriel went away, the Messenger of Allah (ﷺ) recited as he (Gabriel) had recited it}}
\hadithdefcmd{muslim}{1006}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَا قَرَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْجِنِّ وَمَا رَآهُمُ انْطَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي طَائِفَةٍ مِنْ أَصْحَابِهِ عَامِدِينَ إِلَى سُوقِ عُكَاظٍ وَقَدْ حِيلَ بَيْنَ الشَّيَاطِينِ وَبَيْنَ خَبَرِ السَّمَاءِ وَأُرْسِلَتْ عَلَيْهِمُ الشُّهُبُ فَرَجَعَتِ الشَّيَاطِينُ إِلَى قَوْمِهِمْ فَقَالُوا مَا لَكُمْ قَالُوا حِيلَ بَيْنَنَا وَبَيْنَ خَبَرِ السَّمَاءِ وَأُرْسِلَتْ عَلَيْنَا الشُّهُبُ ‏.‏ قَالُوا مَا ذَاكَ إِلاَّ مِنْ شَىْءٍ حَدَثَ فَاضْرِبُوا مَشَارِقَ الأَرْضِ وَمَغَارِبَهَا فَانْظُرُوا مَا هَذَا الَّذِي حَالَ بَيْنَنَا وَبَيْنَ خَبَرِ السَّمَاءِ ‏.‏ فَانْطَلَقُوا يَضْرِبُونَ مَشَارِقَ الأَرْضِ وَمَغَارِبَهَا فَمَرَّ النَّفَرُ الَّذِينَ أَخَذُوا نَحْوَ تِهَامَةَ - وَهُوَ بِنَخْلٍ - عَامِدِينَ إِلَى سُوقِ عُكَاظٍ وَهُوَ يُصَلِّي بِأَصْحَابِهِ صَلاَةَ الْفَجْرِ فَلَمَّا سَمِعُوا الْقُرْآنَ اسْتَمَعُوا لَهُ وَقَالُوا هَذَا الَّذِي حَالَ بَيْنَنَا وَبَيْنَ خَبَرِ السَّمَاءِ ‏.‏ فَرَجَعُوا إِلَى قَوْمِهِمْ فَقَالُوا يَا قَوْمَنَا ‏\{‏ إِنَّا سَمِعْنَا قُرْآنًا عَجَبًا * يَهْدِي إِلَى الرُّشْدِ فَآمَنَّا بِهِ وَلَنْ نُشْرِكَ بِرَبِّنَا أَحَدًا‏\}‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ عَلَى نَبِيِّهِ مُحَمَّدٍ صلى الله عليه وسلم ‏\{‏ قُلْ أُوحِيَ إِلَىَّ أَنَّهُ اسْتَمَعَ نَفَرٌ مِنَ الْجِنِّ‏\}‏ ‏.‏\hadithno{1006}\hadithtrans{Ibn 'Abbas reported:The Messenger of Allah (ﷺ) neither recited the Qur'an to the Jinn nor did he see them. The Messenger of Allah (ﷺ) went out with some of his Companions with the intention of going to the bazaar of 'Ukaz And there had been (at that time) obstructions between satans and the news from the Heaven, and there were flung flames upon them. So satan went back to their people and they said: What has happened to you? They said: There have been created obstructions between us and the news from the Heaven. And there have been flung upon us flames. They said: It cannot happen but for some (important) event. So traverse the eastern parts of the earth and the western parts and find out why is it that there have been created obstructions between us and the news from the Heaven. So they went forth and traversed the easts of the earth and its wests. Some of them proceeded towards Tihama and that is a nakhl towards the bazaar of 'Ukaz and he (the Holy Prophet) was leading his Companions in the morning prayer. So when they heard the Qur'an. they listened to it attentively and said: It is this which has caused obstruction between us and news from the Heaven. They went back to their people and said: O our people, we have heard a strange Qur'an which directs us to the right path; so we affirm our faith in it and we would never associate anyone with our Lord. And Allah, the Exalted and Glorious, revealed to His Apostle Muhammad (ﷺ):" It has been revealed to me that a party of Jinn listened to it" (Qur'an, lxxii)}}
\hadithdefcmd{muslim}{1007}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ دَاوُدَ، عَنْ عَامِرٍ، قَالَ سَأَلْتُ عَلْقَمَةَ هَلْ كَانَ ابْنُ مَسْعُودٍ شَهِدَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيْلَةَ الْجِنِّ قَالَ فَقَالَ عَلْقَمَةُ أَنَا سَأَلْتُ ابْنَ مَسْعُودٍ فَقُلْتُ هَلْ شَهِدَ أَحَدٌ مِنْكُمْ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيْلَةَ الْجِنِّ قَالَ لاَ وَلَكِنَّا كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَفَقَدْنَاهُ فَالْتَمَسْنَاهُ فِي الأَوْدِيَةِ وَالشِّعَابِ فَقُلْنَا اسْتُطِيرَ أَوِ اغْتِيلَ - قَالَ - فَبِتْنَا بِشَرِّ لَيْلَةٍ بَاتَ بِهَا قَوْمٌ فَلَمَّا أَصْبَحْنَا إِذَا هُوَ جَاءٍ مِنْ قِبَلِ حِرَاءٍ - قَالَ - فَقُلْنَا يَا رَسُولَ اللَّهِ فَقَدْنَاكَ فَطَلَبْنَاكَ فَلَمْ نَجِدْكَ فَبِتْنَا بِشَرِّ لَيْلَةٍ بَاتَ بِهَا قَوْمٌ ‏.‏ فَقَالَ ‏"‏ أَتَانِي دَاعِي الْجِنِّ فَذَهَبْتُ مَعَهُ فَقَرَأْتُ عَلَيْهِمُ الْقُرْآنَ ‏"‏ ‏.‏ قَالَ فَانْطَلَقَ بِنَا فَأَرَانَا آثَارَهُمْ وَآثَارَ نِيرَانِهِمْ وَسَأَلُوهُ الزَّادَ فَقَالَ ‏"‏ لَكُمْ كُلُّ عَظْمٍ ذُكِرَ اسْمُ اللَّهِ عَلَيْهِ يَقَعُ فِي أَيْدِيكُمْ أَوْفَرَ مَا يَكُونُ لَحْمًا وَكُلُّ بَعَرَةٍ عَلَفٌ لِدَوَابِّكُمْ ‏"‏ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَلاَ تَسْتَنْجُوا بِهِمَا فَإِنَّهُمَا طَعَامُ إِخْوَانِكُمْ ‏"‏ ‏.‏\hadithno{1007}\hadithtrans{Dawud reported from 'Amir who said:I asked 'Alqama if Ibn Mas'ud was present with the Messenger of Allah (ﷺ) on the night of the Jinn (the night when the Prophet met them). He (Ibn Mas'uad) said: No, but we were in the company of the Messenger of Allah (ﷺ) one night and we missed him. We searched for him in the valleys and the hills and said. He has either been taken away (by jinn) or has been secretly killed. He (the narrator) said. We spent the worst night which people could ever spend. When it was dawn we saw him coming from the side of Hiri'. He (the narrator) reported. We said: Messenger of Allah, we missed you and searched for you, but we could not find you and we spent the worst night which people could ever spend. He (the Holy Prophet) said: There came to me an inviter on behalf of the Jinn and I went along with him and recited to them the Qur'an. He (the narrator) said: He then went along with us and showed us their traces and traces of their embers. They (the Jinn) asked him (the Holy Prophet) about their provision and he said: Every bone on which the name of Allah is recited is your provision. The time it will fall in your hand it would be covered with flesh, and the dung of (the camels) is fodder for your animals. The Messenger of Allah (ﷺ) said: Don't perform istinja with these (things) for these are the food of your brothers (Jinn)}}
\hadithdefcmd{muslim}{1008}{وَحَدَّثَنِيهِ عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ دَاوُدَ، بِهَذَا الإِسْنَادِ إِلَى قَوْلِهِ وَآثَارَ نِيرَانِهِمْ ‏.‏ قَالَ الشَّعْبِيُّ وَسَأَلُوهُ الزَّادَ وَكَانُوا مِنْ جِنِّ الْجَزِيرَةِ ‏.‏ إِلَى آخِرِ الْحَدِيثِ مِنْ قَوْلِ الشَّعْبِيِّ مُفَصَّلاً مِنْ حَدِيثِ عَبْدِ اللَّهِ ‏.‏\hadithno{1008}\hadithtrans{This hadith has been reported by Dawud with the same chain of transmitters up to the word (s):" The traces of their embers." Sha'bi said: They (the Jinn) asked about their provision, and they were the Jinn of al-jazira, up to the end of the hadith, and the words of Sha'bi have been directly transmitted from the hadith of Abdullah}}
\hadithdefcmd{muslim}{1009}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ دَاوُدَ، عَنِ الشَّعْبِيِّ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم إِلَى قَوْلِهِ وَآثَارَ نِيرَانِهِمْ ‏.‏ وَلَمْ يَذْكُرْ مَا بَعْدَهُ ‏.‏\hadithno{1009}\hadithtrans{This hadith has been narrated on the authority of 'Abdullah from the Apostle (ﷺ) up to the words:" The traces of the embers," but he made no mention of what followed afterward}}
\hadithdefcmd{muslim}{1010}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ خَالِدٍ، عَنْ أَبِي مَعْشَرٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ لَمْ أَكُنْ لَيْلَةَ الْجِنِّ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَوَدِدْتُ أَنِّي كُنْتُ مَعَهُ ‏.‏\hadithno{1010}\hadithtrans{Abdullah (b. Mas'ud) said:I was not with the Messenger of Allah (ﷺ) but I wish I were with him}}
\hadithdefcmd{muslim}{1011}{حَدَّثَنَا سَعِيدُ بْنُ مُحَمَّدٍ الْجَرْمِيُّ، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ مِسْعَرٍ، عَنْ مَعْنٍ، قَالَ سَمِعْتُ أَبِي قَالَ، سَأَلْتُ مَسْرُوقًا مَنْ آذَنَ النَّبِيَّ صلى الله عليه وسلم بِالْجِنِّ لَيْلَةَ اسْتَمَعُوا الْقُرْآنَ فَقَالَ حَدَّثَنِي أَبُوكَ - يَعْنِي ابْنَ مَسْعُودٍ - أَنَّهُ آذَنَتْهُ بِهِمْ شَجَرَةٌ ‏.‏\hadithno{1011}\hadithtrans{Ma'n reported.. I heard it from my father who said:I asked Masruq who informed the Messenger of Allah (ﷺ) about the night when they heard the Qur'an. He said: Your father, Ibn Mas'ud, narrated it to me that a tree informed him about that}}
\hadithdefcmd{muslim}{1012}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ الْحَجَّاجِ، - يَعْنِي الصَّوَّافَ - عَنْ يَحْيَى، - وَهُوَ ابْنُ أَبِي كَثِيرٍ - عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، وَأَبِي، سَلَمَةَ عَنْ أَبِي قَتَادَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِنَا فَيَقْرَأُ فِي الظُّهْرِ وَالْعَصْرِ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ بِفَاتِحَةِ الْكِتَابِ وَسُورَتَيْنِ وَيُسْمِعُنَا الآيَةَ أَحْيَانًا وَكَانَ يُطَوِّلُ الرَّكْعَةَ الأُولَى مِنَ الظُّهْرِ وَيُقَصِّرُ الثَّانِيَةَ وَكَذَلِكَ فِي الصُّبْحِ ‏.‏\hadithno{1012}\hadithtrans{Abu Qatada reported:The Messenger of Allah (ﷺ) led us in prayer and recited in the first two rak'ahs of the noon and afternoon prayers Surat al-Fitiha and two (other) surahs. And he would sometimes recite loud enough for us the verses. He would prolong the first rak'ah more than the second. And he acted similarly in the morning prayer}}
\hadithdefcmd{muslim}{1013}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا هَمَّامٌ، وَأَبَانُ بْنُ يَزِيدَ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ مِنَ الظُّهْرِ وَالْعَصْرِ بِفَاتِحَةِ الْكِتَابِ وَسُورَةٍ وَيُسْمِعُنَا الآيَةَ أَحْيَانًا وَيَقْرَأُ فِي الرَّكْعَتَيْنِ الأُخْرَيَيْنِ بِفَاتِحَةِ الْكِتَابِ ‏.‏\hadithno{1013}\hadithtrans{Abu Qatada reported it on the authority of his father:The Messenger of Allah (ﷺ) would recite in the first two rak'ahs of the noon and afternoon prayers the opening chapter of the Book and another surah. He would sometimes recite loud enough to make audible to us the verse and would recite in the last two rak'ahs Surat al-Faitiha (only)}}
\hadithdefcmd{muslim}{1014}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ جَمِيعًا عَنْ هُشَيْمٍ، - قَالَ يَحْيَى أَخْبَرَنَا هُشَيْمٌ، - عَنْ مَنْصُورٍ، عَنِ الْوَلِيدِ بْنِ مُسْلِمٍ، عَنْ أَبِي الصِّدِّيقِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كُنَّا نَحْزِرُ قِيَامَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الظُّهْرِ وَالْعَصْرِ فَحَزَرْنَا قِيَامَهُ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ مِنَ الظُّهْرِ قَدْرَ قِرَاءَةِ الم تَنْزِيلُ السَّجْدَةِ وَحَزَرْنَا قِيَامَهُ فِي الأُخْرَيَيْنِ قَدْرَ النِّصْفِ مِنْ ذَلِكَ وَحَزَرْنَا قِيَامَهُ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ مِنَ الْعَصْرِ عَلَى قَدْرِ قِيَامِهِ فِي الأُخْرَيَيْنِ مِنَ الظُّهْرِ وَفِي الأُخْرَيَيْنِ مِنَ الْعَصْرِ عَلَى النِّصْفِ مِنْ ذَلِكَ ‏.‏ وَلَمْ يَذْكُرْ أَبُو بَكْرٍ فِي رِوَايَتِهِ الم تَنْزِيلُ وَقَالَ قَدْرَ ثَلاَثِينَ آيَةً ‏.‏\hadithno{1014}\hadithtrans{Abu Sa'id al-Khudri reported:We used to estimate how long Allah's Messenger (ﷺ) stood in the noon and afternoon prayers, and we estimated hat he stood in the first two rak'ahs of the noon prayer as long as it takes to recite Alif Lam Mim, Tanzil, i. e. as-Sajda. We estimated that he stood half that time in the last two rak'ahs; that he stood in the first two of the afternoon as long as he did in the last two at noon; and in the last two of the afternoon prayer about half that time. Abu Bakr in his narration has made no mention of Alif Lam Mim, Tanzil, but said: As long as it takes to recite thirty verses}}
\hadithdefcmd{muslim}{1015}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مَنْصُورٍ، عَنِ الْوَلِيدِ أَبِي بِشْرٍ، عَنْ أَبِي الصِّدِّيقِ النَّاجِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي صَلاَةِ الظُّهْرِ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ فِي كُلِّ رَكْعَةٍ قَدْرَ ثَلاَثِينَ آيَةً وَفِي الأُخْرَيَيْنِ قَدْرَ خَمْسَ عَشَرَةَ آيَةً أَوْ قَالَ نِصْفَ ذَلِكَ وَفِي الْعَصْرِ فِي الرَّكْعَتَيْنِ الأُولَيَيْنِ فِي كُلِّ رَكْعَةٍ قَدْرَ قِرَاءَةِ خَمْسَ عَشْرَةَ آيَةً وَفِي الأُخْرَيَيْنِ قَدْرَ نِصْفِ ذَلِكَ ‏.‏\hadithno{1015}\hadithtrans{Abu Sa'id al-Khudri reported:The Apostle of Allah (ﷺ) used to recite in every rak'ah of the first two rak'ahs of the noon prayer about thirty verses and in the last two about fifteen verses or half (of the first rak'ah) and in every rak'ah of the 'Asr prayer of the first two rak'ahs about fifteen verses and in the last two verses half (of the first ones)}}
\hadithdefcmd{muslim}{1016}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، أَنَّ أَهْلَ الْكُوفَةِ، شَكَوْا سَعْدًا إِلَى عُمَرَ بْنِ الْخَطَّابِ فَذَكَرُوا مِنْ صَلاَتِهِ فَأَرْسَلَ إِلَيْهِ عُمَرُ فَقَدِمَ عَلَيْهِ فَذَكَرَ لَهُ مَا عَابُوهُ بِهِ مِنْ أَمْرِ الصَّلاَةِ فَقَالَ إِنِّي لأُصَلِّي بِهِمْ صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا أَخْرِمُ عَنْهَا إِنِّي لأَرْكُدُ بِهِمْ فِي الأُولَيَيْنِ وَأَحْذِفُ فِي الأُخْرَيَيْنِ ‏.‏ فَقَالَ ذَاكَ الظَّنُّ بِكَ أَبَا إِسْحَاقَ ‏.‏\hadithno{1016}\hadithtrans{Jabir b. Samura reported:The people of Kufa complained to Umar b. Khattab about Sa'd and they made a mention of his prayer. 'Umar sent for him. He came to him. He ('Umar) told him that the people had found fault with his prayer. He said: I lead them in prayer in accorance with the prayer of the Messenger of Allah (ﷺ). I make no decrease in it. I make them stand for a longer time in the first two (rak'ahs) and shorten it in the last two. Upon this 'Umar remarked: This is what I deemed of thee, O Abu Ishaq}}
\hadithdefcmd{muslim}{1017}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنْ جَرِيرٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{1017}\hadithtrans{This hadith his been narrated by 'Abu al-Malik with the same chain of transmitters}}
\hadithdefcmd{muslim}{1018}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عَوْنٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ سَمُرَةَ، قَالَ عُمَرُ لِسَعْدٍ قَدْ شَكَوْكَ فِي كُلِّ شَىْءٍ حَتَّى فِي الصَّلاَةِ ‏.‏ قَالَ أَمَّا أَنَا فَأَمُدُّ فِي الأُولَيَيْنِ وَأَحْذِفُ فِي الأُخْرَيَيْنِ وَمَا آلُو مَا اقْتَدَيْتُ بِهِ مِنْ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ ذَاكَ الظَّنُّ بِكَ ‏.‏ أَوْ ذَاكَ ظَنِّي بِكَ ‏.‏\hadithno{1018}\hadithtrans{Jabir b. Samura reported:'Umar said to Sa'd: They complain against you in every matter, even in prayer. He (Sa'd) said: I prolong (standing) in the first two (rak'ahs) and shorten it in the last two, and I make no negligence in following the prayer of the Messenger of Allah (ﷺ). He ('Umar) remarked: This is what is expected of you, or, that is what I deemed of you}}
\hadithdefcmd{muslim}{1019}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ بِشْرٍ، عَنْ مِسْعَرٍ، عَنْ عَبْدِ الْمَلِكِ، وَأَبِي، عَوْنٍ عَنْ جَابِرِ بْنِ سَمُرَةَ، بِمَعْنَى حَدِيثِهِمْ وَزَادَ فَقَالَ تُعَلِّمُنِي الأَعْرَابُ بِالصَّلاَةِ\hadithno{1019}\hadithtrans{This hadith is narrated by Jabir b. Samura but with the addition of these words:" (Sa'd said): These bedouins presume to teach me prayer}}
\hadithdefcmd{muslim}{1020}{حَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا الْوَلِيدُ، - يَعْنِي ابْنَ مُسْلِمٍ - عَنْ سَعِيدٍ، - وَهُوَ ابْنُ عَبْدِ الْعَزِيزِ - عَنْ عَطِيَّةَ بْنِ قَيْسٍ، عَنْ قَزْعَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ لَقَدْ كَانَتْ صَلاَةُ الظُّهْرِ تُقَامُ فَيَذْهَبُ الذَّاهِبُ إِلَى الْبَقِيعِ فَيَقْضِي حَاجَتَهُ ثُمَّ يَتَوَضَّأُ ثُمَّ يَأْتِي وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي الرَّكْعَةِ الأُولَى مِمَّا يُطَوِّلُهَا ‏.‏\hadithno{1020}\hadithtrans{Abu Sa'id al-Khudri reported:The noon prayer would start and one would go to al-Baqi' and after having relieved himself he would perform ablution and then come, while the Messenger of Allah (ﷺ) would be in the first rak'ah, because he would prolong it so much}}
\hadithdefcmd{muslim}{1021}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ رَبِيعَةَ، قَالَ حَدَّثَنِي قَزْعَةُ، قَالَ أَتَيْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ وَهُوَ مَكْثُورٌ عَلَيْهِ فَلَمَّا تَفَرَّقَ النَّاسُ عَنْهُ قُلْتُ إِنِّي لاَ أَسْأَلُكَ عَمَّا يَسْأَلُكَ هَؤُلاَءِ عَنْهُ - قُلْتُ - أَسْأَلُكَ عَنْ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ مَا لَكَ فِي ذَاكَ مِنْ خَيْرٍ ‏.‏ فَأَعَادَهَا عَلَيْهِ فَقَالَ كَانَتْ صَلاَةُ الظُّهْرِ تُقَامُ فَيَنْطَلِقُ أَحَدُنَا إِلَى الْبَقِيعِ فَيَقْضِي حَاجَتَهُ ثُمَّ يَأْتِي أَهْلَهُ فَيَتَوَضَّأُ ثُمَّ يَرْجِعُ إِلَى الْمَسْجِدِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي الرَّكْعَةِ الأُولَى ‏.‏\hadithno{1021}\hadithtrans{Qaz'a reported:I came to Abu Sa'id al-Khudri and he was surrounded by people. When the people departed from him I said: I am not going to ask you what these people have been asking you. I want to ask you about the prayer of the Messenger of Allah (ﷺ). He (Abu Sa'id) said: There is no good for you in this. He (Qaz'a), however, repeated (his demand). He then said: The noon prayer would start and one of us would go to Baqi' and, having relieved himself, would come to his home, then perform ablution and go to the mosque, and (he would find) The Messenger of Allah (ﷺ) in the first rak'ah}}
\hadithdefcmd{muslim}{1022}{وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، عَنِ ابْنِ جُرَيْجٍ، ح قَالَ وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، - وَتَقَارَبَا فِي اللَّفْظِ - حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ عَبَّادِ بْنِ جَعْفَرٍ، يَقُولُ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ سُفْيَانَ، وَعَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ الْعَاصِ، وَعَبْدُ اللَّهِ بْنُ الْمُسَيَّبِ الْعَابِدِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ السَّائِبِ، قَالَ صَلَّى لَنَا النَّبِيُّ صلى الله عليه وسلم الصُّبْحَ بِمَكَّةَ فَاسْتَفْتَحَ سُورَةَ الْمُؤْمِنِينَ حَتَّى جَاءَ ذِكْرُ مُوسَى وَهَارُونَ أَوْ ذِكْرُ عِيسَى - مُحَمَّدُ بْنُ عَبَّادٍ يَشُكُّ أَوِ اخْتَلَفُوا عَلَيْهِ - أَخَذَتِ النَّبِيَّ صلى الله عليه وسلم سَعْلَةٌ فَرَكَعَ وَعَبْدُ اللَّهِ بْنُ السَّائِبِ حَاضِرٌ ذَلِكَ ‏.‏ وَفِي حَدِيثِ عَبْدِ الرَّزَّاقِ فَحَذَفَ فَرَكَعَ ‏.‏ وَفِي حَدِيثِهِ وَعَبْدُ اللَّهِ بْنُ عَمْرٍو ‏.‏ وَلَمْ يَقُلِ ابْنِ الْعَاصِ ‏.‏\hadithno{1022}\hadithtrans{Abdullah b. Sa'id reported:The Apostle of Allah (ﷺ) led us in the morning prayer in Mecca and began Sarat al-Mu'minin (xxiii ) but when he came to the mention of Moses and Aaron (verse. 45) or to the mention of Jesus (verse 50), a cough got the better of him, and he bowed. 'Abdullah b. Sa'ib was present there, and in the hadith narrated by Abd al-Razzaq (the words are): He cut short (the recitation) and bowed}}
\hadithdefcmd{muslim}{1023}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، ح قَالَ وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنِي أَبُو كُرَيْبٍ، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا ابْنُ بِشْرٍ، عَنْ مِسْعَرٍ، قَالَ حَدَّثَنِي الْوَلِيدُ بْنُ سَرِيعٍ، عَنْ عَمْرِو بْنِ حُرَيْثٍ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ فِي الْفَجْرِ ‏\{‏ وَاللَّيْلِ إِذَا عَسْعَسَ‏\}‏\hadithno{1023}\hadithtrans{Amr b. Huwairith reported:I heard the Messenger of Allah (ﷺ) recite in the morning prayer" Wa'l-lail-i-idhd 'As'asa" (ixxxi)}}
\hadithdefcmd{muslim}{1024}{حَدَّثَنِي أَبُو كَامِلٍ الْجَحْدَرِيُّ، فُضَيْلُ بْنُ حُسَيْنٍ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ قُطْبَةَ بْنِ مَالِكٍ، قَالَ صَلَّيْتُ وَصَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَرَأَ ‏\{‏ ق وَالْقُرْآنِ الْمَجِيدِ‏\}‏ حَتَّى قَرَأَ ‏\{‏ وَالنَّخْلَ بَاسِقَاتٍ‏\}‏ قَالَ فَجَعَلْتُ أُرَدِّدُهَا وَلاَ أَدْرِي مَا قَالَ ‏.‏\hadithno{1024}\hadithtrans{Qutba b. Malik reported:I said prayer and the Messenger of Allah (ﷺ) led it and he recited" Qaf. (I.). By the Glorious Qur'an," till he recited" and the tall palm trees" (l. 10). I wanted to repeat it but I could not follow its significance}}
\hadithdefcmd{muslim}{1025}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَرِيكٌ، وَابْنُ، عُيَيْنَةَ ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ قُطْبَةَ بْنِ مَالِكٍ، سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقْرَأُ فِي الْفَجْرِ ‏\{‏ وَالنَّخْلَ بَاسِقَاتٍ لَهَا طَلْعٌ نَضِيدٌ‏\}‏\hadithno{1025}\hadithtrans{Qutba b. Malik reported that he had heard the Messenger of Allah (ﷺ) reciting in the morning prayer this:" And the tall palm trees having flower spikes piled one above another" (Al-Qur'an 50:)}}
\hadithdefcmd{muslim}{1026}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ عَمِّهِ، أَنَّهُ صَلَّى مَعَ النَّبِيِّ صلى الله عليه وسلم الصُّبْحَ فَقَرَأَ فِي أَوَّلِ رَكْعَةٍ ‏\{‏ وَالنَّخْلَ بَاسِقَاتٍ لَهَا طَلْعٌ نَضِيدٌ‏\}‏ وَرُبَّمَا قَالَ ‏\{‏ ق‏\}‏ ‏.‏\hadithno{1026}\hadithtrans{Ziyad b. 'Ilaqa reported it on the authority of his uncle that he said the morning prayer with the Messenger of Allah (ﷺ) and he recited in the first rak'ah:"And the tall palm trees having flower spikes piled one above another (l. 10) or perhaps Surah Qaf}}
\hadithdefcmd{muslim}{1027}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، حَدَّثَنَا سِمَاكُ بْنُ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي الْفَجْرِ بِـ ‏\{‏ ق وَالْقُرْآنِ الْمَجِيدِ‏\}‏ وَكَانَ صَلاَتُهُ بَعْدُ تَخْفِيفًا ‏.‏\hadithno{1027}\hadithtrans{Jabir b. Samura reported:The Apostle of Allah (ﷺ) used to recite in the morning prayer" Qaf. By the Glorious Quran." and his prayer afterward shortened}}
\hadithdefcmd{muslim}{1028}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ رَافِعٍ، - وَاللَّفْظُ لاِبْنِ رَافِعٍ - قَالاَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا زُهَيْرٌ، عَنْ سِمَاكٍ، قَالَ سَأَلْتُ جَابِرَ بْنَ سَمُرَةَ عَنْ صَلاَةِ النَّبِيِّ، صلى الله عليه وسلم فَقَالَ كَانَ يُخَفِّفُ الصَّلاَةَ وَلاَ يُصَلِّي صَلاَةَ هَؤُلاَءِ ‏.‏ قَالَ وَأَنْبَأَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي الْفَجْرِ بـ ‏\{‏ ق وَالْقُرْآنِ‏\}‏ وَنَحْوِهَا ‏.‏\hadithno{1028}\hadithtrans{Simak asked Jabir b. Samura about the prayer of the Apostle (ﷺ). He said:He (the Holy Prophet) shortened the prayer and he did not pray like these people then, and he informed me that the Messenger of Allah (ﷺ) used to recite" Qaf. By the (Glorious) Qur'an," and a passage of similar length}}
\hadithdefcmd{muslim}{1029}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَقْرَأُ فِي الظُّهْرِ بِـ ‏\{‏ اللَّيْلِ إِذَا يَغْشَى‏\}‏ وَفِي الْعَصْرِ نَحْوَ ذَلِكَ وَفِي الصُّبْحِ أَطْوَلَ مِنْ ذَلِكَ ‏.‏\hadithno{1029}\hadithtrans{Jabir b. Samura reported:The Apostle of Allah (ﷺ) used to recite in the noon prayer:" By the night when it envelopes" (xcii.), and in the afternoon like this, but he prolonged the morning prayer as compared to that (noon and afternoon prayers)}}
\hadithdefcmd{muslim}{1030}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، عَنْ شُعْبَةَ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، ‏.‏ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي الظُّهْرِ بِـ ‏\{‏ سَبِّحِ اسْمَ رَبِّكَ الأَعْلَى‏\}‏ وَفِي الصُّبْحِ بِأَطْوَلَ مِنْ ذَلِكَ ‏.‏\hadithno{1030}\hadithtrans{Jabir b. Samura reported:The Apostle of Allah (ﷺ) used to recite in the noon prayer:" Glorify the name of thy Most High Lord in the morning prayer longer than this" (lxxxvii)}}
\hadithdefcmd{muslim}{1031}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنِ التَّيْمِيِّ، عَنْ أَبِي الْمِنْهَالِ، عَنْ أَبِي بَرْزَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي صَلاَةِ الْغَدَاةِ مِنَ السِّتِّينَ إِلَى الْمِائَةِ ‏.‏\hadithno{1031}\hadithtrans{Abu Barza reported:The Messenger of Allah (ﷺ) used to recite in the morning prayer from sixty to one hundred verses}}
\hadithdefcmd{muslim}{1032}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي الْمِنْهَالِ، عَنْ أَبِي بَرْزَةَ الأَسْلَمِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي الْفَجْرِ مَا بَيْنَ السِّتِّينَ إِلَى الْمِائَةِ آيَةً ‏.‏\hadithno{1032}\hadithtrans{Abu Barza Aslami reported:The Messenger of Allah (ﷺ) used to recite from sixty to one hundred verses in the morning prayer}}
\hadithdefcmd{muslim}{1033}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّ أُمَّ الْفَضْلِ بِنْتَ الْحَارِثِ سَمِعَتْهُ وَهُوَ، يَقْرَأُ ‏\{‏ وَالْمُرْسَلاَتِ عُرْفًا‏\}‏ فَقَالَتْ يَا بُنَىَّ لَقَدْ ذَكَّرْتَنِي بِقِرَاءَتِكَ هَذِهِ السُّورَةَ إِنَّهَا لآخِرُ مَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَأُ بِهَا فِي الْمَغْرِبِ ‏.‏\hadithno{1033}\hadithtrans{Ibn Abbas reported:Umm al-Fadl daughter of al-Harith heard him reciting:" By those sent forth to spread goodness" (lxxvii.). (Upon this) she remarked: O my son, you reminded me by the recitation of this surah (the fact) that it was the last surah that I heard from the Messenger of Allah (ﷺ) and he recited it in the evening prayer}}
\hadithdefcmd{muslim}{1034}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، قَالاَ حَدَّثَنَا سُفْيَانُ، ح قَالَ وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح قَالَ وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، ح قَالَ وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ وَزَادَ فِي حَدِيثِ صَالِحٍ ثُمَّ مَا صَلَّى بَعْدُ حَتَّى قَبَضَهُ اللَّهُ عَزَّ وَجَلَّ ‏.‏\hadithno{1034}\hadithtrans{This hadith has been narrated by Zuhri with the same chain of transmitters but with this addition:" And he did not lead the player after this till his death}}
\hadithdefcmd{muslim}{1035}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَأُ بِالطُّورِ فِي الْمَغْرِبِ ‏.‏\hadithno{1035}\hadithtrans{Jubair b. Mut'im reported:I heard the Messenger of Allah (ﷺ) reciting Surat al-Tur (Mountain) (lii) in the evening prayer}}
\hadithdefcmd{muslim}{1036}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، ح قَالَ وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح قَالَ وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏\hadithno{1036}\hadithtrans{This hadith has been narrated by Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{1037}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، قَالَ سَمِعْتُ الْبَرَاءَ، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ فِي سَفَرٍ فَصَلَّى الْعِشَاءَ الآخِرَةَ فَقَرَأَ فِي إِحْدَى الرَّكْعَتَيْنِ ‏\{‏ وَالتِّينِ وَالزَّيْتُونِ‏\}‏\hadithno{1037}\hadithtrans{Adi reported:I heard al-Bara' narrating it from the Messenger of Allah (ﷺ) that while in a journey he said the night prayer and recited in one of the two rak'ahs:" By the Fig and the Olive" (Su'rah xcv)}}
\hadithdefcmd{muslim}{1038}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ - عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، أَنَّهُ قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْعِشَاءَ فَقَرَأَ بِالتِّينِ وَالزَّيْتُونِ ‏.‏\hadithno{1038}\hadithtrans{Al-Bara' b. 'Azib reported that he said prayer with the Messenger of Allah (ﷺ) and he recited:" By the Fig and the Olive}}
\hadithdefcmd{muslim}{1039}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا مِسْعَرٌ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم قَرَأَ فِي الْعِشَاءِ بِالتِّينِ وَالزَّيْتُونِ ‏.‏ فَمَا سَمِعْتُ أَحَدًا أَحْسَنَ صَوْتًا مِنْهُ ‏.‏\hadithno{1039}\hadithtrans{Al-Bara' b. 'Azib reported:I heard the Messenger of Allah (ﷺ) reciting in the night prayer:" By the Fig and the Olive," and I have never heard anyone with a sweeter voice than he}}
\hadithdefcmd{muslim}{1040}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ جَابِرٍ، قَالَ كَانَ مُعَاذٌ يُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ يَأْتِي فَيَؤُمُّ قَوْمَهُ فَصَلَّى لَيْلَةً مَعَ النَّبِيِّ صلى الله عليه وسلم الْعِشَاءَ ثُمَّ أَتَى قَوْمَهُ فَأَمَّهُمْ فَافْتَتَحَ بِسُورَةِ الْبَقَرَةِ فَانْحَرَفَ رَجُلٌ فَسَلَّمَ ثُمَّ صَلَّى وَحْدَهُ وَانْصَرَفَ فَقَالُوا لَهُ أَنَافَقْتَ يَا فُلاَنُ قَالَ لاَ وَاللَّهِ وَلآتِيَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَلأُخْبِرَنَّهُ ‏.‏ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّا أَصْحَابُ نَوَاضِحَ نَعْمَلُ بِالنَّهَارِ وَإِنَّ مُعَاذًا صَلَّى مَعَكَ الْعِشَاءَ ثُمَّ أَتَى فَافْتَتَحَ بِسُورَةِ الْبَقَرَةِ ‏.‏ فَأَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى مُعَاذٍ فَقَالَ ‏"‏ يَا مُعَاذُ أَفَتَّانٌ أَنْتَ اقْرَأْ بِكَذَا وَاقْرَأْ بِكَذَا ‏"‏ ‏.‏ قَالَ سُفْيَانُ فَقُلْتُ لِعَمْرٍو إِنَّ أَبَا الزُّبَيْرِ حَدَّثَنَا عَنْ جَابِرٍ أَنَّهُ قَالَ ‏"‏ اقْرَأْ وَالشَّمْسِ وَضُحَاهَا ‏.‏ وَالضُّحَى ‏.‏ وَاللَّيْلِ إِذَا يَغْشَى ‏.‏ وَسَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏"‏ ‏.‏ فَقَالَ عَمْرٌو نَحْوَ هَذَا ‏.‏\hadithno{1040}\hadithtrans{Jabir reported that Mu'adh b. Jabal used to pray with the Apostle (ﷺ), then came and led his people in prayer. One night he said the night prayer with the Messenger of Allah (ﷺ). He then came to his people and led them in prayer beginning with Surat al-Baqara. A man turned aside, pronounced the taslim (salutation for concluding the prayer), then prayed alone and departed. The people said to him:Have you become a hypocrite, so and so? He said: I swear by Allah that I have not, but I will certainly go to Allah's Messenger (ﷺ) and will inform (him) about this. He then came to the Messenger of Allah (ﷺ) and said: Messenger of Allah, we look after camels used for watering and work by day. Mu'adh said the night prayer with you. He then came and began with Surat al-Baqara. Allah's Messenger (ﷺ) then turned to Mu'adh and said: Are you there to (put the people) to trial? Recite such and recite such (and such a surah). It is transmitted on the authority of Jabir, as told by Sufyan, that he (the Holy Prophet) had said: "By the sun and its morning brightness" (Surah xci), "By brightness" (Surah xciii), "By the night when it spreads" (Surah xcii), and "Glorify the name of thy most high Lord" (Surah lxxxii)}}
\hadithdefcmd{muslim}{1041}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح قَالَ وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّهُ قَالَ صَلَّى مُعَاذُ بْنُ جَبَلٍ الأَنْصَارِيُّ لأَصْحَابِهِ الْعِشَاءَ فَطَوَّلَ عَلَيْهِمْ فَانْصَرَفَ رَجُلٌ مِنَّا فَصَلَّى فَأُخْبِرَ مُعَاذٌ عَنْهُ فَقَالَ إِنَّهُ مُنَافِقٌ ‏.‏ فَلَمَّا بَلَغَ ذَلِكَ الرَّجُلَ دَخَلَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ مَا قَالَ مُعَاذٌ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَتُرِيدُ أَنْ تَكُونَ فَتَّانًا يَا مُعَاذُ إِذَا أَمَمْتَ النَّاسَ فَاقْرَأْ بِالشَّمْسِ وَضُحَاهَا ‏.‏ وَسَبِّحِ اسْمَ رَبِّكَ الأَعْلَى ‏.‏ وَاقْرَأْ بِاسْمِ رَبِّكَ ‏.‏ وَاللَّيْلِ إِذَا يَغْشَى ‏"‏ ‏.‏\hadithno{1041}\hadithtrans{Jabir reported:'Mu'adh b. Jabal al-Ansari led his companions in the night prayer and prolonged it for them. A person amongst us said prayer (after having separated himself from the congregation). Mu'adh was informed of this, and he remarked that he was a hypocrite. When it (the remark) was conveyed to the man, he went to the Messenger of Allah (ﷺ) and informed him of what Mu'adh had said. Upon this the Messenger of Allah (ﷺ) said to him: Mu'adh, do you want to become a person putting (people) to trial? When you lead people in prayer, recite:" By the Sun and its morning brightness" (Surat ash-Shams)," Glorify the name of thy most high Lord" (Surat al-A`la) and" Read in the name of Lord" (Surat al-`Alaq), and" By the night when it spreads" (Surat al-Lail)}}
\hadithdefcmd{muslim}{1042}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ مَنْصُورٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ مُعَاذَ بْنَ جَبَلٍ، كَانَ يُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْعِشَاءَ الآخِرَةَ ثُمَّ يَرْجِعُ إِلَى قَوْمِهِ فَيُصَلِّي بِهِمْ تِلْكَ الصَّلاَةَ ‏.‏\hadithno{1042}\hadithtrans{Jabir b. 'Abdullah reported:Mu'adh b. Jabal said the night prayer with the Messenger of Allah (ﷺ) and then returned to his people and then led them in this prayer}}
\hadithdefcmd{muslim}{1043}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو الرَّبِيعِ الزَّهْرَانِيُّ، قَالَ أَبُو الرَّبِيعِ حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ مُعَاذٌ يُصَلِّي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الْعِشَاءَ ثُمَّ يَأْتِي مَسْجِدَ قَوْمِهِ فَيُصَلِّي بِهِمْ ‏.‏\hadithno{1043}\hadithtrans{Jabir b. Abdullah reported:Mu'adh said the night prayer with the Messenger of Allah (ﷺ). He then came to the mosque of his people and led them in prayer}}
\hadithdefcmd{muslim}{1044}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسٍ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنِّي لأَتَأَخَّرُ عَنْ صَلاَةِ الصُّبْحِ مِنْ أَجْلِ فُلاَنٍ مِمَّا يُطِيلُ بِنَا ‏.‏ فَمَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم غَضِبَ فِي مَوْعِظَةٍ قَطُّ أَشَدَّ مِمَّا غَضِبَ يَوْمَئِذٍ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ إِنَّ مِنْكُمْ مُنَفِّرِينَ فَأَيُّكُمْ أَمَّ النَّاسَ فَلْيُوجِزْ فَإِنَّ مِنْ وَرَائِهِ الْكَبِيرَ وَالضَّعِيفَ وَذَا الْحَاجَةِ ‏"‏ ‏.‏\hadithno{1044}\hadithtrans{Abu Mas'ud al-Ainsari reported:A person came to the Messenger of Allah (ﷺ) and said: I keep away from the morning prayer on account of such and such (a man), because; he keeps us so long. I never saw God's Messenger (ﷺ) more angry when giving an exhortation than he was that day. He said: 0 people, some of you are scaring people away. So whoever of you leads the people in prayer he must be brief, for behind him are the weak, the aged, and the people who have (argent) business to attend}}
\hadithdefcmd{muslim}{1045}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمٌ، وَوَكِيعٌ، ح قَالَ وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، كُلُّهُمْ عَنْ إِسْمَاعِيلَ، فِي هَذَا الإِسْنَادِ بِمِثْلِ حَدِيثِ هُشَيْمٍ ‏.‏\hadithno{1045}\hadithtrans{This hadith like one narrated by Hashalm has been narrated from Isma'il with the same chain of transmitters}}
\hadithdefcmd{muslim}{1046}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - وَهُوَ ابْنُ عَبْدِ الرَّحْمَنِ الْحِزَامِيُّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أَمَّ أَحَدُكُمُ النَّاسَ فَلْيُخَفِّفْ فَإِنَّ فِيهِمُ الصَّغِيرَ وَالْكَبِيرَ وَالضَّعِيفَ وَالْمَرِيضَ فَإِذَا صَلَّى وَحْدَهُ فَلْيُصَلِّ كَيْفَ شَاءَ ‏"‏ ‏.‏\hadithno{1046}\hadithtrans{Abu Huraira reported:The Apostle of Allah (ﷺ) said: When any one of you leads the people in prayer, he should be brief for among them are the young and the aged, the weak and the sick. But when one of you prays by himself, he may (prolong) as he likes}}
\hadithdefcmd{muslim}{1047}{حَدَّثَنَا ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ مُحَمَّدٍ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا مَا قَامَ أَحَدُكُمْ لِلنَّاسِ فَلْيُخَفِّفِ الصَّلاَةَ فَإِنَّ فِيهِمُ الْكَبِيرَ وَفِيهِمُ الضَّعِيفَ وَإِذَا قَامَ وَحْدَهُ فَلْيُطِلْ صَلاَتَهُ مَا شَاءَ ‏"‏ ‏.‏\hadithno{1047}\hadithtrans{Hammam b. Munabbih reported:This is what Abu Huraira transmitted to us from Muhammad the Messenger of Allah (ﷺ), and he narrated (some) ahadith out of (these narrations and one of them is this): The Messenger of Allah (ﷺ) said: When any one of you stands to lead people In prayer, he should shorten it, for amongst them are the aged, and amongst them are the weak, but when he prays by himself, he may prolong his prayer as he likes}}
\hadithdefcmd{muslim}{1048}{وَحَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا صَلَّى أَحَدُكُمْ لِلنَّاسِ فَلْيُخَفِّفْ فَإِنَّ فِي النَّاسِ الضَّعِيفَ وَالسَّقِيمَ وَذَا الْحَاجَةِ ‏"‏ ‏.‏\hadithno{1048}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: When any one of you leads people in prayer, he must shorten it for among them are the weak, the infirm and those who have business to attend}}
\hadithdefcmd{muslim}{1049}{وَحَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، حَدَّثَنِي اللَّيْثُ بْنُ سَعْدٍ، حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي أَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ - بَدَلَ السَّقِيمِ - الْكَبِيرَ ‏.‏\hadithno{1049}\hadithtrans{Abu Bakr b. 'Abd al-Rahman reported that he had heard Abu Huraira say that the Messenger of Allah (ﷺ) said like it, but he substituted" the aged" for 'the infirm}}
\hadithdefcmd{muslim}{1050}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا مُوسَى بْنُ طَلْحَةَ، حَدَّثَنِي عُثْمَانُ بْنُ أَبِي الْعَاصِ الثَّقَفِيُّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهُ ‏"‏ أُمَّ قَوْمَكَ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أَجِدُ فِي نَفْسِي شَيْئًا ‏.‏ قَالَ ‏"‏ ادْنُهْ ‏"‏ ‏.‏ فَجَلَّسَنِي بَيْنَ يَدَيْهِ ثُمَّ وَضَعَ كَفَّهُ فِي صَدْرِي بَيْنَ ثَدْيَىَّ ثُمَّ قَالَ ‏"‏ تَحَوَّلْ ‏"‏ ‏.‏ فَوَضَعَهَا فِي ظَهْرِي بَيْنَ كَتِفَىَّ ثُمَّ قَالَ ‏"‏ أُمَّ قَوْمَكَ فَمَنْ أَمَّ قَوْمًا فَلْيُخَفِّفْ فَإِنَّ فِيهِمُ الْكَبِيرَ وَإِنَّ فِيهِمُ الْمَرِيضَ وَإِنَّ فِيهِمُ الضَّعِيفَ وَإِنَّ فِيهِمْ ذَا الْحَاجَةِ وَإِذَا صَلَّى أَحَدُكُمْ وَحْدَهُ فَلْيُصَلِّ كَيْفَ شَاءَ ‏"‏ ‏.‏\hadithno{1050}\hadithtrans{Uthman b. Abu'l-'As at-Thaqafi reported:The Apostle of Allah (ﷺ) said to him: Lead your people in prayer. I said: Messenger of Allah. I perceive something (disturbing) in my soul. He (the Holy Prophet) asked me to draw near him and making me sit down in front of him he placed his hand on my breast between my nipples. and then, telling me to turn round, he placed it on my back between my shoulders. He then said: Act as an Imam for your people. He who acts as Imam of the people, he must be brief, for among them are the aged, among them are the sick, among them are the weak, and among them are the people who have business to attend. But when any of you prays alone, he may pray as he likes}}
\hadithdefcmd{muslim}{1051}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، قَالَ حَدَّثَ عُثْمَانُ بْنُ أَبِي الْعَاصِ، قَالَ آخِرُ مَا عَهِدَ إِلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَمَمْتَ قَوْمًا فَأَخِفَّ بِهِمُ الصَّلاَةَ ‏"‏ ‏.‏\hadithno{1051}\hadithtrans{Uthman b. Abu'l-'As reported:The last thing which the Messenger of Allah (ﷺ) instructed me was: When you lead the people in prayer, be brief}}
\hadithdefcmd{muslim}{1052}{وَحَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، وَأَبُو الرَّبِيعِ الزَّهْرَانِيُّ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُوجِزُ فِي الصَّلاَةِ وَيُتِمُّ ‏.‏\hadithno{1052}\hadithtrans{Anas reported:The Apostle of Allah (ﷺ) used to be brief and perfect in prayer}}
\hadithdefcmd{muslim}{1053}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ، قُتَيْبَةُ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ مِنْ أَخَفِّ النَّاسِ صَلاَةً فِي تَمَامٍ ‏.‏\hadithno{1053}\hadithtrans{Anas reported:The Messenger of Allah (ﷺ) was among those whose prayers was brief and perfect}}
\hadithdefcmd{muslim}{1054}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالَ يَحْيَى بْنُ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ قَالَ مَا صَلَّيْتُ وَرَاءَ إِمَامٍ قَطُّ أَخَفَّ صَلاَةً وَلاَ أَتَمَّ صَلاَةً مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1054}\hadithtrans{Anas reported:I never prayed behind an Imam who was more brief and more perfect in prayer than the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1055}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ ثَابِتٍ الْبُنَانِيِّ، عَنْ أَنَسٍ، قَالَ أَنَسٌ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْمَعُ بُكَاءَ الصَّبِيِّ مَعَ أُمِّهِ وَهُوَ فِي الصَّلاَةِ فَيَقْرَأُ بِالسُّورَةِ الْخَفِيفَةِ أَوْ بِالسُّورَةِ الْقَصِيرَةِ ‏.‏\hadithno{1055}\hadithtrans{Anas reported:The Messenger of Allah (ﷺ) would listen to the crying of a lad in the company of his mother, in prayer, and he would recite a short surah or a small surah}}
\hadithdefcmd{muslim}{1056}{وَحَدَّثَنَا مُحَمَّدُ بْنُ مِنْهَالٍ الضَّرِيرُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي لأَدْخُلُ الصَّلاَةَ أُرِيدُ إِطَالَتَهَا فَأَسْمَعُ بُكَاءَ الصَّبِيِّ فَأُخَفِّفُ مِنْ شِدَّةِ وَجْدِ أُمِّهِ بِهِ ‏"‏ ‏.‏\hadithno{1056}\hadithtrans{Anas b. Malik reported the Messenger of Allah (ﷺ) having said:When I begin the prayer I Intend to make it long, but I hear a boy cry. ing; I then shorten it because of his mother's feelings}}
\hadithdefcmd{muslim}{1057}{وَحَدَّثَنَا حَامِدُ بْنُ عُمَرَ الْبَكْرَاوِيُّ، وَأَبُو كَامِلٍ فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ كِلاَهُمَا عَنْ أَبِي عَوَانَةَ، - قَالَ حَامِدٌ حَدَّثَنَا أَبُو عَوَانَةَ، - عَنْ هِلاَلِ بْنِ أَبِي حُمَيْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ رَمَقْتُ الصَّلاَةَ مَعَ مُحَمَّدٍ صلى الله عليه وسلم فَوَجَدْتُ قِيَامَهُ فَرَكْعَتَهُ فَاعْتِدَالَهُ بَعْدَ رُكُوعِهِ فَسَجْدَتَهُ فَجَلْسَتَهُ بَيْنَ السَّجْدَتَيْنِ فَسَجْدَتَهُ فَجَلْسَتَهُ مَا بَيْنَ التَّسْلِيمِ وَالاِنْصِرَافِ قَرِيبًا مِنَ السَّوَاءِ ‏.‏\hadithno{1057}\hadithtrans{Al-Bara' b. 'Azib reported:I noticed the prayer of Muhammad (ﷺ) and saw his Qiyam (standing), his bowing, and then going back to the standing posture after bowing, his prostration, his sitting between the two prostrations, and his prostration and sitting between salutation and going away, all these were nearly equal to one another}}
\hadithdefcmd{muslim}{1058}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ غَلَبَ عَلَى الْكُوفَةِ رَجُلٌ - قَدْ سَمَّاهُ - زَمَنَ ابْنِ الأَشْعَثِ فَأَمَرَ أَبَا عُبَيْدَةَ بْنَ عَبْدِ اللَّهِ أَنْ يُصَلِّيَ بِالنَّاسِ فَكَانَ يُصَلِّي فَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ قَامَ قَدْرَ مَا أَقُولُ اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ مِلْءَ السَّمَوَاتِ وَمِلْءَ الأَرْضِ وَمِلْءَ مَا شِئْتَ مِنْ شَىْءٍ بَعْدُ أَهْلَ الثَّنَاءِ وَالْمَجْدِ لاَ مَانِعَ لِمَا أَعْطَيْتَ وَلاَ مُعْطِيَ لِمَا مَنَعْتَ وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏.‏ قَالَ الْحَكَمُ فَذَكَرْتُ ذَلِكَ لِعَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى فَقَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ يَقُولُ كَانَتْ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَرُكُوعُهُ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ وَسُجُودُهُ وَمَا بَيْنَ السَّجْدَتَيْنِ قَرِيبًا مِنَ السَّوَاءِ ‏.‏ قَالَ شُعْبَةُ فَذَكَرْتُهُ لِعَمْرِو بْنِ مُرَّةَ فَقَالَ قَدْ رَأَيْتُ ابْنَ أَبِي لَيْلَى فَلَمْ تَكُنْ صَلاَتُهُ هَكَذَا ‏.‏\hadithno{1058}\hadithtrans{Hakam reported:There dominated in Kufa a man whose name was men- tioned as Zaman b. al-Ash'ath, who ordered Abu 'Ubaidah b. 'Abdullah to lead people in prayer and he accordingly used to lead them. Whenever he raised his head after bowing, he stood up equal to the time that I can recite (this supplication): O Allah! our Lord! unto Thee be the praise which would fill the heavens and the earth, and that which will please Thee besides them I Worthy art Thou of all praise and glory. None can prevent that which Thou bestowest, and none can bestow that whichthou preventest. And the greatness of the great will not avail him against Thee. Hakam (the narrator) said: I made a mention of that to Abd al-Rahman ibn Abi Laila who reported: I heard al-Bara' b. 'Azib say that the prayer of the Messenger of Allah (ﷺ) and his bowing, and when he lifted his head from bowing, and his prostration, and between the two prostrations (all these acts) were nearly proportionate. I made a mention of that to 'Ar b. Murrah and he said: I saw Ibn Abi Laili (saying the prayer), but his prayer was not like this}}
\hadithdefcmd{muslim}{1059}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، أَنَّ مَطَرَ بْنَ نَاجِيَةَ، لَمَّا ظَهَرَ عَلَى الْكُوفَةِ أَمَرَ أَبَا عُبَيْدَةَ أَنْ يُصَلِّيَ، بِالنَّاسِ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{1059}\hadithtrans{Hakam reported:When Matar b. Najiya dominated Kufa he ordered Abu Ubaida to lead people in prayer, and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{1060}{حَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ إِنِّي لاَ آلُو أَنْ أُصَلِّيَ بِكُمْ كَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِنَا ‏.‏ قَالَ فَكَانَ أَنَسٌ يَصْنَعُ شَيْئًا لاَ أَرَاكُمْ تَصْنَعُونَهُ كَانَ إِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ انْتَصَبَ قَائِمًا حَتَّى يَقُولَ الْقَائِلُ قَدْ نَسِيَ ‏.‏ وَإِذَا رَفَعَ رَأْسَهُ مِنَ السَّجْدَةِ مَكَثَ حَتَّى يَقُولَ الْقَائِلُ قَدْ نَسِيَ ‏.‏\hadithno{1060}\hadithtrans{Thabit reported it on the authority of Anas:While leading you in prayer I do not shorten anything in the prayer. I pray as I saw the Messenger of Allah (ﷺ) leading us. He (Thabit) said: Anas used to do that which I do not see you doing; when he lifted his head from bowing he stood up (so long) that one would say: He has forgotten (to baw down in prostration). And when he lifted his head from prostration, he stayed in that position, till someone would say: He has forgotten (to bow down in prostration for the second sajda)}}
\hadithdefcmd{muslim}{1061}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ الْعَبْدِيُّ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا ثَابِتٌ، عَنْ أَنَسٍ، قَالَ مَا صَلَّيْتُ خَلْفَ أَحَدٍ أَوْجَزَ صَلاَةً مِنْ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي تَمَامٍ كَانَتْ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم مُتَقَارِبَةً وَكَانَتْ صَلاَةُ أَبِي بَكْرٍ مُتَقَارِبَةً فَلَمَّا كَانَ عُمَرُ بْنُ الْخَطَّابِ مَدَّ فِي صَلاَةِ الْفَجْرِ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ قَامَ حَتَّى نَقُولَ قَدْ أَوْهَمَ ‏.‏ ثُمَّ يَسْجُدُ وَيَقْعُدُ بَيْنَ السَّجْدَتَيْنِ حَتَّى نَقُولَ قَدْ أَوْهَمَ ‏.‏\hadithno{1061}\hadithtrans{Thabit reported it on the authority of Anas:I have never said such a light and perfect prayer as I said behind the Messenger of Allah (ﷺ). The prayer of the Messenger. of Allah (ﷺ) was well balanced. And so too was the prayer of Abu Bakr well balanced. When it was the time of 'Umar b. al-Khattab he prolonged the morning prayer. When the Messenger of Allah (ﷺ) said: Allah listened to him who praised Him, he stood erect till we said: He has forgotten. He then prostrated and sat between two prostration till we said: He has forgotten}}
\hadithdefcmd{muslim}{1062}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، ح قَالَ وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، قَالَ حَدَّثَنِي الْبَرَاءُ، وَهُوَ غَيْرُ كَذُوبٍ أَنَّهُمْ كَانُوا يُصَلُّونَ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ لَمْ أَرَ أَحَدًا يَحْنِي ظَهْرَهُ حَتَّى يَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم جَبْهَتَهُ عَلَى الأَرْضِ ثُمَّ يَخِرُّ مَنْ وَرَاءَهُ سُجَّدًا ‏.‏\hadithno{1062}\hadithtrans{Al-Bara' (b. 'Azib), and he was no liar (but a truthful Companion of the Holy Prophet), reported:They used to say prayer behind the Messenger of Allah (ﷺ). I never saw anyone bending his back at the time when he (the Holy Prophet) raised his head, till the Messenger of Allah (ﷺ) placed his forehead on the ground. They then fell in prostration after him}}
\hadithdefcmd{muslim}{1063}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي أَبُو إِسْحَاقَ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنِي الْبَرَاءُ، - وَهُوَ غَيْرُ كَذُوبٍ - قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ لَمْ يَحْنِ أَحَدٌ مِنَّا ظَهْرَهُ حَتَّى يَقَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَاجِدًا ثُمَّ نَقَعُ سُجُودًا بَعْدَهُ ‏.‏\hadithno{1063}\hadithtrans{Al-Bara' reported, and he was no liar:When the Messenger of Allah (ﷺ) said: Allah listened to him who praised Him, none of us bent his back till he (the Holy Prophet) prostrated; we then, afterwards, went down in prostration}}
\hadithdefcmd{muslim}{1064}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ سَهْمٍ الأَنْطَاكِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُحَمَّدٍ أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ أَبِي إِسْحَاقَ الشَّيْبَانِيِّ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ يَزِيدَ، يَقُولُ عَلَى الْمِنْبَرِ حَدَّثَنَا الْبَرَاءُ، أَنَّهُمْ كَانُوا يُصَلُّونَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِذَا رَكَعَ رَكَعُوا وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ فَقَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ لَمْ نَزَلْ قِيَامًا حَتَّى نَرَاهُ قَدْ وَضَعَ وَجْهَهُ فِي الأَرْضِ ثُمَّ نَتَّبِعُهُ ‏.‏\hadithno{1064}\hadithtrans{Al-Bara' reported:They (the Companions) said prayer with the Messenger of Allah (ﷺ), and they bowed when he (the Holy Prophet) bowed. and when he raised his head after bowing, he pronounced:" Allah listened to him who praised Him," and we kept standing till we saw him placing his face on the ground and then we followed him}}
\hadithdefcmd{muslim}{1065}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا أَبَانٌ، وَغَيْرُهُ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنِ الْبَرَاءِ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم لاَ يَحْنُو أَحَدٌ مِنَّا ظَهْرَهُ حَتَّى نَرَاهُ قَدْ سَجَدَ ‏.‏ فَقَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ قَالَ حَدَّثَنَا الْكُوفِيُّونَ أَبَانٌ وَغَيْرُهُ قَالَ حَتَّى نَرَاهُ يَسْجُدُ ‏.‏\hadithno{1065}\hadithtrans{Al-Bara' reported:When we were (in prayer) with the Messenger of Allah Allah (ﷺ) none of us benfft his back till we saw he prostrated. Zuhair and others reported:" till we saw him prostrating}}
\hadithdefcmd{muslim}{1066}{حَدَّثَنَا مُحْرِزُ بْنُ عَوْنِ بْنِ أَبِي عَوْنٍ، حَدَّثَنَا خَلَفُ بْنُ خَلِيفَةَ الأَشْجَعِيُّ أَبُو أَحْمَدَ، عَنِ الْوَلِيدِ بْنِ سَرِيعٍ، مَوْلَى آلِ عَمْرِو بْنِ حُرَيْثٍ عَنْ عَمْرِو بْنِ حُرَيْثٍ، قَالَ صَلَّيْتُ خَلْفَ النَّبِيِّ صلى الله عليه وسلم الْفَجْرَ فَسَمِعْتُهُ يَقْرَأُ ‏\{‏ فَلاَ أُقْسِمُ بِالْخُنَّسِ * الْجَوَارِ الْكُنَّسِ‏\}‏ وَكَانَ لاَ يَحْنِي رَجُلٌ مِنَّا ظَهْرَهُ حَتَّى يَسْتَتِمَّ سَاجِدًا ‏.‏\hadithno{1066}\hadithtrans{Amr b. Huraith reported:I said the dawn prayer behind the Apostle of (ﷺ) and heard him reciting: 'Nay. I call to witness the stars, running their courses and setting" (al-Qur'an, lxxxi. 15-16) and Done of us bent his back till he completed prostration}}
\hadithdefcmd{muslim}{1067}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ عُبَيْدِ بْنِ الْحَسَنِ، عَنِ ابْنِ أَبِي أَوْفَى، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا رَفَعَ ظَهْرَهُ مِنَ الرُّكُوعِ قَالَ ‏ "‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ مِلْءَ السَّمَوَاتِ وَمِلْءَ الأَرْضِ وَمِلْءَ مَا شِئْتَ مِنْ شَىْءٍ بَعْدُ ‏"‏ ‏.‏\hadithno{1067}\hadithtrans{(Abdullah b ) Ibn Abi Aufa reported:When the Messenger of Allah (ﷺ) raised his back from the rukd' he pronounced: Allah listened to him who praised Him. O Allah! our Lord! unto Thee be praise that would fill the heavens and the earth and fill that which will please Thee besides them}}
\hadithdefcmd{muslim}{1068}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عُبَيْدِ بْنِ الْحَسَنِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْعُو بِهَذَا الدُّعَاءِ ‏ "‏ اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ مِلْءَ السَّمَوَاتِ وَمِلْءَ الأَرْضِ وَمِلْءَ مَا شِئْتَ مِنْ شَىْءٍ بَعْدُ ‏"‏ ‏.‏\hadithno{1068}\hadithtrans{Abdullah b. Aufa reported:The Messenger of Allah (ﷺ) used to recite this supplication: O Allah! our Lord, unto Thee be praise that would fill the heavens and the earth and fill that which will please Thee besides them}}
\hadithdefcmd{muslim}{1069}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَجْزَأَةَ بْنِ زَاهِرٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَقُولُ ‏ "‏ اللَّهُمَّ لَكَ الْحَمْدُ مِلْءَ السَّمَاءِ وَمِلْءَ الأَرْضِ وَمِلْءَ مَا شِئْتَ مِنْ شَىْءٍ بَعْدُ اللَّهُمَّ طَهِّرْنِي بِالثَّلْجِ وَالْبَرَدِ وَالْمَاءِ الْبَارِدِ اللَّهُمَّ طَهِّرْنِي مِنَ الذُّنُوبِ وَالْخَطَايَا كَمَا يُنَقَّى الثَّوْبُ الأَبْيَضُ مِنَ الْوَسَخِ ‏"‏ ‏.‏\hadithno{1069}\hadithtrans{Abdullah b. Abu Aufa reported that the Messenger of Allah (ﷺ) used to recite (this supplication):O Allah! our Lord, unto Thee be praise that would fill the heavens and the earth and fill that which will please Thee besides (them). O Allah! purify me with snow, (water of) hail and with cold water; O Allah. cleanse me from the sins and errors just as a white garment is cleansed from dirt}}
\hadithdefcmd{muslim}{1070}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، قَالَ وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، كِلاَهُمَا عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ فِي رِوَايَةِ مُعَاذٍ ‏"‏ كَمَا يُنَقَّى الثَّوْبُ الأَبْيَضُ مِنَ الدَّرَنِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ يَزِيدَ ‏"‏ مِنَ الدَّنَسِ ‏"‏ ‏.‏\hadithno{1070}\hadithtrans{This hadith with the same chain of transmitters has been narrated by Shu'ba, and in the narration of Mu'adh the words are:" just as the white garment is cleansed from filth," and in the narration of Yazid:" from dirt}}
\hadithdefcmd{muslim}{1071}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا مَرْوَانُ بْنُ مُحَمَّدٍ الدِّمَشْقِيُّ، حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الْعَزِيزِ، عَنْ عَطِيَّةَ بْنِ قَيْسٍ، عَنْ قَزْعَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ قَالَ ‏ "‏ رَبَّنَا لَكَ الْحَمْدُ مِلْءَ السَّمَوَاتِ وَالأَرْضِ وَمِلْءَ مَا شِئْتَ مِنْ شَىْءٍ بَعْدُ أَهْلَ الثَّنَاءِ وَالْمَجْدِ أَحَقُّ مَا قَالَ الْعَبْدُ وَكُلُّنَا لَكَ عَبْدٌ اللَّهُمَّ لاَ مَانِعَ لِمَا أَعْطَيْتَ وَلاَ مُعْطِيَ لِمَا مَنَعْتَ وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏"‏ ‏.‏\hadithno{1071}\hadithtrans{Abu Sa'id al-Khudri reported:When the Messenger of Allah (ﷺ) raised his head after bowing, he said: O Allah! our Lord, to Thee be the praise that would fill all the heavens and the earth, and all that it pleases Thee besides (them). O, thou art worthy of praise and glory, most worthy of what a servant says, and we all are Thy servants, no one can withhold what Thou givest or give what Thou withholdest, and riches cannot avail a wealthy person against Thee}}
\hadithdefcmd{muslim}{1072}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمُ بْنُ بَشِيرٍ، أَخْبَرَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ قَيْسِ بْنِ سَعْدٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ قَالَ ‏ "‏ اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ مِلْءَ السَّمَوَاتِ وَمِلْءَ الأَرْضِ وَمَا بَيْنَهُمَا وَمِلْءَ مَا شِئْتَ مِنْ شَىْءٍ بَعْدُ أَهْلَ الثَّنَاءِ وَالْمَجْدِ لاَ مَانِعَ لِمَا أَعْطَيْتَ وَلاَ مُعْطِيَ لِمَا مَنَعْتَ وَلاَ يَنْفَعُ ذَا الْجَدِّ مِنْكَ الْجَدُّ ‏"‏ ‏.‏\hadithno{1072}\hadithtrans{Ibn Abbas reported:When the Messenger of Allah (ﷺ) raised his head after bowing, he said: Allah! our Lord, to Thee be the praise that would fill the heavens and the earth and that which is between them, and that which will please Thee besides (them). Worthy art Thou of all praise and glory. No one can withhold what Thou givest, or give what Thou withholdest. And the greatness O! the great availeth not against Thee}}
\hadithdefcmd{muslim}{1073}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا حَفْصٌ، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، حَدَّثَنَا قَيْسُ بْنُ سَعْدٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم إِلَى قَوْلِهِ ‏ "‏ وَمِلْءَ مَا شِئْتَ مِنْ شَىْءٍ بَعْدُ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ مَا بَعْدَهُ ‏.‏\hadithno{1073}\hadithtrans{Ibn Abbas reported from the Messenger of Allah (ﷺ) the words:" And that would fill that which will please Thee besides (them)!" and he did not mention the subsequent (portion of supplication)}}
\hadithdefcmd{muslim}{1074}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، أَخْبَرَنِي سُلَيْمَانُ بْنُ سُحَيْمٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ مَعْبَدٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَشَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم السِّتَارَةَ وَالنَّاسُ صُفُوفٌ خَلْفَ أَبِي بَكْرٍ فَقَالَ ‏ "‏ أَيُّهَا النَّاسُ إِنَّهُ لَمْ يَبْقَ مِنْ مُبَشِّرَاتِ النُّبُوَّةِ إِلاَّ الرُّؤْيَا الصَّالِحَةُ يَرَاهَا الْمُسْلِمُ أَوْ تُرَى لَهُ أَلاَ وَإِنِّي نُهِيتُ أَنْ أَقْرَأَ الْقُرْآنَ رَاكِعًا أَوْ سَاجِدًا فَأَمَّا الرُّكُوعُ فَعَظِّمُوا فِيهِ الرَّبَّ عَزَّ وَجَلَّ وَأَمَّا السُّجُودُ فَاجْتَهِدُوا فِي الدُّعَاءِ فَقَمِنٌ أَنْ يُسْتَجَابَ لَكُمْ ‏"‏ ‏.‏\hadithno{1074}\hadithtrans{Ibn 'Abbas reported:The Messenger of Allah (ﷺ) drew aside the curtain (of his apartment) and (he saw) people in rows (saying prayer) behind Aba Bakr. And he said: Nothing remains of the glad tidings of apostlehood, except good visions which a Muslim sees or someone is made to see for him. And see that I have been forbidden to recite the Qur'an in the state of bowing and prostration. So far as Ruk'u is concerned, extol in it the Great and Glorious Lord, and while prostrating yourselves be earnest in supplication, for it is fitting that your supplications should be answered}}
\hadithdefcmd{muslim}{1075}{قَالَ أَبُو بَكْرٍ حَدَّثَنَا سُفْيَانُ، عَنْ سُلَيْمَانَ، حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، أَخْبَرَنِي سُلَيْمَانُ بْنُ سُحَيْمٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ مَعْبَدِ بْنِ عَبَّاسٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، قَالَ كَشَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم السِّتْرَ وَرَأْسُهُ مَعْصُوبٌ فِي مَرَضِهِ الَّذِي مَاتَ فِيهِ فَقَالَ ‏"‏ اللَّهُمَّ هَلْ بَلَّغْتُ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏"‏ إِنَّهُ لَمْ يَبْقَ مِنْ مُبَشِّرَاتِ النُّبُوَّةِ إِلاَّ الرُّؤْيَا يَرَاهَا الْعَبْدُ الصَّالِحُ أَوْ تُرَى لَهُ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ سُفْيَانَ ‏.‏\hadithno{1075}\hadithtrans{Abdullah b. 'Abbas reported:The Messenger of Allah (ﷺ) drew aside the curtain and his head was bandaged on account of illness in which he died. He said: O Allah, have I not delivered (Thy Message)? (He repeated it) three times. Nothing has been left out of the glad tidings of apostlebood, but good vision. which a pious servant (of Allah) sees or someone else is made to see for him. He then narrated like the hadith transmitted by Sufyan}}
\hadithdefcmd{muslim}{1076}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ عَلِيَّ بْنَ أَبِي طَالِبٍ، قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أَقْرَأَ رَاكِعًا أَوْ سَاجِدًا ‏.‏\hadithno{1076}\hadithtrans{Ali b. Abi Talib reported:The Messenger of Allah (ﷺ) forbade me to recite (the Qur'an) in a state of bowing and prostration}}
\hadithdefcmd{muslim}{1077}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ، - يَعْنِي ابْنَ كَثِيرٍ - حَدَّثَنِي إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ عَلِيَّ بْنَ أَبِي طَالِبٍ، يَقُولُ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ قِرَاءَةِ الْقُرْآنِ وَأَنَا رَاكِعٌ أَوْ سَاجِدٌ ‏.‏\hadithno{1077}\hadithtrans{Ali b. Abi Talib reported:The Messenger of Allah (ﷺ) forbade to recite the Qur'an, while I am in the state of bowing and prostration}}
\hadithdefcmd{muslim}{1078}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ إِسْحَاقَ، أَخْبَرَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّهُ قَالَ نَهَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْقِرَاءَةِ فِي الرُّكُوعِ وَالسُّجُودِ وَلاَ أَقُولُ نَهَاكُمْ ‏.‏\hadithno{1078}\hadithtrans{Ali b. Abi Talib reported:The Messenger of Allah (ﷺ) forbade me from the recitation (of the Qur'an) in bowing and prostration and I do not say that he forbade you}}
\hadithdefcmd{muslim}{1079}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ، قَالاَ أَخْبَرَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، حَدَّثَنَا دَاوُدُ بْنُ قَيْسٍ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، عَنْ عَلِيٍّ، قَالَ نَهَانِي حِبِّي صلى الله عليه وسلم أَنْ أَقْرَأَ رَاكِعًا أَوْ سَاجِدًا ‏.‏\hadithno{1079}\hadithtrans{Ali reported:My loved one (the Holy Prophet) forbade me that I should recite (the Qur'an) in a state of bowing and prostration}}
\hadithdefcmd{muslim}{1080}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، ح وَحَدَّثَنِي عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، ح قَالَ وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنَا الضَّحَّاكُ بْنُ عُثْمَانَ، ح قَالَ وَحَدَّثَنَا الْمُقَدَّمِيُّ، حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنِ ابْنِ عَجْلاَنَ، ح وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي أُسَامَةُ بْنُ زَيْدٍ، ح قَالَ وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - أَخْبَرَنِي مُحَمَّدٌ، وَهُوَ ابْنُ عَمْرٍو ح قَالَ وَحَدَّثَنِي هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا عَبْدَةُ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، كُلُّ هَؤُلاَءِ عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، - إِلاَّ الضَّحَّاكَ وَابْنَ عَجْلاَنَ فَإِنَّهُمَا زَادَا عَنِ ابْنِ عَبَّاسٍ، عَنْ عَلِيٍّ، - عَنِ النَّبِيِّ صلى الله عليه وسلم كُلُّهُمْ قَالُوا نَهَانِي عَنْ قِرَاءَةِ الْقُرْآنِ وَأَنَا رَاكِعٌ وَلَمْ يَذْكُرُوا فِي رِوَايَتِهِمُ النَّهْىَ عَنْهَا فِي السُّجُودِ كَمَا ذَكَرَ الزُّهْرِيُّ وَزَيْدُ بْنُ أَسْلَمَ وَالْوَلِيدُ بْنُ كَثِيرٍ وَدَاوُدُ بْنُ قَيْسٍ ‏.‏\hadithno{1080}\hadithtrans{This hadith has been narrated by some other narrators, Ibn 'Abbas and others, and they all reported that 'Ali said:The Apostle of Allah (ﷺ) forbade me to recite the Qur'an while I am in a state of bowing and prostration, and in their narration (there is a mention of) forbiddance from that (recital) in the state of prostration as it has been transmitted by Zuhri, Zaid b. Aslam, al-Wahid b. Kathir, and Dawud b. Qais}}
\hadithdefcmd{muslim}{1081}{وَحَدَّثَنَاهُ قُتَيْبَةُ، عَنْ حَاتِمِ بْنِ إِسْمَاعِيلَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ عَلِيٍّ، وَلَمْ يَذْكُرْ فِي السُّجُودِ ‏.‏\hadithno{1081}\hadithtrans{This hadith is transmitted on the authority of 'Ali, but he made no mention of" while in prostration}}
\hadithdefcmd{muslim}{1082}{وَحَدَّثَنِي عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بَكْرِ بْنِ حَفْصٍ، عَنْ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ نُهِيتُ أَنْ أَقْرَأَ، وَأَنَا رَاكِعٌ، ‏.‏ لاَ يَذْكُرُ فِي الإِسْنَادِ عَلِيًّا ‏.‏\hadithno{1082}\hadithtrans{Ibn 'Abbas reported:I was forbidden to recite (the Qur'an) while I was bowing, and there is no mention of 'Ali in the chain of transmitters}}
\hadithdefcmd{muslim}{1083}{وَحَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، وَعَمْرُو بْنُ سَوَّادٍ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ أَنَّهُ سَمِعَ أَبَا صَالِحٍ، ذَكْوَانَ يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَقْرَبُ مَا يَكُونُ الْعَبْدُ مِنْ رَبِّهِ وَهُوَ سَاجِدٌ فَأَكْثِرُوا الدُّعَاءَ ‏"‏ ‏.‏\hadithno{1083}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: The nearest a servant comes to his Lord is when he is prostrating himself, so make supplication (in this state)}}
\hadithdefcmd{muslim}{1084}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَيُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يَحْيَى بْنُ أَيُّوبَ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرٍ عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ فِي سُجُودِهِ ‏ "‏ اللَّهُمَّ اغْفِرْ لِي ذَنْبِي كُلَّهُ دِقَّهُ وَجِلَّهُ وَأَوَّلَهُ وَآخِرَهُ وَعَلاَنِيَتَهُ وَسِرَّهُ ‏"‏ ‏.‏\hadithno{1084}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) used to say while prostrating himself: O Lord, forgive me all my sins, small and great, first and last, open and secret}}
\hadithdefcmd{muslim}{1085}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ زُهَيْرٌ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكْثِرُ أَنْ يَقُولَ فِي رُكُوعِهِ وَسُجُودِهِ ‏ "‏ سُبْحَانَكَ اللَّهُمَّ رَبَّنَا وَبِحَمْدِكَ اللَّهُمَّ اغْفِرْ لِي ‏"‏ ‏.‏ يَتَأَوَّلُ الْقُرْآنَ ‏.‏\hadithno{1085}\hadithtrans{A'isha reported:The Messenger of Allah (may peace be upon him') often said while bowing and prostrating himself:" Glory be to Thee, O Allah, our Lord, and praise be to Thee, O Allah, forgive me," thus complying with the (command in) the Qur'an}}
\hadithdefcmd{muslim}{1086}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكْثِرُ أَنْ يَقُولَ قَبْلَ أَنْ يَمُوتَ ‏"‏ سُبْحَانَكَ وَبِحَمْدِكَ أَسْتَغْفِرُكَ وَأَتُوبُ إِلَيْكَ ‏"‏ ‏.‏ قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ مَا هَذِهِ الْكَلِمَاتُ الَّتِي أَرَاكَ أَحْدَثْتَهَا تَقُولُهَا قَالَ ‏"‏ جُعِلَتْ لِي عَلاَمَةٌ فِي أُمَّتِي إِذَا رَأَيْتُهَا قُلْتُهَا ‏\{‏ إِذَا جَاءَ نَصْرُ اللَّهِ وَالْفَتْحُ‏\}‏ ‏"‏ ‏.‏ إِلَى آخِرِ السُّورَةِ ‏.‏\hadithno{1086}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) before his death recited often:Hallowed be Thou, and with Thy praise, I seek forgiveness from Thee and return to Thee. She reported: I said: Messenger of Allah, what are these words that I find you reciting? He said: There has been made a sign for me in my Ummah; when I saw that, I uttered them (these words of glorification for Allah), and the sign is:" When Allah's help and victory..... to the end of the surah}}
\hadithdefcmd{muslim}{1087}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا مُفَضَّلٌ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمِ بْنِ صُبَيْحٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ مَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم مُنْذُ نَزَلَ عَلَيْهِ ‏\{‏ إِذَا جَاءَ نَصْرُ اللَّهِ وَالْفَتْحُ‏\}‏ يُصَلِّي صَلاَةً إِلاَّ دَعَا أَوْ قَالَ فِيهَا ‏"‏ سُبْحَانَكَ رَبِّي وَبِحَمْدِكَ اللَّهُمَّ اغْفِرْ لِي ‏"‏ ‏.‏\hadithno{1087}\hadithtrans{A'isha reported:Never did I, see the Messenger of Allah (ﷺ) after the revelation (of these verses):" When Allah's help and victory came." observin- his prayer without making (this supplication) or he said in it (supplication): Hallowed be Thee, my Lord, and with Thy praise, O Allah, forgive me}}
\hadithdefcmd{muslim}{1088}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي عَبْدُ الأَعْلَى، حَدَّثَنَا دَاوُدُ، عَنْ عَامِرٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكْثِرُ مِنْ قَوْلِ ‏"‏ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ أَسْتَغْفِرُ اللَّهَ وَأَتُوبُ إِلَيْهِ ‏"‏ ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ أَرَاكَ تُكْثِرُ مِنْ قَوْلِ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ أَسْتَغْفِرُ اللَّهَ وَأَتُوبُ إِلَيْهِ ‏.‏ فَقَالَ ‏"‏ خَبَّرَنِي رَبِّي أَنِّي سَأَرَى عَلاَمَةً فِي أُمَّتِي فَإِذَا رَأَيْتُهَا أَكْثَرْتُ مِنْ قَوْلِ سُبْحَانَ اللَّهِ وَبِحَمْدِهِ أَسْتَغْفِرُ اللَّهَ وَأَتُوبُ إِلَيْهِ ‏.‏ فَقَدْ رَأَيْتُهَا ‏\{‏ إِذَا جَاءَ نَصْرُ اللَّهِ وَالْفَتْحُ‏\}‏ فَتْحُ مَكَّةَ ‏\{‏ وَرَأَيْتَ النَّاسَ يَدْخُلُونَ فِي دِينِ اللَّهِ أَفْوَاجًا * فَسَبِّحْ بِحَمْدِ رَبِّكَ وَاسْتَغْفِرْهُ إِنَّهُ كَانَ تَوَّابًا‏\}‏ ‏"‏ ‏.‏\hadithno{1088}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) recited often these words: Hallowed be Allah and with His praise, I seek the forgiveness of Allah and return to Him. She said: I asked: Messenger of Allah, I see that you often repeat the saying" subhan allahi bihamdihi astag firullahi watubuilaih" whereupon he said: My Lord informed me that I would soon see a sign in my Ummah, so when I see it I often recite (these) words: Hallowed be Allah and with His Praise, I seek forgiveness of Allah and return to Him. Indeed I saw it (when this verse) was revealed:" When Allah's help and victory came, it marked the victory of Mecca, and you see people entering into Allah's religion in troops, celebrate the praise of Thy Lord and ask His forgiveness. Surely He is ever returning to Mercy}}
\hadithdefcmd{muslim}{1089}{وَحَدَّثَنِي حَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ قُلْتُ لِعَطَاءٍ كَيْفَ تَقُولُ أَنْتَ فِي الرُّكُوعِ قَالَ أَمَّا سُبْحَانَكَ وَبِحَمْدِكَ لاَ إِلَهَ إِلاَّ أَنْتَ فَأَخْبَرَنِي ابْنُ أَبِي مُلَيْكَةَ عَنْ عَائِشَةَ قَالَتِ افْتَقَدْتُ النَّبِيَّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَظَنَنْتُ أَنَّهُ ذَهَبَ إِلَى بَعْضِ نِسَائِهِ فَتَحَسَّسْتُ ثُمَّ رَجَعْتُ فَإِذَا هُوَ رَاكِعٌ أَوْ سَاجِدٌ يَقُولُ ‏ "‏ سُبْحَانَكَ وَبِحَمْدِكَ لاَ إِلَهَ إِلاَّ أَنْتَ ‏"‏ ‏.‏ فَقُلْتُ بِأَبِي أَنْتَ وَأُمِّي إِنِّي لَفِي شَأْنٍ وَإِنَّكَ لَفِي آخَرَ ‏.‏\hadithno{1089}\hadithtrans{Ibn Juraij reported:I asked 'Ata': What do you recite when you are in a state of bowing (in prayer)? He said:" Hallowed be Thou, and with Thy praise, there is no god but Thou." Son of Abd Mulaika narrated to me on the anthority of 'A'isha (who reported): I missed one night the Messenger of Allah (ﷺ) (from his bed). I thought that he might have gone to one of his other wives. I searched for him and then came back and (found him) in a state of bowing, or prostration, saying: Hallowed be Thou and with Thy praise; there is no god but Thou. I said: With my father mayest thou be ransomed and with my mother. I was thinking of (another) affair, whereas you are (occupied) in another one}}
\hadithdefcmd{muslim}{1090}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ عَائِشَةَ، قَالَتْ فَقَدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم لَيْلَةً مِنَ الْفِرَاشِ فَالْتَمَسْتُهُ فَوَقَعَتْ يَدِي عَلَى بَطْنِ قَدَمَيْهِ وَهُوَ فِي الْمَسْجِدِ وَهُمَا مَنْصُوبَتَانِ وَهُوَ يَقُولُ ‏ "‏ اللَّهُمَّ أَعُوذُ بِرِضَاكَ مِنْ سَخَطِكَ وَبِمُعَافَاتِكَ مِنْ عُقُوبَتِكَ وَأَعُوذُ بِكَ مِنْكَ لاَ أُحْصِي ثَنَاءً عَلَيْكَ أَنْتَ كَمَا أَثْنَيْتَ عَلَى نَفْسِكَ ‏"‏ ‏.‏\hadithno{1090}\hadithtrans{A'isha reported:One night I missed Allah's Messenger (ﷺ) from the bed, and when I sought him my hand touched the soles of his feet while he was in the state of prostration; they (feet) were raised and he was saying:" O Allah, I seek refuge in Thy pleasure from Thy anger, and in Thy forgiveness from Thy punishment, and I seek refuge in Thee from Thee (Thy anger). I cannot reckon Thy praise. Thou art as Thou hast lauded Thyself}}
\hadithdefcmd{muslim}{1091}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ الْعَبْدِيُّ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفِ بْنِ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، أَنَّ عَائِشَةَ، نَبَّأَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ فِي رُكُوعِهِ وَسُجُودِهِ ‏ "‏ سُبُّوحٌ قُدُّوسٌ رَبُّ الْمَلاَئِكَةِ وَالرُّوحِ ‏"‏ ‏.‏\hadithno{1091}\hadithtrans{A'isha reported that the Messenger of Allah (may peace he upon him) used to pronounce while bowing and prostrating himself:All Glorious, All Holy, Lord of the Angels and the Spirit}}
\hadithdefcmd{muslim}{1092}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، أَخْبَرَنِي قَتَادَةُ، قَالَ سَمِعْتُ مُطَرِّفَ بْنَ عَبْدِ اللَّهِ بْنِ الشِّخِّيرِ، قَالَ أَبُو دَاوُدَ وَحَدَّثَنِي هِشَامٌ، عَنْ قَتَادَةَ، عَنْ مُطَرِّفٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏.‏\hadithno{1092}\hadithtrans{This hadith has been narrated on the authority of 'A'isha by another chain of transmitters}}
\hadithdefcmd{muslim}{1093}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، قَالَ سَمِعْتُ الأَوْزَاعِيَّ، قَالَ حَدَّثَنِي الْوَلِيدُ بْنُ هِشَامٍ الْمُعَيْطِيُّ، حَدَّثَنِي مَعْدَانُ بْنُ أَبِي طَلْحَةَ الْيَعْمَرِيُّ، قَالَ لَقِيتُ ثَوْبَانَ مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ أَخْبِرْنِي بِعَمَلٍ أَعْمَلُهُ يُدْخِلُنِي اللَّهُ بِهِ الْجَنَّةَ ‏.‏ أَوْ قَالَ قُلْتُ بِأَحَبِّ الأَعْمَالِ إِلَى اللَّهِ ‏.‏ فَسَكَتَ ثُمَّ سَأَلْتُهُ فَسَكَتَ ثُمَّ سَأَلْتُهُ الثَّالِثَةَ فَقَالَ سَأَلْتُ عَنْ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ عَلَيْكَ بِكَثْرَةِ السُّجُودِ لِلَّهِ فَإِنَّكَ لاَ تَسْجُدُ لِلَّهِ سَجْدَةً إِلاَّ رَفَعَكَ اللَّهُ بِهَا دَرَجَةً وَحَطَّ عَنْكَ بِهَا خَطِيئَةً ‏"‏ ‏.‏ قَالَ مَعْدَانُ ثُمَّ لَقِيتُ أَبَا الدَّرْدَاءِ فَسَأَلْتُهُ فَقَالَ لِي مِثْلَ مَا قَالَ لِي ثَوْبَانُ ‏.‏\hadithno{1093}\hadithtrans{Ma'dan b. Talha reported:I met Thauban, the freed slave. of Allah's Messenger (ﷺ), and asked him to tell me about an act for which, if I do it, Allah will admit me to Paradise, or I asked about the act which was loved most by Allah. He gave no reply. I again asked and he gave no reply. I asked him for the third time, and he said: I asked Allah's Messenger (ﷺ) about that and he said: Make frequent prostrations before Allah, for you will not make one prostration without raising you a degree because of it, and removing a sin from you, because of it. Ma'dan said that then lie met Abu al-Darda' and when he asked him, he received a reply similar to that given by Thauban}}
\hadithdefcmd{muslim}{1094}{حَدَّثَنَا الْحَكَمُ بْنُ مُوسَى أَبُو صَالِحٍ، حَدَّثَنَا هِقْلُ بْنُ زِيَادٍ، قَالَ سَمِعْتُ الأَوْزَاعِيَّ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي أَبُو سَلَمَةَ، حَدَّثَنِي رَبِيعَةُ بْنُ كَعْبٍ الأَسْلَمِيُّ، قَالَ كُنْتُ أَبِيتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَتَيْتُهُ بِوَضُوئِهِ وَحَاجَتِهِ فَقَالَ لِي ‏"‏ سَلْ ‏"‏ ‏.‏ فَقُلْتُ أَسْأَلُكَ مُرَافَقَتَكَ فِي الْجَنَّةِ ‏.‏ قَالَ ‏"‏ أَوَغَيْرَ ذَلِكَ ‏"‏ ‏.‏ قُلْتُ هُوَ ذَاكَ ‏.‏ قَالَ ‏"‏ فَأَعِنِّي عَلَى نَفْسِكَ بِكَثْرَةِ السُّجُودِ ‏"‏ ‏.‏\hadithno{1094}\hadithtrans{Rabi'a b. Ka'b said:I was with Allah's Messenger (ﷺ) one night. and I brought him water and what he required. He said to me: Ask (anything you like). I said: I ask your company in Paradise. He (the Holy Prophet) said: Or anything else besides it. I said: That is all (what I require). He said: Then help me to achieve this for you by devoting yourself often to prostration}}
\hadithdefcmd{muslim}{1095}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو الرَّبِيعِ الزَّهْرَانِيُّ، قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ أَبُو الرَّبِيعِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أُمِرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَسْجُدَ عَلَى سَبْعَةٍ وَنُهِيَ أَنْ يَكُفَّ شَعْرَهُ وَثِيَابَهُ ‏.‏ هَذَا حَدِيثُ يَحْيَى ‏.‏ وَقَالَ أَبُو الرَّبِيعِ عَلَى سَبْعَةِ أَعْظُمٍ وَنُهِيَ أَنْ يَكُفَّ شَعْرَهُ وَثِيَابَهُ الْكَفَّيْنِ وَالرُّكْبَتَيْنِ وَالْقَدَمَيْنِ وَالْجَبْهَةِ ‏.‏\hadithno{1095}\hadithtrans{Ibn 'Abbas reported:The Apostle of Allah (ﷺ) had been commanded that he should prostrate on the seven (bones) and he was forbidden to fold back the hair and clothing. And in the narration transmitted by Abu Rabi' (the words are):" on the seven bones and I was forbidden to fold back the hair and clothing". According to Abu'l-Rabi' (the seven bones are): The hands, the knees, and the (extremities) of the feet and the forehead}}
\hadithdefcmd{muslim}{1096}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ جَعْفَرٍ - حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أُمِرْتُ أَنْ أَسْجُدَ عَلَى سَبْعَةِ أَعْظُمٍ وَلاَ أَكُفَّ ثَوْبًا وَلاَ شَعْرًا ‏"‏ ‏.‏\hadithno{1096}\hadithtrans{Ibn 'Abbas reported from the Messenger of Allah (ﷺ):I was commanded to prostrate myself on seven bones and not to fold back clothing or hair}}
\hadithdefcmd{muslim}{1097}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، أُمِرَ النَّبِيُّ صلى الله عليه وسلم أَنْ يَسْجُدَ عَلَى سَبْعٍ وَنُهِيَ أَنْ يَكْفِتَ الشَّعْرَ وَالثِّيَابَ ‏"‏ ‏.‏\hadithno{1097}\hadithtrans{Ibn 'Abbas reported:The Messenger of Allah (ﷺ) had been commanded to prostrate on seven (bones) and forbidden to fold back hair and clothing}}
\hadithdefcmd{muslim}{1098}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ طَاوُسٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أُمِرْتُ أَنْ أَسْجُدَ عَلَى سَبْعَةِ أَعْظُمٍ الْجَبْهَةِ - وَأَشَارَ بِيَدِهِ عَلَى أَنْفِهِ - وَالْيَدَيْنِ وَالرِّجْلَيْنِ وَأَطْرَافِ الْقَدَمَيْنِ وَلاَ نَكْفِتَ الثِّيَابَ وَلاَ الشَّعْرَ ‏"‏ ‏.‏\hadithno{1098}\hadithtrans{Ibn Abbas reported that the Messenger of Allah (ﷺ) said:I have been commanded to prostrate myself on seven bones:" forehead," and then pointed with his hand towards his nose, hands, feet, and the extremities of the feet; and we were forbidden to fold back clothing and hair}}
\hadithdefcmd{muslim}{1099}{حَدَّثَنَا أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي ابْنُ جُرَيْجٍ، عَنْ عَبْدِ اللَّهِ بْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أُمِرْتُ أَنْ أَسْجُدَ عَلَى سَبْعٍ وَلاَ أَكْفِتَ الشَّعْرَ وَلاَ الثِّيَابَ الْجَبْهَةِ وَالأَنْفِ وَالْيَدَيْنِ وَالرُّكْبَتَيْنِ وَالْقَدَمَيْنِ ‏"‏ ‏.‏\hadithno{1099}\hadithtrans{Ibn Abbas reported:The Messenger of Allah (ﷺ) said: I was commanded to prostrate myself on the seven (bones) and forbidden to fold back hair and clothing. (The seven bones are): forehead, nose, hands, knees and feet}}
\hadithdefcmd{muslim}{1100}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا بَكْرٌ، - وَهُوَ ابْنُ مُضَرَ - عَنِ ابْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنِ الْعَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا سَجَدَ الْعَبْدُ سَجَدَ مَعَهُ سَبْعَةُ أَطْرَافٍ وَجْهُهُ وَكَفَّاهُ وَرُكْبَتَاهُ وَقَدَمَاهُ ‏"‏ ‏.‏\hadithno{1100}\hadithtrans{It was narrated from Al-'Abbas bin 'Abdul Muttalib that he heard the Messenger of Allah (ﷺ) say:"When a person prostates, he prostates on seven part of the body: His face, his hands, his knees and his feet}}
\hadithdefcmd{muslim}{1101}{حَدَّثَنَا عَمْرُو بْنُ سَوَّادٍ الْعَامِرِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنَا عَمْرُو بْنُ الْحَارِثِ، أَنَّ بُكَيْرًا، حَدَّثَهُ أَنَّ كُرَيْبًا مَوْلَى ابْنِ عَبَّاسٍ حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ رَأَى عَبْدَ اللَّهِ بْنَ الْحَارِثِ يُصَلِّي وَرَأْسُهُ مَعْقُوصٌ مِنْ وَرَائِهِ فَقَامَ فَجَعَلَ يَحُلُّهُ فَلَمَّا انْصَرَفَ أَقْبَلَ إِلَى ابْنِ عَبَّاسٍ فَقَالَ مَا لَكَ وَرَأْسِي فَقَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّمَا مَثَلُ هَذَا مَثَلُ الَّذِي يُصَلِّي وَهُوَ مَكْتُوفٌ ‏"‏ ‏.‏\hadithno{1101}\hadithtrans{Abdullah b. Abbas reported that he saw 'Abdullah b. al-Harith observing the prayer and (his hair) was plaited behind his head. He ('Abdullah b. 'Abbas) stood up and unfolded them. While going back (from the prayer) he met Ibn 'Abbas and said to him:Why is it that you touched my head? He (Ibn 'Abbas) replied: (The man who observes prayer with plaited hair) is like one who prays with his hands tied behind}}
\hadithdefcmd{muslim}{1102}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اعْتَدِلُوا فِي السُّجُودِ وَلاَ يَبْسُطْ أَحَدُكُمْ ذِرَاعَيْهِ انْبِسَاطَ الْكَلْبِ ‏"‏ ‏.‏\hadithno{1102}\hadithtrans{Anas reported:The Messenger of Allah (ﷺ) said: Observe moderation in prostration, and let none of you stretch out his forearms (on the ground) like a dog}}
\hadithdefcmd{muslim}{1103}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح قَالَ وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - قَالاَ حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِ ابْنِ جَعْفَرٍ ‏ "‏ وَلاَ يَتَبَسَّطْ أَحَدُكُمْ ذِرَاعَيْهِ انْبِسَاطَ الْكَلْبِ ‏"‏ ‏.‏\hadithno{1103}\hadithtrans{This hadith has been narrated by Shu'ba with the same chain of transmitters. And in the hidith transmitted by Ibn Ja'far (the words are):" None of you should stretch out his forearms like the stretching out of a dog}}
\hadithdefcmd{muslim}{1104}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ إِيَادٍ، عَنْ إِيَادٍ، عَنِ الْبَرَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا سَجَدْتَ فَضَعْ كَفَّيْكَ وَارْفَعْ مِرْفَقَيْكَ ‏"‏ ‏.‏\hadithno{1104}\hadithtrans{Al-Bira' (b. 'Azib) reported:The Messenger of Allah (ﷺ) said. When you prostrate yourself, place the palms of your hands on the ground and raise your elbows}}
\hadithdefcmd{muslim}{1105}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا بَكْرٌ، - وَهُوَ ابْنُ مُضَرَ - عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، عَنْ عَبْدِ اللَّهِ بْنِ مَالِكٍ ابْنِ بُحَيْنَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا صَلَّى فَرَّجَ بَيْنَ يَدَيْهِ حَتَّى يَبْدُوَ بَيَاضُ إِبْطَيْهِ ‏.‏\hadithno{1105}\hadithtrans{Abdullah b. Malik ibn Bujainah reported:When the Prophet (ﷺ) prostrated, lie spread out his arms so that the whiteness of his armpits was visible}}
\hadithdefcmd{muslim}{1106}{حَدَّثَنَا عَمْرُو بْنُ سَوَّادٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنَا عَمْرُو بْنُ الْحَارِثِ، وَاللَّيْثُ بْنُ سَعْدٍ، كِلاَهُمَا عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي رِوَايَةِ عَمْرِو بْنِ الْحَارِثِ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَجَدَ يُجَنِّحُ فِي سُجُودِهِ حَتَّى يُرَى وَضَحُ إِبْطَيْهِ ‏.‏ وَفِي رِوَايَةِ اللَّيْثِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا سَجَدَ فَرَّجَ يَدَيْهِ عَنْ إِبْطَيْهِ حَتَّى إِنِّي لأَرَى بَيَاضَ إِبْطَيْهِ ‏.‏\hadithno{1106}\hadithtrans{This hadith has been narrated by Ja'far b. Rabi' with the same chain of transmitters. And in the narration transmitted by 'Amr b. al-Harith (the words are):" When the Messenger of Allah (rtiay peace be upon him) prostrated, he spread out his arms so that the whiteness of his armpits was visible." And in the narration transmitted by al-Laith (the words are:" When the Messenger of Allah (ﷺ) prostrated. he spread his hands from the armpits so that I saw their whiteness}}
\hadithdefcmd{muslim}{1107}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنْ سُفْيَانَ، - قَالَ يَحْيَى أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ الأَصَمِّ، عَنْ عَمِّهِ، يَزِيدَ بْنِ الأَصَمِّ عَنْ مَيْمُونَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا سَجَدَ لَوْ شَاءَتْ بَهْمَةٌ أَنْ تَمُرَّ بَيْنَ يَدَيْهِ لَمَرَّتْ ‏.‏\hadithno{1107}\hadithtrans{Maimuna reported:When the Messenger of Allah (ﷺ) prostrated himself, if a lamb wanted to pass between his arms, it could pass}}
\hadithdefcmd{muslim}{1108}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، قَالَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ الأَصَمِّ، عَنْ يَزِيدَ بْنِ الأَصَمِّ، أَنَّهُ أَخْبَرَهُ عَنْ مَيْمُونَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَجَدَ خَوَّى بِيَدَيْهِ - يَعْنِي جَنَّحَ - حَتَّى يُرَى وَضَحُ إِبْطَيْهِ مِنْ وَرَائِهِ وَإِذَا قَعَدَ اطْمَأَنَّ عَلَى فَخِذِهِ الْيُسْرَى ‏.‏\hadithno{1108}\hadithtrans{Maimuna, the wife of the Messenger of Allah (ﷺ), reported:When the Messenger of Allah (ﷺ) prostrated himself, he spread his arms, i. e. he separated them so much that the whiteness of his armpits became visible from behind and when he sat (for Jalsa) he rested on his left thigh}}
\hadithdefcmd{muslim}{1109}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِعَمْرٍو - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا جَعْفَرُ بْنُ بُرْقَانَ، عَنْ يَزِيدَ بْنِ الأَصَمِّ، عَنْ مَيْمُونَةَ بِنْتِ الْحَارِثِ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سَجَدَ جَافَى حَتَّى يَرَى مَنْ خَلْفَهُ وَضَحَ إِبْطَيْهِ ‏.‏ قَالَ وَكِيعٌ يَعْنِي بَيَاضَهُمَا ‏.‏\hadithno{1109}\hadithtrans{Maimuna daughter of Harith reported:When the Messenger of Allah (ﷺ) prostrated, he kept his hands so much apart from each other that when it was seen from behind the armpits became visible. Waki' said: That is their whiteness}}
\hadithdefcmd{muslim}{1110}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو خَالِدٍ، - يَعْنِي الأَحْمَرَ - عَنْ حُسَيْنٍ الْمُعَلِّمِ، ح قَالَ وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لَهُ - قَالَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا حُسَيْنٌ الْمُعَلِّمُ، عَنْ بُدَيْلِ بْنِ مَيْسَرَةَ، عَنْ أَبِي الْجَوْزَاءِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْتَفْتِحُ الصَّلاَةَ بِالتَّكْبِيرِ وَالْقِرَاءَةَ بِـ ‏\{‏ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ‏\}‏ وَكَانَ إِذَا رَكَعَ لَمْ يُشْخِصْ رَأْسَهُ وَلَمْ يُصَوِّبْهُ وَلِكَنْ بَيْنَ ذَلِكَ وَكَانَ إِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ لَمْ يَسْجُدْ حَتَّى يَسْتَوِيَ قَائِمًا وَكَانَ إِذَا رَفَعَ رَأْسَهُ مِنَ السَّجْدَةِ لَمْ يَسْجُدْ حَتَّى يَسْتَوِيَ جَالِسًا وَكَانَ يَقُولُ فِي كُلِّ رَكْعَتَيْنِ التَّحِيَّةَ وَكَانَ يَفْرِشُ رِجْلَهُ الْيُسْرَى وَيَنْصِبُ رِجْلَهُ الْيُمْنَى وَكَانَ يَنْهَى عَنْ عُقْبَةِ الشَّيْطَانِ وَيَنْهَى أَنْ يَفْتَرِشَ الرَّجُلُ ذِرَاعَيْهِ افْتِرَاشَ السَّبُعِ وَكَانَ يَخْتِمُ الصَّلاَةَ بِالتَّسْلِيمِ ‏.‏ وَفِي رِوَايَةِ ابْنِ نُمَيْرٍ عَنْ أَبِي خَالِدٍ وَكَانَ يَنْهَى عَنْ عَقِبِ الشَّيْطَانِ ‏.‏\hadithno{1110}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) used to begin prayer with takbir (saying Allahu Akbar) and the recitation: "Praise be to Allah, the Lord of the Universe." When he bowed he neither kept his head up nor bent it down, but kept it between these extremes; when he raised his head after bowing he did not prostrate himself till he had stood erect; when he raised his head after prostration he did not prostrate himself again till he sat up. At the end of every two rak'ahs he recited the tahiyya; and he used to place his left foot flat (on the ground) and raise up the right; he prohibited the devil's way of sitting on the heels, and he forbade people to spread out their arms like a wild beast. And he used to finish the prayer with the taslim}}
\hadithdefcmd{muslim}{1111}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا وَضَعَ أَحَدُكُمْ بَيْنَ يَدَيْهِ مِثْلَ مُؤْخِرَةِ الرَّحْلِ فَلْيُصَلِّ وَلاَ يُبَالِ مَنْ مَرَّ وَرَاءَ ذَلِكَ ‏"‏ ‏.‏\hadithno{1111}\hadithtrans{Musa b. Talha reported it on the authority of his father:The Messenger of Allah (ﷺ) said: When one of you places in front of him so me. thing such as the back of a saddle, he should pray without caring who passes on the other side of it}}
\hadithdefcmd{muslim}{1112}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ ابْنُ نُمَيْرٍ، حَدَّثَنَا عُمَرُ بْنُ عُبَيْدٍ الطَّنَافِسِيُّ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ مُوسَى بْنِ طَلْحَةَ، عَنْ أَبِيهِ، قَالَ كُنَّا نُصَلِّي وَالدَّوَابُّ تَمُرُّ بَيْنَ أَيْدِينَا فَذَكَرْنَا ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مِثْلُ مُؤْخِرَةِ الرَّحْلِ تَكُونُ بَيْنَ يَدَىْ أَحَدِكُمْ ثُمَّ لاَ يَضُرُّهُ مَا مَرَّ بَيْنَ يَدَيْهِ ‏"‏ ‏.‏ وَقَالَ ابْنُ نُمَيْرٍ ‏"‏ فَلاَ يَضُرُّهُ مَنْ مَرَّ بَيْنَ يَدَيْهِ ‏"‏ ‏.‏\hadithno{1112}\hadithtrans{Musa b. Talha reported on the authority of his father:We used to say prayer and the animals moved in front of us. We mentioned it to the Messenger of Allah (ﷺ) and he said: If anything equal to the back of a saddle is in front of you, then what walks in front, no harm would come to him. Ibn Numair said: No harm would come whosoever walks in front}}
\hadithdefcmd{muslim}{1113}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، أَخْبَرَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنْ أَبِي الأَسْوَدِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ سُتْرَةِ الْمُصَلِّي فَقَالَ ‏ "‏ مِثْلُ مُؤْخِرَةِ الرَّحْلِ ‏"‏ ‏.‏\hadithno{1113}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) was asked about sutra of a worshipper; he said: Equal to the back of the saddle}}
\hadithdefcmd{muslim}{1114}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، أَخْبَرَنَا حَيْوَةُ، عَنْ أَبِي الأَسْوَدِ، مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ فِي غَزْوَةِ تَبُوكَ عَنْ سُتْرَةِ الْمُصَلِّي فَقَالَ ‏ "‏ كَمُؤْخِرَةِ الرَّحْلِ ‏"‏ ‏.‏\hadithno{1114}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) was asked in the expedition of Tabuk about the sutra the worshipper; he said: Like the back of the saddle}}
\hadithdefcmd{muslim}{1115}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا خَرَجَ يَوْمَ الْعِيدِ أَمَرَ بِالْحَرْبَةِ فَتُوضَعُ بَيْنَ يَدَيْهِ فَيُصَلِّي إِلَيْهَا وَالنَّاسُ وَرَاءَهُ وَكَانَ يَفْعَلُ ذَلِكَ فِي السَّفَرِ فَمِنْ ثَمَّ اتَّخَذَهَا الأُمَرَاءُ ‏.‏\hadithno{1115}\hadithtrans{Ibn Umar reported:When the Messenger of Allah (may peace he upon him) went out on the 'Id day, he ordered to carry a spear-and it was fixed in front of him, and he said prayer towards its (direction), and the people were behind him. And he did it in the journey, and that is the reason why the Amirs carried it}}
\hadithdefcmd{muslim}{1116}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَرْكُزُ - وَقَالَ أَبُو بَكْرٍ يَغْرِزُ - الْعَنَزَةَ وَيُصَلِّي إِلَيْهَا ‏.‏ زَادَ ابْنُ أَبِي شَيْبَةَ قَالَ عُبَيْدُ اللَّهِ وَهْىَ الْحَرْبَةُ ‏.‏\hadithno{1116}\hadithtrans{Ibn Umar reported:The Apostle of Allah (ﷺ) set up (sutra), and Abu Bakr said: He implanted iron-tipped spear and said prayer towards its direction. Ibn Abu Shaiba made this addition to it:" Ubaidullah said that it was a spear}}
\hadithdefcmd{muslim}{1117}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَعْرِضُ رَاحِلَتَهُ وَهُوَ يُصَلِّي إِلَيْهَا ‏.‏\hadithno{1117}\hadithtrans{Ibn 'Umar said:The Apostle of Allah (ﷺ) used to place his camel (towards the Ka'ba) and said prayer in its direction}}
\hadithdefcmd{muslim}{1118}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي إِلَى رَاحِلَتِهِ ‏.‏ وَقَالَ ابْنُ نُمَيْرٍ إِنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى إِلَى بَعِيرٍ ‏.‏\hadithno{1118}\hadithtrans{Ibn 'Umar reported:The Apostle of Allah (ﷺ) used to say prayer towards his camel. Ibn Numair said: The Apostle of Allah (ﷺ) said prayer towards the camel}}
\hadithdefcmd{muslim}{1119}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنْ وَكِيعٍ، - قَالَ زُهَيْرٌ حَدَّثَنَا وَكِيعٌ، - حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَوْنُ بْنُ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم بِمَكَّةَ وَهُوَ بِالأَبْطَحِ فِي قُبَّةٍ لَهُ حَمْرَاءَ مِنْ أَدَمٍ - قَالَ - فَخَرَجَ بِلاَلٌ بِوَضُوئِهِ فَمِنْ نَائِلٍ وَنَاضِحٍ - قَالَ - فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم عَلَيْهِ حُلَّةٌ حَمْرَاءُ كَأَنِّي أَنْظُرُ إِلَى بَيَاضِ سَاقَيْهِ - قَالَ - فَتَوَضَّأَ وَأَذَّنَ بِلاَلٌ - قَالَ - فَجَعَلْتُ أَتَتَبَّعُ فَاهُ هَا هُنَا وَهَا هُنَا - يَقُولُ يَمِينًا وَشِمَالاً - يَقُولُ حَىَّ عَلَى الصَّلاَةِ حَىَّ عَلَى الْفَلاَحِ - قَالَ - ثُمَّ رُكِزَتْ لَهُ عَنَزَةٌ فَتَقَدَّمَ فَصَلَّى الظُّهْرَ رَكْعَتَيْنِ يَمُرُّ بَيْنْ يَدَيْهِ الْحِمَارُ وَالْكَلْبُ لاَ يُمْنَعُ ثُمَّ صَلَّى الْعَصْرَ رَكْعَتَيْنِ ثُمَّ لَمْ يَزَلْ يُصَلِّي رَكْعَتَيْنِ حَتَّى رَجَعَ إِلَى الْمَدِينَةِ ‏.‏\hadithno{1119}\hadithtrans{Abu Juhaifa reported it on the authority of his father:I came to the Messenger of Allah (ﷺ) in Mecca and he was (at that time) at al- Abtah in a red leather tent. And Bilal stepped out with ablution water for him. (And what was left out of that water) some of them got it (whereas others could not get it) and (those who got it) rubbed themselves with it. Then the Messenger of Allah (ﷺ) stepped out with a red mantle on him and I was catching a glimpse of the whiteness of his shanks. The narrator said: He (the Holy Prophet) performed the ablution. and Bilal pronounced Adhan and I followed his mouth (as he turned) this side and that as he said on the right and the left:" Come to prayer, come to success." ' A spear was then fixed for him (on the ground). He stepped forward and said two rak'ahs of Zuhr, while there passed in front of him a donkey and a dog, and these were not checked. He then said two rak'ahs of the 'Asr prayer, and he then continued saying two rak'ahs till he came back to Medina}}
\hadithdefcmd{muslim}{1120}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا عُمَرُ بْنُ أَبِي زَائِدَةَ، حَدَّثَنَا عَوْنُ بْنُ أَبِي جُحَيْفَةَ، أَنَّ أَبَاهُ، رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم فِي قُبَّةٍ حَمْرَاءَ مِنْ أَدَمٍ وَرَأَيْتُ بِلاَلاً أَخْرَجَ وَضُوءًا فَرَأَيْتُ النَّاسَ يَبْتَدِرُونَ ذَلِكَ الْوَضُوءَ فَمَنْ أَصَابَ مِنْهُ شَيْئًا تَمَسَّحَ بِهِ وَمَنْ لَمْ يُصِبْ مِنْهُ أَخَذَ مِنْ بَلَلِ يَدِ صَاحِبِهِ ثُمَّ رَأَيْتُ بِلاَلاً أَخْرَجَ عَنَزَةً فَرَكَزَهَا وَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي حُلَّةٍ حَمْرَاءَ مُشَمِّرًا فَصَلَّى إِلَى الْعَنَزَةِ بِالنَّاسِ رَكْعَتَيْنِ وَرَأَيْتُ النَّاسَ وَالدَّوَابَّ يَمُرُّونَ بَيْنَ يَدَىِ الْعَنَزَةِ ‏.‏\hadithno{1120}\hadithtrans{Abu Juhaifa reported on the authority of his father:I saw the Messenger of Allah (ﷺ) (in Mecca at al-Abtah) in a red leather tent. and I saw Bilal take the ablution water (left by Allah's Messenger), and I saw the people racing, with one another to get that ablution water. If anyone got some of it, he rubbed himself with it, and anyone who did not get any got some of the moisture from his companion's hand. I then saw Bilal take a staff and fix it in the ground, after which the Messenger of Allah (ﷺ) came out quickly in a red mantle and led the people in two rak'ahs facing the staff, and I saw people and animals passing in front of the staff}}
\hadithdefcmd{muslim}{1121}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا جَعْفَرُ بْنُ عَوْنٍ، أَخْبَرَنَا أَبُو عُمَيْسٍ، ح قَالَ وَحَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّاءَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، قَالَ حَدَّثَنَا مَالِكُ بْنُ مِغْوَلٍ، كِلاَهُمَا عَنْ عَوْنِ بْنِ أَبِي جُحَيْفَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِ حَدِيثِ سُفْيَانَ وَعُمَرَ بْنِ أَبِي زَائِدَةَ يَزِيدُ بَعْضُهُمْ عَلَى بَعْضٍ وَفِي حَدِيثِ مَالِكِ بْنِ مِغْوَلٍ فَلَمَّا كَانَ بِالْهَاجِرَةِ خَرَجَ بِلاَلٌ فَنَادَى بِالصَّلاَةِ ‏.‏\hadithno{1121}\hadithtrans{Aun b. Abu Juhaifa narrated from the Messenger of Allah (ﷺ) on the authority of his father a hadith like that of Sufyan, and 'Umar b. Abu Za'ida made this addition:Some of them tried to excel the others (in obtaining water), and in the hadith transmitted by Malik b. Mighwal (the words are): When it was noon, Bilal came out and summoned (people) to (noon) prayer}}
\hadithdefcmd{muslim}{1122}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ سَمِعْتُ أَبَا جُحَيْفَةَ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْهَاجِرَةِ إِلَى الْبَطْحَاءِ فَتَوَضَّأَ فَصَلَّى الظُّهْرَ رَكْعَتَيْنِ وَالْعَصْرَ رَكْعَتَيْنِ وَبَيْنَ يَدَيْهِ عَنَزَةٌ ‏.‏ قَالَ شُعْبَةُ وَزَادَ فِيهِ عَوْنٌ عَنْ أَبِيهِ أَبِي جُحَيْفَةَ وَكَانَ يَمُرُّ مِنْ وَرَائِهَا الْمَرْأَةُ وَالْحِمَارُ ‏.‏\hadithno{1122}\hadithtrans{Abu Juhaifa reported:The Messenger of Allah (ﷺ) went at noon towards al-Batha', he performed ablution, and said two rak'ahs of the Zuhr prayer and two of the 'Asr prayer, and there was a spear in front of him. Shu'ba said and Aun made this addition to it on the authority of his father Abu Juhaifa: And the woman and the donkey passed behind it}}
\hadithdefcmd{muslim}{1123}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ حَاتِمٍ، قَالاَ حَدَّثَنَا ابْنُ مَهْدِيٍّ، حَدَّثَنَا شُعْبَةُ، بِالإِسْنَادَيْنِ جَمِيعًا مِثْلَهُ ‏.‏ وَزَادَ فِي حَدِيثِ الْحَكَمِ فَجَعَلَ النَّاسُ يَأْخُذُونَ مِنْ فَضْلِ وَضُوئِهِ ‏.‏\hadithno{1123}\hadithtrans{Shu'ba narrated the same on the basis of two authorities and in the hadith transmitted by Hakam (the words are):The people began to get water that was left out of his (the Prophet's) ablution}}
\hadithdefcmd{muslim}{1124}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَقْبَلْتُ رَاكِبًا عَلَى أَتَانٍ وَأَنَا يَوْمَئِذٍ، قَدْ نَاهَزْتُ الاِحْتِلاَمَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي بِالنَّاسِ بِمِنًى فَمَرَرْتُ بَيْنَ يَدَىِ الصَّفِّ فَنَزَلْتُ فَأَرْسَلْتُ الأَتَانَ تَرْتَعُ وَدَخَلْتُ فِي الصَّفِّ فَلَمْ يُنْكِرْ ذَلِكَ عَلَىَّ أَحَدٌ ‏.‏\hadithno{1124}\hadithtrans{Ibn 'Abbas reported:I came riding on a she-ass, and I was on the threshold of maturity, and the Messenger of Allah (ﷺ) was leading people in prayer at Mina. I passed in front of the row and got down, and sent the she-ass for grazing and joined the row, and nobody made any objection to it}}
\hadithdefcmd{muslim}{1125}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّهُ، أَقْبَلَ يَسِيرُ عَلَى حِمَارٍ وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ يُصَلِّي بِمِنًى فِي حَجَّةِ الْوَدَاعِ يُصَلِّي بِالنَّاسِ - قَالَ - فَسَارَ الْحِمَارُ بَيْنَ يَدَىْ بَعْضِ الصَّفِّ ثُمَّ نَزَلَ عَنْهُ فَصَفَّ مَعَ النَّاسِ ‏.‏\hadithno{1125}\hadithtrans{Abdullah b. Abbas reported that he came riding on a donkey, and the Messenger of Allah (ﷺ) was leading the people in prayer at Mina on the occasion of the Farewell Pilgrimage and (the narrator) reported:The donkey passed in front of the row and then he got down from it And joined the row along with the people}}
\hadithdefcmd{muslim}{1126}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَعَمْرٌو النَّاقِدُ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ قَالَ وَالنَّبِيُّ صلى الله عليه وسلم يُصَلِّي بِعَرَفَةَ ‏.‏\hadithno{1126}\hadithtrans{This hadith has been narrated by Ibn 'Uyaina on the authority of al-Zuhri with the same chain of transmitters and he reported:The Apostle of Allah (ﷺ) was leading prayer at 'Arafa}}
\hadithdefcmd{muslim}{1127}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ وَلَمْ يَذْكُرْ فِيهِ مِنًى وَلاَ عَرَفَةَ وَقَالَ فِي حَجَّةِ الْوَدَاعِ أَوْ يَوْمَ الْفَتْحِ ‏.‏\hadithno{1127}\hadithtrans{This hadith has been reported by Ma'mar on the authority of al-Zuhri with the came chain of transmitters, but here no mention has been made of Mina or 'Arafa, and he said:It was in the Farewell Pilgrimage or on the Day of Victory}}
\hadithdefcmd{muslim}{1128}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانَ أَحَدُكُمْ يُصَلِّي فَلاَ يَدَعْ أَحَدًا يَمُرُّ بَيْنَ يَدَيْهِ وَلْيَدْرَأْهُ مَا اسْتَطَاعَ فَإِنْ أَبَى فَلْيُقَاتِلْهُ فَإِنَّمَا هُوَ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{1128}\hadithtrans{Abu Sa'id al-Khudri reported that the Messenger of Allah (ﷺ) said:When any one of you prays he should not let anyone pass in front of him (if there is no sutra), and should try to turn him away as far as possible, but if he refuses to go, he should turn him away forcibly for he is a devil}}
\hadithdefcmd{muslim}{1129}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، حَدَّثَنَا ابْنُ هِلاَلٍ، - يَعْنِي حُمَيْدًا - قَالَ بَيْنَمَا أَنَا وَصَاحِبٌ، لِي نَتَذَاكَرُ حَدِيثًا إِذْ قَالَ أَبُو صَالِحٍ السَّمَّانُ أَنَا أُحَدِّثُكَ، مَا سَمِعْتُ مِنْ أَبِي سَعِيدٍ، وَرَأَيْتُ، مِنْهُ قَالَ بَيْنَمَا أَنَا مَعَ أَبِي سَعِيدٍ، يُصَلِّي يَوْمَ الْجُمُعَةِ إِلَى شَىْءٍ يَسْتُرُهُ مِنَ النَّاسِ إِذْ جَاءَ رَجُلٌ شَابٌّ مِنْ بَنِي أَبِي مُعَيْطٍ أَرَادَ أَنْ يَجْتَازَ بَيْنَ يَدَيْهِ فَدَفَعَ فِي نَحْرِهِ فَنَظَرَ فَلَمْ يَجِدْ مَسَاغًا إِلاَّ بَيْنَ يَدَىْ أَبِي سَعِيدٍ فَعَادَ فَدَفَعَ فِي نَحْرِهِ أَشَدَّ مِنَ الدَّفْعَةِ الأُولَى فَمَثَلَ قَائِمًا فَنَالَ مِنْ أَبِي سَعِيدٍ ثُمَّ زَاحَمَ النَّاسَ فَخَرَجَ فَدَخَلَ عَلَى مَرْوَانَ فَشَكَا إِلَيْهِ مَا لَقِيَ - قَالَ - وَدَخَلَ أَبُو سَعِيدٍ عَلَى مَرْوَانَ فَقَالَ لَهُ مَرْوَانُ مَا لَكَ وَلاِبْنِ أَخِيكَ جَاءَ يَشْكُوكَ ‏.‏ فَقَالَ أَبُو سَعِيدٍ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا صَلَّى أَحَدُكُمْ إِلَى شَىْءٍ يَسْتُرُهُ مِنَ النَّاسِ فَأَرَادَ أَحَدٌ أَنْ يَجْتَازَ بَيْنَ يَدَيْهِ فَلْيَدْفَعْ فِي نَحْرِهِ فَإِنْ أَبَى فَلْيُقَاتِلْهُ فَإِنَّمَا هُوَ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{1129}\hadithtrans{Abu Salih al-Samman reported:I narrate to you what I heard and saw from Abu Sa'id al-Khudri: One day I was with Abu Sa'id and he was saying prayer on Friday turning to a thing which concealed him from the people when a young man from Banu Mu'ait came there and he tried to pass in front of him; he turned him back by striking his chest. He looked about but finding no other way to pass except in front of Abu Sa'id, made a second attempt. He (Abu Sa'id) turned him away by Striking his chest more vigorously than the first stroke. He stood up and had a scuffle with Abu Sa'id. Then the people gathered there He came out and went to Marwan and complained to him what had happened to him. Abu Sa'id too came to Marwan. Marwin said to him: What has happened to you and the son of your brother that he came to complain against you? Abu Sa'id said: I heard from the Messenger of Allah (ﷺ) saying: When any one of you prays facing something which conceals him from people and anyone tries to pass in front of him, he should be turned away, but if he refuses, he should be forcibly restrained from it, for he is a devil}}
\hadithdefcmd{muslim}{1130}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ أَبِي فُدَيْكٍ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ صَدَقَةَ بْنِ يَسَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا كَانَ أَحَدُكُمْ يُصَلِّي فَلاَ يَدَعْ أَحَدًا يَمُرُّ بَيْنَ يَدَيْهِ فَإِنْ أَبَى فَلْيُقَاتِلْهُ فَإِنَّ مَعَهُ الْقَرِينَ ‏"‏ ‏.‏\hadithno{1130}\hadithtrans{Abdullah b. 'Umar reported that the Messenger of Allah (ﷺ) said:When any one of you prays, he should not allow anyone to pass before him, and if he refuses, he should be then forcibly resisted, for there is a devil with him}}
\hadithdefcmd{muslim}{1131}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا الضَّحَّاكُ بْنُ عُثْمَانَ، حَدَّثَنَا صَدَقَةُ بْنُ يَسَارٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{1131}\hadithtrans{This hadith has been narrated by Ibn Umar by another chain of transmitters}}
\hadithdefcmd{muslim}{1132}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، أَنَّ زَيْدَ بْنَ خَالِدٍ الْجُهَنِيَّ، أَرْسَلَهُ إِلَى أَبِي جُهَيْمٍ يَسْأَلُهُ مَاذَا سَمِعَ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْمَارِّ بَيْنَ يَدَىِ الْمُصَلِّي قَالَ أَبُو جُهَيْمٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ يَعْلَمُ الْمَارُّ بَيْنَ يَدَىِ الْمُصَلِّي مَاذَا عَلَيْهِ لَكَانَ أَنْ يَقِفَ أَرْبَعِينَ خَيْرًا لَهُ مِنْ أَنْ يَمُرَّ بَيْنَ يَدَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو النَّضْرِ لاَ أَدْرِي قَالَ أَرْبَعِينَ يَوْمًا أَوْ شَهْرًا أَوْ سَنَةً\hadithno{1132}\hadithtrans{Busr b Sa'id reported that Zaid b Khalid al-Juhani sent him to Abu Juhaim in order to ask him what he had heard from the Messenger of Allah (ﷺ) with regard to the passer in front of the worshipper. Abu Juhaim reported that the Messenger of Allah (ﷺ) said:If anyone who passes in front of a man who is praying knew the responsibility he incurs, he would stand still forty (years) rather than to pass in front of him Abu Nadr said: I do not know whether he said forty days or months or years}}
\hadithdefcmd{muslim}{1133}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ هَاشِمِ بْنِ حَيَّانَ الْعَبْدِيُّ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سَالِمٍ أَبِي النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، أَنَّ زَيْدَ بْنَ خَالِدٍ الْجُهَنِيَّ، أَرْسَلَ إِلَى أَبِي جُهَيْمٍ الأَنْصَارِيِّ مَا سَمِعْتَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ فَذَكَرَ بِمَعْنَى حَدِيثِ مَالِكٍ ‏.‏\hadithno{1133}\hadithtrans{This hadith has been narrated from Abu Juhaim Ansari by another chain of transmitters}}
\hadithdefcmd{muslim}{1134}{حَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، حَدَّثَنِي أَبِي، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ كَانَ بَيْنَ مُصَلَّى رَسُولِ اللَّهِ صلى الله عليه وسلم وَبَيْنَ الْجِدَارِ مَمَرُّ الشَّاةِ ‏.‏\hadithno{1134}\hadithtrans{Sahl b. Sa'd al-Si'idi reported:Between the place of worship where the Messenger of Allah (ﷺ) prayed and the wall, there was a gap through which a goat could pass}}
\hadithdefcmd{muslim}{1135}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ ابْنُ الْمُثَنَّى، حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، - عَنْ يَزِيدَ، - يَعْنِي ابْنَ أَبِي عُبَيْدٍ - عَنْ سَلَمَةَ، - وَهُوَ ابْنُ الأَكْوَعِ أَنَّهُ كَانَ يَتَحَرَّى مَوْضِعَ مَكَانِ الْمُصْحَفِ يُسَبِّحُ فِيهِ ‏.‏ وَذَكَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَتَحَرَّى ذَلِكَ الْمَكَانَ وَكَانَ بَيْنَ الْمِنْبَرِ وَالْقِبْلَةِ قَدْرُ مَمَرِّ الشَّاةِ ‏.‏\hadithno{1135}\hadithtrans{Salama b. Akwa' reported:He sought the place (in the mosque) where the copies of the Qur'an were kept and glorified Allah there, and the narrator made a mention that the Messenger of Allah (ﷺ) sought that place and that was between the pulpit and the qibla-a place where a goat could pass}}
\hadithdefcmd{muslim}{1136}{حَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مَكِّيٌّ، قَالَ يَزِيدُ أَخْبَرَنَا قَالَ كَانَ سَلَمَةُ يَتَحَرَّى الصَّلاَةَ عِنْدَ الأُسْطُوَانَةِ الَّتِي عِنْدَ الْمُصْحَفِ فَقُلْتُ لَهُ يَا أَبَا مُسْلِمٍ أَرَاكَ تَتَحَرَّى الصَّلاَةَ عِنْدَ هَذِهِ الأُسْطُوَانَةِ ‏.‏ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَتَحَرَّى الصَّلاَةَ عِنْدَهَا ‏.‏\hadithno{1136}\hadithtrans{Yazid reported:Salama sought to say prayer near the pillar which was by that place where copies of the Qur'an were kept. I said to him: Abu Muslim. I see you striving to offer your prayer by this pillar. He said: I saw the Messenger of Allah (ﷺ) seeking to pray by its side}}
\hadithdefcmd{muslim}{1137}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، ح قَالَ وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ يُونُسَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا قَامَ أَحَدُكُمْ يُصَلِّي فَإِنَّهُ يَسْتُرُهُ إِذَا كَانَ بَيْنَ يَدَيْهِ مِثْلُ آخِرَةِ الرَّحْلِ فَإِذَا لَمْ يَكُنْ بَيْنَ يَدَيْهِ مِثْلُ آخِرَةِ الرَّحْلِ فَإِنَّهُ يَقْطَعُ صَلاَتَهُ الْحِمَارُ وَالْمَرْأَةُ وَالْكَلْبُ الأَسْوَدُ ‏"‏ ‏.‏ قُلْتُ يَا أَبَا ذَرٍّ مَا بَالُ الْكَلْبِ الأَسْوَدِ مِنَ الْكَلْبِ الأَحْمَرِ مِنَ الْكَلْبِ الأَصْفَرِ قَالَ يَا ابْنَ أَخِي سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم كَمَا سَأَلْتَنِي فَقَالَ ‏"‏ الْكَلْبُ الأَسْوَدُ شَيْطَانٌ ‏"‏ ‏.‏\hadithno{1137}\hadithtrans{Abu Dharr reported:The Messenger of 'Allah (ﷺ) said: When any one of you stands for prayer and there is a thing before him equal to the back of the saddle that covers him and in case there is not before him (a thing) equal to the back of the saddle, his prayer would be cut off by (passing of an) ass, woman, and black Dog. I said: O Abu Dharr, what feature is there in a black dog which distinguish it from the red dog and the yellow dog? He said: O, son of my brother, I asked the Messenger of Allah (ﷺ) as you are asking me, and he said: The black dog is a devil}}
\hadithdefcmd{muslim}{1138}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، ح قَالَ وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح قَالَ وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي ح، قَالَ وَحَدَّثَنَا إِسْحَاقُ، أَيْضًا أَخْبَرَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ سَمِعْتُ سَلْمَ بْنَ أَبِي الذَّيَّالِ، ح قَالَ وَحَدَّثَنِي يُوسُفُ بْنُ حَمَّادٍ الْمَعْنِيُّ، حَدَّثَنَا زِيَادٌ الْبَكَّائِيُّ، عَنْ عَاصِمٍ الأَحْوَلِ، كُلُّ هَؤُلاَءِ عَنْ حُمَيْدِ بْنِ هِلاَلٍ، بِإِسْنَادِ يُونُسَ كَنَحْوِ حَدِيثِهِ ‏.‏\hadithno{1138}\hadithtrans{This hadith has been transmitted by Humaid b. Hilal on the authority of Yunus}}
\hadithdefcmd{muslim}{1139}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْمَخْزُومِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، - وَهُوَ ابْنُ زِيَادٍ - حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ الأَصَمِّ، حَدَّثَنَا يَزِيدُ بْنُ الأَصَمِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَقْطَعُ الصَّلاَةَ الْمَرْأَةُ وَالْحِمَارُ وَالْكَلْبُ وَيَقِي ذَلِكَ مِثْلُ مُؤْخِرَةِ الرَّحْلِ ‏"‏ ‏.‏\hadithno{1139}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: A woman, an ass and a dog disrupt the prayer, but something like the back of a saddle guards against that}}
\hadithdefcmd{muslim}{1140}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي مِنَ اللَّيْلِ وَأَنَا مُعْتَرِضَةٌ بَيْنَهُ وَبَيْنَ الْقِبْلَةِ كَاعْتِرَاضِ الْجِنَازَةِ ‏.‏\hadithno{1140}\hadithtrans{A'isha reported:The Prophet (ﷺ) used to pray at night while I lay interposed between him and the Qibla like a corpse on the bier}}
\hadithdefcmd{muslim}{1141}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي صَلاَتَهُ مِنَ اللَّيْلِ كُلَّهَا وَأَنَا مُعْتَرِضَةٌ بَيْنَهُ وَبَيْنَ الْقِبْلَةِ فَإِذَا أَرَادَ أَنْ يُوتِرَ أَيْقَظَنِي فَأَوْتَرْتُ ‏.‏\hadithno{1141}\hadithtrans{A'isha reported:The Apostle of Allah (ﷺ) said his whole prayer (Tahajjud prayer) during the night while I lay between him and the Qibla. When he intended to say Witr (prayer) he awakened me and I too said witr (prayer)}}
\hadithdefcmd{muslim}{1142}{وَحَدَّثَنِي عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بَكْرِ بْنِ حَفْصٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، قَالَ قَالَتْ عَائِشَةُ مَا يَقْطَعُ الصَّلاَةَ قَالَ فَقُلْنَا الْمَرْأَةُ وَالْحِمَارُ ‏.‏ فَقَالَتْ إِنَّ الْمَرْأَةَ لَدَابَّةُ سَوْءٍ لَقَدْ رَأَيْتُنِي بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم مُعْتَرِضَةً كَاعْتِرَاضِ الْجِنَازَةِ وَهُوَ يُصَلِّي ‏.‏\hadithno{1142}\hadithtrans{Urwa b. Zubair reported:'A'isha asked: What disrupts the prayer? We said: The woman and the ass. Upon this she remarked: Is the woman an ugly animal? I lay in front of the Messenger of Allah (ﷺ) like the bier of a corpse and he said prayer}}
\hadithdefcmd{muslim}{1143}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، ح قَالَ وَحَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنِي إِبْرَاهِيمُ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، ‏.‏ قَالَ الأَعْمَشُ وَحَدَّثَنِي مُسْلِمٌ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، وَذُكِرَ، عِنْدَهَا مَا يَقْطَعُ الصَّلاَةَ الْكَلْبُ وَالْحِمَارُ وَالْمَرْأَةُ ‏.‏ فَقَالَتْ عَائِشَةُ قَدْ شَبَّهْتُمُونَا بِالْحَمِيرِ وَالْكِلاَبِ ‏.‏ وَاللَّهِ لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي وَإِنِّي عَلَى السَّرِيرِ بَيْنَهُ وَبَيْنَ الْقِبْلَةِ مُضْطَجِعَةً فَتَبْدُو لِي الْحَاجَةُ فَأَكْرَهُ أَنْ أَجْلِسَ فَأُوذِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَنْسَلُّ مِنْ عِنْدِ رِجْلَيْهِ ‏.‏\hadithno{1143}\hadithtrans{Masruq reported:It was mentioned before'A'isha that prayer is invalidated (in case of passing) of a dog, an ass and a woman (before the worshipper, when he is not screened). Upon this 'A'isha said: You likened us to the asses and the dogs. By Allah I saw the Messenger of Allah (ﷺ) saying prayer while I lay on the bedstead interposing between him and the Qibla. When I felt the need, I did not like to wit to front (of the Holy Prophet) and perturb the Messenger of Allah (ﷺ) and quietly moved out from under its (i. e. of the bedstead) legs}}
\hadithdefcmd{muslim}{1144}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ عَدَلْتُمُونَا بِالْكِلاَبِ وَالْحُمُرِ لَقَدْ رَأَيْتُنِي مُضْطَجِعَةً عَلَى السَّرِيرِ فَيَجِيءُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَيَتَوَسَّطُ السَّرِيرَ فَيُصَلِّي فَأَكْرَهُ أَنْ أَسْنَحَهُ فَأَنْسَلُّ مِنْ قِبَلِ رِجْلَىِ السَّرِيرِ حَتَّى أَنْسَلَّ مِنْ لِحَافِي ‏.‏\hadithno{1144}\hadithtrans{Al-Aswad reported that 'A'isha said:You have made us equal to the dogs and the asses, whereas I lay on the bedstead and the Messenger of Allah (ﷺ) came there and stood in the middle of the bedstead and said prayer. I did not like to take off the quilt from me (in that state), so I moved away quietly from the front legs of the bedstead and thus came out of the quilt}}
\hadithdefcmd{muslim}{1145}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي النَّضْرِ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَنَامُ بَيْنَ يَدَىْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَرِجْلاَىَ فِي قِبْلَتِهِ فَإِذَا سَجَدَ غَمَزَنِي فَقَبَضْتُ رِجْلَىَّ وَإِذَا قَامَ بَسَطْتُهُمَا - قَالَتْ - وَالْبُيُوتُ يَوْمَئِذٍ لَيْسَ فِيهَا مَصَابِيحُ ‏.‏\hadithno{1145}\hadithtrans{A'isha reported:I was sleeping in front of the Mcsseinger ef Allah (ﷺ) with my legs between him and the Qibla. When he prostrated himself he pinched me and I drew up my legs, and when be stood up, I stretched them out. She said: At that time there were no lamps in the houses}}
\hadithdefcmd{muslim}{1146}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، ح قَالَ وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، جَمِيعًا عَنِ الشَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادِ بْنِ الْهَادِ، قَالَ حَدَّثَتْنِي مَيْمُونَةُ، زَوْجُ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي وَأَنَا حِذَاءَهُ وَأَنَا حَائِضٌ وَرُبَّمَا أَصَابَنِي ثَوْبُهُ إِذَا سَجَدَ ‏.‏\hadithno{1146}\hadithtrans{Maimuna, the wife of the Apostle (ﷺ), reported:The Messenger of Allah (ﷺ) said prayer and I (lay) opposite to him while I was in menses. Sometimes his clothes touched me when he prostrated}}
\hadithdefcmd{muslim}{1147}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالَ زُهَيْرٌ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، قَالَ سَمِعْتُهُ عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ وَأَنَا إِلَى جَنْبِهِ وَأَنَا حَائِضٌ وَعَلَىَّ مِرْطٌ وَعَلَيْهِ بَعْضُهُ إِلَى جَنْبِهِ ‏.‏\hadithno{1147}\hadithtrans{A'isha reported:The Apostle of Allah (ﷺ) said prayer at night and I was by his side in a state of meanses and I had a sheet pulled over me a portion of which was on his side}}
\hadithdefcmd{muslim}{1148}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، ‏.‏ أَنَّ سَائِلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّلاَةِ فِي الثَّوْبِ الْوَاحِدِ فَقَالَ ‏ "‏ أَوَلِكُلِّكُمْ ثَوْبَانِ ‏"‏ ‏.‏\hadithno{1148}\hadithtrans{Abu Huraira reported:An inquirer asked the Messenger of Allah (ﷺ) about the prayer in a single garment. He (the Holy Prophet) add: Has everyone of you two garments?}}
\hadithdefcmd{muslim}{1149}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح قَالَ وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، وَحَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ حَدَّثَنِي عُقَيْلُ بْنُ خَالِدٍ، كِلاَهُمَا عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{1149}\hadithtrans{A hadith like this has been narrated by Abu Huraira with another chain of transmitters}}
\hadithdefcmd{muslim}{1150}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالَ عَمْرٌو حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَادَى رَجُلٌ النَّبِيَّ صلى الله عليه وسلم فَقَالَ أَيُصَلِّي أَحَدُنَا فِي ثَوْبٍ وَاحِدٍ فَقَالَ ‏ "‏ أَوَكُلُّكُمْ يَجِدُ ثَوْبَيْنِ ‏"‏ ‏.‏\hadithno{1150}\hadithtrans{Abu Huraira reported:A person addressed the Messenger of Allah (ﷺ) and said to him: Can any one of us say prayer in one garment? He said: Do all of you possess two garments?}}
\hadithdefcmd{muslim}{1151}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُصَلِّي أَحَدُكُمْ فِي الثَّوْبِ الْوَاحِدِ لَيْسَ عَلَى عَاتِقَيْهِ مِنْهُ شَىْءٌ ‏"‏ ‏.‏\hadithno{1151}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) said: None of you must pray in a single garment of which no part comes over his shoulders}}
\hadithdefcmd{muslim}{1152}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، أَنَّ عُمَرَ بْنَ أَبِي سَلَمَةَ، أَخْبَرَهُ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِي ثَوْبٍ وَاحِدٍ مُشْتَمِلاً بِهِ فِي بَيْتِ أُمِّ سَلَمَةَ وَاضِعًا طَرَفَيْهِ عَلَى عَاتِقَيْهِ ‏.‏\hadithno{1152}\hadithtrans{Umar b. Abu Salama reported:I saw the Messenger of Allah (ﷺ) praying in Umm Salama's house in a single garment, placing its two ends over his shoulders}}
\hadithdefcmd{muslim}{1153}{حَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، عَنْ وَكِيعٍ، قَالَ حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ مُتَوَشِّحًا ‏.‏ وَلَمْ يَقُلْ مُشْتَمِلاً ‏.‏\hadithno{1153}\hadithtrans{This hadith has been narrated by Hisham b. 'Urwa with the same chain of transmitters except (with this difference) that the word mutawashshihan was used and not the word mushtamilan}}
\hadithdefcmd{muslim}{1154}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِي بَيْتِ أُمِّ سَلَمَةَ فِي ثَوْبٍ قَدْ خَالَفَ بَيْنَ طَرَفَيْهِ ‏.‏\hadithno{1154}\hadithtrans{Umar b. Abu Salama reported:I saw the Messenger of Allah (ﷺ) saying prayer in the house of Umm Salama in a single garment with its extremities crossing each other}}
\hadithdefcmd{muslim}{1155}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَعِيسَى بْنُ حَمَّادٍ، قَالاَ حَدَّثَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِي ثَوْبٍ وَاحِدٍ مُلْتَحِفًا مُخَالِفًا بَيْنَ طَرَفَيْهِ ‏.‏ زَادَ عِيسَى بْنُ حَمَّادٍ فِي رِوَايَتِهِ قَالَ عَلَى مَنْكِبَيْهِ ‏.‏\hadithno{1155}\hadithtrans{Umar b. Abu Salama reported:I saw the Messenger of Allah (ﷺ) praying in a single garment with its ends crossing each other. 'Isa b. Hammad added:" placing on his shoulders}}
\hadithdefcmd{muslim}{1156}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يُصَلِّي فِي ثَوْبٍ وَاحِدٍ مُتَوَشِّحًا بِهِ ‏.‏\hadithno{1156}\hadithtrans{Jabir reported:I saw the Messenger of Allah (ﷺ) praying in a single garment crossing the two ends}}
\hadithdefcmd{muslim}{1157}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سُفْيَانُ، ح قَالَ وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، عَنْ سُفْيَانَ، جَمِيعًا بِهَذَا الإِسْنَادِ وَفِي حَدِيثِ ابْنِ نُمَيْرٍ قَالَ دَخَلْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1157}\hadithtrans{This hadith has been narrated by Sufyan with the same chain of transmitters and in the hadith transmitted by Numair the words are:I called upon the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1158}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، أَنَّ أَبَا الزُّبَيْرِ الْمَكِّيَّ، حَدَّثَهُ أَنَّهُ، رَأَى جَابِرَ بْنَ عَبْدِ اللَّهِ يُصَلِّي فِي ثَوْبٍ مُتَوَشِّحًا بِهِ وَعِنْدَهُ ثِيَابُهُ ‏.‏ وَقَالَ جَابِرٌ إِنَّهُ رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم يَصْنَعُ ذَلِكَ ‏.‏\hadithno{1158}\hadithtrans{Abu Zubair reported that he saw Jabir b. 'Abdullah praying in a single garment crossing Its ends even though he had the garments, and Jabir said:He saw the Messenger of Allah (ﷺ) doing like this}}
\hadithdefcmd{muslim}{1159}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِعَمْرٍو - قَالَ حَدَّثَنِي عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، حَدَّثَنِي أَبُو سَعِيدٍ الْخُدْرِيُّ، أَنَّهُ دَخَلَ عَلَى النَّبِيِّ صلى الله عليه وسلم قَالَ فَرَأَيْتُهُ يُصَلِّي عَلَى حَصِيرٍ يَسْجُدُ عَلَيْهِ - قَالَ - وَرَأَيْتُهُ يُصَلِّي فِي ثَوْبٍ وَاحِدٍ مُتَوَشِّحًا بِهِ ‏.‏\hadithno{1159}\hadithtrans{Abu Sa'id al Khudri reported:I visited the Apostle (ﷺ) and saw him praying on a reed mat on which he was prostrating himself. And I saw him praying in a single garment with ends crossed with each other}}
\hadithdefcmd{muslim}{1160}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح قَالَ وَحَدَّثَنِيهِ سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي رِوَايَةِ أَبِي كُرَيْبٍ وَاضِعًا طَرَفَيْهِ عَلَى عَاتِقَيْهِ ‏.‏ وَرِوَايَةُ أَبِي بَكْرٍ وَسُوَيْدٍ مُتَوَشِّحًا بِهِ ‏.‏\hadithno{1160}\hadithtrans{This hadith has been narrated by A'mash with the came chain of transmitters, and in the narration of Abu Karaib the words are:" Placing its (mantle's) ends on his shoulders" ; and the narration transmitted by Abu Bakr and Suwaid (the words are):" the ends crossing with each other}}
