% Auto-generated chapter 33 for muslim
% Hadiths in this chapter: 257

\hadithdefcmd{muslim}{4701}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِيَانِ الْحِزَامِيَّ ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعَمْرٌو النَّاقِدُ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، كِلاَهُمَا عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَفِي حَدِيثِ زُهَيْرٍ يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم ‏.‏ وَقَالَ عَمْرٌو رِوَايَةً ‏ "‏ النَّاسُ تَبَعٌ لِقُرَيْشٍ فِي هَذَا الشَّأْنِ مُسْلِمُهُمْ لِمُسْلِمِهِمْ وَكَافِرُهُمْ لِكَافِرِهِمْ ‏"‏ ‏.‏\hadithno{4701}\hadithtrans{It has been narrarted on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:People are subservient to the Quraish: the Muslims among them being subservient to the Muslims among them, and the disbelievers among the people being subservient to the disbelievers among them}}
\hadithdefcmd{muslim}{4702}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ النَّاسُ تَبَعٌ لِقُرَيْشٍ فِي هَذَا الشَّأْنِ مُسْلِمُهُمْ تَبَعٌ لِمُسْلِمِهِمْ وَكَافِرُهُمْ تَبَعٌ لِكَافِرِهِمْ ‏"‏ ‏.‏\hadithno{4702}\hadithtrans{It has been narrated on the authority of Hammam b. Munabbih who said:This is one of the traditions narrated by Abu Huraira from the Messenger of Allah (ﷺ) who said: People are subservient to the Quraish: the Muslims among them being subservient to the Muslims among them, and the disbelievers among them being subservient to the disbelievers among them}}
\hadithdefcmd{muslim}{4703}{وَحَدَّثَنِي يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا ابْنُ جُرَيْجٍ، حَدَّثَنِي أَبُو الزُّبَيْرِ أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ النَّاسُ تَبَعٌ لِقُرَيْشٍ فِي الْخَيْرِ وَالشَّرِّ ‏"‏ ‏.‏\hadithno{4703}\hadithtrans{It has been narrated on the authority of Jabir b. 'Abdullah that the Messenger of Allah (ﷺ) said:People are the followers of Quraish in good as well as evil (i. e. in the customs of Islamic as well as pre-Islamic times)}}
\hadithdefcmd{muslim}{4704}{وَحَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا عَاصِمُ بْنُ مُحَمَّدِ بْنِ زَيْدٍ، عَنْ أَبِيهِ، قَالَ قَالَ عَبْدُ اللَّهِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَزَالُ هَذَا الأَمْرُ فِي قُرَيْشٍ مَا بَقِيَ مِنَ النَّاسِ اثْنَانِ ‏"‏ ‏.‏\hadithno{4704}\hadithtrans{It has been narrated on the authority of 'Abdullah that the Messenger of Allah (ﷺ) said:The Caliphate will remain among the Quraish even if only two persons are left (on the earth)}}
\hadithdefcmd{muslim}{4705}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ حُصَيْنٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ح وَحَدَّثَنَا رِفَاعَةُ بْنُ الْهَيْثَمِ الْوَاسِطِيُّ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ عَبْدِ اللَّهِ الطَّحَّانَ - عَنْ حُصَيْنٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ دَخَلْتُ مَعَ أَبِي عَلَى النَّبِيِّ صلى الله عليه وسلم فَسَمِعْتُهُ يَقُولُ ‏"‏ إِنَّ هَذَا الأَمْرَ لاَ يَنْقَضِي حَتَّى يَمْضِيَ فِيهِمُ اثْنَا عَشَرَ خَلِيفَةً ‏"‏ ‏.‏ قَالَ ثُمَّ تَكَلَّمَ بِكَلاَمٍ خَفِيَ عَلَىَّ - قَالَ - فَقُلْتُ لأَبِي مَا قَالَ قَالَ ‏"‏ كُلُّهُمْ مِنْ قُرَيْشٍ ‏"‏ ‏.‏\hadithno{4705}\hadithtrans{It has been narrated on the authority of Jabir b. Samura who said:I joined the company of the Prophet (ﷺ) with my father and I heard him say: This Caliphate will not end until there have been twelve Caliphs among them. The narrator said: Then he (the Holy Prophet) said something that I could not follow. I said to my father: What did he say? He said: He has said: All of them will be from the Quraish}}
\hadithdefcmd{muslim}{4706}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يَزَالُ أَمْرُ النَّاسِ مَاضِيًا مَا وَلِيَهُمُ اثْنَا عَشَرَ رَجُلاً ‏"‏ ‏.‏ ثُمَّ تَكَلَّمَ النَّبِيُّ صلى الله عليه وسلم بِكَلِمَةٍ خَفِيَتْ عَلَىَّ فَسَأَلْتُ أَبِي مَاذَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ كُلُّهُمْ مِنْ قُرَيْشٍ ‏"‏ ‏.‏\hadithno{4706}\hadithtrans{It has been reported on the authority of Jabir b. Samura who said:I heard the Messenger of Allah (ﷺ) say: The affairs of the people will continue to be conducted (well) as long as they are governed by twelve men. Then the Prophet (ﷺ) said words which were obscure to me. I asked my father: What did the Messenger of Allah (ﷺ) say? He said: All of the (twelve men) will be from the Quraish}}
\hadithdefcmd{muslim}{4707}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكِ بْنِ جَابِرِ بْنِ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ وَلَمْ يَذْكُرْ ‏ "‏ لاَ يَزَالُ أَمْرُ النَّاسِ مَاضِيًا ‏"‏ ‏.‏\hadithno{4707}\hadithtrans{This hadith has been narrated on the authority of Jabir b. Samura through another chain of transmitters}}
\hadithdefcmd{muslim}{4708}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ الأَزْدِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ سَمُرَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يَزَالُ الإِسْلاَمُ عَزِيزًا إِلَى اثْنَىْ عَشَرَ خَلِيفَةً ‏"‏ ‏.‏ ثُمَّ قَالَ كَلِمَةً لَمْ أَفْهَمْهَا فَقُلْتُ لأَبِي مَا قَالَ فَقَالَ ‏"‏ كُلُّهُمْ مِنْ قُرَيْشٍ ‏"‏ ‏.‏\hadithno{4708}\hadithtrans{It has been narrated on the authority of Jabir b. Samura who said:I heard the Messenger of Allah (ﷺ) say: Islam will continue to be triumphant until there have been twelve Caliphs. Then the Prophet (ﷺ) said something which I could not understand. I asked my father: What did he say? He said: He has said that all of them (twelve Caliphs) will be from the Quraish}}
\hadithdefcmd{muslim}{4709}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ دَاوُدَ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ، بْنِ سَمُرَةَ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ يَزَالُ هَذَا الأَمْرُ عَزِيزًا إِلَى اثْنَىْ عَشَرَ خَلِيفَةً ‏"‏ ‏.‏ قَالَ ثُمَّ تَكَلَّمَ بِشَىْءٍ لَمْ أَفْهَمْهُ فَقُلْتُ لأَبِي مَا قَالَ فَقَالَ ‏"‏ كُلُّهُمْ مِنْ قُرَيْشٍ ‏"‏ ‏.‏\hadithno{4709}\hadithtrans{It has been narrated on the authority of Jabir b. Samura that the Prophet (ﷺ) said:This order will continue to be dominant until there have been twelve Caliphs. The narrator says: Then he said something which I could not understand, and I said to my father: What did he say? My father told me that he said that all of them (Caliphs) would be from the Quraish}}
\hadithdefcmd{muslim}{4710}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا ابْنُ عَوْنٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ النَّوْفَلِيُّ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَزْهَرُ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ انْطَلَقْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَعِي أَبِي فَسَمِعْتُهُ يَقُولُ ‏"‏ لاَ يَزَالُ هَذَا الدِّينُ عَزِيزًا مَنِيعًا إِلَى اثْنَىْ عَشَرَ خَلِيفَةً ‏"‏ ‏.‏ فَقَالَ كَلِمَةً صَمَّنِيهَا النَّاسُ فَقُلْتُ لأَبِي مَا قَالَ قَالَ ‏"‏ كُلُّهُمْ مِنْ قُرَيْشٍ ‏"‏ ‏.‏\hadithno{4710}\hadithtrans{It has been reported on the authority of Jabir b. Samura who said:I went with my father to the Messenger of Allah (may peeace be upon him) and I heard him say: This religion would continue to remain powerful and dominant until there have been twelve Caliphs. Then he added something which I couldn't catch on account of the noise of the people. I asked my father: What did he say? My father said: He has said that all of them will be from the Quraish}}
\hadithdefcmd{muslim}{4711}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ قَالاَ حَدَّثَنَا حَاتِمٌ، - وَهُوَ ابْنُ إِسْمَاعِيلَ - عَنِ الْمُهَاجِرِ بْنِ مِسْمَارٍ، عَنْ عَامِرِ بْنِ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ كَتَبْتُ إِلَى جَابِرِ بْنِ سَمُرَةَ مَعَ غُلاَمِي نَافِعٍ أَنْ أَخْبِرْنِي بِشَىْءٍ، سَمِعْتَهُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَكَتَبَ إِلَىَّ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمَ جُمُعَةٍ عَشِيَّةَ رُجِمَ الأَسْلَمِيُّ يَقُولُ ‏"‏ لاَ يَزَالُ الدِّينُ قَائِمًا حَتَّى تَقُومَ السَّاعَةُ أَوْ يَكُونَ عَلَيْكُمُ اثْنَا عَشَرَ خَلِيفَةً كُلُّهُمْ مِنْ قُرَيْشٍ ‏"‏ ‏.‏ وَسَمِعْتُهُ يَقُولُ ‏"‏ عُصَيْبَةٌ مِنَ الْمُسْلِمِينَ يَفْتَتِحُونَ الْبَيْتَ الأَبْيَضَ بَيْتَ كِسْرَى أَوْ آلِ كِسْرَى ‏"‏ ‏.‏ وَسَمِعْتُهُ يَقُولُ ‏"‏ إِنَّ بَيْنَ يَدَىِ السَّاعَةِ كَذَّابِينَ فَاحْذَرُوهُمْ ‏"‏ ‏.‏ وَسَمِعْتُهُ يَقُولُ ‏"‏ إِذَا أَعْطَى اللَّهُ أَحَدَكُمْ خَيْرًا فَلْيَبْدَأْ بِنَفْسِهِ وَأَهْلِ بَيْتِهِ ‏"‏ ‏.‏ وَسَمِعْتُهُ يَقُولُ ‏"‏ أَنَا الْفَرَطُ عَلَى الْحَوْضِ ‏"‏ ‏.‏\hadithno{4711}\hadithtrans{It has been narrated on the authority of Amir b. Sa'd b. Abu Waqqas who said:I wrote (a letter) to Jabir b. Samura and sent it to him through my servant Nafi', asking him to inform me of something he had heard from the Messenger of Allah (ﷺ). He wrote to me (in reply): I heard the Messenger of Allah (ﷺ) say on Friday evening, the day on which al-Aslami was stoned to death (for committing adultery): The Islamic religion will continue until the Hour has been established, or you have been ruled over by twelve Caliphs, all of them being from the Quraish. also heard him say: A small force of the Muslims will capture the white palace, the police of the Persian Emperor or his descendants. I also heard him say: Before the Day of Judgment there will appear (a number of) impostors. You are to guard against them. I also heard him say: When God grants wealth to any one of you, he should first spend it on himself and his family (and then give it in charity to the poor). I heard him (also) say: I will be your forerunner at the Cistern (expecting your arrival)}}
\hadithdefcmd{muslim}{4712}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ مُهَاجِرِ، بْنِ مِسْمَارٍ عَنْ عَامِرِ بْنِ سَعْدٍ، أَنَّهُ أَرْسَلَ إِلَى ابْنِ سَمُرَةَ الْعَدَوِيِّ حَدِّثْنَا مَا، سَمِعْتَ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ حَاتِمٍ ‏.‏\hadithno{4712}\hadithtrans{Ibn Samura al-'Adawi reported:I heard Allah's Messenger (ﷺ) say, and he then narrated (the above-mentioned hadith)}}
\hadithdefcmd{muslim}{4713}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ حَضَرْتُ أَبِي حِينَ أُصِيبَ فَأَثْنَوْا عَلَيْهِ وَقَالُوا جَزَاكَ اللَّهُ خَيْرًا ‏.‏ فَقَالَ رَاغِبٌ وَرَاهِبٌ قَالُوا اسْتَخْلِفْ فَقَالَ أَتَحَمَّلُ أَمْرَكُمْ حَيًّا وَمَيِّتًا لَوَدِدْتُ أَنَّ حَظِّي مِنْهَا الْكَفَافُ لاَ عَلَىَّ وَلاَ لِي فَإِنْ أَسْتَخْلِفْ فَقَدِ اسْتَخْلَفَ مَنْ هُوَ خَيْرٌ مِنِّي - يَعْنِي أَبَا بَكْرٍ - وَإِنْ أَتْرُكْكُمْ فَقَدْ تَرَكَكُمْ مَنْ هُوَ خَيْرٌ مِنِّي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ عَبْدُ اللَّهِ فَعَرَفْتُ أَنَّهُ حِينَ ذَكَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم غَيْرُ مُسْتَخْلِفٍ ‏.‏\hadithno{4713}\hadithtrans{It has been narrated on the authority of 'Abdullah b. 'Umar who said:I was present with my father when he was wounded. People praised him and said: May God give you a noble recompense! He said: I am hopeful (of God's mercy) as well as afraid (of His wrath) People said: Appoint anyone as your successor. He said: Should I carry the burden of conducting your affairs in my life as well as in my death? (So far as Caliphate is concerned) I wish I could acquit myself (before the Almighty) in a way that there is neither anything to my credit nor anything to my discredit. If I would appoint my successor, (I would because) one better than me did so. (He meant Abu Bakr.) If I would leave You alone, (I would do so because) one better than me, i. e. the Messenger of Allah (ﷺ), did so. 'Abdullah says: When he mentioned the Messenger of Allah (ﷺ) I understood that he would not appoint anyone as Caliph}}
\hadithdefcmd{muslim}{4714}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، وَمُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، وَأَلْفَاظُهُمْ، مُتَقَارِبَةٌ قَالَ إِسْحَاقُ وَعَبْدٌ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، - أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَالِمٌ، عَنِ ابْنِ عُمَرَ، قَالَ دَخَلْتُ عَلَى حَفْصَةَ فَقَالَتْ أَعَلِمْتَ أَنَّ أَبَاكَ غَيْرُ مُسْتَخْلِفٍ قَالَ قُلْتُ مَا كَانَ لِيَفْعَلَ ‏.‏ قَالَتْ إِنَّهُ فَاعِلٌ ‏.‏ قَالَ فَحَلَفْتُ أَنِّي أُكَلِّمُهُ فِي ذَلِكَ فَسَكَتُّ حَتَّى غَدَوْتُ وَلَمْ أُكَلِّمْهُ - قَالَ - فَكُنْتُ كَأَنَّمَا أَحْمِلُ بِيَمِينِي جَبَلاً حَتَّى رَجَعْتُ فَدَخَلْتُ عَلَيْهِ فَسَأَلَنِي عَنْ حَالِ النَّاسِ وَأَنَا أُخْبِرُهُ - قَالَ - ثُمَّ قُلْتُ لَهُ إِنِّي سَمِعْتُ النَّاسَ يَقُولُونَ مَقَالَةً فَآلَيْتُ أَنْ أَقُولَهَا لَكَ زَعَمُوا أَنَّكَ غَيْرُ مُسْتَخْلِفٍ وَإِنَّهُ لَوْ كَانَ لَكَ رَاعِي إِبِلٍ أَوْ رَاعِي غَنَمٍ ثُمَّ جَاءَكَ وَتَرَكَهَا رَأَيْتَ أَنْ قَدْ ضَيَّعَ فَرِعَايَةُ النَّاسِ أَشَدُّ قَالَ فَوَافَقَهُ قَوْلِي فَوَضَعَ رَأْسَهُ سَاعَةً ثُمَّ رَفَعَهُ إِلَىَّ فَقَالَ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَحْفَظُ دِينَهُ وَإِنِّي لَئِنْ لاَ أَسْتَخْلِفْ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَسْتَخْلِفْ وَإِنْ أَسْتَخْلِفْ فَإِنَّ أَبَا بَكْرٍ قَدِ اسْتَخْلَفَ ‏.‏ قَالَ فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ ذَكَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَبَا بَكْرٍ فَعَلِمْتُ أَنَّهُ لَمْ يَكُنْ لِيَعْدِلَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم أَحَدًا وَأَنَّهُ غَيْرُ مُسْتَخْلِفٍ ‏.‏\hadithno{4714}\hadithtrans{It has been reported on the authority of Ibn 'Umar who said:I entered the apartment of (my sister) Hafsa. She said: Do yoa know that your father is not going to nominate his successor? I said: He won't do that (i. e. he would nominate). She said: He is going to do that. The narrator said: I took an oath that I will talk to him about the matter. I kept quiet until the next morning, still I did not talk to him, and I felt as if I were carryint, a mountain on my right hand. At last I came to him and entered his apartment. (Seeing me) he began to ask me about the condition of the people, and I informed him (about them). Then I said to him: I heard something from the people and took an oath that I will communicate it to you. They presume that you are not going to nominate a successor. If a grazer of camels and sheep that you had appointed comes back to you leaving the cattle, you will (certainly) think that the cattle are lost. To look after the people is more serious and grave. (The dying Caliph) was moved at my words. He bent his head in a thoughtful mood for some time and raised it to me and said: God will doubtlessly protect His religion. If I do not nominate a successor (I have a precedent before me), for the Messenger of Allah (ﷺ) did not nominate his successor. And if I nominate one (I have a precedent), for Abu Bakr did nominate. The narrator (Ibn Umar) said: By God. when he mentioned the Messenger of Allah (ﷺ) and Abu Bakr, I (at once) understood that he would not place anyone at a par with the Messenger of Allah (ﷺ) and would not nominate anyone}}
\hadithdefcmd{muslim}{4715}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنَا الْحَسَنُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، بْنُ سَمُرَةَ قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا عَبْدَ الرَّحْمَنِ لاَ تَسْأَلِ الإِمَارَةَ فَإِنَّكَ إِنْ أُعْطِيتَهَا عَنْ مَسْأَلَةٍ أُكِلْتَ إِلَيْهَا وَإِنْ أُعْطِيتَهَا عَنْ غَيْرِ مَسْأَلَةٍ أُعِنْتَ عَلَيْهَا ‏"‏ ‏.‏\hadithno{4715}\hadithtrans{It has been reported on the authority of 'Abd al-Rahman b. Samura who said:The Messenger of Allah (ﷺ) said to me: 'Abd al-Rahman, do not ask for a position of authority, for if you are granted this position as a result of your asking for it, you will be left alone (without God's help to discharge the responsibilities attendant thereon), and it you are granted it without making any request for it, you will be helped (by God in the discharge of your duties)}}
\hadithdefcmd{muslim}{4716}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ يُونُسَ، ح وَحَدَّثَنِي عَلِيُّ، بْنُ حُجْرٍ السَّعْدِيُّ حَدَّثَنَا هُشَيْمٌ، عَنْ يُونُسَ، وَمَنْصُورٍ، وَحُمَيْدٍ، ح وَحَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ سِمَاكِ بْنِ عَطِيَّةَ، وَيُونُسَ بْنِ عُبَيْدٍ، وَهِشَامِ بْنِ حَسَّانَ، كُلُّهُمْ عَنِ الْحَسَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ جَرِيرٍ ‏.‏\hadithno{4716}\hadithtrans{The same tradition has been narrated through a different chain of transmitters}}
\hadithdefcmd{muslim}{4717}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ، بْنِ عَبْدِ اللَّهِ عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ دَخَلْتُ عَلَى النَّبِيِّ صلى الله عليه وسلم أَنَا وَرَجُلاَنِ مِنْ بَنِي عَمِّي فَقَالَ أَحَدُ الرَّجُلَيْنِ يَا رَسُولَ اللَّهِ أَمِّرْنَا عَلَى بَعْضِ مَا وَلاَّكَ اللَّهُ عَزَّ وَجَلَّ ‏.‏ وَقَالَ الآخَرُ مِثْلَ ذَلِكَ فَقَالَ ‏ "‏ إِنَّا وَاللَّهِ لاَ نُوَلِّي عَلَى هَذَا الْعَمَلِ أَحَدًا سَأَلَهُ وَلاَ أَحَدًا حَرَصَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{4717}\hadithtrans{It has been narrated by Abu Musa who said:Two of my cousins and I entered the apartment of the Prophet (ﷺ). One of them said: Messenger of Allah, appoint us rulers of some lands that the Almighty and Glorious God has entrusted to thy care. The other also said something similar. He said: We do not appoint to this position one who asks for it nor anyone who is covetous for the same}}
\hadithdefcmd{muslim}{4718}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ حَاتِمٍ، - وَاللَّفْظُ لاِبْنِ حَاتِمٍ - قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ الْقَطَّانُ، حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، حَدَّثَنَا حُمَيْدُ بْنُ هِلاَلٍ، حَدَّثَنِي أَبُو بُرْدَةَ، قَالَ قَالَ أَبُو مُوسَى أَقْبَلْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَمَعِي رَجُلاَنِ مِنَ الأَشْعَرِيِّينَ أَحَدُهُمَا عَنْ يَمِينِي وَالآخَرُ عَنْ يَسَارِي فَكِلاَهُمَا سَأَلَ الْعَمَلَ وَالنَّبِيُّ صلى الله عليه وسلم يَسْتَاكُ فَقَالَ ‏"‏ مَا تَقُولُ يَا أَبَا مُوسَى أَوْ يَا عَبْدَ اللَّهِ بْنَ قَيْسٍ ‏"‏ ‏.‏ قَالَ فَقُلْتُ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا أَطْلَعَانِي عَلَى مَا فِي أَنْفُسِهِمَا وَمَا شَعَرْتُ أَنَّهُمَا يَطْلُبَانِ الْعَمَلَ ‏.‏ قَالَ وَكَأَنِّي أَنْظُرُ إِلَى سِوَاكِهِ تَحْتَ شَفَتِهِ وَقَدْ قَلَصَتْ فَقَالَ ‏"‏ لَنْ أَوْ لاَ نَسْتَعْمِلُ عَلَى عَمَلِنَا مَنْ أَرَادَهُ وَلَكِنِ اذْهَبْ أَنْتَ يَا أَبَا مُوسَى أَوْ يَا عَبْدَ اللَّهِ بْنَ قَيْسِ ‏"‏ ‏.‏ فَبَعَثَهُ عَلَى الْيَمَنِ ثُمَّ أَتْبَعَهُ مُعَاذَ بْنَ جَبَلٍ فَلَمَّا قَدِمَ عَلَيْهِ قَالَ انْزِلْ وَأَلْقَى لَهُ وِسَادَةً وَإِذَا رَجُلٌ عِنْدَهُ مُوثَقٌ قَالَ مَا هَذَا قَالَ هَذَا كَانَ يَهُودِيًّا فَأَسْلَمَ ثُمَّ رَاجَعَ دِينَهُ دِينَ السَّوْءِ فَتَهَوَّدَ قَالَ لاَ أَجْلِسُ حَتَّى يُقْتَلَ قَضَاءُ اللَّهِ وَرَسُولِهِ فَقَالَ اجْلِسْ نَعَمْ ‏.‏ قَالَ لاَ أَجْلِسُ حَتَّى يُقْتَلَ قَضَاءُ اللَّهِ وَرَسُولِهِ ثَلاَثَ مَرَّاتٍ ‏.‏ فَأَمَرَ بِهِ فَقُتِلَ ثُمَّ تَذَاكَرَا الْقِيَامَ مِنَ اللَّيْلِ فَقَالَ أَحَدُهُمَا مُعَاذٌ أَمَّا أَنَا فَأَنَامُ وَأَقُومُ وَأَرْجُو فِي نَوْمَتِي مَا أَرْجُو فِي قَوْمَتِي ‏.‏\hadithno{4718}\hadithtrans{It has been reported on the authority of Abu Musa who said:I went to the Prophet (ﷺ) and with me were two men from the Ash'ari tribe. One of them was on my right hand and the other on my left. Both of them made a request for a position (of authority) while the Prophet (ﷺ) was brushing his teeth with a tooth-stick. He said (to me): Abu Musa (or 'Abdullah b. Qais), what do you say (about the request they have made)? I said: By God Who sent thee on thy mission with truth, they did not disclose to me what they had in their minds, and I did not know that they would ask for a position. The narrator says (while recalling this hadith): I visualise as if I were looking at the miswak of the Prophet (ﷺ) between his lips. He (the Holy Prophet) said: We shall not or shall never appoint to the public offices (in our State) those who with to have them, but you may go, Abu Musa (or Abdullah b. Qais) (to take up your assignment). He sent him to Yemen as governor. then he sent Mu'adh b. jabal in his wake (to help him in the discharge of duties). When Mu'adh reached the camp of Abu Musa, the latter (received him and) said: Please get yourself down; and he spread for him a mattress, while there was a man bound hand and foot as a prisoner. Mu'adh said: Who is this? Abu Musa said: He was a Jew. He embraced Islam. Then he reverted to his false religion and became a Jew. Mu'adh said: I won't sit until he is killed according to the decree of Allah and His Apostle (ﷺ) (in this case). Abu Musa said: Be seated. It will be done. He said: I won't sit unless he is killed in accordance with the decree of Allah and His Apostle (ﷺ). He repeated these words thrice. Then Abu Musa ordered him (to be killed) and he was kilied. Then the two talked of standing in prayer at night. One of them, i. e. Mu'adh, said: I sleep (for a part of the night) and stand in prayer (for a part) and I hope that I shall get the same reward for steeping as I shall get for standing (in prayer)}}
\hadithdefcmd{muslim}{4719}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي شُعَيْبُ بْنُ اللَّيْثِ، حَدَّثَنِي اللَّيْثُ، بْنُ سَعْدٍ حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، عَنْ بَكْرِ بْنِ عَمْرٍو، عَنِ الْحَارِثِ بْنِ يَزِيدَ الْحَضْرَمِيِّ، عَنِ ابْنِ حُجَيْرَةَ الأَكْبَرِ، عَنْ أَبِي ذَرٍّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَلاَ تَسْتَعْمِلُنِي قَالَ فَضَرَبَ بِيَدِهِ عَلَى مَنْكِبِي ثُمَّ قَالَ ‏ "‏ يَا أَبَا ذَرٍّ إِنَّكَ ضَعِيفٌ وَإِنَّهَا أَمَانَةٌ وَإِنَّهَا يَوْمَ الْقِيَامَةِ خِزْىٌ وَنَدَامَةٌ إِلاَّ مَنْ أَخَذَهَا بِحَقِّهَا وَأَدَّى الَّذِي عَلَيْهِ فِيهَا ‏"‏ ‏.‏\hadithno{4719}\hadithtrans{It has been narrated on the authority of Abu Dharr who said:I said to the Prophet (ﷺ): Messenger of Allah, will you not appoint me to a public office? He stroked my shoulder with his hand and said: Abu Dharr, thou art weak and authority is a trust. and on the Day of judgment it is a cause of humiliation and repentance except for one who fulfils its obligations and (properly) discharges the duties attendant thereon}}
\hadithdefcmd{muslim}{4720}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، كِلاَهُمَا عَنِ الْمُقْرِئِ، قَالَ زُهَيْرٌ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ الْقُرَشِيِّ، عَنْ سَالِمِ، بْنِ أَبِي سَالِمٍ الْجَيْشَانِيِّ عَنْ أَبِيهِ، عَنْ أَبِي ذَرٍّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَا أَبَا ذَرٍّ إِنِّي أَرَاكَ ضَعِيفًا وَإِنِّي أُحِبُّ لَكَ مَا أُحِبُّ لِنَفْسِي لاَ تَأَمَّرَنَّ عَلَى اثْنَيْنِ وَلاَ تَوَلَّيَنَّ مَالَ يَتِيمٍ ‏"‏ ‏.‏\hadithno{4720}\hadithtrans{It has been reported on the authority of Abu Dharr that the Messenger of of Allah (ﷺ) said:Abu Dharr, I find that thou art weak and I like for thee what I like for myself. Do not rule over (even) two persons and do not manage the property of an orphan}}
\hadithdefcmd{muslim}{4721}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، نُمَيْرٍ قَالُوا حَدَّثَنَا سُفْيَانُ، بْنُ عُيَيْنَةَ عَنْ عَمْرٍو، - يَعْنِي ابْنَ دِينَارٍ - عَنْ عَمْرِو بْنِ أَوْسٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ ابْنُ نُمَيْرٍ وَأَبُو بَكْرٍ يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم وَفِي حَدِيثِ زُهَيْرٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْمُقْسِطِينَ عِنْدَ اللَّهِ عَلَى مَنَابِرَ مِنْ نُورٍ عَنْ يَمِينِ الرَّحْمَنِ عَزَّ وَجَلَّ وَكِلْتَا يَدَيْهِ يَمِينٌ الَّذِينَ يَعْدِلُونَ فِي حُكْمِهِمْ وَأَهْلِيهِمْ وَمَا وَلُوا ‏"‏ ‏.‏\hadithno{4721}\hadithtrans{It has been narrated on the authority of 'Abdullah b. 'Umar that the Messenger of Allah (ﷺ) said:Behold! the Dispensers of justice will be seated on the pulpits of light beside God, on the right side of the Merciful, Exalted and GlorioUS. Either side of the Being is the right side both being equally mrneritorious. (The Dispensers of justice are) those who do justice in their rules, in matters relating to their families and in all that they undertake to do}}
\hadithdefcmd{muslim}{4722}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي حَرْمَلَةُ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ شُمَاسَةَ قَالَ أَتَيْتُ عَائِشَةَ أَسْأَلُهَا عَنْ شَىْءٍ، فَقَالَتْ مِمَّنْ أَنْتَ فَقُلْتُ رَجُلٌ مِنْ أَهْلِ مِصْرَ ‏.‏ فَقَالَتْ كَيْفَ كَانَ صَاحِبُكُمْ لَكُمْ فِي غَزَاتِكُمْ هَذِهِ فَقَالَ مَا نَقَمْنَا مِنْهُ شَيْئًا إِنْ كَانَ لَيَمُوتُ لِلرَّجُلِ مِنَّا الْبَعِيرُ فَيُعْطِيهِ الْبَعِيرَ وَالْعَبْدُ فَيُعْطِيهِ الْعَبْدَ وَيَحْتَاجُ إِلَى النَّفَقَةِ فَيُعْطِيهِ النَّفَقَةَ فَقَالَتْ أَمَا إِنَّهُ لاَ يَمْنَعُنِي الَّذِي فَعَلَ فِي مُحَمَّدِ بْنِ أَبِي بَكْرٍ أَخِي أَنْ أُخْبِرَكَ مَا سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي بَيْتِي هَذَا ‏ "‏ اللَّهُمَّ مَنْ وَلِيَ مِنْ أَمْرِ أُمَّتِي شَيْئًا فَشَقَّ عَلَيْهِمْ فَاشْقُقْ عَلَيْهِ وَمَنْ وَلِيَ مِنْ أَمْرِ أُمَّتِي شَيْئًا فَرَفَقَ بِهِمْ فَارْفُقْ بِهِ ‏"‏ ‏.‏\hadithno{4722}\hadithtrans{It has been reported on the authority of Abd al-Rahman b. Shumasa who said:I came to A'isha to inquire something from her. She said: From which people art thou? I said: I am from the people of Egypt. She said: What was the behaviour of your governor towards you in this war of yours? I said: We did not experience anything bad from him. If the camel of a man from us died, he would bestow on him a camel. If any one of us lost his slave, he would give him a slave. If anybody was in need of the basic necessities of life, he would provide them with provisions. She said: Behold! the treatment that was meted out to my brother, Muhammad b. Abu Bakr, does not prevent me from telling you what I heard from the Messenger of Allah (ﷺ). He said in this house of mine: O God, who (happens to) acquire some kind of control over the affairs of my people and is hard upon them-be Thou hard upon him, and who (happens to) acquire some kind of control over the affairs of my people and is kind to them-be Thou kind to him}}
\hadithdefcmd{muslim}{4723}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ حَرْمَلَةَ، الْمِصْرِيِّ عَنْ عَبْدِ الرَّحْمَنِ بْنِ شُمَاسَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ\hadithno{4723}\hadithtrans{This hadith has been narrated on the authority of Abd al-Rahman b. Shumasa with another chain of transmitters}}
\hadithdefcmd{muslim}{4724}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ أَلاَ كُلُّكُمْ رَاعٍ وَكُلُّكُمْ مَسْئُولٌ عَنْ رَعِيَّتِهِ فَالأَمِيرُ الَّذِي عَلَى النَّاسِ رَاعٍ وَهُوَ مَسْئُولٌ عَنْ رَعِيَّتِهِ وَالرَّجُلُ رَاعٍ عَلَى أَهْلِ بَيْتِهِ وَهُوَ مَسْئُولٌ عَنْهُمْ وَالْمَرْأَةُ رَاعِيَةٌ عَلَى بَيْتِ بَعْلِهَا وَوَلَدِهِ وَهِيَ مَسْئُولَةٌ عَنْهُمْ وَالْعَبْدُ رَاعٍ عَلَى مَالِ سَيِّدِهِ وَهُوَ مَسْئُولٌ عَنْهُ أَلاَ فَكُلُّكُمْ رَاعٍ وَكُلُّكُمْ مَسْئُولٌ عَنْ رَعِيَّتِهِ ‏"‏ ‏.‏\hadithno{4724}\hadithtrans{It has been narrated on the authority of Ibn 'Umar that the Prophet (May be upon him) said:Beware. every one of you is a shepherd and every one is answerable with regard to his flock. The Caliph is a shepherd over the people and shall be questioned about his subjects (as to how he conducted their affairs). A man is a guardian over the members of his family and shal be questioned about them (as to how he looked after their physical and moral well-being). A woman is a guardian over the household of her husband and his children and shall be questioned about them (as to how she managed the household and brought up the children). A slave is a guardian over the property of his master and shall be questioned about it (as to how he safeguarded his trust). Beware, every one of you is a guardian and every one of you shall be questioned with regard to his trust}}
\hadithdefcmd{muslim}{4727}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَيَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، حُجْرٍ كُلُّهُمْ عَنْ إِسْمَاعِيلَ بْنِ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ح. وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏ بِمَعْنَى حَدِيثِ نَافِعٍ عَنِ ابْنِ عُمَرَ وَزَادَ فِي حَدِيثِ الزُّهْرِيِّ قَالَ وَحَسِبْتُ أَنَّهُ قَدْ قَالَ ‏ "‏ الرَّجُلُ رَاعٍ فِي مَالِ أَبِيهِ وَمَسْئُولٌ عَنْ رَعِيَّتِهِ ‏"‏ ‏.‏\hadithno{4727}\hadithtrans{This hadith has been transmitted on the authority of Ibn 'Umar, but there is (a slight change of wording) in the hadith transmitted through Zuhri that he said:" I think that he (the narrator) said: The man is a custodian of the wealth of his father, and he would be answerable for what is in his custody}}
\hadithdefcmd{muslim}{4728}{وَحَدَّثَنِي أَحْمَدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ وَهْبٍ، أَخْبَرَنِي عَمِّي عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي رَجُلٌ، سَمَّاهُ وَعَمْرُو بْنُ الْحَارِثِ عَنْ بُكَيْرٍ، عَنْ بُسْرِ بْنِ سَعِيدٍ، حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْمَعْنَى ‏.‏\hadithno{4728}\hadithtrans{A hadith having the same meaning has been transmitted on the authority of 'Abdullah b. 'Umar}}
\hadithdefcmd{muslim}{4729}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا أَبُو الأَشْهَبِ، عَنِ الْحَسَنِ، قَالَ عَادَ عُبَيْدُ اللَّهِ بْنُ زِيَادٍ مَعْقِلَ بْنَ يَسَارٍ الْمُزَنِيَّ فِي مَرَضِهِ الَّذِي مَاتَ فِيهِ فَقَالَ مَعْقِلٌ إِنِّي مُحَدِّثُكَ حَدِيثًا سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم لَوْ عَلِمْتُ أَنَّ لِي حَيَاةً مَا حَدَّثْتُكَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ عَبْدٍ يَسْتَرْعِيهِ اللَّهُ رَعِيَّةً يَمُوتُ يَوْمَ يَمُوتُ وَهُوَ غَاشٌّ لِرَعِيَّتِهِ إِلاَّ حَرَّمَ اللَّهُ عَلَيْهِ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{4729}\hadithtrans{It has been narrated on the authority of Hasan who said:Ubaidullah b Ziyad visited Ma'qil b. Yasir al-Muzani in his last iliness. Ma'qil said (to him): I am narrating to you a tradition I heard from the Messenger of Allah (ﷺ). If I knew that I am to survive this illness. I would, not narrate it to you. I heard the Messenger of Allah (ﷺ) say: If God appointed anyone ruler over a people and he died while he was still treacherous to his people, God would forbid his entry into Paradise}}
\hadithdefcmd{muslim}{4730}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، قَالَ دَخَلَ ابْنُ زِيَادٍ عَلَى مَعْقِلِ بْنِ يَسَارٍ وَهُوَ وَجِعٌ ‏.‏ بِمِثْلِ حَدِيثِ أَبِي الأَشْهَبِ وَزَادَ قَالَ أَلاَّ كُنْتَ حَدَّثْتَنِي هَذَا، قَبْلَ الْيَوْمِ قَالَ مَا حَدَّثْتُكَ أَوْ، لَمْ أَكُنْ لأُحَدِّثَكَ ‏.‏\hadithno{4730}\hadithtrans{It has been narrated through a different chain of transmitters on the authority of Hasan who said:Ibn, Ziyad paid a visit to Ma'qil b. Yasir who was seriously ill. Here follows the same tradition as has gone before with the addition that Ibn Ziyad asked: Why didn't you narrate this tradition to me before this day? Ma'qil reprimanded him and said: I did not narrate it to you or I was not going to narrate it to you}}
\hadithdefcmd{muslim}{4731}{وَحَدَّثَنَا أَبُو غَسَّانَ الْمِسْمَعِيُّ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي الْمَلِيحِ، أَنَّإِنِّي مُحَدِّثُكَ بِحَدِيثٍ لَوْلاَ أَنِّي فِي الْمَوْتِ لَمْ أُحَدِّثْكَ بِهِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ أَمِيرٍ يَلِي أَمْرَ الْمُسْلِمِينَ ثُمَّ لاَ يَجْهَدُ لَهُمْ وَيَنْصَحُ إِلاَّ لَمْ يَدْخُلْ مَعَهُمُ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{4731}\hadithtrans{It has been narrated on the authority of Abu Malik that Ubaidullah b. Ziyad visited Ma'qil b. Yaser in the latter's illness. Ma'qil said to him:I am narrating to you a tradition. If I were not at death's door, I would not narrate it to you. I heard the Messenger of Allah (may peace he upon him) say: A ruler who, having obtained control over the affairs of the Muslims, does not strive for their betterment and does not serve them sincerely shall not enter Paradise with them}}
\hadithdefcmd{muslim}{4732}{وَحَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ الْعَمِّيُّ، حَدَّثَنَا يَعْقُوبُ بْنُ إِسْحَاقَ، أَخْبَرَنِي سَوَادَةُ بْنُ أَبِي، الأَسْوَدِ حَدَّثَنِي أَبِي أَنَّ مَعْقِلَ بْنَ يَسَارٍ، مَرِضَ فَأَتَاهُ عُبَيْدُ اللَّهِ بْنُ زِيَادٍ يَعُودُهُ ‏.‏ نَحْوَ حَدِيثِ الْحَسَنِ عَنْ مَعْقِلٍ، ‏.‏\hadithno{4732}\hadithtrans{It has been narrated on the authority of Abu al-Aswad who said:My father related to me that Ma'qil b. Yasir fell ill. 'Ubaidullah b. Ziyad called on him to inquire after his health. Here follows the tradition as narrated by Hasan from Ma'qil}}
\hadithdefcmd{muslim}{4733}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنَا الْحَسَنُ، أَنَّ عَائِذَ بْنَ عَمْرٍو، - وَكَانَ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم - دَخَلَ عَلَى عُبَيْدِ اللَّهِ بْنِ زِيَادٍ فَقَالَ أَىْ بُنَىَّ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ شَرَّ الرِّعَاءِ الْحُطَمَةُ فَإِيَّاكَ أَنْ تَكُونَ مِنْهُمْ ‏"‏ ‏.‏ فَقَالَ لَهُ اجْلِسْ فَإِنَّمَا أَنْتَ مِنْ نُخَالَةِ أَصْحَابِ مُحَمَّدٍ صلى الله عليه وسلم ‏.‏ فَقَالَ وَهَلْ كَانَتْ لَهُمْ نُخَالَةٌ إِنَّمَا كَانَتِ النُّخَالَةُ بَعْدَهُمْ وَفِي غَيْرِهِمْ ‏.‏\hadithno{4733}\hadithtrans{It has been narrated on the authority of Hasan that A'idh b. 'Amr who was one of the Companions of the Messenger of Allah (ﷺ) called on 'Ubaidullah b. Ziyad and said (to him):O my son, I have heard the Messenger of Allah (ﷺ) say: The worst of guardians is the cruel ruler. Beware of being one of them. Ubaidullah said (to him out of arrogance): Sit you down. You are from the chaff of the Companions of Muhammad (ﷺ). A'idh said: Was there worthless chaff among them? Such worthless chaff appeared after them and among other people}}
\hadithdefcmd{muslim}{4734}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَبِي حَيَّانَ، عَنْ أَبِي، زُرْعَةَ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَامَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم ذَاتَ يَوْمٍ فَذَكَرَ الْغُلُولَ فَعَظَّمَهُ وَعَظَّمَ أَمْرَهُ ثُمَّ قَالَ ‏ "‏ لاَ أُلْفِيَنَّ أَحَدَكُمْ يَجِيءُ يَوْمَ الْقِيَامَةِ عَلَى رَقَبَتِهِ بَعِيرٌ لَهُ رُغَاءٌ يَقُولُ يَا رَسُولَ اللَّهِ أَغِثْنِي ‏.‏ فَأَقُولُ لاَ أَمْلِكُ لَكَ شَيْئًا قَدْ أَبْلَغْتُكَ ‏.‏ لاَ أُلْفِيَنَّ أَحَدَكُمْ يَجِيءُ يَوْمَ الْقِيَامَةِ عَلَى رَقَبَتِهِ فَرَسٌ لَهُ حَمْحَمَةٌ فَيَقُولُ يَا رَسُولَ اللَّهِ أَغِثْنِي ‏.‏ فَأَقُولُ لاَ أَمْلِكُ لَكَ شَيْئًا قَدْ أَبْلَغْتُكَ ‏.‏ لاَ أُلْفِيَنَّ أَحَدَكُمْ يَجِيءُ يَوْمَ الْقِيَامَةِ عَلَى رَقَبَتِهِ شَاةٌ لَهَا ثُغَاءٌ يَقُولُ يَا رَسُولَ اللَّهِ أَغِثْنِي ‏.‏ فَأَقُولُ لاَ أَمْلِكُ لَكَ شَيْئًا قَدْ أَبْلَغْتُكَ ‏.‏ لاَ أُلْفِيَنَّ أَحَدَكُمْ يَجِيءُ يَوْمَ الْقِيَامَةِ عَلَى رَقَبَتِهِ نَفْسٌ لَهَا صِيَاحٌ فَيَقُولُ يَا رَسُولَ اللَّهِ أَغِثْنِي ‏.‏ فَأَقُولُ لاَ أَمْلِكُ لَكَ شَيْئًا قَدْ أَبْلَغْتُكَ ‏.‏ لاَ أُلْفِيَنَّ أَحَدَكُمْ يَجِيءُ يَوْمَ الْقِيَامَةِ عَلَى رَقَبَتِهِ رِقَاعٌ تَخْفِقُ فَيَقُولُ يَا رَسُولَ اللَّهِ أَغِثْنِي ‏.‏ فَأَقُولُ لاَ أَمْلِكُ لَكَ شَيْئًا قَدْ أَبْلَغْتُكَ ‏.‏ لاَ أُلْفِيَنَّ أَحَدَكُمْ يَجِيءُ يَوْمَ الْقِيَامَةِ عَلَى رَقَبَتِهِ صَامِتٌ فَيَقُولُ يَا رَسُولَ اللَّهِ أَغِثْنِي فَأَقُولُ لاَ أَمْلِكُ لَكَ شَيْئًا قَدْ أَبْلَغْتُكَ ‏"‏ ‏.‏\hadithno{4734}\hadithtrans{It has been narrated on the authority of Abu Huraira who said:One day the Messenger of Allah (ﷺ) stood among us (to deliver a sermon). He talked about the misappropriation of booty, and declared it to be a serious matter and a grave sin. Then he said: I shouldn't find that any of you should come on the Day of Judgment with a growling camel mounted on his neck, and should appeal to me for help saying:" Messenger of Allah, help me." and I should say: I have no authority to help you; I already communicated to you. I shouldn't find that any of you should come on the Day of Judgment with a bleating ewe mounted on his neck, and he should say to me:" Messenger of Allah, help me," and I should say: I have no authority to help you; I conveyed to you. I shouldn't find that one of you should come on the Day of Judgment with a Person crying loudly mounted on his neck, and he should say to me:" Messenger of Allah, help me," and I should say: I have no authority to help you; I conveyed to you. I shouldn't find that any one of you should come on the Day of Judgment with fluttering clothes wrapped round his neck and he should say to me:" Messenger of Allah, help me," and I should say: I have no authority to help you; I conveyed to you. I shouldn't find that any of you should come on the Day of Judgment with a heap of gold and silver placed on his neck and he should say to me:" Messenger of Allah, help me." and I should say: I have no authority to help you; I already conveyed to you (the warning from the Almighty)}}
\hadithdefcmd{muslim}{4735}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ أَبِي حَيَّانَ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ أَبِي حَيَّانَ، وَعُمَارَةَ بْنِ الْقَعْقَاعِ، جَمِيعًا عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، بِمِثْلِ حَدِيثِ إِسْمَاعِيلَ عَنْ أَبِي حَيَّانَ، ‏.‏\hadithno{4735}\hadithtrans{The above tradition has been narrated on the same authority through different chains of transmitters}}
\hadithdefcmd{muslim}{4736}{وَحَدَّثَنِي أَحْمَدُ بْنُ سَعِيدِ بْنِ صَخْرٍ الدَّارِمِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ أَيُّوبَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْغُلُولَ فَعَظَّمَهُ ‏.‏ وَاقْتَصَّ الْحَدِيثَ قَالَ حَمَّادٌ ثُمَّ سَمِعْتُ يَحْيَى بَعْدَ ذَلِكَ يُحَدِّثُهُ فَحَدَّثَنَا بِنَحْوِ مَا حَدَّثَنَا عَنْهُ أَيُّوبُ ‏.‏\hadithno{4736}\hadithtrans{Abu Huraira has narrated this hadith with a slight variation of words}}
\hadithdefcmd{muslim}{4737}{وَحَدَّثَنِي أَحْمَدُ بْنُ الْحَسَنِ بْنِ خِرَاشٍ، حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَيُّوبُ، عَنْ يَحْيَى بْنِ سَعِيدِ بْنِ حَيَّانَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِنَحْوِ حَدِيثِهِمْ ‏.‏\hadithno{4737}\hadithtrans{Abu Huraira has narrated this hadith similar to the above mentioned hadith}}
\hadithdefcmd{muslim}{4738}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ اسْتَعْمَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً مِنَ الأَسْدِ يُقَالُ لَهُ ابْنُ اللُّتْبِيَّةِ - قَالَ عَمْرٌو وَابْنُ أَبِي عُمَرَ عَلَى الصَّدَقَةِ - فَلَمَّا قَدِمَ قَالَ هَذَا لَكُمْ وَهَذَا لِي أُهْدِيَ لِي قَالَ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَقَالَ ‏"‏ مَا بَالُ عَامِلٍ أَبْعَثُهُ فَيَقُولُ هَذَا لَكُمْ وَهَذَا أُهْدِيَ لِي ‏.‏ أَفَلاَ قَعَدَ فِي بَيْتِ أَبِيهِ أَوْ فِي بَيْتِ أُمِّهِ حَتَّى يَنْظُرَ أَيُهْدَى إِلَيْهِ أَمْ لاَ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لاَ يَنَالُ أَحَدٌ مِنْكُمْ مِنْهَا شَيْئًا إِلاَّ جَاءَ بِهِ يَوْمَ الْقِيَامَةِ يَحْمِلُهُ عَلَى عُنُقِهِ بَعِيرٌ لَهُ رُغَاءٌ أَوْ بَقَرَةٌ لَهَا خُوَارٌ أَوْ شَاةٌ تَيْعِرُ ‏"‏ ‏.‏ ثُمَّ رَفَعَ يَدَيْهِ حَتَّى رَأَيْنَا عُفْرَتَىْ إِبْطَيْهِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ هَلْ بَلَّغْتُ ‏"‏ ‏.‏ مَرَّتَيْنِ ‏.‏\hadithno{4738}\hadithtrans{It has been narrated on the authority of Abu Humaid as-Sa'idi who said:The Messenger of Allah (ﷺ) appointed a man from the Asad tribe who was called Ibn Lutbiyya in charge of Sadaqa (i. e. authorised hign to receive Sadaqa from the people on behalf of the State. When he returned (with the collictions), he said: This is for you and (this is mine as) it was presented to me as a gift. The narrator said: The Messenger of Allah (may peace be upod him) stood on the pulpit and praised God and extolled Him. Then he said: What about a State official whom I give an assignment and who (comes and) says: This is for you and this has been presented to me as a gift? Why didn't he remain in the house of his father or the house of his mother so that he could observe whether gifts were presented to him or not. By the Being in Whose Hand is the life of Muhammad, any one of you will not take anything from it but will bring it on the Day of Judgment, carrying on his neck a camel that will be growling, or a cow that will be bellowing or an ewe that will be bleating. Then he raised his hands so that we could see the whiteness of his armpits. Then he said twice: O God, I have conveyed (Thy Commandments)}}
\hadithdefcmd{muslim}{4739}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ اسْتَعْمَلَ النَّبِيُّ صلى الله عليه وسلم ابْنَ اللُّتْبِيَّةِ - رَجُلاً مِنَ الأَزْدِ - عَلَى الصَّدَقَةِ فَجَاءَ بِالْمَالِ فَدَفَعَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ هَذَا مَالُكُمْ وَهَذِهِ هَدِيَّةٌ أُهْدِيَتْ لِي ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَفَلاَ قَعَدْتَ فِي بَيْتِ أَبِيكَ وَأُمِّكَ فَتَنْظُرَ أَيُهْدَى إِلَيْكَ أَمْ لاَ ‏"‏ ‏.‏ ثُمَّ قَامَ النَّبِيُّ صلى الله عليه وسلم خَطِيبًا ‏.‏ ثُمَّ ذَكَرَ نَحْوَ حَدِيثِ سُفْيَانَ ‏.‏\hadithno{4739}\hadithtrans{It has been reported on the authority of Abu Humaid as-Sa'idi who said:The Prophet (ﷺ) appointed Ibn Lutbiyya, a man from the Azd tribe, in charge of Sadaqa (authorising him to receive gifts from the people on behalf of the State). He came with the collection, gave it to the Prophet (ﷺ), and said: This wealth is for you and this is a gift presented to me. The Prophet (ﷺ) said to him: Why didn't you remain in the house of your father and your mother to see whether gifts were presented to you or not. Then he stood up to deliver a sermon. Here follows the tradition like the tradition of Sufyan}}
\hadithdefcmd{muslim}{4740}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ أَبِي حُمَيْدٍ السَّاعِدِيِّ، قَالَ اسْتَعْمَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً مِنَ الأَزْدِ عَلَى صَدَقَاتِ بَنِي سُلَيْمٍ يُدْعَى ابْنَ الأُتْبِيَّةِ فَلَمَّا جَاءَ حَاسَبَهُ قَالَ هَذَا مَالُكُمْ وَهَذَا هَدِيَّةٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَهَلاَّ جَلَسْتَ فِي بَيْتِ أَبِيكَ وَأُمِّكَ حَتَّى تَأْتِيَكَ هَدِيَّتُكَ إِنْ كُنْتَ صَادِقًا ‏"‏ ‏.‏ ثُمَّ خَطَبَنَا فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَإِنِّي أَسْتَعْمِلُ الرَّجُلَ مِنْكُمْ عَلَى الْعَمَلِ مِمَّا وَلاَّنِي اللَّهُ فَيَأْتِي فَيَقُولُ هَذَا مَالُكُمْ وَهَذَا هَدِيَّةٌ أُهْدِيَتْ لِي ‏.‏ أَفَلاَ جَلَسَ فِي بَيْتِ أَبِيهِ وَأُمِّهِ حَتَّى تَأْتِيَهُ هَدِيَّتُهُ إِنْ كَانَ صَادِقًا وَاللَّهِ لاَ يَأْخُذُ أَحَدٌ مِنْكُمْ مِنْهَا شَيْئًا بِغَيْرِ حَقِّهِ إِلاَّ لَقِيَ اللَّهَ تَعَالَى يَحْمِلُهُ يَوْمَ الْقِيَامَةِ فَلأَعْرِفَنَّ أَحَدًا مِنْكُمْ لَقِيَ اللَّهَ يَحْمِلُ بَعِيرًا لَهُ رُغَاءٌ أَوْ بَقَرَةً لَهَا خُوَارٌ أَوْ شَاةً تَيْعِرُ ‏"‏ ‏.‏ ثُمَّ رَفَعَ يَدَيْهِ حَتَّى رُئِيَ بَيَاضُ إِبْطَيْهِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ هَلْ بَلَّغْتُ ‏"‏ ‏.‏ بَصُرَ عَيْنِي وَسَمِعَ أُذُنِي ‏.‏\hadithno{4740}\hadithtrans{It has been reported on the authority of Abu Humaid as-Sa'idi who said:The Messenger of Allah (ﷺ) appointed a man from the Azd tribe called Ibn al-Utbiyya, in charge of Sadaqat to be received from Banu Sulaim. When he came (back), the Messenger of Allah (ﷺ) asked him to render his account. He said: This wealth is for you (i.e. for the public treasury) and this is a gift (presented to me). The Messenger of Allah (ﷺ) said: You should have remained in the house of your father and your mother, until your gift came to you if you spoke the truth; then he addressed us. He praised God and extolled Him, and afterwards said: I appoint a man from you to a responsible post sharing with him authority that God has entrusted to me, and he comes to me saying: This wealth is for you (i.e. for the public treasury) and this is a gift presented to me. Why did he not remain in the house of his father and his mother and his gift came to him, if he was truthful? By God, any one of you will not take anything from (the public funds) without any justification, but will meet his Lord carrying it on himself on the Day of judgment. I will recognise any one of you meeting Allah and carrying a growling camel, or a cow bellowing or a goat bleating. Then he raised his hands so high that whiteness of his armpits could be seen. Then he said: O my Lord, I have conveyed (Thy Commandments). The narrator says: My eyes saw (the Prophet standing in that pose) and my ears heard (what he said)}}
\hadithdefcmd{muslim}{4741}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ، وَابْنُ، نُمَيْرٍ وَأَبُو مُعَاوِيَةَ ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ، أَبِي شَيْبَةَ حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، كُلُّهُمْ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِ عَبْدَةَ وَابْنِ نُمَيْرٍ فَلَمَّا جَاءَ حَاسَبَهُ ‏.‏ كَمَا قَالَ أَبُو أُسَامَةَ ‏.‏ وَفِي حَدِيثِ ابْنِ نُمَيْرٍ ‏ "‏ تَعْلَمُنَّ وَاللَّهِ وَالَّذِي نَفْسِي بِيَدِهِ لاَ يَأْخُذُ أَحَدُكُمْ مِنْهَا شَيْئًا ‏"‏ ‏.‏ وَزَادَ فِي حَدِيثِ سُفْيَانَ قَالَ بَصُرَ عَيْنِي وَسَمِعَ أُذُنَاىَ ‏.‏ وَسَلُوا زَيْدَ بْنَ ثَابِتٍ فَإِنَّهُ كَانَ حَاضِرًا مَعِي ‏.‏\hadithno{4741}\hadithtrans{This tradition has been hanoed down through a different chain of transmitters on the authority of Hisham with aslight variation in the wording}}
\hadithdefcmd{muslim}{4742}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنِ الشَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ ذَكْوَانَ، - وَهُوَ أَبُو الزِّنَادِ - عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَعْمَلَ رَجُلاً عَلَى الصَّدَقَةِ فَجَاءَ بِسَوَادٍ كَثِيرٍ فَجَعَلَ يَقُولُ هَذَا لَكُمْ وَهَذَا أُهْدِيَ إِلَىَّ ‏.‏ فَذَكَرَ نَحْوَهُ قَالَ عُرْوَةُ فَقُلْتُ لأَبِي حُمَيْدٍ السَّاعِدِيِّ أَسَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ مِنْ فِيهِ إِلَى أُذُنِي ‏.‏\hadithno{4742}\hadithtrans{It has been narrated on the authority of Abu Humaid as-Sa'idi that the Messenger of Allah (ﷺ) appointed a man in charge of Sadaqa (authorising him to receive charity from the people on behalf of the State). He came (back to the Holy prophet) with a large number of things and started saying:This is for you and this has been presented to me as a gift. Here follows the tradition that has gone before except that 'Urwa (one of the narrators in the chain of transmitters) asked Abu Humaid: Did you hear it from the Messenger of Allah (himself) (ﷺ)? He replied: My ears heard it from his mouth}}
\hadithdefcmd{muslim}{4743}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي، خَالِدٍ عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ عَدِيِّ بْنِ عَمِيرَةَ الْكِنْدِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَنِ اسْتَعْمَلْنَاهُ مِنْكُمْ عَلَى عَمَلٍ فَكَتَمَنَا مِخْيَطًا فَمَا فَوْقَهُ كَانَ غُلُولاً يَأْتِي بِهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ فَقَامَ إِلَيْهِ رَجُلٌ أَسْوَدُ مِنَ الأَنْصَارِ كَأَنِّي أَنْظُرُ إِلَيْهِ فَقَالَ يَا رَسُولَ اللَّهِ اقْبَلْ عَنِّي عَمَلَكَ قَالَ ‏"‏ وَمَا لَكَ ‏"‏ ‏.‏ قَالَ سَمِعْتُكَ تَقُولُ كَذَا وَكَذَا ‏.‏ قَالَ ‏"‏ وَأَنَا أَقُولُهُ الآنَ مَنِ اسْتَعْمَلْنَاهُ مِنْكُمْ عَلَى عَمَلٍ فَلْيَجِئْ بِقَلِيلِهِ وَكَثِيرِهِ فَمَا أُوتِيَ مِنْهُ أَخَذَ وَمَا نُهِيَ عَنْهُ انْتَهَى ‏"‏ ‏.‏\hadithno{4743}\hadithtrans{It has been reported on the authority of 'Adi b. 'Amira al-Kindi who said:I heard the Messenger of Allah (ﷺ) say: Whosoever from you is appointed by us to a position of authority and he conceals from us a needle or something smaller than that, it would be misappropriation (of public funds) and will (have to) produce it on the Day of Judgment. The narrator says: A dark-complexioned man from the Ansar stood up - I can visualise him still - and said: Messenger of Allah, take back from me your assignment. He said: What has happened to you? The man said: I have heard you say so and so. He said: I say that (even) now: Whosoever from you is appointed by us to a position of authority, he should bring everything, big or small, and whatever he is given therefrom he should take, and he should restrain himself from taking that which is forbidden}}
\hadithdefcmd{muslim}{4744}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي وَمُحَمَّدُ بْنُ بِشْرٍ، ح وَحَدَّثَنِي مُحَمَّدُ، بْنُ رَافِعٍ حَدَّثَنَا أَبُو أُسَامَةَ، قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، بِهَذَا الإِسْنَادِ بِمِثْلِهِ ‏.‏\hadithno{4744}\hadithtrans{This hadith has been narrated on the authority of Isma'il with the same chain of transmitters}}
\hadithdefcmd{muslim}{4745}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا الْفَضْلُ بْنُ مُوسَى، حَدَّثَنَا إِسْمَاعِيلُ، بْنُ أَبِي خَالِدٍ أَخْبَرَنَا قَيْسُ بْنُ أَبِي حَازِمٍ، قَالَ سَمِعْتُ عَدِيَّ بْنَ عَمِيرَةَ الْكِنْدِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ بِمِثْلِ حَدِيثِهِمْ ‏.‏\hadithno{4745}\hadithtrans{Adi b. 'Amira al-Kindi heard Allah's Messenger (ﷺ) as saying (as) was narrated in the (above-mentioned) hadith}}
\hadithdefcmd{muslim}{4746}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ نَزَلَ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا أَطِيعُوا اللَّهَ وَأَطِيعُوا الرَّسُولَ وَأُولِي الأَمْرِ مِنْكُمْ‏\}‏ فِي عَبْدِ اللَّهِ بْنِ حُذَافَةَ بْنِ قَيْسِ بْنِ عَدِيٍّ السَّهْمِيِّ بَعَثَهُ النَّبِيُّ صلى الله عليه وسلم فِي سَرِيَّةٍ ‏.‏ أَخْبَرَنِيهِ يَعْلَى بْنُ مُسْلِمٍ عَنْ سَعِيدِ بْنِ جُبَيْرٍ عَنِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{4746}\hadithtrans{It has been narrated on the authority of Ibn Juraij that the Qur'anic injunction:" 0 you who believe, obey Allah, His Apostle and those in authority from amongst You" (iv. 59) -was revealed in respect of 'Abdullah b. Hudhafa b. Qais b. Adi al-Sahmi who was despatched by the Prophet (ﷺ) as leader of a military campaign. The narrator said: He was informed of this fact by Ya'la b. Muslim who was informed by Sa'id b. Jubair who in turn was informed by Ibn Abbas}}
\hadithdefcmd{muslim}{4749}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَهُ قَالَ حَدَّثَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ أَطَاعَنِي فَقَدْ أَطَاعَ اللَّهَ وَمَنْ عَصَانِي فَقَدْ عَصَى اللَّهَ وَمَنْ أَطَاعَ أَمِيرِي فَقَدْ أَطَاعَنِي وَمَنْ عَصَى أَمِيرِي فَقَدْ عَصَانِي ‏"‏ ‏.‏\hadithno{4749}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:Whoso obeys me obeys God; and whose disobeys me disobeys God. Whoso obeys my commander obeys me, and whoso disobeys my commander disobeys me}}
\hadithdefcmd{muslim}{4750}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مَكِّيُّ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ زِيَادٍ، عَنِ ابْنِ شِهَابٍ، أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ سَوَاءً ‏\hadithno{4750}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{4751}{وَحَدَّثَنِي أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ يَعْلَى بْنِ عَطَاءٍ، عَنْ أَبِي عَلْقَمَةَ، قَالَ حَدَّثَنِي أَبُو هُرَيْرَةَ، مِنْ فِيهِ إِلَى فِيَّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ح. وَحَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ يَعْلَى بْنِ عَطَاءٍ، سَمِعَ أَبَا عَلْقَمَةَ، سَمِعَ أَبَا هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِهِمْ ‏\hadithno{4751}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira by more than one chain of transmitters}}
\hadithdefcmd{muslim}{4752}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِهِمْ ‏.‏\hadithno{4752}\hadithtrans{Hammam b. Munabbih has transmitted this hadith on the authority of Abu Huraira}}
\hadithdefcmd{muslim}{4753}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ حَيْوَةَ، أَنَّ أَبَا يُونُسَ، مَوْلَى أَبِي هُرَيْرَةَ حَدَّثَهُ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِذَلِكَ وَقَالَ ‏ "‏ مَنْ أَطَاعَ الأَمِيرَ ‏"‏ ‏.‏ وَلَمْ يَقُلْ أَمِيرِي وَكَذَلِكَ فِي حَدِيثِ هَمَّامٍ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{4753}\hadithtrans{According to one version of the tradition, the Messenger of Allah (ﷺ) said:Whoso obeys the commander. He did not say:" My commander}}
\hadithdefcmd{muslim}{4754}{وَحَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، كِلاَهُمَا عَنْ يَعْقُوبَ، قَالَ سَعِيدٌ حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ عَلَيْكَ السَّمْعَ وَالطَّاعَةَ فِي عُسْرِكَ وَيُسْرِكَ وَمَنْشَطِكَ وَمَكْرَهِكَ وَأَثَرَةٍ عَلَيْكَ ‏"‏ ‏.‏\hadithno{4754}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:It is obligatory for you to listen to the ruler and obey him in adversity and prosperity, in pleasure and displeasure, and even when another person is given (rather undue) preference over you}}
\hadithdefcmd{muslim}{4755}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَبْدُ اللَّهِ بْنُ بَرَّادٍ الأَشْعَرِيُّ، وَأَبُو كُرَيْبٍ قَالُوا حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ شُعْبَةَ، عَنْ أَبِي عِمْرَانَ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ إِنَّ خَلِيلِي أَوْصَانِي أَنْ أَسْمَعَ وَأُطِيعَ وَإِنْ كَانَ عَبْدًا مُجَدَّعَ الأَطْرَافِ ‏.‏\hadithno{4755}\hadithtrans{It has been narrated on the authority of Abu Dharr who said:My friend (i. e. the Holy Prophet) advised me to listen (to the man in position of authority) and obey (him) even if he were a slave maimed (and disabled)}}
\hadithdefcmd{muslim}{4756}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا النَّضْرُ، بْنُ شُمَيْلٍ جَمِيعًا عَنْ شُعْبَةَ، عَنْ أَبِي عِمْرَانَ، بِهَذَا الإِسْنَادِ وَقَالاَ فِي الْحَدِيثِ عَبْدًا حَبَشِيًّا مُجَدَّعَ الأَطْرَافِ ‏.‏\hadithno{4756}\hadithtrans{In another version of the tradition, we have the wording:" An Abyssinian slave maimed and disabled}}
\hadithdefcmd{muslim}{4757}{وَحَدَّثَنَاهُ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عِمْرَانَ، بِهَذَا الإِسْنَادِ كَمَا قَالَ ابْنُ إِدْرِيسَ عَبْدًا مُجَدَّعَ الأَطْرَافِ ‏.‏\hadithno{4757}\hadithtrans{Abu 'Imran narrated this hadith with a slight change of wording}}
\hadithdefcmd{muslim}{4758}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ يَحْيَى بْنِ حُصَيْنٍ، قَالَ سَمِعْتُ جَدَّتِي، تُحَدِّثُ أَنَّهَا سَمِعَتِ النَّبِيَّ صلى الله عليه وسلم يَخْطُبُ فِي حَجَّةِ الْوَدَاعِ وَهُوَ يَقُولُ ‏ "‏ وَلَوِ اسْتُعْمِلَ عَلَيْكُمْ عَبْدٌ يَقُودُكُمْ بِكِتَابِ اللَّهِ فَاسْمَعُوا لَهُ وَأَطِيعُوا ‏"‏ ‏.‏\hadithno{4758}\hadithtrans{It has been narrated on the authority of Yahya b. Husain who learnt the tradition from his grandmother. She said that she heard the Prophet (ﷺ) delivering his sermon on the occasion of the Last Pilgrimage. He was saying:If a slave is appointed over you and he conducts your affairs according to the Book of Allah, you should listen to him and obeey (his orders)}}
\hadithdefcmd{muslim}{4759}{وَحَدَّثَنَاهُ ابْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ وَقَالَ عَبْدًا حَبَشِيًّا ‏.‏\hadithno{4759}\hadithtrans{This hadith has been transmitted on the authority of Shu'ba with the same chain of transmitters, and he said:"An Abyssinian slave}}
\hadithdefcmd{muslim}{4760}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ وَقَالَ عَبْدًا حَبَشِيًّا مُجَدَّعًا ‏.‏\hadithno{4760}\hadithtrans{In other versions of the above tradition, the wordings are" an Abyssinian slave." and" a maimed Abyssinian slave}}
\hadithdefcmd{muslim}{4761}{وَحَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ حَبَشِيًّا مُجَدَّعًا وَزَادَ أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم بِمِنًى أَوْ بِعَرَفَاتٍ ‏\hadithno{4761}\hadithtrans{Another version of the tradition does not qualify the slave with the epithets" maimed,"" an Abyssinian" but makes the addition:" I have heard the Prophet (ﷺ) (say this) at Mina or 'Arafat}}
\hadithdefcmd{muslim}{4762}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ زَيْدِ بْنِ أَبِي، أُنَيْسَةَ عَنْ يَحْيَى بْنِ حُصَيْنٍ، عَنْ جَدَّتِهِ أُمِّ الْحُصَيْنِ، قَالَ سَمِعْتُهَا تَقُولُ، حَجَجْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَجَّةَ الْوَدَاعِ - قَالَتْ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَوْلاً كَثِيرًا ثُمَّ سَمِعْتُهُ يَقُولُ ‏ "‏ إِنْ أُمِّرَ عَلَيْكُمْ عَبْدٌ مُجَدَّعٌ - حَسِبْتُهَا قَالَتْ - أَسْوَدُ يَقُودُكُمْ بِكِتَابِ اللَّهِ فَاسْمَعُوا لَهُ وَأَطِيعُوا ‏"‏ ‏.‏\hadithno{4762}\hadithtrans{It has been narrated on the authority of Yahya b. Husain who learnt the tradition from his grandmother. Umm Husain. He said':I heard her say: I performed Hajjat-ul-Wada' in the company of the Messenger of Allah (ﷺ). He said a lot of things (on this occasion). Then I heard him say: If a maimed slave is appointed a commander over you the narrator says: I think she said:" a black stave" who leads you according to the Book of Allah, then listen to him and obey him}}
\hadithdefcmd{muslim}{4763}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ عَلَى الْمَرْءِ الْمُسْلِمِ السَّمْعُ وَالطَّاعَةُ فِيمَا أَحَبَّ وَكَرِهَ إِلاَّ أَنْ يُؤْمَرَ بِمَعْصِيَةٍ فَإِنْ أُمِرَ بِمَعْصِيَةٍ فَلاَ سَمْعَ وَلاَ طَاعَةَ ‏"‏ ‏.‏\hadithno{4763}\hadithtrans{It has been narrated on the authority of Ibn 'Umar that the Prophet (ﷺ) said:It is obligatory upon a Muslim that he should listen (to the ruler appointed over him) and obey him whether he likes it or not, except that he is ordered to do a sinful thing. If he is ordered to do a sinful act, a Muslim should neither listen to him nor should he obey his orders}}
\hadithdefcmd{muslim}{4764}{وَحَدَّثَنَاهُ زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى، وَهُوَ الْقَطَّانُ ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي كِلاَهُمَا، عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4764}\hadithtrans{This hadith has been transmitted on the authority of 'Ubaidullah}}
\hadithdefcmd{muslim}{4765}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ زُبَيْدٍ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَلِيٍّ، أَنَّعليه وسلم بَعَثَ جَيْشًا وَأَمَّرَ عَلَيْهِمْ رَجُلاً فَأَوْقَدَ نَارًا وَقَالَ ادْخُلُوهَا ‏.‏ فَأَرَادَ نَاسٌ أَنْ يَدْخُلُوهَا وَقَالَ الآخَرُونَ إِنَّا قَدْ فَرَرْنَا مِنْهَا ‏.‏ فَذُكِرَ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لِلَّذِينَ أَرَادُوا أَنْ يَدْخُلُوهَا ‏"‏ لَوْ دَخَلْتُمُوهَا لَمْ تَزَالُوا فِيهَا إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏ وَقَالَ لِلآخَرِينَ قَوْلاً حَسَنًا وَقَالَ ‏"‏ لاَ طَاعَةَ فِي مَعْصِيَةِ اللَّهِ إِنَّمَا الطَّاعَةُ فِي الْمَعْرُوفِ ‏"‏ ‏.‏\hadithno{4765}\hadithtrans{It has been narrated on the authority of Abu 'Abd al-Rahman from 'Ali that the Messenger of Allah (ﷺ) sent a force (on a mission) and appointed over them a man. He kindled a fire and said:Enter it. Some people made up their minds to enter it (the fire), (carrying out the order of their commander), but the others said: We fled from the fire (that's why we have come into the fold of Islam). The matter was reported to the Messenger of Allah (ﷺ). He said to those who Contemplated entering (the fire at the order of their commander): If you had entered it, you would have remained there until the Day of Judgment. He commanded the act of the latter group and said: There is no submission in matters involving God's disobedience or displeasure. Submission is obligatory only in what is good (and reasonable)}}
\hadithdefcmd{muslim}{4766}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَزُهَيْرُ بْنُ حَرْبٍ، وَأَبُو سَعِيدٍ الأَشَجُّ - وَتَقَارَبُوا فِي اللَّفْظِ - قَالُوا حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَلِيٍّ، قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَرِيَّةً وَاسْتَعْمَلَ عَلَيْهِمْ رَجُلاً مِنَ الأَنْصَارِ وَأَمَرَهُمْ أَنْ يَسْمَعُوا لَهُ وَيُطِيعُوا فَأَغْضَبُوهُ فِي شَىْءٍ فَقَالَ اجْمَعُوا لِي حَطَبًا ‏.‏ فَجَمَعُوا لَهُ ثُمَّ قَالَ أَوْقِدُوا نَارًا ‏.‏ فَأَوْقَدُوا ثُمَّ قَالَ أَلَمْ يَأْمُرْكُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ تَسْمَعُوا لِي وَتُطِيعُوا قَالُوا بَلَى ‏.‏ قَالَ فَادْخُلُوهَا ‏.‏ قَالَ فَنَظَرَ بَعْضُهُمْ إِلَى بَعْضٍ فَقَالُوا إِنَّمَا فَرَرْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ النَّارِ ‏.‏ فَكَانُوا كَذَلِكَ وَسَكَنَ غَضَبُهُ وَطُفِئَتِ النَّارُ فَلَمَّا رَجَعُوا ذَكَرُوا ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لَوْ دَخَلُوهَا مَا خَرَجُوا مِنْهَا إِنَّمَا الطَّاعَةُ فِي الْمَعْرُوفِ ‏"‏ ‏.‏\hadithno{4766}\hadithtrans{It has been narrated on the authority of 'All who said:The Mersenger of Allah (ﷺ) sent an expeditionand appointed over the Mujahids a man from the Ansar. (While making the appointment), he ordered that his work should be listened to and obeyed. They made him angry in a matter. He said: Collect for me dry wood. They collected it for him. Then he said: Kindle a fire. They kindled (the fire). Then he said: Didn't the Messenger of Allah (ﷺ) order you to listen to me and obey (my orders)? They said: Yes. He said: Enter the fire. The narrator says: (At this), they began to look at one another and said: We fled from the fire to (find refuge with) the Messenger of Allah (ﷺ) (and now you order us to enter it). They stood quiet until his anger cooled down and the fire went out. When they returned, they related the incident to the Messenger of Allah (ﷺ). He said: If they had entered it, they would not have come out. Obedience (to the commander) is obligatory only in what is good}}
\hadithdefcmd{muslim}{4767}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{4767}\hadithtrans{This hadith has been transmitted on the authority of A'mash}}
\hadithdefcmd{muslim}{4768}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، وَعُبَيْدِ اللَّهِ بْنِ عُمَرَ عَنْ عُبَادَةَ بْنِ الْوَلِيدِ بْنِ عُبَادَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ فِي الْعُسْرِ وَالْيُسْرِ وَالْمَنْشَطِ وَالْمَكْرَهِ وَعَلَى أَثَرَةٍ عَلَيْنَا وَعَلَى أَنْ لاَ نُنَازِعَ الأَمْرَ أَهْلَهُ وَعَلَى أَنْ نَقُولَ بِالْحَقِّ أَيْنَمَا كُنَّا لاَ نَخَافُ فِي اللَّهِ لَوْمَةَ لاَئِمٍ ‏.‏\hadithno{4768}\hadithtrans{It has been narrated on the authority of" Ubida who learnt the tradition from his father who, in turn, learnt it from his own father. 'Ubada's grandfather said:The Messenger of Allah (ﷺ) took an oath of allegiance from us on our listening to and obeying the orders of our commander in adversity and prosperity, in pleasure and displeasure (and even) when somebody is given preference over us, on our avoiding to dispute the delegation of powers to a person deemed to be a fit recipient thereof (in the eye of one who delegates it) and on our telling the truth in whatever position we be without fearing in the matter ef Allah the reproach of the reproacher}}
\hadithdefcmd{muslim}{4769}{وَحَدَّثَنَاهُ ابْنُ نُمَيْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ، - يَعْنِي ابْنَ إِدْرِيسَ - حَدَّثَنَا ابْنُ عَجْلاَنَ، وَعُبَيْدُ اللَّهِ بْنُ عُمَرَ وَيَحْيَى بْنُ سَعِيدٍ عَنْ عُبَادَةَ بْنِ الْوَلِيدِ، فِي هَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4769}\hadithtrans{This hadith has been narrated on the authority of 'Ubada b. Walid with the same chain of transmitters}}
\hadithdefcmd{muslim}{4770}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنْ يَزِيدَ، - وَهُوَ ابْنُ الْهَادِ - عَنْ عُبَادَةَ بْنِ الْوَلِيدِ بْنِ عُبَادَةَ بْنِ الصَّامِتِ، عَنْ أَبِيهِ، حَدَّثَنِي أَبِي قَالَ، بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ ابْنِ إِدْرِيسَ ‏.‏\hadithno{4770}\hadithtrans{The same tradition has been handed down through more than one chain of transmitters}}
\hadithdefcmd{muslim}{4771}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ وَهْبِ بْنِ مُسْلِمٍ، حَدَّثَنَا عَمِّي عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنَا عَمْرُو بْنُ الْحَارِثِ، حَدَّثَنِي بُكَيْرٌ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ جُنَادَةَ بْنِ أَبِي أُمَيَّةَ، قَالَ دَخَلْنَا عَلَى عُبَادَةَ بْنِ الصَّامِتِ وَهُوَ مَرِيضٌ فَقُلْنَا حَدِّثْنَا أَصْلَحَكَ اللَّهُ، بِحَدِيثٍ يَنْفَعُ اللَّهُ بِهِ سَمِعْتَهُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ دَعَانَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَبَايَعْنَاهُ فَكَانَ فِيمَا أَخَذَ عَلَيْنَا أَنْ بَايَعَنَا عَلَى السَّمْعِ وَالطَّاعَةِ فِي مَنْشَطِنَا وَمَكْرَهِنَا وَعُسْرِنَا وَيُسْرِنَا وَأَثَرَةٍ عَلَيْنَا وَأَنْ لاَ نُنَازِعَ الأَمْرَ أَهْلَهُ قَالَ ‏ "‏ إِلاَّ أَنْ تَرَوْا كُفْرًا بَوَاحًا عِنْدَكُمْ مِنَ اللَّهِ فِيهِ بُرْهَانٌ ‏"‏ ‏.‏\hadithno{4771}\hadithtrans{It has been narrated on the authority of Junida b. Abu Umayya who said:We called upon 'Ubada b. Samit who was ill and said to him: May God give you health I Narrate to us a tradition which God may prove beneficial (to us) and which you have heard from the Messenger of Allah (ﷺ). He said: The Messenger of Allah (ﷺ) called us and we took the oath of allegiance to him. Among the injunctions he made binding upon us was: Listening and obedience (to the Amir) in our pleasure and displeasure, in our adversity and prosperity, even when somebody is given preference over us, and without disputing the delegation of powers to a man duly invested with them (Obedience shall be accorded to him in all circumstances) except when you have clear signs of his disbelief in (or disobedience to) God-signs that could be used as a conscientious justification (for non-compliance with his orders)}}
\hadithdefcmd{muslim}{4772}{حَدَّثَنَا إِبْرَاهِيمُ، عَنْ مُسْلِمٍ، حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنِي وَرْقَاءُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا الإِمَامُ جُنَّةٌ يُقَاتَلُ مِنْ وَرَائِهِ وَيُتَّقَى بِهِ فَإِنْ أَمَرَ بِتَقْوَى اللَّهِ عَزَّ وَجَلَّ وَعَدَلَ كَانَ لَهُ بِذَلِكَ أَجْرٌ وَإِنْ يَأْمُرْ بِغَيْرِهِ كَانَ عَلَيْهِ مِنْهُ ‏"‏ ‏.‏\hadithno{4772}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Prophet of Allah (ﷺ) said:A commander (of the Muslims) is a shield for them. They fight behind him and they are protected by (him from tyrants and aggressors). If he enjoins fear of God, the Exalted and Glorious, and dispenses justice, there will be a (great) reward for him; and if he enjoins otherwise, it redounds on him}}
\hadithdefcmd{muslim}{4773}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ فُرَاتٍ الْقَزَّازِ، عَنْ أَبِي حَازِمٍ، قَالَ قَاعَدْتُ أَبَا هُرَيْرَةَ خَمْسَ سِنِينَ فَسَمِعْتُهُ يُحَدِّثُ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ كَانَتْ بَنُو إِسْرَائِيلَ تَسُوسُهُمُ الأَنْبِيَاءُ كُلَّمَا هَلَكَ نَبِيٌّ خَلَفَهُ نَبِيٌّ وَإِنَّهُ لاَ نَبِيَّ بَعْدِي وَسَتَكُونُ خُلَفَاءُ فَتَكْثُرُ ‏"‏ ‏.‏ قَالُوا فَمَا تَأْمُرُنَا قَالَ ‏"‏ فُوا بِبَيْعَةِ الأَوَّلِ فَالأَوَّلِ وَأَعْطُوهُمْ حَقَّهُمْ فَإِنَّ اللَّهَ سَائِلُهُمْ عَمَّا اسْتَرْعَاهُمْ ‏"‏ ‏.‏\hadithno{4773}\hadithtrans{It has been narrated by Abu Huraira that the Prophet (may pceace be upon him) said:Banu Isra'il were ruled over by the Prophets. When one Prophet died, another succeeded him; but after me there is no prophet and there will be caliphs and they will be quite large in number. His Companions said: What do you order us to do (in case we come to have more than one Caliph)? He said: The one to whom allegiance is sworn first has a supremacy over the others. Concede to them their due rights (i. e. obey them). God (Himself) will question them about the subjects whom He had entrusted to them}}
\hadithdefcmd{muslim}{4774}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَبْدُ اللَّهِ بْنُ بَرَّادٍ الأَشْعَرِيُّ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ، بْنُ إِدْرِيسَ عَنِ الْحَسَنِ بْنِ فُرَاتٍ، عَنْ أَبِيهِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4774}\hadithtrans{The same tradition has been transmitted by a different chain of narrators}}
\hadithdefcmd{muslim}{4775}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، وَوَكِيعٌ، ح وَحَدَّثَنِي أَبُو سَعِيدٍ، الأَشَجُّ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ خَشْرَمٍ، قَالاَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، كُلُّهُمْ عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ، وَهْبٍ عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهَا سَتَكُونُ بَعْدِي أَثَرَةٌ وَأُمُورٌ تُنْكِرُونَهَا ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ كَيْفَ تَأْمُرُ مَنْ أَدْرَكَ مِنَّا ذَلِكَ قَالَ ‏"‏ تُؤَدُّونَ الْحَقَّ الَّذِي عَلَيْكُمْ وَتَسْأَلُونَ اللَّهَ الَّذِي لَكُمْ ‏"‏ ‏.‏\hadithno{4775}\hadithtrans{It has been narrated on the authority of 'Abdullah who said:The Messenger of Allah (ﷺ) said: After me there will be favouritism and many things that you will not like. They (his Companions) said: Messenger of Allah, what do you order that one should do if anyone from us has to live through such a time? He said: You should discharge your own responsibility (by obeying your Amir), and ask God for your right (by guiding the Amir to the right path or by replacing him by one more just and God-fearing)}}
\hadithdefcmd{muslim}{4776}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، زُهَيْرٌ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ رَبِّ الْكَعْبَةِ، قَالَ دَخَلْتُ الْمَسْجِدَ فَإِذَا عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ الْعَاصِ جَالِسٌ فِي ظِلِّ الْكَعْبَةِ وَالنَّاسُ مُجْتَمِعُونَ عَلَيْهِ فَأَتَيْتُهُمْ فَجَلَسْتُ إِلَيْهِ فَقَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَنَزَلْنَا مَنْزِلاً فَمِنَّا مَنْ يُصْلِحُ خِبَاءَهُ وَمِنَّا مَنْ يَنْتَضِلُ وَمِنَّا مَنْ هُوَ فِي جَشَرِهِ إِذْ نَادَى مُنَادِي رَسُولِ اللَّهِ صلى الله عليه وسلم الصَّلاَةَ جَامِعَةً ‏.‏ فَاجْتَمَعْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنَّهُ لَمْ يَكُنْ نَبِيٌّ قَبْلِي إِلاَّ كَانَ حَقًّا عَلَيْهِ أَنْ يَدُلَّ أُمَّتَهُ عَلَى خَيْرِ مَا يَعْلَمُهُ لَهُمْ وَيُنْذِرَهُمْ شَرَّ مَا يَعْلَمُهُ لَهُمْ وَإِنَّ أُمَّتَكُمْ هَذِهِ جُعِلَ عَافِيَتُهَا فِي أَوَّلِهَا وَسَيُصِيبُ آخِرَهَا بَلاَءٌ وَأُمُورٌ تُنْكِرُونَهَا وَتَجِيءُ فِتْنَةٌ فَيُرَقِّقُ بَعْضُهَا بَعْضًا وَتَجِيءُ الْفِتْنَةُ فَيَقُولُ الْمُؤْمِنُ هَذِهِ مُهْلِكَتِي ‏.‏ ثُمَّ تَنْكَشِفُ وَتَجِيءُ الْفِتْنَةُ فَيَقُولُ الْمُؤْمِنُ هَذِهِ هَذِهِ ‏.‏ فَمَنْ أَحَبَّ أَنْ يُزَحْزَحَ عَنِ النَّارِ وَيَدْخُلَ الْجَنَّةَ فَلْتَأْتِهِ مَنِيَّتُهُ وَهُوَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ وَلْيَأْتِ إِلَى النَّاسِ الَّذِي يُحِبُّ أَنْ يُؤْتَى إِلَيْهِ وَمَنْ بَايَعَ إِمَامًا فَأَعْطَاهُ صَفْقَةَ يَدِهِ وَثَمَرَةَ قَلْبِهِ فَلْيُطِعْهُ إِنِ اسْتَطَاعَ فَإِنْ جَاءَ آخَرُ يُنَازِعُهُ فَاضْرِبُوا عُنُقَ الآخَرِ ‏"‏ ‏.‏ فَدَنَوْتُ مِنْهُ فَقُلْتُ لَهُ أَنْشُدُكَ اللَّهَ آنْتَ سَمِعْتَ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَهْوَى إِلَى أُذُنَيْهِ وَقَلْبِهِ بِيَدَيْهِ وَقَالَ سَمِعَتْهُ أُذُنَاىَ وَوَعَاهُ قَلْبِي ‏.‏ فَقُلْتُ لَهُ هَذَا ابْنُ عَمِّكَ مُعَاوِيَةُ يَأْمُرُنَا أَنْ نَأْكُلَ أَمْوَالَنَا بَيْنَنَا بِالْبَاطِلِ وَنَقْتُلَ أَنْفُسَنَا وَاللَّهُ يَقُولُ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا لاَ تَأْكُلُوا أَمْوَالَكُمْ بَيْنَكُمْ بِالْبَاطِلِ إِلاَّ أَنْ تَكُونَ تِجَارَةً عَنْ تَرَاضٍ مِنْكُمْ وَلاَ تَقْتُلُوا أَنْفُسَكُمْ إِنَّ اللَّهَ كَانَ بِكُمْ رَحِيمًا‏\}‏ قَالَ فَسَكَتَ سَاعَةً ثُمَّ قَالَ أَطِعْهُ فِي طَاعَةِ اللَّهِ وَاعْصِهِ فِي مَعْصِيَةِ اللَّهِ ‏.‏\hadithno{4776}\hadithtrans{It has been narrated on the authority of 'Abd al-Rahman b. Abd Rabb al-Ka'ba who said:I entered the mosque when 'Abdullah b. 'Amr b. al-'As was sitting in the shade of the Ka'ba and the people had gathered around him. I betook myself to them and sat near him. (Now) Abdullah said: I accompanied the Messenger of Allah (ﷺ) on a journey. We halted at a place. Some of us began to set right their tents, others began to compete with one another in shooting, and others began to graze their beasts, when an announcer of the Messenger of Allah (ﷺ) announced that the people should gather together for prayer, so we gathered around the Messenger of Allah (ﷺ). He said: It was the duty of every Prophet that has gone before me to guide his followers to what he knew was good for them and warn them against what he knew was bad for them; but this Umma of yours has its days of peace and (security) in the beginning of its career, and in the last phase of its existence it will be afflicted with trials and with things disagreeable to you. (In this phase of the Umma), there will be tremendous trials one after the other, each making the previous one dwindle into insignificance. When they would be afflicted with a trial, the believer would say: This is going to bring about my destruction. When at (the trial) is over, they would be afflicted with another trial, and the believer would say: This surely is going to be my end. Whoever wishes to be delivered from the fire and enter the garden should die with faith in Allah and the Last Day and should treat the people as he wishes to be treated by them. He who swears allegiance to a Caliph should give him the piedge of his hand and the sincerity of his heart (i. e. submit to him both outwardly as well as inwardly). He should obey him to the best of his capacity. It another man comes forward (as a claimant to Caliphate), disputing his authority, they (the Muslims) should behead the latter. The narrator says: I came close to him ('Abdullah b. 'Amr b. al-'As) and said to him: Can you say on oath that you heard it from the Messenger of Allah (ﷺ)? He pointed with his hands to his ears and his heart and said: My ears heard it and my mind retained it. I said to him: This cousin of yours, Mu'awiya, orders us to unjustly consume our wealth among ourselves and to kill one another, while Allah says:" O ye who believe, do not consume your wealth among yourselves unjustly, unless it be trade based on mutual agreement, and do not kill yourselves. Verily, God is Merciful to you" (iv. 29). The narrator says that (hearing this) Abdullah b. 'Amr b. al-As kept quiet for a while and then said: Obey him in so far as he is obedient to God; and diqobey him in matters involving disobedience to God}}
\hadithdefcmd{muslim}{4777}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ وَأَبُو سَعِيدٍ الأَشَجُّ قَالُوا حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{4777}\hadithtrans{This hadith has been narrated on the authority of A'mash with a different chain of transmitters}}
\hadithdefcmd{muslim}{4778}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو الْمُنْذِرِ، إِسْمَاعِيلُ بْنُ عُمَرَ حَدَّثَنَا يُونُسُ بْنُ، أَبِي إِسْحَاقَ الْهَمْدَانِيُّ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي السَّفَرِ، عَنْ عَامِرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ، رَبِّ الْكَعْبَةِ الصَّائِدِيِّ قَالَ رَأَيْتُ جَمَاعَةً عِنْدَ الْكَعْبَةِ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ الأَعْمَشِ ‏.‏\hadithno{4778}\hadithtrans{It has been narrated on the authority of 'Abd Rabb al-Ka'ba as-Sa'idl who said:I saw a group of people near the Ka'ba.... Then he narrated the tradition as narrated by A'mash}}
\hadithdefcmd{muslim}{4779}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أُسَيْدِ بْنِ حُضَيْرٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ خَلاَ بِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَلاَ تَسْتَعْمِلُنِي كَمَا اسْتَعْمَلْتَ فُلاَنًا فَقَالَ ‏ "‏ إِنَّكُمْ سَتَلْقَوْنَ بَعْدِي أَثَرَةً فَاصْبِرُوا حَتَّى تَلْقَوْنِي عَلَى الْحَوْضِ ‏"‏ ‏.‏\hadithno{4779}\hadithtrans{It has been narrated on the authority of Usaid b. Hudair that a man from the Ansar took the Messenger of Allah (ﷺ) aside and said to him:Will you not appoint me governor as you have appointed so and so? He (the Messenger of Allah) said: You will surely come across preferential treatment after me, so you should be patient until you meet me at the Cistern (Haud-i-Kauthar)}}
\hadithdefcmd{muslim}{4782}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عَلْقَمَةَ بْنِ وَائِلٍ الْحَضْرَمِيِّ، عَنْ أَبِيهِ، قَالَ سَأَلَ سَلَمَةُ بْنُ يَزِيدَ الْجُعْفِيُّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا نَبِيَّ اللَّهِ أَرَأَيْتَ إِنْ قَامَتْ عَلَيْنَا أُمَرَاءُ يَسْأَلُونَا حَقَّهُمْ وَيَمْنَعُونَا حَقَّنَا فَمَا تَأْمُرُنَا فَأَعْرَضَ عَنْهُ ثُمَّ سَأَلَهُ فَأَعْرَضَ عَنْهُ ثُمَّ سَأَلَهُ فِي الثَّانِيَةِ أَوْ فِي الثَّالِثَةِ فَجَذَبَهُ الأَشْعَثُ بْنُ قَيْسٍ وَقَالَ ‏ "‏ اسْمَعُوا وَأَطِيعُوا فَإِنَّمَا عَلَيْهِمْ مَا حُمِّلُوا وَعَلَيْكُمْ مَا حُمِّلْتُمْ ‏"‏ ‏.‏\hadithno{4782}\hadithtrans{It has been narrated on the authority of Alqama b. Wai'l al-Hadrami who learnt the tradition from his father. The latter said:Salama b. Yazid al-ju'afi asked the Messenger of Allah (ﷺ): Prophet of Allah, what do you think if we have rulers who rule over us and demand that we discharge our obligations towards them, but they (themselves) do not discharge their own responsibilities towards us? What do you order us to do? The Messenger of Allah (ﷺ) avoided giving any answer. Salama asked him again. He (again) avoided giving any answer. Then he asked again-it was the second time or the third time-when Ash'ath b. Qais (finding that the Prophet was unnecessarily being pressed for answer) pulled him aside and said: Listen to them and obey them, for on them shall he their burden and on you shall be your burden}}
\hadithdefcmd{muslim}{4783}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكٍ، بِهَذَا الإِسْنَادِ مِثْلَهُ وَقَالَ فَجَذَبَهُ الأَشْعَثُ بْنُ قَيْسٍ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اسْمَعُوا وَأَطِيعُوا فَإِنَّمَا عَلَيْهِمْ مَا حُمِّلُوا وَعَلَيْكُمْ مَا حُمِّلْتُمْ ‏"‏ ‏.‏\hadithno{4783}\hadithtrans{It has been narrated through a different chain of transmitters, on the authority of Simak who said:Ash'ath b. Qais pulled him (Salama b. Yazid) when the Messenger of Allah (ﷺ) said: Listen to them and obey them, for on them shall be the burden of what they do and on you shall be the burden of what you do}}
\hadithdefcmd{muslim}{4784}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ بْنِ، جَابِرٍ حَدَّثَنِي بُسْرُ بْنُ عُبَيْدِ اللَّهِ الْحَضْرَمِيُّ، أَنَّهُ سَمِعَ أَبَا إِدْرِيسَ الْخَوْلاَنِيَّ، يَقُولُ سَمِعْتُ حُذَيْفَةَ بْنَ الْيَمَانِ، يَقُولُ كَانَ النَّاسُ يَسْأَلُونَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْخَيْرِ وَكُنْتُ أَسْأَلُهُ عَنِ الشَّرِّ مَخَافَةَ أَنْ يُدْرِكَنِي فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّا كُنَّا فِي جَاهِلِيَّةٍ وَشَرٍّ فَجَاءَنَا اللَّهُ بِهَذَا الْخَيْرِ فَهَلْ بَعْدَ هَذَا الْخَيْرِ شَرٌّ قَالَ ‏"‏ نَعَمْ ‏"‏ فَقُلْتُ هَلْ بَعْدَ ذَلِكَ الشَّرِّ مِنْ خَيْرٍ قَالَ ‏"‏ نَعَمْ وَفِيهِ دَخَنٌ ‏"‏ ‏.‏ قُلْتُ وَمَا دَخَنُهُ قَالَ ‏"‏ قَوْمٌ يَسْتَنُّونَ بِغَيْرِ سُنَّتِي وَيَهْدُونَ بِغَيْرِ هَدْيِي تَعْرِفُ مِنْهُمْ وَتُنْكِرُ ‏"‏ ‏.‏ فَقُلْتُ هَلْ بَعْدَ ذَلِكَ الْخَيْرِ مِنْ شَرٍّ قَالَ ‏"‏ نَعَمْ دُعَاةٌ عَلَى أَبْوَابِ جَهَنَّمَ مَنْ أَجَابَهُمْ إِلَيْهَا قَذَفُوهُ فِيهَا ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ صِفْهُمْ لَنَا ‏.‏ قَالَ ‏"‏ نَعَمْ قَوْمٌ مِنْ جِلْدَتِنَا وَيَتَكَلَّمُونَ بِأَلْسِنَتِنَا ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ فَمَا تَرَى إِنْ أَدْرَكَنِي ذَلِكَ قَالَ ‏"‏ تَلْزَمُ جَمَاعَةَ الْمُسْلِمِينَ وَإِمَامَهُمْ ‏"‏ ‏.‏ فَقُلْتُ فَإِنْ لَمْ تَكُنْ لَهُمْ جَمَاعَةٌ وَلاَ إِمَامٌ قَالَ ‏"‏ فَاعْتَزِلْ تِلْكَ الْفِرَقَ كُلَّهَا وَلَوْ أَنْ تَعَضَّ عَلَى أَصْلِ شَجَرَةٍ حَتَّى يُدْرِكَكَ الْمَوْتُ وَأَنْتَ عَلَى ذَلِكَ ‏"‏ ‏.‏\hadithno{4784}\hadithtrans{It has been narrated on the authority of Hudhaifa b. al-Yaman who said:People used to ask the Messenger of Allah (ﷺ) about the good times, but I used to ask him about bad times fearing lest they overtake me. I said: Messenger of Allah, we were in the midst of ignorance and evil, and then God brought us this good (time through Islam). Is there any bad time after this good one? He said: Yes. I asked: Will there be a good time again after that bad time? He said: Yes, but therein will be a hidden evil. I asked: What will be the evil hidden therein? He said: (That time will witness the rise of) the people who will adopt ways other than mine and seek guidance other than mine. You will know good points as well as bad points. I asked: Will there be a bad time after this good one? He said: Yes. (A time will come) when there will be people standing and inviting at the gates of Hell. Whoso responds to their call they will throw them into the fire. I said: Messenger of Allah, describe them for us. He said: All right. They will be a people having the same complexion as ours and speaking our language. I said: Messenger of Allah, what do you suggest if I happen to live in that time? He said: You should stick to the main body of the Muslims and their leader. I said: If they have no (such thing as the) main body and have no leader? He said: Separate yourself from all these factions, though you may have to eat the roots of trees (in a jungle) until death comes to you and you are in this state}}
\hadithdefcmd{muslim}{4785}{وَحَدَّثَنِي مُحَمَّدُ بْنُ سَهْلِ بْنِ عَسْكَرٍ التَّمِيمِيُّ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا يَحْيَى، - وَهُوَ ابْنُ حَسَّانَ - حَدَّثَنَا مُعَاوِيَةُ، - يَعْنِي ابْنَ سَلاَّمٍ - حَدَّثَنَا زَيْدُ بْنُ سَلاَّمٍ، عَنْ أَبِي سَلاَّمٍ، قَالَ قَالَ حُذَيْفَةُ بْنُ الْيَمَانِ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا كُنَّا بِشَرٍّ فَجَاءَ اللَّهُ بِخَيْرٍ فَنَحْنُ فِيهِ فَهَلْ مِنْ وَرَاءِ هَذَا الْخَيْرِ شَرٌّ قَالَ نَعَمْ ‏.‏ قُلْتُ هَلْ وَرَاءَ ذَلِكَ الشَّرِّ خَيْرٌ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قُلْتُ فَهَلْ وَرَاءَ ذَلِكَ الْخَيْرِ شَرٌّ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قُلْتُ كَيْفَ قَالَ ‏"‏ يَكُونُ بَعْدِي أَئِمَّةٌ لاَ يَهْتَدُونَ بِهُدَاىَ وَلاَ يَسْتَنُّونَ بِسُنَّتِي وَسَيَقُومُ فِيهِمْ رِجَالٌ قُلُوبُهُمْ قُلُوبُ الشَّيَاطِينِ فِي جُثْمَانِ إِنْسٍ ‏"‏ ‏.‏ قَالَ قُلْتُ كَيْفَ أَصْنَعُ يَا رَسُولَ اللَّهِ إِنْ أَدْرَكْتُ ذَلِكَ قَالَ ‏"‏ تَسْمَعُ وَتُطِيعُ لِلأَمِيرِ وَإِنْ ضُرِبَ ظَهْرُكَ وَأُخِذَ مَالُكَ فَاسْمَعْ وَأَطِعْ ‏"‏ ‏.‏\hadithno{4785}\hadithtrans{It his been narrated through a different chain of transmitters, on the authority of Hudhaifa b. al-Yaman who said:Messenger of Allah, no doubt, we had an evil time (i. e. the days of Jahiliyya or ignorance) and God brought us a good time (i. e. Islamic period) through which we are now living Will there be a bad time after this good time? He (the Holy Prophet) said: Yes. I said: Will there be a good time after this bad time? He said: Yes. I said: Will there be a bad time after good time? He said: Yes. I said: How? Whereupon he said: There will be leaders who will not be led by my guidance and who will not adopt my ways? There will be among them men who will have the hearts of devils in the bodies of human beings. I said: What should I do. Messenger of Allah, if I (happen) to live in that time? He replied: You will listen to the Amir and carry out his orders; even if your back is flogged and your wealth is snatched, you should listen and obey}}
\hadithdefcmd{muslim}{4786}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا جَرِيرٌ، - يَعْنِي ابْنَ حَازِمٍ - حَدَّثَنَا غَيْلاَنُ بْنُ، جَرِيرٍ عَنْ أَبِي قَيْسِ بْنِ رِيَاحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ خَرَجَ مِنَ الطَّاعَةِ وَفَارَقَ الْجَمَاعَةَ فَمَاتَ مَاتَ مِيتَةً جَاهِلِيَّةً وَمَنْ قَاتَلَ تَحْتَ رَايَةٍ عُمِّيَّةٍ يَغْضَبُ لِعَصَبَةٍ أَوْ يَدْعُو إِلَى عَصَبَةٍ أَوْ يَنْصُرُ عَصَبَةً فَقُتِلَ فَقِتْلَةٌ جَاهِلِيَّةٌ وَمَنْ خَرَجَ عَلَى أُمَّتِي يَضْرِبُ بَرَّهَا وَفَاجِرَهَا وَلاَ يَتَحَاشَ مِنْ مُؤْمِنِهَا وَلاَ يَفِي لِذِي عَهْدٍ عَهْدَهُ فَلَيْسَ مِنِّي وَلَسْتُ مِنْهُ ‏"‏ ‏.‏\hadithno{4786}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:One who defected from obedience (to the Amir) and separated from the main body of the Muslims - if he died in that state-would die the death of one belonging to the days of Jahiliyya (i.e. would not die as a Muslim). One who fights under the banner of a people who are blind (to the cause for which they are fighting, i.e. do not know whether their cause is just or otherwise), who gets flared up with family pride, calls (people) to fight for their family honour, and supports his kith and kin (i.e. fights not for the cause of Allah but for the sake of this family or tribe) - if he is killed (in this fight), he dies as one belonging to the days of Jahiliyya. Whoso attacks my Ummah (indiscriminately) killing the righteous and the wicked of them, sparing not (even) those staunch in faith and fulfilling not his promise made with those who have been given a pledge of security - he has nothing to do with me and I have nothing to do with him}}
\hadithdefcmd{muslim}{4787}{وَحَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا أَيُّوبُ، عَنْ غَيْلاَنَ، بْنِ جَرِيرٍ عَنْ زِيَادِ بْنِ رِيَاحٍ الْقَيْسِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِنَحْوِ حَدِيثِ جَرِيرٍ وَقَالَ ‏ "‏ لاَ يَتَحَاشَى مِنْ مُؤْمِنِهَا ‏"‏ ‏.‏\hadithno{4787}\hadithtrans{The same tradition has been narrated by the same authority through another chain of transmitters with a slight difference in wording}}
\hadithdefcmd{muslim}{4788}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ زِيَادِ بْنِ رِيَاحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ خَرَجَ مِنَ الطَّاعَةِ وَفَارَقَ الْجَمَاعَةَ ثُمَّ مَاتَ مَاتَ مِيتَةً جَاهِلِيَّةً وَمَنْ قُتِلَ تَحْتَ رَايَةٍ عُمِّيَّةٍ يَغْضَبُ لِلْعَصَبَةِ وَيُقَاتِلُ لِلْعَصَبَةِ فَلَيْسَ مِنْ أُمَّتِي وَمَنْ خَرَجَ مِنْ أُمَّتِي عَلَى أُمَّتِي يَضْرِبُ بَرَّهَا وَفَاجِرَهَا لاَ يَتَحَاشَ مِنْ مُؤْمِنِهَا وَلاَ يَفِي بِذِي عَهْدِهَا فَلَيْسَ مِنِّي ‏"‏ ‏.‏\hadithno{4788}\hadithtrans{It has been narrated (through a different chain of transmitters) on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:Whoever defects from obedience (to the Amir) and separates from the main body of the Muslim - and dies in that state - dies the death of one belonging to the days of jahiliyya. And he who is killed under the banner of a man who is blind (to the cause for which he is fighting), who gets flared up with family pride and fights for his tribe is not from my Ummah, and whosoever from my followers attacks my followers (indiscriminately) killing the righteous and the wicked of them, sparing not (even) those staunch in faith and fulfilling not his obligation towards them who have been given a pledge (of security), is not from me (i.e. is not my follower)}}
\hadithdefcmd{muslim}{4789}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، بِهَذَا الإِسْنَادِ ‏.‏ أَمَّا ابْنُ الْمُثَنَّى فَلَمْ يَذْكُرِ النَّبِيَّ صلى الله عليه وسلم فِي الْحَدِيثِ وَأَمَّا ابْنُ بَشَّارٍ فَقَالَ فِي رِوَايَتِهِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِنَحْوِ حَدِيثِهِمْ ‏.‏\hadithno{4789}\hadithtrans{This hadlth has been narrated on the authority of Jarir with the same chain of transmitters with a slight variation in wording}}
\hadithdefcmd{muslim}{4790}{حَدَّثَنَا حَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنِ الْجَعْدِ أَبِي عُثْمَانَ، عَنْ أَبِي، رَجَاءٍ عَنِ ابْنِ عَبَّاسٍ، يَرْوِيهِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ رَأَى مِنْ أَمِيرِهِ شَيْئًا يَكْرَهُهُ فَلْيَصْبِرْ فَإِنَّهُ مَنْ فَارَقَ الْجَمَاعَةَ شِبْرًا فَمَاتَ فَمِيتَةٌ جَاهِلِيَّةٌ ‏"‏ ‏.‏\hadithno{4790}\hadithtrans{It has been narrated on the authority of Ibn 'Abbas that the messenger of Allah (ﷺ) said:One who found in his Amir something which he disliked should hold his patience, for one who separated from the main body of the Muslims even to the extent of a handspan and then he died would die the death of one belonging to the days of Jahiliyya}}
\hadithdefcmd{muslim}{4791}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا الْجَعْدُ، حَدَّثَنَا أَبُو رَجَاءٍ، الْعُطَارِدِيُّ عَنِ ابْنِ عَبَّاسٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَرِهَ مِنْ أَمِيرِهِ شَيْئًا فَلْيَصْبِرْ عَلَيْهِ فَإِنَّهُ لَيْسَ أَحَدٌ مِنَ النَّاسِ خَرَجَ مِنَ السُّلْطَانِ شِبْرًا فَمَاتَ عَلَيْهِ إِلاَّ مَاتَ مِيتَةً جَاهِلِيَّةً ‏"‏ ‏.‏\hadithno{4791}\hadithtrans{It has been narrated (through a different chain of transmitters) on the authority of Ibn Abbas that the Messenger of Allah (may peace be upoh him) said:One who dislikes a thing done by his Amir should be patient over it, for anyone from the people who withdraws (his obedience) from the government, even to the extent of a handspan and died in that conditions, would die the death of one belonging to the days of jahilliyya}}
\hadithdefcmd{muslim}{4792}{حَدَّثَنَا هُرَيْمُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا الْمُعْتَمِرُ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ أَبِي، مِجْلَزٍ عَنْ جُنْدَبِ بْنِ عَبْدِ اللَّهِ الْبَجَلِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قُتِلَ تَحْتَ رَايَةٍ عُمِّيَّةٍ يَدْعُو عَصَبِيَّةً أَوْ يَنْصُرُ عَصَبِيَّةً فَقِتْلَةٌ جَاهِلِيَّةٌ ‏"‏ ‏.‏\hadithno{4792}\hadithtrans{It has been narrated on the authority of Ibn 'Abdullah al-Bajali that the Messenger of Allah (ﷺ) said:One who is killed under the banner of a man who is blind (to his just cause), who raises the slogan of family or supports his own tribe, dies the death of one belonging to the days of Jahiliyya}}
\hadithdefcmd{muslim}{4793}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَاصِمٌ، - وَهُوَ ابْنُ مُحَمَّدِ بْنِ زَيْدٍ - عَنْ زَيْدِ بْنِ مُحَمَّدٍ، عَنْ نَافِعٍ، قَالَ جَاءَ عَبْدُ اللَّهِ بْنُ عُمَرَ إِلَى عَبْدِ اللَّهِ بْنِ مُطِيعٍ حِينَ كَانَ مِنْ أَمْرِ الْحَرَّةِ مَا كَانَ زَمَنَ يَزِيدَ بْنِ مُعَاوِيَةَ فَقَالَ اطْرَحُوا لأَبِي عَبْدِ الرَّحْمَنِ وِسَادَةً فَقَالَ إِنِّي لَمْ آتِكَ لأَجْلِسَ أَتَيْتُكَ لأُحَدِّثَكَ حَدِيثًا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُهُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ خَلَعَ يَدًا مِنْ طَاعَةٍ لَقِيَ اللَّهَ يَوْمَ الْقِيَامَةِ لاَ حُجَّةَ لَهُ وَمَنْ مَاتَ وَلَيْسَ فِي عُنُقِهِ بَيْعَةٌ مَاتَ مِيتَةً جَاهِلِيَّةً ‏"‏ ‏.‏\hadithno{4793}\hadithtrans{It has been reported on the authority of Nafi, that 'Abdullah b. Umar paid a visit to Abdullah b. Muti' in the days (when atrocities were perpetrated on the People Of Medina) at Harra in the time of Yazid b. Mu'awiya. Ibn Muti' said:Place a pillow for Abu 'Abd al-Rahman (family name of 'Abdullah b. 'Umar). But the latter said: I have not come to sit with you. I have come to you to tell you a tradition I heard from the Messenger of Allah (ﷺ). I heard him say: One who withdraws his band from obedience (to the Amir) will find no argument (in his defence) when he stands before Allah on the Day of Judgment, and one who dies without having bound himself by an oath of allegiance (to an Amir) will die the death of one belonging to the days of Jahillyya}}
\hadithdefcmd{muslim}{4794}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا يَحْيَى بْنُ عَبْدِ اللَّهِ بْنِ بُكَيْرٍ، حَدَّثَنَا لَيْثٌ، عَنْ عُبَيْدِ اللَّهِ، بْنِ أَبِي جَعْفَرٍ عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ أَتَى ابْنَ مُطِيعٍ ‏.‏ فَذَكَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{4794}\hadithtrans{It has been narrated on the authority of Ibn 'Umar that he visited Ibn Muti', and related from the Prophet (ﷺ) the tradition that has gone before}}
\hadithdefcmd{muslim}{4795}{حَدَّثَنَا عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ جَبَلَةَ، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، قَالاَ جَمِيعًا حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ نَافِعٍ عَنِ ابْنِ عُمَرَ ‏.‏\hadithno{4795}\hadithtrans{The same tradition has been transmitted by a different chain of narrators}}
\hadithdefcmd{muslim}{4796}{حَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ ، وَمُحَمَّدُ بْنُ بَشَّارٍ ، قَالَ ابْنُ نَافِعٍ : حَدَّثَنَا غُنْدَرٌ ، وقَالَ ابْنُ بَشَّارٍ : حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ ، حَدَّثَنَا شُعْبَةُ ، عَنْ زِيَادِ بْنِ عِلَاقَةَ ، قَالَ : سَمِعْتُ عَرْفَجَةَ ، قَالَ : سَمِعْتُ رَسُولَ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ ، يَقُولُ : " إِنَّهُ سَتَكُونُ هَنَاتٌ وَهَنَاتٌ ، فَمَنْ أَرَادَ أَنْ يُفَرِّقَ أَمْرَ هَذِهِ الْأُمَّةِ وَهِيَ جَمِيعٌ ، فَاضْرِبُوهُ بِالسَّيْفِ كَائِنًا مَنْ كَانَ\hadithno{4796}\hadithtrans{It has been narrated on the authority of 'Arfaja who said:I have heard the Messenger of Allah (ﷺ) say: Different evils will make their appearance in the near future. Anyone who tries to disrupt the affairs of this Umma while they are united you should strike him with the sword whoever he be. (If remonstrance does not prevail with him and he does not desist from his disruptive activities, he is to be killed)}}
\hadithdefcmd{muslim}{4797}{وَحَدَّثَنَا أَحْمَدُ بْنُ خِرَاشٍ، حَدَّثَنَا حَبَّانُ، حَدَّثَنَا أَبُو عَوَانَةَ، ح وَحَدَّثَنِي الْقَاسِمُ بْنُ، زَكَرِيَّاءَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْمُصْعَبُ بْنُ الْمِقْدَامِ الْخَثْعَمِيُّ، حَدَّثَنَا إِسْرَائِيلُ، ح وَحَدَّثَنِي حَجَّاجٌ، حَدَّثَنَا عَارِمُ بْنُ الْفَضْلِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُخْتَارِ، وَرَجُلٌ، سَمَّاهُ كُلُّهُمْ عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ عَرْفَجَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ غَيْرَ أَنَّ فِي حَدِيثِهِمْ جَمِيعًا ‏ "‏ فَاقْتُلُوهُ ‏"‏ ‏\hadithno{4797}\hadithtrans{In another version of the tradition narrated on the same authority through a different chains of transmitters we have the words:" Kill him}}
\hadithdefcmd{muslim}{4798}{وَحَدَّثَنِي عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ أَبِي يَعْفُورٍ، عَنْ أَبِيهِ، عَنْ عَرْفَجَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ أَتَاكُمْ وَأَمْرُكُمْ جَمِيعٌ عَلَى رَجُلٍ وَاحِدٍ يُرِيدُ أَنْ يَشُقَّ عَصَاكُمْ أَوْ يُفَرِّقَ جَمَاعَتَكُمْ فَاقْتُلُوهُ ‏"‏ ‏.‏\hadithno{4798}\hadithtrans{It has been narrated (through a still different chain of transmitters) on the Same authority (i. e. 'Arfaja) who said similarly-but adding:" Kill all of them." I heard the Messenger of Allah (ﷺ) say: When you are holding to one single man as your leader, you should kill who seeks to undermine your solidarity or disrupt your unity}}
\hadithdefcmd{muslim}{4799}{وَحَدَّثَنِي وَهْبُ بْنُ بَقِيَّةَ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي، نَضْرَةَ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا بُويِعَ لِخَلِيفَتَيْنِ فَاقْتُلُوا الآخَرَ مِنْهُمَا ‏"‏ ‏.‏\hadithno{4799}\hadithtrans{It has been narrated on the authority of Aba Sa'id al-Khudri that the Messenger of Allah (ﷺ) said:When oath of allegiance has been taken for two caliphs, kill the one for whom the oath was taken later}}
\hadithdefcmd{muslim}{4800}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ الأَزْدِيُّ، حَدَّثَنَا هَمَّامُ بْنُ يَحْيَى، حَدَّثَنَا قَتَادَةُ، عَنِ الْحَسَنِ، عَنْ ضَبَّةَ بْنِ مِحْصَنٍ، عَنْ أُمِّ سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ سَتَكُونُ أُمَرَاءُ فَتَعْرِفُونَ وَتُنْكِرُونَ فَمَنْ عَرَفَ بَرِئَ وَمَنْ أَنْكَرَ سَلِمَ وَلَكِنْ مَنْ رَضِيَ وَتَابَعَ ‏"‏ ‏.‏ قَالُوا أَفَلاَ نُقَاتِلُهُمْ قَالَ ‏"‏ لاَ مَا صَلَّوْا ‏"‏ ‏.‏\hadithno{4800}\hadithtrans{It has been narrated on the authority of Umm Salama that the Messenger of Allah (ﷺ) said:In the near future there will be Amirs and you will like their good deeds and dislike their bad deeds. One who sees through their bad deeds (and tries to prevent their repetition by his band or through his speech), is absolved from blame, but one who hates their bad deeds (in the heart of his heart, being unable to prevent their recurrence by his hand or his tongue), is (also) fafe ( so far as God's wrath is concerned). But one who approves of their bad deeds and imitates them is spiritually ruined. People asked (the Holy Prophet): Shouldn't we fight against them? He replied: No, as long as they say their prayers}}
\hadithdefcmd{muslim}{4801}{وَحَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، وَمُحَمَّدُ بْنُ بَشَّارٍ، جَمِيعًا عَنْ مُعَاذٍ، - وَاللَّفْظُ لأَبِي غَسَّانَ - حَدَّثَنَا مُعَاذٌ، - وَهُوَ ابْنُ هِشَامٍ الدَّسْتَوَائِيُّ - حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، حَدَّثَنَا الْحَسَنُ، عَنْ ضَبَّةَ بْنِ مِحْصَنٍ الْعَنَزِيِّ، عَنْ أُمِّ سَلَمَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ إِنَّهُ يُسْتَعْمَلُ عَلَيْكُمْ أُمَرَاءُ فَتَعْرِفُونَ وَتُنْكِرُونَ فَمَنْ كَرِهَ فَقَدْ بَرِئَ وَمَنْ أَنْكَرَ فَقَدْ سَلِمَ وَلَكِنْ مَنْ رَضِيَ وَتَابَعَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَلاَ نُقَاتِلُهُمْ قَالَ ‏"‏ لاَ مَا صَلَّوْا ‏"‏ ‏.‏ أَىْ مَنْ كَرِهَ بِقَلْبِهِ وَأَنْكَرَ بِقَلْبِهِ ‏.‏\hadithno{4801}\hadithtrans{It has been narrated (through a different chain of tmnamitters) on the authority of Umm Salama (wife of the Holy Prophet) that he said:Amirs will be appointed over you, and you will find them doing good as well as bad deeds. One who hates their bad deeds is absolved from blame. One who disapproves of their bad deeds is (also) safe (so far as Divine wrath is concerned). But one who approves of their bad deeds and imitates them (is doomed). People asked: Messenger of Allah, shouldn't we fight against them? He replied: No, as long as they say their prayer. (" Hating and disapproving" refers to liking and disliking from the heart)}}
\hadithdefcmd{muslim}{4802}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الْعَتَكِيُّ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - حَدَّثَنَا الْمُعَلَّى بْنُ، زِيَادٍ وَهِشَامٌ عَنِ الْحَسَنِ، عَنْ ضَبَّةَ بْنِ مِحْصَنٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِنَحْوِ ذَلِكَ غَيْرَ أَنَّهُ قَالَ ‏ "‏ فَمَنْ أَنْكَرَ فَقَدْ بَرِئَ وَمَنْ كَرِهَ فَقَدْ سَلِمَ ‏"‏ ‏.‏\hadithno{4802}\hadithtrans{Another version of the tradition narrated on the same authority attributes the same words to the Messenger of Allah (ﷺ) except that it replaces kariha with ankhara and vice versa}}
\hadithdefcmd{muslim}{4803}{وَحَدَّثَنَاهُ حَسَنُ بْنُ الرَّبِيعِ الْبَجَلِيُّ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ هِشَامٍ، عَنِ الْحَسَنِ، عَنْ ضَبَّةَ بْنِ مِحْصَنٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ مِثْلَهُ إِلاَّ قَوْلَهُ ‏ "‏ وَلَكِنْ مَنْ رَضِيَ وَتَابَعَ ‏"‏ ‏.‏ لَمْ يَذْكُرْهُ ‏.‏\hadithno{4803}\hadithtrans{Another version omits a portion at the end of the tradition-a portion which begins with man radiya wa taba and ends with the last word of the tradition}}
\hadithdefcmd{muslim}{4804}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَزِيدَ بْنِ يَزِيدَ بْنِ جَابِرٍ، عَنْ رُزَيْقِ بْنِ حَيَّانَ، عَنْ مُسْلِمِ بْنِ قَرَظَةَ، عَنْ عَوْفِ بْنِ مَالِكٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ خِيَارُ أَئِمَّتِكُمُ الَّذِينَ تُحِبُّونَهُمْ وَيُحِبُّونَكُمْ وَيُصَلُّونَ عَلَيْكُمْ وَتُصَلُّونَ عَلَيْهِمْ وَشِرَارُ أَئِمَّتِكُمُ الَّذِينَ تُبْغِضُونَهُمْ وَيُبْغِضُونَكُمْ وَتَلْعَنُونَهُمْ وَيَلْعَنُونَكُمْ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ أَفَلاَ نُنَابِذُهُمْ بِالسَّيْفِ فَقَالَ ‏"‏ لاَ مَا أَقَامُوا فِيكُمُ الصَّلاَةَ وَإِذَا رَأَيْتُمْ مِنْ وُلاَتِكُمْ شَيْئًا تَكْرَهُونَهُ فَاكْرَهُوا عَمَلَهُ وَلاَ تَنْزِعُوا يَدًا مِنْ طَاعَةٍ ‏"‏ ‏.‏\hadithno{4804}\hadithtrans{It has been narrated on the authority of 'Auf b. Malik that the Messenger of Allah (ﷺ) said:The best of your rulers are those whom you love and who love you, who invoke God's blessings upon you and you invoke His blessings upon them. And the worst of your rulers are those whom you hate and who hate you and whom you curse and who curse you. It was asked (by those present): Shouldn't we overthrow them with the help of the sword? He said: No, as long as they establish prayer among you. If you then find anything detestable in them. You should hate their administration, but do not withdraw yourselves from their obedience}}
\hadithdefcmd{muslim}{4805}{حَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا الْوَلِيدُ، - يَعْنِي ابْنَ مُسْلِمٍ - حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ، يَزِيدَ بْنِ جَابِرٍ أَخْبَرَنِي مَوْلَى بَنِي فَزَارَةَ، - وَهُوَ رُزَيْقُ بْنُ حَيَّانَ - أَنَّهُ سَمِعَ مُسْلِمَ بْنَ، قَرَظَةَ ابْنَ عَمِّ عَوْفِ بْنِ مَالِكٍ الأَشْجَعِيِّ يَقُولُ سَمِعْتُ عَوْفَ بْنَ مَالِكٍ الأَشْجَعِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ خِيَارُ أَئِمَّتِكُمُ الَّذِينَ تُحِبُّونَهُمْ وَيُحِبُّونَكُمْ وَتُصَلُّونَ عَلَيْهِمْ وَيُصَلُّونَ عَلَيْكُمْ وَشِرَارُ أَئِمَّتِكُمُ الَّذِينَ تُبْغِضُونَهُمْ وَيُبْغِضُونَكُمْ وَتَلْعَنُونَهُمْ وَيَلْعَنُونَكُمْ ‏"‏ ‏.‏ قَالُوا قُلْنَا يَا رَسُولَ اللَّهِ أَفَلاَ نُنَابِذُهُمْ عِنْدَ ذَلِكَ قَالَ ‏"‏ لاَ مَا أَقَامُوا فِيكُمُ الصَّلاَةَ لاَ مَا أَقَامُوا فِيكُمُ الصَّلاَةَ أَلاَ مَنْ وَلِيَ عَلَيْهِ وَالٍ فَرَآهُ يَأْتِي شَيْئًا مِنْ مَعْصِيَةِ اللَّهِ فَلْيَكْرَهْ مَا يَأْتِي مِنْ مَعْصِيَةِ اللَّهِ وَلاَ يَنْزِعَنَّ يَدًا مِنْ طَاعَةٍ ‏"‏ ‏.‏ قَالَ ابْنُ جَابِرٍ فَقُلْتُ - يَعْنِي لِرُزَيْقٍ - حِينَ حَدَّثَنِي بِهَذَا الْحَدِيثِ آللَّهِ يَا أَبَا الْمِقْدَامِ لَحَدَّثَكَ بِهَذَا أَوْ سَمِعْتَ هَذَا مِنْ مُسْلِمِ بْنِ قَرَظَةَ يَقُولُ سَمِعْتُ عَوْفًا يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فَجَثَا عَلَى رُكْبَتَيْهِ وَاسْتَقْبَلَ الْقِبْلَةَ فَقَالَ إِي وَاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ لَسَمِعْتُهُ مِنْ مُسْلِمِ بْنِ قَرَظَةَ يَقُولُ سَمِعْتُ عَوْفَ بْنَ مَالِكٍ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4805}\hadithtrans{It has been narrated on the authority of Auf b. Malik al-Ashja'i who said that he heard the Messenger of Allah (ﷺ) say:The best of your rulers are those whom you love and who love you, upon whom you invoke God's blessings and who invoke His blessing upon you. And the worst of your rulers are those whom you hate and who hate you, who curse you and whom you curse. (Those present) said: Shouldn't we overthrow them at this? He said: No, as long as they establish prayer among you. No, as long as they establish prayer among you. Mind you! One who has a governor appointed over him and he finds that the governor indulges in an act of disobedience to God, he should condemn the governor's act, in disobedience to God, but should not withdraw himself from his obedience. Ibn Jabir said: Ruzaiq narrated to me this hadith. I asked him: Abu Miqdam, have you heard it from Muslim b. Qaraza or did he describe it to you and he heard it from 'Auf (b. Malik) and he transmitted this tradition of Allah's Messenger (ﷺ)? Upon this Ruzaiq sat upon his knees and facing the Qibla said: By Allah, besides Whom there is no other God, I heard it from Muslim b. Qaraza and he said that te had heard it from Auf (b. Malik) and he said that he had heard it from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{4806}{وَحَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا ابْنُ جَابِرٍ، بِهَذَا الإِسْنَادِ وَقَالَ رُزَيْقٌ مَوْلَى بَنِي فَزَارَةَ ‏.‏ قَالَ مُسْلِمٌ وَرَوَاهُ مُعَاوِيَةُ بْنُ صَالِحٍ عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنْ مُسْلِمِ بْنِ قَرَظَةَ، عَنْ عَوْفِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{4806}\hadithtrans{The above hadith has been narrated through addtional chains of transmitters}}
\hadithdefcmd{muslim}{4807}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثُ بْنُ سَعْدٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ كُنَّا يَوْمَ الْحُدَيْبِيَةِ أَلْفًا وَأَرْبَعَمِائَةٍ فَبَايَعْنَاهُ وَعُمَرُ آخِذٌ بِيَدِهِ تَحْتَ الشَّجَرَةِ وَهِيَ سَمُرَةٌ ‏.‏ وَقَالَ بَايَعْنَاهُ عَلَى أَلاَ نَفِرَّ ‏.‏ وَلَمْ نُبَايِعْهُ عَلَى الْمَوْتِ\hadithno{4807}\hadithtrans{It has been narrated on the authority of Jabir who said:We were one thousand and four hundred on the Day of Hudaibiya. We swore fealty to hiin (the Holy Prophet) and 'Umar was holding the latter's hand (when he was sitting) under the tree (called) Samura (to administer the oath to the Companions). The narrator added: We took oath to the effect that we would not flee (from the battlefield if there was an encounter with the Meccans), but we did not take oath to fight to death}}
\hadithdefcmd{muslim}{4808}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ لَمْ نُبَايِعْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الْمَوْتِ إِنَّمَا بَايَعْنَاهُ عَلَى أَنْ لاَ نَفِرَّ ‏.‏\hadithno{4808}\hadithtrans{It has been narrated (through a different chain of transmitters) on the authority of Jabir who said:While swearing fealty to the Prophet (ﷺ) we did not take the oath to death but that we would not run away (from the battlefield)}}
\hadithdefcmd{muslim}{4809}{وَحَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا حَجَّاجٌ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، سَمِعَ جَابِرًا، يُسْأَلُ كَمْ كَانُوا يَوْمَ الْحُدَيْبِيَةِ قَالَ كُنَّا أَرْبَعَ عَشْرَةَ مِائَةً فَبَايَعْنَاهُ وَعُمَرُ آخِذٌ بِيَدِهِ تَحْتَ الشَّجَرَةِ وَهِيَ سَمُرَةٌ فَبَايَعْنَاهُ غَيْرَ جَدِّ ابْنِ قَيْسٍ الأَنْصَارِيِّ اخْتَبَأَ تَحْتَ بَطْنِ بَعِيرِهِ\hadithno{4809}\hadithtrans{It has been narrated on the authority of Abu Zubair who heard Jabir being questioned as to how many people were there on the Day of Hudaibiya. He replied:We were fourteen hundred. We swore fealty to him, and Umar was holding his hand while he was sitting under the tree (to administer the oath). The tree was a samura (a wild tree found in deserts). All of as took the oath of fealty at his hands except Jadd b. Qais al-Ansari who hid himself under the belly of his camel}}
\hadithdefcmd{muslim}{4810}{وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ دِينَارٍ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ الأَعْوَرُ، مَوْلَى سُلَيْمَانَ بْنِ مُجَالِدٍ قَالَ قَالَ ابْنُ جُرَيْجٍ وَأَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرًا، يُسْأَلُ هَلْ بَايَعَ النَّبِيُّ صلى الله عليه وسلم بِذِي الْحُلَيْفَةِ فَقَالَ لاَ وَلَكِنْ صَلَّى بِهَا وَلَمْ يُبَايِعْ عِنْدَ شَجَرَةٍ إِلاَّ الشَّجَرَةَ الَّتِي بِالْحُدَيْبِيَةِ ‏.‏ قَالَ ابْنُ جُرَيْجٍ وَأَخْبَرَنِي أَبُو الزُّبَيْرِ أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ يَقُولُ دَعَا النَّبِيُّ صلى الله عليه وسلم عَلَى بِئْرِ الْحُدَيْبِيَةِ ‏.‏\hadithno{4810}\hadithtrans{It has been narrated (through a different chain of transmitters) on the authority of Abu Zubair who heard Jabir being questioned as to whether the Prophet (ﷺ) took the oath of fealty at Dhu'l-Hulaifa. He said:No! But he offered his prayers at that place, and he administered the oath of fealty nowhere except near the tree in (the plain oo Hudaibiya. Ibn Juraij said that he was informed by Abu Zabair who heard Jabir b. Abdullah say: The Prophet (ﷺ) prayed over the well at Hudaibiya (as a result of which its scanty water rose up and increased so as to be sufficient for the 1400 or 1500 men who had encamped at the place)}}
\hadithdefcmd{muslim}{4811}{حَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، وَسُوَيْدُ بْنُ سَعِيدٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَأَحْمَدُ، بْنُ عَبْدَةَ - وَاللَّفْظُ لِسَعِيدٍ قَالَ سَعِيدٌ وَإِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ جَابِرٍ، قَالَ كُنَّا يَوْمَ الْحُدَيْبِيَةِ أَلْفًا وَأَرْبَعَمِائَةٍ فَقَالَ لَنَا النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَنْتُمُ الْيَوْمَ خَيْرُ أَهْلِ الأَرْضِ ‏"‏ ‏.‏ وَقَالَ جَابِرٌ لَوْ كُنْتُ أُبْصِرُ لأَرَيْتُكُمْ مَوْضِعَ الشَّجَرَةِ\hadithno{4811}\hadithtrans{It has been narrated (through a different chain of transmitters) on the authority of Jabir who said:We were one thousand and four hundred on the Day of Hudaibiya when the Prophet (ﷺ) said to us: Today you are the best people on the earth. And Jabir said: If I had the eyesight, I could show you the place of the tree}}
\hadithdefcmd{muslim}{4812}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، قَالَ سَأَلْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ عَنْ أَصْحَابِ، الشَّجَرَةِ فَقَالَ لَوْ كُنَّا مِائَةَ أَلْفٍ لَكَفَانَا كُنَّا أَلْفًا وَخَمْسَمِائَةٍ ‏.‏\hadithno{4812}\hadithtrans{It has been narrated on the authority of Salim b. Abu al-Ja'd who said:I asked Jabir b. 'Abdullah about the number of the Companions (of the Prophet who took the oath of fealty under) the tree. He said: If we were a hundred thousand, it (i. e. the water in the well at Hudaibiya) would have sufficed us, but actually we were one thousand and five hundred}}
\hadithdefcmd{muslim}{4813}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، ح وَحَدَّثَنَا رِفَاعَةُ بْنُ الْهَيْثَمِ، حَدَّثَنَا خَالِدٌ، - يَعْنِي الطَّحَّانَ - كِلاَهُمَا يَقُولُ عَنْ حُصَيْنٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرٍ، قَالَ لَوْ كُنَّا مِائَةَ أَلْفٍ لَكَفَانَا كُنَّا خَمْسَ عَشْرَةَ مِائَةً ‏.‏\hadithno{4813}\hadithtrans{It has been narrated on the authority of Jabir who said:If we had been a hundred thousand in number, it (the water) would have sufficed us, but actually we were fifteen hundred}}
\hadithdefcmd{muslim}{4814}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، عُثْمَانُ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، حَدَّثَنِي سَالِمُ بْنُ أَبِي الْجَعْدِ، قَالَ قُلْتُ لِجَابِرٍ كَمْ كُنْتُمْ يَوْمَئِذٍ قَالَ أَلْفًا وَأَرْبَعَمِائَةٍ ‏.‏\hadithno{4814}\hadithtrans{It has been narrated (through a different chain of transmitters) on the authority of Salim b. al-Ja'd who said:I asked Jabir: How many were you on the Day of Hudaibiya? He said: One thousand and four hundred}}
\hadithdefcmd{muslim}{4815}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، - يَعْنِي ابْنَ مُرَّةَ - حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي أَوْفَى، قَالَ كَانَ أَصْحَابُ الشَّجَرَةِ أَلْفًا وَثَلاَثَمِائَةٍ وَكَانَتْ أَسْلَمُ ثُمُنَ الْمُهَاجِرِينَ ‏.‏\hadithno{4815}\hadithtrans{It has been narrated on the authority of 'Abdullah b. Abu Aufa who said:The Companions of the Tree (i e. those who swore fealty under the tree) were one thousand and three hundred, and the people of Aslam tribe were one-eighth of the Muhajirs}}
\hadithdefcmd{muslim}{4816}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، ح وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، جَمِيعًا عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4816}\hadithtrans{The same tradition has been handed down through a different chain of transmitters}}
\hadithdefcmd{muslim}{4817}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ خَالِدٍ، عَنِ الْحَكَمِ بْنِ عَبْدِ اللَّهِ، بْنِ الأَعْرَجِ عَنْ مَعْقِلِ بْنِ يَسَارٍ، قَالَ لَقَدْ رَأَيْتُنِي يَوْمَ الشَّجَرَةِ وَالنَّبِيُّ صلى الله عليه وسلم يُبَايِعُ النَّاسَ وَأَنَا رَافِعٌ غُصْنًا مِنْ أَغْصَانِهَا عَنْ رَأْسِهِ وَنَحْنُ أَرْبَعَ عَشْرَةَ مِائَةً قَالَ لَمْ نُبَايِعْهُ عَلَى الْمَوْتِ وَلَكِنْ بَايَعْنَاهُ عَلَى أَنْ لاَ نَفِرَّ ‏.‏\hadithno{4817}\hadithtrans{It has been narrated on the authority of Ma'qil b. Yasar who aaid:I remember being present on the Day of the Tree, and the Prophet (ﷺ) was taking the oath of the people and I was holding a twig of the tree over his head. We were fourteen hundred (in number). We did not take oath to the death, but to the effect that we would not run away from the battlefield}}
\hadithdefcmd{muslim}{4818}{وَحَدَّثَنَاهُ يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ يُونُسَ، بِهَذَا الإِسْنَادِ\hadithno{4818}\hadithtrans{This hadith has been narrated on the authority of Yunus with the same chain of transmitters}}
\hadithdefcmd{muslim}{4821}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالاَ حَدَّثَنَا شَبَابَةُ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِيهِ، قَالَ لَقَدْ رَأَيْتُ الشَّجَرَةَ ثُمَّ أَتَيْتُهَا بَعْدُ فَلَمْ أَعْرِفْهَا\hadithno{4821}\hadithtrans{The tradition has been narrated on the authority of Sa'id b. Musayyib who learnt it from his father. The latter said:I had seen the tree. When I came to the spot afterwards, I could not recognise it}}
\hadithdefcmd{muslim}{4822}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ - عَنْ يَزِيدَ بْنِ أَبِي، عُبَيْدٍ مَوْلَى سَلَمَةَ بْنِ الأَكْوَعِ قَالَ قُلْتُ لِسَلَمَةَ عَلَى أَىِّ شَىْءٍ بَايَعْتُمْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمَ الْحُدَيْبِيَةِ قَالَ عَلَى الْمَوْتِ ‏.‏\hadithno{4822}\hadithtrans{It has been narrated on the authority of Yazid b. Abu Ubaid (the freed slave of Salama b. al-Akwa') who said:1 asked Salama as to what effect he had sworn fealty to the Messenger of Allah (ﷺ) on the Day of Hudaibiya. He said: To the effect that we will die fighting}}
\hadithdefcmd{muslim}{4823}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا حَمَّادُ بْنُ مَسْعَدَةَ، حَدَّثَنَا يَزِيدُ، عَنْ سَلَمَةَ، بِمِثْلِهِ ‏.‏\hadithno{4823}\hadithtrans{The above tradition has also been handed down through a different chain of transmitters}}
\hadithdefcmd{muslim}{4824}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْمَخْزُومِيُّ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَمْرُو بْنُ، يَحْيَى عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، قَالَ أَتَاهُ آتٍ فَقَالَ هَذَاكَ ابْنُ حَنْظَلَةَ يُبَايِعُ النَّاسَ فَقَالَ عَلَى مَاذَا قَالَ عَلَى الْمَوْتِ قَالَ لاَ أُبَايِعُ عَلَى هَذَا أَحَدًا بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4824}\hadithtrans{It has been narrated on the authority of Abdullah b. Zaid who said:A person came to him and said: Here is Ibn Hanzala who is making people swear allegiance to him. He (, Abdullah) asked: To what effect? He replied: To the effect that they will die for him. 'Abdullah said: I will never swear allegiance to this effect after the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{4825}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ - عَنْ يَزِيدَ بْنِ أَبِي، عُبَيْدٍ عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، أَنَّهُ دَخَلَ عَلَى الْحَجَّاجِ فَقَالَ يَا ابْنَ الأَكْوَعِ ارْتَدَدْتَ عَلَى عَقِبَيْكَ تَعَرَّبْتَ قَالَ لاَ وَلَكِنْ رَسُولُ اللَّهِ صلى الله عليه وسلم أَذِنَ لِي فِي الْبَدْوِ ‏.‏\hadithno{4825}\hadithtrans{It has been narrated by Salama b. al-Akwa' that he visited al-Hajjaj who said to him:O son of al-Akwa', you have turned apostate and have come to live again in the desert with the Bedouins (after your migration). He said: No, but the Messenger of Allah (ﷺ) has permitted me to live in the desert}}
\hadithdefcmd{muslim}{4826}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ أَبُو جَعْفَرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ زَكَرِيَّاءَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، حَدَّثَنِي مُجَاشِعُ بْنُ مَسْعُودٍ السُّلَمِيُّ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم أُبَايِعُهُ عَلَى الْهِجْرَةِ فَقَالَ ‏ "‏ إِنَّ الْهِجْرَةَ قَدْ مَضَتْ لأَهْلِهَا وَلَكِنْ عَلَى الإِسْلاَمِ وَالْجِهَادِ وَالْخَيْرِ ‏"‏ ‏.‏\hadithno{4826}\hadithtrans{It has been reported on the authority of Mujashi' b. Mas'ud as-Sulami who said:I came to the Prophet (ﷺ) to offer him my pledge of migration. He said: The period of migration has expired (and those who wereto get the reward for this great act of devotion have got it). You may now give your pledge to serve the cause of Islam, to strive in the way of Allah and to follow the path of virtue}}
\hadithdefcmd{muslim}{4827}{وَحَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عَاصِمٍ، عَنْ أَبِي عُثْمَانَ، قَالَ أَخْبَرَنِي مُجَاشِعُ بْنُ مَسْعُودٍ السُّلَمِيُّ، قَالَ جِئْتُ بِأَخِي أَبِي مَعْبَدٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بَعْدَ الْفَتْحِ فَقُلْتُ يَا رَسُولَ اللَّهِ بَايِعْهُ عَلَى الْهِجْرَةِ ‏.‏ قَالَ ‏"‏ قَدْ مَضَتِ الْهِجْرَةُ بِأَهْلِهَا ‏"‏ ‏.‏ قُلْتُ فَبِأَىِّ شَىْءٍ تُبَايِعُهُ قَالَ ‏"‏ عَلَى الإِسْلاَمِ وَالْجِهَادِ وَالْخَيْرِ ‏"‏ ‏.‏ قَالَ أَبُو عُثْمَانَ فَلَقِيتُ أَبَا مَعْبَدٍ فَأَخْبَرْتُهُ بِقَوْلِ مُجَاشِعٍ فَقَالَ صَدَقَ ‏.‏\hadithno{4827}\hadithtrans{It has been reported on the authority of Mujashi' b. Mas'ud who said:I brought my brother Abu Ma'bad to the Messenger of Allah (may peace he upon him) after the conquest of Mecca and said: Messenger of Allah, allow him to swear his pledge of migration at your hand. He said: The period of migration is over with those who had to do it (and now nobody can get this meritorious distinctions) I said: For what actions will you allow him to bind himself in oath? He said: (He can do so) for serving the cause of Islam, for fighting in the way of Allah and for fighting in the cause of virtue. Abd Uthman said: I met Abd Ma'bad and told him what I had heard from Mujashi'. He said: He has told the truth}}
\hadithdefcmd{muslim}{4828}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عَاصِمٍ، بِهَذَا الإِسْنَادِ قَالَ فَلَقِيتُ أَخَاهُ فَقَالَ صَدَقَ مُجَاشِعٌ ‏.‏ وَلَمْ يَذْكُرْ أَبَا مَعْبَدٍ ‏.‏\hadithno{4828}\hadithtrans{Another version of the tradition transmitted on the authority of Asim has the same wording but does not mention the name of Abu Ma'bad}}
\hadithdefcmd{muslim}{4829}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالاَ أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الْفَتْحِ فَتْحِ مَكَّةَ ‏ "‏ لاَ هِجْرَةَ وَلَكِنْ جِهَادٌ وَنِيَّةٌ وَإِذَا اسْتُنْفِرْتُمْ فَانْفِرُوا ‏"‏ ‏.‏\hadithno{4829}\hadithtrans{It has been narrated on the authority of Ibn 'Abbas that the Messenger of Allah (ﷺ) said on the day of the Conquest of Mecca:There is no Hijra now, but (only) Jihad (fighting for the cause of Islam) and sincerity of purpose (have great reward) ; when you are asked to set out (on an expedition undertaken for the cause of Islam) you should (readily) do so}}
\hadithdefcmd{muslim}{4830}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، وَابْنُ، رَافِعٍ عَنْ يَحْيَى بْنِ آدَمَ، حَدَّثَنَا مُفَضَّلٌ، - يَعْنِي ابْنَ مُهَلْهِلٍ - ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، كُلُّهُمْ عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏\hadithno{4830}\hadithtrans{The above tradition has been handed down through a different chain of transmitters}}
\hadithdefcmd{muslim}{4831}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ حَبِيبِ بْنِ أَبِي، ثَابِتٍ عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي حُسَيْنٍ، عَنْ عَطَاءٍ، عَنْ عَائِشَةَ، قَالَتْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْهِجْرَةِ فَقَالَ ‏ "‏ لاَ هِجْرَةَ بَعْدَ الْفَتْحِ وَلَكِنْ جِهَادٌ وَنِيَّةٌ وَإِذَا اسْتُنْفِرْتُمْ فَانْفِرُوا ‏"‏ ‏.‏\hadithno{4831}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) was asked about migration, whereupon he said:There is no migration after the Conquest (of Mecca), but Jihad and sincere intention. When you are asked to set out (for the cause of Islam), you should set out}}
\hadithdefcmd{muslim}{4832}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ خَلاَّدٍ الْبَاهِلِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، بْنُ عَمْرٍو الأَوْزَاعِيُّ حَدَّثَنِي ابْنُ شِهَابٍ الزُّهْرِيُّ، حَدَّثَنِي عَطَاءُ بْنُ يَزِيدَ اللَّيْثِيُّ، أَنَّهُ حَدَّثَهُمْ قَالَ حَدَّثَنِي أَبُو سَعِيدٍ الْخُدْرِيُّ، أَنَّ أَعْرَابِيًّا، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْهِجْرَةِ فَقَالَ ‏"‏ وَيْحَكَ إِنَّ شَأْنَ الْهِجْرَةِ لَشَدِيدٌ فَهَلْ لَكَ مِنْ إِبِلٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَهَلْ تُؤْتِي صَدَقَتَهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَاعْمَلْ مِنْ وَرَاءِ الْبِحَارِ فَإِنَّ اللَّهَ لَنْ يَتِرَكَ مِنْ عَمَلِكَ شَيْئًا ‏"‏ ‏.‏\hadithno{4832}\hadithtrans{It has been narrated on the authority of Abu Sa'id al-Khudari that a Bedouin asked the Messenger of Allah (ﷺ) about Migration. He replied:Do you talk of Hijra? The affair of Hijra is very difficult. But have you got camels? The bedouin said: Yes. He asked: Do you pay the poor-rate payable on their account? He replied: Yes. He (the Holy Prophet) said: Go on doing good deeds (across the seas), for surely God will not leave any of your deeds unrewarded}}
\hadithdefcmd{muslim}{4833}{وَحَدَّثَنَاهُ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنِ الأَوْزَاعِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّهُ قَالَ ‏"‏ إِنَّ اللَّهَ لَنْ يَتِرَكَ مِنْ عَمَلِكَ شَيْئًا ‏"‏ ‏.‏ وَزَادَ فِي الْحَدِيثِ قَالَ ‏"‏ فَهَلْ تَحْلُبُهَا يَوْمَ وِرْدِهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏\hadithno{4833}\hadithtrans{This tradition has been handed down through a different chain of transmitter with the addition of the following words at the end:" Do you milk them on the day they arrive at the water? He replied: Yes}}
\hadithdefcmd{muslim}{4834}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، بْنُ يَزِيدَ قَالَ قَالَ ابْنُ شِهَابٍ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَتِ الْمُؤْمِنَاتُ إِذَا هَاجَرْنَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يُمْتَحَنَّ بِقَوْلِ اللَّهِ عَزَّ وَجَلَّ ‏\{‏ يَا أَيُّهَا النَّبِيُّ إِذَا جَاءَكَ الْمُؤْمِنَاتُ يُبَايِعْنَكَ عَلَى أَنْ لاَ يُشْرِكْنَ بِاللَّهِ شَيْئًا وَلاَ يَسْرِقْنَ وَلاَ يَزْنِينَ‏\}‏ إِلَى آخِرِ الآيَةِ ‏.‏ قَالَتْ عَائِشَةُ فَمَنْ أَقَرَّ بِهَذَا مِنَ الْمُؤْمِنَاتِ فَقَدْ أَقَرَّ بِالْمِحْنَةِ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَقْرَرْنَ بِذَلِكَ مِنْ قَوْلِهِنَّ قَالَ لَهُنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ انْطَلِقْنَ فَقَدْ بَايَعْتُكُنَّ ‏"‏ ‏.‏ وَلاَ وَاللَّهِ مَا مَسَّتْ يَدُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَدَ امْرَأَةٍ قَطُّ ‏.‏ غَيْرَ أَنَّهُ يُبَايِعُهُنَّ بِالْكَلاَمِ - قَالَتْ عَائِشَةُ - وَاللَّهِ مَا أَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى النِّسَاءِ قَطُّ إِلاَّ بِمَا أَمَرَهُ اللَّهُ تَعَالَى وَمَا مَسَّتْ كَفُّ رَسُولِ اللَّهِ صلى الله عليه وسلم كَفَّ امْرَأَةٍ قَطُّ وَكَانَ يَقُولُ لَهُنَّ إِذَا أَخَذَ عَلَيْهِنَّ ‏"‏ قَدْ بَايَعْتُكُنَّ ‏"‏ ‏.‏ كَلاَمًا ‏.‏\hadithno{4834}\hadithtrans{It has been narrated on the authority of 'A'isha, the wife of the Prophet (ﷺ). She said:When the believing women migrated (to Medina) and came to the Messenger of Allah (ﷺ), they would be tested in accordance with the following words of Allah. the Almighty and Exalted:" O Prophet, when believing women come to thee to take the oath of fealty to thee that they will not associate in worship anything with God, that they will not steal. that, they will not commit adultery..." to the end of the verse (lx. 62). Whoso from the believing women accepted these conditions and agreed to abide by them were considered to have offered themselves for swearing fealty. When they had (formally) declared their resolve to do so, the Messenger of Allah (may peace he upon him) would say to them: You may go. I have confirmed your fealty. By God, the hand of the Messenger of Allah (ﷺ) never touched the hand of a woman. He would take the oath of fealty from them by oral declaration. By God, the Messenger of Allah (ﷺ) never took any vow from women except that which God had ordered him to take, and his palm never touched the palm of a woman. When he had taken their vow, he would tell them that he had taken the oath from them orally}}
\hadithdefcmd{muslim}{4835}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَبُو الطَّاهِرِ، قَالَ أَبُو الطَّاهِرِ أَخْبَرَنَا وَقَالَ، هَارُونُ حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ عَنْ بَيْعَةِ النِّسَاءِ، قَالَتْ مَا مَسَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ امْرَأَةً قَطُّ إِلاَّ أَنْ يَأْخُذَ عَلَيْهَا فَإِذَا أَخَذَ عَلَيْهَا فَأَعْطَتْهُ قَالَ ‏ "‏ اذْهَبِي فَقَدْ بَايَعْتُكِ ‏"‏ ‏.‏\hadithno{4835}\hadithtrans{It has been narrated on the authority of 'Urwa that 'A'isha described to him the way the Prophet (ﷺ) took the oath of fealty from women. She said:The Messenger of Allah (ﷺ) never touched a woman with his hand. He would only take a vow from her and when he had taken the (verbal) vow, he would say: You may go. I have accepted your fealty}}
\hadithdefcmd{muslim}{4836}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ - وَاللَّفْظُ لاِبْنِ أَيُّوبَ - قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ دِينَارٍ، أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ كُنَّا نُبَايِعُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ يَقُولُ لَنَا ‏ "‏ فِيمَا اسْتَطَعْتَ ‏"‏ ‏.‏\hadithno{4836}\hadithtrans{It has been narrated on the authority of Abdullah b. 'Umar who said:We used to take oath to the Messenger of Allah (ﷺ) that we would listen to and obey his orders. He would tell us (to say in the oath): As far as it lies in my power}}
\hadithdefcmd{muslim}{4837}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ عَرَضَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ أُحُدٍ فِي الْقِتَالِ وَأَنَا ابْنُ أَرْبَعَ عَشْرَةَ سَنَةً فَلَمْ يُجِزْنِي وَعَرَضَنِي يَوْمَ الْخَنْدَقِ وَأَنَا ابْنُ خَمْسَ عَشْرَةَ سَنَةً فَأَجَازَنِي ‏.‏ قَالَ نَافِعٌ فَقَدِمْتُ عَلَى عُمَرَ بْنِ عَبْدِ الْعَزِيزِ وَهُوَ يَوْمَئِذٍ خَلِيفَةٌ فَحَدَّثْتُهُ هَذَا الْحَدِيثَ فَقَالَ إِنَّ هَذَا لَحَدٌّ بَيْنَ الصَّغِيرِ وَالْكَبِيرِ ‏.‏ فَكَتَبَ إِلَى عُمَّالِهِ أَنْ يَفْرِضُوا لِمَنْ كَانَ ابْنَ خَمْسَ عَشْرَةَ سَنَةً وَمَنْ كَانَ دُونَ ذَلِكَ فَاجْعَلُوهُ فِي الْعِيَالِ ‏.‏\hadithno{4837}\hadithtrans{It has been narrated on the authority of Ibn 'Umar who said:The Messenger of Allah (ﷺ) inspected me on the battlefield on the Day of Uhud, and I was fourteen years old. He did not allow me (to take part in the fight). He inspected me on the Day of Khandaq-and I was fifteen yearsold, and he permitted me (to fight), Nafi' said: I came to 'Umar b. 'Abd al-'Aziz who was then Caliph, and narrated this tradition to him. He said: Surely, this is the demarcation between a minor and a major. So he wrote to his governors that they should pay subsistence allowance to one who was fifteen years old, but should treat those of lesser age among children}}
\hadithdefcmd{muslim}{4838}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، وَعَبْدُ الرَّحِيمِ بْنُ، سُلَيْمَانَ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي الثَّقَفِيَّ - جَمِيعًا عَنْ عُبَيْدِ، اللَّهِ بِهَذَا الإِسْنَادِ غَيْرَ أَنَّ فِي حَدِيثِهِمْ وَأَنَا ابْنُ أَرْبَعَ عَشْرَةَ سَنَةً فَاسْتَصْغَرَنِي ‏.‏\hadithno{4838}\hadithtrans{This tradition has been handed down through a different chain Of transmitters with the following change in the wording:" I was fourteen years old and he thought me too young (to participate in the fight)}}
\hadithdefcmd{muslim}{4839}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُسَافَرَ بِالْقُرْآنِ إِلَى أَرْضِ الْعَدُوِّ ‏.‏\hadithno{4839}\hadithtrans{It has been narrated on the authority of Ibn 'Umar who said:The Messenger of Allah (ﷺ) forbade that one should travel to the land of the enemy taking the Qur'an with him}}
\hadithdefcmd{muslim}{4840}{وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنْ عَبْدِ، اللَّهِ بْنِ عُمَرَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ كَانَ يَنْهَى أَنْ يُسَافَرَ بِالْقُرْآنِ إِلَى أَرْضِ الْعَدُوِّ مَخَافَةَ أَنْ يَنَالَهُ الْعَدُوُّ ‏.‏\hadithno{4840}\hadithtrans{It has been narrated on the authority of Abdullah b. Umar that the Messenger of Allah (ﷺ) used to forbid that one should travel to the land of the enemy taking the Qur'an (with him) lest it should fall into the hands of the enemy}}
\hadithdefcmd{muslim}{4841}{وَحَدَّثَنَا أَبُو الرَّبِيعِ الْعَتَكِيُّ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُسَافِرُوا بِالْقُرْآنِ فَإِنِّي لاَ آمَنُ أَنْ يَنَالَهُ الْعَدُوُّ ‏"‏ ‏.‏ قَالَ أَيُّوبُ فَقَدْ نَالَهُ الْعَدُوُّ وَخَاصَمُوكُمْ بِهِ ‏.‏\hadithno{4841}\hadithtrans{It has been narrated on the authority of Ibn 'Umar that the Messenger of Allah (ﷺ) said:Do not take the Qur'an on a journey with you, for I am afraid lost it should fall into the hands of the enemy. Ayyub (one of the narrators in the chain of transmitters) said: The enemy may seize it and may quarrel with you over it}}
\hadithdefcmd{muslim}{4842}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ يَعْنِي ابْنَ عُلَيَّةَ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، وَالثَّقَفِيُّ، كُلُّهُمْ عَنْ أَيُّوبَ، ح وَحَدَّثَنَا ابْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، - يَعْنِي ابْنَ عُثْمَانَ - جَمِيعًا عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ فِي حَدِيثِ ابْنِ عُلَيَّةَ وَالثَّقَفِيِّ ‏"‏ فَإِنِّي أَخَافُ ‏"‏ ‏.‏ وَفِي حَدِيثِ سُفْيَانَ وَحَدِيثِ الضَّحَّاكِ بْنِ عُثْمَانَ ‏"‏ مَخَافَةَ أَنْ يَنَالَهُ الْعَدُوُّ ‏"‏ ‏.‏\hadithno{4842}\hadithtrans{The above hadith has been narrated through several other chains with slight differences of wording}}
\hadithdefcmd{muslim}{4843}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، ‏.‏ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَابَقَ بِالْخَيْلِ الَّتِي قَدْ أُضْمِرَتْ مِنَ الْحَفْيَاءِ وَكَانَ أَمَدُهَا ثَنِيَّةَ الْوَدَاعِ وَسَابَقَ بَيْنَ الْخَيْلِ الَّتِي لَمْ تُضْمَرْ مِنَ الثَّنِيَّةِ إِلَى مَسْجِدِ بَنِي زُرَيْقٍ وَكَانَ ابْنُ عُمَرَ فِيمَنْ سَابَقَ بِهَا ‏.‏\hadithno{4843}\hadithtrans{It has been narrated on the authority of Ibn 'Umar that the Messenger of Allah (ﷺ) had a race of the horses which had been especially prepared for the purpose from Hafya' to Thaniyyat al-Wada' (the latter being the winning post), and of those which had not been trained from Thaniyya to the mosque of Banu Zuraiq, and Ibn Umar was among those who took part in this race}}
\hadithdefcmd{muslim}{4844}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، وَأَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالُوا حَدَّثَنَا حَمَّادٌ، - وَهُوَ ابْنُ زَيْدٍ - عَنْ أَيُّوبَ، ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - جَمِيعًا عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، وَأَحْمَدُ بْنُ عَبْدَةَ، وَابْنُ أَبِي عُمَرَ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي مُوسَى بْنُ عُقْبَةَ، ح وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي أُسَامَةُ، - يَعْنِي ابْنَ زَيْدٍ - كُلُّ هَؤُلاَءِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، بِمَعْنَى حَدِيثِ مَالِكٍ عَنْ نَافِعٍ، ‏.‏ وَزَادَ فِي حَدِيثِ أَيُّوبَ مِنْ رِوَايَةِ حَمَّادٍ وَابْنِ عُلَيَّةَ قَالَ عَبْدُ اللَّهِ فَجِئْتُ سَابِقًا فَطَفَّفَ بِي الْفَرَسُ الْمَسْجِدَ ‏.‏\hadithno{4844}\hadithtrans{This tradition has been handed down through several other chains of transmitters. One of the chaines has the addition of the following words from Abdullah b. 'Umar:" I came first in the race and my horse jumped into the mosque with me}}
\hadithdefcmd{muslim}{4845}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْخَيْلُ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4845}\hadithtrans{It has been narrated on the authority of Ibn Umar that the Messenger of Allah (ﷺ) said:There will be great benefit in the forelock of the horses until the Day of judgment}}
\hadithdefcmd{muslim}{4846}{وَحَدَّثَنَا قُتَيْبَةُ، وَابْنُ، رُمْحٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، وَعَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا عُبَيْدُ، اللَّهِ بْنُ سَعِيدٍ حَدَّثَنَا يَحْيَى، كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي أُسَامَةُ، كُلُّهُمْ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ مَالِكٍ عَنْ نَافِعٍ ‏.‏\hadithno{4846}\hadithtrans{The same tradition has been handed down through a different chain of transmitters}}
\hadithdefcmd{muslim}{4847}{وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَصَالِحُ بْنُ حَاتِمِ بْنِ وَرْدَانَ، جَمِيعًا عَنْ يَزِيدَ، - قَالَ الْجَهْضَمِيُّ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، - حَدَّثَنَا يُونُسُ بْنُ عُبَيْدٍ، عَنْ عَمْرِو بْنِ سَعِيدٍ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَلْوِي نَاصِيَةَ فَرَسٍ بِإِصْبَعِهِ وَهُوَ يَقُولُ ‏ "‏ الْخَيْلُ مَعْقُودٌ بِنَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ الأَجْرُ وَالْغَنِيمَةُ ‏"‏ ‏.‏\hadithno{4847}\hadithtrans{It has been narrated on the authority of Jarir b. Abdullah who said:I saw that the Messenger of Allah (ﷺ) was twisting the forelock of a horse with his fingers and he was saying: (A great) benefit. i. e. reward (for rearing them for Jihad) and spoils of war, has been tied to the forelocks of horses until the Day of Judgment}}
\hadithdefcmd{muslim}{4848}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ، أَبِي شَيْبَةَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، كِلاَهُمَا عَنْ يُونُسَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4848}\hadithtrans{The above tradition has also been narrated on the authority of Yunus through a different chain of transmitters}}
\hadithdefcmd{muslim}{4849}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا زَكَرِيَّاءُ، عَنْ عَامِرٍ، عَنْ عُرْوَةَ الْبَارِقِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْخَيْلُ مَعْقُودٌ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ الأَجْرُ وَالْمَغْنَمُ ‏"‏ ‏.‏\hadithno{4849}\hadithtrans{The same tradition has been narrated on the authority of Urwat al-Bariqi who said that the Prophet (ﷺ) said:Great good is attached to the forelock of the horses until the Day of Judgment}}
\hadithdefcmd{muslim}{4850}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ فُضَيْلٍ، وَابْنُ، إِدْرِيسَ عَنْ حُصَيْنٍ، عَنِ الشَّعْبِيِّ، عَنْ عُرْوَةَ الْبَارِقِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْخَيْرُ مَعْقُوصٌ بِنَوَاصِي الْخَيْلِ ‏"‏ ‏.‏ قَالَ فَقِيلَ لَهُ يَا رَسُولَ اللَّهِ بِمَ ذَاكَ قَالَ ‏"‏ الأَجْرُ وَالْمَغْنَمُ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4850}\hadithtrans{Urwat al-Bariqi reported Allah's Messenger (ﷺ) having said this:Good is tied to the forelock of the horses. It Was said to him: Messenger of Allah, why is it so? He (the Prophet said): For reward and booty until the Day of Judgment}}
\hadithdefcmd{muslim}{4851}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ حُصَيْنٍ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ عُرْوَةُ بْنُ الْجَعْدِ ‏.‏\hadithno{4851}\hadithtrans{This hadith has been narrated with the same chain of transmitters with the difference that here instead of" Urwat al-Bariqi" there is" Urwa b. ja'd}}
\hadithdefcmd{muslim}{4852}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَخَلَفُ بْنُ هِشَامٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ جَمِيعًا عَنْ أَبِي، الأَحْوَصِ ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، كِلاَهُمَا عَنْ سُفْيَانَ، جَمِيعًا عَنْ شَبِيبِ بْنِ غَرْقَدَةَ، عَنْ عُرْوَةَ الْبَارِقِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَلَمْ يَذْكُرِ الأَجْرَ وَالْمَغْنَمَ ‏.‏ وَفِي حَدِيثِ سُفْيَانَ سَمِعَ عُرْوَةَ الْبَارِقِيَّ سَمِعَ النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{4852}\hadithtrans{A version of the tradition narrated on the authority of 'Urwat al-Bariqi does not mention (the words):" reward and booty}}
\hadithdefcmd{muslim}{4853}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، كِلاَهُمَا عَنْ شُعْبَةَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْعَيْزَارِ بْنِ حُرَيْثٍ، عَنْ عُرْوَةَ، بْنِ الْجَعْدِ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا ‏.‏ وَلَمْ يَذْكُرِ ‏ "‏ الأَجْرَ وَالْمَغْنَمَ ‏"‏ ‏.‏\hadithno{4853}\hadithtrans{A version of the tradition transmitted on the authority of 'Urwa b. al-ja'd does not mention" reward and booty}}
\hadithdefcmd{muslim}{4854}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، كِلاَهُمَا عَنْ شُعْبَةَ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْبَرَكَةُ فِي نَوَاصِي الْخَيْلِ ‏"‏ ‏.‏\hadithno{4854}\hadithtrans{It has been narrated on the authority of Anas b. Malik that the Messenger of Allah (ﷺ) said:There is a blessing in the forelocks of the war horses}}
\hadithdefcmd{muslim}{4855}{وَحَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ يَعْنِي ابْنَ الْحَارِثِ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ، الْوَلِيدِ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، سَمِعَ أَنَسًا، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{4855}\hadithtrans{A hadith like this has been narrated on the authority of Anas through another chain of transmitters}}
\hadithdefcmd{muslim}{4856}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ وَأَبُو كُرَيْبٍ قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سَلْمِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَكْرَهُ الشِّكَالَ مِنَ الْخَيْلِ ‏.‏\hadithno{4856}\hadithtrans{It has been narrated on the authority of Abn Huraira that the Messenger of Allah (ﷺ) used to dislike the Shikal horse}}
\hadithdefcmd{muslim}{4857}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ، حَدَّثَنَا عَبْدُ، الرَّزَّاقِ جَمِيعًا عَنْ سُفْيَانَ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ وَزَادَ فِي حَدِيثِ عَبْدِ الرَّزَّاقِ وَالشِّكَالُ أَنْ يَكُونَ الْفَرَسُ فِي رِجْلِهِ الْيُمْنَى بَيَاضٌ وَفِي يَدِهِ الْيُسْرَى أَوْ فِي يَدِهِ الْيُمْنَى وَرِجْلِهِ الْيُسْرَى ‏.‏\hadithno{4857}\hadithtrans{This tradition has been narrated on the authority of Sufyan with the addition from Abd ar-Razzaq (one of the narrators) explaining the meaning of shikal as a bone whose right back foot and left front foot or left back foot and right front foot are white}}
\hadithdefcmd{muslim}{4858}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ يَعْنِي ابْنَ جَعْفَرٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي وَهْبُ بْنُ جَرِيرٍ، جَمِيعًا عَنْ شُعْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ النَّخَعِيِّ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ وَكِيعٍ ‏.‏ وَفِي رِوَايَةِ وَهْبٍ عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ ‏.‏ وَلَمْ يَذْكُرِ النَّخَعِيَّ ‏.‏\hadithno{4858}\hadithtrans{The tradition has been handed down through a different chain of transmitters}}
\hadithdefcmd{muslim}{4859}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عُمَارَةَ، - وَهُوَ ابْنُ الْقَعْقَاعِ - عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَضَمَّنَ اللَّهُ لِمَنْ خَرَجَ فِي سَبِيلِهِ لاَ يُخْرِجُهُ إِلاَّ جِهَادًا فِي سَبِيلِي وَإِيمَانًا بِي وَتَصْدِيقًا بِرُسُلِي فَهُوَ عَلَىَّ ضَامِنٌ أَنْ أُدْخِلَهُ الْجَنَّةَ أَوْ أَرْجِعَهُ إِلَى مَسْكَنِهِ الَّذِي خَرَجَ مِنْهُ نَائِلاً مَا نَالَ مِنْ أَجْرٍ أَوْ غَنِيمَةٍ ‏.‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ مَا مِنْ كَلْمٍ يُكْلَمُ فِي سَبِيلِ اللَّهِ إِلاَّ جَاءَ يَوْمَ الْقِيَامَةِ كَهَيْئَتِهِ حِينَ كُلِمَ لَوْنُهُ لَوْنُ دَمٍ وَرِيحُهُ مِسْكٌ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَوْلاَ أَنْ يَشُقَّ عَلَى الْمُسْلِمِينَ مَا قَعَدْتُ خِلاَفَ سَرِيَّةٍ تَغْزُو فِي سَبِيلِ اللَّهِ أَبَدًا وَلَكِنْ لاَ أَجِدُ سَعَةً فَأَحْمِلَهُمْ وَلاَ يَجِدُونَ سَعَةً وَيَشُقُّ عَلَيْهِمْ أَنْ يَتَخَلَّفُوا عَنِّي وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَوَدِدْتُ أَنِّي أَغْزُو فِي سَبِيلِ اللَّهِ فَأُقْتَلُ ثُمَّ أَغْزُو فَأُقْتَلُ ثُمَّ أَغْزُو فَأُقْتَلُ ‏"‏ ‏.‏\hadithno{4859}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger of Allah (may peace upon him) said:Allah has undertaken to look after the affairs of one who goes out to fight in His way believing in Him and affirming the truth of His Apostles. He is committed to His care that Re will either admit him to Paradise or bring him back to his home from where he set out with a reward or (his share of) booty. By the Being in Whose Hand is the life of Muhammad. If a person gets wounded in the way of Allah, he will come on the Day of Judgment with his wound in the same condition as it was when it was first inflicted; its colour being the colour of blood but its smell will be the smell of musk. By, the Being in Whose Hand is Muhammad's life, if it were not to be too hard upon the Muslime. I would not lag behind any expedition which is going to fight in the cause of Allah. But I do not have abundant means to provide them (the Mujahids) with riding beasts, nor have they (i. e. all of them) abundant means (to provide themselves with all the means of Jihad) so that they could he left behind. By the Being in Whose Hand is Muhammad's life, I love to fight in the way of Allah and be killed, to fight and again be killed and to fight again and be killed}}
\hadithdefcmd{muslim}{4860}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ عُمَارَةَ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{4860}\hadithtrans{The same tradition has been melted through another chain of transmitters}}
\hadithdefcmd{muslim}{4861}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ الْحِزَامِيُّ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تَكَفَّلَ اللَّهُ لِمَنْ جَاهَدَ فِي سَبِيلِهِ لاَ يُخْرِجُهُ مِنْ بَيْتِهِ إِلاَّ جِهَادٌ فِي سَبِيلِهِ وَتَصْدِيقُ كَلِمَتِهِ - بِأَنْ يُدْخِلَهُ الْجَنَّةَ أَوْ يَرْجِعَهُ إِلَى مَسْكَنِهِ الَّذِي خَرَجَ مِنْهُ مَعَ مَا نَالَ مِنْ أَجْرٍ أَوْ غَنِيمَةٍ ‏"‏ ‏.‏\hadithno{4861}\hadithtrans{It has been narrated on the authority of Abu Huraira who said:Allah has undertaken to provide for one who leaves his home (only) to fight for His cause and to affirm the truth of His word; Allah will either admit him to Paradise or will bring him back home from where he had come out, with his reward and booty}}
\hadithdefcmd{muslim}{4862}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُكْلَمُ أَحَدٌ فِي سَبِيلِ اللَّهِ - وَاللَّهُ أَعْلَمُ بِمَنْ يُكْلَمُ فِي سَبِيلِهِ - إِلاَّ جَاءَ يَوْمَ الْقِيَامَةِ وَجُرْحُهُ يَثْعَبُ اللَّوْنُ لَوْنُ دَمٍ وَالرِّيحُ رِيحُ مِسْكٍ ‏"‏ ‏.‏\hadithno{4862}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:One who is wounded in the way of Allah-and Allah knows better who is wounded in His way-will appear on the Day of Judgment with his wound bleediing. The colour (of its discharge) will be the colour of blood, (but) its smell will be the smell of musk}}
\hadithdefcmd{muslim}{4863}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كُلُّ كَلْمٍ يُكْلَمُهُ الْمُسْلِمُ فِي سَبِيلِ اللَّهِ ثُمَّ تَكُونُ يَوْمَ الْقِيَامَةِ كَهَيْئَتِهَا إِذَا طُعِنَتْ تَفَجَّرُ دَمًا اللَّوْنُ لَوْنُ دَمٍ وَالْعَرْفُ عَرْفُ الْمِسْكِ ‏"‏ ‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسُ مُحَمَّدٍ فِي يَدِهِ لَوْلاَ أَنْ أَشُقَّ عَلَى الْمُؤْمِنِينَ مَا قَعَدْتُ خَلْفَ سَرِيَّةٍ تَغْزُو فِي سَبِيلِ اللَّهِ وَلَكِنْ لاَ أَجِدُ سَعَةً فَأَحْمِلَهُمْ وَلاَ يَجِدُونَ سَعَةً فَيَتَّبِعُونِي وَلاَ تَطِيبُ أَنْفُسُهُمْ أَنْ يَقْعُدُوا بَعْدِي ‏"‏ ‏.‏\hadithno{4863}\hadithtrans{It has been narrated on the authority of Abu Haraira that the Messenger of Allah (ﷺ) said:Every wound received by a Muslim in the way of Allah will appear on the Day of Judgment in the same condition as it was when it was inflicted, and would be bleeding profusely. The colour (of its discharge) will be the colour of blood, but its smell will be the smell of musk. By the Being in Whose Hand is Muhammad's life, if it were not hard upon the Muslims, I would not lag behind any expedition undertaken for Jihad, but I do not possess abundant means to provide the Mujahids with riding animals, nor do they (i. e. all of them) have abundant means (to provide themselves with all the means of Jihad) to follow me, nor would it please their hearts to stay behind me}}
\hadithdefcmd{muslim}{4864}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لَوْلاَ أَنْ أَشُقَّ عَلَى الْمُؤْمِنِينَ ما قَعَدْتُ خِلاَفَ سَرِيَّةٍ ‏"‏ ‏.‏ بِمِثْلِ حَدِيثِهِمْ ‏.‏ وَبِهَذَا الإِسْنَادِ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَوَدِدْتُ أَنِّي أُقْتَلُ فِي سَبِيلِ اللَّهِ ثُمَّ أُحْيَى ‏"‏ ‏.‏ بِمِثْلِ حَدِيثِ أَبِي زُرْعَةَ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{4864}\hadithtrans{It has been narrated on the authority of Abu Huraira who said:I heard the Messenger of Allah (ﷺ) say: I would not stay behind (when) an expedition (for Jihad was being mobilised) if it were going to be too hard upon the believers.... This is followed by the same words as have appeared in the previous tradition, but this tradition has the same ending as the previous hadith with a slight difference in the wording:" By the Being in Whose Hand is my life, I love that I should be killed in the way of Allah; then I should be brought back to life and be killed again in His way}}
\hadithdefcmd{muslim}{4865}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ يَعْنِي الثَّقَفِيَّ، ح وَحَدَّثَنَا أَبُو بَكْرِ، بْنُ أَبِي شَيْبَةَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، كُلُّهُمْ عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَحْبَبْتُ أَنْ لاَ أَتَخَلَّفَ خَلْفَ سَرِيَّةٍ ‏"‏ ‏.‏ نَحْوَ حَدِيثِهِمْ ‏.‏\hadithno{4865}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:If it were not hard upon my Umma (to follow my example), I would not lag behind any expedition-as in the traditions gone before}}
\hadithdefcmd{muslim}{4866}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَضَمَّنَ اللَّهُ لِمَنْ خَرَجَ فِي سَبِيلِهِ - إِلَى قَوْلِهِ - مَا تَخَلَّفْتُ خِلاَفَ سَرِيَّةٍ تَغْزُو فِي سَبِيلِ اللَّهِ تَعَالَى ‏"‏ ‏.‏\hadithno{4866}\hadithtrans{Another version of the tradition narrated through a different chain of transmitters on the authority of Abu Huraira has the same wording as the previous tradition:" Allah takes care of one who goes out in the way of Allah" but ends in the words:" I would not lag behind any expedition which is undertaken to fight in the way of Allah, the Exalted}}
\hadithdefcmd{muslim}{4867}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، وَحُمَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ نَفْسٍ تَمُوتُ لَهَا عِنْدَ اللَّهِ خَيْرٌ يَسُرُّهَا أَنَّهَا تَرْجِعُ إِلَى الدُّنْيَا وَلاَ أَنَّ لَهَا الدُّنْيَا وَمَا فِيهَا إِلاَّ الشَّهِيدُ فَإِنَّهُ يَتَمَنَّى أَنْ يَرْجِعَ فَيُقْتَلَ فِي الدُّنْيَا لِمَا يَرَى مِنْ فَضْلِ الشَّهَادَةِ ‏"‏ ‏.‏\hadithno{4867}\hadithtrans{It has been narrated on the authority of Anas b. Malik that the Messenger of Allah (ﷺ) said:" Nobody who dies and has something good for him with Allah will (ever like to) return to this world even though he were offered the whole world and all that is in its (as an inducement), except the martyr who desires to return and be killed in the world for the (great) merit of martyrdom that he has seen}}
\hadithdefcmd{muslim}{4868}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ أَحَدٍ يَدْخُلُ الْجَنَّةَ يُحِبُّ أَنْ يَرْجِعَ إِلَى الدُّنْيَا وَأَنَّ لَهُ مَا عَلَى الأَرْضِ مِنْ شَىْءٍ غَيْرُ الشَّهِيدِ فَإِنَّهُ يَتَمَنَّى أَنْ يَرْجِعَ فَيُقْتَلَ عَشْرَ مَرَّاتٍ لِمَا يَرَى مِنَ الْكَرَامَةِ ‏"‏ ‏.‏\hadithno{4868}\hadithtrans{It has been narrated on the authority of Anas b. Malik (through a different chain of transmitters) that the Messenger of Allah (ﷺ) said:Nobody who enters Paradise will (ever like to) return to this world even if he were offered everything on the surface of the earth (as an inducement) except the martyr who will desire to return to this world and be killed ten times for the sake of the great honour that has been bestowed upon him}}
\hadithdefcmd{muslim}{4869}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ الْوَاسِطِيُّ، عَنْ سُهَيْلِ بْنِ أَبِي، صَالِحٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قِيلَ لِلنَّبِيِّ صلى الله عليه وسلم مَا يَعْدِلُ الْجِهَادَ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ قَالَ ‏"‏ لاَ تَسْتَطِيعُونَهُ ‏"‏ ‏.‏ قَالَ فَأَعَادُوا عَلَيْهِ مَرَّتَيْنِ أَوْ ثَلاَثًا كُلُّ ذَلِكَ يَقُولُ ‏"‏ لاَ تَسْتَطِيعُونَهُ ‏"‏ ‏.‏ وَقَالَ فِي الثَّالِثَةِ ‏"‏ مَثَلُ الْمُجَاهِدِ فِي سَبِيلِ اللَّهِ كَمَثَلِ الصَّائِمِ الْقَائِمِ الْقَانِتِ بِآيَاتِ اللَّهِ لاَ يَفْتُرُ مِنْ صِيَامٍ وَلاَ صَلاَةٍ حَتَّى يَرْجِعَ الْمُجَاهِدُ فِي سَبِيلِ اللَّهِ تَعَالَى ‏"‏ ‏.‏\hadithno{4869}\hadithtrans{It has been narrated on the authority of Abu Huraira who said:The Messenger of Allah (ﷺ) was asked: What deed could be an equivalent of Jihad in the way of Allah, the Almighty and Exalted? He answered: You do not have the strength to do that deed. The narrator said: They repeated the question twice or thrice. Every time he answered: You do not have the strength to do it. When the question was asked for the third time, he said: One who goes out for Jihad is like a person who keeps fasts, stands in prayer (constantly), (obeying) Allah's (behests contained in) the verses (of the Qur'an), and does not exhibit any lassitude in fasting and prayer until the Mujahid returns from Jihad in the way of Allah, the Exalted}}
\hadithdefcmd{muslim}{4870}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، كُلُّهُمْ عَنْ سُهَيْلٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{4870}\hadithtrans{This tradition has been handed down through a different chain of transmitters}}
\hadithdefcmd{muslim}{4871}{حَدَّثَنِي حَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا أَبُو تَوْبَةَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ سَلاَّمٍ، عَنْ زَيْدِ بْنِ سَلاَّمٍ، أَنَّهُ سَمِعَ أَبَا سَلاَّمٍ، قَالَ حَدَّثَنِي النُّعْمَانُ بْنُ بَشِيرٍ، قَالَ كُنْتُ عِنْدَ مِنْبَرِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَجُلٌ مَا أُبَالِي أَنْ لاَ أَعْمَلَ عَمَلاً بَعْدَ الإِسْلاَمِ إِلاَّ أَنْ أُسْقِيَ الْحَاجَّ ‏.‏ وَقَالَ آخَرُ مَا أُبَالِي أَنْ لاَ أَعْمَلَ عَمَلاً بَعْدَ الإِسْلاَمِ إِلاَّ أَنْ أَعْمُرَ الْمَسْجِدَ الْحَرَامَ ‏.‏ وَقَالَ آخَرُ الْجِهَادُ فِي سَبِيلِ اللَّهِ أَفْضَلُ مِمَّا قُلْتُمْ ‏.‏ فَزَجَرَهُمْ عُمَرُ وَقَالَ لاَ تَرْفَعُوا أَصْوَاتَكُمْ عِنْدَ مِنْبَرِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يَوْمُ الْجُمُعَةِ وَلَكِنْ إِذَا صَلَّيْتُ الْجُمُعَةَ دَخَلْتُ فَاسْتَفْتَيْتُهُ فِيمَا اخْتَلَفْتُمْ فِيهِ ‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ أَجَعَلْتُمْ سِقَايَةَ الْحَاجِّ وَعِمَارَةَ الْمَسْجِدِ الْحَرَامِ كَمَنْ آمَنَ بِاللَّهِ وَالْيَوْمِ الآخِرِ‏\}‏ الآيَةَ إِلَى آخِرِهَا ‏.‏\hadithno{4871}\hadithtrans{It has been narrated on the authority of Nu'man b. Bashir who said:As I was (sitting) near the pulpit of the Messenger of Allah (ﷺ), a man said: I do not care if, after embracing Islam, I do not do any good deed (except) distributing drinking water among the pilgrims. Another said: I do not care if, after embracing Islam, I do not do any good deed beyond maintenance service to the Sacred Mosque. Another said: Jihad in the way of Allah is better than what you have said. 'Umar reprimanded them and said: Don't raise your voices near the pulpit of the Messenger of Allah (ﷺ) on Friday. When prayer was over, I entered (the apartment of the Holy Prophet) and asked his verdict about the matter in which they had differed. (It was upon this that) Allah, the Almighty and Exalted, revealed the Qur'anic verse:" Do you make the giving of drinking water to the pilgrims and the maintenance of the Sacred Mosque equal to (the service of those) who believe in Allah and the Last Day and strive hard in the cause of Allah. They are not equal in the sight of God. And Allah guides not the wrongdoing people" (ix)}}
\hadithdefcmd{muslim}{4872}{وَحَدَّثَنِيهِ عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا مُعَاوِيَةُ، أَخْبَرَنِي زَيْدٌ، أَنَّهُ سَمِعَ أَبَا سَلاَّمٍ، قَالَ حَدَّثَنِي النُّعْمَانُ بْنُ بَشِيرٍ، قَالَ كُنْتُ عِنْدَ مِنْبَرِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ أَبِي تَوْبَةَ ‏.‏\hadithno{4872}\hadithtrans{This tradition has been narrated on the authority of Nu'man b. Bashir through another chain of transmitters}}
\hadithdefcmd{muslim}{4873}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسِ، بْنِ مَالِكٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَغَدْوَةٌ فِي سَبِيلِ اللَّهِ أَوْ رَوْحَةٌ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏\hadithno{4873}\hadithtrans{It has been narrated on the authority of Anas b. Malik that the Messenger of Allah (ﷺ) said:Leaving (for Jihad) in the way of Allah in the morning or in the evening (will merit a reward) better than the world and all that is in it}}
\hadithdefcmd{muslim}{4874}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلِ، بْنِ سَعْدٍ السَّاعِدِيِّ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ وَالْغَدْوَةَ يَغْدُوهَا الْعَبْدُ فِي سَبِيلِ اللَّهِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏\hadithno{4874}\hadithtrans{It has been narrated on the authority of Sahl b. Sa'd as-Sa'idi that the Messenger of Allah (ﷺ) said:The journey undertaken by a person in the morning (for Jihad) in the way of Allah (will merit a reward) better than the world and all that is in it}}
\hadithdefcmd{muslim}{4875}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ غَدْوَةٌ أَوْ رَوْحَةٌ فِي سَبِيلِ اللَّهِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏\hadithno{4875}\hadithtrans{It has been narrated on the authority of Sahl b. Sa'd as-Sa'idi that the Messenger of Allah (ﷺ) said:A journey undertaken in the morning or evening (fond Jihad) in the way of Allah (will merit a reward) better than the world and all that is in it}}
\hadithdefcmd{muslim}{4876}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ ذَكْوَانَ، بْنِ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْلاَ أَنَّ رِجَالاً مِنْ أُمَّتِي ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ وَقَالَ فِيهِ ‏"‏ وَلَرَوْحَةٌ فِي سَبِيلِ اللَّهِ أَوْ غَدْوَةٌ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏\hadithno{4876}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:If some persons of my Umma (were not to undertake the hardships of Jihad), and he (Abu Huraira) then narrated the rest of the hadith and then said: A journey undertaken for jihad in the evening or morning merits a reward better than the world and all that is in it}}
\hadithdefcmd{muslim}{4877}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لأَبِي بَكْرٍ وَإِسْحَاقَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ حَدَّثَنَا الْمُقْرِئُ عَبْدُ اللَّهِ بْنُ يَزِيدَ عَنْ سَعِيدِ بْنِ أَبِي أَيُّوبَ حَدَّثَنِي شُرَحْبِيلُ بْنُ شَرِيكٍ الْمَعَافِرِيُّ عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ قَالَ سَمِعْتُ أَبَا أَيُّوبَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَدْوَةٌ فِي سَبِيلِ اللَّهِ أَوْ رَوْحَةٌ خَيْرٌ مِمَّا طَلَعَتْ عَلَيْهِ الشَّمْسُ وَغَرَبَتْ ‏"‏ ‏.‏\hadithno{4877}\hadithtrans{It has been narrated on the authority of Abu Ayyub that the Messenger of Allah (ﷺ) said:A journey undertaken in the morning or evening (for Jihad) in the way of Allah is better than (anything) on which the sun rises or sets}}
\hadithdefcmd{muslim}{4878}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ قُهْزَاذَ، حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ، عَنْ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ، أَخْبَرَنَا سَعِيدُ بْنُ أَبِي أَيُّوبَ، وَحَيْوَةُ بْنُ شُرَيْحٍ، قَالَ كُلُّ وَاحِدٍ مِنْهُمَا حَدَّثَنِي شُرَحْبِيلُ بْنُ، شَرِيكٍ عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، أَنَّهُ سَمِعَ أَبَا أَيُّوبَ الأَنْصَارِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِثْلِهِ سَوَاءً ‏.‏\hadithno{4878}\hadithtrans{This tradition has been narrated on the authority of Abu Ayyub through a different chain of transmitters having the same wording}}
\hadithdefcmd{muslim}{4879}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي أَبُو هَانِئٍ الْخَوْلاَنِيُّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يَا أَبَا سَعِيدٍ مَنْ رَضِيَ بِاللَّهِ رَبًّا وَبِالإِسْلاَمِ دِينًا وَبِمُحَمَّدٍ نَبِيًّا وَجَبَتْ لَهُ الْجَنَّةُ ‏"‏ ‏.‏ فَعَجِبَ لَهَا أَبُو سَعِيدٍ فَقَالَ أَعِدْهَا عَلَىَّ يَا رَسُولَ اللَّهِ فَفَعَلَ ثُمَّ قَالَ ‏"‏ وَأُخْرَى يُرْفَعُ بِهَا الْعَبْدُ مِائَةَ دَرَجَةٍ فِي الْجَنَّةِ مَا بَيْنَ كُلِّ دَرَجَتَيْنِ كَمَا بَيْنَ السَّمَاءِ وَالأَرْضِ ‏"‏ ‏.‏ قَالَ وَمَا هِيَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الْجِهَادُ فِي سَبِيلِ اللَّهِ الْجِهَادُ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏\hadithno{4879}\hadithtrans{It has been narrated on the authority of Abu Sa`id al-Khudri that the Messenger of Allah (ﷺ) said (to him):Abu Sa`id, whoever cheerfully accepts Allah as his Lord, Islam as his religion and Muhammad as his Apostle is necessarily entitled to enter Paradise. He (Abu Sa`id) wondered at it and said: Messenger of Allah, repeat it for me. He (the Messenger of Allah) did that and said: There is another act which elevates the position of a man in Paradise to a grade one hundred (higher), and the elevation between one grade and the other is equal to the height of the heaven from the earth. He (Abu Sa`id) said: What is that act? He replied: Jihad in the way of Allah! Jihad in the way of Allah}}
\hadithdefcmd{muslim}{4880}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي، قَتَادَةَ عَنْ أَبِي قَتَادَةَ، أَنَّهُ سَمِعَهُ يُحَدِّثُ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَامَ فِيهِمْ فَذَكَرَ لَهُمْ ‏"‏ أَنَّ الْجِهَادَ فِي سَبِيلِ اللَّهِ وَالإِيمَانَ بِاللَّهِ أَفْضَلُ الأَعْمَالِ ‏"‏ ‏.‏ فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ قُتِلْتُ فِي سَبِيلِ اللَّهِ تُكَفَّرُ عَنِّي خَطَايَاىَ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ إِنْ قُتِلْتَ فِي سَبِيلِ اللَّهِ وَأَنْتَ صَابِرٌ مُحْتَسِبٌ مُقْبِلٌ غَيْرُ مُدْبِرٍ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَيْفَ قُلْتَ ‏"‏ ‏.‏ قَالَ أَرَأَيْتَ إِنْ قُتِلْتُ فِي سَبِيلِ اللَّهِ أَتُكَفَّرُ عَنِّي خَطَايَاىَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ نَعَمْ وَأَنْتَ صَابِرٌ مُحْتَسِبٌ مُقْبِلٌ غَيْرُ مُدْبِرٍ إِلاَّ الدَّيْنَ فَإِنَّ جِبْرِيلَ عَلَيْهِ السَّلاَمُ قَالَ لِي ذَلِكَ ‏"‏ ‏.‏\hadithno{4880}\hadithtrans{It has been narrated on the authority of Abu Qatada that the Messenger of Allah (ﷺ) stood up among them (his Companions) to deliver his sermon in which he told them that Jihad in the way of Allah and belief in Allah (with all His Attributes) are the most meritorious of acts. A man stood up and said:Messenger of Allah, do you think that if I am killed in the way of Allah, my sins will be blotted out from me? The Messenger of Allah (ﷺ) said: Yes, in case you are killed in the way of Allah and you were patient and sincere and you always fought facing the enemy, never turming your back upon him. Then he added: What have you said (now)? (Wishing to have further assurance from him for his satisfaction), he asked (again): Do you think if I am killed in the way of Allah, all my sins will be obliterated from me? The Messenger of Allah (ﷺ) said: Yes, it you were patient and sincere and always fought facing the enemy and never turning your back upon him, (all your lapses would be forgiven) except debt. Gabriel has told me this}}
\hadithdefcmd{muslim}{4881}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ جَاءَ رَجُلٌ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَرَأَيْتَ إِنْ قُتِلْتُ فِي سَبِيلِ اللَّهِ بِمَعْنَى حَدِيثِ اللَّيْثِ ‏.‏\hadithno{4881}\hadithtrans{The tradition has been narrated through a different chain of transmitters on the authority of Abu Qatada who said:A man came to the Messenger of Allah (ﷺ) while he was on the pulpit and said: Do you think if I am killed in the way of Allah... (except this difference in its beginning, the rest of the tradition is the same as the previous one)}}
\hadithdefcmd{muslim}{4882}{وَحَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ مُحَمَّدِ بْنِ قَيْسٍ، ح قَالَ وَحَدَّثَنَا مُحَمَّدُ بْنُ عَجْلاَنَ، عَنْ مُحَمَّدِ بْنِ قَيْسٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم يَزِيدُ أَحَدُهُمَا عَلَى صَاحِبِهِ أَنَّ رَجُلاً أَتَى النَّبِيَّ صلى الله عليه وسلم وَهُوَ عَلَى الْمِنْبَرِ فَقَالَ أَرَأَيْتَ إِنْ ضَرَبْتُ بِسَيْفِي ‏.‏ بِمَعْنَى حَدِيثِ الْمَقْبُرِيِّ ‏.‏\hadithno{4882}\hadithtrans{Another version of the tradition differently transmitted begins with the words:" A man came to the Messenger of Allah (ﷺ) and he was sitting on the pulpit.... He said: What do you find if I strike with the sword?" (The rest of the tradition is the same as the previous one)}}
\hadithdefcmd{muslim}{4883}{حَدَّثَنَا زَكَرِيَّاءُ بْنُ يَحْيَى بْنِ صَالِحٍ الْمِصْرِيُّ، حَدَّثَنَا الْمُفَضَّلُ، - يَعْنِي ابْنَ فَضَالَةَ - عَنْ عَيَّاشٍ، - وَهُوَ ابْنُ عَبَّاسٍ الْقِتْبَانِيُّ - عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يُغْفَرُ لِلشَّهِيدِ كُلُّ ذَنْبٍ إِلاَّ الدَّيْنَ ‏"‏ ‏.‏\hadithno{4883}\hadithtrans{It has been reported on the authority of 'Amr b. al-'As that the Messenger of Allah (ﷺ) said:All the sins of a Shahid (martyr) are forgiven except debt}}
\hadithdefcmd{muslim}{4884}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ الْمُقْرِئُ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي، أَيُّوبَ حَدَّثَنِي عَيَّاشُ بْنُ عَبَّاسٍ الْقِتْبَانِيُّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ، عَمْرِو بْنِ الْعَاصِ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الْقَتْلُ فِي سَبِيلِ اللَّهِ يُكَفِّرُ كُلَّ شَىْءٍ إِلاَّ الدَّيْنَ ‏"‏ ‏.‏\hadithno{4884}\hadithtrans{It has been reported on the authority of Amr b. al-'As through a different chain of transmitters that the Messenger of Allah (ﷺ) said:Death in the way of Allah blots out everything except debt}}
\hadithdefcmd{muslim}{4885}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ كِلاَهُمَا عَنْ أَبِي مُعَاوِيَةَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، وَعِيسَى بْنُ يُونُسَ، جَمِيعًا عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَسْبَاطٌ، وَأَبُو مُعَاوِيَةَ قَالاَ حَدَّثَنَا الأَعْمَشُ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، قَالَ سَأَلْنَا عَبْدَ اللَّهِ عَنْ هَذِهِ الآيَةِ، ‏\{‏ وَلاَ تَحْسَبَنَّ الَّذِينَ قُتِلُوا فِي سَبِيلِ اللَّهِ أَمْوَاتًا بَلْ أَحْيَاءٌ عِنْدَ رَبِّهِمْ يُرْزَقُونَ‏\}‏ قَالَ أَمَا إِنَّا قَدْ سَأَلْنَا عَنْ ذَلِكَ فَقَالَ ‏"‏ أَرْوَاحُهُمْ فِي جَوْفِ طَيْرٍ خُضْرٍ لَهَا قَنَادِيلُ مُعَلَّقَةٌ بِالْعَرْشِ تَسْرَحُ مِنَ الْجَنَّةِ حَيْثُ شَاءَتْ ثُمَّ تَأْوِي إِلَى تِلْكَ الْقَنَادِيلِ فَاطَّلَعَ إِلَيْهِمْ رَبُّهُمُ اطِّلاَعَةً فَقَالَ هَلْ تَشْتَهُونَ شَيْئًا قَالُوا أَىَّ شَىْءٍ نَشْتَهِي وَنَحْنُ نَسْرَحُ مِنَ الْجَنَّةِ حَيْثُ شِئْنَا فَفَعَلَ ذَلِكَ بِهِمْ ثَلاَثَ مَرَّاتٍ فَلَمَّا رَأَوْا أَنَّهُمْ لَنْ يُتْرَكُوا مِنْ أَنْ يُسْأَلُوا قَالُوا يَا رَبِّ نُرِيدُ أَنْ تَرُدَّ أَرْوَاحَنَا فِي أَجْسَادِنَا حَتَّى نُقْتَلَ فِي سَبِيلِكَ مَرَّةً أُخْرَى ‏.‏ فَلَمَّا رَأَى أَنْ لَيْسَ لَهُمْ حَاجَةٌ تُرِكُوا ‏"‏ ‏.‏\hadithno{4885}\hadithtrans{It has been narrated on the authority of Masruq Who said:We asked 'Abdullah about the Qur'anic verse:" Think not of those who are slain in Allah's way as dead. Nay, they are alive, finding their sustenance in the presence of their Lord.." (iii. 169). He said: We asked the meaning of the verse (from the Holy Prophet) who said: The souls, of the martyrs live in the bodies of green birds who have their nests in chandeliers hung from the throne of the Almighty. They eat the fruits of Paradise from wherever they like and then nestle in these chandeliers. Once their Lord cast a glance at them and said: Do ye want anything? They said: What more shall we desire? We eat the fruit of Paradise from wherever we like. Their Lord asked them the same question thrice. When they saw that they will continue to be asked and not left (without answering the question). they said: O Lord, we wish that Thou mayest return our souls to our bodies so that we may be slain in Thy way once again. When He (Allah) saw that they had no need, they were left (to their joy in heaven)}}
\hadithdefcmd{muslim}{4886}{حَدَّثَنَا مَنْصُورُ بْنُ أَبِي مُزَاحِمٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، عَنْ مُحَمَّدِ بْنِ الْوَلِيدِ الزُّبَيْدِيِّ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ أَىُّ النَّاسِ أَفْضَلُ فَقَالَ ‏"‏ رَجُلٌ يُجَاهِدُ فِي سَبِيلِ اللَّهِ بِمَالِهِ وَنَفْسِهِ ‏"‏ قَالَ ثُمَّ مَنْ قَالَ ‏"‏ مُؤْمِنٌ فِي شِعْبٍ مِنَ الشِّعَابِ يَعْبُدُ اللَّهَ رَبَّهُ وَيَدَعُ النَّاسَ مِنْ شَرِّهِ ‏"‏ ‏.‏\hadithno{4886}\hadithtrans{It has been narrated on the authority of Abu Sa'id Khudri that a man came to the Prophet (may peace he upon him) and said:Who is the best of men? He replied: A man who fights in the way of Allah spending his wealth and staking his life. The man then asked: Who is next to him (in excellence)? He said: Next to him is a believer who lives in a mountain gorge worshipping hid Lord and sparing men from his mischief}}
\hadithdefcmd{muslim}{4887}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ، بْنِ يَزِيدَ اللَّيْثِيِّ عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَجُلٌ أَىُّ النَّاسِ أَفْضَلُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ مُؤْمِنٌ يُجَاهِدُ بِنَفْسِهِ وَمَالِهِ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ ثُمَّ مَنْ قَالَ ‏"‏ ثُمَّ رَجُلٌ مُعْتَزِلٌ فِي شِعْبٍ مِنَ الشِّعَابِ يَعْبُدُ رَبَّهُ وَيَدَعُ النَّاسَ مِنْ شَرِّهِ ‏"‏ ‏.‏\hadithno{4887}\hadithtrans{It has been narrated (through a diferent chain of transmetters) on the same authority (i. e. Abu Sa'id Khadri) who said:A man asked: Messenger of Allah, which of men is the best? He said: A believer who fights staking his life and spending his wealth in the way of Allah. He asked: Who is next to him (in excellence)? He said: Next to him is a man who lives an isolated life in a mountain gorge, worshipping his Lord and sparing men from his mischief}}
\hadithdefcmd{muslim}{4888}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا مُحَمَّدُ بْنُ يُوسُفَ، عَنِ الأَوْزَاعِيِّ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ فَقَالَ ‏"‏ وَرَجُلٌ فِي شِعْبٍ ‏"‏ ‏.‏ وَلَمْ يَقُلْ ‏"‏ ثُمَّ رَجُلٌ ‏"‏ ‏.‏\hadithno{4888}\hadithtrans{A version of the tradition narrated on the authority of Ibn Shihab has a little differently worded ending. i. e." A man in a mountain valley." but did not mention" next to him a man who}}
\hadithdefcmd{muslim}{4889}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ بَعْجَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مِنْ خَيْرِ مَعَاشِ النَّاسِ لَهُمْ رَجُلٌ مُمْسِكٌ عِنَانَ فَرَسِهِ فِي سَبِيلِ اللَّهِ يَطِيرُ عَلَى مَتْنِهِ كُلَّمَا سَمِعَ هَيْعَةً أَوْ فَزْعَةً طَارَ عَلَيْهِ يَبْتَغِي الْقَتْلَ وَالْمَوْتَ مَظَانَّهُ أَوْ رَجُلٌ فِي غُنَيْمَةٍ فِي رَأْسِ شَعَفَةٍ مِنْ هَذِهِ الشَّعَفِ أَوْ بَطْنِ وَادٍ مِنْ هَذِهِ الأَوْدِيَةِ يُقِيمُ الصَّلاَةَ وَيُؤْتِي الزَّكَاةَ وَيَعْبُدُ رَبَّهُ حَتَّى يَأْتِيَهُ الْيَقِينُ لَيْسَ مِنَ النَّاسِ إِلاَّ فِي خَيْرٍ ‏"‏ ‏.‏\hadithno{4889}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:Of the men he lives the best life who holds the reins of his horse (ever ready to march) in the way of Allah, flies on its back whenever he hears a fearful shriek, or a call for help, flies to it seeking death at places where it can be expected. (Next to him) is a man who lives with his sheep at a hill-top or in a valley, says his prayers regularly, gives Zakat and worships his Lord until death comes to him. There is no better person among men except these two}}
\hadithdefcmd{muslim}{4890}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ أَبِي حَازِمٍ، وَيَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - كِلاَهُمَا عَنْ أَبِي حَازِمٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ وَقَالَ عَنْ بَعْجَةَ بْنِ، عَبْدِ اللَّهِ بْنِ بَدْرٍ وَقَالَ ‏ "‏ فِي شِعْبَةٍ مِنْ هَذِهِ الشِّعَابِ ‏"‏ ‏.‏ خِلاَفَ رِوَايَةِ يَحْيَى ‏.‏\hadithno{4890}\hadithtrans{This hadith has been transmitted on the authority of Abu Huraira with a slight variation of wording}}
\hadithdefcmd{muslim}{4891}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَ أَبُو كُرَيْبٍ قَالُوا حَدَّثَنَا وَكِيعٌ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ بَعْجَةَ بْنِ عَبْدِ اللَّهِ الْجُهَنِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ أَبِي حَازِمٍ عَنْ بَعْجَةَ وَقَالَ ‏ "‏ فِي شِعْبٍ مِنَ الشِّعَابِ ‏"‏ ‏.‏\hadithno{4891}\hadithtrans{Two more versions of the tradition narrated by 'Abdullah b. Badr and Abu Huraira, respectively, have been handed down through different chains of transmitters with negligible difference in the wording}}
\hadithdefcmd{muslim}{4892}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ يَضْحَكُ اللَّهُ إِلَى رَجُلَيْنِ يَقْتُلُ أَحَدُهُمَا الآخَرَ كِلاَهُمَا يَدْخُلُ الْجَنَّةَ ‏"‏ ‏.‏ فَقَالُوا كَيْفَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ يُقَاتِلُ هَذَا فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ فَيُسْتَشْهَدُ ثُمَّ يَتُوبُ اللَّهُ عَلَى الْقَاتِلِ فَيُسْلِمُ فَيُقَاتِلُ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ فَيُسْتَشْهَدُ ‏"‏ ‏.‏\hadithno{4892}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:God laughs at the two men both of whom will enter Paradise (though) one of them kills the other. They said: Messenger of Allah, how is it? He said: One of them fights in the way of Allah, the Almighty and Exalted. and dies a martyr. Then God turns in mercy to the murderer who embraces Islam, fights in the way of Allah, the Almighty and Exalted, and dies a martyr}}
\hadithdefcmd{muslim}{4893}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَأَبُو كُرَيْبٍ قَالُوا حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي الزِّنَادِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4893}\hadithtrans{The same tradition has been narrated on the authority of Abu Zinad (with the same chain of transmitters)}}
\hadithdefcmd{muslim}{4894}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَضْحَكُ اللَّهُ لِرَجُلَيْنِ يَقْتُلُ أَحَدُهُمَا الآخَرَ كِلاَهُمَا يَدْخُلُ الْجَنَّةَ ‏"‏ قَالُوا كَيْفَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ يُقْتَلُ هَذَا فَيَلِجُ الْجَنَّةَ ثُمَّ يَتُوبُ اللَّهُ عَلَى الآخَرِ فَيَهْدِيهِ إِلَى الإِسْلاَمِ ثُمَّ يُجَاهِدُ فِي سَبِيلِ اللَّهِ فَيُسْتَشْهَدُ ‏"‏ ‏.‏\hadithno{4894}\hadithtrans{It has been reported on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:God laughs at the two men one of whom kills the other; both of them will enter Paradise. They (the Companions) said: How, Messenger of Allah? He said: One is slain (in the way of Allah) and enters Paradise. Then God forgives the other and guides him to Islam; then he fights in the way of Allah and dies a martyr}}
\hadithdefcmd{muslim}{4895}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَعَلِيُّ بْنُ حُجْرٍ، قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَجْتَمِعُ كَافِرٌ وَقَاتِلُهُ فِي النَّارِ أَبَدًا ‏"‏ ‏.‏\hadithno{4895}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger Allah (ﷺ) said:A disbeliever and a believer who killed him will never be gathered together in Hell}}
\hadithdefcmd{muslim}{4896}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَوْنٍ الْهِلاَلِيُّ، حَدَّثَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، إِبْرَاهِيمُ بْنُ مُحَمَّدٍ عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَجْتَمِعَانِ فِي النَّارِ اجْتِمَاعًا يَضُرُّ أَحَدُهُمَا الآخَرَ ‏"‏ ‏.‏ قِيلَ مَنْ هُمْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ مُؤْمِنٌ قَتَلَ كَافِرًا ثُمَّ سَدَّدَ ‏"‏ ‏.‏\hadithno{4896}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:No two such persons shall be together in Hell as if one of them is such that his presence hurts the other. It was asked: Messenger of Allah, who are they? He said: A believer who killed a disbeliever and (then) kept to the right path}}
\hadithdefcmd{muslim}{4897}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، أَخْبَرَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي عَمْرٍو، الشَّيْبَانِيِّ عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ جَاءَ رَجُلٌ بِنَاقَةٍ مَخْطُومَةٍ فَقَالَ هَذِهِ فِي سَبِيلِ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَكَ بِهَا يَوْمَ الْقِيَامَةِ سَبْعُمِائَةِ نَاقِةٍ كُلُّهَا مَخْطُومَةٌ ‏"‏ ‏.‏\hadithno{4897}\hadithtrans{It has been narrated on the authority of Abu Mas'ud al-Ansari who said A man brought a muzzled she-camel and said:It is (offered) in the way of Allah. The Messenger of Allah (ﷺ) said: For this you will have seven hundred she-camels on the Day of Judgment all of which will be muzzled}}
\hadithdefcmd{muslim}{4898}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ زَائِدَةَ، ح وَحَدَّثَنِي بِشْرُ بْنُ، خَالِدٍ حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - حَدَّثَنَا شُعْبَةُ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{4898}\hadithtrans{A similar tradition has been narrated on the authority of al-A'mash}}
\hadithdefcmd{muslim}{4899}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَابْنُ أَبِي عُمَرَ - وَاللَّفْظُ لأَبِي كُرَيْبٍ - قَالُوا حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي عَمْرٍو الشَّيْبَانِيِّ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنِّي أُبْدِعَ بِي فَاحْمِلْنِي فَقَالَ ‏"‏ مَا عِنْدِي ‏"‏ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَنَا أَدُلُّهُ عَلَى مَنْ يَحْمِلُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ دَلَّ عَلَى خَيْرٍ فَلَهُ مِثْلُ أَجْرِ فَاعِلِهِ ‏"‏ ‏.‏\hadithno{4899}\hadithtrans{It has been narrated on the authority of Abu Mas'ud al-Ansari who said:A man came to the Messenger of Allah (ﷺ) and said: My riding beast has been killed, so give me some animal to ride upon. He (the Holy Prophet) said: I have none with me. A man said: Messenger of Allah, I can guide him to one who will provide him with a riding beast. The Messenger of Allah (ﷺ) said: One who guides to something good has a reward similar to that of its doer}}
\hadithdefcmd{muslim}{4900}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنِي بِشْرُ بْنُ خَالِدٍ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا سُفْيَانُ، كُلُّهُمْ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{4900}\hadithtrans{The above tradition has been handed down through a different chain of transmitters}}
\hadithdefcmd{muslim}{4901}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، ح وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ فَتًى، مِنْ أَسْلَمَ قَالَ يَا رَسُولَ اللَّهِ إِنِّي أُرِيدُ الْغَزْوَ وَلَيْسَ مَعِي مَا أَتَجَهَّزُ قَالَ ‏ "‏ ائْتِ فُلاَنًا فَإِنَّهُ قَدْ كَانَ تَجَهَّزَ فَمَرِضَ ‏"‏ ‏.‏ فَأَتَاهُ فَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يُقْرِئُكَ السَّلاَمَ وَيَقُولُ أَعْطِنِي الَّذِي تَجَهَّزْتَ بِهِ قَالَ يَا فُلاَنَةُ أَعْطِيهِ الَّذِي تَجَهَّزْتُ بِهِ وَلاَ تَحْبِسِي عَنْهُ شَيْئًا فَوَاللَّهِ لاَ تَحْبِسِي مِنْهُ شَيْئًا فَيُبَارَكَ لَكِ فِيهِ ‏.‏\hadithno{4901}\hadithtrans{It has been narrated on the authority of Anas b. Malik that a young man from Aslam tribe said:Messenger of Allah, I wish to fight (in the way of Allah) but I don't have anything to equip myself with for fighting. He (the Holy Prophet) said: Go to so and so, for he had equipped himself (for fighting) but he fell ill. So, he (the young man) went to him and said: The Messenger of Allah (ﷺ) sends you his greetings and says that you should give me the equipage that you have provided yourself with. The man said (to his wife or maidservant): So and so, give him the equipage I have collected for myself and do not withhold anything from him. Do not withhold anything from him so that you may be blessed therein}}
\hadithdefcmd{muslim}{4902}{وَحَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَأَبُو الطَّاهِرِ، قَالَ أَبُو الطَّاهِرِ أَخْبَرَنَا ابْنُ وَهْبٍ، وَقَالَ، سَعِيدٌ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ بُسْرِ، بْنِ سَعِيدٍ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَنْ جَهَّزَ غَازِيًا فِي سَبِيلِ اللَّهِ فَقَدْ غَزَا وَمَنْ خَلَفَهُ فِي أَهْلِهِ بِخَيْرٍ فَقَدْ غَزَا ‏"‏ ‏.‏\hadithno{4902}\hadithtrans{It has been narrated on the authority of Zaid b. Khalid al-Juhani that the Messenger of Allah (ﷺ) said:Anybody who equips a warrior (going to fight) in the way of Allah (is like one who actually) fights. And anybody who looks well after his family in his absence (is also like one who actually) fights}}
\hadithdefcmd{muslim}{4903}{حَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا حُسَيْنٌ، الْمُعَلِّمُ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ قَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنَ جَهَّزَ غَازِيًا فَقَدْ غَزَا وَمَنْ خَلَفَ غَازِيًا فِي أَهْلِهِ فَقَدْ غَزَا ‏"‏ ‏.‏\hadithno{4903}\hadithtrans{The above tradition has been narrated on the authority of Khalid al- Juhani who said:The Prophet of Allah (ﷺ) said: He who equips a warrior in the way of Allah (is like one who dctually fights) aud he who looks after the family of a warrior in the way of Allah in fact participated in the battle}}
\hadithdefcmd{muslim}{4904}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ عَلِيِّ بْنِ الْمُبَارَكِ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي أَبُو سَعِيدٍ، مَوْلَى الْمَهْرِيِّ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ بَعْثًا إِلَى بَنِي لِحْيَانَ - مِنْ هُذَيْلٍ - فَقَالَ ‏ "‏ لِيَنْبَعِثْ مِنْ كُلِّ رَجُلَيْنِ أَحَدُهُمَا وَالأَجْرُ بَيْنَهُمَا ‏"‏ ‏.‏\hadithno{4904}\hadithtrans{It has been narrated on the authority of Abu Sa'id Khudri that the Messenger of Allah (ﷺ) sent a force to Banu Lihyan (who are from Banu Hudhail, and said:One man from every two and the reward (will be divided) between the two}}
\hadithdefcmd{muslim}{4907}{وَحَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ يَزِيدَ بْنِ أَبِي سَعِيدٍ، مَوْلَى الْمَهْرِيِّ عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ إِلَى بَنِي لَحْيَانَ ‏"‏ لِيَخْرُجْ مِنْ كُلِّ رَجُلَيْنِ رَجُلٌ ‏"‏ ‏.‏ ثُمَّ قَالَ لِلْقَاعِدِ ‏"‏ أَيُّكُمْ خَلَفَ الْخَارِجَ فِي أَهْلِهِ وَمَالِهِ بِخَيْرٍ كَانَ لَهُ مِثْلُ نِصْفِ أَجْرِ الْخَارِجِ ‏"‏ ‏.‏\hadithno{4907}\hadithtrans{It has been narrated (through a still different chain of transmitters) on the authority of Abu Sa'id Khudrl that the Messenger of Allah (ﷺ) despatched a force to Banu Lihyan. (and said:) One man from every two should join the force. Then he said to those who stayed behind: Those of you who will look well after the family and wealth of those who are going on the expedition will be getting half the reward of the warriors}}
\hadithdefcmd{muslim}{4908}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ حُرْمَةُ نِسَاءِ الْمُجَاهِدِينَ عَلَى الْقَاعِدِينَ كَحُرْمَةِ أُمَّهَاتِهِمْ وَمَا مِنْ رَجُلٍ مِنَ الْقَاعِدِينَ يَخْلُفُ رَجُلاً مِنَ الْمُجَاهِدِينَ فى أَهْلِهِ فَيَخُونُهُ فِيهِمْ إِلاَّ وُقِفَ لَهُ يَوْمَ الْقِيَامَةِ فَيَأْخُذُ مِنْ عَمَلِهِ مَا شَاءَ فَمَا ظَنُّكُمْ ‏"‏ ‏.‏\hadithno{4908}\hadithtrans{It has been narrated on the authority of Sulaimin b. Buraida who learnt the tradition from his father. The latter said that the Messenger of Allah (ﷺ) said:The sanctity of the wives of Mujahids is like the sanctity of their mothers for those who sit at home (i. e do not go out for Jihad). Anyone who stays behind looking after the family of a Mujahid and betrays his trust will be made to stand on the Day of judgment before the Mujahid who will take away from his meritorious deeds whatever he likes. So what do you think (will he leave anything)?}}
\hadithdefcmd{muslim}{4909}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا مِسْعَرٌ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ - يَعْنِي النَّبِيَّ صلى الله عليه وسلم ‏.‏ بِمَعْنَى حَدِيثِ الثَّوْرِيِّ ‏.‏\hadithno{4909}\hadithtrans{This tradition has been narrated by the same authority through different chain of transmitters}}
\hadithdefcmd{muslim}{4910}{وَحَدَّثَنَاهُ سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا سُفْيَانُ، عَنْ قَعْنَبٍ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، بِهَذَا الإِسْنَادِ ‏"‏ فَقَالَ فَخُذْ مِنْ حَسَنَاتِهِ مَا شِئْتَ ‏"‏ ‏.‏ فَالْتَفَتَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ فَمَا ظَنُّكُمْ ‏"‏ ‏.‏\hadithno{4910}\hadithtrans{A version of the tradition narrated on the authority of 'Alqama b. Murthad has a differently worded end:It will be said to the Mujahid: Take from his noble deeds whatever you like. Then the Messenger of Allah (ﷺ) turned to us and asked: What do you think (will he leave anything)? - (i. e. he will take away everything)}}
\hadithdefcmd{muslim}{4911}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، أَنَّهُ سَمِعَ الْبَرَاءَ، يَقُولُ فِي هَذِهِ الآيَةِ لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ وَالْمُجَاهِدُونَ فِي سَبِيلِ اللَّهِ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَيْدًا فَجَاءَ بِكَتِفٍ يَكْتُبُهَا فَشَكَا إِلَيْهِ ابْنُ أُمِّ مَكْتُومٍ ضَرَارَتَهُ فَنَزَلَتْ ‏\{‏ لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ غَيْرُ أُولِي الضَّرَرِ‏\}‏ قَالَ شُعْبَةُ وَأَخْبَرَنِي سَعْدُ بْنُ إِبْرَاهِيمَ عَنْ رَجُلٍ عَنْ زَيْدِ بْنِ ثَابِتٍ فِي هَذِهِ الآيَةِ لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ بِمِثْلِ حَدِيثِ الْبَرَاءِ وَقَالَ ابْنُ بَشَّارٍ فِي رِوَايَتِهِ سَعْدُ بْنُ إِبْرَاهِيمَ عَنْ أَبِيهِ عَنْ رَجُلٍ عَنْ زَيْدِ بْنِ ثَابِتٍ ‏.‏\hadithno{4911}\hadithtrans{It has been narrated on the authority of Abu Ishaq, that he heard Bara' talking about the Qur'anic verse:" Those who sit (at home) from among the believers and those who go out for Jihad in the way of Allah are not aqual" (iv. 95). (He said that) the Messenger of Allah (ﷺ) ordered Zaid (to write the verse). He brought a shoulder-blade (of a slaughtered camel) and inscribed it (the verse) thereon. The son of Umm Maktum complained of his blindness to the Prophet (ﷺ). (At this) descended the revelation:" Those of the believers who sit (at home) without any trouble (illness, incapacity, disability)" (iv. 95). The tradition has been handed down through two other chains of transmitters}}
\hadithdefcmd{muslim}{4912}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ بِشْرٍ، عَنْ مِسْعَرٍ، حَدَّثَنِي أَبُو إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ لَمَّا نَزَلَتْ ‏\{‏ لاَ يَسْتَوِي الْقَاعِدُونَ مِنَ الْمُؤْمِنِينَ‏\}‏ كَلَّمَهُ ابْنُ أُمِّ مَكْتُومٍ فَنَزَلَتْ ‏\{‏ غَيْرُ أُولِي الضَّرَرِ‏\}‏\hadithno{4912}\hadithtrans{It has been narrated on the authority of Bara' who said:When the Qur'anic verse:" Those who sit (at home) from among mu'min" (iv. 94) was revealed, the son of Umm Maktum spoke to him (the Holy Prophet). (At this). the words:" other than those who have a trouble (illness)" were revealed}}
\hadithdefcmd{muslim}{4913}{حَدَّثَنَا سَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، وَسُوَيْدُ بْنُ سَعِيدٍ، - وَاللَّفْظُ لِسَعِيدٍ - أَخْبَرَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعَ جَابِرًا، يَقُولُ قَالَ رَجُلٌ أَيْنَ أَنَا يَا، رَسُولَ اللَّهِ إِنْ قُتِلْتُ قَالَ ‏ "‏ فِي الْجَنَّةِ ‏"‏ ‏.‏ فَأَلْقَى تَمَرَاتٍ كُنَّ فِي يَدِهِ ثُمَّ قَاتَلَ حَتَّى قُتِلَ ‏.‏ وَفِي حَدِيثِ سُوَيْدٍ قَالَ رَجُلٌ لِلنَّبِيِّ صلى الله عليه وسلم يَوْمَ أُحُدٍ ‏.‏\hadithno{4913}\hadithtrans{It has been reported on the authority of Jabir that a man said:Messenger of Allah, where shall I be if I am killed? He replied: In Paradise. The man threw away the dates he had in his hand and fought until he was killed (i. e. he did not wait until he could finish the dates). In the version of the tradition narrated by Suwaid we have the words:" A man said to the Prophet (ﷺ). on the day of Uhud}}
\hadithdefcmd{muslim}{4914}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ زَكَرِيَّاءَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ جَاءَ رَجُلٌ مِنْ بَنِي النَّبِيتِ إِلَى النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنَا أَحْمَدُ بْنُ جَنَابٍ الْمِصِّيصِيُّ حَدَّثَنَا عِيسَى - يَعْنِي ابْنَ يُونُسَ - عَنْ زَكَرِيَّاءَ عَنْ أَبِي إِسْحَاقَ عَنِ الْبَرَاءِ قَالَ جَاءَ رَجُلٌ مِنْ بَنِي النَّبِيتِ - قَبِيلٍ مِنَ الأَنْصَارِ - فَقَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّكَ عَبْدُهُ وَرَسُولُهُ ‏.‏ ثُمَّ تَقَدَّمَ فَقَاتَلَ حَتَّى قُتِلَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ عَمِلَ هَذَا يَسِيرًا وَأُجِرَ كَثِيرًا ‏"‏ ‏.‏\hadithno{4914}\hadithtrans{It has been reported on the authority of Bara! ' who stated:A man from Banu Nabit (one of the Ansar tribes) came to the Prophet (ﷺ) and said: I testify that there is no god except Allah and that thou art His bondman and Messenger. Then he went forward and fought until he was killed. The Prophet (ﷺ) said: He has done a little but shall be given a great reward}}
\hadithdefcmd{muslim}{4915}{حَدَّثَنَا أَبُو بَكْرِ بْنُ النَّضْرِ بْنِ أَبِي النَّضْرِ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، وَمُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ - وَأَلْفَاظُهُمْ مُتَقَارِبَةٌ - قَالُوا حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا سُلَيْمَانُ، - وَهُوَ ابْنُ الْمُغِيرَةِ - عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم بُسَيْسَةَ عَيْنًا يَنْظُرُ مَا صَنَعَتْ عِيرُ أَبِي سُفْيَانَ فَجَاءَ وَمَا فِي الْبَيْتِ أَحَدٌ غَيْرِي وَغَيْرُ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ لاَ أَدْرِي مَا اسْتَثْنَى بَعْضَ نِسَائِهِ قَالَ فَحَدَّثَهُ الْحَدِيثَ قَالَ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَتَكَلَّمَ فَقَالَ ‏"‏ إِنَّ لَنَا طَلِبَةً فَمَنْ كَانَ ظَهْرُهُ حَاضِرًا فَلْيَرْكَبْ مَعَنَا ‏"‏ ‏.‏ فَجَعَلَ رِجَالٌ يَسْتَأْذِنُونَهُ فِي ظُهْرَانِهِمْ فِي عُلْوِ الْمَدِينَةِ فَقَالَ ‏"‏ لاَ إِلاَّ مَنْ كَانَ ظَهْرُهُ حَاضِرًا ‏"‏ ‏.‏ فَانْطَلَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَصْحَابُهُ حَتَّى سَبَقُوا الْمُشْرِكِينَ إِلَى بَدْرٍ وَجَاءَ الْمُشْرِكُونَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يُقَدِّمَنَّ أَحَدٌ مِنْكُمْ إِلَى شَىْءٍ حَتَّى أَكُونَ أَنَا دُونَهُ ‏"‏ ‏.‏ فَدَنَا الْمُشْرِكُونَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قُومُوا إِلَى جَنَّةٍ عَرْضُهَا السَّمَوَاتُ وَالأَرْضُ ‏"‏ ‏.‏ قَالَ يَقُولُ عُمَيْرُ بْنُ الْحُمَامِ الأَنْصَارِيُّ يَا رَسُولَ اللَّهِ جَنَّةٌ عَرْضُهَا السَّمَوَاتُ وَالأَرْضُ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ بَخٍ بَخٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا يَحْمِلُكَ عَلَى قَوْلِكَ بَخٍ بَخٍ ‏"‏ ‏.‏ قَالَ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ إِلاَّ رَجَاءَةَ أَنْ أَكُونَ مِنْ أَهْلِهَا ‏.‏ قَالَ ‏"‏ فَإِنَّكَ مِنْ أَهْلِهَا ‏"‏ ‏.‏ فَأَخْرَجَ تَمَرَاتٍ مِنْ قَرْنِهِ فَجَعَلَ يَأْكُلُ مِنْهُنَّ ثُمَّ قَالَ لَئِنْ أَنَا حَيِيتُ حَتَّى آكُلَ تَمَرَاتِي هَذِهِ إِنَّهَا لَحَيَاةٌ طَوِيلَةٌ - قَالَ - فَرَمَى بِمَا كَانَ مَعَهُ مِنَ التَّمْرِ ‏.‏ ثُمَّ قَاتَلَهُمْ حَتَّى قُتِلَ ‏.‏\hadithno{4915}\hadithtrans{It has been reported on the authority of Anas b. Malik who said:The Messenger of Allah (ﷺ) sent Busaisah as a scout to see what the caravan of Abu Sufyan was doing. He came (back and met the Prophet in his house) where there was nobody except myself and the Messenger of Allah. I do not remember whether he (Hadrat Anas) made an exception of some wives of the Prophet (ﷺ) or not and told him the news of the caravan. (Having heard the news), the Messenger of Allah (ﷺ) came out (hurriedly), spoke to the people and said: We are in need (of men) ; whoever has an animal to ride upon ready with him should ride with us. People began to ask him permission for bringing their riding animals which were grazing on the hillocks near Medina. He said: No. (I want) only those who have their riding animals ready. So the Messenger of Allah (ﷺ) and his Companions proceeded towards Badr and reached there forestalling the polytheists (of Mecca). When the polytheists (also) reached there, the Messenger of Allah (ﷺ) said: None of you should step forward to (do) anything unless I am ahead of him. The polytheists (now) advanced (towards us), and the Messenger of Allah (ﷺ) said. Get up to enter Paradise which is equal in width to the heavens and the earth. 'Umair b. al- Humam al-Ansari said: Messenger of Allah, is Paradise equal in extent to the heavens and the earth? He said: Yes. 'Umair said: My goodness! The Messenger of Allah (ﷺ) asked him: What prompted you to utter these words (i. e. my goodness! ')? He said: Messenger of Allah, nothing but the desire that I be among its residents. He said: Thou art (surely) amona its residents. He took out dates from his bag and began to eat them. Then he said: If I were to live until I have eaten all these dates of mine, it would be a long life. (The narrator said): He threw away all the dates he had with him. Then he fought the enemies until he was killed}}
\hadithdefcmd{muslim}{4916}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، - وَاللَّفْظُ لِيَحْيَى - قَالَ قُتَيْبَةُ حَدَّثَنَا وَقَالَ، يَحْيَى أَخْبَرَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ أَبِي بَكْرِ بْنِ، عَبْدِ اللَّهِ بْنِ قَيْسٍ عَنْ أَبِيهِ، قَالَ سَمِعْتُ أَبِي وَهُوَ، بِحَضْرَةِ الْعَدُوِّ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَبْوَابَ الْجَنَّةِ تَحْتَ ظِلاَلِ السُّيُوفِ ‏"‏ ‏.‏ فَقَامَ رَجُلٌ رَثُّ الْهَيْئَةِ فَقَالَ يَا أَبَا مُوسَى آنْتَ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ هَذَا قَالَ نَعَمْ ‏.‏ قَالَ فَرَجَعَ إِلَى أَصْحَابِهِ فَقَالَ أَقْرَأُ عَلَيْكُمُ السَّلاَمَ ‏.‏ ثُمَّ كَسَرَ جَفْنَ سَيْفِهِ فَأَلْقَاهُ ثُمَّ مَشَى بِسَيْفِهِ إِلَى الْعَدُوِّ فَضَرَبَ بِهِ حَتَّى قُتِلَ ‏.‏\hadithno{4916}\hadithtrans{The tradition has been narrated on the authority of 'Abdullah b. Qais. He heard it from his father who, while facing the enemy, reported that the Messenger of Allah (ﷺ) said:Surely, the gates of Paradise are under the shadows of the swords. A man in a shabby condition got up and said; Abu Musa, did you hear the Messenger of Allah (ﷺ) say this? He said: Yes. (The narrator said): He returned to his friends and said: I greet you (a farewell greeting). Then he broke the sheath of his sword, threw it away, advanced with his (naked) sword towards the enemy and fought (them) with it until he was slain}}
\hadithdefcmd{muslim}{4917}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا ثَابِتٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ جَاءَ نَاسٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالُوا أَنِ ابْعَثْ مَعَنَا رِجَالاً يُعَلِّمُونَا الْقُرْآنَ وَالسُّنَّةَ ‏.‏ فَبَعَثَ إِلَيْهِمْ سَبْعِينَ رَجُلاً مِنَ الأَنْصَارِ يُقَالُ لَهُمُ الْقُرَّاءُ فِيهِمْ خَالِي حَرَامٌ يَقْرَءُونَ الْقُرْآنَ وَيَتَدَارَسُونَ بِاللَّيْلِ يَتَعَلَّمُونَ وَكَانُوا بِالنَّهَارِ يَجِيئُونَ بِالْمَاءِ فَيَضَعُونَهُ فِي الْمَسْجِدِ وَيَحْتَطِبُونَ فَيَبِيعُونَهُ وَيَشْتَرُونَ بِهِ الطَّعَامَ لأَهْلِ الصُّفَّةِ وَلِلْفُقَرَاءِ فَبَعَثَهُمُ النَّبِيُّ صلى الله عليه وسلم إِلَيْهِمْ فَعَرَضُوا لَهُمْ فَقَتَلُوهُمْ قَبْلَ أَنْ يَبْلُغُوا الْمَكَانَ ‏.‏ فَقَالُوا اللَّهُمَّ بَلِّغْ عَنَّا نَبِيَّنَا أَنَّا قَدْ لَقِينَاكَ فَرَضِينَا عَنْكَ وَرَضِيتَ عَنَّا - قَالَ - وَأَتَى رَجُلٌ حَرَامًا خَالَ أَنَسٍ مِنْ خَلْفِهِ فَطَعَنَهُ بِرُمْحٍ حَتَّى أَنْفَذَهُ ‏.‏ فَقَالَ حَرَامٌ فُزْتُ وَرَبِّ الْكَعْبَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَصْحَابِهِ ‏ "‏ إِنَّ إِخْوَانَكُمْ قَدْ قُتِلُوا وَإِنَّهُمْ قَالُوا اللَّهُمَّ بَلِّغْ عَنَّا نَبِيَّنَا أَنَّا قَدْ لَقِينَاكَ فَرَضِينَا عَنْكَ وَرَضِيتَ عَنَّا ‏"‏ ‏.‏\hadithno{4917}\hadithtrans{It has been reported on the authority of Anas b. Malik that some people came to the Messenger of Allah (ﷺ) and said to him:Send with us some men who may teach us the Qur'an and the Sunnah. Accordingjy, he sent seventy men from the Ansar. They were called the Reciters and among them was my maternal uncle. Haram. They used to recite the Qur'an, discuss and ponder over its meaning at night. In the day they brought water and poured it (in pitchers) in the mosque, collected wood and sold it, and with the sale proceeds bought food for the people of the Suffa and the needy. The Prophet (ﷺ) sent the Reciters with these people, but these (treacherous people) fell upon them and killed thern before they reached their destination (While dying), they said: O Allah, convey from us the news to our Prophet that we have met Thee (in a way) that we are pleased with Thee and Thou art pleased with us. (The narrator said): A man attacked Haram (maternal uncle of Anas) ) from behind and smote him with a spear which pierced him. (While dying), Haram said: By the Lord of the Ka'ba, I have met with success. The Messenger of Allah (ﷺ) said to his Companions: Your brethren have been slain grid they were saying: O Allah, convey from us to our Prophet the news that we have met Thee in a way that we are pleased with Thee and Thou art pleased with us}}
\hadithdefcmd{muslim}{4918}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، عَنْ ثَابِتٍ، قَالَ قَالَ أَنَسٌ عَمِّيَ الَّذِي سُمِّيتُ بِهِ لَمْ يَشْهَدْ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بَدْرًا - قَالَ - فَشَقَّ عَلَيْهِ قَالَ أَوَّلُ مَشْهَدٍ شَهِدَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم غُيِّبْتُ عَنْهُ وَإِنْ أَرَانِيَ اللَّهُ مَشْهَدًا فِيمَا بَعْدُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيَرَانِيَ اللَّهُ مَا أَصْنَعُ - قَالَ - فَهَابَ أَنْ يَقُولَ غَيْرَهَا - قَالَ - فَشَهِدَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ أُحُدٍ - قَالَ - فَاسْتَقْبَلَ سَعْدُ بْنُ مُعَاذٍ فَقَالَ لَهُ أَنَسٌ يَا أَبَا عَمْرٍو أَيْنَ فَقَالَ وَاهًا لِرِيحِ الْجَنَّةِ أَجِدُهُ دُونَ أُحُدٍ - قَالَ - فَقَاتَلَهُمْ حَتَّى قُتِلَ - قَالَ - فَوُجِدَ فِي جَسَدِهِ بِضْعٌ وَثَمَانُونَ مِنْ بَيْنِ ضَرْبَةٍ وَطَعْنَةٍ وَرَمْيَةٍ - قَالَ - فَقَالَتْ أُخْتُهُ عَمَّتِيَ الرُّبَيِّعُ بِنْتُ النَّضْرِ فَمَا عَرَفْتُ أَخِي إِلاَّ بِبَنَانِهِ ‏.‏ وَنَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ رِجَالٌ صَدَقُوا مَا عَاهَدُوا اللَّهَ عَلَيْهِ فَمِنْهُمْ مَنْ قَضَى نَحْبَهُ وَمِنْهُمْ مَنْ يَنْتَظِرُ وَمَا بَدَّلُوا تَبْدِيلاً‏\}‏ قَالَ فَكَانُوا يُرَوْنَ أَنَّهَا نَزَلَتْ فِيهِ وَفِي أَصْحَابِهِ ‏.‏\hadithno{4918}\hadithtrans{It has been Deported on the authority of Anas who said:My uncle and I have been named after him was not present with the Messenger of Allah (mav peace be upon him) on the Day of Badr. He felt distressed about it. He would say: I have missed the first battle fought by the Messenger of Allah (ﷺ), and if God now gives me an opportunity to see a battlefield with the Messenger of Allah (ﷺ), God will see what I do therein. He was afraid to say more than this (lest he be unable to keep his word with God). He was present with the Messenger of Allah (ﷺ) on the Day of Uhud. He met Sa'd b. Mu'adh (who was retreating). Anas said to him: O Abu 'Amr, where (are you going)? Woe (to thee)! I find the smell of Paradise beside the Uhud mountain. (Reprimanding Sa'd in these words) he went forward and fought thein (the enemy) until he was killed. (The narrator says). More than eighty wounds inflicted with swords, spears and arrows were found on his body. His sister, my aunt, ar-Rubayyi', daughter of Nadr, said: I could not recognise my brother's body (it was so badly mutilated) except from his finger-tips. (It was on this occasion that) the Qur'anic verse:" Among the Believers are men who have been true to their covenant with God. Of them some have completed their vow (to the extreme), and some still wait: but they have never changed (their determination) in the least" (xxxiii. 23). The narrator said that the verse had been revealed about him (Anas b. Nadr) and his Companions}}
\hadithdefcmd{muslim}{4919}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، قَالَ حَدَّثَنَا أَبُو مُوسَى، الأَشْعَرِيُّ أَنَّ رَجُلاً، أَعْرَابِيًّا أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ الرَّجُلُ يُقَاتِلُ لِلْمَغْنَمِ وَالرَّجُلُ يُقَاتِلُ لِيُذْكَرَ وَالرَّجُلُ يُقَاتِلُ لِيُرَى مَكَانُهُ فَمَنْ فِي سَبِيلِ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَاتَلَ لِتَكُونَ كَلِمَةُ اللَّهِ أَعْلَى فَهُوَ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏\hadithno{4919}\hadithtrans{It has been narrated on the authority of Abu Musa Ash'ari that a desert Arab came to the Prophet (ﷺ) and said:Messenger of Allah, one man fights fgr the spoils of war; another fights that he may be remembered, and another fights that he may see his (high) position (achieved as a result of his valour in fighting). Which of these is fighting in the cause of God? The Messenger of Allah (ﷺ) said: Who fights so that the word of Allah is exalted is fighting in the way of Allah}}
\hadithdefcmd{muslim}{4920}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ وَمُحَمَّدُ بْنُ الْعَلاَءِ قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ أَبِي، مُوسَى قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الرَّجُلِ يُقَاتِلُ شَجَاعَةً وَيُقَاتِلُ حَمِيَّةً وَيُقَاتِلُ رِيَاءً أَىُّ ذَلِكَ فِي سَبِيلِ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَاتَلَ لِتَكُونَ كَلِمَةُ اللَّهِ هِيَ الْعُلْيَا فَهُوَ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏\hadithno{4920}\hadithtrans{It has been narrated (through another chain of transmitters) on the authority of Abu Musa who said. The Messenger of Allah (ﷺ) was asked which of the men fights in the way of Allah:(one who fights) for displaying his valour; (a man who) fights out of his family pride and (a man who) fights for the sake of show, who amongst these fights in the way of Allah? The Messenger of Allah (ﷺ) said: Who fights that the word of Allah be exalted fights in the way of Allah}}
\hadithdefcmd{muslim}{4921}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ أَبِي مُوسَى، قَالَ أَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْنَا يَا رَسُولَ اللَّهِ الرَّجُلُ يُقَاتِلُ مِنَّا شَجَاعَةً ‏.‏ فَذَكَرَ مِثْلَهُ ‏.‏\hadithno{4921}\hadithtrans{It has been narrated (through yet another chain of transmitters) on the same authority, i. e. Abu Musa, who said:We, came to the Messenger of Allah (ﷺ) and said: Messenger of Allah, one of us hho fights to display his valour... (followed by the same words as we have in the previous tradition)}}
\hadithdefcmd{muslim}{4922}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي، مُوسَى الأَشْعَرِيِّ أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْقِتَالِ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ فَقَالَ الرَّجُلُ يُقَاتِلُ غَضَبًا وَيُقَاتِلُ حَمِيَّةً قَالَ فَرَفَعَ رَأْسَهُ إِلَيْهِ - وَمَا رَفَعَ رَأْسَهُ إِلَيْهِ إِلاَّ أَنَّهُ كَانَ قَائِمًا - فَقَالَ ‏ "‏ مَنْ قَاتَلَ لِتَكُونَ كَلِمَةُ اللَّهِ هِيَ الْعُلْيَا فَهُوَ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏\hadithno{4922}\hadithtrans{It has been narrated through a different chain of transmitters on the same authority, i. e. Abu Musa Ash'ari, that a man asked the Messenger of Allah (ﷺ) about fighting in the way of Allah, the Exalted and Majestic, a man who fights out of rage or out of family pride. He raised his head towards him-and he did so because the man was standing and said:Who fights that the word of Allah be exalted fights in the way of Allah}}
\hadithdefcmd{muslim}{4923}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا ابْنُ جُرَيْجٍ، حَدَّثَنِي يُونُسُ بْنُ يُوسُفَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، قَالَ تَفَرَّقَ النَّاسُ عَنْ أَبِي هُرَيْرَةَ، فَقَالَ لَهُ نَاتِلُ أَهْلِ الشَّامِ أَيُّهَا الشَّيْخُ حَدِّثْنَا حَدِيثًا سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ أَوَّلَ النَّاسِ يُقْضَى يَوْمَ الْقِيَامَةِ عَلَيْهِ رَجُلٌ اسْتُشْهِدَ فَأُتِيَ بِهِ فَعَرَّفَهُ نِعَمَهُ فَعَرَفَهَا قَالَ فَمَا عَمِلْتَ فِيهَا قَالَ قَاتَلْتُ فِيكَ حَتَّى اسْتُشْهِدْتُ ‏.‏ قَالَ كَذَبْتَ وَلَكِنَّكَ قَاتَلْتَ لأَنْ يُقَالَ جَرِيءٌ ‏.‏ فَقَدْ قِيلَ ‏.‏ ثُمَّ أُمِرَ بِهِ فَسُحِبَ عَلَى وَجْهِهِ حَتَّى أُلْقِيَ فِي النَّارِ وَرَجُلٌ تَعَلَّمَ الْعِلْمَ وَعَلَّمَهُ وَقَرَأَ الْقُرْآنَ فَأُتِيَ بِهِ فَعَرَّفَهُ نِعَمَهُ فَعَرَفَهَا قَالَ فَمَا عَمِلْتَ فِيهَا قَالَ تَعَلَّمْتُ الْعِلْمَ وَعَلَّمْتُهُ وَقَرَأْتُ فِيكَ الْقُرْآنَ ‏.‏ قَالَ كَذَبْتَ وَلَكِنَّكَ تَعَلَّمْتَ الْعِلْمَ لِيُقَالَ عَالِمٌ ‏.‏ وَقَرَأْتَ الْقُرْآنَ لِيُقَالَ هُوَ قَارِئٌ ‏.‏ فَقَدْ قِيلَ ثُمَّ أُمِرَ بِهِ فَسُحِبَ عَلَى وَجْهِهِ حَتَّى أُلْقِيَ فِي النَّارِ ‏.‏ وَرَجُلٌ وَسَّعَ اللَّهُ عَلَيْهِ وَأَعْطَاهُ مِنْ أَصْنَافِ الْمَالِ كُلِّهِ فَأُتِيَ بِهِ فَعَرَّفَهُ نِعَمَهُ فَعَرَفَهَا قَالَ فَمَا عَمِلْتَ فِيهَا قَالَ مَا تَرَكْتُ مِنْ سَبِيلٍ تُحِبُّ أَنْ يُنْفَقَ فِيهَا إِلاَّ أَنْفَقْتُ فِيهَا لَكَ قَالَ كَذَبْتَ وَلَكِنَّكَ فَعَلْتَ لِيُقَالَ هُوَ جَوَادٌ ‏.‏ فَقَدْ قِيلَ ثُمَّ أُمِرَ بِهِ فَسُحِبَ عَلَى وَجْهِهِ ثُمَّ أُلْقِيَ فِي النَّارِ ‏"‏ ‏.‏\hadithno{4923}\hadithtrans{It has been narrated on the authority of Sulaiman b. Yasar who said:People dispersed from around Abu Huraira, and Natil, who was from the Syrians. said to him: O Shaikh, relate (to us) a tradition you have heard from the Messenger of Allah (ﷺ). He said: Yes. I heard the Messenger of Allah (ﷺ) say: The first of men (whose case) will be decided on the Day of Judgment will be a man who died as a martyr. He shall be brought (before the Judgment Seat). Allah will make him recount His blessings (i. e. the blessings which He had bestowed upon him) and he will recount them (and admit having enjoyed them in his life). (Then) will Allah say: What did you do (to requite these blessings)? He will say: I fought for Thee until I died as a martyr. Allah will say: You have told a lie. You fought that you might be called a" brave warrior". And you were called so. (Then) orders will be passed against him and he will be dragged with his face downward and cast into Hell. Then will be brought forward a man who acquired knowledge and imparted it (to others) and recited the Qur'an. He will be brought And Allah will make him recount His blessings and he will recount them (and admit having enjoyed them in his lifetime). Then will Allah ask: What did you do (to requite these blessings)? He will say: I acquired knowledge and disseminated it and recited the Qur'an seeking Thy pleasure. Allah will say: You have told a lie. You acquired knowledge so that you might be called" a scholar," and you recited the Qur'an so that it might be said:" He is a Qari" and such has been said. Then orders will be passed against him and he shall be dragged with his face downward and cast into the Fire. Then will be brought a man whom Allah had made abundantly rich and had granted every kind of wealth. He will be brought and Allah will make him recount His blessings and he will recount them and (admit having enjoyed them in his lifetime). Allah will (then) ask: What have you done (to requite these blessings)? He will say: I spent money in every cause in which Thou wished that it should be spent. Allah will say: You are lying. You did (so) that it might be said about (You):" He is a generous fellow" and so it was said. Then will Allah pass orders and he will be dragged with his face downward and thrown into Hell}}
\hadithdefcmd{muslim}{4924}{وَحَدَّثَنَاهُ عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا الْحَجَّاجُ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنِ ابْنِ جُرَيْجٍ، حَدَّثَنِي يُونُسُ بْنُ يُوسُفَ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، قَالَ تَفَرَّجَ النَّاسُ عَنْ أَبِي هُرَيْرَةَ، فَقَالَ لَهُ نَاتِلُ الشَّامِ وَاقْتَصَّ الْحَدِيثَ بِمِثْلِ حَدِيثِ خَالِدِ بْنِ الْحَارِثِ ‏.‏\hadithno{4924}\hadithtrans{This tradition has been handed down through a different chain of transmitters}}
\hadithdefcmd{muslim}{4925}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ أَبُو عَبْدِ الرَّحْمَنِ، حَدَّثَنَا حَيْوَةُ بْنُ، شُرَيْحٍ عَنْ أَبِي هَانِئٍ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ غَازِيَةٍ تَغْزُو فِي سَبِيلِ اللَّهِ فَيُصِيبُونَ الْغَنِيمَةَ إِلاَّ تَعَجَّلُوا ثُلُثَىْ أَجْرِهِمْ مِنَ الآخِرَةِ وَيَبْقَى لَهُمُ الثُّلُثُ وَإِنْ لَمْ يُصِيبُوا غَنِيمَةً تَمَّ لَهُمْ أَجْرُهُمْ ‏"‏ ‏.‏\hadithno{4925}\hadithtrans{It has been narrated on the authority of 'Abdullah b. 'Amr that the Messenger of Allah (ﷺ) said:A troop of soldiers who fight in tile way of Allah and get their share of the booty receive in advance two-thirds of their reward in the Hereafter and only one-third will remain (to their credit). If they do not receive any booty, they will get their full reward}}
\hadithdefcmd{muslim}{4926}{حَدَّثَنِي مُحَمَّدُ بْنُ سَهْلٍ التَّمِيمِيُّ، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا نَافِعُ بْنُ يَزِيدَ، حَدَّثَنِي أَبُو هَانِئٍ، حَدَّثَنِي أَبُو عَبْدِ الرَّحْمَنِ الْحُبُلِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ غَازِيَةٍ أَوْ سَرِيَّةٍ تَغْزُو فَتَغْنَمُ وَتَسْلَمُ إِلاَّ كَانُوا قَدْ تَعَجَّلُوا ثُلُثَىْ أُجُورِهِمْ وَمَا مِنْ غَازِيَةٍ أَوْ سَرِيَّةٍ تُخْفِقُ وَتُصَابُ إِلاَّ تَمَّ أُجُورُهُمْ ‏"‏ ‏.‏\hadithno{4926}\hadithtrans{It has been narrated on the authority of Abdullah b. Amr (through a different chain of transmitters) that the Messenger of Allah (ﷺ) said:A troop of soldiers, large or small, who fight (in the way of Allah), get their share of the booty and return safe and sound, receive in advance two-thirds of their reward (only one-third remaining to their credit to be received in the Hereafter) ; and a troop of soldiers, large or small, who return empty-handed and are afflicted or wounded, will receive their full reward (in the Hereafter)}}
\hadithdefcmd{muslim}{4927}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا مَالِكٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ، بْنِ إِبْرَاهِيمَ عَنْ عَلْقَمَةَ بْنِ وَقَّاصٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الأَعْمَالُ بِالنِّيَّةِ وَإِنَّمَا لاِمْرِئٍ مَا نَوَى فَمَنْ كَانَتْ هِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ فَهِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ وَمَنْ كَانَتْ هِجْرَتُهُ لِدُنْيَا يُصِيبُهَا أَوِ امْرَأَةٍ يَتَزَوَّجُهَا فَهِجْرَتُهُ إِلَى مَا هَاجَرَ إِلَيْهِ ‏"‏ ‏.‏\hadithno{4927}\hadithtrans{It has been narrated on the authority of Umar b. al-Khattab that the Messenger of Allah (ﷺ) said:(The value of) an action depends on the intention behind it. A man will be rewarded only for what he intended. The emigration of one who emigrates for the sake of Allah and His Messenger (ﷺ) is for the sake of Allah and His Messenger (ﷺ) ; and the emigration of one who emigrates for gaining a worldly advantage or for marrying a woman is for what he has emigrated}}
\hadithdefcmd{muslim}{4928}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا أَبُو الرَّبِيعِ الْعَتَكِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ يَعْنِي الثَّقَفِيَّ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَبُو خَالِدٍ الأَحْمَرُ، سُلَيْمَانُ بْنُ حَيَّانَ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ، اللَّهِ بْنِ نُمَيْرٍ حَدَّثَنَا حَفْصٌ، - يَعْنِي ابْنَ غِيَاثٍ - وَيَزِيدُ بْنُ هَارُونَ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ، الْعَلاَءِ الْهَمْدَانِيُّ حَدَّثَنَا ابْنُ الْمُبَارَكِ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، كُلُّهُمْ عَنْ يَحْيَى، بْنِ سَعِيدٍ بِإِسْنَادِ مَالِكٍ وَمَعْنَى حَدِيثِهِ وَفِي حَدِيثِ سُفْيَانَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ عَلَى الْمِنْبَرِ يُخْبِرُ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{4928}\hadithtrans{It has been narrated through a different chain of transmitters on the authority of Sufyan who said that he heard 'Umar b. al-Khattab relate (this tradition) from the Prophet (ﷺ) while he was delivering a sermon from the pulpit}}
\hadithdefcmd{muslim}{4929}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ طَلَبَ الشَّهَادَةَ صَادِقًا أُعْطِيَهَا وَلَوْ لَمْ تُصِبْهُ ‏"‏ ‏.‏\hadithno{4929}\hadithtrans{It has been narrated on the authority of Anas b. Malik that the Messenger of Allah (may peace he upon him) said:Who seeks martyrdom with sincerity shall get its reward, though he may not achieve it}}
\hadithdefcmd{muslim}{4930}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، - وَاللَّفْظُ لِحَرْمَلَةَ - قَالَ أَبُو الطَّاهِرِ أَخْبَرَنَا وَقَالَ، حَرْمَلَةُ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي أَبُو شُرَيْحٍ، أَنَّ سَهْلَ بْنَ أَبِي أُمَامَةَ بْنِ سَهْلِ، بْنِ حُنَيْفٍ حَدَّثَهُ عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ سَأَلَ اللَّهَ الشَّهَادَةَ بِصِدْقٍ بَلَّغَهُ اللَّهُ مَنَازِلَ الشُّهَدَاءِ وَإِنْ مَاتَ عَلَى فِرَاشِهِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ أَبُو الطَّاهِرِ فِي حَدِيثِهِ ‏"‏ بِصِدْقٍ ‏"‏ ‏.‏\hadithno{4930}\hadithtrans{It has been reported on the authority of Sahl b. Aba Umama b. Sahl b. Hunaif who learned the tradition from his father who (in turn) learned it from his grandfather-that the Messenger of Allah (ﷺ) said:Who sought martyrdom with sincerity will be ranked by Allah among the martyrs even if he died on his bed. In his version of the tradition Abd Tahir did not mention the words:" with sincerity}}
\hadithdefcmd{muslim}{4931}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ سَهْمٍ الأَنْطَاكِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ وُهَيْبٍ الْمَكِّيِّ، عَنْ عُمَرَ بْنِ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ مَاتَ وَلَمْ يَغْزُ وَلَمْ يُحَدِّثْ بِهِ نَفْسَهُ مَاتَ عَلَى شُعْبَةٍ مِنْ نِفَاقٍ ‏"‏ ‏.‏ قَالَ ابْنُ سَهْمٍ قَالَ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ فَنُرَى أَنَّ ذَلِكَ كَانَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4931}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:One who died but did not fight in the way of Allah nor did he express any desire (or determination) for Jihad died the death of a hypocrite. 'Abdullah b. Mubarak said: We think the hadith pertained to the time of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{4932}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي غَزَاةٍ فَقَالَ ‏ "‏ إِنَّ بِالْمَدِينَةِ لَرِجَالاً مَا سِرْتُمْ مَسِيرًا وَلاَ قَطَعْتُمْ وَادِيًا إِلاَّ كَانُوا مَعَكُمْ حَبَسَهُمُ الْمَرَضُ ‏"‏ ‏.‏\hadithno{4932}\hadithtrans{It has been narrated on the authority of Jabir who said:We were with the Prophet (ﷺ) on an expedition. He said: There are some people in Medina. They are with you whenever you cover a distance or cross a valley. They have been detained by illness}}
\hadithdefcmd{muslim}{4933}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ، يُونُسَ كُلُّهُمْ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّ فِي، حَدِيثِ وَكِيعٍ ‏ "‏ إِلاَّ شَرِكُوكُمْ فِي الأَجْرِ ‏"‏ ‏.‏\hadithno{4933}\hadithtrans{In a version of the tradition narrated on the authority of A'mash, we have the words:" They will share with you the reward (for Jihad)}}
\hadithdefcmd{muslim}{4934}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي، طَلْحَةَ عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَدْخُلُ عَلَى أُمِّ حَرَامٍ بِنْتِ مِلْحَانَ فَتُطْعِمُهُ وَكَانَتْ أُمُّ حَرَامٍ تَحْتَ عُبَادَةَ بْنِ الصَّامِتِ فَدَخَلَ عَلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا فَأَطْعَمَتْهُ ثُمَّ جَلَسَتْ تَفْلِي رَأْسَهُ فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ اسْتَيْقَظَ وَهُوَ يَضْحَكُ قَالَتْ فَقُلْتُ مَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ غُزَاةً فِي سَبِيلِ اللَّهِ يَرْكَبُونَ ثَبَجَ هَذَا الْبَحْرِ مُلُوكًا عَلَى الأَسِرَّةِ أَوْ مِثْلَ الْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏ ‏.‏ يَشُكُّ أَيَّهُمَا قَالَ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ فَدَعَا لَهَا ثُمَّ وَضَعَ رَأْسَهُ فَنَامَ ثُمَّ اسْتَيْقَظَ وَهُوَ يَضْحَكُ قَالَتْ فَقُلْتُ مَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ غُزَاةً فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ كَمَا قَالَ فِي الأُولَى قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهَ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ قَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏ ‏.‏ فَرَكِبَتْ أُمُّ حَرَامٍ بِنْتُ مِلْحَانَ الْبَحْرَ فِي زَمَنِ مُعَاوِيَةَ فَصُرِعَتْ عَنْ دَابَّتِهَا حِينَ خَرَجَتْ مِنَ الْبَحْرِ فَهَلَكَتْ ‏.‏\hadithno{4934}\hadithtrans{It has been reported on the authority of Anas b. Malik that the Messenger of Allah (ﷺ) used to visit Umm Haram daughter of Milhan (who was the sister of his foster-mother or his father's aunt). She was the wife of 'Ubada b. Samit, One day the Messenger of Allah (ﷺ) paid her a visit. She entertained him with food and then sat down to rub his head. The Messenger of Allah (ﷺ) dozed off and when he woke up (after a while), he was laughing. She asked:What made you laugh. Messenger of Allah? He said: Some people from my Umma were presented to me who were fighters in the way of Allah and were sailing in this sea. (Gliding smoothly on the water), they appeared to be kings or like kings (sitting) on thrones (the narrator has a doubt about the actual expression used by the Holy Prophet). She said: Messenger of Allah, pray to Allah that He may include me among these warriors. He prayed for her. Then he placed his head (down) and dozed off (again). He woke up laughing, as before. (She said) I said: Messenger of Allah, what makes you laugh? He replied: A people from my Umma were presented to me. They were fighters in Allah's way. (He described them in the same words as he had described the first warriors.) She said: Messenger of Allah, pray to God that He may include me among these warriors. He said: You are among the first ones. Umm Haram daughter of Milhan sailed in the aea in the time of Mu'awiya. When she came out of the sea and (was going to mount a riding animal) she fell down and died}}
\hadithdefcmd{muslim}{4935}{حَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ، يَحْيَى بْنِ حَبَّانَ عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أُمِّ حَرَامٍ، وَهْىَ خَالَةُ أَنَسٍ قَالَتْ أَتَانَا النَّبِيُّ صلى الله عليه وسلم يَوْمًا فَقَالَ عِنْدَنَا فَاسْتَيْقَظَ وَهُوَ يَضْحَكُ فَقُلْتُ مَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ بِأَبِي أَنْتَ وَأُمِّي قَالَ ‏"‏ أُرِيتُ قَوْمًا مِنْ أُمَّتِي يَرْكَبُونَ ظَهْرَ الْبَحْرِ كَالْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏ ‏.‏ فَقُلْتُ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ قَالَ ‏"‏ فَإِنَّكِ مِنْهُمْ ‏"‏ ‏.‏ قَالَتْ ثُمَّ نَامَ فَاسْتَيْقَظَ أَيْضًا وَهُوَ يَضْحَكُ فَسَأَلْتُهُ فَقَالَ مِثْلَ مَقَالَتِهِ فَقُلْتُ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ ‏.‏ قَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏ ‏.‏ قَالَ فَتَزَوَّجَهَا عُبَادَةُ بْنُ الصَّامِتِ بَعْدُ فَغَزَا فِي الْبَحْرِ فَحَمَلَهَا مَعَهُ فَلَمَّا أَنْ جَاءَتْ قُرِّبَتْ لَهَا بَغْلَةٌ فَرَكِبَتْهَا فَصَرَعَتْهَا فَانْدَقَّتْ عُنُقُهَا ‏.‏\hadithno{4935}\hadithtrans{It has been narrated on the authority of Umm Haram (and she was the aunt of Anas) who said:The Prophet (ﷺ) came to us one day and had a nap in our house. When he woke up, he was laughing. I said: Messenger of Allah, what made you laugh? He said: I saw a people from my followers sailing on the surface of the sea (looking) like kings (sitting) on their thrones. I said: Pray to Allah that He may include me among them. He said: You will be among them. He had a (second) nap, woke up and was laughing. I asked him (the reason for his laughter). He gave the same reply. I said: Pray to Allah that He may include me among them. He said: You are among the first ones. Anas said: 'Ubada b. Samit married her. He joined a naval expedition and took her along with him. When she returned, a mule was brought for her. While mounting it she fell down, broke her neck (and died)}}
\hadithdefcmd{muslim}{4936}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، وَيَحْيَى بْنُ يَحْيَى، قَالاَ أَخْبَرَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ ابْنِ حَبَّانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ خَالَتِهِ أُمِّ حَرَامٍ بِنْتِ مِلْحَانَ، أَنَّهَا قَالَتْ نَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا قَرِيبًا مِنِّي ثُمَّ اسْتَيْقَظَ يَتَبَسَّمُ - قَالَتْ - فَقُلْتُ يَا رَسُولَ اللَّهِ مَا أَضْحَكَكَ قَالَ ‏ "‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ يَرْكَبُونَ ظَهْرَ هَذَا الْبَحْرِ الأَخْضَرِ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ نَحْوَ حَدِيثِ حَمَّادِ بْنِ زَيْدٍ ‏.‏\hadithno{4936}\hadithtrans{It has been reported on the authority of Umm Haram daughter of Milhan (through another chain of transmitters). She said:One day the Messenger of Allah (ﷺ) slept (at a place) near me. He woke up smiling. She said: Messenger of Allah. what made thee laugh? He said: A people from my followers were presented to me. They were sailing on the surface of this green sea... (here follows the tradition that has gone before)}}
\hadithdefcmd{muslim}{4937}{وَحَدَّثَنِي يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ أَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم ابْنَةَ مِلْحَانَ خَالَةَ أَنَسٍ فَوَضَعَ رَأْسَهُ عِنْدَهَا ‏.‏ وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ إِسْحَاقَ بْنِ أَبِي طَلْحَةَ وَمُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ ‏.‏\hadithno{4937}\hadithtrans{It has been reported by 'Abdullah b. 'Abd al-Rahman that he heard Anas b. Malik say:The Messenger of Allah (ﷺ) paid a visit to Milhan's daughter, maternal aunt of Anas (and the sister of the Holy Prophet's foster-mother). He placed his head near her (from this point onward, the narrator carried on the previous tradition to its end)}}
\hadithdefcmd{muslim}{4938}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ بَهْرَامَ الدَّارِمِيُّ، حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا لَيْثٌ، - يَعْنِي ابْنَ سَعْدٍ - عَنْ أَيُّوبَ بْنِ مُوسَى، عَنْ مَكْحُولٍ، عَنْ شُرَحْبِيلَ بْنِ السَّمِطِ، عَنْ سَلْمَانَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ رِبَاطُ يَوْمٍ وَلَيْلَةٍ خَيْرٌ مِنْ صِيَامِ شَهْرٍ وَقِيَامِهِ وَإِنْ مَاتَ جَرَى عَلَيْهِ عَمَلُهُ الَّذِي كَانَ يَعْمَلُهُ وَأُجْرِيَ عَلَيْهِ رِزْقُهُ وَأَمِنَ الْفَتَّانَ ‏"‏ ‏.‏\hadithno{4938}\hadithtrans{It has been narrated on the authority of Salman who said:I heard the Messenger of Allah (ﷺ) say: Keeping watch for a day and a night is better (in point of reward) than fasting for a whole month and standing in prayer every night. If a person dies (while, performing this duty), his (meritorious) activity will continue and he will go on receiving his reward for it perpetually and will be saved from the torture of the grave}}
\hadithdefcmd{muslim}{4939}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ شُرَيْحٍ، عَنْ عَبْدِ الْكَرِيمِ، بْنِ الْحَارِثِ عَنْ أَبِي عُبَيْدَةَ بْنِ عُقْبَةَ، عَنْ شُرَحْبِيلَ بْنِ السَّمِطِ، عَنْ سَلْمَانَ الْخَيْرِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ اللَّيْثِ عَنْ أَيُّوبَ بْنِ مُوسَى ‏.‏\hadithno{4939}\hadithtrans{This tradition has been handed down on the authority of Salman al-Khair through another chain of transmitters}}
\hadithdefcmd{muslim}{4940}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَمَا رَجُلٌ يَمْشِي بِطَرِيقٍ وَجَدَ غُصْنَ شَوْكٍ عَلَى الطَّرِيقِ فَأَخَّرَهُ فَشَكَرَ اللَّهُ لَهُ فَغَفَرَ لَهُ ‏"‏ ‏.‏ وَقَالَ ‏"‏ الشُّهَدَاءُ خَمْسَةٌ الْمَطْعُونُ وَالْمَبْطُونُ وَالْغَرِقُ وَصَاحِبُ الْهَدْمِ وَالشَّهِيدُ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4940}\hadithtrans{It has been narrated on the authority of Abu Huraira that the, Messenger of Allah (ﷺ) said:While a man walks along a path, finds a thorny twig lying on the way and puts it aside, Allah would appreciate it and forgive him The Prophet (ﷺ) said: The martyrs are of five kinds: one who dies of plague; one who dies of diarrhoea (or cholera) ; one who is drowned; one who is buried under debris and one who dies fighting in the way of Allah}}
\hadithdefcmd{muslim}{4941}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا تَعُدُّونَ الشَّهِيدَ فِيكُمْ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ مَنْ قُتِلَ فِي سَبِيلِ اللَّهِ فَهُوَ شَهِيدٌ قَالَ ‏"‏ إِنَّ شُهَدَاءَ أُمَّتِي إِذًا لَقَلِيلٌ ‏"‏ ‏.‏ قَالُوا فَمَنْ هُمْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ مَنْ قُتِلَ فِي سَبِيلِ اللَّهِ فَهُوَ شَهِيدٌ وَمَنْ مَاتَ فِي سَبِيلِ اللَّهِ فَهُوَ شَهِيدٌ وَمَنْ مَاتَ فِي الطَّاعُونِ فَهُوَ شَهِيدٌ وَمَنْ مَاتَ فِي الْبَطْنِ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏ قَالَ ابْنُ مِقْسَمٍ أَشْهَدُ عَلَى أَبِيكَ فِي هَذَا الْحَدِيثِ أَنَّهُ قَالَ ‏"‏ وَالْغَرِيقُ شَهِيدٌ ‏"‏ ‏.‏\hadithno{4941}\hadithtrans{It has been narrated on the authority of Abu Huraira (through another chain of transmitters) that the Messenger of Allah (ﷺ) said:Whom do you consider to be a martyr among you? They (the Companions) said: Messenger, of Allah, one who is slain in the way of Allah is a martyr. He said: Then (if this is the definition of a martyr) the martyrs of my Umma will be small in number. They asked: Messenger of Allah, who are they? He said: One who is slain in the way of Allah is a martyr; one who dies in the way of Allah, is a martyr; one who dies of plague is a martyr; one who dies of cholera is a martyr. Ibn Miqsam said: I testify the truth of your father's statement (with regard to this tradition) that the Prophet (ﷺ) said: One who is drowned is a martyr}}
\hadithdefcmd{muslim}{4942}{حَدَّثَنِي عَبْدُ الْحَمِيدِ بْنُ بَيَانٍ الْوَاسِطِيُّ، حَدَّثَنَا خَالِدٌ، عَنْ سُهَيْلٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّ فِي حَدِيثِهِ قَالَ سُهَيْلٌ قَالَ عُبَيْدُ اللَّهِ بْنُ مِقْسَمٍ أَشْهَدُ عَلَى أَبِيكَ أَنَّهُ زَادَ فِي هَذَا الْحَدِيثِ ‏ "‏ وَمَنْ غَرِقَ فَهُوَ شَهِيدٌ ‏"‏ ‏.‏\hadithno{4942}\hadithtrans{A version of the tradition narrated on the authority of Suhail contains the additional words:" And one who is drowned is a martyr}}
\hadithdefcmd{muslim}{4943}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا سُهَيْلٌ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِهِ قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ مِقْسَمٍ، عَنْ أَبِي صَالِحٍ، وَزَادَ، فِيهِ ‏ "‏ وَالْغَرِقُ شَهِيدٌ ‏"‏ ‏.‏\hadithno{4943}\hadithtrans{Another version of the tradition narrated on the authority of Suhail thouch a different chain of transmitters contains the additional words:" A drowned person is a martyr}}
\hadithdefcmd{muslim}{4944}{حَدَّثَنَا حَامِدُ بْنُ عُمَرَ الْبَكْرَاوِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، - يَعْنِي ابْنَ زِيَادٍ - حَدَّثَنَا عَاصِمٌ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، قَالَتْ قَالَ لِي أَنَسُ بْنُ مَالِكٍ بِمَا مَاتَ يَحْيَى بْنُ أَبِي عَمْرَةَ قَالَتْ قُلْتُ بِالطَّاعُونِ ‏.‏ قَالَتْ فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الطَّاعُونُ شَهَادَةٌ لِكُلِّ مُسْلِمٍ ‏"‏ ‏.‏\hadithno{4944}\hadithtrans{It has been narrated on the authority of Hafsa daughter of Sirin who said:Anas b. Malik asked me the cause of death of Yahya b. 'Abu 'Amra. I said: (He died) of plague. He said: The Messenger of Allah (ﷺ) said that death by plague is martyrdom for a Muslim}}
\hadithdefcmd{muslim}{4945}{وَحَدَّثَنَاهُ الْوَلِيدُ بْنُ شُجَاعٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عَاصِمٍ، فِي هَذَا الإِسْنَادِ بِمِثْلِهِ ‏.‏\hadithno{4945}\hadithtrans{This hadith has been narrated on the authority of 'Asim through the same chain of transmitters}}
\hadithdefcmd{muslim}{4946}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ أَبِي عَلِيٍّ، ثُمَامَةَ بْنِ شُفَىٍّ أَنَّهُ سَمِعَ عُقْبَةَ بْنَ عَامِرٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى الْمِنْبَرِ يَقُولُ ‏ "‏ وَأَعِدُّوا لَهُمْ مَا اسْتَطَعْتُمْ مِنْ قُوَّةٍ أَلاَ إِنَّ الْقُوَّةَ الرَّمْىُ أَلاَ إِنَّ الْقُوَّةَ الرَّمْىُ أَلاَ إِنَّ الْقُوَّةَ الرَّمْىُ ‏"‏\hadithno{4946}\hadithtrans{It has been narrated on the authority of Ibn Amir who said:I heard the Messenger of Allah (ﷺ) say-and he was delivering a sermon from the pulpit: Prepare to meet them with as much strength as you can afford. Beware, strength consists in archery. Beware, strength consists in archery. Beware, strength consists in archery}}
\hadithdefcmd{muslim}{4947}{وَحَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ أَبِي عَلِيٍّ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ سَتُفْتَحُ عَلَيْكُمْ أَرَضُونَ وَيَكْفِيكُمُ اللَّهُ فَلاَ يَعْجِزُ أَحَدُكُمْ أَنْ يَلْهُوَ بِأَسْهُمِهِ ‏"‏ ‏.‏\hadithno{4947}\hadithtrans{It has been narrated on the authority of Uqba b. Amir who said:I heard the Messenger of Allah (ﷺ) say: Lands shall be thrown open to you and Allah will suffice you (against your enemies), but none of you should give up playing with his arrows}}
\hadithdefcmd{muslim}{4948}{وَحَدَّثَنَاهُ دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا الْوَلِيدُ، عَنْ بَكْرِ بْنِ مُضَرَ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ أَبِي عَلِيٍّ الْهَمْدَانِيِّ، قَالَ سَمِعْتُ عُقْبَةَ بْنَ عَامِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{4948}\hadithtrans{This tradition has also been narrated on the same authority through another chain of transmitters}}
\hadithdefcmd{muslim}{4949}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَخْبَرَنَا اللَّيْثُ، عَنِ الْحَارِثِ بْنِ يَعْقُوبَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ شَمَاسَةَ، أَنَّ فُقَيْمًا اللَّخْمِيَّ، قَالَ لِعُقْبَةَ بْنِ عَامِرٍ تَخْتَلِفُ بَيْنَ هَذَيْنِ الْغَرَضَيْنِ وَأَنْتَ كَبِيرٌ يَشُقُّ عَلَيْكَ ‏.‏ قَالَ عُقْبَةُ لَوْلاَ كَلاَمٌ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم لَمْ أُعَانِهِ ‏.‏ قَالَ الْحَارِثُ فَقُلْتُ لاِبْنِ شُمَاسَةَ وَمَا ذَاكَ قَالَ إِنَّهُ قَالَ ‏ "‏ مَنْ عَلِمَ الرَّمْىَ ثُمَّ تَرَكَهُ فَلَيْسَ مِنَّا أَوْ قَدْ عَصَى ‏"‏ ‏.‏\hadithno{4949}\hadithtrans{It has been reported by 'Abd al-Rahman b. Shamasa that Fuqaim al- Lakhmi said to Uqba b. Amir:You frequent between these two targets and you are an old man, so you will be finding it very hard. 'Uqba said: But for a thing I heard from the Prophet (ﷺ), I would not strain myself. Harith (one of the narrators in the chain of transmitters) said: I asked Ibn Shamasa: What was that? He said that he (the Holy Prophet) said: Who learnt archery and then gave it up is not from us. or he has been guilty of disobedience (to Allah's Apostle)}}
\hadithdefcmd{muslim}{4950}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَأَبُو الرَّبِيعِ الْعَتَكِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالُوا حَدَّثَنَا حَمَّادٌ، - وَهُوَ ابْنُ زَيْدٍ - عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَزَالُ طَائِفَةٌ مِنْ أُمَّتِي ظَاهِرِينَ عَلَى الْحَقِّ لاَ يَضُرُّهُمْ مَنْ خَذَلَهُمْ حَتَّى يَأْتِيَ أَمْرُ اللَّهِ وَهُمْ كَذَلِكَ ‏"‏ ‏.‏ وَلَيْسَ فِي حَدِيثِ قُتَيْبَةَ ‏"‏ وَهُمْ كَذَلِكَ ‏"‏ ‏.‏\hadithno{4950}\hadithtrans{It has been narrated on the authority of Thauban that the Messenger of Allah (ﷺ) said:A group of people from my Umma will always remain triumphant on the right path and continue to be triumphant (against their opponents). He who deserts them shall not be able to do them any harm. They will remain in this position until Allah's Command is executed (i.e. Qiyamah is established). In Qutaiba's version of the tradition, we do not have the words:" They will remain in this position}}
\hadithdefcmd{muslim}{4951}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا وَكِيعٌ، وَعَبْدَةُ كِلاَهُمَا عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا مَرْوَانُ، - يَعْنِي الْفَزَارِيَّ - عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنِ الْمُغِيرَةِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَنْ يَزَالَ قَوْمٌ مِنْ أُمَّتِي ظَاهِرِينَ عَلَى النَّاسِ حَتَّى يَأْتِيَهُمْ أَمْرُ اللَّهِ وَهُمْ ظَاهِرُونَ ‏"‏ ‏.‏\hadithno{4951}\hadithtrans{It has been narrated on the authority of Mughira who said:I heard the Messenger of Allah (ﷺ) say: A group of people from my Umma will continue to be triumphant over the people until the Command of Allah overtakes them while they are still triumphant}}
\hadithdefcmd{muslim}{4952}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنِي إِسْمَاعِيلُ، عَنْ قَيْسٍ، قَالَ سَمِعْتُ الْمُغِيرَةَ بْنَ شُعْبَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ بِمِثْلِ حَدِيثِ مَرْوَانَ سَوَاءً ‏.‏\hadithno{4952}\hadithtrans{The same tradition has been narrated through another chain of transmitters on the same authority}}
\hadithdefcmd{muslim}{4953}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لَنْ يَبْرَحَ هَذَا الدِّينُ قَائِمًا يُقَاتِلُ عَلَيْهِ عِصَابَةٌ مِنَ الْمُسْلِمِينَ حَتَّى تَقُومَ السَّاعَةُ ‏"‏ ‏.‏\hadithno{4953}\hadithtrans{It has been narrated on the authority of Jabir b. Samura that the Prophet (ﷺ) said:This religion will continue to exist, and a group of people from the Muslims will continue to fight for its protection until the Hour is established}}
\hadithdefcmd{muslim}{4954}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، وَحَجَّاجُ بْنُ الشَّاعِرِ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَزَالُ طَائِفَةٌ مِنْ أُمَّتِي يُقَاتِلُونَ عَلَى الْحَقِّ ظَاهِرِينَ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4954}\hadithtrans{It has been narrated on the authority of Jabir b. 'Abdullah who said:I heard the Messenger of Allah (ﷺ) say: A group of people from my Umma will continue to fight In defence of truth and remain triumphant until the Day of judgment}}
\hadithdefcmd{muslim}{4955}{حَدَّثَنَا مَنْصُورُ بْنُ أَبِي مُزَاحِمٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، بْنِ جَابِرٍ أَنَّ عُمَيْرَ بْنَ هَانِئٍ، حَدَّثَهُ قَالَ سَمِعْتُ مُعَاوِيَةَ، عَلَى الْمِنْبَرِ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَزَالُ طَائِفَةٌ مِنْ أُمَّتِي قَائِمَةً بِأَمْرِ اللَّهِ لاَ يَضُرُّهُمْ مَنْ خَذَلَهُمْ أَوْ خَالَفَهُمْ حَتَّى يَأْتِيَ أَمْرُ اللَّهِ وَهُمْ ظَاهِرُونَ عَلَى النَّاسِ ‏"‏ ‏.‏\hadithno{4955}\hadithtrans{It his been narrated on the authority of Umair b. Umm Hani who said:I heard Mu'awiya say (while delivering a sermon from the pulpit) that he heard the Messenger of Allah (ﷺ) say: A group of people from my Umma will continue to obey Allah's Command, and those who desert or oppose them shall not be able to do them any harm. They will be dominating the peeple until Allah's Command is executed (i. e. Resurrection is established)}}
\hadithdefcmd{muslim}{4956}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا كَثِيرُ بْنُ هِشَامٍ، حَدَّثَنَا جَعْفَرٌ، - وَهُوَ ابْنُ بُرْقَانَ - حَدَّثَنَا يَزِيدُ بْنُ الأَصَمِّ، قَالَ سَمِعْتُ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ، ذَكَرَ حَدِيثًا رَوَاهُ عَنِ النَّبِيِّ صلى الله عليه وسلم لَمْ أَسْمَعْهُ رَوَى عَنِ النَّبِيِّ صلى الله عليه وسلم عَلَى مِنْبَرِهِ حَدِيثًا غَيْرَهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يُرِدِ اللَّهُ بِهِ خَيْرًا يُفَقِّهْهُ فِي الدِّينِ وَلاَ تَزَالُ عِصَابَةٌ مِنَ الْمُسْلِمِينَ يُقَاتِلُونَ عَلَى الْحَقِّ ظَاهِرِينَ عَلَى مَنْ نَاوَأَهُمْ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4956}\hadithtrans{It has been related by, Yazid b. al-Asamm that he heard Mu'awiya b. Abu Sfyan quote a tradition from the Prophet (ﷺ) which he related from the Prophet (mail peace he upon him) -and he did not hear him quote from the Prophet (masy peace be upon him) any tradition other than this in the course of his sermon from the pulpit-that whom Allah wants to do a favour, He grants him an understanding of religion. A group of people from the Muslims will remain on the Right Path and continue until the Day of Judgment to triumph over those who oppose them}}
\hadithdefcmd{muslim}{4957}{حَدَّثَنِي أَحْمَدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ وَهْبٍ، حَدَّثَنَا عَمِّي عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنَا عَمْرُو بْنُ الْحَارِثِ، حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ شُمَاسَةَ الْمَهْرِيُّ، قَالَ كُنْتُ عِنْدَ مَسْلَمَةَ بْنِ مُخَلَّدٍ وَعِنْدَهُ عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ الْعَاصِ فَقَالَ عَبْدُ اللَّهِ لاَ تَقُومُ السَّاعَةُ إِلاَّ عَلَى شِرَارِ الْخَلْقِ هُمْ شَرٌّ مِنْ أَهْلِ الْجَاهِلِيَّةِ لاَ يَدْعُونَ اللَّهَ بِشَىْءٍ إِلاَّ رَدَّهُ عَلَيْهِمْ ‏.‏ فَبَيْنَمَا هُمْ عَلَى ذَلِكَ أَقْبَلَ عُقْبَةُ بْنُ عَامِرٍ فَقَالَ لَهُ مَسْلَمَةُ يَا عُقْبَةُ اسْمَعْ مَا يَقُولُ عَبْدُ اللَّهِ ‏.‏ فَقَالَ عُقْبَةُ هُوَ أَعْلَمُ وَأَمَّا أَنَا فَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تَزَالُ عِصَابَةٌ مِنْ أُمَّتِي يُقَاتِلُونَ عَلَى أَمْرِ اللَّهِ قَاهِرِينَ لِعَدُوِّهِمْ لاَ يَضُرُّهُمْ مَنْ خَالَفَهُمْ حَتَّى تَأْتِيَهُمُ السَّاعَةُ وَهُمْ عَلَى ذَلِكَ ‏"‏ ‏.‏ فَقَالَ عَبْدُ اللَّهِ أَجَلْ ‏.‏ ثُمَّ يَبْعَثُ اللَّهُ رِيحًا كَرِيحِ الْمِسْكِ مَسُّهَا مَسُّ الْحَرِيرِ فَلاَ تَتْرُكُ نَفْسًا فِي قَلْبِهِ مِثْقَالُ حَبَّةٍ مِنَ الإِيمَانِ إِلاَّ قَبَضَتْهُ ثُمَّ يَبْقَى شِرَارُ النَّاسِ عَلَيْهِمْ تَقُومُ السَّاعَةُ ‏.‏\hadithno{4957}\hadithtrans{It has been narrated on the authority of 'Abd al-Rahman b. Shamasa al- Mahri who said:I was in the company of Maslama b. Mukhallad, and 'Abdullah b. 'Amr b. 'As was with him. 'Abdullah said: The Hour shall some oniy when the worst type of people are left on the earth. They will be worse than the people of pre-Islamic days. They will get whatever they ask of Allah. While we were yet sitting when 'Uqba b. 'Amir came, and Maslama said to him: 'Uqba, listen to what 'Abdullah says. 'Uqba said: He knows better; so far as I am concerned, I heard the Messenger of Allah (ﷺ) say: A group of people from my Umma will continue to fight in obedience to the Command of Allah, remaining dominant over their enemies. Those who will oppose them shall not do them any harm. They will remain ill this condition until the Hour overtakes them. (At this) 'Abdullah said: Yes. Then Allah will raise a wild which will be fragrant like musk and whose touch will be like the touch of silk; (but) it will cause the death of all (faithful) persons, not leaving behind a single person with an iota of faith in his heart. Then only the worst of men will remain to be overwhelmed by the Hour}}
\hadithdefcmd{muslim}{4958}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنْ أَبِي عُثْمَانَ، عَنْ سَعْدِ بْنِ أَبِي وَقَّاصٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَزَالُ أَهْلُ الْغَرْبِ ظَاهِرِينَ عَلَى الْحَقِّ حَتَّى تَقُومَ السَّاعَةُ ‏"‏ ‏.‏\hadithno{4958}\hadithtrans{It has been narrated by Sa'd b. Abu Waqqas that the Messenger of Allah (ﷺ) said:The people of the West will continue to triumphantly follow the truth until the Hour is established}}
\hadithdefcmd{muslim}{4959}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا سَافَرْتُمْ فِي الْخِصْبِ فَأَعْطُوا الإِبِلَ حَظَّهَا مِنَ الأَرْضِ وَإِذَا سَافَرْتُمْ فِي السَّنَةِ فَأَسْرِعُوا عَلَيْهَا السَّيْرَ وَإِذَا عَرَّسْتُمْ بِاللَّيْلِ فَاجْتَنِبُوا الطَّرِيقَ فَإِنَّهَا مَأْوَى الْهَوَامِّ بِاللَّيْلِ ‏"‏ ‏.‏\hadithno{4959}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:When you journey through a fertile land, you should (go slow and) give the camels a chance to graze in the land. When you travel In an arid (land) where there is scarcity of vegetation, you should quicken their pace (lest your camels grow feeble and emaciated for lack of fodder). When you halt for the night, avoid (pitching your tent on) the road, for it is the abode of noxious little animals at night}}
\hadithdefcmd{muslim}{4960}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا سَافَرْتُمْ فِي الْخِصْبِ فَأَعْطُوا الإِبِلَ حَظَّهَا مِنَ الأَرْضِ وَإِذَا سَافَرْتُمْ فِي السَّنَةِ فَبَادِرُوا بِهَا نِقَيَهَا وَإِذَا عَرَّسْتُمْ فَاجْتَنِبُوا الطَّرِيقَ فَإِنَّهَا طُرُقُ الدَّوَابِّ وَمَأْوَى الْهَوَامِّ بِاللَّيْلِ ‏"‏ ‏.‏\hadithno{4960}\hadithtrans{It has been narrated (through another chain of transmitters) on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:When you travel (through a land) where there is plenty of vegetation, you should (go slow and) give the camels a chance to enjoy the benefit of the earth. When you travel (through a land) where there is scarcity of vegetation, you should hasten with them (so that you may be able to cross that land while your animals ore still in a good condition of health). When you make a halt for the night, avoid (doing so on) the road, for the tracks are the pathways of wild beasts or the abode of noxious little animals}}
\hadithdefcmd{muslim}{4961}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، وَإِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، وَأَبُو مُصْعَبٍ الزُّهْرِيُّ وَمَنْصُورُ بْنُ أَبِي مُزَاحِمٍ وَقُتَيْبَةُ بْنُ سَعِيدٍ قَالُوا حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا يَحْيَى، بْنُ يَحْيَى التَّمِيمِيُّ - وَاللَّفْظُ لَهُ - قَالَ قُلْتُ لِمَالِكٍ حَدَّثَكَ سُمَىٌّ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ السَّفَرُ قِطْعَةٌ مِنَ الْعَذَابِ يَمْنَعُ أَحَدَكُمْ نَوْمَهُ وَطَعَامَهُ وَشَرَابَهُ فَإِذَا قَضَى أَحَدُكُمْ نَهْمَتَهُ مِنْ وَجْهِهِ فَلْيُعَجِّلْ إِلَى أَهْلِهِ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏\hadithno{4961}\hadithtrans{On the authority of Abu Huraira that the Prophet (ﷺ) said:Travelling is a tortuous experience. It deprives a person of his sleep. his food and drink. When one of you has accomplished his purpose, he should hasten his return to his family}}
\hadithdefcmd{muslim}{4962}{حَدَّثَنِي أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ هَمَّامٍ، عَنْ إِسْحَاقَ، بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ لاَ يَطْرُقُ أَهْلَهُ لَيْلاً وَكَانَ يَأْتِيهِمْ غُدْوَةً أَوْ عَشِيَّةً ‏\hadithno{4962}\hadithtrans{It has been narrated on the authority of Anas b. Malik that the Messenger of Allah (ﷺ) would not come (back) to his family by night. He would come to them in the morning or in the evening}}
\hadithdefcmd{muslim}{4963}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا إِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ كَانَ لاَ يَدْخُلُ ‏\hadithno{4963}\hadithtrans{Another version of the tradition narrated on the same authority worded slightly differently. It says:(He) would not enter (upon his household at night)}}
\hadithdefcmd{muslim}{4964}{حَدَّثَنِي إِسْمَاعِيلُ بْنُ سَالِمٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا سَيَّارٌ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - حَدَّثَنَا هُشَيْمٌ، عَنْ سَيَّارٍ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزَاةٍ فَلَمَّا قَدِمْنَا الْمَدِينَةَ ذَهَبْنَا لِنَدْخُلَ فَقَالَ ‏ "‏ أَمْهِلُوا حَتَّى نَدْخُلَ لَيْلاً - أَىْ عِشَاءً - كَىْ تَمْتَشِطَ الشَّعِثَةُ وَتَسْتَحِدَّ الْمُغِيبَةُ ‏"‏ ‏.‏\hadithno{4964}\hadithtrans{It has been narrated on the authority of Jabir b. 'Abdullah who said:We accompanied the Messenger of Allah (ﷺ) on an expedition. When we came (back) to Medina and were going to enter our houses, he said: Wait and enter (your houses) in the later part of the evening so that a woman with dishevelled hair may have used the comb, and a woman whose husband has been away from home may have removed the hair from her private parts}}
\hadithdefcmd{muslim}{4965}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي عَبْدُ الصَّمَدِ، حَدَّثَنَا شُعْبَةُ، عَنْ سَيَّارٍ، عَنْ عَامِرٍ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا قَدِمَ أَحَدُكُمْ لَيْلاً فَلاَ يَأْتِيَنَّ أَهْلَهُ طُرُوقًا حَتَّى تَسْتَحِدَّ الْمُغِيبَةُ وَتَمْتَشِطَ الشَّعِثَةُ ‏"‏ ‏.‏\hadithno{4965}\hadithtrans{It has been narrated on the authority of Jabir that the Messenger of Allah (ﷺ) said:If one of you comes (back from a journey) at night. he should not enter his house as a night visitor (but should wait) until a woman whose husband has been away from house has removed the hair from her private parts and a woman with dishevelled hair has combed her hair}}
\hadithdefcmd{muslim}{4966}{وَحَدَّثَنِيهِ يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا سَيَّارٌ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4966}\hadithtrans{This tradition has been handed down through another chain of transmitters}}
\hadithdefcmd{muslim}{4967}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - حَدَّثَنَا شُعْبَةُ، عَنْ عَاصِمٍ، عَنِ الشَّعْبِيِّ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَطَالَ الرَّجُلُ الْغَيْبَةَ أَنْ يَأْتِيَ أَهْلَهُ طُرُوقًا ‏.‏\hadithno{4967}\hadithtrans{It has been narrated (through a different chain of tranmitters) on the authority of Jabir who said:The Messenger of Allah (ﷺ) forbade that a man who had long absent should come to his family like (an unexpected) night visitor}}
