% Auto-generated chapter 36 for ibnmajah
% Hadiths in this chapter: 175

\hadithdefcmd{ibnmajah}{3927}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَحَفْصُ بْنُ غِيَاثٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَإِذَا قَالُوهَا عَصَمُوا مِنِّي دِمَاءَهُمْ وَأَمْوَالَهُمْ إِلاَّ بِحَقِّهَا وَحِسَابُهُمْ عَلَى اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{3927}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“I have been commanded to fight the people until they say: La ilaha illallah. If they say it, then their blood and wealth are protected from me, except for a right that is due from it, and their reckoning will be with Allah.”}}
\hadithdefcmd{ibnmajah}{3928}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَإِذَا قَالُوا لاَ إِلَهَ إِلاَّ اللَّهُ عَصَمُوا مِنِّي دِمَاءَهُمْ وَأَمْوَالَهُمْ إِلاَّ بِحَقِّهَا وَحِسَابُهُمْ عَلَى اللَّهِ ‏"‏ ‏.‏\hadithno{3928}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“I have been commanded to fight the people until they say: La ilaha illallah. If they say: La ilaha illallah, then their blood and wealth are protected from me, except for a right that is due from it, and their reckoning will be with Allah.”}}
\hadithdefcmd{ibnmajah}{3929}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَكْرٍ السَّهْمِيُّ، حَدَّثَنَا حَاتِمُ بْنُ أَبِي صَغِيرَةَ، عَنِ النُّعْمَانِ بْنِ سَالِمٍ، أَنَّ عَمْرَو بْنَ أَوْسٍ، أَخْبَرَهُ أَنَّ أَبَاهُ أَوْسًا أَخْبَرَهُ قَالَ إِنَّا لَقُعُودٌ عِنْدَ النَّبِيِّ ـ صلى الله عليه وسلم ـ وَهُوَ يَقُصُّ عَلَيْنَا وَيُذَكِّرُنَا إِذْ أَتَاهُ رَجُلٌ فَسَارَّهُ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ اذْهَبُوا بِهِ فَاقْتُلُوهُ ‏"‏ ‏.‏ فَلَمَّا وَلَّى الرَّجُلُ دَعَاهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ هَلْ تَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏ قَالَ نَعَمْ قَالَ ‏"‏ اذْهَبُوا فَخَلُّوا سَبِيلَهُ فَإِنَّمَا أُمِرْتُ أَنْ أُقَاتِلَ النَّاسَ حَتَّى يَقُولُوا لاَ إِلَهَ إِلاَّ اللَّهُ فَإِذَا فَعَلُوا ذَلِكَ حَرُمَ عَلَىَّ دِمَاؤُهُمْ وَأَمْوَالُهُمْ ‏"‏ ‏.‏\hadithno{3929}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Amr bin Aws narrated that his father, Aws, told him:“We were sitting with the Prophet (ﷺ) and he was narrating to us and reminding us, when a man came and spoke privately to him. He said: ‘Take him away and kill him.’ When the man turned away, the Messenger of Allah (ﷺ) called him back and said: ‘Do you bear witness that none has the right to be worshiped but Allah?’ He said, ‘Yes.’ He said: ‘Then go and let him go, for I have been commanded to fight the people until they say: La ilaha illallah, then if they do that, their blood and wealth are forbidden to me.’”}}
\hadithdefcmd{ibnmajah}{3930}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عَاصِمٍ، عَنِ السُّمَيْطِ بْنِ السُّمَيْرِ، عَنْ عِمْرَانَ بْنِ الْحُصَيْنِ، قَالَ أَتَى نَافِعُ بْنُ الأَزْرَقِ وَأَصْحَابُهُ فَقَالُوا هَلَكْتَ يَا عِمْرَانُ ‏.‏ قَالَ مَا هَلَكْتُ ‏.‏ قَالُوا بَلَى ‏.‏ قَالَ مَا الَّذِي أَهْلَكَنِي قَالُوا قَالَ اللَّهُ ‏\{وَقَاتِلُوهُمْ حَتَّى لاَ تَكُونَ فِتْنَةٌ وَيَكُونَ الدِّينُ كُلُّهُ لِلَّهِ\}‏ ‏.‏ قَالَ قَدْ قَاتَلْنَاهُمْ حَتَّى نَفَيْنَاهُمْ فَكَانَ الدِّينُ كُلُّهُ لِلَّهِ إِنْ شِئْتُمْ حَدَّثْتُكُمْ حَدِيثًا سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ قَالُوا وَأَنْتَ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ نَعَمْ شَهِدْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَقَدْ بَعَثَ جَيْشًا مِنَ الْمُسْلِمِينَ إِلَى الْمُشْرِكِينَ فَلَمَّا لَقُوهُمْ قَاتَلُوهُمْ قِتَالاً شَدِيدًا فَمَنَحُوهُمْ أَكْتَافَهُمْ فَحَمَلَ رَجُلٌ مِنْ لُحْمَتِي عَلَى رَجُلٍ مِنَ الْمُشْرِكِينَ بِالرُّمْحِ فَلَمَّا غَشِيَهُ قَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ إِنِّي مُسْلِمٌ فَطَعَنَهُ فَقَتَلَهُ فَأَتَى رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ هَلَكْتُ قَالَ ‏"‏ وَمَا الَّذِي صَنَعْتَ ‏"‏ ‏.‏ مَرَّةً أَوْ مَرَّتَيْنِ فَأَخْبَرَهُ بِالَّذِي صَنَعَ فَقَالَ لَهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ فَهَلاَّ شَقَقْتَ عَنْ بَطْنِهِ فَعَلِمْتَ مَا فِي قَلْبِهِ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ لَوْ شَقَقْتُ بَطْنَهُ أَكُنْتُ أَعْلَمُ مَا فِي قَلْبِهِ قَالَ ‏"‏ فَلاَ أَنْتَ قَبِلْتَ مَا تَكَلَّمَ بِهِ وَلاَ أَنْتَ تَعْلَمُ مَا فِي قَلْبِهِ ‏"‏ ‏.‏ قَالَ فَسَكَتَ عَنْهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَلَمْ يَلْبَثْ إِلاَّ يَسِيرًا حَتَّى مَاتَ فَدَفَنَّاهُ فَأَصْبَحَ عَلَى ظَهْرِ الأَرْضِ فَقَالُوا لَعَلَّ عَدُوًّا نَبَشَهُ فَدَفَنَّاهُ ثُمَّ أَمَرْنَا غِلْمَانَنَا يَحْرُسُونَهُ فَأَصْبَحَ عَلَى ظَهْرِ الأَرْضِ فَقُلْنَا لَعَلَّ الْغِلْمَانَ نَعَسُوا فَدَفَنَّاهُ ثُمَّ حَرَسْنَاهُ بِأَنْفُسِنَا فَأَصْبَحَ عَلَى ظَهْرِ الأَرْضِ فَأَلْقَيْنَاهُ فِي بَعْضِ تِلْكَ الشِّعَابِ ‏.‏\hadithno{3930}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sumait bin Sumair, that ‘Imran bin Husain said:“Nafi’ bin Azraq and his companions came and said: ‘You are doomed, O ‘Imran!’ He (‘Imran) said: ‘I am not doomed.’ They said: ‘Yes you are.’ I said: ‘Why am I doomed?’ They said: ‘Allah says: “And fight them until there is no more Fitnah (disbelief and polytheism, i.e., worshipping others besides Allah), and the religion (worship) will be all for Allah Alone.”[8:39] He said: ‘We fought them until they were defeated and the religion was all for Allah Alone. If you wish, I will tell you a Hadith that I heard from the Messenger of Allah (ﷺ).’ They said: ‘Did you (really) hear it from the Messenger of Allah (ﷺ)?’ He said: ‘Yes. I was with the Messenger of Allah (ﷺ) and he had sent an army of the Muslims to the idolaters. When they met them they fought them fiercely, and they (the idolaters) gave them their shoulders (i.e., turned and fled). A man among my kin attacked an idolator man with a spear, and when he was defeated he said: “I bear witness that none has the right to be worshipped but Allah, I am a Muslim.” But he stabbed him and killed him. He came to the Messenger of Allah (ﷺ) and said: “O Messenger of Allah, I am doomed.” He said “What is it that you have done?” one or two times. He told him what he had done and the Messenger of Allah (ﷺ) said to him: “Why didn’t you cut open his belly and find out what was in his heart?” He said: “O Messenger of Allah, I wish I had cut open his belly and could have known what was in his heart.” He said: “You did not accept what he said, and you could not have known what was in his heart!” The Messenger of Allah (ﷺ) remained silent concerning him (that man), and a short while later he died. We buried him, but the following morning he was on the surface of the earth. They said: “Perhaps an enemy of his disinterred him.” So we buried him (again) and told our slaves to stand guard. But the following morning he was on the surface of the earth again then we said: ‘Perhaps the slaves dozed off.’ So we buried him (again) and stood guard ourselves, but the following morning he was on the surface of the earth (again). So we threw him into one of these mountain passes.’”}}
\hadithdefcmd{ibnmajah}{3930p2}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ حَفْصٍ الأُبُلِّيُّ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ عَاصِمٍ، عَنِ السُّمَيْطِ، عَنْ عِمْرَانَ بْنِ الْحُصَيْنِ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي سَرِيَّةٍ فَحَمَلَ رَجُلٌ مِنَ الْمُسْلِمِينَ عَلَى رَجُلٍ مِنَ الْمُشْرِكِينَ فَذَكَرَ الْحَدِيثَ وَزَادَ فِيهِ فَنَبَذَتْهُ الأَرْضُ فَأُخْبِرَ النَّبِيُّ ـ صلى الله عليه وسلم ـ وَقَالَ ‏ "‏ إِنَّ الأَرْضَ لَتَقْبَلُ مَنْ هُوَ أَشَرُّ مِنْهُ وَلَكِنَّ اللَّهَ أَحَبَّ أَنْ يُرِيَكُمْ تَعْظِيمَ حُرْمَةِ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏\hadithno{3930.2}\hadithtrans{It was narrated from Sumait, from ‘Imran bin Husain who said:“The Messenger of Allah (ﷺ) sent us on a campaign, and a Muslim man attacked an idolater man.” And he mentioned the Hadith and added: “And the earth cast him out. The Prophet (ﷺ) was told about that and he said: ‘The earth accepts those who are worse than him, but Allah wanted to show you how great is the sanctity of La ilaha illallah.’”}}
\hadithdefcmd{ibnmajah}{3931}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي حِجَّةِ الْوَدَاعِ ‏"‏ أَلاَ إِنَّ أَحْرَمَ الأَيَّامِ يَوْمُكُمْ هَذَا أَلاَ وَإِنَّ أَحْرَمَ الشُّهُورِ شَهْرُكُمْ هَذَا أَلاَ وَإِنَّ أَحْرَمَ الْبَلَدِ بَلَدُكُمْ هَذَا أَلاَ وَإِنَّ دِمَاءَكُمْ وَأَمْوَالَكُمْ عَلَيْكُمْ حَرَامٌ كَحُرْمَةِ يَوْمِكُمْ هَذَا فِي شَهْرِكُمْ هَذَا فِي بَلَدِكُمْ هَذَا أَلاَ هَلْ بَلَّغْتُ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ اللَّهُمَّ اشْهَدْ ‏"‏ ‏.‏\hadithno{3931}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sa’eed said:“The Messenger of Allah (ﷺ) said, during the Farewell Pilgrimage: ‘Is not the most sacred of your days this day, is not the most sacred of your months this month, is not the most sacred of your lands this land? Your blood and your wealth are as sacred to you as this day of yours in this month of yours. Have I not conveyed (the message)?’ They said: ‘Yes.” He said: ‘O Allah, bear witness.’”}}
\hadithdefcmd{ibnmajah}{3932}{حَدَّثَنَا أَبُو الْقَاسِمِ بْنُ أَبِي ضَمْرَةَ، نَصْرُ بْنُ مُحَمَّدِ بْنِ سُلَيْمَانَ الْحِمْصِيُّ حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي قَيْسٍ النَّصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَطُوفُ بِالْكَعْبَةِ وَيَقُولُ ‏ "‏ مَا أَطْيَبَكِ وَأَطْيَبَ رِيحَكِ مَا أَعْظَمَكِ وَأَعْظَمَ حُرْمَتَكِ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَحُرْمَةُ الْمُؤْمِنِ أَعْظَمُ عِنْدَ اللَّهِ حُرْمَةً مِنْكِ مَالِهِ وَدَمِهِ وَأَنْ نَظُنَّ بِهِ إِلاَّ خَيْرًا ‏"‏ ‏.‏\hadithno{3932}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah bin ‘Amr said:“I saw the Messenger of Allah (ﷺ) circumambulating the Ka’bah and saying: ‘How good you are and how good your fragrance; how great you are and how great your sanctity. By the One in Whose Hand is the soul of Muhammad, the sanctity of the believer is greater before Allah than your sanctity, his blood and his wealth, and to think anything but good of him.’”}}
\hadithdefcmd{ibnmajah}{3933}{حَدَّثَنَا بَكْرُ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ، وَيُونُسُ بْنُ يَحْيَى، جَمِيعًا عَنْ دَاوُدَ بْنِ قَيْسٍ، عَنْ أَبِي سَعِيدٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ كُرَيْزٍ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كُلُّ الْمُسْلِمِ عَلَى الْمُسْلِمِ حَرَامٌ دَمُهُ وَمَالُهُ وَعِرْضُهُ ‏"‏ ‏.‏\hadithno{3933}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The whole of the Muslim is sacred to his fellow Muslim, his blood, his wealth and his honor.”}}
\hadithdefcmd{ibnmajah}{3934}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ أَبِي هَانِئٍ، عَنْ عَمْرِو بْنِ مَالِكٍ الْجَنْبِيِّ، أَنَّ فَضَالَةَ بْنَ عُبَيْدٍ، حَدَّثَهُ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْمُؤْمِنُ مَنْ أَمِنَهُ النَّاسُ عَلَى أَمْوَالِهِمْ وَأَنْفُسِهِمْ وَالْمُهَاجِرُ مَنْ هَجَرَ الْخَطَايَا وَالذُّنُوبَ ‏"‏ ‏.‏\hadithno{3934}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Fadalah bin ‘Ubaid narrated that the Prophet (ﷺ) said:“The believer is the one from whom their (people’s) wealth and lives are safe, and the Muhajir is the one who forsakes mistakes and sins.”}}
\hadithdefcmd{ibnmajah}{3935}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنِ انْتَهَبَ نُهْبَةً مَشْهُورَةً فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{3935}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) said:“Whoever plunders openly is not one of us.”}}
\hadithdefcmd{ibnmajah}{3936}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَزْنِي الزَّانِي حِينَ يَزْنِي وَهُوَ مُؤْمِنٌ وَلاَ يَشْرَبُ الْخَمْرَ حِينَ يَشْرَبُهَا وَهُوَ مُؤْمِنٌ وَلاَ يَسْرِقُ السَّارِقُ حِينَ يَسْرِقُ وَهُوَ مُؤْمِنٌ وَلاَ يَنْتَهِبُ نُهْبَةً يَرْفَعُ النَّاسُ إِلَيْهِ أَبْصَارَهُمْ حِينَ يَنْتَهِبُهَا وَهُوَ مُؤْمِنٌ ‏"‏ ‏.‏\hadithno{3936}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The adulterer, at the time he is committing adultery, is not a believer; (the wine drinker) at the time he is drinking, is not a believer; the thief, at the time he is stealing, is not a believer; the plunderer, at the time he is plundering with the people looking on, is not a believer.”}}
\hadithdefcmd{ibnmajah}{3937}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا حُمَيْدٌ، حَدَّثَنَا الْحَسَنُ، عَنْ عِمْرَانَ بْنِ الْحُصَيْنِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنِ انْتَهَبَ نُهْبَةً فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{3937}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Imran bin Husain that the Messenger of Allah (ﷺ) said:“Whoever plunders is not one of us.”}}
\hadithdefcmd{ibnmajah}{3938}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ ثَعْلَبَةَ بْنِ الْحَكَمِ، قَالَ أَصَبْنَا غَنَمًا لِلْعَدُوِّ فَانْتَهَبْنَاهَا فَنَصَبْنَا قُدُورَنَا فَمَرَّ النَّبِيُّ ـ صلى الله عليه وسلم ـ بِالْقُدُورِ فَأَمَرَ بِهَا فَأُكْفِئَتْ ثُمَّ قَالَ ‏ "‏ إِنَّ النُّهْبَةَ لاَ تَحِلُّ ‏"‏ ‏.‏\hadithno{3938}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Tha’labah bin Hakam said:“We came across some of the enemy’s sheep and plundered them, and set up our cooking pots. The Prophet (ﷺ) passed by the pots and ordered that they be overturned, then he said: ‘Plunder is not permissible.’”}}
\hadithdefcmd{ibnmajah}{3939}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنِ ابْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ سِبَابُ الْمُسْلِمِ فُسُوقٌ وَقِتَالُهُ كُفْرٌ ‏"‏ ‏.‏\hadithno{3939}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn Mas’ud that the Messenger of Allah (ﷺ) said:“Verbally abusing a Muslim is Fusuq disobedience and fighting him is Kufr (ungratefulness to Allah).’”}}
\hadithdefcmd{ibnmajah}{3940}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ الْحَسَنِ الأَسَدِيُّ، حَدَّثَنَا أَبُو هِلاَلٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ سِبَابُ الْمُسْلِمِ فُسُوقٌ وَقِتَالُهُ كُفْرٌ ‏"‏ ‏.‏\hadithno{3940}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Verbally abusing a Muslim is Fusuq (disobedience) and fighting him is Kufr (ungratefulness to Allah).”}}
\hadithdefcmd{ibnmajah}{3941}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ شَرِيكٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ سَعْدٍ، عَنْ سَعْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ سِبَابُ الْمُسْلِمِ فُسُوقٌ وَقِتَالُهُ كُفْرٌ ‏"‏ ‏.‏\hadithno{3941}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Sa’d that the Messenger of Allah (ﷺ) said:“Verbally abusing a Muslim is Fusuq (disobedience) and fighting him is Kufr.”}}
\hadithdefcmd{ibnmajah}{3942}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ عَلِيِّ بْنِ مُدْرِكٍ، قَالَ سَمِعْتُ أَبَا زُرْعَةَ بْنَ عَمْرِو بْنِ جَرِيرٍ، يُحَدِّثُ عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ فِي حِجَّةِ الْوَدَاعِ ‏"‏ اسْتَنْصِتِ النَّاسَ ‏"‏ ‏.‏ فَقَالَ ‏"‏ لاَ تَرْجِعُوا بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏ ‏.‏\hadithno{3942}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Jarir bin ‘Abdullah that the Messenger of Allah (ﷺ) said, during the Farewell Pilgrimage:“Make the people pay attention.” Then he said: “Do not turn back into disbelievers after I am gone, striking one another’s necks.”}}
\hadithdefcmd{ibnmajah}{3943}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، أَخْبَرَنِي عُمَرُ بْنُ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ وَيْحَكُمْ - أَوْ وَيْلَكُمْ - لاَ تَرْجِعُوا بَعْدِي كُفَّارًا يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ ‏"‏ ‏.‏\hadithno{3943}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“Woe to you! Do not turn back into disbelievers after I am gone, striking one another’s necks.”}}
\hadithdefcmd{ibnmajah}{3944}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي وَمُحَمَّدُ بْنُ بِشْرٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ قَيْسٍ، عَنِ الصُّنَابِحِ الأَحْمَسِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَلاَ إِنِّي فَرَطُكُمْ عَلَى الْحَوْضِ وَإِنِّي مُكَاثِرٌ بِكُمُ الأُمَمَ فَلاَ تَقْتَتِلُنَّ بَعْدِي ‏"‏ ‏.‏\hadithno{3944}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Sunabih Al-Ahmasi that the Messenger of Allah (ﷺ) said:“I shall reach the Cistern (Haud) before you, and I will boast of your great numbers before the nations, so do not fight one another after I am gone.’”}}
\hadithdefcmd{ibnmajah}{3945}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا أَحْمَدُ بْنُ خَالِدٍ الْوَهْبِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ الْمَاجِشُونُ، عَنْ عَبْدِ الْوَاحِدِ بْنِ أَبِي عَوْنٍ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ حَابِسٍ الْيَمَانِيِّ، عَنْ أَبِي بَكْرٍ الصِّدِّيقِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ صَلَّى الصُّبْحَ فَهُوَ فِي ذِمَّةِ اللَّهِ فَلاَ تُخْفِرُوا اللَّهَ فِي عَهْدِهِ فَمَنْ قَتَلَهُ طَلَبَهُ اللَّهُ حَتَّى يَكُبَّهُ فِي النَّارِ عَلَى وَجْهِهِ ‏"‏ ‏.‏\hadithno{3945}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Bakr Siddiq that the Messenger of Allah (ﷺ) said:“Whoever offers the morning prayer, he is under the protection of Allah, so do not betray Allah by betraying those who are under His protection. Whoever kills him, Allah will seek him out until He throws him on his face into Hell.”}}
\hadithdefcmd{ibnmajah}{3946}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا أَشْعَثُ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ صَلَّى الصُّبْحَ فَهُوَ فِي ذِمَّةِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{3946}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Samurah bin Jundab that the Prophet (ﷺ) said:“Whoever offers the morning prayer, he is under the protection of Allah, the Mighty and Sublime.”}}
\hadithdefcmd{ibnmajah}{3947}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا أَبُو الْمُهَزِّمِ، يَزِيدُ بْنُ سُفْيَانَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْمُؤْمِنُ أَكْرَمُ عَلَى اللَّهِ عَزَّ وَجَلَّ مِنْ بَعْضِ مَلاَئِكَتِهِ ‏"‏ ‏.‏\hadithno{3947}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The believer is more precious to Allah, the Mighty and Sublime, than some of His angels.”}}
\hadithdefcmd{ibnmajah}{3948}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، حَدَّثَنَا أَيُّوبُ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ زِيَادِ بْنِ رِيَاحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ قَاتَلَ تَحْتَ رَايَةٍ عِمِّيَّةٍ يَدْعُو إِلَى عَصَبِيَّةٍ أَوْ يَغْضَبُ لِعَصَبِيَّةٍ فَقِتْلَتُهُ جَاهِلِيَّةٌ ‏"‏ ‏.‏\hadithno{3948}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever fights under a banner of folly, supporting tribalism, or getting angry for the sake of tribalism, he dies in a state of ignorance.”}}
\hadithdefcmd{ibnmajah}{3949}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زِيَادُ بْنُ الرَّبِيعِ الْيُحْمِدِيُّ، عَنْ عَبَّادِ بْنِ كَثِيرٍ الشَّامِيِّ، عَنِ امْرَأَةٍ، مِنْهُمْ يُقَالَ لَهَا فُسَيْلَةُ قَالَتْ سَمِعْتُ أَبِي يَقُولُ، سَأَلْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقُلْتُ يَا رَسُولَ اللَّهِ أَمِنَ الْعَصَبِيَّةِ أَنْ يُحِبَّ الرَّجُلُ قَوْمَهُ قَالَ ‏ "‏ لاَ وَلَكِنْ مِنَ الْعَصَبِيَّةِ أَنْ يُعِينَ الرَّجُلُ قَوْمَهُ عَلَى الظُّلْمِ ‏"‏ ‏.‏\hadithno{3949}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Abbad bin Kathir Ash-Shami narrated from a woman among them, called Fasilah, that she heard her father say:“I asked the Prophet (ﷺ): ‘O Messenger of Allah, is it tribalism if a man loves his people?’ He said: ‘No, rather tribalism is when a man helps his people to do wrong.’”}}
\hadithdefcmd{ibnmajah}{3950}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا مُعَانُ بْنُ رِفَاعَةَ السَّلاَمِيُّ، حَدَّثَنِي أَبُو خَلَفٍ الأَعْمَى، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّ أُمَّتِي لَنْ تَجْتَمِعَ عَلَى ضَلاَلَةٍ فَإِذَا رَأَيْتُمُ اخْتِلاَفًا فَعَلَيْكُمْ بِالسَّوَادِ الأَعْظَمِ ‏"‏ ‏.‏\hadithno{3950}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik said:“I heard the Messenger of Allah (ﷺ) say: ‘My nation will not unite on misguidance, so if you see them differing, follow the great majority.’”}}
\hadithdefcmd{ibnmajah}{3951}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ رَجَاءٍ الأَنْصَارِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادِ بْنِ الْهَادِ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمًا صَلاَةً فَأَطَالَ فِيهَا فَلَمَّا انْصَرَفَ قُلْنَا - أَوْ قَالُوا - يَا رَسُولَ اللَّهِ أَطَلْتَ الْيَوْمَ الصَّلاَةَ قَالَ ‏ "‏ إِنِّي صَلَّيْتُ صَلاَةَ رَغْبَةٍ وَرَهْبَةٍ سَأَلْتُ اللَّهَ عَزَّ وَجَلَّ لأُمَّتِي ثَلاَثًا فَأَعْطَانِي اثْنَتَيْنِ وَرَدَّ عَلَىَّ وَاحِدَةً سَأَلْتُهُ أَنْ لاَ يُسَلِّطَ عَلَيْهِمْ عَدُوًّا مِنْ غَيْرِهِمْ فَأَعْطَانِيهَا وَسَأَلْتُهُ أَنْ لاَ يُهْلِكَهُمْ غَرَقًا فَأَعْطَانِيهَا وَسَأَلْتُهُ أَنْ لاَ يَجْعَلَ بَأْسَهُمْ بَيْنَهُمْ فَرَدَّهَا عَلَىَّ ‏"‏ ‏.‏\hadithno{3951}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Mu’adh bin Jabal said:“The Messenger of Allah (ﷺ) prayed one day, and made the prayer lengthy. When he finished we said (or they said): ‘O Messenger of Allah, you made the prayer lengthy today.’ He said: ‘I offered a prayer of hope and fear. I asked Allah for three things for my nation, and He granted me two and refused one. I asked Him not to let my nation be destroyed by enemies from without, and He granted me that. And I asked Him not to let them be destroyed by drowning, and He granted me that. And I asked Him not to let them be destroyed by fighting among themselves, but He refused that.’”}}
\hadithdefcmd{ibnmajah}{3952}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبِ بْنِ شَابُورَ، حَدَّثَنَا سَعِيدُ بْنُ بَشِيرٍ، عَنْ قَتَادَةَ، أَنَّهُ حَدَّثَهُمْ عَنْ أَبِي قِلاَبَةَ الْجَرْمِيِّ عَبْدِ اللَّهِ بْنِ زَيْدٍ، عَنْ أَبِي أَسْمَاءَ الرَّحَبِيِّ، عَنْ ثَوْبَانَ، مَوْلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ زُوِيَتْ لِيَ الأَرْضُ حَتَّى رَأَيْتُ مَشَارِقَهَا وَمَغَارِبَهَا وَأُعْطِيتُ الْكَنْزَيْنِ الأَصْفَرَ - أَوِ الأَحْمَرَ - وَالأَبْيَضَ - يَعْنِي الذَّهَبَ وَالْفِضَّةَ - وَقِيلَ لِي إِنَّ مُلْكَكَ إِلَى حَيْثُ زُوِيَ لَكَ وَإِنِّي سَأَلْتُ اللَّهَ عَزَّ وَجَلَّ ثَلاَثًا أَنْ لاَ يُسَلِّطَ عَلَى أُمَّتِي جُوعًا فَيُهْلِكَهُمْ بِهِ عَامَّةً وَأَنْ لاَ يَلْبِسَهُمْ شِيَعًا وَيُذِيقَ بَعْضَهُمْ بَأْسَ بَعْضٍ وَإِنَّهُ قِيلَ لِي إِذَا قَضَيْتُ قَضَاءً فَلاَ مَرَدَّ لَهُ وَإِنِّي لَنْ أُسَلِّطَ عَلَى أُمَّتِكَ جُوعًا فَيُهْلِكَهُمْ فِيهِ وَلَنْ أَجْمَعَ عَلَيْهِمْ مَنْ بَيْنَ أَقْطَارِهَا حَتَّى يُفْنِيَ بَعْضُهُمْ بَعْضًا وَيَقْتُلَ بَعْضُهُمْ بَعْضًا ‏.‏ وَإِذَا وُضِعَ السَّيْفُ فِي أُمَّتِي فَلَنْ يُرْفَعَ عَنْهُمْ إِلَى يَوْمِ الْقِيَامَةِ وَإِنَّ مِمَّا أَتَخَوَّفُ عَلَى أُمَّتِي أَئِمَّةً مُضِلِّينَ وَسَتَعْبُدُ قَبَائِلُ مِنْ أُمَّتِي الأَوْثَانَ وَسَتَلْحَقُ قَبَائِلُ مِنْ أُمَّتِي بِالْمُشْرِكِيِنَ وَإِنَّ بَيْنَ يَدَىِ السَّاعَةِ دَجَّالِينَ كَذَّابِينَ قَرِيبًا مِنْ ثَلاَثِينَ كُلُّهُمْ يَزْعُمُ أَنَّهُ نَبِيٌّ وَلَنْ تَزَالَ طَائِفَةٌ مِنْ أُمَّتِي عَلَى الْحَقِّ مَنْصُورِينَ لاَ يَضُرُّهُمْ مَنْ خَالَفَهُمْ حَتَّى يَأْتِيَ أَمْرُ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ لَمَّا فَرَغَ أَبُو عَبْدِ اللَّهِ مِنْ هَذَا الْحَدِيثِ قَالَ مَا أَهْوَلَهُ ‏.‏\hadithno{3952}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Thawban, the freed slave of the Messenger of Allah (ﷺ), that the Messenger of Allah (ﷺ) said:“The earth was brought together for me so that I could see the east and the west, and I was given two treasures, the yellow (or the red) and the white – meaning gold and silver. And it was said to me: ‘Your dominion will extend as far as has been shown to you.’ I asked Allah for three things: That my nation would not be overwhelmed by famine that would destroy them all, and that they would not be rent by schism and fight one another, but it was said to me: ‘When I (Allah) issue My decree it cannot be revoked. But I will never cause your nation to be overwhelmed by famine that would destroy them all, and I will not gather their enemies against them (and destroy them) until they annihilate one another and kill one another.’ Once they start to fight amongst themselves, that will continue until the Day of Resurrection. What I fear most for my nation is misguiding leaders. Some tribes among my nation will worship idols and some tribes among my nation will join the idolaters. Before the Hour comes there will be nearly thirty Dajjals (great liars), each of them claiming to be a Prophet. But a group among my nation will continue to adhere to the truth and be victorious, and those who oppose them will not harm them, until the command of Allah comes to pass.’”}}
\hadithdefcmd{ibnmajah}{3953}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ زَيْنَبَ ابْنَةِ أُمِّ سَلَمَةَ، عَنْ حَبِيبَةَ، عَنْ أُمِّ حَبِيبَةَ، عَنْ زَيْنَبَ بِنْتِ جَحْشٍ، أَنَّهَا قَالَتِ اسْتَيْقَظَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ نَوْمِهِ وَهُوَ مُحْمَرٌّ وَجْهُهُ وَهُوَ يَقُولُ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَيْلٌ لِلْعَرَبِ مِنْ شَرٍّ قَدِ اقْتَرَبَ فُتِحَ الْيَوْمَ مِنْ رَدْمِ يَأْجُوجَ وَمَأْجُوجَ ‏"‏ ‏.‏ وَعَقَدَ بِيَدَيْهِ عَشَرَةً ‏.‏ قَالَتْ زَيْنَبُ قُلْتُ يَا رَسُولَ اللَّهِ أَنَهْلِكُ وَفِينَا الصَّالِحُونَ قَالَ ‏"‏ إِذَا كَثُرَ الْخَبَثُ ‏"‏ ‏.‏\hadithno{3953}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Zainab bint Jahsh said:“The Messenger of Allah (ﷺ) woke up red in the face and said: ‘La ilaha illallah, woe to the Arabs from an evil that has drawn nigh. Today a hole has been opened in the barrier of Gog and Magog.’ And he gestured to indicate the size of the hole.” Zainab said: “I said: ‘O Messenger of Allah! Will we be destroyed when there are righteous people among us?’ He said: ‘If sin and evil deeds increase.’”}}
\hadithdefcmd{ibnmajah}{3954}{حَدَّثَنَا رَاشِدُ بْنُ سَعِيدٍ الرَّمْلِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الْوَلِيدِ بْنِ سُلَيْمَانَ بْنِ أَبِي السَّائِبِ، عَنْ عَلِيِّ بْنِ يَزِيدَ، عَنِ الْقَاسِمِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ أَبِي أُمَامَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ سَتَكُونُ فِتَنٌ يُصْبِحُ الرَّجُلُ فِيهَا مُؤْمِنًا وَيُمْسِي كَافِرًا إِلاَّ مَنْ أَحْيَاهُ اللَّهُ بِالْعِلْمِ ‏"‏ ‏.‏\hadithno{3954}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Umamah that the Messenger of Allah (ﷺ) said:“There will be tribulation in which a man will be a believer in the morning and a disbeliever by evening, except the one to whom Allah grants knowledge.”}}
\hadithdefcmd{ibnmajah}{3955}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَأَبِي، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ حُذَيْفَةَ، قَالَ كُنَّا جُلُوسًا عِنْدَ عُمَرَ فَقَالَ أَيُّكُمْ يَحْفَظُ حَدِيثَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي الْفِتْنَةِ قَالَ حُذَيْفَةُ فَقُلْتُ أَنَا ‏.‏ قَالَ إِنَّكَ لَجَرِيءٌ قَالَ كَيْفَ قَالَ سَمِعْتُهُ يَقُولُ ‏ "‏ فِتْنَةُ الرَّجُلِ فِي أَهْلِهِ وَوَلَدِهِ وَجَارِهِ تُكَفِّرُهَا الصَّلاَةُ وَالصِّيَامُ وَالصَّدَقَةُ وَالأَمْرُ بِالْمَعْرُوفِ وَالنَّهْىُ عَنِ الْمُنْكَرِ ‏"‏ ‏.‏ فَقَالَ عُمَرُ لَيْسَ هَذَا أُرِيدُ إِنَّمَا أُرِيدُ الَّتِي تَمُوجُ كَمَوْجِ الْبَحْرِ ‏.‏ فَقَالَ مَالَكَ وَلَهَا يَا أَمِيرَ الْمُؤْمِنِينَ إِنَّ بَيْنَكَ وَبَيْنَهَا بَابًا مُغْلَقًا ‏.‏ قَالَ فَيُكْسَرُ الْبَابُ أَوْ يُفْتَحُ قَالَ لاَ بَلْ يُكْسَرُ ‏.‏ قَالَ ذَاكَ أَجْدَرُ أَنْ لاَ يُغْلَقَ ‏.‏ قُلْنَا لِحُذَيْفَةَ أَكَانَ عُمَرُ يَعْلَمُ مَنِ الْبَابُ قَالَ نَعَمْ كَمَا يَعْلَمُ أَنَّ دُونَ غَدٍ اللَّيْلَةَ إِنِّي حَدَّثْتُهُ حَدِيثًا لَيْسَ بِالأَغَالِيطِ ‏.‏ فَهِبْنَا أَنْ نَسْأَلَهُ مَنِ الْبَابُ فَقُلْنَا لِمَسْرُوقٍ سَلْهُ فَسَأَلَهُ فَقَالَ عُمَرُ ‏.‏\hadithno{3955}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Hudhaifah said:“We were sitting with ‘Umar and he said: ‘Which of you has remembered a Hadith from the Messenger of Allah (ﷺ) concerning Fitnah?’” Hudhaifah said: “I said: ‘I have.’ He said: ‘You are very bold.’ He said: ‘How?’ He said: ‘I heard him say: “The fitnah of a man with regard to his family, his children and his neigbors are expiated by his prayers, fasts, charity and enjoining what is good and forbidding what is evil.” ‘Umar said: ‘This is not what I meant, rather I meant that which moves like the waves of the sea.’” Hudhaifah said: “Don’t worry about it, O Commander of the Believers! For there is a closed door between you and them.” ‘Umar said: “Will that door be broken or opened?” I said: “No, it will be broken.” ‘Umar said: “Then it will never be closed.’” We asked Hudhaifah: “Did ‘Umar know what that door meant?” He said: "Yes, just as he knows that there will be night before morning, because I narrated to him a Hadith in which there are no errors.” We were afraid to ask him who the door was, so we said to Masruq: “Ask him." He said: “‘Umar.”}}
\hadithdefcmd{ibnmajah}{3956}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَعَبْدُ الرَّحْمَنِ الْمُحَارِبِيُّ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ رَبِّ الْكَعْبَةِ، قَالَ انْتَهَيْتُ إِلَى عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ وَهُوَ جَالِسٌ فِي ظِلِّ الْكَعْبَةِ وَالنَّاسُ مُجْتَمِعُونَ عَلَيْهِ فَسَمِعْتُهُ يَقُولُ بَيْنَا نَحْنُ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي سَفَرٍ إِذْ نَزَلَ مَنْزِلاً فَمِنَّا مَنْ يَضْرِبُ خِبَاءَهُ وَمِنَّا مَنْ يَنْتَضِلُ وَمِنَّا مَنْ هُوَ فِي جَشَرِهِ إِذْ نَادَى مُنَادِيهِ الصَّلاَةُ جَامِعَةٌ فَاجْتَمَعْنَا فَقَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَخَطَبَنَا فَقَالَ ‏ "‏ إِنَّهُ لَمْ يَكُنْ نَبِيٌّ قَبْلِي إِلاَّ كَانَ حَقًّا عَلَيْهِ أَنْ يَدُلَّ أُمَّتَهُ عَلَى مَا يَعْلَمُهُ خَيْرًا لَهُمْ وَيُنْذِرَهُمْ مَا يَعْلَمُهُ شَرًّا لَهُمْ وَإِنَّ أُمَّتَكُمْ هَذِهِ جُعِلَتْ عَافِيَتُهَا فِي أَوَّلِهَا وَإِنَّ آخِرَهُمْ يُصِيبُهُمْ بَلاَءٌ وَأُمُورٌ تُنْكِرُونَهَا ثُمَّ تَجِيءُ فِتَنٌ يُرَقِّقُ بَعْضُهَا بَعْضًا فَيَقُولُ الْمُؤْمِنُ هَذِهِ مُهْلِكَتِي ثُمَّ تَنْكَشِفُ ثُمَّ تَجِيءُ فِتْنَةٌ فَيَقُولُ الْمُؤْمِنُ هَذِهِ مُهْلِكَتِي ‏.‏ ثُمَّ تَنْكَشِفُ فَمَنْ سَرَّهُ أَنْ يُزَحْزَحَ عَنِ النَّارِ وَيُدْخَلَ الْجَنَّةَ فَلْتُدْرِكْهُ مَوْتَتُهُ وَهُوَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ وَلْيَأْتِ إِلَى النَّاسِ الَّذِي يُحِبُّ أَنْ يَأْتُوا إِلَيْهِ وَمَنْ بَايَعَ إِمَامًا فَأَعْطَاهُ صَفْقَةَ يَمِينِهِ وَثَمَرَةَ قَلْبِهِ فَلْيُطِعْهُ مَا اسْتَطَاعَ فَإِنْ جَاءَ آخَرُ يُنَازِعُهُ فَاضْرِبُوا عُنُقَ الآخَرِ ‏"‏ ‏.‏ قَالَ فَأَدْخَلْتُ رَأْسِي مِنْ بَيْنِ النَّاسِ فَقُلْتُ أَنْشُدُكَ اللَّهَ أَنْتَ سَمِعْتَ هَذَا مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ فَأَشَارَ بِيَدِهِ إِلَى أُذُنَيْهِ فَقَالَ سَمِعَتْهُ أُذُنَاىَ وَوَعَاهُ قَلْبِي ‏.‏\hadithno{3956}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Abdur-Rahman bin ‘Abd Rabbil-Ka’bah said:“I came to ‘Abdullah bin ‘Amr bin ‘As when he was sitting in the shade of the Ka’bah, and the people were gathered around him, and I heard him say: ‘While we were with the Messenger of Allah (ﷺ) on a journey, he stopped to camp and some of us were pitching tents, some were competing in shooting arrows and some were taking the animals out to graze them. Then his caller called out: “As-Salatu Jami’ah (prayer is about to begin).” So we gathered, and the Messenger of Allah (ﷺ) stood up and addressed us. He said: “There has never been a Prophet before me who was not obliged to tell his nation of what he knew was good for them, and to warn against what he knew was bad for them. With regard to this nation of yours, soundness (of religious commitment) and well-being has been placed in its earlier generations and the last of them will be afflicted with calamities and things that you dislike. Then there will come tribulations which will make the earlier ones pale into significance, and the believer will say: ‘This will be the end of me,’ then relief will come. Then (more) tribulations will come and the believer will say: ‘This will be the end of me,’ then relief will come. Whoever would like to be taken far away from Hell and admitted to Paradise, let him die believing in Allah and the Last Day, and let him treat people as he would like to be treated. Whoever gives his oath of allegiance to a ruler and gives a sincere promise, let him obey him as much as he can, and if another comes and challenges him, let them strike the neck (i.e., kill) the second one.’” He the narrator said: “I raised my head among the people and said: 'I adjure you by Allah, did you hear that from the Messenger of Allah (ﷺ)?' He ('Abdullah bin 'Amr bin Al-'As) pointed with his hand to his ears and said: I heard it directly from him and memorized it.'”}}
\hadithdefcmd{ibnmajah}{3957}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، حَدَّثَنِي أَبِي، عَنْ عُمَارَةَ بْنِ حَزْمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ كَيْفَ بِكُمْ وَبِزَمَانٍ يُوشِكُ أَنْ يَأْتِيَ يُغَرْبَلُ النَّاسُ فِيهِ غَرْبَلَةً وَتَبْقَى حُثَالَةٌ مِنَ النَّاسِ قَدْ مَرِجَتْ عُهُودُهُمْ وَأَمَانَاتُهُمْ فَاخْتَلَفُوا وَكَانُوا هَكَذَا ‏"‏ ‏.‏ وَشَبَّكَ بَيْنَ أَصَابِعِهِ قَالُوا كَيْفَ بِنَا يَا رَسُولَ اللَّهِ إِذَا كَانَ ذَلِكَ قَالَ ‏"‏ تَأْخُذُونَ بِمَا تَعْرِفُونَ وَتَدَعُونَ مَا تُنْكِرُونَ وَتُقْبِلُونَ عَلَى خَاصَّتِكُمْ وَتَذَرُونَ أَمْرَ عَوَامِّكُمْ ‏"‏ ‏.‏\hadithno{3957}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr that the Messenger of Allah (ﷺ) said:“How will you be at a time that will soon come, when the good people will pass away and only the worst ones will be left, who will break their promises and betray their trusts, and they will differ while they were previously together like this,” – and he interlaced his fingers. They said: “What should we do, O Messenger of Allah, when that comes to pass?” He said: “Follow that which you know is true, and leave that which you dislike. Take care of your own affairs and turn away from the common folk.”}}
\hadithdefcmd{ibnmajah}{3958}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنِ الْمُشَعَّثِ بْنِ طَرِيفٍ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ كَيْفَ أَنْتَ يَا أَبَا ذَرٍّ وَمَوْتًا يُصِيبُ النَّاسَ حَتَّى يُقَوَّمَ الْبَيْتُ بِالْوَصِيفِ ‏"‏ ‏.‏ يَعْنِي الْقَبْرَ قُلْتُ مَا خَارَ اللَّهُ لِي وَرَسُولُهُ - أَوْ قَالَ اللَّهُ وَرَسُولُهُ أَعْلَمُ - قَالَ ‏"‏ تَصَبَّرْ ‏"‏ ‏.‏ قَالَ ‏"‏ كَيْفَ أَنْتَ وَجُوعًا يُصِيبُ النَّاسَ حَتَّى تَأْتِيَ مَسْجِدَكَ فَلاَ تَسْتَطِيعَ أَنْ تَرْجِعَ إِلَى فِرَاشِكَ وَلاَ تَسْتَطِيعَ أَنْ تَقُومَ مِنْ فِرَاشِكَ إِلَى مَسْجِدِكَ ‏"‏ ‏.‏ قَالَ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ أَوْ - مَا خَارَ اللَّهُ لِي وَرَسُولُهُ - قَالَ ‏"‏ عَلَيْكَ بِالْعِفَّةِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ كَيْفَ أَنْتَ وَقَتْلاً يُصِيبُ النَّاسَ حَتَّى تُغْرَقَ حِجَارَةُ الزَّيْتِ بِالدَّمِ ‏"‏ ‏.‏ قُلْتُ مَا خَارَ اللَّهُ لِي وَرَسُولُهُ ‏.‏ قَالَ ‏"‏ الْحَقْ بِمَنْ أَنْتَ مِنْهُ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَفَلاَ آخُذُ بِسَيْفِي فَأَضْرِبَ بِهِ مَنْ فَعَلَ ذَلِكَ قَالَ ‏"‏ شَارَكْتَ الْقَوْمَ إِذًا وَلَكِنِ ادْخُلْ بَيْتَكَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ فَإِنْ دُخِلَ بَيْتِي قَالَ ‏"‏ إِنْ خَشِيتَ أَنْ يَبْهَرَكَ شُعَاعُ السَّيْفِ فَأَلْقِ طَرَفَ رِدَائِكَ عَلَى وَجْهِكَ فَيَبُوءَ بِإِثْمِهِ وَإِثْمِكَ فَيَكُونَ مِنْ أَصْحَابِ النَّارِ ‏"‏ ‏.‏\hadithno{3958}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Dharr that the Messenger of Allah (ﷺ) said:“What will you do, O Abu Dharr, when death overwhelms the people to such an extent that a grave will be equal in value to a slave?” I said: “Whatever Allah and His Messenger choose for me, or Allah and His Messenger know best.” He said “Be patient.” He said: ‘What will you do when famine strikes the people so that you will go to the place where you pray and will not be able to return to your bed, or you will not be able to get up from your bed to go to the place where you pray?” He said: “I said: ‘Allah and His Messenger know best, or whatever Allah and His Messenger choose for me.” He said: “You must refrain from forbidden things.” He said: “What will you do when killing befalls the people so that Hijaratuz-Zait*is covered with blood?” I said: “Whatever Allah and His Messenger choose for me.” He said: “Stay with those whom you belong to.” He said: “I said: ‘O Messenger of Allah, should I not take my sword and strike those who do that?’” He said: “Then you will be just like the people. Rather enter your house.” I said: “O Messenger of Allah, what if they enter my house?” He said: “If you are afraid that the flashing of the sword will dazzle you, then put the edge of your garment over your face, and let him carry his own sin and your sin, and he will be one of the people of the Hellfire.”}}
\hadithdefcmd{ibnmajah}{3959}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا عَوْفٌ، عَنِ الْحَسَنِ، حَدَّثَنَا أَسِيدُ بْنُ الْمُتَشَمِّسِ، قَالَ حَدَّثَنَا أَبُو مُوسَى، حَدَّثَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ بَيْنَ يَدَىِ السَّاعَةِ لَهَرْجًا ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَا الْهَرْجُ قَالَ ‏"‏ الْقَتْلُ ‏"‏ ‏.‏ فَقَالَ بَعْضُ الْمُسْلِمِينَ يَا رَسُولَ اللَّهِ إِنَّا نَقْتُلُ الآنَ فِي الْعَامِ الْوَاحِدِ مِنَ الْمُشْرِكِينَ كَذَا وَكَذَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لَيْسَ بِقَتْلِ الْمُشْرِكِينَ وَلَكِنْ يَقْتُلُ بَعْضُكُمْ بَعْضًا حَتَّى يَقْتُلَ الرَّجُلُ جَارَهُ وَابْنَ عَمِّهِ وَذَا قَرَابَتِهِ ‏"‏ ‏.‏ فَقَالَ بَعْضُ الْقَوْمِ يَا رَسُولَ اللَّهِ وَمَعَنَا عُقُولُنَا ذَلِكَ الْيَوْمَ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لاَ تُنْزَعُ عُقُولُ أَكْثَرِ ذَلِكَ الزَّمَانِ وَيَخْلُفُ لَهُ هَبَاءٌ مِنَ النَّاسِ لاَ عُقُولَ لَهُمْ ‏"‏ ‏.‏ ثُمَّ قَالَ الأَشْعَرِيُّ وَايْمُ اللَّهِ إِنِّي لأَظُنُّهَا مُدْرِكَتِي وَإِيَّاكُمْ وَايْمُ اللَّهِ مَا لِي وَلَكُمْ مِنْهَا مَخْرَجٌ إِنْ أَدْرَكَتْنَا فِيمَا عَهِدَ إِلَيْنَا نَبِيُّنَا ـ صلى الله عليه وسلم ـ إِلاَّ أَنْ نَخْرُجَ كَمَا دَخَلْنَا فِيهَا ‏.‏\hadithno{3959}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Musa narrated that the Messenger of Allah (ﷺ) said:“Before the Hour comes there will be Harj.” I said: “O Messenger of Allah, what is Harj?” He said: “Killing.” Some of the Muslims said: “O Messenger of Allah, now we kill such and such a number of idolaters in one year.” The Messenger of Allah (ﷺ) said: “That will not be like killing the idolaters, rather you will kill one another, until a man will kill his neighbor and son of the cousin and a relative.” Some of the people said: “O Messenger of Allah, will we be in our right minds that day?” The Messenger of Allah (ﷺ) said: “No, reason will be taken away from most of the people at that time, and there will be left the insignificant people who have no reason.”}}
\hadithdefcmd{ibnmajah}{3960}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُبَيْدٍ، مُؤَذِّنُ مَسْجِدِ جُرْدَانَ قَالَ حَدَّثَتْنِي عُدَيْسَةُ بِنْتُ أُهْبَانَ، قَالَتْ لَمَّا جَاءَ عَلِيُّ بْنُ أَبِي طَالِبٍ هَاهُنَا الْبَصْرَةَ دَخَلَ عَلَى أَبِي فَقَالَ يَا أَبَا مُسْلِمٍ أَلاَ تُعِينُنِي عَلَى هَؤُلاَءِ الْقَوْمِ قَالَ بَلَى ‏.‏ قَالَ فَدَعَا جَارِيَةً لَهُ فَقَالَ يَا جَارِيَةُ أَخْرِجِي سَيْفِي ‏.‏ قَالَ فَأَخْرَجَتْهُ فَسَلَّ مِنْهُ قَدْرَ شِبْرٍ فَإِذَا هُوَ خَشَبٌ فَقَالَ إِنَّ خَلِيلِي وَابْنَ عَمِّكَ ـ صلى الله عليه وسلم ـ عَهِدَ إِلَىَّ إِذَا كَانَتِ الْفِتْنَةُ بَيْنَ الْمُسْلِمِينَ فَأَتَّخِذُ سَيْفًا مِنْ خَشَبٍ فَإِنْ شِئْتَ خَرَجْتُ مَعَكَ ‏.‏ قَالَ لاَ حَاجَةَ لِي فِيكَ وَلاَ فِي سَيْفِكَ ‏.‏\hadithno{3960}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{‘Udaisah bint Uhban said:“When ‘Ali bin Abu Talib came to Basrah, he entered upon my father and said: ‘O Abu Muslim, will you not help me against these people?’ He said: ‘Of course.’ So he called a slave woman of his and said: ‘O slave woman, bring me my sword.’ So she brought it, and he unsheathed it a span, and (I saw that) it was made of wood. He said: ‘My close friend and your cousin (ﷺ) advised me, if tribulation (Fitnah) arose among the Muslims, that I should take a sword of wood. If you wish I will go out with you.’ He said: ‘I have no need of you or of your sword.’”}}
\hadithdefcmd{ibnmajah}{3961}{حَدَّثَنَا عِمْرَانُ بْنُ مُوسَى اللَّيْثِيُّ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جُحَادَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ ثَرْوَانَ، عَنْ هُزَيْلِ بْنِ شُرَحْبِيلَ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ بَيْنَ يَدَىِ السَّاعَةِ فِتَنًا كَقِطَعِ اللَّيْلِ الْمُظْلِمِ يُصْبِحُ الرَّجُلُ فِيهَا مُؤْمِنًا وَيُمْسِي كَافِرًا وَيُمْسِي مُؤْمِنًا وَيُصْبِحُ كَافِرًا الْقَاعِدُ فِيهَا خَيْرٌ مِنَ الْقَائِمِ وَالْقَائِمُ فِيهَا خَيْرٌ مِنَ الْمَاشِي وَالْمَاشِي فِيهَا خَيْرٌ مِنَ السَّاعِي فَكَسِّرُوا قِسِيَّكُمْ وَقَطِّعُوا أَوْتَارَكُمْ وَاضْرِبُوا بِسُيُوفِكُمُ الْحِجَارَةَ فَإِنْ دُخِلَ عَلَى أَحَدٍ مِنْكُمْ فَلْيَكُنْ كَخَيْرِ ابْنَىْ آدَمَ ‏"‏ ‏.‏\hadithno{3961}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Musa Al-Ash’ari that the Messenger of Allah (ﷺ) said:“Before the Hour comes, there will be tribulation like pieces of black night, when a man will wake up as a believer but be a disbeliever by evening, or he will be a believer in the evening but will be a disbeliever by morning. And the one who is sitting will be better than the one who is standing, and the one who is standing will be better than the one who is walking, and the one who is walking will be better than the one who is running. So break your bows, cut their strings and strike your swords against rocks, and if anyone enters upon anyone of you, let him be like the better of the two sons of Adam. (i.e. the one killed, not the killer).”}}
\hadithdefcmd{ibnmajah}{3962}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ ثَابِتٍ، - أَوْ عَلِيِّ بْنِ زَيْدِ بْنِ جُدْعَانَ شَكَّ أَبُو بَكْرٍ - عَنْ أَبِي بُرْدَةَ، قَالَ دَخَلْتُ عَلَى مُحَمَّدِ بْنِ مَسْلَمَةَ فَقَالَ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّهَا سَتَكُونُ فِتْنَةٌ وَفُرْقَةٌ وَاخْتِلاَفٌ فَإِذَا كَانَ كَذَلِكَ فَأْتِ بِسَيْفِكَ أُحُدًا فَاضْرِبْهُ حَتَّى يَنْقَطِعَ ثُمَّ اجْلِسْ فِي بَيْتِكَ حَتَّى تَأْتِيَكَ يَدٌ خَاطِئَةٌ أَوْ مَنِيَّةٌ قَاضِيَةٌ ‏"‏ ‏.‏ فَقَدْ وَقَعَتْ وَفَعَلْتُ مَا قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{3962}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Burdah said:“I entered upon Muhammad bin Maslamah and he said that the Messenger of Allah (ﷺ) said: ‘There will be tribulation, division and dissension. When that comes, take your sword to Uhud and strike it until it breaks, then sit in your house until there comes to you the hand of the evildoer (to kill you) or a predestined (natural) death.’” "And that came to pass, and I did as the Messenger of Allah (ﷺ) said}}
\hadithdefcmd{ibnmajah}{3963}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا مُبَارَكُ بْنُ سُحَيْمٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا مِنْ مُسْلِمَيْنِ الْتَقَيَا بِأَسْيَافِهِمَا إِلاَّ كَانَ الْقَاتِلُ وَالْمَقْتُولُ فِي النَّارِ ‏"‏ ‏.‏\hadithno{3963}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik that the Prophet (ﷺ) said:“There are no two Muslims who confront one another with their swords, but both the killer and the slain will be in Hell.”}}
\hadithdefcmd{ibnmajah}{3964}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، وَسَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِذَا الْتَقَى الْمُسْلِمَانِ بِسَيْفَيْهِمَا فَالْقَاتِلُ وَالْمَقْتُولُ فِي النَّارِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ هَذَا الْقَاتِلُ فَمَا بَالُ الْمَقْتُولِ قَالَ ‏"‏ إِنَّهُ أَرَادَ قَتْلَ صَاحِبِهِ ‏"‏ ‏.‏\hadithno{3964}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Musa that the Messenger of Allah (ﷺ) said:“When two Muslims confront one another with their swords, both the killer and the slain will be in Hell.” They said: “O Messenger of Allah, (we understand about) this killer, but what is wrong with the one who is slain?” He said: “He wanted to kill his companion.’”}}
\hadithdefcmd{ibnmajah}{3965}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ أَبِي بَكْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِذَا الْمُسْلِمَانِ حَمَلَ أَحَدُهُمَا عَلَى أَخِيهِ السِّلاَحَ فَهُمَا عَلَى جُرُفِ جَهَنَّمَ فَإِذَا قَتَلَ أَحَدُهُمَا صَاحِبَهُ دَخَلاَهَا جَمِيعًا ‏"‏ ‏.‏\hadithno{3965}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Bakrah that the Prophet (ﷺ) said:“When one Muslim wields his weapon against his brother, both of them are at the edge of Hell, and if one of them kills the other, they will both enter it.”}}
\hadithdefcmd{ibnmajah}{3966}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنْ عَبْدِ الْحَكَمِ السَّدُوسِيِّ، حَدَّثَنَا شَهْرُ بْنُ حَوْشَبٍ، عَنْ أَبِي أُمَامَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مِنْ شَرِّ النَّاسِ مَنْزِلَةً عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ عَبْدٌ أَذْهَبَ آخِرَتَهُ بِدُنْيَا غَيْرِهِ ‏"‏ ‏.‏\hadithno{3966}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Umamah that the Messenger of Allah (ﷺ) said:“Among the worst people in status before Allah on the Day of Resurrection will be a person who loses his Hereafter for the sake of this world.”}}
\hadithdefcmd{ibnmajah}{3967}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاوِيَةَ الْجُمَحِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ لَيْثٍ، عَنْ طَاوُسٍ، عَنْ زِيَادٍ، سِيمِينْ كُوشْ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَكُونُ فِتْنَةٌ تَسْتَنْظِفُ الْعَرَبَ قَتْلاَهَا فِي النَّارِ اللِّسَانُ فِيهَا أَشَدُّ مِنْ وَقْعِ السَّيْفِ ‏"‏ ‏.‏\hadithno{3967}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr that the Messenger of Allah (ﷺ) said:“There will be a tribulation which will utterly destroy the Arabs, and those who are slain will be in Hell. At that time the tongue will be worse than a blow of the sword.”}}
\hadithdefcmd{ibnmajah}{3968}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ الْحَارِثِ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ الْبَيْلَمَانِيِّ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِيَّاكُمْ وَالْفِتَنَ فَإِنَّ اللِّسَانَ فِيهَا مِثْلُ وَقْعِ السَّيْفِ ‏"‏ ‏.‏\hadithno{3968}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“Beware of tribulations, for at that time the tongue will be like the blow of a sword.”}}
\hadithdefcmd{ibnmajah}{3969}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، حَدَّثَنِي أَبِي، عَنْ أَبِيهِ، عَلْقَمَةَ بْنِ وَقَّاصٍ قَالَ مَرَّ بِهِ رَجُلٌ لَهُ شَرَفٌ فَقَالَ لَهُ عَلْقَمَةُ إِنَّ لَكَ رَحِمًا وَإِنَّ لَكَ حَقًّا وَإِنِّي رَأَيْتُكَ تَدْخُلُ عَلَى هَؤُلاَءِ الأُمَرَاءِ وَتَتَكَلَّمُ عِنْدَهُمْ بِمَا شَاءَ اللَّهُ أَنْ تَتَكَلَّمَ بِهِ وَإِنِّي سَمِعْتُ بِلاَلَ بْنَ الْحَارِثِ الْمُزَنِيَّ صَاحِبَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ أَحَدَكُمْ لَيَتَكَلَّمُ بِالْكَلِمَةِ مِنْ رِضْوَانِ اللَّهِ مَا يَظُنُّ أَنْ تَبْلُغَ مَا بَلَغَتْ فَيَكْتُبُ اللَّهُ عَزَّ وَجَلَّ لَهُ بِهَا رِضْوَانَهُ إِلَى يَوْمِ الْقِيَامَةِ وَإِنَّ أَحَدَكُمْ لَيَتَكَلَّمُ بِالْكَلِمَةِ مِنْ سَخَطِ اللَّهِ مَا يَظُنُّ أَنْ تَبْلُغَ مَا بَلَغَتْ فَيَكْتُبُ اللَّهُ عَزَّ وَجَلَّ عَلَيْهِ بِهَا سَخَطَهُ إِلَى يَوْمِ يَلْقَاهُ ‏"‏ ‏.‏ قَالَ عَلْقَمَةُ فَانْظُرْ وَيْحَكَ مَاذَا تَقُولُ وَمَاذَا تَكَلَّمُ بِهِ فَرُبَّ كَلاَمٍ - قَدْ - مَنَعَنِي أَنْ أَتَكَلَّمَ بِهِ مَا سَمِعْتُ مِنْ بِلاَلِ بْنِ الْحَارِثِ ‏.‏\hadithno{3969}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Alqamah bin Waqqas said that a man passed by him, who held a prominent position, and ‘Alqamah said to him:“You have kinship and rights, and I see you entering upon these rulers and speaking to them as Allah wills you should speak. But i heard Bilal bin Harith Al-Muzani, the Companion of the Messenger of Allah (ﷺ), say that the Messenger of Allah (ﷺ) said: ‘One of you may speak a word that pleases Allah, and not know how far it reaches, but Allah will record for him as pleasure, until the Day of Resurrection due to that word. And one of you may speak a word that angers Allah, and not know how far it reaches, but Allah will record against him his anger, until the Day he meets Him due to that word.” 'Alqamah said: "So look, woe to you, at what you say and what you speak about, for there is something that I wanted to say but I refrained because of what I heard from Bilal bin Harith}}
\hadithdefcmd{ibnmajah}{3970}{حَدَّثَنَا أَبُو يُوسُفَ الصَّيْدَلاَنِيُّ، مُحَمَّدُ بْنُ أَحْمَدَ الرَّقِّيُّ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنِ ابْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ الرَّجُلَ لَيَتَكَلَّمُ بِالْكَلِمَةِ مِنْ سَخَطِ اللَّهِ لاَ يَرَى بِهَا بَأْسًا فَيَهْوِي بِهَا فِي نَارِ جَهَنَّمَ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏\hadithno{3970}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“A man may speak a word that angers Allah and not see anything wrong with it, but it will cause him to sink down in Hell the depth of seventy autumns.”}}
\hadithdefcmd{ibnmajah}{3971}{حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيَقُلْ خَيْرًا أَوْ لِيَسْكُتْ ‏"‏ ‏.‏\hadithno{3971}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever believes in Allah and the Last Day, let him say something good, or else remain silent.”}}
\hadithdefcmd{ibnmajah}{3972}{حَدَّثَنَا أَبُو مَرْوَانَ، مُحَمَّدُ بْنُ عُثْمَانَ الْعُثْمَانِيُّ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ مَاعِزٍ الْعَامِرِيِّ، أَنَّ سُفْيَانَ بْنَ عَبْدِ اللَّهِ الثَّقَفِيَّ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ حَدِّثْنِي بِأَمْرٍ أَعْتَصِمُ بِهِ ‏.‏ قَالَ ‏"‏ قُلْ رَبِّيَ اللَّهُ ثُمَّ اسْتَقِمْ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ مَا أَكْثَرُ مَا تَخَافُ عَلَىَّ فَأَخَذَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِلِسَانِ نَفْسِهِ ثُمَّ قَالَ ‏"‏ هَذَا ‏"‏ ‏.‏\hadithno{3972}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Sufyan bin ‘Abdullah Thaqafi said:“I said: ‘O Messenger of Allah, tell me of something that I can adhere to.’ He said: ‘Say: “Allah is my Lord,” then stand straight (adhere steadfastly to Islam).’ He said: ‘O Messenger of Allah, what is the thing that you fear most for me?’ The Messenger of Allah (ﷺ) took hold of his own tongue, then he said: ‘This.’”}}
\hadithdefcmd{ibnmajah}{3973}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْعَدَنِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُعَاذٍ، عَنْ مَعْمَرٍ، عَنْ عَاصِمِ بْنِ أَبِي النَّجُودِ، عَنْ أَبِي وَائِلٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ، قَالَ كُنْتُ مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فِي سَفَرٍ فَأَصْبَحْتُ يَوْمًا قَرِيبًا مِنْهُ وَنَحْنُ نَسِيرُ فَقُلْتُ يَا رَسُولَ اللَّهِ أَخْبِرْنِي بِعَمَلٍ يُدْخِلُنِي الْجَنَّةَ وَيُبَاعِدُنِي مِنَ النَّارِ ‏.‏ قَالَ ‏"‏ لَقَدْ سَأَلْتَ عَظِيمًا وَإِنَّهُ لَيَسِيرٌ عَلَى مَنْ يَسَّرَهُ اللَّهُ عَلَيْهِ تَعْبُدُ اللَّهَ لاَ تُشْرِكُ بِهِ شَيْئًا وَتُقِيمُ الصَّلاَةَ وَتُؤْتِي الزَّكَاةَ وَتَصُومُ رَمَضَانَ وَتَحُجُّ الْبَيْتَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَلاَ أُدُلُّكَ عَلَى أَبْوَابِ الْجَنَّةِ الصَّوْمُ جُنَّةٌ وَالصَّدَقَةُ تُطْفِئُ الْخَطِيئَةَ كَمَا يُطْفِئُ النَّارَ الْمَاءُ وَصَلاَةُ الرَّجُلِ فِي جَوْفِ اللَّيْلِ ‏"‏ ‏.‏ ثُمَّ قَرَأَ ‏\{تَتَجَافَى جُنُوبُهُمْ عَنِ الْمَضَاجِعِ‏\}‏ حَتَّى بَلَغَ ‏\{جَزَاءً بِمَا كَانُوا يَعْمَلُونَ\}‏ ثُمَّ قَالَ ‏"‏ أَلاَ أُخْبِرُكَ بِرَأْسِ الأَمْرِ وَعَمُودِهِ وَذُرْوَةِ سَنَامِهِ الْجِهَادُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَلاَ أُخْبِرُكَ بِمِلاَكِ ذَلِكَ كُلِّهِ ‏"‏ ‏.‏ قُلْتُ بَلَى ‏.‏ فَأَخَذَ بِلِسَانِهِ فَقَالَ ‏"‏ تَكُفُّ عَلَيْكَ هَذَا ‏"‏ ‏.‏ قُلْتُ يَا نَبِيَّ اللَّهِ وَإِنَّا لَمُؤَاخَذُونَ بِمَا نَتَكَلَّمُ بِهِ قَالَ ‏"‏ ثَكِلَتْكَ أُمُّكَ يَا مُعَاذُ وَهَلْ يَكُبُّ النَّاسَ عَلَى وُجُوهِهِمْ فِي النَّارِ إِلاَّ حَصَائِدُ أَلْسِنَتِهِمْ ‏"‏ ‏.‏\hadithno{3973}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Mu’adh bin Jabal said:“I was with the Messenger of Allah (ﷺ) on a journey. One morning I drew close to him when we were on the move and said: ‘O Messenger of Allah, tell me of an action that will gain me admittance to Paradise and keep me far away from Hell.’ He said: ‘You have asked for something great, but it is easy for the one for whom Allah makes it easy. Worship Allah and do not associate anything in worship with Him, establish prayer, pay charity, fast Ramadan, and perform Hajj to the House.’ Then he said: ‘Shall I not tell you of the means of goodness? Fasting is a shield, and charity extinguishes sin as water extinguishes fire, and a man’s prayer in the middle of the night.’ Then he recited: “Their sides forsake their beds” until he reached: “As a reward for what they used to do.”[32:16-17] Then he said: ‘Shall I not tell you of the head of the matter, and its pillar and pinnacle? (It is) Jihad.’ Then he said: ‘Shall I not tell you of the basis of all that?’ I said: ‘Yes.’ He took hold of his tongue then said: ‘Restrain this.’ I said: ‘O Prophet of Allah, will we be brought to account for what we say?’ He said: ‘May your mother not found you, O Mu’adh! Are people thrown onto their faces in Hell for anything other than the harvest of their tongues?’”}}
\hadithdefcmd{ibnmajah}{3974}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ يَزِيدَ بْنِ خُنَيْسٍ الْمَكِّيُّ، قَالَ سَمِعْتُ سَعِيدَ بْنَ حَسَّانَ الْمَخْزُومِيَّ، قَالَ حَدَّثَتْنِي أُمُّ صَالِحٍ، عَنْ صَفِيَّةَ بِنْتِ شَيْبَةَ، عَنْ أُمِّ حَبِيبَةَ، زَوْجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كَلاَمُ ابْنِ آدَمَ عَلَيْهِ لاَ لَهُ إِلاَّ الأَمْرَ بِالْمَعْرُوفِ وَالنَّهْىَ عَنِ الْمُنْكَرِ وَذِكْرَ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{3974}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Habibah, the wife of the Prophet (ﷺ), that the Prophet (ﷺ) said:“The words of the son of Adam count against him, not for him, except what is good and forbidding what is evil, and remembering Allah.”}}
\hadithdefcmd{ibnmajah}{3975}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا خَالِي، يَعْلَى عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ أَبِي الشَّعْثَاءِ، قَالَ قِيلَ لاِبْنِ عُمَرَ إِنَّا نَدْخُلُ عَلَى أُمَرَائِنَا فَنَقُولُ الْقَوْلَ فَإِذَا خَرَجْنَا قُلْنَا غَيْرَهُ ‏.‏ قَالَ كُنَّا نَعُدُّ ذَلِكَ عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ النِّفَاقَ ‏.‏\hadithno{3975}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Sha’tha said:“It was said to Ibn ‘Umar: ‘We enter upon our rulers and say one thing, and when we leave we say something else.’ He said: ‘At the time of the Messenger of Allah (ﷺ), we used to regard that as hypocrisy.’”}}
\hadithdefcmd{ibnmajah}{3976}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبِ بْنِ شَابُورَ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ قُرَّةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ حَيْوَئِيلَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مِنْ حُسْنِ إِسْلاَمِ الْمَرْءِ تَرْكُهُ مَا لاَ يَعْنِيهِ ‏"‏ ‏.‏\hadithno{3976}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Part of a person’s goodness in Islam is his leaving alone that which does not concern him.”}}
\hadithdefcmd{ibnmajah}{3977}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، أَخْبَرَنِي أَبِي، عَنْ بَعْجَةَ بْنِ عَبْدِ اللَّهِ بْنِ بَدْرٍ الْجُهَنِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ خَيْرُ مَعَايِشِ النَّاسِ لَهُمْ رَجُلٌ مُمْسِكٌ بِعِنَانِ فَرَسِهِ فِي سَبِيلِ اللَّهِ وَيَطِيرُ عَلَى مَتْنِهِ كُلَّمَا سَمِعَ هَيْعَةً أَوْ فَزْعَةً طَارَ عَلَيْهِ إِلَيْهَا يَبْتَغِي الْمَوْتَ أَوِ الْقَتْلَ مَظَانَّهُ وَرَجُلٌ فِي غُنَيْمَةٍ فِي رَأْسِ شَعَفَةٍ مِنْ هَذِهِ الشِّعَافِ أَوْ بَطْنِ وَادٍ مِنْ هَذِهِ الأَوْدِيَةِ يُقِيمُ الصَّلاَةَ وَيُؤْتِي الزَّكَاةَ وَيَعْبُدُ رَبَّهُ حَتَّى يَأْتِيَهُ الْيَقِينُ لَيْسَ مِنَ النَّاسِ إِلاَّ فِي خَيْرٍ ‏"‏ ‏.‏\hadithno{3977}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“The best lifestyle is that of a man who holds onto the reins of his horse for the sake of Allah, riding on its back. Every time he hears a commotion he rushes towards it, seeking death wherever he thinks he can find it; and a man who tends sheep at the top of one of these peaks, or in the bottom of one of these valleys, establishing the prayer, paying the charity, and worshipping his Lord until the inevitable (death) comes to him and there is nothing between him and the people except good.”}}
\hadithdefcmd{ibnmajah}{3978}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنَا الزُّبَيْدِيُّ، حَدَّثَنِي الزُّهْرِيُّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقَالَ أَىُّ النَّاسِ أَفْضَلُ قَالَ ‏"‏ رَجُلٌ مُجَاهِدٌ فِي سَبِيلِ اللَّهِ بِنَفْسِهِ وَمَالِهِ ‏"‏ ‏.‏ قَالَ ثُمَّ مَنْ قَالَ ‏"‏ ثُمَّ امْرُؤٌ فِي شِعْبٍ مِنَ الشِّعَابِ يَعْبُدُ اللَّهَ عَزَّ وَجَلَّ وَيَدَعُ النَّاسَ مِنْ شَرِّهِ ‏"‏ ‏.‏\hadithno{3978}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that a man came to the Prophet (ﷺ) and said:“Which of the people is best?” He said: “A man who strives in Jihad in the cause of Allah with himself and his wealth.” He said: “Then who?” He said: “A man in a mountain pass who worships Allah and leaves the people from his evil.”}}
\hadithdefcmd{ibnmajah}{3979}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ بْنِ جَابِرٍ، حَدَّثَنِي بُسْرُ بْنُ عُبَيْدِ اللَّهِ، حَدَّثَنِي أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ، أَنَّهُ سَمِعَ حُذَيْفَةَ بْنَ الْيَمَانِ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ يَكُونُ دُعَاةٌ عَلَى أَبْوَابِ جَهَنَّمَ مَنْ أَجَابَهُمْ إِلَيْهَا قَذَفُوهُ فِيهَا ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ صِفْهُمْ لَنَا قَالَ ‏"‏ هُمْ قَوْمٌ مِنْ جِلْدَتِنَا يَتَكَلَّمُونَ بِأَلْسِنَتِنَا ‏"‏ ‏.‏ قُلْتُ فَمَا تَأْمُرُنِي إِنْ أَدْرَكَنِي ذَلِكَ قَالَ ‏"‏ فَالْزَمْ جَمَاعَةَ الْمُسْلِمِينَ وَإِمَامَهُمْ فَإِنْ لَمْ يَكُنْ لَهُمْ جَمَاعَةٌ وَلاَ إِمَامٌ فَاعْتَزِلْ تِلْكَ الْفِرَقَ كُلَّهَا وَلَوْ أَنْ تَعَضَّ بِأَصْلِ شَجَرَةٍ حَتَّى يُدْرِكَكَ الْمَوْتُ وَأَنْتَ كَذَلِكَ ‏"‏ ‏.‏\hadithno{3979}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Hudhaifah bin Yaman that the Messenger of Allah (ﷺ) said:“There will be callers at the gates of Hell; whoever responds to them they throw them into it.” I said: “O Messenger of Allah, describe them to us.” He said: “They will be from our people, speaking our language.” I said: “What do you command me to do, if I live to see that?” He said: “Adhere tothe main body of the Muslims and their leader. If there is no such body and no leader, then withdraw from all their groups, even if you bite onto the trunk of a tree until death finds you in that state.”}}
\hadithdefcmd{ibnmajah}{3980}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ الأَنْصَارِيِّ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يُوشِكُ أَنْ يَكُونَ خَيْرَ مَالِ الْمُسْلِمِ غَنَمٌ يَتْبَعُ بِهَا شَعَفَ الْجِبَالِ وَمَوَاقِعَ الْقَطْرِ يَفِرُّ بِدِينِهِ مِنَ الْفِتَنِ ‏"‏ ‏.‏\hadithno{3980}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Messenger of Allah (ﷺ) said:“Soon the best wealth of a Muslim will be sheep which he follows in the mountain peaks and places where rainfall is to be found, fleeing for the sake of his religion from tribulations.”}}
\hadithdefcmd{ibnmajah}{3981}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ عَلِيٍّ الْمُقَدَّمِيُّ، حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ، حَدَّثَنَا أَبُو عَامِرٍ الْخَزَّازُ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ قُرْطٍ، عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَكُونُ فِتَنٌ عَلَى أَبْوَابِهَا دُعَاةٌ إِلَى النَّارِ فَأَنْ تَمُوتَ وَأَنْتَ عَاضٌّ عَلَى جِذْلِ شَجَرَةٍ خَيْرٌ لَكَ مِنْ أَنْ تَتْبَعَ أَحَدًا مِنْهُمْ ‏"‏ ‏.‏\hadithno{3981}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Hudhaifah bin Yaman that the Messenger of Allah (ﷺ) said:“There will be tribulations at the gates of which will be callers (calling people) to Hell. Dying when you are biting onto the stump of a tree will be better for you than following anyone of them.”}}
\hadithdefcmd{ibnmajah}{3982}{حَدَّثَنَا مُحَمَّدُ بْنُ الْحَارِثِ الْمِصْرِيُّ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، حَدَّثَنِي عُقَيْلٌ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يُلْدَغُ الْمُؤْمِنُ مِنْ جُحْرٍ مَرَّتَيْنِ ‏"‏ ‏.‏\hadithno{3982}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah said that the Messenger of Allah (ﷺ) said:“The believer should not be stung from the same hole twice.”}}
\hadithdefcmd{ibnmajah}{3983}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا زَمْعَةُ بْنُ صَالِحٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يُلْدَغُ الْمُؤْمِنُ مِنْ جُحْرٍ مَرَّتَيْنِ ‏"‏ ‏.‏\hadithno{3983}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:‘The believer should not be stung from the same hole twice.’”}}
\hadithdefcmd{ibnmajah}{3984}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، عَنِ الشَّعْبِيِّ، قَالَ سَمِعْتُ النُّعْمَانَ بْنَ بَشِيرٍ، يَقُولُ عَلَى الْمِنْبَرِ وَأَهْوَى بِإِصْبَعَيْهِ إِلَى أُذُنَيْهِ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الْحَلاَلُ بَيِّنٌ وَالْحَرَامُ بَيِّنٌ وَبَيْنَهُمَا مُشْتَبِهَاتٌ لاَ يَعْلَمُهَا كَثِيرٌ مِنَ النَّاسِ فَمَنِ اتَّقَى الشُّبُهَاتِ اسْتَبْرَأَ لِدِينِهِ وَعِرْضِهِ وَمَنْ وَقَعَ فِي الشُّبُهَاتِ وَقَعَ فِي الْحَرَامِ كَالرَّاعِي حَوْلَ الْحِمَى يُوشِكُ أَنْ يَرْتَعَ فِيهِ أَلاَ وَإِنَّ لِكُلِّ مَلِكٍ حِمًى أَلاَ وَإِنَّ حِمَى اللَّهِ مَحَارِمُهُ أَلاَ وَإِنَّ فِي الْجَسَدِ مُضْغَةً إِذَا صَلُحَتْ صَلُحَ الْجَسَدُ كُلُّهُ وَإِذَا فَسَدَتْ فَسَدَ الْجَسَدُ كُلُّهُ أَلاَ وَهِيَ الْقَلْبُ ‏"‏ ‏.‏\hadithno{3984}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{While on the pulpit, pointing with this fingers towards his ears, Nu’man bin Bashir said:“I heard the Messenger of Allah (ﷺ) say: ‘That which is lawful is plain and that which is unlawful is plain, and between them are matters that are not clear, about which not many people know. Thus he who guards against the unclear matters, he clears himself with regard to his religion and his honor. But he who falls into the unclear matters, he falls into that which is unlawful. Like the shepherd who pastures around a sanctuary, all but grazing therein. Every king has a sanctuary. And beware! Allah’s sanctuary is His prohibitions. Beware! In the body there is a piece of flesh which, if it is sound, the whole body will be sound, and if it is corrupt, the whole body will be corrupt. It is the heart.’”}}
\hadithdefcmd{ibnmajah}{3985}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنِ الْمُعَلَّى بْنِ زِيَادٍ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ مَعْقِلِ بْنِ يَسَارٍ، قَالَ قَالَ رَسُولُ ـ صلى الله عليه وسلم ـ ‏ "‏ الْعِبَادَةُ فِي الْهَرْجِ كَهِجْرَةٍ إِلَىَّ ‏"‏ ‏.‏\hadithno{3985}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ma’qil bin Yasar that the Messenger of Allah (ﷺ) said:“Worship during the time of bloodshed is like emigrating to me.”}}
\hadithdefcmd{ibnmajah}{3986}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، وَيَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، وَسُوَيْدُ بْنُ سَعِيدٍ، قَالُوا حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، حَدَّثَنَا يَزِيدُ بْنُ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ بَدَأَ الإِسْلاَمُ غَرِيبًا وَسَيَعُودُ غَرِيبًا فَطُوبَى لِلْغُرَبَاءِ ‏"‏ ‏.‏\hadithno{3986}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Islam began as something strange and will go back to being strange, so glad tidings to the strangers.’”}}
\hadithdefcmd{ibnmajah}{3987}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا عَمْرُو بْنُ الْحَارِثِ، وَابْنُ، لَهِيعَةَ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سِنَانِ بْنِ سَعْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ الإِسْلاَمَ بَدَأَ غَرِيبًا وَسَيَعُودُ غَرِيبًا فَطُوبَى لِلْغُرَبَاءِ ‏"‏ ‏.‏\hadithno{3987}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“Islam began as something strange and will go back to being strange, so glad tidings to the strangers.”}}
\hadithdefcmd{ibnmajah}{3988}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ الإِسْلاَمَ بَدَأَ غَرِيبًا وَسَيَعُودُ غَرِيبًا فَطُوبَى لِلْغُرَبَاءِ ‏"‏ ‏.‏ قَالَ قِيلَ وَمَنِ الْغُرَبَاءُ قَالَ النُّزَّاعُ مِنَ الْقَبَائِلِ ‏.‏\hadithno{3988}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah that the Messenger of Allah (ﷺ) said:“Islam began as something strange and will go back to being strange, so glad tidings to the strangers.” It was said: “Who are the strangers?’ He said: “Strangers who have left their families and tribes.”}}
\hadithdefcmd{ibnmajah}{3989}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ لَهِيعَةَ، عَنْ عِيسَى بْنِ عَبْدِ الرَّحْمَنِ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، أَنَّهُ خَرَجَ يَوْمًا إِلَى مَسْجِدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَوَجَدَ مُعَاذَ بْنَ جَبَلٍ قَاعِدًا عِنْدَ قَبْرِ النَّبِيِّ ـ صلى الله عليه وسلم ـ يَبْكِي فَقَالَ مَا يُبْكِيكَ قَالَ يُبْكِينِي شَىْءٌ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّ يَسِيرَ الرِّيَاءِ شِرْكٌ وَإِنَّ مَنْ عَادَى لِلَّهِ وَلِيًّا فَقَدْ بَارَزَ اللَّهَ بِالْمُحَارَبَةِ إِنَّ اللَّهَ يُحِبُّ الأَبْرَارَ الأَتْقِيَاءَ الأَخْفِيَاءَ الَّذِينَ إِذَا غَابُوا لَمْ يُفْتَقَدُوا وَإِنْ حَضَرُوا لَمْ يُدْعَوْا وَلَمْ يُعْرَفُوا قُلُوبُهُمْ مَصَابِيحُ الْهُدَى يَخْرُجُونَ مِنْ كُلِّ غَبْرَاءَ مُظْلِمَةٍ ‏"‏ ‏.‏\hadithno{3989}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Umar bin Khattab that he went out one day to the mosque of the Messenger of Allah (ﷺ), and he found Mu’adh bin Jabal sitting by the grave of the Prophet (ﷺ), weeping. He said:“Why are you weeping?” He said: “I am weeping because of something that I heard from the Messenger of Allah (ﷺ). I heard the Messenger of Allah (ﷺ) say: ‘A little showing off is polytheism and whoever shows enmity towards a friend of Allah has declared war on Allah. Allah loves those who se righteousness and piety are hidden, those who, if they are absent, are not missed, and if they are present, they are not invited or acknowledged. Their hearts are lamps of guidance and they get out of every trial and difficulty.’”}}
\hadithdefcmd{ibnmajah}{3990}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، حَدَّثَنَا زَيْدُ بْنُ أَسْلَمَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ النَّاسُ كَإِبِلِ مِائَةٍ لاَ تَكَادُ تَجِدُ فِيهَا رَاحِلَةً ‏"‏ ‏.‏\hadithno{3990}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah bin ‘Umar that the Messenger of Allah (ﷺ) said:“People are like a hundred camels; you can hardly find one worth riding among them.”}}
\hadithdefcmd{ibnmajah}{3991}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَفَرَّقَتِ الْيَهُودُ عَلَى إِحْدَى وَسَبْعِينَ فِرْقَةً وَتَفْتَرِقُ أُمَّتِي عَلَى ثَلاَثٍ وَسَبْعِينَ فِرْقَةً ‏"‏ ‏.‏\hadithno{3991}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The Jews split into seventy-one sects and my nation will split into seventy-three sects.”}}
\hadithdefcmd{ibnmajah}{3992}{حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ بْنِ سَعِيدِ بْنِ كَثِيرِ بْنِ دِينَارٍ الْحِمْصِيُّ، حَدَّثَنَا عَبَّادُ بْنُ يُوسُفَ، حَدَّثَنَا صَفْوَانُ بْنُ عَمْرٍو، عَنْ رَاشِدِ بْنِ سَعْدٍ، عَنْ عَوْفِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ افْتَرَقَتِ الْيَهُودُ عَلَى إِحْدَى وَسَبْعِينَ فِرْقَةً فَوَاحِدَةٌ فِي الْجَنَّةِ وَسَبْعُونَ فِي النَّارِ وَافْتَرَقَتِ النَّصَارَى عَلَى ثِنْتَيْنِ وَسَبْعِينَ فِرْقَةً فَإِحْدَى وَسَبْعُونَ فِي النَّارِ وَوَاحِدَةٌ فِي الْجَنَّةِ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَتَفْتَرِقَنَّ أُمَّتِي عَلَى ثَلاَثٍ وَسَبْعِينَ فِرْقَةً فَوَاحِدَةٌ فِي الْجَنَّةِ وَثِنْتَانِ وَسَبْعُونَ فِي النَّارِ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ مَنْ هُمْ قَالَ ‏"‏ الْجَمَاعَةُ ‏"‏ ‏.‏\hadithno{3992}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Awf bin Malik that the Messenger of Allah(ﷺ) said:“The Jews split into seventy-one sects, one of which will be in Paradise and seventy in Hell. The Christians split into seventy-two sects, seventy-one of which will be in Hell and one in Paradise. I swear by the One Whose Hand is the soul of Muhammad, my nation will split into seventy-three sects, one of which will be in Paradise and seventy-two in Hell.” It was said: “O Messenger of Allah, who are they?” He said: “The main body.”}}
\hadithdefcmd{ibnmajah}{3993}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا أَبُو عَمْرٍو، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ بَنِي إِسْرَائِيلَ افْتَرَقَتْ عَلَى إِحْدَى وَسَبْعِينَ فِرْقَةً وَإِنَّ أُمَّتِي سَتَفْتَرِقُ عَلَى ثِنْتَيْنِ وَسَبْعِينَ فِرْقَةً كُلُّهَا فِي النَّارِ إِلاَّ وَاحِدَةً وَهِيَ الْجَمَاعَةُ ‏"‏ ‏.‏\hadithno{3993}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:‘The Children of Israel split into seventy-one sects, and my nation will split into seventy-two, all of which will be in Hell apart from one, which is the main body.”}}
\hadithdefcmd{ibnmajah}{3994}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لَتَتَّبِعُنَّ سُنَّةَ مَنْ كَانَ قَبْلَكُمْ بَاعًا بِبَاعٍ وَذِرَاعًا بِذِرَاعٍ وَشِبْرًا بِشِبْرٍ حَتَّى لَوْ دَخَلُوا فِي جُحْرِ ضَبٍّ لَدَخَلْتُمْ فِيهِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ الْيَهُودُ وَالنَّصَارَى قَالَ ‏"‏ فَمَنْ إِذًا ‏"‏ ‏.‏\hadithno{3994}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“You will most certainly follow the ways of those who came before you, arm’s length by arm’s length, forearm’s length by forearm’s length, hand span by hand span, until even if they entered a hole of a mastigure (lizard) you will enter it too.” They said: “O Messenger of Allah, (do you mean) the Jews and the Christians?” He said: “Who else?”}}
\hadithdefcmd{ibnmajah}{3995}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ قَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَخَطَبَ فَقَالَ ‏"‏ لاَ وَاللَّهِ مَا أَخْشَى عَلَيْكُمْ أَيُّهَا النَّاسُ إِلاَّ مَا يُخْرِجُ اللَّهُ لَكُمْ مِنْ زَهْرَةِ الدُّنْيَا ‏"‏ ‏.‏ فَقَالَ لَهُ رَجُلٌ يَا رَسُولَ اللَّهِ أَيَأْتِي الْخَيْرُ بِالشَّرِّ فَصَمَتَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ سَاعَةً ثُمَّ قَالَ ‏"‏ كَيْفَ قُلْتَ ‏"‏ ‏.‏ قَالَ قُلْتُ وَهَلْ يَأْتِي الْخَيْرُ بِالشَّرِّ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ الْخَيْرَ لاَ يَأْتِي إِلاَّ بِخَيْرٍ أَوَخَيْرٌ هُوَ إِنَّ كُلَّ مَا يُنْبِتُ الرَّبِيعُ يَقْتُلُ حَبَطًا أَوْ يُلِمُّ إِلاَّ آكِلَةَ الْخَضِرِ أَكَلَتْ حَتَّى إِذَا امْتَلأَتْ خَاصِرَتَاهَا اسْتَقْبَلَتِ الشَّمْسَ فَثَلَطَتْ وَبَالَتْ ثُمَّ اجْتَرَّتْ فَعَادَتْ فَأَكَلَتْ فَمَنْ يَأْخُذُ مَالاً بِحَقِّهِ يُبَارَكُ لَهُ وَمَنْ يَأْخُذُ مَالاً بِغَيْرِ حَقِّهِ فَمَثَلُهُ كَمَثَلِ الَّذِي يَأْكُلُ وَلاَ يَشْبَعُ ‏"‏ ‏.‏\hadithno{3995}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Sa’eed Al-Khudri said:“The Messenger of Allah (ﷺ) stood up and addressed the people saying: ‘No, by Allah, I do not fear for you, O people, but I fear the attractions of this world that Allah brings forth for you.’ A man said to him: ‘O Messenger of Allah(ﷺ), does good bring forth evil?’ The Messenger of Allah (ﷺ) remained silent for a while, then he said: ‘What did you say?’ He said: ‘I said, does good bring forth evil?’ The Messenger of Allah (ﷺ) said: ‘Good does not bring forth anything but good, but is it really good? Everything that grows on the banks of a stream may either kill if overeaten or (at least) make the animals sick, except if an animal eats its fill of Khadir* and then faces the sun, and then defecates and urinates, chews the cud and then returns to graze again. Whoever takes wealth in a lawful manner, it will be blessed for him, but whoever takes it in an unlawful manner, his likeness is that of one who eats and it never satisfied.’”}}
\hadithdefcmd{ibnmajah}{3996}{حَدَّثَنَا عَمْرُو بْنُ سَوَّادٍ الْمِصْرِيُّ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا عَمْرُو بْنُ الْحَارِثِ، أَنَّ بَكْرَ بْنَ سَوَادَةَ، حَدَّثَهُ أَنَّ يَزِيدَ بْنَ رَبَاحٍ حَدَّثَهُ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏"‏ إِذَا فُتِحَتْ عَلَيْكُمْ خَزَائِنُ فَارِسَ وَالرُّومِ أَىُّ قَوْمٍ أَنْتُمْ ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ نَقُولُ كَمَا أَمَرَنَا اللَّهُ ‏.‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَوْ غَيْرَ ذَلِكَ تَتَنَافَسُونَ ثُمَّ تَتَحَاسَدُونَ ثُمَّ تَتَدَابَرُونَ ثُمَّ تَتَبَاغَضُونَ أَوْ نَحْوَ ذَلِكَ ثُمَّ تَنْطَلِقُونَ فِي مَسَاكِينِ الْمُهَاجِرِينَ فَتَجْعَلُونَ بَعْضَهُمْ عَلَى رِقَابِ بَعْضٍ ‏"‏ ‏.‏\hadithno{3996}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr bin ‘As that the Messenger of Allah (ﷺ) said:“When the treasures of Persia and Rome are opened for you, what kind of people will you be?” ‘Abdur-Rahman bin ‘Awf said: “We will say what Allah has commanded us to say.” The Messenger of Allah (ﷺ) said: “Or something other than that. You will compete with one another, then you will envy one another, then you will turn your backs on one another, then you will hate one another, or something like that. Then you will go to the poor among the Muhajirun and appoint some of them as leaders of others.”}}
\hadithdefcmd{ibnmajah}{3997}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى الْمِصْرِيُّ، أَخْبَرَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، ‏.‏ أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَهُ عَنْ عَمْرِو بْنِ عَوْفٍ، - وَهُوَ حَلِيفُ بَنِي عَامِرِ بْنِ لُؤَىٍّ وَكَانَ شَهِدَ بَدْرًا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ - أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ بَعَثَ أَبَا عُبَيْدَةَ بْنَ الْجَرَّاحِ إِلَى الْبَحْرَيْنِ يَأْتِي بِجِزْيَتِهَا وَكَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ هُوَ صَالَحَ أَهْلَ الْبَحْرَيْنِ وَأَمَّرَ عَلَيْهِمُ الْعَلاَءَ بْنَ الْحَضْرَمِيِّ فَقَدِمَ أَبُو عُبَيْدَةَ بِمَالٍ مِنَ الْبَحْرَيْنِ فَسَمِعَتِ الأَنْصَارُ بِقُدُومِ أَبِي عُبَيْدَةَ فَوَافَوْا صَلاَةَ الْفَجْرِ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَلَمَّا صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ انْصَرَفَ فَتَعَرَّضُوا لَهُ فَتَبَسَّمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ حِينَ رَآهُمْ ثُمَّ قَالَ ‏"‏ أَظُنُّكُمْ سَمِعْتُمْ أَنَّ أَبَا عُبَيْدَةَ قَدِمَ بِشَىْءٍ مِنَ الْبَحْرَيْنِ ‏"‏ ‏.‏ قَالُوا أَجَلْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ أَبْشِرُوا وَأَمِّلُوا مَا يَسُرُّكُمْ فَوَاللَّهِ مَا الْفَقْرَ أَخْشَى عَلَيْكُمْ وَلَكِنِّي أَخْشَى عَلَيْكُمْ أَنْ تُبْسَطَ الدُّنْيَا عَلَيْكُمْ كَمَا بُسِطَتْ عَلَى مَنْ كَانَ قَبْلَكُمْ فَتَنَافَسُوهَا كَمَا تَنَافَسُوهَا فَتُهْلِكَكُمْ كَمَا أَهْلَكَتْهُمْ ‏"‏ ‏.‏\hadithno{3997}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Amr bin ‘Awf, who was an ally of Banu ‘Amir bin Lu’ai and was present at (the battle of) Badr with the Messenger of Allah (ﷺ), that the Messenger of Allah (ﷺ) sent ‘Ubaidah bin Jarrah to Bahrain to collect the Jizyah, and the Prophet (ﷺ) had made a treaty with the people of Bahrain, and he appointed as their governor ‘Ala’ bin Hadrami. Abu ‘Ubaidan came with the wealth from Bahrain and the Ansar heard that Abu ‘Ubaidah had come, so they attended the Fajr prayer with the Messenger of Allah (ﷺ). When the Messenger of Allah (ﷺ) had prayed, he went away, so they intercepted him. The Messenger of Allah (ﷺ) smiled when he saw them, then he said:‘I think you have heard that Abu ‘Ubaidah has brought something from Bahrain?’ They said: ‘Yes, O Messenger of Allah.’ He said: ‘Be of good cheer and hope for that which will make you happy. By Allah, I do not fear poverty for you, rather I fear that you will enjoy ease and plenty like those who came before you, and that you will compete with one another as they did, and you will be destroyed as they were.’”}}
\hadithdefcmd{ibnmajah}{3998}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، ح وَحَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا أَدَعُ بَعْدِي فِتْنَةً أَضَرَّ عَلَى الرِّجَالِ مِنَ النِّسَاءِ ‏"‏ ‏.‏\hadithno{3998}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Usamah bin Zaid that the Messenger of Allah (ﷺ) said:“I am not leaving behind me any tribulation that is more harmful to men than women.”}}
\hadithdefcmd{ibnmajah}{3999}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ خَارِجَةَ بْنِ مُصْعَبٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ صَبَاحٍ إِلاَّ وَمَلَكَانِ يُنَادِيَانِ وَيْلٌ لِلرِّجَالِ مِنَ النِّسَاءِ وَوَيْلٌ لِلنِّسَاءِ مِنَ الرِّجَالِ ‏"‏ ‏.‏\hadithno{3999}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa’eed that the Messenger of Allah (ﷺ) said:“No morning comes but two angels call out: ‘Woe to men from women, and woe to women from men.’”}}
\hadithdefcmd{ibnmajah}{4000}{حَدَّثَنَا عِمْرَانُ بْنُ مُوسَى اللَّيْثِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا عَلِيُّ بْنُ زَيْدِ بْنِ جُدْعَانَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَامَ خَطِيبًا فَكَانَ فِيمَا قَالَ ‏ "‏ إِنَّ الدُّنْيَا خَضِرَةٌ حُلْوَةٌ وَإِنَّ اللَّهَ مُسْتَخْلِفُكُمْ فِيهَا فَنَاظِرٌ كَيْفَ تَعْمَلُونَ أَلاَ فَاتَّقُوا الدُّنْيَا وَاتَّقُوا النِّسَاءَ ‏"‏ ‏.‏\hadithno{4000}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa’eed that the Messenger of Allah (ﷺ) stood up to deliver a sermon and one of the things that he said was:“This world is fresh and sweet, and Allah will make your successive generations therein, so look at what you do and beware of (the temptations of) this world and beware of (the temptations of) women.”}}
\hadithdefcmd{ibnmajah}{4001}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ مُوسَى بْنِ عُبَيْدَةَ، عَنْ دَاوُدَ بْنِ مُدْرِكٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ بَيْنَمَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ جَالِسٌ فِي الْمَسْجِدِ إِذْ دَخَلَتِ امْرَأَةٌ مِنْ مُزَيْنَةَ تَرْفُلُ فِي زِينَةٍ لَهَا فِي الْمَسْجِدِ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ يَا أَيُّهَا النَّاسُ انْهَوْا نِسَاءَكُمْ عَنْ لُبْسِ الزِّينَةِ وَالتَّبَخْتُرِ فِي الْمَسْجِدِ فَإِنَّ بَنِي إِسْرَائِيلَ لَمْ يُلْعَنُوا حَتَّى لَبِسَ نِسَاؤُهُمُ الزِّينَةَ وَتَبَخْتَرْنَ فِي الْمَسَاجِدِ ‏"‏ ‏.‏\hadithno{4001}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“While the Messenger of Allah (ﷺ) was sitting in the mosque, a woman from Muzainah (tribe) entered, trailing her garment in the mosque. The Prophet (ﷺ) said: ‘O people, tell your women not to wear their adornments and show pride in the mosque, for the Children of Israel were not cursed until their women wore adornments and walked proudly in their places of worship.’”}}
\hadithdefcmd{ibnmajah}{4002}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَاصِمٍ، عَنْ مَوْلَى أَبِي رُهْمٍ، - وَاسْمُهُ عُبَيْدٌ - أَنَّ أَبَا هُرَيْرَةَ، لَقِيَ امْرَأَةً مُتَطَيِّبَةً تُرِيدُ الْمَسْجِدَ فَقَالَ يَا أَمَةَ الْجَبَّارِ أَيْنَ تُرِيدِينَ قَالَتِ الْمَسْجِدَ قَالَ وَلَهُ تَطَيَّبْتِ قَالَتْ نَعَمْ ‏.‏ قَالَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ أَيُّمَا امْرَأَةٍ تَطَيَّبَتْ ثُمَّ خَرَجَتْ إِلَى الْمَسْجِدِ لَمْ تُقْبَلْ لَهَا صَلاَةٌ حَتَّى تَغْتَسِلَ ‏"‏ ‏.‏\hadithno{4002}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah met a woman who was wearing perfume and heading for the mosque. He said:“O slavewoman of the Compeller, where are you headed?” She said: “To the mosque.” He said: “And have you put on perfume for that?” She said: “Yes.” He said: “I heard the Messenger of Allah (ﷺ) say: ‘Any woman who puts on perfume then goes out to the mosque, no prayer will be accepted from her until she takes a bath.’”}}
\hadithdefcmd{ibnmajah}{4003}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏"‏ يَا مَعْشَرَ النِّسَاءِ تَصَدَّقْنَ وَأَكْثِرْنَ مِنَ الاِسْتِغْفَارِ فَإِنِّي رَأَيْتُكُنَّ أَكْثَرَ أَهْلِ النَّارِ ‏"‏ ‏.‏ فَقَالَتِ امْرَأَةٌ مِنْهُنَّ جَزْلَةٌ وَمَا لَنَا يَا رَسُولَ اللَّهِ أَكْثَرَ أَهْلِ النَّارِ قَالَ ‏"‏ تُكْثِرْنَ اللَّعْنَ وَتَكْفُرْنَ الْعَشِيرَ مَا رَأَيْتُ مِنْ نَاقِصَاتِ عَقْلٍ وَدِينٍ أَغْلَبَ لِذِي لُبٍّ مِنْكُنَّ ‏"‏ ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ وَمَا نُقْصَانُ الْعَقْلِ وَالدِّينِ قَالَ ‏"‏ أَمَّا نُقْصَانُ الْعَقْلِ فَشَهَادَةُ امْرَأَتَيْنِ تَعْدِلُ شَهَادَةَ رَجُلٍ فَهَذَا مِنْ نُقْصَانِ الْعَقْلِ وَتَمْكُثُ اللَّيَالِيَ مَا تُصَلِّي وَتُفْطِرُ فِي رَمَضَانَ فَهَذَا مِنْ نُقْصَانِ الدِّينِ ‏"‏ ‏.‏\hadithno{4003}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Abdullah bin ‘Umar that the Messenger of Allah (ﷺ) said:“O women, give in charity and pray a great deal for forgiveness, for I have seen that you form the majority of the people of Hell.” A woman who was very wise said: “Why is it, O Messenger of Allah, that we form the majority of the people of Hell?” He said: “You curse a great deal and you are ungrateful to your husbands, and I have never seen anyone lacking in discernment and religion more overwhelming to a man of wisdom than you.” She said: “O Messenger of Allah, what is this lacking in discernment and religion?” He said: “The lack of discernment is the fact that the testimony of two women is equal to the testimony of one man; this is the lack of reason. And (a woman) spends several nights when she does not pray, and she does not fast in Ramadhan, and this is the lack in religion.”}}
\hadithdefcmd{ibnmajah}{4004}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ هِشَامِ بْنِ سَعْدٍ، عَنْ عَمْرِو بْنِ عُثْمَانَ، عَنْ عَاصِمِ بْنِ عُمَرَ بْنِ عُثْمَانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مُرُوا بِالْمَعْرُوفِ وَانْهَوْا عَنِ الْمُنْكَرِ قَبْلَ أَنْ تَدْعُوا فَلاَ يُسْتَجَابَ لَكُمْ ‏"‏ ‏.‏\hadithno{4004}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“I heard the Messenger of Allah (ﷺ) say: ‘enjoin what is good and forbid what is evil, before you call and you are not answered.’”}}
\hadithdefcmd{ibnmajah}{4005}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، قَالَ قَامَ أَبُو بَكْرٍ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ يَا أَيُّهَا النَّاسُ إِنَّكُمْ تَقْرَءُونَ هَذِهِ الآيَةَ ‏\{يَا أَيُّهَا الَّذِينَ آمَنُوا عَلَيْكُمْ أَنْفُسَكُمْ لاَ يَضُرُّكُمْ مَنْ ضَلَّ إِذَا اهْتَدَيْتُمْ\}‏ وَإِنَّا سَمِعْنَا رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ إِنَّ النَّاسَ إِذَا رَأَوُا الْمُنْكَرَ لاَ يُغَيِّرُونَهُ أَوْشَكَ أَنْ يَعُمَّهُمُ اللَّهُ بِعِقَابِهِ ‏"‏ ‏.‏ قَالَ أَبُو أُسَامَةَ مَرَّةً أُخْرَى فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏.‏\hadithno{4005}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Qais bin Abu Hazim said:“Abu Bakr stood up and praised and glorified Allah, then he said: ‘O people, you recite this Verse – “O you who believe! Take care of your own selves. If you follow the (right) guidance no hurt can come to you from those who are in error.”[5:105] – but I heard the Messenger of Allah (ﷺ) say: ‘If people see some evil but do not change it, soon Allah will send His punishment upon them all.’” (One of the narrators) Abu Usamah repeated: "Indeed I heard that Messenger of Allah (ﷺ) say}}
\hadithdefcmd{ibnmajah}{4006}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَلِيِّ بْنِ بَذِيمَةَ، عَنْ أَبِي عُبَيْدَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ بَنِي إِسْرَائِيلَ لَمَّا وَقَعَ فِيهِمُ النَّقْصُ كَانَ الرَّجُلُ يَرَى أَخَاهُ عَلَى الذَّنْبِ فَيَنْهَاهُ عَنْهُ فَإِذَا كَانَ الْغَدُ لَمْ يَمْنَعْهُ مَا رَأَى مِنْهُ أَنْ يَكُونَ أَكِيلَهُ وَشَرِيبَهُ وَخَلِيطَهُ فَضَرَبَ اللَّهُ قُلُوبَ بَعْضِهِمْ بِبَعْضٍ وَنَزَلَ فِيهِمُ الْقُرْآنُ فَقَالَ ‏\{لُعِنَ الَّذِينَ كَفَرُوا مِنْ بَنِي إِسْرَائِيلَ عَلَى لِسَانِ دَاوُدَ وَعِيسَى ابْنِ مَرْيَمَ\}‏ حَتَّى بَلَغَ ‏\{وَلَوْ كَانُوا يُؤْمِنُونَ بِاللَّهِ وَالنَّبِيِّ وَمَا أُنْزِلَ إِلَيْهِ مَا اتَّخَذُوهُمْ أَوْلِيَاءَ وَلَكِنَّ كَثِيرًا مِنْهُمْ فَاسِقُونَ \}‏ ‏"‏ ‏.‏ قَالَ وَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مُتَّكِئًا فَجَلَسَ وَقَالَ ‏"‏ لاَ حَتَّى تَأْخُذُوا عَلَى يَدَىِ الظَّالِمِ فَتَأْطِرُوهُ عَلَى الْحَقِّ أَطْرًا ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو دَاوُدَ، - أَمْلاَهُ عَلَىَّ - حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي الْوَضَّاحِ، عَنْ عَلِيِّ بْنِ بَذِيمَةَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِمِثْلِهِ ‏.‏\hadithno{4006}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu ‘Ubaidah that the Messenger of Allah (ﷺ) said:“When the Children of Isral became deficient in religious commitment, a man would see his brother committing sin and would tell him not to do it, but the next day, what he had seen him do did not prevent him from eating or drinking with him, or mixing with him. So Allah made the hearts of those who did not commit sin like the hearts of those who did, and He revealed Qur’an concerning them and said: “Those among the Children of Israel who disbelieved were cursed by the tongue of David and ‘Eisa, son of Maryam” until he reached: “And had they believed in Allah, and in the Prophet and in what has been revealed to him, never would they have taken them (the disbelievers) as their friends; but many of them are disobedient (to Allah).”[5:78-81] The Messenger of Allah (ﷺ) sat up and said: "No, not until they take the hand of the wrongdoer (i.e. restrain him] and force him to follow the right way}}
\hadithdefcmd{ibnmajah}{4007}{حَدَّثَنَا عِمْرَانُ بْنُ مُوسَى، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا عَلِيُّ بْنُ زَيْدِ بْنِ جُدْعَانَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَامَ خَطِيبًا فَكَانَ فِيمَا قَالَ ‏ "‏ أَلاَ لاَ يَمْنَعَنَّ رَجُلاً هَيْبَةُ النَّاسِ أَنْ يَقُولَ بِحَقٍّ إِذَا عَلِمَهُ ‏"‏ ‏.‏ قَالَ فَبَكَى أَبُو سَعِيدٍ وَقَالَ قَدْ وَاللَّهِ رَأَيْنَا أَشْيَاءَ فَهِبْنَا ‏.‏\hadithno{4007}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Messenger of Allah (ﷺ) stood up to deliver a sermon, and one of the things he said was:“Indeed, fear of people should not prevent a man from speaking the truth, if he knows it.” Then Abu Sa'eed wept and said: "By Allah, we have seen things that made us scared (and we did not speak up)}}
\hadithdefcmd{ibnmajah}{4008}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ أَبِي الْبَخْتَرِيِّ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لاَ يَحْقِرْ أَحَدُكُمْ نَفْسَهُ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ كَيْفَ يَحْقِرُ أَحَدُنَا نَفْسَهُ قَالَ ‏"‏ يَرَى أَمْرًا لِلَّهِ عَلَيْهِ فِيهِ مَقَالٌ ثُمَّ لاَ يَقُولُ فِيهِ فَيَقُولُ اللَّهُ عَزَّ وَجَلَّ لَهُ يَوْمَ الْقِيَامَةِ مَا مَنَعَكَ أَنْ تَقُولَ فِي كَذَا وَكَذَا فَيَقُولُ خَشْيَةُ النَّاسِ ‏.‏ فَيَقُولُ فَإِيَّاىَ كُنْتَ أَحَقَّ أَنْ تَخْشَى ‏"‏ ‏.‏\hadithno{4008}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa’eed that the Messenger of Allah (ﷺ) said:“No one of you should belittle himself.” They said: “O Messenger of Allah, how could anyone of us belittle himself?” He said: “If he sees something concerning which he should speak out for the sake of Allah but does not say anything. Allah will say to him on the Day of Resurrection: “What prevented you from speaking concerning such and such?” He will say: “Fear of the people.” (Allah) will say: “Rather you should have feared Me.”}}
\hadithdefcmd{ibnmajah}{4009}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عُبَيْدِ اللَّهِ بْنِ جَرِيرٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَا مِنْ قَوْمٍ يُعْمَلُ فِيهِمْ بِالْمَعَاصِي هُمْ أَعَزُّ مِنْهُمْ وَأَمْنَعُ لاَ يُغَيِّرُونَ إِلاَّ عَمَّهُمُ اللَّهُ بِعِقَابٍ ‏"‏ ‏.‏\hadithno{4009}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Ubaidullah bin Jarir that his father said:“The Messenger of Allah (ﷺ) said: ‘There is no people among whom sins are committed when they are stronger and of a higher status (i.e. they have the power and ability to stop the sinners) and they do not change them, but Allah will send His punishment upon them all.’”}}
\hadithdefcmd{ibnmajah}{4010}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ لَمَّا رَجَعَتْ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مُهَاجِرَةُ الْبَحْرِ قَالَ ‏"‏ أَلاَ تُحَدِّثُونِي بِأَعَاجِيبِ مَا رَأَيْتُمْ بِأَرْضِ الْحَبَشَةِ ‏"‏ ‏.‏ قَالَ فِتْيَةٌ مِنْهُمْ بَلَى يَا رَسُولَ اللَّهِ بَيْنَا نَحْنُ جُلُوسٌ مَرَّتْ بِنَا عَجُوزٌ مِنْ عَجَائِزِ رَهَابِينِهِمْ تَحْمِلُ عَلَى رَأْسِهَا قُلَّةً مِنْ مَاءٍ فَمَرَّتْ بِفَتًى مِنْهُمْ فَجَعَلَ إِحْدَى يَدَيْهِ بَيْنَ كَتِفَيْهَا ثُمَّ دَفَعَهَا فَخَرَّتْ عَلَى رُكْبَتَيْهَا فَانْكَسَرَتْ قُلَّتُهَا فَلَمَّا ارْتَفَعَتِ الْتَفَتَتْ إِلَيْهِ فَقَالَتْ سَوْفَ تَعْلَمُ يَا غُدَرُ إِذَا وَضَعَ اللَّهُ الْكُرْسِيَّ وَجَمَعَ الأَوَّلِينَ وَالآخِرِينَ وَتَكَلَّمَتِ الأَيْدِي وَالأَرْجُلُ بِمَا كَانُوا يَكْسِبُونَ فَسَوْفَ تَعْلَمُ كَيْفَ أَمْرِي وَأَمْرُكَ عِنْدَهُ غَدًا ‏.‏ قَالَ يَقُولُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ صَدَقَتْ صَدَقَتْ كَيْفَ يُقَدِّسُ اللَّهُ أُمَّةً لاَ يُؤْخَذُ لِضَعِيفِهِمْ مِنْ شَدِيدِهِمْ ‏"‏ ‏.‏\hadithno{4010}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:“When the emigrants who had crossed the sea came back to the Messenger of Allah (ﷺ), he said: ‘Why don’t you tell me of the strange things that you saw in the land of Abyssinia?’ Some young men among them said: ‘Yes, O Messenger of Allah. While we were sitting, one of their elderly nuns came past, carrying a vessel of water on her head. She passed by some of their youth, one of whom placed his hand between her shoulders and pushed her. She fell on her knees and her vessel broke. When she stood up, she turned to him and said: “You will come to know, O traitor, that when Allah sets up the Footstool and gathers the first and the last, and hands and feet speak of what they used to earn, you will come to know your case and my case in His presence soon.’” The Messenger of Allah (ﷺ) said: ‘She spoke the truth, she spoke the truth. How can Allah purify any people (of sin) when they do not support their weak from their strong?’”}}
\hadithdefcmd{ibnmajah}{4011}{حَدَّثَنَا الْقَاسِمُ بْنُ زَكَرِيَّا بْنِ دِينَارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مُصْعَبٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَادَةَ الْوَاسِطِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، قَالاَ حَدَّثَنَا إِسْرَائِيلُ، أَنْبَأَنَا مُحَمَّدُ بْنُ جُحَادَةَ، عَنْ عَطِيَّةَ الْعَوْفِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَفْضَلُ الْجِهَادِ كَلِمَةُ عَدْلٍ عِنْدَ سُلْطَانٍ جَائِرٍ ‏"‏ ‏.‏\hadithno{4011}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Messenger of Allah (ﷺ) said:“The best of jihad is a just word spoken to an unjust ruler.”}}
\hadithdefcmd{ibnmajah}{4012}{حَدَّثَنَا رَاشِدُ بْنُ سَعِيدٍ الرَّمْلِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَبِي غَالِبٍ، عَنْ أَبِي أُمَامَةَ، قَالَ عَرَضَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ رَجُلٌ عِنْدَ الْجَمْرَةِ الأُولَى فَقَالَ يَا رَسُولَ اللَّهِ أَىُّ الْجِهَادِ أَفْضَلُ فَسَكَتَ عَنْهُ فَلَمَّا رَأَى الْجَمْرَةَ الثَّانِيَةَ سَأَلَهُ فَسَكَتَ عَنْهُ فَلَمَّا رَمَى جَمْرَةَ الْعَقَبَةِ وَضَعَ رِجْلَهُ فِي الْغَرْزِ لِيَرْكَبَ قَالَ ‏"‏ أَيْنَ السَّائِلُ ‏"‏ ‏.‏ قَالَ أَنَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ كَلِمَةُ حَقٍّ عِنْدَ ذِي سُلْطَانٍ جَائِرٍ ‏"‏ ‏.‏\hadithno{4012}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Umamah said:“A man came to the Messenger of Allah (ﷺ) at the first pillar and said: ‘O Messenger of Allah, which Jihad is best?’ but he kept quiet. When he saw the second Pillar, he asked again, and he kept quiet. When he stoned ‘Aqabah Pillar, he placed his foot in the stirrup, to ride, and said: ‘Where is the one who was asking?’ (The man) said: ‘Here I am, O Messenger of Allah.’ He said: ‘A word of truth spoken to an unjust ruler.’”}}
\hadithdefcmd{ibnmajah}{4013}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِسْمَاعِيلَ بْنِ رَجَاءٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَعَنْ قَيْسِ بْنِ مُسْلِمٍ، عَنْ طَارِقِ بْنِ شِهَابٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ أَخْرَجَ مَرْوَانُ الْمِنْبَرَ فِي يَوْمِ عِيدٍ فَبَدَأَ بِالْخُطْبَةِ قَبْلَ الصَّلاَةِ فَقَالَ رَجُلٌ يَا مَرْوَانُ خَالَفْتَ السُّنَّةَ أَخْرَجْتَ الْمِنْبَرَ فِي هَذَا الْيَوْمِ وَلَمْ يَكُنْ يُخْرَجُ وَبَدَأْتَ بِالْخُطْبَةِ قَبْلَ الصَّلاَةِ وَلَمْ يَكُنْ يُبْدَأُ بِهَا ‏.‏ فَقَالَ أَبُو سَعِيدٍ أَمَّا هَذَا فَقَدْ قَضَى مَا عَلَيْهِ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ رَأَى مِنْكُمْ مُنْكَرًا فَاسْتَطَاعَ أَنْ يُغَيِّرَهُ بِيَدِهِ فَلْيُغَيِّرْهُ بِيَدِهِ فَإِنْ لَمْ يَسْتَطِعْ فَبِلِسَانِهِ فَإِنْ لَمْ يَسْتَطِعْ فَبِقَلْبِهِ وَذَلِكَ أَضْعَفُ الإِيمَانِ ‏"‏ ‏.‏\hadithno{4013}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“Marwan brought out the pulpit on the day of ‘Eid, and he started with the sermon before the prayer. A man said: ‘O Marwan, you have gone against the Sunnah. You have brought out the pulpit on this day, and it was not brought out before, and you have started with the sermon before the prayer, and this was not done before.’ Abu Sa’eed said: ‘As for this man, he has done his duty. I heard the Messenger of Allah (ﷺ) say: ‘Whoever among you sees an evil action and can change it with his hand (by taking action), let him change it with his hand. If he cannot do that, then with his tongue (by speaking out); and if he cannot do that, then with his heart (by hating it and feeling that it is wrong), and that is the weakest of faith.’”}}
\hadithdefcmd{ibnmajah}{4014}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، حَدَّثَنِي عُتْبَةُ بْنُ أَبِي حَكِيمٍ، حَدَّثَنِي عَمِّي، عَمْرُو بْنُ جَارِيَةَ عَنْ أَبِي أُمَيَّةَ الشَّعْبَانِيِّ، قَالَ أَتَيْتُ أَبَا ثَعْلَبَةَ الْخُشَنِيَّ قَالَ قُلْتُ كَيْفَ تَصْنَعُ فِي هَذِهِ الآيَةِ قَالَ أَيَّةُ آيَةٍ قُلْتُ ‏\{يَا أَيُّهَا الَّذِينَ آمَنُوا عَلَيْكُمْ أَنْفُسَكُمْ لاَ يَضُرُّكُمْ مَنْ ضَلَّ إِذَا اهْتَدَيْتُمْ\}‏ قَالَ سَأَلْتَ عَنْهَا خَبِيرًا سَأَلْتُ عَنْهَا رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ بَلِ ائْتَمِرُوا بِالْمَعْرُوفِ وَتَنَاهَوْا عَنِ الْمُنْكَرِ حَتَّى إِذَا رَأَيْتَ شُحًّا مُطَاعًا وَهَوًى مُتَّبَعًا وَدُنْيَا مُؤْثَرَةً وَإِعْجَابَ كُلِّ ذِي رَأْىٍ بِرَأْيِهِ وَرَأَيْتَ أَمْرًا لاَ يَدَانِ لَكَ بِهِ فَعَلَيْكَ خُوَيْصَّةَ نَفْسِكَ وَدَعْ أَمْرَ الْعَوَامِّ فَإِنَّ مِنْ وَرَائِكُمْ أَيَّامَ الصَّبْرِ الصَّبْرُ فِيهِنَّ مِثْلُ قَبْضٍ عَلَى الْجَمْرِ لِلْعَامِلِ فِيهِنَّ مِثْلُ أَجْرِ خَمْسِينَ رَجُلاً يَعْمَلُونَ بِمِثْلِ عَمَلِهِ ‏"‏ ‏.‏\hadithno{4014}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Umayyah Sha’bani said:“I came to Abu Tha’labah Al-Khushani and said: ‘How do you understand this Verse?’ He said: ‘Which verse?’ I said: “O you who believe! Take care of your own selves. If you follow the (right) guidance, no hurt can come to you from those who are in error.”?[5:105] He said: ‘You have asked one who knows about it. I asked the Messenger of Allah (ﷺ) about it and he said: “Enjoin good upon one another and forbid one another to do evil, but if you see overwhelming stinginess, desires being followed, this world being preferred (to the Hereafter), every person with an opinion feeling proud of it, and you realize that you have no power to deal with it, then you have to mind your own business and leave the common folk to their own devices. After you will come days of patience, during which patience will be like grasping a burning ember, and one who does good deeds will have a reward like that of fifty men doing the same deed.”}}
\hadithdefcmd{ibnmajah}{4015}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا زَيْدُ بْنُ يَحْيَى بْنِ عُبَيْدٍ الْخُزَاعِيُّ، حَدَّثَنَا الْهَيْثَمُ بْنُ حُمَيْدٍ، حَدَّثَنَا أَبُو مُعَيْدٍ، حَفْصُ بْنُ غَيْلاَنَ الرُّعَيْنِيُّ عَنْ مَكْحُولٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ مَتَى نَتْرُكُ الأَمْرَ بِالْمَعْرُوفِ وَالنَّهْىَ عَنِ الْمُنْكَرِ قَالَ ‏"‏ إِذَا ظَهَرَ فِيكُمْ مَا ظَهَرَ فِي الأُمَمِ قَبْلَكُمْ ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ وَمَا ظَهَرَ فِي الأُمَمِ قَبْلَنَا قَالَ ‏"‏ الْمُلْكُ فِي صِغَارِكُمْ وَالْفَاحِشَةُ فِي كِبَارِكُمْ وَالْعِلْمُ فِي رُذَالَتِكُمْ ‏"‏ ‏.‏ قَالَ زَيْدٌ تَفْسِيرُ مَعْنَى قَوْلِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏"‏ وَالْعِلْمُ فِي رُذَالَتِكُمْ ‏"‏ ‏.‏ إِذَا كَانَ الْعِلْمُ فِي الْفُسَّاقِ ‏.‏\hadithno{4015}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas bin Malik said:“It was said: ‘O Messenger of Allah, when should we stop enjoining what is good and forbidding what is evil?’ He said: ‘When there appears among you that which appeared among those who came before you.’ We said: ‘O Messenger of Allah, what appeared among those that came before us?’ He said: ‘Kingship given to your youth, immorality even among the old, and knowledge among the base and vile.’”}}
\hadithdefcmd{ibnmajah}{4016}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنِ الْحَسَنِ، عَنْ جُنْدُبٍ، عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لاَ يَنْبَغِي لِلْمُؤْمِنِ أَنْ يُذِلَّ نَفْسَهُ ‏"‏ ‏.‏ قَالُوا وَكَيْفَ يُذِلُّ نَفْسَهُ قَالَ ‏"‏ يَتَعَرَّضُ مِنَ الْبَلاَءِ لِمَا لاَ يُطِيقُهُ ‏"‏ ‏.‏\hadithno{4016}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hudhaifah that the Messenger of Allah (ﷺ) said:“The believer should not humiliate himself.” They said: “How could he humiliate himself?” He said: “By taking on a trial that he cannot deal with.”}}
\hadithdefcmd{ibnmajah}{4017}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ أَبُو طُوَالَةَ، حَدَّثَنَا نَهَارٌ الْعَبْدِيُّ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّ اللَّهَ لَيَسْأَلُ الْعَبْدَ يَوْمَ الْقِيَامَةِ حَتَّى يَقُولَ مَا مَنَعَكَ إِذْ رَأَيْتَ الْمُنْكَرَ أَنْ تُنْكِرَهُ فَإِذَا لَقَّنَ اللَّهُ عَبْدًا حُجَّتَهُ قَالَ يَا رَبِّ رَجَوْتُكَ وَفَرِقْتُ مِنَ النَّاسِ ‏"‏ ‏.‏\hadithno{4017}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa’eed Al-Khudri said:“I heard the Messenger of Allah (ﷺ) say: ‘Allah will question His slave on the Day of Resurrection, until He says: “What kept you from denouncing evil when you saw it?” When Allah grants His slave a response, he will say: “O Lord, I hoped for Your mercy but I feared the people.”}}
\hadithdefcmd{ibnmajah}{4018}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ اللَّهَ يُمْلِي لِلظَّالِمِ فَإِذَا أَخَذَهُ لَمْ يُفْلِتْهُ ‏"‏ ‏.‏ ثُمَّ قَرَأَ ‏\{وَكَذَلِكَ أَخْذُ رَبِّكَ إِذَا أَخَذَ الْقُرَى وَهِيَ ظَالِمَةٌ\}‏ ‏.‏\hadithno{4018}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Musa that the Messenger of Allah (ﷺ) said:‘Allah gives respite to the wrongdoer, then when He seizes him, He does not let him go.” Then he recited: “Such is the Seizure of your Lord when He seizes the (population of) towns while they are doing wrong.”[11:]}}
\hadithdefcmd{ibnmajah}{4019}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ الدِّمَشْقِيُّ، حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ أَبُو أَيُّوبَ، عَنِ ابْنِ أَبِي مَالِكٍ، عَنْ أَبِيهِ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ أَقْبَلَ عَلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏ "‏ يَا مَعْشَرَ الْمُهَاجِرِينَ خَمْسٌ إِذَا ابْتُلِيتُمْ بِهِنَّ وَأَعُوذُ بِاللَّهِ أَنْ تُدْرِكُوهُنَّ لَمْ تَظْهَرِ الْفَاحِشَةُ فِي قَوْمٍ قَطُّ حَتَّى يُعْلِنُوا بِهَا إِلاَّ فَشَا فِيهِمُ الطَّاعُونُ وَالأَوْجَاعُ الَّتِي لَمْ تَكُنْ مَضَتْ فِي أَسْلاَفِهِمُ الَّذِينَ مَضَوْا ‏.‏ وَلَمْ يَنْقُصُوا الْمِكْيَالَ وَالْمِيزَانَ إِلاَّ أُخِذُوا بِالسِّنِينَ وَشِدَّةِ الْمَؤُنَةِ وَجَوْرِ السُّلْطَانِ عَلَيْهِمْ ‏.‏ وَلَمْ يَمْنَعُوا زَكَاةَ أَمْوَالِهِمْ إِلاَّ مُنِعُوا الْقَطْرَ مِنَ السَّمَاءِ وَلَوْلاَ الْبَهَائِمُ لَمْ يُمْطَرُوا وَلَمْ يَنْقُضُوا عَهْدَ اللَّهِ وَعَهْدَ رَسُولِهِ إِلاَّ سَلَّطَ اللَّهُ عَلَيْهِمْ عَدُوًّا مِنْ غَيْرِهِمْ فَأَخَذُوا بَعْضَ مَا فِي أَيْدِيهِمْ ‏.‏ وَمَا لَمْ تَحْكُمْ أَئِمَّتُهُمْ بِكِتَابِ اللَّهِ وَيَتَخَيَّرُوا مِمَّا أَنْزَلَ اللَّهُ إِلاَّ جَعَلَ اللَّهُ بَأْسَهُمْ بَيْنَهُمْ ‏"‏ ‏.‏\hadithno{4019}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Abdullah bin ‘Umar said:“The Messenger of Allah (ﷺ) turned to us and said: ‘O Muhajirun, there are five things with which you will be tested, and I seek refuge with Allah lest you live to see them: Immorality never appears among a people to such an extent that they commit it openly, but plagues and diseases that were never known among the predecessors will spread among them. They do not cheat in weights and measures but they will be stricken with famine, severe calamity and the oppression of their rulers. They do not withhold the Zakah of their wealth, but rain will be withheld from the sky, and were it not for the animals, no rain would fall on them. They do not break their covenant with Allah and His Messenger, but Allah will enable their enemies to overpower them and take some of what is in their hands. Unless their leaders rule according to the Book of Allah and seek all good from that which Allah has revealed, Allah will cause them to fight one another.’”}}
\hadithdefcmd{ibnmajah}{4020}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا مَعْنُ بْنُ عِيسَى، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ حَاتِمِ بْنِ حُرَيْثٍ، عَنْ مَالِكِ بْنِ أَبِي مَرْيَمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ غَنْمٍ الأَشْعَرِيِّ، عَنْ أَبِي مَالِكٍ الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيَشْرَبَنَّ نَاسٌ مِنْ أُمَّتِي الْخَمْرَ يُسَمُّونَهَا بِغَيْرِ اسْمِهَا يُعْزَفُ عَلَى رُءُوسِهِمْ بِالْمَعَازِفِ وَالْمُغَنِّيَاتِ يَخْسِفُ اللَّهُ بِهِمُ الأَرْضَ وَيَجْعَلُ مِنْهُمُ الْقِرَدَةَ وَالْخَنَازِيرَ ‏"‏ ‏.‏\hadithno{4020}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Malik Ash’ari that the Messenger of Allah (ﷺ) said:“People among my nation will drink wine, calling it by another name, and musical instruments will be played for them and singing girls (will sing for them). Allah will cause the earth to swallow them up, and will turn them into monkeys and pigs.”}}
\hadithdefcmd{ibnmajah}{4021}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا عَمَّارُ بْنُ مُحَمَّدٍ، عَنْ لَيْثٍ، عَنِ الْمِنْهَالِ، عَنْ زَاذَانَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ ‏\{يَلْعَنُهُمُ اللَّهُ وَيَلْعَنُهُمُ اللاَّعِنُونَ \}‏ ‏"‏ ‏.‏ قَالَ ‏"‏ دَوَابُّ الأَرْضِ ‏"‏ ‏.‏\hadithno{4021}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Bara’ bin ‘Azib that the Messenger of Allah (ﷺ) said:“Allah will curse them and those who curse will curse them.” He said: “The inhabitants of the earth.”}}
\hadithdefcmd{ibnmajah}{4022}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي الْجَعْدِ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ يَزِيدُ فِي الْعُمْرِ إِلاَّ الْبِرُّ وَلاَ يَرُدُّ الْقَدَرَ إِلاَّ الدُّعَاءُ وَإِنَّ الرَّجُلَ لَيُحْرَمُ الرِّزْقَ بِالذَّنْبِ يُصِيبُهُ ‏"‏ ‏.‏\hadithno{4022}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Thawban that the Messenger of Allah (ﷺ) said:“Nothing increases one’s life span except righteousness and nothing repels the Divine decree except supplication, and a man may be deprived of provision by a sin that he commits.’”}}
\hadithdefcmd{ibnmajah}{4023}{حَدَّثَنَا يُوسُفُ بْنُ حَمَّادٍ الْمَعْنِيُّ، وَيَحْيَى بْنُ دُرُسْتَ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَاصِمٍ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، سَعْدِ بْنِ أَبِي وَقَّاصٍ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَىُّ النَّاسِ أَشَدُّ بَلاَءً قَالَ ‏ "‏ الأَنْبِيَاءُ ثُمَّ الأَمْثَلُ فَالأَمْثَلُ يُبْتَلَى الْعَبْدُ عَلَى حَسَبِ دِينِهِ فَإِنْ كَانَ فِي دِينِهِ صُلْبًا اشْتَدَّ بَلاَؤُهُ وَإِنْ كَانَ فِي دِينِهِ رِقَّةٌ ابْتُلِيَ عَلَى حَسَبِ دِينِهِ فَمَا يَبْرَحُ الْبَلاَءُ بِالْعَبْدِ حَتَّى يَتْرُكَهُ يَمْشِي عَلَى الأَرْضِ وَمَا عَلَيْهِ مِنْ خَطِيئَةٍ ‏"‏ ‏.‏\hadithno{4023}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Mus’ab bin Sa’d that his father, Sa’d bin Abu Waqqas, said:“I said: ‘O Messenger of Allah, which people are most severely tested?’ He said: ‘The Prophets, then the next best and the next best. A person is tested according to his religious commitment. If he is steadfast in his religious commitment, he will be tested more severely, and if he is frail in his religious commitment, his test will be according to his commitment. Trials will continue to afflict a person until they leave him walking on the earth with no sin on him.’”}}
\hadithdefcmd{ibnmajah}{4024}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنِي هِشَامُ بْنُ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ دَخَلْتُ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ وَهُوَ يُوعَكُ فَوَضَعْتُ يَدِي عَلَيْهِ فَوَجَدْتُ حَرَّهُ بَيْنَ يَدَىَّ فَوْقَ اللِّحَافِ فَقُلْتُ يَا رَسُولَ اللَّهِ مَا أَشَدَّهَا عَلَيْكَ قَالَ ‏"‏ إِنَّا كَذَلِكَ يُضَعَّفُ لَنَا الْبَلاَءُ وَيُضَعَّفُ لَنَا الأَجْرُ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ أَىُّ النَّاسِ أَشَدُّ بَلاَءً قَالَ ‏"‏ الأَنْبِيَاءُ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ ثُمَّ مَنْ قَالَ ‏"‏ ثُمَّ الصَّالِحُونَ إِنْ كَانَ أَحَدُهُمْ لَيُبْتَلَى بِالْفَقْرِ حَتَّى مَا يَجِدُ أَحَدُهُمْ إِلاَّ الْعَبَاءَةَ يُحَوِّيهَا وَإِنْ كَانَ أَحَدُهُمْ لَيَفْرَحُ بِالْبَلاَءِ كَمَا يَفْرَحُ أَحَدُكُمْ بِالرَّخَاءِ ‏"‏ ‏.‏\hadithno{4024}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Sa’eed Al-Khudri said:“I entered upon the Prophet (ﷺ) when he was suffering from a fever, I placed my hand on him and felt heat with my hand from above the blanket. I said: ‘O Messenger of Allah, how hard it is for you!’ He said: ‘We (Prophets) are like that. The trial is multiplied for us and so is the reward.’ I said: ‘O Messenger of Allah, which people are most severely tested?’ He said: ‘The Prophets.’ I said: ‘O Messenger of Allah, then who?’ He said: ‘Then the righteous, some of whom were tested with poverty until they could not find anything except a cloak to put around themselves. One of them will rejoice at calamity as one of you would rejoice at ease.’”}}
\hadithdefcmd{ibnmajah}{4025}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كَأَنِّي أَنْظُرُ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ يَحْكِي نَبِيًّا مِنَ الأَنْبِيَاءِ ضَرَبَهُ قَوْمُهُ وَهُوَ يَمْسَحُ الدَّمَ عَنْ وَجْهِهِ وَيَقُولُ رَبِّ اغْفِرْ لِقَوْمِي فَإِنَّهُمْ لاَ يَعْلَمُونَ ‏.‏\hadithno{4025}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Abdullah said:“It is as if I can see the Messenger of Allah (ﷺ), telling us the story of one of the Prophets: ‘His people beat him, and he was wiping the blood from his face and saying: “O Lord forgive my people, for they do not know.’”}}
\hadithdefcmd{ibnmajah}{4026}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، وَيُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، وَسَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ نَحْنُ أَحَقُّ بِالشَّكِّ مِنْ إِبْرَاهِيمَ إِذْ قَالَ ‏\{رَبِّ أَرِنِي كَيْفَ تُحْيِي الْمَوْتَى قَالَ أَوَ لَمْ تُؤْمِنْ قَالَ بَلَى وَلَكِنْ لِيَطْمَئِنَّ قَلْبِي\}‏ وَيَرْحَمُ اللَّهُ لُوطًا لَقَدْ كَانَ يَأْوِي إِلَى رُكْنٍ شَدِيدٍ وَلَوْ لَبِثْتُ فِي السِّجْنِ طُولَ مَا لَبِثَ يُوسُفُ لأَجَبْتُ الدَّاعِيَ ‏"‏ ‏.‏\hadithno{4026}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“We are more likely to express doubt than Ibrahim when he said: “My Lord! Show me how You give life to the dead.’ He (Allah) said: ‘Do you not believe?’ He (Ibrahim) said: ‘Yes (I believe), but to be stronger in Faith.’[2:260] And may Allah have mercy on Lut. He wished to have a powerful support. And if i were to stay in prison as long as Yusuf stayed, I would have accepted the offer.’”}}
\hadithdefcmd{ibnmajah}{4027}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا كَانَ يَوْمُ أُحُدٍ كُسِرَتْ رَبَاعِيَةُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَشُجَّ فَجَعَلَ الدَّمُ يَسِيلُ عَلَى وَجْهِهِ وَجَعَلَ يَمْسَحُ الدَّمَ عَنْ وَجْهِهِ وَيَقُولُ ‏ "‏ كَيْفَ يُفْلِحُ قَوْمٌ خَضَبُوا وَجْهَ نَبِيِّهِمْ بِالدَّمِ وَهُوَ يَدْعُوهُمْ إِلَى اللَّهِ ‏"‏ ‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{لَيْسَ لَكَ مِنَ الأَمْرِ شَىْءٌ\}‏ ‏.‏\hadithno{4027}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:On the Day of Uhud, a molar of the Messenger of Allah (ﷺ) was broken and he was wounded. Blood started pouring down his face, and he started to wipe his face and say: “How can any people prosper if they soak the face of their Prophet with blood when he is calling them to Allah?” Then Allah revealed: “Not for you is the decision.”[3:]}}
\hadithdefcmd{ibnmajah}{4028}{حَدَّثَنَا مُحَمَّدُ بْنُ طَرِيفٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ أَنَسٍ، قَالَ جَاءَ جِبْرِيلُ عَلَيْهِ السَّلاَمُ ذَاتَ يَوْمٍ إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ جَالِسٌ حَزِينٌ قَدْ خُضِبَ بِالدِّمَاءِ قَدْ ضَرَبَهُ بَعْضُ أَهْلِ مَكَّةَ فَقَالَ مَا لَكَ فَقَالَ ‏"‏ فَعَلَ بِي هَؤُلاَءِ وَفَعَلُوا ‏"‏ ‏.‏ قَالَ أَتُحِبُّ أَنْ أُرِيَكَ آيَةً قَالَ ‏"‏ نَعَمْ أَرِنِي ‏"‏ ‏.‏ فَنَظَرَ إِلَى شَجَرَةٍ مِنْ وَرَاءِ الْوَادِي فَقَالَ ادْعُ تِلْكَ الشَّجَرَةَ ‏.‏ فَدَعَاهَا فَجَاءَتْ تَمْشِي حَتَّى قَامَتْ بَيْنَ يَدَيْهِ قَالَ قُلْ لَهَا فَلْتَرْجِعْ فَقَالَ لَهَا فَرَجَعَتْ حَتَّى عَادَتْ إِلَى مَكَانِهَا فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ حَسْبِي ‏"‏ ‏.‏\hadithno{4028}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas said:“One day, Jibril (as) came to the Messenger of Allah (ﷺ) when he was sitting in a sorrowful state with his face soaked with blood, because some of the people of Makkah had struck him. He said: ‘What is the matter with you?’ He said: ‘These people did such and such to me.’ He said: ‘Would you like me to show you a sign?’ He said: ‘Yes, show me.’ He looked at a tree on the far side of the valley and said: ‘Call that tree.’ So he called it, and it came walking until it stood before him. He said: ‘Tell it to go back.’ So he told it, and it went back to its place. Then the Messenger of Allah (ﷺ) said: ‘That is sufficient for me.’”}}
\hadithdefcmd{ibnmajah}{4029}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَحْصُوا لِي كُلَّ مَنْ تَلَفَّظَ بِالإِسْلاَمِ ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ أَتَخَافُ عَلَيْنَا وَنَحْنُ مَا بَيْنَ السِّتِّمِائَةِ إِلَى السَّبْعِمِائَةِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّكُمْ لاَ تَدْرُونَ لَعَلَّكُمْ أَنْ تُبْتَلَوْا ‏"‏ ‏.‏ قَالَ فَابْتُلِينَا حَتَّى جَعَلَ الرَّجُلُ مِنَّا مَا يُصَلِّي إِلاَّ سِرًّا ‏.‏\hadithno{4029}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Hudhaifah that the Messenger of Allah (ﷺ) said:“Count for me all those who have uttered (the word of) Islam.” We said: “O Messenger of Allah, do you fear for us when we number between six and seven hundred?” The Messenger of Allah (ﷺ) said: “You do not know, perhaps you will be tested.”}}
\hadithdefcmd{ibnmajah}{4030}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا سَعِيدُ بْنُ بَشِيرٍ، عَنْ قَتَادَةَ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ لَيْلَة�� أُسْرِيَ بِهِ وَجَدَ رِيحًا طَيِّبَةً فَقَالَ ‏ "‏ يَا جِبْرِيلُ مَا هَذِهِ الرِّيحُ الطَّيِّبَةُ قَالَ هَذِهِ رِيحُ قَبْرِ الْمَاشِطَةِ وَابْنَيْهَا وَزَوْجِهَا ‏.‏ قَالَ وَكَانَ بَدْءُ ذَلِكَ أَنَّ الْخَضِرَ كَانَ مِنْ أَشْرَافِ بَنِي إِسْرَائِيلَ وَكَانَ مَمَرُّهُ بِرَاهِبٍ فِي صَوْمَعَتِهِ فَيَطْلُعُ عَلَيْهِ الرَّاهِبُ فَيُعَلِّمُهُ الإِسْلاَمَ فَلَمَّا بَلَغَ الْخَضِرُ زَوَّجَهُ أَبُوهُ امْرَأَةً فَعَلَّمَهَا الْخَضِرُ وَأَخَذَ عَلَيْهَا أَنْ لاَ تُعْلِمَهُ أَحَدًا وَكَانَ لاَ يَقْرَبُ النِّسَاءَ فَطَلَّقَهَا ثُمَّ زَوَّجَهُ أَبُوهُ أُخْرَى فَعَلَّمَهَا وَأَخَذَ عَلَيْهَا أَنْ لاَ تُعْلِمَهُ أَحَدًا فَكَتَمَتْ إِحَدَاهُمَا وَأَفْشَتْ عَلَيْهِ الأُخْرَى فَانْطَلَقَ هَارِبًا حَتَّى أَتَى جَزِيرَةً فِي الْبَحْرِ فَأَقْبَلَ رَجُلاَنِ يَحْتَطِبَانِ فَرَأَيَاهُ فَكَتَمَ أَحَدُهُمَا وَأَفْشَى الآخَرُ وَقَالَ قَدْ رَأَيْتُ الْخَضِرَ ‏.‏ فَقِيلَ وَمَنْ رَآهُ مَعَكَ قَالَ فُلاَنٌ فَسُئِلَ فَكَتَمَ وَكَانَ فِي دِينِهِمْ أَنَّ مَنْ كَذَبَ قُتِلَ قَالَ فَتَزَوَّجَ الْمَرْأَةَ الْكَاتِمَةَ فَبَيْنَمَا هِيَ تَمْشُطُ ابْنَةَ فِرْعَوْنَ إِذْ سَقَطَ الْمُشْطُ فَقَالَتْ تَعِسَ فِرْعَوْنُ ‏.‏ فَأَخْبَرَتْ أَبَاهَا وَكَانَ لِلْمَرْأَةِ ابْنَانِ وَزَوْجٌ فَأَرْسَلَ إِلَيْهِمْ فَرَاوَدَ الْمَرْأَةَ وَزَوْجَهَا أَنْ يَرْجِعَا عَنْ دِينِهِمَا فَأَبَيَا فَقَالَ إِنِّي قَاتِلُكُمَا ‏.‏ فَقَالاَ إِحْسَانًا مِنْكَ إِلَيْنَا إِنْ قَتَلْتَنَا أَنْ تَجْعَلَنَا فِي بَيْتٍ فَفَعَلَ فَلَمَّا أُسْرِيَ بِالنَّبِيِّ ـ صلى الله عليه وسلم ـ وَجَدَ رِيحًا طَيِّبَةً فَسَأَلَ جِبْرِيلَ فَأَخْبَرَهُ ‏"‏ ‏.‏\hadithno{4030}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ubayy bin Ka’b that on the night when he (ﷺ) was taken on the Night Journey (Isra’), the Messenger of Allah (ﷺ) noticed a good fragrance and said:“O Jibril, what is this good fragrance?” He said: “This is the fragrance of the grave of the hairdresser and her two sons and her husband.” He said: “That began when Khadir, who was one of the nobles of the Children of Israel, used to pass by a monk in his cell. The monk used to meet him and he taught him Islam. When Khadir reached adolescence, his father married him to a woman. He taught her and made her promise not to teach it to anyone. He used not to touch women, so he divorced her, then his father married him to another woman, and he taught her and made her promise not to teach it to anyone. One of them kept the secret but the other disclosed it, so he fled until he came to an island in the sea. Two men came, gathering firewood, and saw him. One of them kept the secret but the other disclosed it and said: ‘I have seen Khadir.’ It was said: ‘Who else saw him besides you?’ He said: ‘So-and-so.’ (The other man) was questioned but he kept silent. According to their religion, the liar was to be killed. The woman who had kept the secret got married, and while she was combing the hair of Pharoah’s daughter, she dropped the comb and said: ‘May Pharoah perish!’ (The daughter) told her father about that. The woman had two sons and a husband. (Pharoah) sent for them, and tried to make the woman and her husband give up their religion, but they refused. He said: ‘I am going to kill you.’ They said: ‘It would be an act of kindness on your part, if you kill us, to put us in one grave.’ So he did that.” When the Prophet (ﷺ) was taken on the Night Journey (Isra’), he noticed a good fragrance and asked Jibril about it and he told him.”}}
\hadithdefcmd{ibnmajah}{4031}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سَعْدِ بْنِ سِنَانٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ عِظَمُ الْجَزَاءِ مَعَ عِظَمِ الْبَلاَءِ وَإِنَّ اللَّهَ إِذَا أَحَبَّ قَوْمًا ابْتَلاَهُمْ فَمَنْ رَضِيَ فَلَهُ الرِّضَا وَمَنْ سَخِطَ فَلَهُ السُّخْطُ ‏"‏ ‏.‏\hadithno{4031}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“The greatest reward comes with the greatest trial. When Allah loves a people He tests them. Whoever accepts that wins His pleasure but whoever is discontent with that earns His wrath.”}}
\hadithdefcmd{ibnmajah}{4032}{حَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ صَالِحٍ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ، عَنِ الأَعْمَشِ، عَنْ يَحْيَى بْنِ وَثَّابٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْمُؤْمِنُ الَّذِي يُخَالِطُ النَّاسَ وَيَصْبِرُ عَلَى أَذَاهُمْ أَعْظَمُ أَجْرًا مِنَ الْمُؤْمِنِ الَّذِي لاَ يُخَالِطُ النَّاسَ وَلاَ يَصْبِرُ عَلَى أَذَاهُمْ ‏"‏ ‏.‏\hadithno{4032}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“The believer who mixes with people and bears their annoyance with patience will have a greater reward than the believer who does not mix with people and does not put up with their annoyance.”}}
\hadithdefcmd{ibnmajah}{4033}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ ثَلاَثٌ مَنْ كُنَّ فِيهِ وَجَدَ طَعْمَ الإِيمَانِ - وَقَالَ بُنْدَارٌ حَلاَوَةَ الإِيمَانِ - مَنْ كَانَ يُحِبُّ الْمَرْءَ لاَ يُحِبُّهُ إِلاَّ لِلَّهِ ‏.‏ وَمَنْ كَانَ اللَّهُ وَرَسُولُهُ أَحَبَّ إِلَيْهِ مِمَّا سِوَاهُمَا ‏.‏ وَمَنْ كَانَ أَنْ يُلْقَى فِي النَّارِ أَحَبَّ إِلَيْهِ مِنْ أَنْ يَرْجِعَ فِي الْكُفْرِ بَعْدَ إِذْ أَنْقَذَهُ اللَّهُ مِنْهُ ‏"‏ ‏.‏\hadithno{4033}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“There are three things, whoever has them has found the taste of faith (One of the narrators) Bundar said: ‘The sweetness of faith; When he loves a man and only loves him for the sake of Allah. When Allah and His Messenger are more beloved to him than anything else; and when being thrown into the fire is dearer to him than going back to disbelief after Allah has saved him from it.”}}
\hadithdefcmd{ibnmajah}{4034}{حَدَّثَنَا الْحُسَيْنُ بْنُ الْحَسَنِ الْمَرْوَزِيُّ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، ح وَحَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ، قَالاَ حَدَّثَنَا رَاشِدٌ أَبُو مُحَمَّدٍ الْحِمَّانِيُّ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ أَوْصَانِي خَلِيلِي ـ صلى الله عليه وسلم ـ أَنْ ‏ "‏ لاَ تُشْرِكْ بِاللَّهِ شَيْئًا وَإِنْ قُطِّعْتَ وَحُرِّقْتَ وَلاَ تَتْرُكْ صَلاَةً مَكْتُوبَةً مُتَعَمِّدًا فَمَنْ تَرَكَهَا مُتَعَمِّدًا فَقَدْ بَرِئَتْ مِنْهُ الذِّمَّةُ وَلاَ تَشْرَبِ الْخَمْرَ فَإِنَّهَا مِفْتَاحُ كُلِّ شَرٍّ ‏"‏ ‏.‏\hadithno{4034}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Darda’ that my close friend (ﷺ) advised me:“Do not associate anything with Allah, even if you are cut and burned. Do not neglect any prescribd prayer deliberately, for whoever neglects it deliberately no longer has the protection of Allah. And do not drink wine, for it is the key to all evil.”}}
\hadithdefcmd{ibnmajah}{4035}{حَدَّثَنَا غِيَاثُ بْنُ جَعْفَرٍ الرَّحْبِيُّ، أَنْبَأَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، سَمِعْتُ ابْنَ جَابِرٍ، يَقُولُ قَالَ سَمِعْتُ أَبَا عَبْدِ رَبِّهِ، يَقُولُ سَمِعْتُ مُعَاوِيَةَ، يَقُولُ سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لَمْ يَبْقَ مِنَ الدُّنْيَا إِلاَّ بَلاَءٌ وَفِتْنَةٌ ‏"‏ ‏.‏\hadithno{4035}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Mu’awiyah said:“I heard the Prophet (ﷺ) say: ‘There is nothing left of this world except trials and tribulations.’”}}
\hadithdefcmd{ibnmajah}{4036}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ قُدَامَةَ الْجُمَحِيُّ، عَنْ إِسْحَاقَ بْنِ أَبِي الْفُرَاتِ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ سَيَأْتِي عَلَى النَّاسِ سَنَوَاتٌ خَدَّاعَاتٌ يُصَدَّقُ فِيهَا الْكَاذِبُ وَيُكَذَّبُ فِيهَا الصَّادِقُ وَيُؤْتَمَنُ فِيهَا الْخَائِنُ وَيُخَوَّنُ فِيهَا الأَمِينُ وَيَنْطِقُ فِيهَا الرُّوَيْبِضَةُ قِيلَ وَمَا الرُّوَيْبِضَةُ قَالَ الرَّجُلُ التَّافِهُ فِي أَمْرِ الْعَامَّةِ ‏"‏ ‏.‏\hadithno{4036}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“There will come to the people years of treachery, when the liar will be regarded as honest, and the honest man will be regarded as a liar; the traitor will be regarded as faithful, and the faithful man will be regarded as a traitor; and the Ruwaibidah will decide matters.’ It was said: ‘Who are the Ruwaibidah?’ He said: ‘Vile and base men who control the affairs of the people.’”}}
\hadithdefcmd{ibnmajah}{4037}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِي إِسْمَاعِيلَ الأَسْلَمِيِّ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لاَ تَذْهَبُ الدُّنْيَا حَتَّى يَمُرَّ الرَّجُلُ عَلَى الْقَبْرِ فَيَتَمَرَّغَ عَلَيْهِ وَيَقُولُ يَا لَيْتَنِي كُنْتُ مَكَانَ صَاحِبِ هَذَا الْقَبْرِ وَلَيْسَ بِهِ الدِّينُ إِلاَّ الْبَلاَءُ ‏"‏ ‏.‏\hadithno{4037}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“By the One in Whose Hand is my soul, this world will not pass away until a man will pass by a grave, and will roll on it and say: ‘Would that I were in the place of the occupant of this grave!’ And the reason for that will not be any religious motive, rather it will be because of calamity.”}}
\hadithdefcmd{ibnmajah}{4038}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا طَلْحَةُ بْنُ يَحْيَى، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي حُمَيْدٍ، - يَعْنِي مَوْلَى مُسَافِعٍ - عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَتُنْتَقَوُنَّ كَمَا يُنْتَقَى التَّمْرُ مِنْ أَغْفَالِهِ فَلْيَذْهَبَنَّ خِيَارُكُمْ وَلَيَبْقَيَنَّ شِرَارُكُمْ فَمُوتُوا إِنِ اسْتَطَعْتُمْ ‏"‏ ‏.‏\hadithno{4038}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“You will be picked over just as (good) dates are selected (separated) from its bad ones. So the best of you will be taken and the worst of you will be left, so die if you can.”}}
\hadithdefcmd{ibnmajah}{4039}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا مُحَمَّدُ بْنُ إِدْرِيسَ الشَّافِعِيُّ، حَدَّثَنِي مُحَمَّدُ بْنُ خَالِدٍ الْجَنَدِيُّ، عَنْ أَبَانَ بْنِ صَالِحٍ، عَنِ الْحَسَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَزْدَادُ الأَمْرُ إِلاَّ شِدَّةً وَلاَ الدُّنْيَا إِلاَّ إِدْبَارًا وَلاَ النَّاسُ إِلاَّ شُحًّا وَلاَ تَقُومُ السَّاعَةُ إِلاَّ عَلَى شِرَارِ النَّاسِ وَلاَ الْمَهْدِيُّ إِلاَّ عِيسَى ابْنُ مَرْيَمَ ‏"‏ ‏.‏\hadithno{4039}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“Adhering to religion will only become harder and worldly affairs will only become more difficult, and people will only become more stingy, and the Hour will only come upon the worst of people, and the only Mahdi (after Muhammad (ﷺ)) is ‘Eisa bin Maryam.”}}
\hadithdefcmd{ibnmajah}{4040}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، وَأَبُو هِشَامٍ الرِّفَاعِيُّ مُحَمَّدُ بْنُ يَزِيدَ قَالاَ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، حَدَّثَنَا أَبُو حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ بُعِثْتُ أَنَا وَالسَّاعَةُ كَهَاتَيْنِ ‏"‏ ‏.‏ وَجَمَعَ بَيْنَ إِصْبَعَيْهِ ‏.‏\hadithno{4040}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“I and the Hour have been sent like these two,” and he held up his two fingers together}}
\hadithdefcmd{ibnmajah}{4041}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ فُرَاتٍ الْقَزَّازِ، عَنْ أَبِي الطُّفَيْلِ، عَنْ حُذَيْفَةَ بْنِ أَسِيدٍ، قَالَ اطَّلَعَ عَلَيْنَا النَّبِيُّ ـ صلى الله عليه وسلم ـ مِنْ غُرْفَةٍ وَنَحْنُ نَتَذَاكَرُ السَّاعَةَ فَقَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَكُونَ عَشْرُ آيَاتٍ الدَّجَّالُ وَالدُّخَانُ وَطُلُوعُ الشَّمْسِ مِنْ مَغْرِبِهَا ‏"‏ ‏.‏\hadithno{4041}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Hudhaifah bin Asid said:"The Prophet (ﷺ) looked out at us from a room, when we were talking about the Hour. He said: 'The Hour will not begin until there are ten signs: Dajjal, (False Christ), the smoke, and the rising of the sun from the west}}
\hadithdefcmd{ibnmajah}{4042}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْعَلاَءِ، حَدَّثَنِي بُسْرُ بْنُ عُبَيْدِ اللَّهِ، حَدَّثَنِي أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ، حَدَّثَنِي عَوْفُ بْنُ مَالِكٍ الأَشْجَعِيُّ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ فِي غَزْوَةِ تَبُوكَ وَهُوَ فِي خِبَاءٍ مِنْ أَدَمٍ فَجَلَسْتُ بِفِنَاءِ الْخِبَاءِ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ ادْخُلْ يَا عَوْفُ ‏"‏ ‏.‏ فَقُلْتُ بِكُلِّي يَا رَسُولَ اللَّهِ قَالَ ‏"‏ بِكُلِّكَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ يَا عَوْفُ احْفَظْ خِلاَلاً سِتًّا بَيْنَ يَدَىِ السَّاعَةِ إِحْدَاهُنَّ مَوْتِي ‏"‏ ‏.‏ قَالَ فَوَجَمْتُ عِنْدَهَا وَجْمَةً شَدِيدَةً ‏.‏ فَقَالَ ‏"‏ قُلْ إِحْدَى ثُمَّ فَتْحُ بَيْتِ الْمَقْدِسِ ثُمَّ دَاءٌ يَظْهَرُ فِيكُمْ يَسْتَشْهِدُ اللَّهُ بِهِ ذَرَارِيَّكُمْ وَأَنْفُسَكُمْ وَيُزَكِّي بِهِ أَمْوَالَكُمْ ثُمَّ تَكُونُ الأَمْوَالُ فِيكُمْ حَتَّى يُعْطَى الرَّجُلُ مِائَةَ دِينَارٍ فَيَظَلَّ سَاخِطًا وَفِتْنَةٌ تَكُونُ بَيْنَكُمْ لاَ يَبْقَى بَيْتُ مُسْلِمٍ إِلاَّ دَخَلَتْهُ ثُمَّ تَكُونُ بَيْنَكُمْ وَبَيْنَ بَنِي الأَصْفَرِ هُدْنَةٌ فَيَغْدِرُونَ بِكُمْ فَيَسِيرُونَ إِلَيْكُمْ فِي ثَمَانِينَ غَايَةٍ تَحْتَ كُلِّ غَايَةٍ اثْنَا عَشَرَ أَلْفًا ‏"‏ ‏.‏\hadithno{4042}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{‘Awf bin Malik Al-Ashja’i said:“I came to the Messenger of Allah (ﷺ) during the campaign of Tabuk, when he was in a tent made of leather, so I sat in front of the tent. The Messenger of Allah (ﷺ) said: ‘Enter, O ‘Awf.’ I said, ‘All of me, O Messenger of Allah?’ He said: ‘All of you.’ Then he said: ‘O ‘Awf, remember six things (that will occur) before the Hour comes, one of which is my death.’ I was very shocked and saddened at that. He said: ‘Count that as the first. Then (will come) the conquest of Baitul-Maqdis (Jerusalem); then a disease which will appear among you and cause you and your offspring to die as martyrs and will purify your deeds; then there will be (much) wealth among you, so that if a man were to be given one hundred Dinar he would still be dissatisfied; and there will be tribulation among you that will not leave any Muslim house untouched;* then there will be a treaty between you and the Romans, then they will betray you and march against you with eighty banners, under each of which will be twelve thousand (troops).’”}}
\hadithdefcmd{ibnmajah}{4043}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ الدَّرَاوَرْدِيُّ، حَدَّثَنَا عَمْرٌو، - مَوْلَى الْمُطَّلِبِ - عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ الأَنْصَارِيِّ، عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَقْتُلُوا إِمَامَكُمْ وَتَجْتَلِدُوا بِأَسْيَافِكُمْ وَيَرِثُ دُنْيَاكُمْ شِرَارُكُمْ ‏"‏ ‏.‏\hadithno{4043}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Hudhaifah bin Yaman that the Messenger of Allah (ﷺ) said:“The Hour will not begin until you kill your ruler and fight one another with swords, and your world is inherited by the worst of you.”}}
\hadithdefcmd{ibnmajah}{4044}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَبِي حَيَّانَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمًا بَارِزًا لِلنَّاسِ فَأَتَاهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ مَتَى السَّاعَةُ فَقَالَ ‏"‏ مَا الْمَسْئُولُ عَنْهَا بِأَعْلَمَ مِنَ السَّائِلِ وَلَكِنْ سَأُخْبِرُكَ عَنْ أَشْرَاطِهَا إِذَا وَلَدَتِ الأَمَةُ رَبَّتَهَا فَذَاكَ مِنْ أَشْرَاطِهَا وَإِذَا كَانَتِ الْحُفَاةُ الْعُرَاةُ رُءُوسَ النَّاسِ فَذَاكَ مِنْ أَشْرَاطِهَا وَإِذَا تَطَاوَلَ رِعَاءُ الْغَنَمِ فِي الْبُنْيَانِ فَذَاكَ مِنْ أَشْرَاطِهَا فِي خَمْسٍ لاَ يَعْلَمُهُنَّ إِلاَّ اللَّهُ ‏"‏ ‏.‏ فَتَلاَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏\{إِنَّ اللَّهَ عِنْدَهُ عِلْمُ السَّاعَةِ وَيُنَزِّلُ الْغَيْثَ وَيَعْلَمُ مَا فِي الأَرْحَامِ\}‏ الآيَةَ ‏.‏\hadithno{4044}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) came out one day to the people, and a man came to him and said: ‘O Messenger of Allah, when will the Hour be?’ He said: ‘The one who is asked about it does not know more than the one who is asking. But I will tell you of its portents. When the slave woman gives birth to her mistress, that is one of its portents. When the barefoot and naked become leaders of the people, that is one of its portents. When shepherds compete in constructing buildings, that is one of its portents. (The Hour) is one of five (things) which no one knows except Allah.’ Then the Messenger of Allah (ﷺ) recited the words: “Verily, Allah, with Him (alone) is the knowledge of the Hour, He sends down the rain, and knows that which is in the wombs. (to the end of the Verse).”[31:]}}
\hadithdefcmd{ibnmajah}{4045}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ أَلاَ أُحَدِّثُكُمْ حَدِيثًا سَمِعْتُهُ مِنْ، رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ لاَ يُحَدِّثُكُمْ بِهِ أَحَدٌ بَعْدِي سَمِعْتُهُ مِنْهُ ‏ "‏ إِنَّ مِنْ أَشْرَاطِ السَّاعَةِ أَنْ يُرْفَعَ الْعِلْمُ وَيَظْهَرَ الْجَهْلُ وَيَفْشُوَ الزِّنَا وَيُشْرَبَ الْخَمْرُ وَيَذْهَبَ الرِّجَالُ وَيَبْقَى النِّسَاءُ حَتَّى يَكُونَ لِخَمْسِينَ امْرَأَةً قَيِّمٌ وَاحِدٌ ‏"‏ ‏.‏\hadithno{4045}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Anas bin Malik said:“Shall I not tell you a Hadith that I heard from the Messenger of Allah (ﷺ), which no one will tell you after me? I heard it from him (saying): ‘Among the portents of the Hour are that knowledge will be taken away and ignorance will prevail, illegal sex will become widespread and wine will be drunk, and men will disappear and women will be left, until there is one man in charge of fifty women.”}}
\hadithdefcmd{ibnmajah}{4046}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَحْسِرَ الْفُرَاتُ عَنْ جَبَلٍ مِنْ ذَهَبٍ فَيَقْتَتِلُ النَّاسُ عَلَيْهِ فَيُقْتَلُ مِنْ كُلِّ عَشَرَةٍ تِسْعَةٌ ‏"‏ ‏.‏\hadithno{4046}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The Hour will not begin until the Euphrates uncovers a mountain of gold and people fight over it, and out of every ten, nine will be killed.’”}}
\hadithdefcmd{ibnmajah}{4047}{حَدَّثَنَا أَبُو مَرْوَانَ الْعُثْمَانِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَفِيضَ الْمَالُ وَتَظْهَرَ الْفِتَنُ وَيَكْثُرَ الْهَرْجُ ‏"‏ ‏.‏ قَالُوا وَمَا الْهَرْجُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الْقَتْلُ الْقَتْلُ الْقَتْلُ ‏"‏ ‏.‏ ثَلاَثًا ‏.‏\hadithno{4047}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The Hour will not begin until wealth becomes abundant and tribulations appear, and Harj increases.” They said: “What is Harj, O Messenger of Allah?” He said: “Killing, killing, killing,” three times}}
\hadithdefcmd{ibnmajah}{4048}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ زِيَادِ بْنِ لَبِيدٍ، قَالَ ذَكَرَ النَّبِيُّ ـ صلى الله عليه وسلم ـ شَيْئًا فَقَالَ ‏"‏ ذَاكَ عِنْدَ أَوَانِ ذَهَابِ الْعِلْمِ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ وَكَيْفَ يَذْهَبُ الْعِلْمُ وَنَحْنُ نَقْرَأُ الْقُرْآنَ وَنُقْرِئُهُ أَبْنَاءَنَا وَيُقْرِئُهُ أَبْنَاؤُنَا أَبْنَاءَهُمْ إِلَى يَوْمِ الْقِيَامَةِ قَالَ ‏"‏ ثَكِلَتْكَ أُمُّكَ زِيَادُ إِنْ كُنْتُ لأَرَاكَ مِنْ أَفْقَهِ رَجُلٍ بِالْمَدِينَةِ أَوَلَيْسَ هَذِهِ الْيَهُودُ وَالنَّصَارَى يَقْرَءُونَ التَّوْرَاةَ وَالإِنْجِيلَ لاَ يَعْمَلُونَ بِشَىْءٍ مِمَّا فِيهِمَا ‏"‏ ‏.‏\hadithno{4048}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ziyad bin Labid said:“The Prophet (ﷺ) mentioned something and said: ‘That will be at the time when knowledge (of Qur’an) disappears.’ I said: ‘O Messenger of Allah, how will knowledge disappear when we read the Qur’an and teach it to our children, until the Day of Resurrection?’ He said: ‘May your mother be bereft of you, Ziyad! I thought that you were the wisest man in Al- Madinah. Is it not the case that these Jews and Christians read the Tawrah and the Injil, but they do not act upon anything of what is in them?’”}}
\hadithdefcmd{ibnmajah}{4049}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ بْنِ الْيَمَانِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَدْرُسُ الإِسْلاَمُ كَمَا يَدْرُسُ وَشْىُ الثَّوْبِ حَتَّى لاَ يُدْرَى مَا صِيَامٌ وَلاَ صَلاَةٌ وَلاَ نُسُكٌ وَلاَ صَدَقَةٌ وَلَيُسْرَى عَلَى كِتَابِ اللَّهِ عَزَّ وَجَلَّ فِي لَيْلَةٍ فَلاَ يَبْقَى فِي الأَرْضِ مِنْهُ آيَةٌ وَتَبْقَى طَوَائِفُ مِنَ النَّاسِ الشَّيْخُ الْكَبِيرُ وَالْعَجُوزُ يَقُولُونَ أَدْرَكْنَا آبَاءَنَا عَلَى هَذِهِ الْكَلِمَةِ لاَ إِلَهَ إِلاَّ اللَّهُ فَنَحْنُ نَقُولُهَا ‏"‏ ‏.‏ فَقَالَ لَهُ صِلَةُ مَا تُغْنِي عَنْهُمْ لاَ إِلَهَ إِلاَّ اللَّهُ وَهُمْ لاَ يَدْرُونَ مَا صَلاَةٌ وَلاَ صِيَامٌ وَلاَ نُسُكٌ وَلاَ صَدَقَةٌ فَأَعْرَضَ عَنْهُ حُذَيْفَةُ ثُمَّ رَدَّهَا عَلَيْهِ ثَلاَثًا كُلَّ ذَلِكَ يُعْرِضُ عَنْهُ حُذَيْفَةُ ثُمَّ أَقْبَلَ عَلَيْهِ فِي الثَّالِثَةِ فَقَالَ يَا صِلَةُ تُنْجِيهِمْ مِنَ النَّارِ ‏.‏ ثَلاَثًا ‏.‏\hadithno{4049}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hudhaifah bin Yaman that the Messenger of Allah (ﷺ) said:“Islam will wear out as embroidery on a garment wears out, until no one will know what fasting, prayer, (pilgrimage) rites and charity are. The Book of Allah will be taken away at night, and not one Verse of it will be left on earth. And there will be some people left, old men and old women, who will say: “We saw our fathers saying these words: ‘La ilaha illallah’ so we say them too.” Silah said to him: “What good will (saying): La ilaha illallah do them, when they do not know what fasting, prayer, (pilgrimage) rites and charity are?” Hudhaifah turned away from his. He repeated his question three times, and Hudhaifah turned away from him each time. Then he turned to him on the third time and said: “O Silah! It will save them from Hell,” three times}}
\hadithdefcmd{ibnmajah}{4050}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي وَوَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَكُونُ بَيْنَ يَدَىِ السَّاعَةِ أَيَّامٌ يُرْفَعُ فِيهَا الْعِلْمُ وَيَنْزِلُ فِيهَا الْجَهْلُ وَيَكْثُرُ فِيهَا الْهَرْجُ ‏"‏ ‏.‏ وَالْهَرْجُ الْقَتْلُ ‏.‏\hadithno{4050}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Abdullah that the Messenger of Allah (ﷺ) said:“Just before the Hour, there will be days when knowledge will disappear, ignorance will become widespread and there will be much Harj. And Harj means killing.”}}
\hadithdefcmd{ibnmajah}{4051}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ مِنْ وَرَائِكُمْ أَيَّامًا يَنْزِلُ فِيهَا الْجَهْلُ وَيُرْفَعُ فِيهَا الْعِلْمُ وَيَكْثُرُ فِيهَا الْهَرْجُ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَا الْهَرْجُ قَالَ ‏"‏ الْقَتْلُ ‏"‏ ‏.‏\hadithno{4051}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Musa that the Messenger of Allah (ﷺ) said:“After you days will come when ignorance will become widespread, knowledge will disappear and there will be much Harj.” They said: “O Messenger of Allah, what is Harj?” He said: “Killing.”}}
\hadithdefcmd{ibnmajah}{4052}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، يَرْفَعُهُ قَالَ ‏"‏ يَتَقَارَبُ الزَّمَانُ وَيَنْقُصُ الْعِلْمُ وَيُلْقَى الشُّحُّ وَتَظْهَرُ الْفِتَنُ وَيَكْثُرُ الْهَرْجُ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَا الْهَرْجُ قَالَ ‏"‏ الْقَتْلُ ‏"‏ ‏.‏\hadithno{4052}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah in a Marfu’ report (meaning, attributed to the Prophet (ﷺ)):“Time will pass quickly, knowledge will decrease, miserliness will be cast into people’s hearts, tribulations will appear and there will be much Harj.” They said: “O Messenger of Allah, what is Harj?” He said: “Killing.”}}
\hadithdefcmd{ibnmajah}{4053}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ حُذَيْفَةَ، قَالَ حَدَّثَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ حَدِيثَيْنِ قَدْ رَأَيْتُ أَحَدَهُمَا وَأَنَا أَنْتَظِرُ الآخَرَ حَدَّثَنَا ‏"‏ أَنَّ الأَمَانَةَ نَزَلَتْ فِي جَذْرِ قُلُوبِ الرِّجَالِ ‏"‏ ‏.‏ - قَالَ الطَّنَافِسِيُّ يَعْنِي وَسْطَ قُلُوبِ الرِّجَالِ - وَنَزَلَ الْقُرْآنُ فَعَلِمْنَا مِنَ الْقُرْآنِ وَعَلِمْنَا مِنَ السُّنَّةِ ‏.‏ ثُمَّ حَدَّثَنَا عَنْ رَفْعِهِمَا فَقَالَ ‏"‏ يَنَامُ الرَّجُلُ النَّوْمَةَ فَتُرْفَعُ الأَمَانَةُ مِنْ قَلْبِهِ فَيَظَلُّ أَثَرُهَا كَأَثَرِ الْوَكْتِ ثُمَّ يَنَامُ النَّوْمَةَ فَتُنْزَعُ الأَمَانَةُ مِنْ قَلْبِهِ فَيَظَلُّ أَثَرُهَا كَأَثَرِ الْمَجْلِ كَجَمْرٍ دَحْرَجْتَهُ عَلَى رِجْلِكَ فَنَفِطَ فَتَرَاهُ مُنْتَبِرًا وَلَيْسَ فِيهِ شَىْءٌ ‏"‏ ‏.‏ ثُمَّ أَخَذَ حُذَيْفَةُ كَفًّا مِنْ حَصًى فَدَحْرَجَهُ عَلَى سَاقِهِ ‏.‏ قَالَ ‏"‏ فَيُصْبِحُ النَّاسُ يَتَبَايَعُونَ وَلاَ يَكَادُ أَحَدٌ يُؤَدِّي الأَمَانَةَ حَتَّى يُقَالَ إِنَّ فِي بَنِي فُلاَنٍ رَجُلاً أَمِينًا ‏.‏ وَحَتَّى يُقَالَ لِلرَّجُلِ مَا أَعْقَلَهُ وَأَجْلَدَهُ وَأَظْرَفَهُ ‏.‏ وَمَا فِي قَلْبِهِ حَبَّةُ خَرْدَلٍ مِنْ إِيمَانٍ ‏"‏ ‏.‏ وَلَقَدْ أَتَى عَلَىَّ زَمَانٌ وَلَسْتُ أُبَالِي أَيَّكُمْ بَايَعْتُ لَئِنْ كَانَ مُسْلِمًا لَيَرُدَّنَّهُ عَلَىَّ إِسْلاَمُهُ وَلَئِنْ كَانَ يَهُودِيًّا أَوْ نَصْرَانِيًّا لَيَرُدَّنَّهُ عَلَىَّ سَاعِيهِ فَأَمَّا الْيَوْمَ فَمَا كُنْتُ لأُبَايِعَ إِلاَّ فُلاَنًا وَفُلاَنًا ‏.‏\hadithno{4053}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Hudhaifah said:“The Messenger of Allah (ﷺ) told us two Ahadith, one of which I have seen, and I am still waiting for the other. He told us: ‘Honesty was preserved in the roots of men’s hearts’ – (One of the narrators) Tanafisi said: ‘Meaning in the middle of men’s hearts’ – ‘Then the Qur’an was revealed and we learned (it) from the Qur’an and the Sunnah.’ Then he told us about its disappearance, saying; ‘A man will go to sleep and honesty will be taken away from his heart, and only its trace will remain, like spots without color. Then he will go to sleep again and the remainder of the honesty will also be taken away (from his heart) and leaving a trace like a blister, as when an ember touches your foot and raises a blister which has nothing inside.’” Then Hudhaifah picked up a handful of pebbles and rolled them on his leg. He said: “People will engage in business with one another, but there will hardly be any honest persons among them. Then it will be said that in such and such a tribe there is an honest man, and a man will be admired for his intelligence, good manners and strength, but there will not be even a mustard seed of faith in his heart.” "There was a time when I did not mind dealing with anyone of you, for if he was a Muslim, his religion would prevent him from cheating; and if he was a Christian, his Muslim ruler would prevent him from cheating. But today I cannot deal except with so-and-so and so-and-so}}
\hadithdefcmd{ibnmajah}{4054}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى، حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، عَنْ سَعِيدِ بْنِ سِنَانٍ، عَنْ أَبِي الزَّاهِرِيَّةِ، عَنْ أَبِي شَجَرَةَ، كَثِيرِ بْنِ مُرَّةَ عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ إِذَا أَرَادَ أَنْ يُهْلِكَ عَبْدًا نَزَعَ مِنْهُ الْحَيَاءَ فَإِذَا نَزَعَ مِنْهُ الْحَيَاءَ لَمْ تَلْقَهُ إِلاَّ مَقِيتًا مُمَقَّتًا فَإِذَا لَمْ تَلْقَهُ إِلاَّ مَقِيتًا مُمَقَّتًا نُزِعَتْ مِنْهُ الأَمَانَةُ فَإِذَا نُزِعَتْ مِنْهُ الأَمَانَةُ لَمْ تَلْقَهُ إِلاَّ خَائِنًا مُخَوَّنًا فَإِذَا لَمْ تَلْقَهُ إِلاَّ خَائِنًا مُخَوَّنًا نُزِعَتْ مِنْهُ الرَّحْمَةُ فَإِذَا نُزِعَتْ مِنْهُ الرَّحْمَةُ لَمْ تَلْقَهُ إِلاَّ رَجِيمًا مُلَعَّنًا فَإِذَا لَمْ تَلْقَهُ إِلاَّ رَجِيمًا مُلَعَّنًا نُزِعَتْ مِنْهُ رِبْقَةُ الإِسْلاَمِ ‏"‏ ‏.‏\hadithno{4054}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) said:“When Allah wants to destroy a person, He takes away modesty from him, you will only see him with the wrath of Allah upon him, and he will be hated by people. When you only see him with the wrath of Allah upon him, and hated by people, then honesty will be taken away from him, and when honesty is taken away from him, you will only see him as a traitor who is called such by others. When you only see him as a traitor who is called such by others, then mercy will be taken away from him, and when mercy is taken away from him, you will only see him as rejected and accursed, and when you only see him as rejected and accursed, then the bond of Islam will be taken away from him.”}}
\hadithdefcmd{ibnmajah}{4055}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ فُرَاتٍ الْقَزَّازِ، عَنْ عَامِرِ بْنِ وَاثِلَةَ أَبِي الطُّفَيْلِ الْكِنَانِيِّ، عَنْ حُذَيْفَةَ بْنِ أَسِيدٍ أَبِي سَرِيحَةَ، قَالَ اطَّلَعَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ غُرْفَةٍ وَنَحْنُ نَتَذَاكَرُ السَّاعَةَ فَقَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَكُونَ عَشْرُ آيَاتٍ طُلُوعُ الشَّمْسِ مِنْ مَغْرِبِهَا وَالدَّجَّالُ وَالدُّخَانُ وَالدَّابَّةُ وَيَأْجُوجُ وَمَأْجُوجُ وَخُرُوجُ عِيسَى ابْنِ مَرْيَمَ عَلَيْهِ السَّلاَمُ وَثَلاَثُ خُسُوفٍ خَسْفٌ بِالْمَشْرِقِ وَخَسْفٌ بِالْمَغْرِبِ وَخَسْفٌ بِجَزِيرَةِ الْعَرَبِ وَنَارٌ تَخْرُجُ مِنْ قَعْرِ عَدَنِ أَبْيَنَ تَسُوقُ النَّاسَ إِلَى الْمَحْشَرِ تَبِيتُ مَعَهُمْ إِذَا بَاتُوا وَتَقِيلُ مَعَهُمْ إِذَا قَالُوا ‏"‏ ‏.‏\hadithno{4055}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Hudhaifah bin Asid, Abu Sarihah, said:"The Messenger of Allah (ﷺ) looked out from a room, when we were talking about the Hour. He said: 'The Hour will not begin until ten signs appear: The rising of the sun from the west (place of its setting); Dajjal; the smoke; the beast; Gog and Magog people; the appearance of 'Eisa bin Maryam(as), the earth collapsing three times - once in the east, one in the west and one in the Arabian Peninsula; and fire that will emerge from the plain of Aden Abyan and will drive the people to the place of Gathering, stopping with them when they stop at night and when they stop to rest at midday}}
\hadithdefcmd{ibnmajah}{4056}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، وَابْنُ، لَهِيعَةَ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سِنَانِ بْنِ سَعْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ بَادِرُوا بِالأَعْمَالِ سِتًّا طُلُوعَ الشَّمْسِ مِنْ مَغْرِبِهَا وَالدُّخَانَ وَدَابَّةَ الأَرْضِ وَالدَّجَّالَ وَخُوَيْصَّةَ أَحَدِكُمْ وَأَمْرَ الْعَامَّةِ ‏"‏ ‏.‏\hadithno{4056}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:"Hasten to do good deeds (before) six things (happen): The rising of the sun from the west (place of its setting), the smoke, the beast of the earth, Dajjal (False Christ), that which will happen to each of you (death); and that which will happen to all people (the Day of Resurrection)}}
\hadithdefcmd{ibnmajah}{4057}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَوْنُ بْنُ عُمَارَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُثَنَّى بْنِ ثُمَامَةَ بْنِ عَبْدِ اللَّهِ بْنِ أَنَسٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ أَبِي قَتَادَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الآيَاتُ بَعْدَ الْمِائَتَيْنِ ‏"‏ ‏.‏\hadithno{4057}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that Abu Qatadah said:“The Messenger of Allah (ﷺ) said: “The (lesser) signs (will come) after two hundred (years).’”}}
\hadithdefcmd{ibnmajah}{4058}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا نُوحُ بْنُ قَيْسٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَعْقِلٍ، عَنْ يَزِيدَ الرَّقَاشِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ أُمَّتِي عَلَى خَمْسِ طَبَقَاتٍ فَأَرْبَعُونَ سَنَةً أَهْلُ بِرٍّ وَتَقْوَى ثُمَّ الَّذِينَ يَلُونَهُمْ إِلَى عِشْرِينَ وَمِائَةِ سَنَةٍ أَهْلُ تَرَاحُمٍ وَتَوَاصُلٍ ثُمَّ الَّذِينَ يَلُونَهُمْ إِلَى سِتِّينَ وَمِائَةِ سَنَةٍ أَهْلُ تَدَابُرٍ وَتَقَاطُعٍ ثُمَّ الْهَرْجُ الْهَرْجُ النَّجَا النَّجَا ‏"‏ ‏.‏ حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا خَازِمٌ أَبُو مُحَمَّدٍ الْعَنَزِيُّ، حَدَّثَنَا الْمِسْوَرُ بْنُ الْحَسَنِ، عَنْ أَبِي مَعْنٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أُمَّتِي عَلَى خَمْسِ طَبَقَاتٍ كُلُّ طَبَقَةٍ أَرْبَعُونَ عَامًا فَأَمَّا طَبَقَتِي وَطَبَقَةُ أَصْحَابِي فَأَهْلُ عِلْمٍ وَإِيمَانٍ وَأَمَّا الطَّبَقَةُ الثَّانِيَةُ مَا بَيْنَ الأَرْبَعِينَ إِلَى الثَّمَانِينَ فَأَهْلُ بِرٍّ وَتَقْوَى ‏"‏ ‏.‏ ثُمَّ ذَكَرَ نَحْوَهُ ‏.‏\hadithno{4058}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“My nation will pass through five stages. For forty years (they will be) people of righteousness and piety. Then those who follow them, for the next one hundred and twenty years, will be people who show mercy to one another and uphold ties with one another. Then those who follow them for the next one hundred and sixty years will be people who will turn their backs on one another and sever ties with one another. Then there will be Harj after Harj (killing). Seek deliverance, seek deliverance.”}}
\hadithdefcmd{ibnmajah}{4059}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا بَشِيرُ بْنُ سَلْمَانَ، عَنْ سَيَّارٍ، عَنْ طَارِقٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ بَيْنَ يَدَىِ السَّاعَةِ مَسْخٌ وَخَسْفٌ وَقَذْفٌ ‏"‏ ‏.‏\hadithno{4059}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah that the Prophet (ﷺ) said:“Just before the Hour comes there will be transformations, the earth collapsing, and Qadhf. (i.e. the throwing of stones perhaps as a means of punishment – maybe it refers to landslides).”}}
\hadithdefcmd{ibnmajah}{4060}{حَدَّثَنَا أَبُو مُصْعَبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي حَازِمِ بْنِ دِينَارٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّهُ سَمِعَ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ يَكُونُ فِي آخِرِ أُمَّتِي خَسْفٌ وَمَسْخٌ وَقَذْفٌ ‏"‏ ‏.‏\hadithno{4060}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sahl bin Sa’d that the Prophet (ﷺ) said:“At the end of my nation there will be the earth collapsing, transformations, and Qadhf.”}}
\hadithdefcmd{ibnmajah}{4061}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا حَيْوَةُ بْنُ شُرَيْحٍ، حَدَّثَنَا أَبُو صَخْرٍ، عَنْ نَافِعٍ، أَنَّ رَجُلاً، أَتَى ابْنَ عُمَرَ فَقَالَ إِنَّ فُلاَنًا يَقْرَأُ عَلَيْكَ السَّلاَمَ قَالَ إِنَّهُ بَلَغَنِي أَنَّهُ قَدْ أَحْدَثَ فَإِنْ كَانَ قَدْ أَحْدَثَ فَلاَ تُقْرِئْهُ مِنِّي السَّلاَمَ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ يَكُونُ فِي أُمَّتِي - أَوْ فِي هَذِهِ الأُمَّةِ - مَسْخٌ وَخَسْفٌ وَقَذْفٌ ‏"‏ ‏.‏ وَذَلِكَ فِي أَهْلِ الْقَدَرِ ‏.‏\hadithno{4061}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Nafi’ that a man came to Ibn ‘Umar and said:“So-and-so sends his Salam to you.” He said: “I have heard that he has introduced innovations (into Islam). If he has indeed introduced innovations, then do not convey my Salam to him, for I heard the Messenger of Allah (ﷺ) say: ‘There will be among my nation – or among this nation – transformations, the earth collapsing, and Qadhf.’ That was concerning Ahlul-Qadar.”}}
\hadithdefcmd{ibnmajah}{4062}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَمُحَمَّدُ بْنُ فُضَيْلٍ، عَنِ الْحَسَنِ بْنِ عَمْرٍو، عَنْ أَبِي الزُّبَيْرِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَكُونُ فِي أُمَّتِي خَسْفٌ وَمَسْخٌ وَقَذْفٌ ‏"‏ ‏.‏\hadithno{4062}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr that the Messenger of Allah (ﷺ) said:“There will be among my nation collapsing of the earth, transformations, and Qadhf.”}}
\hadithdefcmd{ibnmajah}{4063}{حَدَّثَنَا هِشَامُ بْنُ عُمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أُمَيَّةَ بْنِ صَفْوَانَ بْنِ عَبْدِ اللَّهِ بْنِ صَفْوَانَ، سَمِعَ جَدَّهُ عَبْدَ اللَّهِ بْنَ صَفْوَانَ، يَقُولُ أَخْبَرَتْنِي حَفْصَةُ، أَنَّهَا سَمِعَتْ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لَيَؤُمَّنَّ هَذَا الْبَيْتَ جَيْشٌ يَغْزُونَهُ حَتَّى إِذَا كَانُوا بِبَيْدَاءَ مِنَ الأَرْضِ خُسِفَ بِأَوْسَطِهِمْ وَيَتَنَادَى أَوَّلُهُمْ آخِرَهُمْ فَيُخْسَفُ بِهِمْ فَلاَ يَبْقَى مِنْهُمْ إِلاَّ الشَّرِيدُ الَّذِي يُخْبِرُ عَنْهُمْ ‏"‏ ‏.‏ فَلَمَّا جَاءَ جَيْشُ الْحَجَّاجِ ظَنَنَّا أَنَّهُمْ هُمْ فَقَالَ رَجُلٌ أَشْهَدُ عَلَيْكَ أَنَّكَ لَمْ تَكْذِبْ عَلَى حَفْصَةَ وَ أَنَّ حَفْصَةَ لَمْ تَكْذِبْ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{4063}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Hafsah narrated that she heard the Messenger of Allah (ﷺ) say:“An invading army will come towards this House until, when they are in Bayda’, the middle of them will be swallowed up by the earth, and the first of them will call out to the last of them, and they will be swallowed up, until there is no one left of them except a fugitive who will tell them of what happened to them.” When the army of Hajjaj came, we thought that they were (the ones mentioned in this Hadith). A man said: “I bear witness that you did not attribute a lie to Hafsah and that Hafsah did not attribute a lie to the Prophet (ﷺ).”}}
\hadithdefcmd{ibnmajah}{4064}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ أَبِي إِدْرِيسَ الْمُرْهِبِيِّ، عَنْ مُسْلِمِ بْنِ صَفْوَانَ، عَنْ صَفِيَّةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لاَ يَنْتَهِي النَّاسُ عَنْ غَزْوِ هَذَا الْبَيْتِ حَتَّى يَغْزُوَ جَيْشٌ حَتَّى إِذَا كَانُوا بِالْبَيْدَاءِ - أَوْ بَيْدَاءَ مِنَ الأَرْضِ - خُسِفَ بِأَوَّلِهِمْ وَآخِرِهِمْ وَلَمْ يَنْجُ أَوْسَطُهُمْ ‏"‏ ‏.‏ قُلْتُ فَإِنْ كَانَ فِيهِمْ مَنْ يُكْرَهُ قَالَ ‏"‏ يَبْعَثُهُمُ اللَّهُ عَلَى مَا فِي أَنْفُسِهِمْ ‏"‏ ‏.‏\hadithno{4064}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Safiyyah that the Messenger of Allah (ﷺ) said:“People will not stop attacking this House until an army attacks, until when they are in Baida’, the first and the last of them will be swallowed by the earth, and the middle of them will not be saved.’” I said: “What if there are those among them who were forced (to join the army)?” He said: “Allah will resurrect them according to what is in the hearts.”}}
\hadithdefcmd{ibnmajah}{4065}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَنَصْرُ بْنُ عَلِيٍّ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ الْحَمَّالُ، قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ سُوقَةَ، سَمِعَ نَافِعَ بْنَ جُبَيْرٍ، يُخْبِرُ عَنْ أُمِّ سَلَمَةَ، قَالَتْ ذَكَرَ النَّبِيُّ ـ صلى الله عليه وسلم ـ الْجَيْشَ الَّذِي يُخْسَفُ بِهِمْ فَقَالَتْ أُمُّ سَلَمَةَ يَا رَسُولَ اللَّهِ لَعَلَّ فِيهِمُ الْمُكْرَهُ قَالَ ‏ "‏ إِنَّهُمْ يُبْعَثُونَ عَلَى نِيَّاتِهِمْ ‏"‏ ‏.‏\hadithno{4065}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Umm Salamah said:“The Prophet (ﷺ) mentioned the army that would be swallowed up by the earth, and Umm Salamah said: ‘O Messenger of Allah, perhaps there will be some among them who were forced (to join them)?’ He said: ‘They will be resurrected according to their intentions.’”}}
\hadithdefcmd{ibnmajah}{4066}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ أَوْسِ بْنِ خَالِدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ تَخْرُجُ الدَّابَّةُ وَمَعَهَا خَاتَمُ سُلَيْمَانَ بْنِ دَاوُدَ وَعَصَا مُوسَى بْنِ عِمْرَانَ عَلَيْهِمَا السَّلاَمُ فَتَجْلُو وَجْهَ الْمُؤْمِنِ بِالْعَصَا وَ تَخْطِمُ أَنْفَ الْكَافِرِ بِالْخَاتَمِ حَتَّى أَنَّ أَهْلَ الْحِوَاءِ لَيَجْتَمِعُونَ فَيَقُولُ هَذَا يَا مُؤْمِنُ وَيَقُولُ هَذَا يَا كَافِرُ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ الْقَطَّانُ حَدَّثَنَاهُ إِبْرَاهِيمُ بْنُ يَحْيَى، حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، فَذَكَرَ نَحْوَهُ وَقَالَ فِيهِ مَرَّةً فَيَقُولُ هَذَا يَا مُؤْمِنُ ‏.‏ وَهَذَا يَا كَافِرُ ‏.‏\hadithno{4066}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The Beast will emerge and will have with it the seal of Sulaiman bin Dawud and the staff of Musa bin ‘Imran (as). It will make the faces of the believers shine with the staff, and will mark the noses of the disbelievers with the seal, until the inhabitants of a cluster of houses will gather together; then one will say ‘O believer!’ And to another ‘O disbeliever.’”}}
\hadithdefcmd{ibnmajah}{4067}{حَدَّثَنَا أَبُو غَسَّانَ، مُحَمَّدُ بْنُ عَمْرٍو زُنَيْجٌ حَدَّثَنَا أَبُو تُمَيْلَةَ، حَدَّثَنَا خَالِدُ بْنُ عُبَيْدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ ذَهَبَ بِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى مَوْضِعٍ بِالْبَادِيَةِ قَرِيبٍ مِنْ مَكَّةَ فَإِذَا أَرْضٌ يَابِسَةٌ حَوْلَهَا رَمْلٌ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَخْرُجُ الدَّابَّةُ مِنْ هَذَا الْمَوْضِعِ ‏"‏ ‏.‏ فَإِذَا فِتْرٌ فِي شِبْرٍ ‏.‏ قَالَ ابْنُ بُرَيْدَةَ فَحَجَجْتُ بَعْدَ ذَلِكَ بِسِنِينَ فَأَرَانَا عَصًا لَهُ فَإِذَا هُوَ بِعَصَاىَ هَذِهِ كَذَا وَكَذَا ‏.‏\hadithno{4067}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{‘Abdullah bin Buraidah narrated that his father said:“The Messenger of Allah (ﷺ) took me to a place in the desert, near Makkah, where there was arid land surrounded by sand. The Messenger of Allah (ﷺ) said: ‘The Beast will emerge from this spot – span by a span. (i.e, the size of that spot).’”}}
\hadithdefcmd{ibnmajah}{4068}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَطْلُعَ الشَّمْسُ مِنْ مَغْرِبِهَا فَإِذَا طَلَعَتْ وَرَآهَا النَّاسُ آمَنَ مَنْ عَلَيْهَا فَذَلِكَ حِينَ لاَ يَنْفَعُ نَفْسًا إِيمَانُهَا لَمْ تَكُنْ آمَنَتْ مِنْ قَبْلُ ‏"‏ ‏.‏\hadithno{4068}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Hurairah said:“I heard the Messenger of Allah (ﷺ) say: ‘The Hour will not begin until the sun rises from the west (i.e. the place of its setting). When it rises, the people will see it, and everyone on (earth) will believe, but that will be at a time when faith will not benefit anyone who did not believe before.’”}}
\hadithdefcmd{ibnmajah}{4069}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي حَيَّانَ التَّيْمِيِّ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَوَّلُ الآيَاتِ خُرُوجًا طُلُوعُ الشَّمْسِ مِنْ مَغْرِبِهَا وَخُرُوجُ الدَّابَّةِ عَلَى النَّاسِ ضُحًى ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ فَأَيَّتُهُمَا مَا خَرَجَتْ قَبْلَ الأُخْرَى فَالأُخْرَى مِنْهَا قَرِيبٌ ‏.‏ قَالَ عَبْدُ اللَّهِ وَلاَ أَظُنُّهَا إِلاَّ طُلُوعَ الشَّمْسِ مِنْ مَغْرِبِهَا ‏.‏\hadithno{4069}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amr that the Messenger of Allah (ﷺ) said:“The first signs to appear will be at the rising of the sun from the west and the emergence of the Beast to the people, at forenoon.’” 'Abdullah said: "Whichever of them appears first, the other will come soon after." 'Abdullah said: "I do not think it will be anything other than the sun rising from the west}}
\hadithdefcmd{ibnmajah}{4070}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ إِسْرَائِيلَ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ صَفْوَانَ بْنِ عَسَّالٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ مِنْ قِبَلِ مَغْرِبِ الشَّمْسِ بَابًا مَفْتُوحًا عَرْضُهُ سَبْعُونَ سَنَةً فَلاَ يَزَالُ ذَلِكَ الْبَابُ مَفْتُوحًا لِلتَّوْبَةِ حَتَّى تَطْلُعَ الشَّمْسُ مِنْ نَحْوِهِ فَإِذَا طَلَعَتْ مِنْ نَحْوِهِ لَمْ يَنْفَعْ نَفْسًا إِيمَانُهَا لَمْ تَكُنْ آمَنَتْ مِنْ قَبْلُ أَوْ كَسَبَتْ فِي إِيمَانِهَا خَيْرًا ‏"‏ ‏.‏\hadithno{4070}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Safwan bin ‘Assal that the Messenger of Allah (ﷺ) said:“Towards the west (i.e., the place of the setting of the sun) there is an open door, seventy years wide. That door will remain open for repentance until the sun rises from this direction. When it rises from this direction, faith will not benefit any soul that did not believe before or earn anything good through its faith.”}}
\hadithdefcmd{ibnmajah}{4071}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الدَّجَّالُ أَعْوَرُ عَيْنِ الْيُسْرَى جُفَالُ الشَّعَرِ مَعَهُ جَنَّةٌ وَنَارٌ فَنَارُهُ جَنَّةٌ وَجَنَّتُهُ نَارٌ ‏"‏ ‏.‏\hadithno{4071}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Hudhaifah said:"The Messenger of Allah (ﷺ) said: 'The Dajjal (False Christ) is blind in his left eye and has abundant hair. With him will be a Paradise and a Hell, but his Hell is Paradise and his Paradise is Hell}}
\hadithdefcmd{ibnmajah}{4072}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَمُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالُوا حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ أَبِي التَّيَّاحِ، عَنِ الْمُغِيرَةِ بْنِ سُبَيْعٍ، عَنْ عَمْرِو بْنِ حُرَيْثٍ، عَنْ أَبِي بَكْرٍ الصِّدِّيقِ، قَالَ حَدَّثَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَنَّ الدَّجَّالَ يَخْرُجُ مِنْ أَرْضٍ بِالْمَشْرِقِ يُقَالُ لَهَا خُرَاسَانُ يَتْبَعُهُ أَقْوَامٌ كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطْرَقَةُ ‏"‏ ‏.‏\hadithno{4072}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Bakr Siddiq said:"The Messenger of Allah (ﷺ) told us: 'Dajjal will emerge in a land in the east called Khorasan, and will be followed by people with faces like hammered shields}}
\hadithdefcmd{ibnmajah}{4073}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ مَا سَأَلَ أَحَدٌ النَّبِيَّ ـ صلى الله عليه وسلم ـ عَنِ الدَّجَّالِ أَكْثَرَ مِمَّا سَأَلْتُهُ - وَقَالَ ابْنُ نُمَيْرٍ أَشَدَّ سُؤَالاً مِنِّي - فَقَالَ لِي ‏"‏ مَا تَسْأَلُ عَنْهُ ‏"‏ ‏.‏ قُلْتُ إِنَّهُمْ يَقُولُونَ إِنَّ مَعَهُ الطَّعَامَ وَالشَّرَابَ قَالَ ‏"‏ هُوَ أَهْوَنُ عَلَى اللَّهِ مِنْ ذَلِكَ ‏"‏ ‏.‏\hadithno{4073}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{It was narrated that Mughirah bin Shu'bah said:"No one asked the Prophet (ﷺ) about Dajjal more than I did." (One of the narrators) Ibn Numair said (in his version): "(No one asked) more difficult questions than I did." - "He said to me: 'What are you asking about him?' I said: 'They say he will have food and drink with him.' He said: 'He is too insignificant before Allah for that}}
\hadithdefcmd{ibnmajah}{4074}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ مُجَالِدٍ، عَنِ الشَّعْبِيِّ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، قَالَتْ صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ذَاتَ يَوْمٍ وَصَعِدَ الْمِنْبَرَ وَكَانَ لاَ يَصْعَدُ عَلَيْهِ قَبْلَ ذَلِكَ إِلاَّ يَوْمَ الْجُمُعَةِ فَاشْتَدَّ ذَلِكَ عَلَى النَّاسِ فَمِنْ بَيْنِ قَائِمٍ وَجَالِسٍ فَأَشَارَ إِلَيْهِمْ بِيَدِهِ أَنِ اقْعُدُوا ‏"‏ فَإِنِّي وَاللَّهِ مَا قُمْتُ مَقَامِي هَذَا لأَمْرٍ يَنْفَعُكُمْ لِرَغْبَةٍ وَلاَ لِرَهْبَةٍ وَلَكِنَّ تَمِيمًا الدَّارِيَّ أَتَانِي فَأَخْبَرَنِي خَبَرًا مَنَعَنِي الْقَيْلُولَةَ مِنَ الْفَرَحِ وَقُرَّةِ الْعَيْنِ فَأَحْبَبْتُ أَنْ أَنْشُرَ عَلَيْكُمْ فَرَحَ نَبِيِّكُمْ أَلاَ إِنَّ ابْنَ عَمٍّ لَتَمِيمٍ الدَّارِيِّ أَخْبَرَنِي أَنَّ الرِّيحَ أَلْجَأَتْهُمْ إِلَى جَزِيرَةٍ لاَ يَعْرِفُونَهَا فَقَعَدُوا فِي قَوَارِبِ السَّفِينَةِ فَخَرَجُوا فِيهَا فَإِذَا هُمْ بِشَىْءٍ أَهْدَبَ أَسْوَدَ قَالُوا لَهُ مَا أَنْتَ قَالَ أَنَا الْجَسَّاسَةُ ‏.‏ قَالُوا أَخْبِرِينَا ‏.‏ قَالَتْ مَا أَنَا بِمُخْبِرَتِكُمْ شَيْئًا وَلاَ سَائِلَتِكُمْ وَلَكِنْ هَذَا الدَّيْرُ قَدْ رَمَقْتُمُوهُ فَأْتُوهُ فَإِنَّ فِيهِ رَجُلاً بِالأَشْوَاقِ إِلَى أَنْ تُخْبِرُوهُ وَيُخْبِرَكُمْ فَأَتَوْهُ فَدَخَلُوا عَلَيْهِ فَإِذَا هُمْ بِشَيْخٍ مُوثَقٍ شَدِيدِ الْوَثَاقِ يُظْهِرُ الْحُزْنَ شَدِيدِ التَّشَكِّي فَقَالَ لَهُمْ مِنْ أَيْنَ قَالُوا مِنَ الشَّامِ ‏.‏ قَالَ مَا فَعَلَتِ الْعَرَبُ قَالُوا نَحْنُ قَوْمٌ مِنَ الْعَرَبِ عَمَّ تَسْأَلُ قَالَ مَا فَعَلَ هَذَا الرَّجُلُ الَّذِي خَرَجَ فِيكُمْ قَالُوا خَيْرًا نَاوَى قَوْمًا فَأَظْهَرَهُ اللَّهُ عَلَيْهِمْ فَأَمْرُهُمُ الْيَوْمَ جَمِيعٌ إِلَهُهُمْ وَاحِدٌ وَدِينُهُمْ وَاحِدٌ قَالَ مَا فَعَلَتْ عَيْنُ زُغَرَ قَالُوا خَيْرًا يَسْقُونَ مِنْهَا زُرُوعَهُمْ وَيَسْتَقُونَ مِنْهَا لِسَقْيِهِمْ قَالَ فَمَا فَعَلَ نَخْلٌ بَيْنَ عَمَّانَ وَبَيْسَانَ قَالُوا يُطْعِمُ ثَمَرَهُ كُلَّ عَامٍ ‏.‏ قَالَ فَمَا فَعَلَتْ بُحَيْرَةُ الطَّبَرِيَّةِ قَالُوا تَدَفَّقُ جَنَبَاتُهَا مِنْ كَثْرَةِ الْمَاءِ ‏.‏ قَالَ فَزَفَرَ ثَلاَثَ زَفَرَاتٍ ثُمَّ قَالَ لَوِ انْفَلَتُّ مِنْ وَثَاقِي هَذَا لَمْ أَدَعْ أَرْضًا إِلاَّ وَطِئْتُهَا بِرِجْلَىَّ هَاتَيْنِ إِلاَّ طَيْبَةَ لَيْسَ لِي عَلَيْهَا سَبِيلٌ ‏"‏ ‏.‏ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ إِلَى هَذَا يَنْتَهِي فَرَحِي هَذِهِ طَيْبَةُ وَالَّذِي نَفْسِي بِيَدِهِ مَا فِيهَا طَرِيقٌ ضَيِّقٌ وَلاَ وَاسِعٌ وَلاَ سَهْلٌ وَلاَ جَبَلٌ إِلاَّ وَعَلَيْهِ مَلَكٌ شَاهِرٌ سَيْفَهُ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4074}\hadithgrade{Al-Albani: Sahih Matn; Muhammad Fouad Abd al-Baqi: Sahih Matn; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Fatimah bint Qais said:"The Messenger of Allah (ﷺ) prayed one day, and ascended the pulpit, and he never used to ascend it, before that, except on Fridays. The people were alarmed by that, and some were standing and some were sitting. He gestured to them with his hand, telling them to sit. (Then he said:) 'By Allah, I am not standing here for something that will benefit you, an exhortation or warning. Rather Tamim Dari has come to me and told me something that prevented me from taking a rest because of the joy and delight (I felt), and I wanted to spread that joy among you. A cousin of Tamim Dari told me that the wind drove them to an island that they did not know, so they sat in the rowing boats of the ship and set out. There they saw something black, with long eyelashes. They said to it: "What are you?" It said: "I am Jassasah," They said: "Tell us." It said: "I will not tell you anything or ask you anything. Rather there is this monastery that you have looked at. Go to it, for there is a man there who is longing to hear your news and tell you news." So they went there and entered upon him, and they saw an old man firmly shackled, with a sorrowful appearance and complaining a great deal. He said to them: "Where have you come from?" They said: "From Sham." He said: "How are the Arabs faring?" They said: "We are from among the Arabs. What do you want to ask about?" He said: "What has this man done who has appeared among you?" They said: "(He has done) well. He made enemies of some people, but Allah supported him against them and now they have become one, with one God and one religion." He said: "What happened to the spring of Zughar?" They said: "It is good; we irrigate out crops from it and drink from it." He said: "What happened to the date-palms between 'Amman and Baisan?" They said: "They bear fruit every year." He said: "What happened to the Lake of Tiberias?" They said: "It overflows because of the abundance of water." He gave three deep sighs, then he said: "If I were to free myself from these chains, I would not leave any land without entering it on these two feet of mine, except for Taibah, for I have no way to enter it." The Prophet (ﷺ) said: 'My joy is so great. This (Al-Madinah) is Taibah, and by the One in Whose Hand is my soul, there is no narrow or broad road in it, or any plain or mountain, but there is an angel (standing) over it with his sword unsheathed, until the Day of Resurrection}}
\hadithdefcmd{ibnmajah}{4075}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ بْنِ جَابِرٍ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ جُبَيْرِ بْنِ نُفَيْرٍ، حَدَّثَنِي أَبِي أَنَّهُ، سَمِعَ النَّوَّاسَ بْنَ سَمْعَانَ الْكِلاَبِيَّ، يَقُولُ ذَكَرَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الدَّجَّالَ الْغَدَاةَ فَخَفَضَ فِيهِ وَرَفَعَ حَتَّى ظَنَنَّا أَنَّهُ فِي طَائِفَةِ النَّخْلِ فَلَمَّا رُحْنَا إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ عَرَفَ ذَلِكَ فِينَا فَقَالَ ‏"‏ مَا شَأْنُكُمْ ‏"‏ ‏.‏ فَقُلْنَا يَا رَسُولَ اللَّهِ ذَكَرْتَ الدَّجَّالَ الْغَدَاةَ فَخَفَضْتَ فِيهِ ثُمَّ رَفَعْتَ حَتَّى ظَنَنَّا أَنَّهُ فِي طَائِفَةِ النَّخْلِ ‏.‏ قَالَ ‏"‏ غَيْرُ الدَّجَّالِ أَخْوَفُنِي عَلَيْكُمْ إِنْ يَخْرُجْ وَأَنَا فِيكُمْ فَأَنَا حَجِيجُهُ دُونَكُمْ وَإِنْ يَخْرُجْ وَلَسْتُ فِيكُمْ فَامْرُؤٌ حَجِيجُ نَفْسِهِ وَاللَّهُ خَلِيفَتِي عَلَى كُلِّ مُسْلِمٍ إِنَّهُ شَابٌّ قَطَطٌ عَيْنُهُ قَائِمَةٌ كَأَنِّي أُشَبِّهُهُ بِعَبْدِ الْعُزَّى بْنِ قَطَنٍ فَمَنْ رَآهُ مِنْكُمْ فَلْيَقْرَأْ عَلَيْهِ فَوَاتِحَ سُورَةِ الْكَهْفِ إِنَّهُ يَخْرُجُ مِنْ خَلَّةٍ بَيْنَ الشَّامِ وَالْعِرَاقِ فَعَاثَ يَمِينًا وَعَاثَ شِمَالاً يَا عِبَادَ اللَّهِ اثْبُتُوا ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ وَمَا لُبْثُهُ فِي الأَرْضِ قَالَ ‏"‏ أَرْبَعُونَ يَوْمًا يَوْمٌ كَسَنَةٍ وَيَوْمٌ كَشَهْرٍ وَيَوْمٌ كَجُمُعَةٍ وَسَائِرُ أَيَّامِهِ كَأَيَّامِكُمْ ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ فَذَلِكَ الْيَوْمُ الَّذِي كَسَنَةٍ تَكْفِينَا فِيهِ صَلاَةُ يَوْمٍ قَالَ ‏"‏ فَاقْدُرُوا لَهُ قَدْرًا ‏"‏ ‏.‏ قَالَ قُلْنَا فَمَا إِسْرَاعُهُ فِي الأَرْضِ قَالَ ‏"‏ كَالْغَيْثِ اشْتَدَّ بِهِ الرِّيحُ ‏"‏ ‏.‏ قَالَ ‏"‏ فَيَأْتِي الْقَوْمَ فَيَدْعُوهُمْ فَيَسْتَجِيبُونَ لَهُ وَيُؤْمِنُونَ بِهِ فَيَأْمُرُ السَّمَاءَ أَنْ تُمْطِرَ فَتُمْطِرَ وَيَأْمُرُ الأَرْضَ أَنْ تُنْبِتَ فَتُنْبِتَ وَتَرُوحُ عَلَيْهِمْ سَارِحَتُهُمْ أَطْوَلَ مَا كَانَتْ ذُرًى وَأَسْبَغَهُ ضُرُوعًا وَأَمَدَّهُ خَوَاصِرَ ثُمَّ يَأْتِي الْقَوْمَ فَيَدْعُوهُمْ فَيَرُدُّونَ عَلَيْهِ قَوْلَهُ فَيَنْصَرِفُ عَنْهُمْ فَيُصْبِحُونَ مُمْحِلِينَ مَا بِأَيْدِيهِمْ شَىْءٌ ثُمَّ يَمُرُّ بِالْخَرِبَةِ فَيَقُولُ لَهَا أَخْرِجِي كُنُوزَكِ فَيَنْطَلِقُ فَتَتْبَعُهُ كُنُوزُهَا كَيَعَاسِيبِ النَّحْلِ ثُمَّ يَدْعُو رَجُلاً مُمْتَلِئًا شَبَابًا فَيَضْرِبُهُ بِالسَّيْفِ ضَرْبَةً فَيَقْطَعُهُ جِزْلَتَيْنِ رَمْيَةَ الْغَرَضِ ثُمَّ يَدْعُوهُ فَيُقْبِلُ يَتَهَلَّلُ وَجْهُهُ يَضْحَكُ فَبَيْنَمَا هُمْ كَذَلِكَ إِذْ بَعَثَ اللَّهُ عِيسَى ابْنَ مَرْيَمَ فَيَنْزِلُ عِنْدَ الْمَنَارَةِ الْبَيْضَاءِ شَرْقِيَّ دِمَشْقَ بَيْنَ مَهْرُودَتَيْنِ وَاضِعًا كَفَّيْهِ عَلَى أَجْنِحَةِ مَلَكَيْنِ إِذَا طَأْطَأَ رَأْسَهُ قَطَرَ وَإِذَا رَفَعَهُ يَنْحَدِرُ مِنْهُ جُمَانٌ كَاللُّؤْلُؤِ وَلاَ يَحِلُّ لِكَافِرٍ أَنْ يَجِدَ رِيِحَ نَفَسِهِ إِلاَّ مَاتَ وَنَفَسُهُ يَنْتَهِي حَيْثُ يَنْتَهِي طَرْفُهُ فَيَنْطَلِقُ حَتَّى يُدْرِكَهُ عِنْدَ بَابِ لُدٍّ فَيَقْتُلُهُ ثُمَّ يَأْتِي نَبِيُّ اللَّهِ عِيسَى قَوْمًا قَدْ عَصَمَهُمُ اللَّهُ فَيَمْسَحُ وُجُوهَهُمْ وَيُحَدِّثُهُمْ بِدَرَجَاتِهِمْ فِي الْجَنَّةِ فَبَيْنَمَا هُمْ كَذَلِكَ إِذْ أَوْحَى اللَّهُ إِلَيْهِ يَا عِيسَى إِنِّي قَدْ أَخْرَجْتُ عِبَادًا لِي لاَ يَدَانِ لأَحَدٍ بِقِتَالِهِمْ وَأَحْرِزْ عِبَادِي إِلَى الطُّورِ ‏.‏ وَيَبْعَثُ اللَّهُ يَأْجُوجَ وَمَأْجُوجَ وَهُمْ كَمَا قَالَ اللَّهُ مِنْ كُلِّ حَدَبٍ يَنْسِلُونَ فَيَمُرُّ أَوَائِلُهُمْ عَلَى بُحَيْرَةِ الطَّبَرِيَّةِ فَيَشْرَبُونَ مَا فِيهَا ثُمَّ يَمُرُّ آخِرُهُمْ فَيَقُولُونَ لَقَدْ كَانَ فِي هَذَا مَاءٌ مَرَّةً وَيَحْضُرُ نَبِيُّ اللَّهِ عِيسَى وَأَصْحَابُهُ حَتَّى يَكُونَ رَأْسُ الثَّوْرِ لأَحَدِهِمْ خَيْرًا مِنْ مِائَةِ دِينَارٍ لأَحَدِكُمُ الْيَوْمَ فَيَرْغَبُ نَبِيُّ اللَّهِ عِيسَى وَأَصْحَابُهُ إِلَى اللَّهِ فَيُرْسِلُ اللَّهُ عَلَيْهِمُ النَّغَفَ فِي رِقَابِهِمْ فَيُصْبِحُونَ فَرْسَى كَمَوْتِ نَفْسٍ وَاحِدَةٍ ‏.‏ وَيَهْبِطُ نَبِيُّ اللَّهِ عِيسَى وَأَصْحَابُهُ فَلاَ يَجِدُونَ مَوْضِعَ شِبْرٍ إِلاَّ قَدْ مَلأَهُ زَهَمُهُمْ وَنَتْنُهُمْ وَدِمَاؤُهُمْ فَيَرْغَبُونَ إِلَى اللَّهِ سُبْحَانَهُ فَيُرْسِلُ عَلَيْهِمْ طَيْرًا كَأَعْنَاقِ الْبُخْتِ فَتَحْمِلُهُمْ فَتَطْرَحُهُمْ حَيْثُ شَاءَ اللَّهُ ثُمَّ يُرْسِلُ اللَّهُ عَلَيْهِمْ مَطَرًا لاَ يُكِنُّ مِنْهُ بَيْتُ مَدَرٍ وَلاَ وَبَرٍ فَيَغْسِلُهُ حَتَّى يَتْرُكَهُ كَالزَّلَقَةِ ثُمَّ يُقَالُ لِلأَرْضِ أَنْبِتِي ثَمَرَتَكِ وَرُدِّي بَرَكَتَكِ فَيَوْمَئِذٍ تَأْكُلُ الْعِصَابَةُ مِنَ الرُّمَّانَةِ فَتُشْبِعُهُمْ وَيَسْتَظِلُّونَ بِقِحْفِهَا وَيُبَارِكُ اللَّهُ فِي الرِّسْلِ حَتَّى إِنَّ اللِّقْحَةَ مِنَ الإِبِلِ تَكْفِي الْفِئَامَ مِنَ النَّاسِ وَاللِّقْحَةَ مِنَ الْبَقَرِ تَكْفِي الْقَبِيلَةَ وَاللِّقْحَةَ مِنَ الْغَنَمِ تَكْفِي الْفَخِذَ ‏.‏ فَبَيْنَمَا هُمْ كَذَلِكَ إِذْ بَعَثَ اللَّهُ عَلَيْهِمْ رِيحًا طَيِّبَةً فَتَأْخُذُ تَحْتَ آبَاطِهِمْ فَتَقْبِضُ رُوحَ كُلِّ مُسْلِمٍ وَيَبْقَى سَائِرُ النَّاسِ يَتَهَارَجُونَ كَمَا تَتَهَارَجُ الْحُمُرُ فَعَلَيْهِمْ تَقُومُ السَّاعَةُ ‏"‏ ‏.‏\hadithno{4075}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Nawwas bin Sam'an Al-Kilabi said:"The Messenger of Allah (ﷺ) mentioned Dajjal, one morning, as something despised but also alarming, until we thought that he was in the stand of date-palm trees. When we came to the Messenger of Allah (ﷺ) in the evening, he saw that (fear) in us, and said: 'What is the matter with you?' We said: 'O Messenger of Allah, you mentioned Dajjal this morning, and you spoke of him as something despised but also alarming, until we thought that he was in the stand of date-palm trees.' He said: 'There are things that I fear more for you than the Dajjal. If he appears while I am among you, I will contend with him on your behalf, and if he appears when I am not among you, then each man must fend for himself, and Allah will take care of every Muslim on my behalf. He (Dajjal) will be a young man with curly hair and a protuberant eye; I liken him to 'Abdul-'Uzza bin Qatan. Whoever among you sees him, let him recite the first Verses of Surat Al-Kahf over him. He will emerge from Khallah, between Sham and Iraq, and will wreak havoc right and left. O slaves of Allah, remain steadfast.' We said: 'O Messenger of Allah, how long will he stay on earth?' He said: 'Forty days, one day like a year, one day like a month, one day like a week, and the rest of his days like your days.' We said: 'O Messenger of Allah, on that day which is like a year, will the prayers of one day suffice us?' He said: 'Make an estimate of time (and then observe prayer).' We said: 'How fast will he move through the earth?' He said: 'Like a rain cloud driving by the wind.' He said: 'He will come to some people and call them, and they will respond and believe in him. Then he will command the sky to rain and it will rain, and he will command the earth to produce vegetation and it will do so, and their flocks will come back in the evening with their humps taller, their udders fuller and their flanks fatter than they have ever been. Then he will come to some (other) people and call them, and they will reject him, so he will turn away from them and they will suffer drought and be left with nothing. Then he will pass through the wasteland and will say: "Bring forth your treasures," then go away, and its treasures will follow him like a swarm of bees. Then he will call a man brimming with youth and will strike him with a sword and cut him in two. He will put the two pieces as far apart as the distance between an archer and his target. Then he will call him and he will come with his face shining, laughing. While they are like that, Allah will send 'Eisa bin Maryam, who will come down at the white minaret in the east of Damascus, wearing two Mahrud[garment dyed with Wars and then Saffron], resting his hands on the wings of two angels. When he lowers his head, beads of perspiration will fall from it. Every disbeliever who smells the fragrance of his breath will die, and his breath will reach as far as his eye can see. Then he will set out and catch up with him (the Dajjal) at the gate of Ludd, and will kill him. Then the Prophet of Allah 'Eisa will come to some people whom Allah has protected, and he will wipe their faces and tell them of their status in Paradise. While they are like that, Allah will reveal to him: "O 'Eisa, I have brought forth some of My slaves whom no one will be able to kill, so take My slaves to Tur in safety." Then Gog and Magog will emerge and they will, as Allah describes, "swoop down from every mound."[21:96] The first of them will pass by lake Tiberias and drink from it, then the last of them will pass by it and will say: "There was water here once." The Prophet of Allah, 'Eisa and his companions will be besieged there until the head of an ox would be dearer to any one of them than one hundred Dinar are to any one of you today. Then, the Prophet of Allah, 'Eisa and his companions will supplicate Allah. Then Allah will send a worm in their necks and the next morning they will all die as one. The Prophet of Allah 'Eisa and his companions will come down and they will not find even the space of a hand span that is free of their stink, stench and blood. They will pray to Allah, and He will send birds with necks like the necks of Bactrian camels, which will pick them up and throw them wherever Allah wills. Then Allah will send rain which will not leave any house of clay or hair, and it will wash the earth until it leaves it like a mirror (or a smooth rock). Then it will be said to the earth: "Bring forth your fruits and bring back your blessing." On that day a group of people will eat from a (single) pomegranate and it will suffice them, and they will seek shelter beneath its skin. Allah will bless a milch- camel so that it will be sufficient for a large number of people, and a milch-cow will be sufficient for a whole tribe and a milch-ewe will be sufficient for a whole clan. While they are like that, Allah will send a pleasant wind which will seize them beneath their armpits and will take the soul of every Muslim, leaving the rest of the people fornicating like donkeys, and upon them will come the Hour}}
\hadithdefcmd{ibnmajah}{4076}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، حَدَّثَنَا ابْنُ جَابِرٍ، عَنْ يَحْيَى بْنِ جَابِرٍ الطَّائِيِّ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ النَّوَّاسَ بْنَ سَمْعَانَ، يَقُولُ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ سَيُوقِدُ الْمُسْلِمُونَ مِنْ قِسِيِّ يَأْجُوجَ وَمَأْجُوجَ وَنُشَّابِهِمْ وَأَتْرِسَتِهِمْ سَبْعَ سِنِينَ ‏"‏ ‏.‏\hadithno{4076}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Nawwas bin Sam'an that the Messenger of Allah (ﷺ) said:"The Muslims will use the bows, arrows and shields of Gog and Magog as firewood, for seven years}}
\hadithdefcmd{ibnmajah}{4077}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ الْمُحَارِبِيُّ، عَنْ إِسْمَاعِيلَ بْنِ رَافِعٍ أَبِي رَافِعٍ، عَنْ أَبِي زُرْعَةَ السَّيْبَانِيِّ، يَحْيَى بْنِ أَبِي عَمْرٍو عَنْ أَبِي أُمَامَةَ الْبَاهِلِيِّ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَكَانَ أَكْثَرُ خُطْبَتِهِ حَدِيثًا حَدَّثَنَاهُ عَنِ الدَّجَّالِ وَحَذَّرَنَاهُ فَكَانَ مِنْ قَوْلِهِ أَنْ قَالَ ‏"‏ إِنَّهُ لَمْ تَكُنْ فِتْنَةٌ فِي الأَرْضِ مُنْذُ ذَرَأَ اللَّهُ ذُرِّيَّةَ آدَمَ أَعْظَمَ مِنْ فِتْنَةِ الدَّجَّالِ وَإِنَّ اللَّهَ لَمْ يَبْعَثْ نَبِيًّا إِلاَّ حَذَّرَ أُمَّتَهُ الدَّجَّالَ وَأَنَا آخِرُ الأَنْبِيَاءِ وَأَنْتُمْ آخِرُ الأُمَمِ وَهُوَ خَارِجٌ فِيكُمْ لاَ مَحَالَةَ وَإِنْ يَخْرُجْ وَأَنَا بَيْنَ ظَهْرَانَيْكُمْ فَأَنَا حَجِيجٌ لِكُلِّ مُسْلِمٍ وَإِنْ يَخْرُجْ مِنْ بَعْدِي فَكُلُّ امْرِئٍ حَجِيجُ نَفْسِهِ وَاللَّهُ خَلِيفَتِي عَلَى كُلِّ مُسْلِمٍ وَإِنَّهُ يَخْرُجُ مِنْ خَلَّةٍ بَيْنَ الشَّامِ وَالْعِرَاقِ فَيَعِيثُ يَمِينًا وَيَعِيثُ شِمَالاً ‏.‏ يَا عِبَادَ اللَّهِ أَيُّهَا النَّاسُ فَاثْبُتُوا فَإِنِّي سَأَصِفُهُ لَكُمْ صِفَةً لَمْ يَصِفْهَا إِيَّاهُ نَبِيٌّ قَبْلِي إِنَّهُ يَبْدَأُ فَيَقُولُ أَنَا نَبِيٌّ وَلاَ نَبِيَّ بَعْدِي ثُمَّ يُثَنِّي فَيَقُولُ أَنَا رَبُّكُمْ ‏.‏ وَلاَ تَرَوْنَ رَبَّكُمْ حَتَّى تَمُوتُوا وَإِنَّهُ أَعْوَرُ وَإِنَّ رَبَّكُمْ لَيْسَ بِأَعْوَرَ وَإِنَّهُ مَكْتُوبٌ بَيْنَ عَيْنَيْهِ كَافِرٌ يَقْرَؤُهُ كُلُّ مُؤْمِنٍ كَاتِبٍ أَوْ غَيْرِ كَاتِبٍ وَإِنَّ مِنْ فِتْنَتِهِ أَنَّ مَعَهُ جَنَّةً وَنَارًا فَنَارُهُ جَنَّةٌ وَجَنَّتُهُ نَارٌ فَمَنِ ابْتُلِيَ بِنَارِهِ فَلْيَسْتَغِثْ بِاللَّهِ وَلْيَقْرَأْ فَوَاتِحَ الْكَهْفِ فَتَكُونَ عَلَيْهِ بَرْدًا وَسَلاَمًا كَمَا كَانَتِ النَّارُ عَلَى إِبْرَاهِيمَ وَإِنَّ مِنْ فِتْنَتِهِ أَنْ يَقُولَ لأَعْرَابِيٍّ أَرَأَيْتَ إِنْ بَعَثْتُ لَكَ أَبَاكَ وَأُمَّكَ أَتَشْهَدُ أَنِّي رَبُّكَ فَيَقُولُ نَعَمْ ‏.‏ فَيَتَمَثَّلُ لَهُ شَيْطَانَانِ فِي صُورَةِ أَبِيهِ وَأُمِّهِ فَيَقُولاَنِ يَا بُنَىَّ اتَّبِعْهُ فَإِنَّهُ رَبُّكَ ‏.‏ وَإِنَّ مِنْ فِتْنَتِهِ أَنْ يُسَلَّطَ عَلَى نَفْسٍ وَاحِدَةٍ فَيَقْتُلَهَا وَيَنْشُرَهَا بِالْمِنْشَارِ حَتَّى يُلْقَى شِقَّتَيْنِ ثُمَّ يَقُولُ انْظُرُوا إِلَى عَبْدِي هَذَا فَإِنِّي أَبْعَثُهُ الآنَ ثُمَّ يَزْعُمُ أَنَّ لَهُ رَبًّا غَيْرِي ‏.‏ فَيَبْعَثُهُ اللَّهُ وَيَقُولُ لَهُ الْخَبِيثُ مَنْ رَبُّكَ فَيَقُولُ رَبِّيَ اللَّهُ وَأَنْتَ عَدُوُّ اللَّهِ أَنْتَ الدَّجَّالُ وَاللَّهِ مَا كُنْتُ بَعْدُ أَشَدَّ بَصِيرَةً بِكَ مِنِّي الْيَوْمَ ‏"‏ ‏.‏ قَالَ أَبُو الْحَسَنِ الطَّنَافِسِيُّ فَحَدَّثَنَا الْمُحَارِبِيُّ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ الْوَلِيدِ الْوَصَّافِيُّ عَنْ عَطِيَّةَ عَنْ أَبِي سَعِيدٍ قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ ذَلِكَ الرَّجُلُ أَرْفَعُ أُمَّتِي دَرَجَةً فِي الْجَنَّةِ ‏"‏ ‏.‏ قَالَ قَالَ أَبُو سَعِيدٍ وَاللَّهِ مَا كُنَّا نُرَى ذَلِكَ الرَّجُلَ إِلاَّ عُمَرَ بْنَ الْخَطَّابِ حَتَّى مَضَى لِسَبِيلِهِ ‏.‏ قَالَ الْمُحَارِبِيُّ ثُمَّ رَجَعْنَا إِلَى حَدِيثِ أَبِي رَافِعٍ قَالَ ‏"‏ وَإِنَّ مِنْ فِتْنَتِهِ أَنْ يَأْمُرَ السَّمَاءَ أَنْ تُمْطِرَ فَتُمْطِرَ وَيَأْمُرَ الأَرْضَ أَنْ تُنْبِتَ فَتُنْبِتَ وَإِنَّ مِنْ فِتْنَتِهِ أَنْ يَمُرَّ بِالْحَىِّ فَيُكَذِّبُونَهُ فَلاَ تَبْقَى لَهُمْ سَائِمَةٌ إِلاَّ هَلَكَتْ وَإِنَّ مِنْ فِتْنَتِهِ أَنْ يَمُرَّ بِالْحَىِّ فَيُصَدِّقُونَهُ فَيَأْمُرَ السَّمَاءَ أَنْ تُمْطِرَ فَتُمْطِرَ وَيَأْمُرَ الأَرْضَ أَنْ تُنْبِتَ فَتُنْبِتَ حَتَّى تَرُوحَ مَوَاشِيهِمْ مِنْ يَوْمِهِمْ ذَلِكَ أَسْمَنَ مَا كَانَتْ وَأَعْظَمَهُ وَأَمَدَّهُ خَوَاصِرَ وَأَدَرَّهُ ضُرُوعًا وَإِنَّهُ لاَ يَبْقَى شَىْءٌ مِنَ الأَرْضِ إِلاَّ وَطِئَهُ وَظَهَرَ عَلَيْهِ إِلاَّ مَكَّةَ وَالْمَدِينَةَ لاَ يَأْتِيهِمَا مِنْ نَقْبٍ مِنْ نِقَابِهِمَا إِلاَّ لَقِيَتْهُ الْمَلاَئِكَةُ بِالسُّيُوفِ صَلْتَةً حَتَّى يَنْزِلَ عِنْدَ الظُّرَيْبِ الأَحْمَرِ عِنْدَ مُنْقَطَعِ السَّبَخَةِ فَتَرْجُفُ الْمَدِينَةُ بِأَهْلِهَا ثَلاَثَ رَجَفَاتٍ فَلاَ يَبْقَى مُنَافِقٌ وَلاَ مُنَافِقَةٌ إِلاَّ خَرَجَ إِلَيْهِ فَتَنْفِي الْخَبَثَ مِنْهَا كَمَا يَنْفِي الْكِيرُ خَبَثَ الْحَدِيدِ وَيُدْعَى ذَلِكَ الْيَوْمُ يَوْمَ الْخَلاَصِ ‏"‏ ‏.‏ فَقَالَتْ أُمُّ شَرِيكٍ بِنْتُ أَبِي الْعُكَرِ يَا رَسُولَ اللَّهِ فَأَيْنَ الْعَرَبُ يَوْمَئِذٍ قَالَ ‏"‏ هُمْ يَوْمَئِذٍ قَلِيلٌ وَجُلُّهُمْ بِبَيْتِ الْمَقْدِسِ وَإِمَامُهُمْ رَجُلٌ صَالِحٌ فَبَيْنَمَا إِمَامُهُمْ قَدْ تَقَدَّمَ يُصَلِّي بِهِمُ الصُّبْحَ إِذْ نَزَلَ عَلَيْهِمْ عِيسَى ابْنُ مَرْيَمَ الصُّبْحَ فَرَجَعَ ذَلِكَ الإِمَامُ يَنْكُصُ يَمْشِي الْقَهْقَرَى لِيَتَقَدَّمَ عِيسَى يُصَلِّي بِالنَّاسِ فَيَضَعُ عِيسَى يَدَهُ بَيْنَ كَتِفَيْهِ ثُمَّ يَقُولُ لَهُ تَقَدَّمْ فَصَلِّ فَإِنَّهَا لَكَ أُقِيمَتْ ‏.‏ فَيُصَلِّي بِهِمْ إِمَامُهُمْ فَإِذَا انْصَرَفَ قَالَ عِيسَى عَلَيْهِ السَّلاَمُ افْتَحُوا الْبَابَ ‏.‏ فَيُفْتَحُ وَوَرَاءَهُ الدَّجَّالُ مَعَهُ سَبْعُونَ أَلْفِ يَهُودِيٍّ كُلُّهُمْ ذُو سَيْفٍ مُحَلًّى وَسَاجٍ فَإِذَا نَظَرَ إِلَيْهِ الدَّجَّالُ ذَابَ كَمَا يَذُوبُ الْمِلْحُ فِي الْمَاءِ وَيَنْطَلِقُ هَارِبًا وَيَقُولُ عِيسَى عَلَيْهِ السَّلاَمُ إِنَّ لِي فِيكَ ضَرْبَةً لَنْ تَسْبِقَنِي بِهَا ‏.‏ فَيُدْرِكُهُ عِنْدَ بَابِ اللُّدِّ الشَّرْقِيِّ فَيَقْتُلُهُ فَيَهْزِمُ اللَّهُ الْيَهُودَ فَلاَ يَبْقَى شَىْءٌ مِمَّا خَلَقَ اللَّهُ يَتَوَارَى بِهِ يَهُودِيٌّ إِلاَّ أَنْطَقَ اللَّهُ ذَلِكَ الشَّىْءَ لاَ حَجَرَ وَلاَ شَجَرَ وَلاَ حَائِطَ وَلاَ دَابَّةَ - إِلاَّ الْغَرْقَدَةَ فَإِنَّهَا مِنْ شَجَرِهِمْ لاَ تَنْطِقُ - إِلاَّ قَالَ يَا عَبْدَ اللَّهِ الْمُسْلِمَ هَذَا يَهُودِيٌّ فَتَعَالَ اقْتُلْهُ ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ وَإِنَّ أَيَّامَهُ أَرْبَعُونَ سَنَةً السَّنَةُ كَنِصْفِ السَّنَةِ وَالسَّنَةُ كَالشَّهْرِ وَالشَّهْرُ كَالْجُمُعَةِ وَآخِرُ أَيَّامِهِ كَالشَّرَرَةِ يُصْبِحُ أَحَدُكُمْ عَلَى بَابِ الْمَدِينَةِ فَلاَ يَبْلُغُ بَابَهَا الآخَرَ حَتَّى يُمْسِيَ ‏"‏ ‏.‏ فَقِيلَ لَهُ يَا رَسُولَ اللَّهِ كَيْفَ نُصَلِّي فِي تِلْكَ الأَيَّامِ الْقِصَارِ قَالَ ‏"‏ تَقْدُرُونَ فِيهَا الصَّلاَةَ كَمَا تَقْدُرُونَهَا فِي هَذِهِ الأَيَّامِ الطِّوَالِ ثُمَّ صَلُّوا ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ فَيَكُونُ عِيسَى ابْنُ مَرْيَمَ عَلَيْهِ السَّلاَمُ فِي أُمَّتِي حَكَمًا عَدْلاً وَإِمَامًا مُقْسِطًا يَدُقُّ الصَّلِيبَ وَيَذْبَحُ الْخِنْزِيرَ وَيَضَعُ الْجِزْيَةَ وَيَتْرُكُ الصَّدَقَةَ فَلاَ يُسْعَى عَلَى شَاةٍ وَلاَ بَعِيرٍ وَتُرْفَعُ الشَّحْنَاءُ وَالتَّبَاغُضُ وَتُنْزَعُ حُمَةُ كُلِّ ذَاتِ حُمَةٍ حَتَّى يُدْخِلَ الْوَلِيدُ يَدَهُ فِي فِي الْحَيَّةِ فَلاَ تَضُرَّهُ وَتُفِرُّ الْوَلِيدَةُ الأَسَدَ فَلاَ يَضُرُّهَا وَيَكُونُ الذِّئْبُ فِي الْغَنَمِ كَأَنَّهُ كَلْبُهَا وَتُمْلأُ الأَرْضُ مِنَ السِّلْمِ كَمَا يُمْلأُ الإِنَاءُ مِنَ الْمَاءِ وَتَكُونُ الْكَلِمَةُ وَاحِدَةً فَلاَ يُعْبَدُ إِلاَّ اللَّهُ وَتَضَعُ الْحَرْبُ أَوْزَارَهَا وَتُسْلَبُ قُرَيْشٌ مُلْكَهَا وَتَكُونُ الأَرْضُ كَفَاثُورِ الْفِضَّةِ تُنْبِتُ نَبَاتَهَا بِعَهْدِ آدَمَ حَتَّى يَجْتَمِعَ النَّفَرُ عَلَى الْقِطْفِ مِنَ الْعِنَبِ فَيُشْبِعَهُمْ وَيَجْتَمِعَ النَّفَرُ عَلَى الرُّمَّانَةِ فَتُشْبِعَهُمْ وَيَكُونَ الثَّوْرُ بِكَذَا وَكَذَا مِنَ الْمَالِ وَتَكُونَ الْفَرَسُ بِالدُّرَيْهِمَاتِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَا يُرْخِصُ الْفَرَسَ قَالَ ‏"‏ لاَ تُرْكَبُ لِحَرْبٍ أَبَدًا ‏"‏ ‏.‏ قِيلَ لَهُ فَمَا يُغْلِي الثَّوْرَ قَالَ ‏"‏ تُحْرَثُ الأَرْضُ كُلُّهَا وَإِنَّ قَبْلَ خُرُوجِ الدَّجَّالِ ثَلاَثَ سَنَوَاتٍ شِدَادٍ يُصِيبُ النَّاسَ فِيهَا جُوعٌ شَدِيدٌ يَأْمُرُ اللَّهُ السَّمَاءَ فِي السَّنَةِ الأُولَى أَنْ تَحْبِسَ ثُلُثَ مَطَرِهَا وَيَأْمُرُ الأَرْضَ فَتَحْبِسُ ثُلُثَ نَبَاتِهَا ثُمَّ يَأْمُرُ السَّمَاءَ فِي السَّنَةِ الثَّانِيَةِ فَتَحْبِسُ ثُلُثَىْ مَطَرِهَا وَيَأْمُرُ الأَرْضَ فَتَحْبِسُ ثُلُثَىْ نَبَاتِهَا ثُمَّ يَأْمُرُ اللَّهُ السَّمَاءَ فِي السَّنَةِ الثَّالِثَةِ فَتَحْبِسُ مَطَرَهَا كُلَّهُ فَلاَ تَقْطُرُ قَطْرَةٌ وَيَأْمُرُ الأَرْضَ فَتَحْبِسُ نَبَاتَهَا كُلَّهُ فَلاَ تُنْبِتُ خَضْرَاءَ فَلاَ تَبْقَى ذَاتُ ظِلْفٍ إِلاَّ هَلَكَتْ إِلاَّ مَا شَاءَ اللَّهُ ‏"‏ ‏.‏ قِيلَ فَمَا يُعِيشُ النَّاسَ فِي ذَلِكَ الزَّمَانِ قَالَ ‏"‏ التَّهْلِيلُ وَالتَّكْبِيرُ وَالتَّسْبِيحُ وَالتَّحْمِيدُ وَيُجْرَى ذَلِكَ عَلَيْهِمْ مَجْرَى الطَّعَامِ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ سَمِعْتُ أَبَا الْحَسَنِ الطَّنَافِسِيَّ يَقُولُ سَمِعْتُ عَبْدَ الرَّحْمَنِ الْمُحَارِبِيَّ يَقُولُ يَنْبَغِي أَنْ يُدْفَعَ هَذَا الْحَدِيثُ إِلَى الْمُؤَدِّبِ حَتَّى يُعَلِّمَهُ الصِّبْيَانَ فِي الْكُتَّابِ ‏.‏\hadithno{4077}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Umamah Al-Bahili said:"The Messenger of Allah (ﷺ) addressed us, and most of his speech had to do with telling us about Dajjal. He warned about him, and among the things he said was: 'There will not be any tribulation on earth, since the time Allah created the offspring of Adam, that will be greater than the tribulation of Dajjal. Allah has not sent any Prophet but he warned his nation about Dajjal. I am the last of the Prophets, and you are the last of the nations. He will undoubtedly appear among you. If he appears while I am among you, I will contend with him on behalf of every Muslim, and if he appears while I am not among you, then each man must fend for himself and Allah will take care of every Muslim on my behalf. He will emerge from Al-Khallah, between Sham and Iraq, and will wreak havoc right and left. O slaves of Allah, remain steadfast. I will describe him to you in a manner in which none of the Prophets has described him before me. He will start by saying "I am a Prophet," and there is no Prophet after me. Then a second time he will say: "I am your Lord." But you will not see your Lord until you die. He is one-eyed, and your Lord is not one-eyed, and written between his eyes is Kafir. Every believer will read it, whether he is literate or illiterate. Part of his Fitnah will be that he will have with him Paradise and Hell, but his Hell will be a Paradise and his Paradise a Hell. Whoever is tested with his fire (hell), let him seek the help of Allah and recite the first Verses of Al-Kahf, then it will be cool and safe for him, as the fire was for Ibrahim. Part of his Fitnah will be that he will say to a Bedouin: "What do you think, if I resurrect your father and mother for you, will you bear witness that I am your Lord?" He will say: "Yes." Then two devils will appear to him in the form of his father and mother and will say: "O my son, follow him, for he is your Lord." And part of his Fitnah will be that he will overpower a single soul and kill him, then he will cut him with a saw until he falls in two pieces. Then he will say: "Look at this slave of mine; I will resurrect him now, then he will claim that he has a Lord other than me." Then Allah will resurrect him and the evil one will say to him: "Who is your Lord?" and he will say: "Allah is my Lord, and you are the enemy of Allah, you are Dajjal. By Allah, I have never had more insight about you than I have today." (An addition) Abul-Hasan Tanafisi said: "Muharibi told us: 'Ubaidullah bin al-Walid Al-Wassafi told us, from 'Atiyyah, that Abu Sa'eed said: "The Messenger of Allah (ﷺ) said: 'That man will be the highest in status in my nation in Paradise'" - He said: "Abu Sa'eed said: 'By Allah, we did not think that man would be anyone other than 'Umar bin Khattab, until he passed away. - Muharibi said: "Then we went back to the narration of Abu Rafi'." He said: - 'Part of his Fitnah will be that he will command the sky to rain, and it will rain, and he will command the earth to bring forth vegetation and it will do so. And part of his Fitnah will be that he will pass by a clan and they will disbelieve in him, so all their flocks will perish and none will be left. And part of his Fitnah will be that he will pass by a clan who will believe in him, so he will command the sky to rain, and it will rain, and he will command the earth to bring forth vegetation and it will do so, until their flocks will come back in the evening of that day, bigger and fatter than they have ever been, with their flanks stretched and their udders full of milk. There will be no part of the earth left that he does not enter and prevail over, except for Makkah and Al-Madinah, for he will not approach them on any of their mountain paths but he will be met by angels with unsheathed swords, until he will stop at the red hill at the end of the marsh. Then Al-Madinah will be shaken with its people three times, and no hypocrite, male or female, will be left, all will come out to him. Thus it will be cleansed of impurity just as the bellows cleanses the iron of dross. And that day will be called the Day of Deliverance.' "Umm Sharik bint Abi 'akar said: 'O Messenger of Allah, where will the Arabs be that day?' He said: 'On that day they will be few, and most of them will be in Baitul-Maqdis (Jerusalem), and their leader will be a righteous man. When their leader has stepped forward to lead them in subh prayer, 'Eisa bin Maryam will come down to them. Their leader will step backwards so that 'Eisa can come forward and lead the people in prayer, but 'Eisa will place his hand between his shoulders and say to him: "Go forward and pray, for the Iqamah was given for you." Then their leader will lead them in prayer. When he has finished, 'Eisa (as), will say: "Open the gate." So they will open it and behind it will be Dajjal with seventy thousand Jews, each of them carrying an adorned sword and wearing a greenish cloak. When Dajjal looks at him, he will start to melt as salt melts in water. He will run away, and 'Eisa (as), will say: "I have only one blow for you, which you will not be able to escape!" He will catch up with him at the eastern gate of Ludd, and will kill him. Then Allah will defeat the Jews, and there will be nothing left that Allah has created which the Jews will be able to hide behind, except that Allah will cause it to speak - no stone, no tree, no wall, no animal - except for Al-Gharqad (the box-thorn), for it is one of their trees, and will not speak - except that it will say: "O Muslim slave of Allah, here is a Jews, come and kill him!" "The Messenger of Allah (ﷺ) said: 'His (Dajjal's) days will number forty years: a year like half a year, a year like a month, a month like a week, and the rest of his days will be like sparks from a fire (i.e., they will pass quickly). One of you will enter the gate of Al-Madinah in the morning and not reach its other gate until evening comes.' It was said: 'O Messenger of Allah, how should we pray on those short days?' He said: 'Estimate (the times of) the prayer, as you do on these long days, then pray.' The Messenger of Allah (ﷺ) said: "Eisa bin Maryam (as), will be a just judge and a just ruler among my nation. He will break the cross, slaughter the pigs, abolish the Jizyah and charity will be left. No one will be appointed to (collect the Zakah of) sheep and camels. Grudges and mutual hatred will disappear and the venom of every venomous creature will be removed, so that a baby boy will but his hand in a snake and it will not harm him, and a baby girl will make a lion run away, and it will not harm her; and the wolf will be among the sheep like their sheepdog. The earth will be filled with peace just as a vessel is filled with water. The people will be united and none will be worshipped except Allah. War will cease and Quraish will no longer be in power. The earth will be like a silver platter, with its vegetation growing as it did at the time of Adam, until a group of people will gather around one bunch of grapes and it will suffice them, and a group will gather around a single pomegranate and it will suffice them. An ox will be sold for such and such amount of money, and a horse will be sold for a few Dirham.' They said: 'O Messenger of Allah, why will horses be so cheap?' He said: 'They will never be ridden in war again.' It was said to him: 'Why will oxen be so expensive?' He said: 'Because all the land will be tilled. Before Dajjal appears there will be three difficult years in which the people will suffer severe famine. In the first year, Allah will command the sky to withhold one third of its rain and the earth to withhold one third of its produce. In the second year, He will command the sky to withhold two thirds of its rain and the earth to withhold two-thirds of its produce. In the third year, he will command the sky to withhold all of its rain, and not a single drop will fall, and the earth to withhold all of its produce, and nothing will grow. All cloven-hoofed animals will die, except those that Allah wills.' It was said: 'What will the people live on at that time?' He said: 'Tahlil, Takbir, Tasbih and Tahmid. That will take the place of food for them.'" Abu 'Abdullah (Ibn Majah) said: "I heard Abul-Hasan Tanafisi say: 'I heard 'Abdur-Rahman Al-Muharibi say: "This Hadith should be sent to every teacher so that they can teach it to the children in the schools}}
\hadithdefcmd{ibnmajah}{4078}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَنْزِلَ عِيسَى ابْنُ مَرْيَمَ حَكَمًا مُقْسِطًا وَإِمَامًا عَدْلاً فَيَكْسِرُ الصَّلِيبَ وَيَقْتُلُ الْخِنْزِيرَ وَيَضَعُ الْجِزْيَةَ وَيَفِيضُ الْمَالُ حَتَّى لاَ يَقْبَلَهُ أَحَدٌ ‏"‏ ‏.‏\hadithno{4078}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:"The Hour will not begin until 'Eisa bin Maryam comes down as a just judge and a just ruler. He will break the cross, kill the pigs and abolish the Jizyah, and wealth will become so abundant that no one will accept it}}
\hadithdefcmd{ibnmajah}{4079}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي عَاصِمُ بْنُ عُمَرَ بْنِ قَتَادَةَ، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ تُفْتَحُ يَأْجُوجُ وَمَأْجُوجُ فَيَخْرُجُونَ كَمَا قَالَ اللَّهُ تَعَالَى ‏\{وَهُمْ مِنْ كُلِّ حَدَبٍ يَنْسِلُونَ\}‏ فَيَعُمُّونَ الأَرْضَ وَيَنْحَازُ مِنْهُمُ الْمُسْلِمُونَ حَتَّى تَصِيرَ بَقِيَّةُ الْمُسْلِمِينَ فِي مَدَائِنِهِمْ وَحُصُونِهِمْ وَيَضُمُّونَ إِلَيْهِمْ مَوَاشِيَهُمْ حَتَّى أَنَّهُمْ لَيَمُرُّونَ بِالنَّهَرِ فَيَشْرَبُونَهُ حَتَّى مَا يَذَرُونَ فِيهِ شَيْئًا فَيَمُرُّ آخِرُهُمْ عَلَى أَثَرِهِمْ فَيَقُولُ قَائِلُهُمْ لَقَدْ كَانَ بِهَذَا الْمَكَانِ مَرَّةً مَاءٌ وَيَظْهَرُونَ عَلَى الأَرْضِ فَيَقُولُ قَائِلُهُمْ هَؤُلاَءِ أَهْلُ الأَرْضِ قَدْ فَرَغْنَا مِنْهُمْ وَلَنُنَازِلَنَّ أَهْلَ السَّمَاءِ حَتَّى إِنَّ أَحَدَهُمْ لَيَهُزُّ حَرْبَتَهُ إِلَى السَّمَاءِ فَتَرْجِعُ مُخَضَّبَةً بِالدَّمِ فَيَقُولُونَ قَدْ قَتَلْنَا أَهْلَ السَّمَاءِ ‏.‏ فَبَيْنَمَا هُمْ كَذَلِكَ إِذْ بَعَثَ اللَّهُ دَوَابَّ كَنَغَفِ الْجَرَادِ فَتَأْخُذُ بِأَعْنَاقِهِمْ فَيَمُوتُونَ مَوْتَ الْجَرَادِ يَرْكَبُ بَعْضُهُمْ بَعْضًا فَيُصْبِحُ الْمُسْلِمُونَ لاَ يَسْمَعُونَ لَهُمْ حِسًّا فَيَقُولُونَ مَنْ رَجُلٌ يَشْرِي نَفْسَهُ وَيَنْظُرُ مَا فَعَلُوا فَيَنْزِلُ مِنْهُمْ رَجُلٌ قَدْ وَطَّنَ نَفْسَهُ عَلَى أَنْ يَقْتُلُوهُ فَيَجِدُهُمْ مَوْتَى فَيُنَادِيهِمْ أَلاَ أَبْشِرُوا فَقَدْ هَلَكَ عَدُوُّكُمْ ‏.‏ فَيَخْرُجُ النَّاسُ وَيُخْلُونَ سَبِيلَ مَوَاشِيهِمْ فَمَا يَكُونُ لَهُمْ رَعْىٌ إِلاَّ لُحُومُهُمْ فَتَشْكَرُ عَلَيْهَا كَأَحْسَنِ مَا شَكِرَتْ مِنْ نَبَاتٍ أَصَابَتْهُ قَطُّ ‏"‏ ‏.‏\hadithno{4079}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that the Messenger of Allah (ﷺ) said:"Gog and Magog people will be set free and they will emerge as Allah says: "swoop(ing) down from every mound."[21:96] They will spread throughout the earth, and the Muslims will flee from them until the remainder of the Muslims are in their cities and fortresses, taking their flocks with them. They will pass by a river and drink from it, until they leave nothing behind, and the last of them will follow in their footsteps and one of them will say: 'There was once water in this place.' They will prevail over the earth, then their leader will say: 'These are the people of the earth, and we have finished them off. Now let us fight the people of heaven!' Then one of them will throw his spear towards the sky, and it will come back down smeared with blood. And they will say: 'We have killed the people of heaven.' While they are like that, Allah will send a worm like the worm that is found in the noses of sheep, which will penetrate their necks and they will die like locusts, one on top of another. In the morning the Muslims will not hear any sound from them, and they will say: 'Who will sell his soul for the sake of Allah and see what they are doing?' A man will go down, having prepared himself to be killed by them, and he will find them dead, so he will call out to them: 'Be of good cheer, for your enemy is dead!' Then the people will come out and let their flocks loose, but they will not have anything to graze on except their flesh, and they will become very fat as if they were grazing on the best vegetation they ever found}}
\hadithdefcmd{ibnmajah}{4080}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، قَالَ حَدَّثَنَا أَبُو رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ يَأْجُوجَ وَمَأْجُوجَ يَحْفِرُونَ كُلَّ يَوْمٍ حَتَّى إِذَا كَادُوا يَرَوْنَ شُعَاعَ الشَّمْسِ قَالَ الَّذِي عَلَيْهِمُ ارْجِعُوا فَسَنَحْفِرُهُ غَدًا ‏.‏ فَيُعِيدُهُ اللَّهُ أَشَدَّ مَا كَانَ حَتَّى إِذَا بَلَغَتْ مُدَّتُهُمْ وَأَرَادَ اللَّهُ أَنْ يَبْعَثَهُمْ عَلَى النَّاسِ حَفَرُوا حَتَّى إِذَا كَادُوا يَرَوْنَ شُعَاعَ الشَّمْسِ قَالَ الَّذِي عَلَيْهِمُ ارْجِعُوا فَسَتَحْفِرُونَهُ غَدًا إِنْ شَاءَ اللَّهُ تَعَالَى وَاسْتَثْنَوْا فَيَعُودُونَ إِلَيْهِ وَهُوَ كَهَيْئَتِهِ حِينَ تَرَكُوهُ فَيَحْفِرُونَهُ وَيَخْرُجُونَ عَلَى النَّاسِ فَيَنْشِفُونَ الْمَاءَ وَيَتَحَصَّنُ النَّاسُ مِنْهُمْ فِي حُصُونِهِمْ فَيَرْمُونَ بِسِهَامِهِمْ إِلَى السَّمَاءِ فَتَرْجِعُ عَلَيْهَا الدَّمُ الَّذِي اجْفَظَّ فَيَقُولُونَ قَهَرْنَا أَهْلَ الأَرْضِ وَعَلَوْنَا أَهْلَ السَّمَاءِ فَيَبْعَثُ اللَّهُ نَغَفًا فِي أَقْفَائِهِمْ فَيَقْتُلُهُمْ بِهَا ‏"‏ ‏.‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّ دَوَابَّ الأَرْضِ لَتَسْمَنُ وَتَشْكَرُ شَكَرًا مِنْ لُحُومِهِمْ ‏"‏ ‏.‏\hadithno{4080}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:"Gog and Magog people dig every day until, when they can almost see the rays of the sun, the one in charge of them says: "Go back and we will dig it tomorrow." Then Allah puts it back, stronger than it was before. (This will continue) until, when their time has come, and Allah wants to send them against the people, they will dig until they can almost see the rays of the sun, then the one who is in charge of them will say: "Go back, and we will dig it tomorrow if Allah wills.' So they will say: "If Allah wills." Then they will come back to it and it will be as they left it. So they will dig and will come out to the people, and they will drink all the water. The people will fortify themselves against them in their fortresses. They will shoot their arrows towards the sky and they will come back with blood on them, and they will say: "We have defeated the people of earth and dominated the people of heaven." Then Allah will send a worm in the napes of their necks and will kill them thereby.'" The Messenger of Allah (ﷺ) said: "By the One in Whose Hand is my soul, the beasts of the earth will grow fat on their flesh}}
\hadithdefcmd{ibnmajah}{4081}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا الْعَوَّامُ بْنُ حَوْشَبٍ، حَدَّثَنِي جَبَلَةُ بْنُ سُحَيْمٍ، عَنْ مُؤْثِرِ بْنِ عَفَازَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ لَمَّا كَانَ لَيْلَةَ أُسْرِيَ بِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ لَقِيَ إِبْرَاهِيمَ وَمُوسَى وَعِيسَى فَتَذَاكَرُوا السَّاعَةَ فَبَدَءُوا بِإِبْرَاهِيمَ فَسَأَلُوهُ عَنْهَا فَلَمْ يَكُنْ عِنْدَهُ مِنْهَا عِلْمٌ ثُمَّ سَأَلُوا مُوسَى فَلَمْ يَكُنْ عِنْدَهُ مِنْهَا عِلْمٌ فَرُدَّ الْحَدِيثُ إِلَى عِيسَى ابْنِ مَرْيَمَ فَقَالَ قَدْ عُهِدَ إِلَىَّ فِيمَا دُونَ وَجْبَتِهَا فَأَمَّا وَجْبَتُهَا فَلاَ يَعْلَمُهَا إِلاَّ اللَّهُ ‏.‏ فَذَكَرَ خُرُوجَ الدَّجَّالِ قَالَ فَأَنْزِلُ فَأَقْتُلُهُ فَيَرْجِعُ النَّاسُ إِلَى بِلاَدِهِمْ فَيَسْتَقْبِلُهُمْ يَأْجُوجُ وَمَأْجُوجُ وَهُمْ مِنْ كُلِّ حَدَبٍ يَنْسِلُونَ فَلاَ يَمُرُّونَ بِمَاءٍ إِلاَّ شَرِبُوهُ وَلاَ بِشَىْءٍ إِلاَّ أَفْسَدُوهُ فَيَجْأَرُونَ إِلَى اللَّهِ فَأَدْعُو اللَّهَ أَنْ يُمِيتَهُمْ فَتَنْتُنُ الأَرْضُ مِنْ رِيحِهِمْ فَيَجْأَرُونَ إِلَى اللَّهِ فَأَدْعُو اللَّهَ فَيُرْسِلُ السَّمَاءَ بِالْمَاءِ فَيَحْمِلُهُمْ فَيُلْقِيهِمْ فِي الْبَحْرِ ثُمَّ تُنْسَفُ الْجِبَالُ وَتُمَدُّ الأَرْضُ مَدَّ الأَدِيمِ فَعُهِدَ إِلَىَّ مَتَى كَانَ ذَلِكَ كَانَتِ السَّاعَةُ مِنَ النَّاسِ كَالْحَامِلِ الَّتِي لاَ يَدْرِي أَهْلُهَا مَتَى تَفْجَؤُهُمْ بِوِلاَدَتِهَا ‏.‏ قَالَ الْعَوَّامُ وَوُجِدَ تَصْدِيقُ ذَلِكَ فِي كِتَابِ اللَّهِ تَعَالَى ‏\{حَتَّى إِذَا فُتِحَتْ يَأْجُوجُ وَمَأْجُوجُ وَهُمْ مِنْ كُلِّ حَدَبٍ يَنْسِلُونَ\}‏ ‏.‏\hadithno{4081}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that 'Abdullah bin Mas'ud said:"On the night on which the Messenger of Allah (ﷺ) was taken on the Night Journey (Isra'), he met Ibrahim, Musa and 'Eisa, and they discussed the Hour. They started with Ibrahim, and asked him about it, but he did not have any knowledge of it. Then they asked Musa, and he did not have any knowledge of it. Then they asked 'Eisa bin Maryam, and he said: 'I have been assigned to some tasks before it happens.' As for as when it will take place, no one knows that except Allah. Then he mentioned Dajjal and said: 'I will descend and kill him, then the people will return to their own lands and will be confronted with Gog and Magog people, who will: "swoop down from every mound."[21:96] They will not pass by any water but they will drink it, (and they will not pass) by anything but they will spoil it. They (the people) will beseech Allah, and I will pray to Allah to kill them. The earth will be filled with their stench and (the people) will beseech Allah and I will pray to Allah, then the sky will send down rain that will carry them and throw them in the sea. Then the mountains will turn to dust and the earth will be stretched out like a hide. I have been promised that when that happens, the Hour will come upon the people, like a pregnant woman whose family does not know when she will suddenly give birth.'" (One of the narrators) 'Awwam said: "Confirmation of that is found in the Book of Allah, where Allah says: "Until, when Gog and Magog people are let loose (from their barrier), and they swoop down from every mound (21:)}}
\hadithdefcmd{ibnmajah}{4082}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، حَدَّثَنَا عَلِيُّ بْنُ صَالِحٍ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ بَيْنَمَا نَحْنُ عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِذْ أَقْبَلَ فِتْيَةٌ مِنْ بَنِي هَاشِمٍ فَلَمَّا رَآهُمُ النَّبِيُّ ـ صلى الله عليه وسلم ـ اغْرَوْرَقَتْ عَيْنَاهُ وَتَغَيَّرَ لَوْنُهُ قَالَ فَقُلْتُ مَا نَزَالُ نَرَى فِي وَجْهِكَ شَيْئًا نَكْرَهُهُ ‏.‏ فَقَالَ ‏ "‏ إِنَّا أَهْلُ بَيْتٍ اخْتَارَ اللَّهُ لَنَا الآخِرَةَ عَلَى الدُّنْيَا وَإِنَّ أَهْلَ بَيْتِي سَيَلْقَوْنَ بَعْدِي بَلاَءً وَتَشْرِيدًا وَتَطْرِيدًا حَتَّى يَأْتِيَ قَوْمٌ مِنْ قِبَلِ الْمَشْرِقِ مَعَهُمْ رَايَاتٌ سُودٌ فَيَسْأَلُونَ الْخَيْرَ فَلاَ يُعْطَوْنَهُ فَيُقَاتِلُونَ فَيُنْصَرُونَ فَيُعْطَوْنَ مَا سَأَلُوا فَلاَ يَقْبَلُونَهُ حَتَّى يَدْفَعُوهَا إِلَى رَجُلٍ مِنْ أَهْلِ بَيْتِي فَيَمْلَؤُهَا قِسْطًا كَمَا مَلَؤُوهَا جَوْرًا فَمَنْ أَدْرَكَ ذَلِكَ مِنْكُمْ فَلْيَأْتِهِمْ وَلَوْ حَبْوًا عَلَى الثَّلْجِ ‏"‏ ‏.‏\hadithno{4082}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that 'Abdullah said:"While we were with the Messenger of Allah (ﷺ), some youngsters from Banu Hashim came along. When the Prophet (ﷺ) saw them, his eyes filled with tears and his color changed. I said: 'We still see something in your face that we do not like (to see).' He said: 'We are members of a Household for whom Allah has chosen the Hereafter over this world. The people of my Household will face calamity, expulsion and exile after I am gone, until some people will come from the east carrying black banners. They will ask for something good but will not be given it. Then they will fight and will be victorious, then they will be given what they wanted, but they will not accept it and will give leadership to a man from my family. Then they will fill it with justice just as it was filled with injustice. Whoever among you lives to see that, let him go to them even if he has to crawl over snow}}
\hadithdefcmd{ibnmajah}{4083}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ مَرْوَانَ الْعُقَيْلِيُّ، حَدَّثَنَا عُمَارَةُ بْنُ أَبِي حَفْصَةَ، عَنْ زَيْدٍ الْعَمِّيِّ، عَنْ أَبِي صِدِّيقٍ النَّاجِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ يَكُونُ فِي أُمَّتِي الْمَهْدِيُّ إِنْ قُصِرَ فَسَبْعٌ وَإِلاَّ فَتِسْعٌ فَتَنْعَمُ فِيهِ أُمَّتِي نَعْمَةً لَمْ يَنْعَمُوا مِثْلَهَا قَطُّ تُؤْتَى أُكُلَهَا وَلاَ تَدَّخِرُ مِنْهُمْ شَيْئًا وَالْمَالُ يَوْمَئِذٍ كُدُوسٌ فَيَقُومُ الرَّجُلُ فَيَقُولُ يَا مَهْدِيُّ أَعْطِنِي فَيَقُولُ خُذْ ‏"‏ ‏.‏\hadithno{4083}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that the Prophet (ﷺ) said:"The Mahdi will be among my nation. If he lives for a short period, it will be seven, and if he lives for a long period, it will be nine, during which my nation will enjoy a time of ease such as it has never enjoyed. The land will bring forth its yield and will not hold back anything, and wealth at that time will be piled up. A man will stand up and say: 'O Mahdi, give me!' He will say: 'Take}}
\hadithdefcmd{ibnmajah}{4084}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَأَحْمَدُ بْنُ يُوسُفَ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ سُفْيَانَ الثَّوْرِيِّ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ الرَّحَبِيِّ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ يَقْتَتِلُ عِنْدَ كَنْزِكُمْ ثَلاَثَةٌ كُلُّهُمُ ابْنُ خَلِيفَةٍ ثُمَّ لاَ يَصِيرُ إِلَى وَاحِدٍ مِنْهُمْ ثُمَّ تَطْلُعُ الرَّايَاتُ السُّودُ مِنْ قِبَلِ الْمَشْرِقِ فَيَقْتُلُونَكُمْ قَتْلاً لَمْ يُقْتَلْهُ قَوْمٌ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ شَيْئًا لاَ أَحْفَظُهُ فَقَالَ ‏"‏ فَإِذَا رَأَيْتُمُوهُ فَبَايِعُوهُ وَلَوْ حَبْوًا عَلَى الثَّلْجِ فَإِنَّهُ خَلِيفَةُ اللَّهِ الْمَهْدِيُّ ‏"‏ ‏.‏\hadithno{4084}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Thawban that the Messenger of Allah (ﷺ) said:"Three will fight one another for your treasure, each one of them the son of a caliph, but none of them will gain it. Then the black banners will come from the east, and they will kill you in an unprecedented manner." Then he mentioned something that I do not remember, then he said: "When you see them, then pledge your allegiance to them even if you have to crawl over the snow, for that is the caliph of Allah, Mahdi}}
\hadithdefcmd{ibnmajah}{4085}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو دَاوُدَ الْحَفَرِيُّ، حَدَّثَنَا يَاسِينُ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ ابْنِ الْحَنَفِيَّةِ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْمَهْدِيُّ مِنَّا أَهْلَ الْبَيْتِ يُصْلِحُهُ اللَّهُ فِي لَيْلَةٍ ‏"‏ ‏.‏\hadithno{4085}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from 'Ali that the Messenger of Allah (ﷺ) said:"Mahdi is one of us, the people of the Household. Allah will rectify him in a single night}}
\hadithdefcmd{ibnmajah}{4086}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ الْمَلِكِ، حَدَّثَنَا أَبُو الْمَلِيحِ الرَّقِّيُّ، عَنْ زِيَادِ بْنِ بَيَانٍ، عَنْ عَلِيِّ بْنِ نُفَيْلٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ كُنَّا عِنْدَ أُمِّ سَلَمَةَ فَتَذَاكَرْنَا الْمَهْدِيَّ فَقَالَتْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الْمَهْدِيُّ مِنْ وَلَدِ فَاطِمَةَ ‏"‏ ‏.‏\hadithno{4086}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Sa'eed bin Musayyab said:"We were with Umm Salamah and we were discussing Mahdi. She said: 'I heard the Messenger of Allah (ﷺ) say: "Mahdi will be one of the descendents of Fatimah}}
\hadithdefcmd{ibnmajah}{4087}{حَدَّثَنَا هَدِيَّةُ بْنُ عَبْدِ الْوَهَّابِ، حَدَّثَنَا سَعْدُ بْنُ عَبْدِ الْحَمِيدِ بْنِ جَعْفَرٍ، عَنْ عَلِيِّ بْنِ زِيَادٍ الْيَمَامِيِّ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ نَحْنُ وَلَدَ عَبْدِ الْمُطَّلِبِ سَادَةُ أَهْلِ الْجَنَّةِ أَنَا وَحَمْزَةُ وَعَلِيٌّ وَجَعْفَرٌ وَالْحَسَنُ وَالْحُسَيْنُ وَالْمَهْدِيُّ ‏"‏ ‏.‏\hadithno{4087}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:"I heard the Messenger of Allah (ﷺ) say: 'We, the sons of 'Abdul-Muttalib, will be leaders of the people of Paradise: Myself, Hamzah. 'Ali, Ja'far, Hasan, Husain and Mahdi}}
\hadithdefcmd{ibnmajah}{4088}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى الْمِصْرِيُّ، وَإِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، قَالاَ حَدَّثَنَا أَبُو صَالِحٍ عَبْدُ الْغَفَّارِ بْنُ دَاوُدَ الْحَرَّانِيُّ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ أَبِي زُرْعَةَ، عَمْرِو بْنِ جَابِرٍ الْحَضْرَمِيِّ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ جَزْءٍ الزُّبَيْدِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ يَخْرُجُ نَاسٌ مِنَ الْمَشْرِقِ فَيُوَطِّئُونَ لِلْمَهْدِيِّ ‏"‏ ‏.‏ يَعْنِي سُلْطَانَهُ ‏.‏\hadithno{4088}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin Harith bin Jaz' Az-Zabidi that the Messenger of Allah (ﷺ) said:"People will come from the east, paving the way for Mahdi," meaning, for his rule}}
\hadithdefcmd{ibnmajah}{4089}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنِ الأَوْزَاعِيِّ، عَنْ حَسَّانَ بْنِ عَطِيَّةَ، قَالَ مَالَ مَكْحُولٌ وَابْنُ أَبِي زَكَرِيَّا إِلَى خَالِدِ بْنِ مَعْدَانَ وَمِلْتُ مَعَهُمَا فَحَدَّثَنَا عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، قَالَ قَالَ لِي جُبَيْرٌ انْطَلِقْ بِنَا إِلَى ذِي مِخْمَرٍ - وَكَانَ رَجُلاً مِنْ أَصْحَابِ النَّبِيِّ ـ صلى الله عليه وسلم ـ - فَانْطَلَقْتُ مَعَهُمَا فَسَأَلَهُ عَنِ الْهُدْنَةِ فَقَالَ سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ سَتُصَالِحُكُمُ الرُّومُ صُلْحًا آمِنًا ثُمَّ تَغْزُونَ أَنْتُمْ وَهُمْ عَدُوًّا فَتُنْصَرُونَ وَتَغْنَمُونَ وَتَسْلَمُونَ ثُمَّ تَنْصَرِفُونَ حَتَّى تَنْزِلُوا بِمَرْجٍ ذِي تُلُولٍ فَيَرْفَعُ رَجُلٌ مِنْ أَهْلِ الصَّلِيبِ الصَّلِيبَ فَيَقُولُ غَلَبَ الصَّلِيبُ ‏.‏ فَيَغْضَبُ رَجُلٌ مِنَ الْمُسْلِمِينَ فَيَقُومُ إِلَيْهِ فَيَدُقُّهُ فَعِنْدَ ذَلِكَ تَغْدِرُ الرُّومُ وَيَجْتَمِعُونَ لِلْمَلْحَمَةِ ‏"‏ ‏.‏\hadithno{4089}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Jubair bin Nufair said:“Jubair said to me: ‘Let’s go to Dhu Mikhmar, who was a man from among the Companions of the Prophet (ﷺ).’ So I went with them and he asked him about the peace treaty (with the Romans). He said: ‘I heard the Prophet (ﷺ) say: “The Romans will enter into a peace treaty with you, then you and they will fight one another as enemies, and you will be victorious; you will collect the spoils of war and be safe. Then you will come back until you stop in a meadow with many hillocks. A man from among the people of the Cross will raise the Cross and will say: ‘The Cross has prevailed.’ Then a man among the Muslims will become angry and will go and break the Cross. Then the Romans will prove treacherous (breaking the treaty) (and will gather) for the fierce battle.”}}
\hadithdefcmd{ibnmajah}{4089p2}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ حَسَّانَ بْنِ عَطِيَّةَ، بِإِسْنَادِهِ نَحْوَهُ وَزَادَ فِيهِ فَيَجْتَمِعُونَ لِلْمَلْحَمَةِ فَيَأْتُونَ حِينَئِذٍ تَحْتَ ثَمَانِينَ غَايَةٍ تَحْتَ كُلِّ غَايَةٍ اثْنَا عَشَرَ أَلْفًا ‏.‏\hadithno{4089.2}\hadithtrans{Another chain with a similar report to which he added:"They will gather for the fierce battle, and at that time they will come with eighty banners, under each of which will be twelve thousand troops}}
\hadithdefcmd{ibnmajah}{4090}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عُثْمَانُ بْنُ أَبِي الْعَاتِكَةِ، عَنْ سُلَيْمَانَ بْنِ حَبِيبٍ الْمُحَارِبِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا وَقَعَتِ الْمَلاَحِمُ بَعَثَ اللَّهُ بَعْثًا مِنَ الْمَوَالِي هُمْ أَكْرَمُ الْعَرَبِ فَرَسًا وَأَجْوَدُهُ سِلاَحًا يُؤَيِّدُ اللَّهُ بِهِمُ الدِّينَ ‏"‏ ‏.‏\hadithno{4090}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“When the fierce battles take place, Allah will send a troop of freed slaves who will be the best Arab horsemen and the best armed, with whom Allah will support His religion.”}}
\hadithdefcmd{ibnmajah}{4091}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، عَنْ نَافِعِ بْنِ عُتْبَةَ بْنِ أَبِي وَقَّاصٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ سَتُقَاتِلُونَ جَزِيرَةَ الْعَرَبِ فَيَفْتَحُهَا اللَّهُ ثُمَّ تُقَاتِلُونَ الرُّومَ فَيَفْتَحُهَا اللَّهُ ثُمَّ تُقَاتِلُونَ الدَّجَّالَ فَيَفْتَحُهَا اللَّهُ ‏"‏ ‏.‏ قَالَ جَابِرٌ فَمَا يَخْرُجُ الدَّجَّالُ حَتَّى تُفْتَحَ الرُّومُ ‏.‏\hadithno{4091}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin Samurah, that Nafi' bin 'Utbah bin Abu Waqqas narrated that the Prophet (ﷺ) said:"You will fight the Arabian Peninsula and victory will be granted by Allah. Then you will fight the Romans and victory will be granted (by Allah). Then you will fight Dajjal and victory will be granted (by Allah)." Jabir said: "Dajjal will not appear until you have fought the Romans}}
\hadithdefcmd{ibnmajah}{4092}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، وَإِسْمَاعِيلُ بْنُ عَيَّاشٍ، قَالاَ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي مَرْيَمَ، عَنِ الْوَلِيدِ بْنِ سُفْيَانَ بْنِ أَبِي مَرْيَمَ، عَنْ يَزِيدَ بْنِ قُطَيْبٍ السَّكُونِيِّ، - وَقَالَ الْوَلِيدُ يَزِيدُ بْنُ قُطْبَةَ - عَنْ أَبِي بَحْرِيَّةَ، عَنْ مُعَاذِ بْنِ جَبَلٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْمَلْحَمَةُ الْكُبْرَى وَفَتْحُ الْقُسْطُنْطِينِيَّةِ وَخُرُوجُ الدَّجَّالِ فِي سَبْعَةِ أَشْهُرٍ ‏"‏ ‏.‏\hadithno{4092}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Mu'adh bin Jabal that the Prophet (ﷺ) said:"The great fierce battle, the conquest of Constantinople and the emergence of Dajjal, will all happen within seven months}}
\hadithdefcmd{ibnmajah}{4093}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا بَقِيَّةُ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ أَبِي بِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ بَيْنَ الْمَلْحَمَةِ وَفَتْحِ الْمَدِينَةِ سِتُّ سِنِينَ وَيَخْرُجُ الدَّجَّالُ فِي السَّابِعَةِ ‏"‏ ‏.‏\hadithno{4093}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from 'Abdullah bin Busr that the Messenger of Allah (ﷺ) said:"Between the fierce battle and the conquest of Al-Madinah will be six years, and the appearance of Dajjal will come in the seventh}}
\hadithdefcmd{ibnmajah}{4094}{حَدَّثَنَا عَلِيُّ بْنُ مَيْمُونٍ الرَّقِّيُّ، حَدَّثَنَا أَبُو يَعْقُوبَ الْحُنَيْنِيُّ، عَنْ كَثِيرِ بْنِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ عَوْفٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَكُونَ أَدْنَى مَسَالِحِ الْمُسْلِمِينَ بِبَوْلاَءَ ‏"‏ ‏.‏ ثُمَّ قَالَ ـ صلى الله عليه وسلم ـ ‏"‏ يَا عَلِيُّ يَا عَلِيُّ يَا عَلِيُّ ‏"‏ ‏.‏ قَالَ بِأَبِي وَأُمِّي ‏.‏ قَالَ ‏"‏ إِنَّكُمْ سَتُقَاتِلُونَ بَنِي الأَصْفَرِ وَيُقَاتِلُهُمُ الَّذِينَ مِنْ بَعْدِكُمْ حَتَّى تَخْرُجَ إِلَيْهِمْ رُوقَةُ الإِسْلاَمِ أَهْلُ الْحِجَازِ الَّذِينَ لاَ يَخَافُونَ فِي اللَّهِ لَوْمَةَ لاَئِمٍ فَيَفْتَتِحُونَ الْقُسْطُنْطِينِيَّةَ بِالتَّسْبِيحِ وَالتَّكْبِيرِ فَيُصِيبُونَ غَنَائِمَ لَمْ يُصِيبُوا مِثْلَهَا حَتَّى يَقْتَسِمُوا بِالأَتْرِسَةِ وَيَأْتِي آتٍ فَيَقُولُ إِنَّ الْمَسِيحَ قَدْ خَرَجَ فِي بِلاَدِكُمْ أَلاَ وَهِيَ كِذْبَةٌ فَالآخِذُ نَادِمٌ وَالتَّارِكُ نَادِمٌ ‏"‏ ‏.‏\hadithno{4094}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Kathir bin ‘Abdullah bin ‘Amr bin ‘Awf, from his father, that his grandfather said:“The Messenger of Allah (ﷺ) said: ‘The Hour will not begin until the closest Muslim outpost will be at Baula’.’ Then he said: ‘O ‘Ali, O ‘Ali, O ‘Ali.’ He (‘Ali) said: ‘May my father and mother be ransomed for you.’ He said: ‘You will fight Banu Asfar (the Romans) and those who come after you will fight them, until the best of the Muslims go out to fight them, the people of Hijaz who do not fear the blame of anyone for the sake of Allah. They will conquer Constantinople with Tasbih and Takbir and will acquire such spoils of war as has never been seen before, which they will distribute by the shieldful. Someone will come and say: “Masih has appeared in your land!” But he will be lying, so the one who takes (some of the spoils) will regret it, and the one who leaves it behind will regret it too.’”}}
\hadithdefcmd{ibnmajah}{4095}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْعَلاَءِ، حَدَّثَنِي بُسْرُ بْنُ عُبَيْدِ اللَّهِ، حَدَّثَنِي أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ، حَدَّثَنِي عَوْفُ بْنُ مَالِكٍ الأَشْجَعِيُّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَكُونُ بَيْنَكُمْ وَبَيْنَ بَنِي الأَصْفَرِ هُدْنَةٌ فَيَغْدِرُونَ بِكُمْ فَيَسِيرُونَ إِلَيْكُمْ فِي ثَمَانِينَ غَايَةً تَحْتَ كُلِّ غَايَةٍ اثْنَا عَشَرَ أَلْفًا ‏"‏ ‏.‏\hadithno{4095}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Awf bin Malik Al-Ashja’i that the Messenger of Allah (ﷺ) said:“There will be a treaty between you and Banu Asfar (The Romans), but they will betray you and will march against you with eighty banners, under each of which there will be twelve thousand troops.”}}
\hadithdefcmd{ibnmajah}{4096}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا نِعَالُهُمُ الشَّعَرُ وَلاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا صِغَارَ الأَعْيُنِ ‏"‏ ‏.‏\hadithno{4096}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah conveying it from the Prophet (ﷺ):“The Hour will not begin until you fight people with shoes of hair, and the Hour will not begin until you fight people with small eyes.”}}
\hadithdefcmd{ibnmajah}{4097}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا صِغَارَ الأَعْيُنِ ذُلْفَ الأُنُوفِ كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطْرَقَةُ وَلاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا نِعَالُهُمُ الشَّعَرُ ‏"‏ ‏.‏\hadithno{4097}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:‘The Hour will not begin until you fight people with small eyes and small, even noses, as if their faces were hammered shields. And the Hour will not begin until you fight people whose shoes are made of hair.”}}
\hadithdefcmd{ibnmajah}{4098}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةُ، حَدَّثَنَا أَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنَا الْحَسَنُ، عَنْ عَمْرِو بْنِ تَغْلِبَ، قَالَ سَمِعْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّ مِنْ أَشْرَاطِ السَّاعَةِ أَنْ تُقَاتِلُوا قَوْمًا عِرَاضَ الْوُجُوهِ كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطْرَقَةُ وَإِنَّ مِنْ أَشْرَاطِ السَّاعَةِ أَنْ تُقَاتِلُوا قَوْمًا يَنْتَعِلُونَ الشَّعَرَ ‏"‏ ‏.‏\hadithno{4098}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that ‘Amr bin Taghlib said:“I heard the Prophet (ﷺ) say: ‘One of the portents of the Hour is that you fight people with broad faces, as if their faces are hammered shields. And one of hte portents of the Hour is that you will fight people who wear shoes of hair.’”}}
\hadithdefcmd{ibnmajah}{4099}{حَدَّثَنَا الْحَسَنُ بْنُ عَرَفَةَ، حَدَّثَنَا عَمَّارُ بْنُ مُحَمَّدٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا صِغَارَ الأَعْيُنِ عِرَاضَ الْوُجُوهِ كَأَنَّ أَعْيُنَهُمْ حَدَقُ الْجَرَادِ كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطْرَقَةُ يَنْتَعِلُونَ الشَّعَرَ وَيَتَّخِذُونَ الدَّرَقَ يَرْبِطُونَ خَيْلَهُمْ بِالنَّخْلِ ‏"‏ ‏.‏\hadithno{4099}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Messenger of Allah (ﷺ) said:“The Hour will not begin until you fight people with small eyes and wide faces, as if their eyes are the pupils of locusts and as if their faces are hammered shields. They will be wearing shoes of hair, using leather shields and tying their horses to date-palm trees.”}}
