% Auto-generated chapter 6 for ibnmajah
% Hadiths in this chapter: 205

\hadithdefcmd{ibnmajah}{1433}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لِلْمُسْلِمِ عَلَى الْمُسْلِمِ سِتَّةٌ بِالْمَعْرُوفِ يُسَلِّمُ عَلَيْهِ إِذَا لَقِيَهُ وَيُجِيبُهُ إِذَا دَعَاهُ وَيُشَمِّتُهُ إِذَا عَطَسَ وَيَعُودُهُ إِذَا مَرِضَ وَيَتْبَعُ جِنَازَتَهُ إِذَا مَاتَ وَيُحِبُّ لَهُ مَا يُحِبُّ لِنَفْسِهِ ‏"‏ ‏.‏\hadithno{1433}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali said that the Messenger of Allah (ﷺ) said:“The Muslim has six courtesies due from the Muslim: He should greet him with Salam when he meets him; he should accept his invitation if he invites him; he should answer [by Yarhamuk-Allah (may Allah have mercy on you)] to him if he sneezes (and says Al- Hamdulillah); he should visit him if he falls sick; he should follow his funeral if he dies; and he should love for him what he loves for himself.”}}
\hadithdefcmd{ibnmajah}{1434}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ وَمُحَمَّدُ بْنُ بَشَّارٍ قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، عَنْ أَبِيهِ، عَنْ حَكِيمِ بْنِ أَفْلَحَ، عَنْ أَبِي مَسْعُودٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لِلْمُسْلِمِ عَلَى الْمُسْلِمِ أَرْبَعُ خِلاَلٍ يُشَمِّتُهُ إِذَا عَطَسَ وَيُجِيبُهُ إِذَا دَعَاهُ وَيَشْهَدُهُ إِذَا مَاتَ وَيَعُودُهُ إِذَا مَرِضَ ‏"‏ ‏.‏\hadithno{1434}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Mas’ud that the Prophet (ﷺ) said:“The Muslim has four things due from the Muslim: He should answer [by saying Yarhamuk-Allah (may Allah have mercy on you)] to him if he sneezes (and says Al-Hamdulillah); he should accept his invitation if he invites him; he should attend his funeral if he dies; and he should visit him if he falls sick.”}}
\hadithdefcmd{ibnmajah}{1435}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ خَمْسٌ مِنْ حَقِّ الْمُسْلِمِ عَلَى الْمُسْلِمِ رَدُّ التَّحِيَّةِ وَإِجَابَةُ الدَّعْوَةِ وَشُهُودُ الْجِنَازَةِ وَعِيَادَةُ الْمَرِيضِ وَتَشْمِيتُ الْعَاطِسِ إِذَا حَمِدَ اللَّهَ ‏"‏ ‏.‏\hadithno{1435}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Five are the rights of the Muslim: Returning his greeting, accepting his invitation; attending his funeral; visiting the sick; and answering (saying Yarhamuk-Allah) to the one who sneezes, if he praises Allah (says Al-Hamdu Lillah).”}}
\hadithdefcmd{ibnmajah}{1436}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ الْمُنْكَدِرِ، يَقُولُ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ عَادَنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مَاشِيًا وَأَبُو بَكْرٍ وَأَنَا فِي بَنِي سَلِمَةَ ‏.‏\hadithno{1436}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Jabir bin ‘Abdullah said:“The Messenger of Allah (ﷺ) came walking to visit me (when I was sick), as did Abu Bakr, when I was with Banu Salimah}}
\hadithdefcmd{ibnmajah}{1437}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا مَسْلَمَةُ بْنُ عُلَىٍّ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ لاَ يَعُودُ مَرِيضًا إِلاَّ بَعْدَ ثَلاَثٍ ‏.‏\hadithno{1437}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“The Prophet (ﷺ) did not visit any sick person until after three days.”}}
\hadithdefcmd{ibnmajah}{1438}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ السَّكُونِيُّ، عَنْ مُوسَى بْنِ مُحَمَّدِ بْنِ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا دَخَلْتُمْ عَلَى الْمَرِيضِ فَنَفِّسُوا لَهُ فِي الأَجَلِ فَإِنَّ ذَلِكَ لاَ يَرُدُّ شَيْئًا وَهُوَ يَطِيبُ بِنَفْسِ الْمَرِيضِ ‏"‏ ‏.‏\hadithno{1438}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Messenger of Allah (ﷺ) said:“When you enter upon one who is sick, cheer him up and give him hope of a long life, for that does not change anything (of the Divine Decree), but it will cheer the heart of the one who is sick.”}}
\hadithdefcmd{ibnmajah}{1439}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا صَفْوَانُ بْنُ هُبَيْرَةَ، حَدَّثَنَا أَبُو مَكِينٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ عَادَ رَجُلاً فَقَالَ ‏"‏ مَا تَشْتَهِي ‏"‏ ‏.‏ قَالَ أَشْتَهِي خُبْزَ بُرٍّ ‏.‏ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ مَنْ كَانَ عِنْدَهُ خُبْزُ بُرٍّ فَلْيَبْعَثْ إِلَى أَخِيهِ ‏"‏ ثُمَّ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ إِذَا اشْتَهَى مَرِيضُ أَحَدِكُمْ شَيْئًا فَلْيُطْعِمْهُ ‏"‏ ‏.‏\hadithno{1439}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) visited a man and said:“What do you long for?” He said: “I long for wheat bread.” The Prophet (ﷺ) said: “Whoever has any wheat bread, let him send it to his brother.” Then the Prophet (ﷺ) said: “If any sick person among you longs for something, then feed him.”}}
\hadithdefcmd{ibnmajah}{1440}{حَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا أَبُو يَحْيَى الْحِمَّانِيُّ، عَنِ الأَعْمَشِ، عَنْ يَزِيدَ الرَّقَاشِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ دَخَلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ عَلَى مَرِيضٍ يَعُودُهُ فَقَالَ ‏ "‏ أَتَشْتَهِي شَيْئًا أَتَشْتَهِي كَعْكًا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَطَلَبُوا لَهُ ‏.‏\hadithno{1440}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“The Prophet (ﷺ) entered upon a sick person to visit him. He said: ‘Do you long for anything? Do you long for Ka’k (a type of bread)?’ He said: ‘Yes.’ So they sent someone to bring some Ka’k for him.”}}
\hadithdefcmd{ibnmajah}{1441}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، حَدَّثَنِي كَثِيرُ بْنُ هِشَامٍ، حَدَّثَنَا جَعْفَرُ بْنُ بُرْقَانَ، عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ قَالَ لِي النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا دَخَلْتَ عَلَى مَرِيضٍ فَمُرْهُ أَنْ يَدْعُوَ لَكَ فَإِنَّ دُعَاءَهُ كَدُعَاءِ الْمَلاَئِكَةِ ‏"‏ ‏.‏\hadithno{1441}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Umar bin Al-Khattab said:“The Prophet (ﷺ) said to me: ‘When you enter upon one who is sick, tell him to pray for you, for his supplication is like the supplication of the angels.’”}}
\hadithdefcmd{ibnmajah}{1442}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنِ الْحَكَمِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ عَلِيٍّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَنْ أَتَى أَخَاهُ الْمُسْلِمَ عَائِدًا مَشَى فِي خِرَافَةِ الْجَنَّةِ حَتَّى يَجْلِسَ فَإِذَا جَلَسَ غَمَرَتْهُ الرَّحْمَةُ فَإِنْ كَانَ غُدْوَةً صَلَّى عَلَيْهِ سَبْعُونَ أَلْفَ مَلَكٍ حَتَّى يُمْسِيَ وَإِنْ كَانَ مَسَاءً صَلَّى عَلَيْهِ سَبْعُونَ أَلْفَ مَلَكٍ حَتَّى يُصْبِحَ ‏"‏ ‏.‏\hadithno{1442}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali said:“I heard the Messenger of Allah (ﷺ) say: ‘Whoever comes to his Muslim brother and visits him (when he is sick), he is walking among the harvest of Paradise until he sits down, and when he sits down he is covered with mercy. If it is morning, seventy thousand angels will send blessing upon him until evening, and if it is evening, seventy thousand angels will send blessing upon him until morning.’”}}
\hadithdefcmd{ibnmajah}{1443}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يُوسُفُ بْنُ يَعْقُوبَ، حَدَّثَنَا أَبُو سِنَانٍ الْقَسْمَلِيُّ، عَنْ عُثْمَانَ بْنِ أَبِي سَوْدَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ عَادَ مَرِيضًا نَادَى مُنَادٍ مِنَ السَّمَاءِ طِبْتَ وَطَابَ مَمْشَاكَ وَتَبَوَّأْتَ مِنَ الْجَنَّةِ مَنْزِلاً ‏"‏ ‏.‏\hadithno{1443}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:‘Whoever visits a sick person, a caller calls from heaven: ‘May you be happy, may your walking be blessed, and may you occupy a dignified position in Paradise.’”}}
\hadithdefcmd{ibnmajah}{1444}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَقِّنُوا مَوْتَاكُمْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏\hadithno{1444}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah that the Messenger of Allah (ﷺ) said:‘Urge your dying ones to say La ilaha illallah.”}}
\hadithdefcmd{ibnmajah}{1445}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنْ عُمَارَةَ بْنِ غَزِيَّةَ، عَنْ يَحْيَى بْنِ عُمَارَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَقِّنُوا مَوْتَاكُمْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏\hadithno{1445}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Sa’eed Al-Khudri said:“The Messenger of Allah (ﷺ) said: ‘Urge your dying ones to say: “La ilaha illallah.”}}
\hadithdefcmd{ibnmajah}{1446}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا كَثِيرُ بْنُ زَيْدٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لَقِّنُوا مَوْتَاكُمْ لاَ إِلَهَ إِلاَّ اللَّهُ الْحَلِيمُ الْكَرِيمُ سُبْحَانَ اللَّهِ رَبِّ الْعَرْشِ الْعَظِيمِ الْحَمْدُ لِلَّهِ رَبِّ الْعَالَمِينَ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ كَيْفَ لِلأَحْيَاءِ قَالَ ‏"‏ أَجْوَدُ وَأَجْوَدُ ‏"‏ ‏.‏\hadithno{1446}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ishaq bin ‘Abdullah bin Ja’far that his father said:“The Messenger of Allah (ﷺ) said: ‘Urge your dying ones to say: “La ilaha illallahul-Halimul-Karim, Subhan-Allahi Rabbil-‘Arshil-‘Azim, Al-Hamdu Lillahi Rabbil-‘alamin (None has the right to be worshipped but Allah, the Forbearing, the Most Kind. Glory is to Allah, Lord of the magnificent Throne; praise is to Allah, the Lord of the worlds).’” They said: ‘O Messenger of Allah, what about those who are alive?’ He said: ‘Even better, even better.’”}}
\hadithdefcmd{ibnmajah}{1447}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِذَا حَضَرْتُمُ الْمَرِيضَ أَوِ الْمَيِّتَ فَقُولُوا خَيْرًا فَإِنَّ الْمَلاَئِكَةَ يُؤَمِّنُونَ عَلَى مَا تَقُولُونَ ‏"‏ ‏.‏ فَلَمَّا مَاتَ أَبُو سَلَمَةَ أَتَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أَبَا سَلَمَةَ قَدْ مَاتَ ‏.‏ قَالَ ‏"‏ قُولِي اللَّهُمَّ اغْفِرْ لِي وَلَهُ وَأَعْقِبْنِي مِنْهُ عُقْبَى حَسَنَةً ‏"‏ ‏.‏ قَالَتْ فَفَعَلْتُ فَأَعْقَبَنِي اللَّهُ مَنْ هُوَ خَيْرٌ مِنْهُ ‏.‏ مُحَمَّدٌ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1447}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Umm Salamah said:“The Messenger of Allah (ﷺ) said: ‘When you visit one who is sick or dying, say good things, for the angels say: Amin to whatever you say.’ When Abu Salamah died, I came to the Prophet (ﷺ) and said: ‘O Messenger of Allah! Abu Salamah has died.’ He said: ‘Say: “Allahummaghfir li wa lahu, wa a’qibni minhu ‘uqba hasanah (O Allah, forgive me and him, and compensate me with someone better than him).’” She said: ‘I said that, and Allah compensated me with someone better than him: Muhammad the Messenger of Allah (ﷺ).’”}}
\hadithdefcmd{ibnmajah}{1448}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ بْنِ شَقِيقٍ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ، - وَلَيْسَ بِالنَّهْدِيِّ - عَنْ أَبِيهِ، عَنْ مَعْقِلِ بْنِ يَسَارٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اقْرَءُوهَا عِنْدَ مَوْتَاكُمْ ‏"‏ ‏.‏ يَعْنِي ‏\{يس\}‏ ‏.‏\hadithno{1448}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ma’qil bin Yasar that the Messenger of Allah (ﷺ) said:“Recite Qur’an near your dying ones,” meaning Ya-Sin}}
\hadithdefcmd{ibnmajah}{1449}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا الْمُحَارِبِيُّ، جَمِيعًا عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ الْحَارِثِ بْنِ فُضَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، قَالَ لَمَّا حَضَرَتْ كَعْبًا الْوَفَاةُ أَتَتْهُ أُمُّ بِشْرٍ بِنْتُ الْبَرَاءِ بْنِ مَعْرُورٍ فَقَالَتْ يَا أَبَا عَبْدِ الرَّحْمَنِ إِنْ لَقِيتَ فُلاَنًا فَاقْرَأْ عَلَيْهِ مِنِّي السَّلاَمَ ‏.‏ قَالَ غَفَرَ اللَّهُ لَكِ يَا أُمَّ بِشْرٍ نَحْنُ أَشْغَلُ مِنْ ذَلِكِ ‏.‏ قَالَتْ يَا أَبَا عَبْدِ الرَّحْمَنِ أَمَا سَمِعْتَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِنَّ أَرْوَاحَ الْمُؤْمِنِينَ فِي طَيْرٍ خُضْرٍ تَعْلُقُ فِي شَجَرِ الْجَنَّةِ ‏"‏ ‏.‏ قَالَ بَلَى ‏.‏ قَالَتْ فَهُوَ ذَاكَ ‏.‏\hadithno{1449}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdur-Rahman bin Ka’b bin Malik, about Ka’b:“When Ka’b was dying, Umm Bishr bint Bara’ bin Ma’rur came to him and said: ‘O Abu ‘Abdur-Rahman! If you meet so-and-so, convey Salam to him from me.’ He said: ‘May Allah forgive you, O Umm Bishr! We are too busy to think of that.’ She said: ‘O Abu ‘Abdur-Rahman! Did you not hear the Messenger of Allah (ﷺ) say: “The souls of the believers are in green birds, eating from the trees of Paradise”?’ He said: ‘Yes.’ She said: ‘That is what I mean.’”}}
\hadithdefcmd{ibnmajah}{1450}{حَدَّثَنَا أَحْمَدُ بْنُ الأَزْهَرِ، حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا يُوسُفُ بْنُ الْمَاجِشُونِ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُنْكَدِرِ، قَالَ دَخَلْتُ عَلَى جَابِرِ بْنِ عَبْدِ اللَّهِ وَهُوَ يَمُوتُ فَقُلْتُ اقْرَأْ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ السَّلاَمَ ‏.‏\hadithno{1450}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Muhammad bin Munkadir said:“I entered upon Jabir bin ‘Abdullah when he was dying, and I said: ‘Convey my Salam to the Messenger of Allah (ﷺ).’”}}
\hadithdefcmd{ibnmajah}{1451}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ عَطَاءٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ دَخَلَ عَلَيْهَا وَعِنْدَهَا حَمِيمٌ لَهَا يَخْنُقُهُ الْمَوْتُ فَلَمَّا رَأَى النَّبِيُّ ـ صلى الله عليه وسلم ـ مَا بِهَا قَالَ لَهَا ‏ "‏ لاَ تَبْتَئِسِي عَلَى حَمِيمِكِ فَإِنَّ ذَلِكَ مِنْ حَسَنَاتِهِ ‏"‏ ‏.‏\hadithno{1451}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) entered upon her and there was a close relative of hers who was in the throes of death. When the Prophet (ﷺ) saw how upset she was, he said:“Do not grieve for your relative, for that is part of his Hasanat (merits).”}}
\hadithdefcmd{ibnmajah}{1452}{حَدَّثَنَا بَكْرُ بْنُ خَلَفٍ أَبُو بِشْرٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ الْمُثَنَّى بْنِ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ الْمُؤْمِنُ يَمُوتُ بِعَرَقِ الْجَبِينِ ‏"‏ ‏.‏\hadithno{1452}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Buraidah from his father that the Prophet (ﷺ) said:“The believer dies with sweat on his brow.”}}
\hadithdefcmd{ibnmajah}{1453}{حَدَّثَنَا رَوْحُ بْنُ الْفَرَجِ، حَدَّثَنَا نَصْرُ بْنُ حَمَّادٍ، حَدَّثَنَا مُوسَى بْنُ كَرْدَمٍ، عَنْ مُحَمَّدِ بْنِ قَيْسٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ سَأَلْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَتَى تَنْقَطِعُ مَعْرِفَةُ الْعَبْدِ مِنَ النَّاسِ قَالَ ‏ "‏ إِذَا عَايَنَ ‏"‏ ‏.‏\hadithno{1453}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Musa said:“I asked the Messenger of Allah (ﷺ): ‘When does a person stop recognizing people?’ he said: ‘When he sees.”}}
\hadithdefcmd{ibnmajah}{1454}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَسَدٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو إِسْحَاقَ الْفَزَارِيُّ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ قَبِيصَةَ بْنِ ذُؤَيْبٍ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ دَخَلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَى أَبِي سَلَمَةَ وَقَدْ شَقَّ بَصَرُهُ فَأَغْمَضَهُ ثُمَّ قَالَ ‏ "‏ إِنَّ الرُّوحَ إِذَا قُبِضَ تَبِعَهُ الْبَصَرُ ‏"‏ ‏.‏\hadithno{1454}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Umm Salamah said:“The Messenger of Allah (ﷺ) entered upon Abu Salamah (after he had died), and his eyes were wide open. He closed his eyes, then he said: ‘When the soul is taken, the sight follows it.’”}}
\hadithdefcmd{ibnmajah}{1455}{حَدَّثَنَا أَبُو دَاوُدَ، سُلَيْمَانُ بْنُ تَوْبَةَ حَدَّثَنَا عَاصِمُ بْنُ عَلِيٍّ، حَدَّثَنَا قَزَعَةُ بْنُ سُوَيْدٍ، عَنْ حُمَيْدٍ الأَعْرَجِ، عَنِ الزُّهْرِيِّ، عَنْ مَحْمُودِ بْنِ لَبِيدٍ، عَنْ شَدَّادِ بْنِ أَوْسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا حَضَرْتُمْ مَوْتَاكُمْ فَأَغْمِضُوا الْبَصَرَ فَإِنَّ الْبَصَرَ يَتْبَعُ الرُّوحَ وَقُولُوا خَيْرًا فَإِنَّ الْمَلاَئِكَةَ تُؤَمِّنُ عَلَى مَا قَالَ أَهْلُ الْبَيْتِ ‏"‏ ‏.‏\hadithno{1455}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Shaddad bin Aws that the Messenger of Allah (ﷺ) said:“When you come to your dead ones, close their eyes, for the sight follows the soul. And say good things, for the Angels say Amin to what the members of the household say.”}}
\hadithdefcmd{ibnmajah}{1456}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ قَبَّلَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عُثْمَانَ بْنَ مَظْعُونٍ وَهُوَ مَيِّتٌ فَكَأَنِّي أَنْظُرُ إِلَى دُمُوعِهِ تَسِيلُ عَلَى خَدَّيْهِ ‏.‏\hadithno{1456}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) kissed ‘Uthman bin Maz’un when he had died, and it is as if I can see him with his tears flowing down his cheeks.”}}
\hadithdefcmd{ibnmajah}{1457}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، وَالْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، وَسَهْلُ بْنُ أَبِي سَهْلٍ، قَالُوا حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، عَنْ مُوسَى بْنِ أَبِي عَائِشَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، وَعَائِشَةَ، أَنَّ أَبَا بَكْرٍ، قَبَّلَ النَّبِيَّ ـ صلى الله عليه وسلم ـ وَهُوَ مَيِّتٌ ‏.‏\hadithno{1457}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Ibn ‘Abbas and ‘Aishah that Abu Bakr kissed the Prophet (ﷺ) when he died}}
\hadithdefcmd{ibnmajah}{1458}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَنَحْنُ نُغَسِّلُ ابْنَتَهُ أُمَّ كُلْثُومٍ فَقَالَ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا أَوْ أَكْثَرَ مِنْ ذَلِكِ إِنْ رَأَيْتُنَّ ذَلِكِ بِمَاءٍ وَسِدْرٍ وَاجْعَلْنَ فِي الآخِرَةِ كَافُورًا أَوْ شَيْئًا مِنْ كَافُورٍ فَإِذَا فَرَغْتُنَّ فَآذِنَّنِي ‏"‏ ‏.‏ فَلَمَّا فَرَغْنَا آذَنَّاهُ فَأَلْقَى إِلَيْنَا حَقْوَهُ ‏.‏ وَقَالَ ‏"‏ أَشْعِرْنَهَا إِيَّاهُ ‏"‏ ‏.‏\hadithno{1458}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Muhammad bin Sirin narrated that Umm ‘Atiyyah said:“The Messenger of Allah (ﷺ) entered upon us when we were washing his daughter Umm Kulthum. He said: ‘Wash her three or five times, or more than that if you think you need to, with water and lote leaves, and put camphor or a little camphor in (the water) for the last washing. When you have finished, call for me.’ When we finished, we called him, and he gave his waist-wrapper to us and said: ‘Shroud her with it.’”}}
\hadithdefcmd{ibnmajah}{1459}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ أَيُّوبَ، حَدَّثَتْنِي حَفْصَةُ، عَنْ أُمِّ عَطِيَّةَ، بِمِثْلِ حَدِيثِ مُحَمَّدٍ وَكَانَ فِي حَدِيثِ حَفْصَةَ ‏"‏ اغْسِلْنَهَا وِتْرًا ‏"‏ ‏.‏ وَكَانَ فِيهِ ‏"‏ اغْسِلْنَهَا ثَلاَثًا أَوْ خَمْسًا ‏"‏ ‏.‏ وَكَانَ فِيهِ ‏"‏ ابْدَءُوا بِمَيَامِنِهَا وَمَوَاضِعِ الْوُضُوءِ مِنْهَا ‏"‏ ‏.‏ وَكَانَ فِيهِ أَنَّ أُمَّ عَطِيَّةَ قَالَتْ وَامْشِطْنَهَا ثَلاَثَةَ قُرُونٍ ‏.‏\hadithno{1459}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ayyub who said:“Hafsah narrated to me, from Umm ‘Atiyyah” and it is similar to the Hadith of Muhammad. And in the narration of Hafsah it says: “Wash her an odd number of times.” And: “Wash her face three or five times.” And “Start on her right, with the places washed in ablution.” And it says that Umm ‘Atiyyah said: “And we combed her hair into three braids.”}}
\hadithdefcmd{ibnmajah}{1460}{حَدَّثَنَا بِشْرُ بْنُ آدَمَ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، قَالَ قَالَ لِي النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تُبْرِزْ فَخِذَكَ وَلاَ تَنْظُرْ إِلَى فَخِذِ حَىٍّ وَلاَ مَيِّتٍ ‏"‏ ‏.‏\hadithno{1460}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali said:“The Prophet (ﷺ) said to me: ‘Do not show your thigh, and do not look at the thigh of anyone, living or dead.’”}}
\hadithdefcmd{ibnmajah}{1461}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ مُبَشِّرِ بْنِ عُبَيْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لِيُغَسِّلْ مَوْتَاكُمُ الْمَأْمُونُونَ ‏"‏ ‏.‏\hadithno{1461}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah bin ‘Umar that the Messenger of Allah (ﷺ) said:‘Let the honest wash your dead.”}}
\hadithdefcmd{ibnmajah}{1462}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ الْمُحَارِبِيُّ، حَدَّثَنَا عَبَّادُ بْنُ كَثِيرٍ، عَنْ عَمْرِو بْنِ خَالِدٍ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عَاصِمِ بْنِ ضَمْرَةَ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ غَسَّلَ مَيِّتًا وَكَفَّنَهُ وَحَنَّطَهُ وَحَمَلَهُ وَصَلَّى عَلَيْهِ وَلَمْ يُفْشِ عَلَيْهِ مَا رَأَى خَرَجَ مِنْ خَطِيئَتِهِ مِثْلَ يَوْمِ وَلَدَتْهُ أُمُّهُ ‏"‏ ‏.‏\hadithno{1462}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Ali that the Messenger of Allah (ﷺ) said:“Whoever washes a deceased person, shrouds him, embalms him, carries him and offers the funeral prayer for him, and does not disclose what he has seen, he will emerge from his sins as on the day his mother bore him.”}}
\hadithdefcmd{ibnmajah}{1463}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ غَسَّلَ مَيِّتًا فَلْيَغْتَسِلْ ‏"‏ ‏.‏\hadithno{1463}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever washes a dead person, let him take a bath.”}}
\hadithdefcmd{ibnmajah}{1464}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَحْمَدُ بْنُ خَالِدٍ الْوَهْبِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ يَحْيَى بْنِ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لَوْ كُنْتُ اسْتَقْبَلْتُ مِنَ الأَمْرِ مَا اسْتَدْبَرْتُ مَا غَسَّلَ النَّبِيَّ ـ صلى الله عليه وسلم ـ غَيْرُ نِسَائِهِ ‏.‏\hadithno{1464}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Aishah said:“If I had known then what I know now, no one would have washed the Prophet (ﷺ) but his wives.”}}
\hadithdefcmd{ibnmajah}{1465}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَعْقُوبَ بْنِ عُتْبَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنْ عَائِشَةَ، قَالَتْ رَجَعَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِنَ الْبَقِيعِ فَوَجَدَنِي وَأَنَا أَجِدُ صُدَاعًا فِي رَأْسِي وَأَنَا أَقُولُ وَارَأْسَاهُ فَقَالَ ‏"‏ بَلْ أَنَا يَا عَائِشَةُ وَارَأْسَاهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ مَا ضَرَّكِ لَوْ مِتِّ قَبْلِي فَقُمْتُ عَلَيْكِ فَغَسَّلْتُكِ وَكَفَّنْتُكِ وَصَلَّيْتُ عَلَيْكِ وَدَفَنْتُكِ ‏"‏ ‏.‏\hadithno{1465}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) came back from Al-Baqi’ and I had a headache and was saying: ‘O my head!’ He said: ‘Rather, I should say, O my head, O ‘Aishah!’ Then he said: ‘It will not matter if you were to die before me, for I will take care of you, wash you, shroud you, offer the funeral prayer for you and bury you.’”}}
\hadithdefcmd{ibnmajah}{1466}{حَدَّثَنَا سَعِيدُ بْنُ يَحْيَى بْنِ الأَزْهَرِ الْوَاسِطِيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا أَبُو بُرْدَةَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ لَمَّا أَخَذُوا فِي غُسْلِ النَّبِيِّ ـ صلى الله عليه وسلم ـ نَادَاهُمْ مُنَادٍ مِنَ الدَّاخِلِ لاَ تَنْزِعُوا عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَمِيصَهُ ‏.‏\hadithno{1466}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Buraidah that his father said:“When they started to wash the Prophet (ﷺ), a voice called out from inside (the house) saying: ‘Do not remove the shirt of the Messenger of Allah.’”}}
\hadithdefcmd{ibnmajah}{1467}{حَدَّثَنَا يَحْيَى بْنُ خِذَامٍ، حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، أَنْبَأَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ لَمَّا غَسَّلَ النَّبِيَّ ـ صلى الله عليه وسلم ـ ذَهَبَ يَلْتَمِسُ مِنْهُ مَا يَلْتَمِسُ مِنَ الْمَيِّتِ فَلَمْ يَجِدْهُ ‏.‏ فَقَالَ بِأَبِي الطَّيِّبُ طِبْتَ حَيًّا وَطِبْتَ مَيِّتًا ‏.‏\hadithno{1467}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali bin Abu Talib said that when he washed the Messenger of Allah (ﷺ) he looked for what which is usually looked for on the deceased (i.e., dirt), and he found none. He said:“May my father be sacrificed for you, you are pure; you were pure in life and you are pure in death.”}}
\hadithdefcmd{ibnmajah}{1468}{حَدَّثَنَا عَبَّادُ بْنُ يَعْقُوبَ، حَدَّثَنَا الْحُسَيْنُ بْنُ زَيْدِ بْنِ عَلِيِّ بْنِ الْحُسَيْنِ بْنِ عَلِيٍّ، عَنْ إِسْمَاعِيلَ بْنِ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، عَنْ أَبِيهِ، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا أَنَا مُتُّ فَاغْسِلْنِي بِسَبْعِ قِرَبٍ مِنْ بِئْرِي بِئْرِ غَرْسٍ ‏"‏ ‏.‏\hadithno{1468}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Ali that the Messenger of Allah (ﷺ) said:“When I die, then wash me with seven buckets from me well, the well of Ghars.”}}
\hadithdefcmd{ibnmajah}{1469}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كُفِّنَ فِي ثَلاَثَةِ أَثْوَابٍ بِيضٍ يَمَانِيَةٍ لَيْسَ فِيهَا قَمِيصٌ وَلاَ عِمَامَةٌ فَقِيلَ لِعَائِشَةَ إِنَّهُمْ كَانُوا يَزْعُمُونَ أَنَّهُ قَدْ كَانَ كُفِّنَ فِي حِبَرَةٍ ‏.‏ فَقَالَتْ عَائِشَةُ قَدْ جَاءُوا بِبُرْدِ حِبَرَةٍ فَلَمْ يُكَفِّنُوهُ ‏.‏\hadithno{1469}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from ‘Aishah that the Prophet (ﷺ) was shrouded in three white Yemeni cloths, among which there was no shirt and no turban. It was said to ‘Aishah:“They used to claim that he was shrouded in Hibarah.” ‘Aishah said: “They brought a Hibarah Burd, but they did not shroud him in it.”}}
\hadithdefcmd{ibnmajah}{1470}{حَدَّثَنَا مُحَمَّدُ بْنُ خَلَفٍ الْعَسْقَلاَنِيُّ، حَدَّثَنَا عَمْرُو بْنُ أَبِي سَلَمَةَ، قَالَ هَذَا مَا سَمِعْتُ مِنْ أَبِي مُعَيْدٍ، حَفْصِ بْنِ غَيْلاَنَ عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ كُفِّنَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي ثَلاَثِ رِيَاطٍ بِيضٍ سَحُولِيَّةٍ ‏.‏\hadithno{1470}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Abdullah bin ‘Umar said:“The Messenger of Allah (ﷺ) was shrouded in three thin white Suhuli cloths.”}}
\hadithdefcmd{ibnmajah}{1471}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُفِّنَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فِي ثَلاَثَةِ أَثْوَابٍ قَمِيصُهُ الَّذِي قُبِضَ فِيهِ وَحُلَّةٌ نَجْرَانِيَّةٌ ‏.‏\hadithno{1471}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) was shrouded in three garments: The shirt in which he died, and a Najrani Hullah}}
\hadithdefcmd{ibnmajah}{1472}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ الْمَكِّيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ خَيْرُ ثِيَابِكُمُ الْبَيَاضُ فَكَفِّنُوا فِيهَا مَوْتَاكُمْ وَالْبَسُوهَا ‏"‏ ‏.‏\hadithno{1472}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“The best of your garments are those which are white, so shroud your dead in them, and wear them.”}}
\hadithdefcmd{ibnmajah}{1473}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَنْبَأَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ حَاتِمِ بْنِ أَبِي نَصْرٍ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ أَبِيهِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ خَيْرُ الْكَفَنِ الْحُلَّةُ ‏"‏ ‏.‏\hadithno{1473}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Ubadah bin Samit that the Messenger of Allah (ﷺ) said:“The best of shrouds is the Hullah (two-piecer).”}}
\hadithdefcmd{ibnmajah}{1474}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، عَنْ هِشَامِ بْنِ حَسَّانٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي قَتَادَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا وَلِيَ أَحَدُكُمْ أَخَاهُ فَلْيُحْسِنْ كَفَنَهُ ‏"‏ ‏.‏\hadithno{1474}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Qatadah that the Messenger of Allah (ﷺ) said:“If anyone of you is charged with taking care of his brother (after death), let him shroud him well.”}}
\hadithdefcmd{ibnmajah}{1475}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ سَمُرَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ الْحَسَنِ، حَدَّثَنَا أَبُو شَيْبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا قُبِضَ إِبْرَاهِيمُ ابْنُ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ لَهُمُ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تُدْرِجُوهُ فِي أَكْفَانِهِ حَتَّى أَنْظُرَ إِلَيْهِ ‏"‏ ‏.‏ فَأَتَاهُ فَانْكَبَّ عَلَيْهِ وَبَكَى ‏.‏\hadithno{1475}\hadithgrade{Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Anas bin Malik said:“When Ibrahim the son of the Prophet (ﷺ) died, the Prophet (ﷺ) said to them: ‘Do not wrap him in his shroud until I look at him.’ He came to him, bent over and wept.”}}
\hadithdefcmd{ibnmajah}{1476}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ حَبِيبِ بْنِ سُلَيْمٍ، عَنْ بِلاَلِ بْنِ يَحْيَى، قَالَ كَانَ حُذَيْفَةُ إِذَا مَاتَ لَهُ الْمَيِّتُ قَالَ لاَ تُؤْذِنُوا بِهِ أَحَدًا إِنِّي أَخَافُ أَنْ يَكُونَ نَعْيًا إِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ بِأُذُنَىَّ هَاتَيْنِ يَنْهَى عَنِ النَّعْىِ ‏.‏\hadithno{1476}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Bilal bin Yahya said:“If one of the members of his family died, Hudhaifah would say: ‘Do not inform anyone of it, for I am afraid that that would be a public death announcement. I heard the Messenger of Allah (ﷺ) with these two ears of mine forbidding making public death announcements.’”}}
\hadithdefcmd{ibnmajah}{1477}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهِشَامُ بْنُ عَمَّارٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَسْرِعُوا بِالْجِنَازَةِ فَإِنْ تَكُنْ صَالِحَةً فَخَيْرٌ تُقَدِّمُونَهَا إِلَيْهِ وَإِنْ تَكُنْ غَيْرَ ذَلِكَ فَشَرٌّ تَضَعُونَهُ عَنْ رِقَابِكُمْ ‏"‏ ‏.‏\hadithno{1477}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:‘Hasten with the funeral (procession), for if the person was righteous then you are advancing him towards good, and if he was otherwise then it is evil which you are taking off of your necks.”}}
\hadithdefcmd{ibnmajah}{1478}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ مَنْصُورٍ، عَنْ عُبَيْدِ بْنِ نِسْطَاسٍ، عَنْ أَبِي عُبَيْدَةَ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ مَنِ اتَّبَعَ جِنَازَةً فَلْيَحْمِلْ بِجِوَانِبِ السَّرِيرِ كُلِّهَا فَإِنَّهُ مِنَ السُّنَّةِ ثُمَّ إِنْ شَاءَ فَلْيَتَطَوَّعْ وَإِنْ شَاءَ فَلْيَدَعْ ‏.‏\hadithno{1478}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu ‘Ubaidah said:“ ‘Abdullah bin Mas’ud said: ‘Whoever follows a funeral (procession), let him carry all (four) corners of it (in turn), for that is Sunnah. Then if he wishes let him voluntarily carry it, and if he wishes let him not do so.’”}}
\hadithdefcmd{ibnmajah}{1479}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ بْنِ عَقِيلٍ، حَدَّثَنَا بِشْرُ بْنُ ثَابِتٍ، حَدَّثَنَا شُعْبَةُ، عَنْ لَيْثٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ رَأَى جِنَازَةً يُسْرِعُونَ بِهَا قَالَ ‏ "‏ لِتَكُنْ عَلَيْكُمُ السَّكِينَةُ ‏"‏ ‏.‏\hadithno{1479}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Musa that the Prophet (ﷺ) saw a funeral (procession) with which the people were rushing. He said:“You should move with tranquility.”}}
\hadithdefcmd{ibnmajah}{1480}{حَدَّثَنَا كَثِيرُ بْنُ عُبَيْدٍ الْحِمْصِيُّ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ أَبِي بَكْرِ بْنِ أَبِي مَرْيَمَ، عَنْ رَاشِدِ بْنِ سَعْدٍ، عَنْ ثَوْبَانَ، مَوْلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ رَأَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ نَاسًا رُكْبَانًا عَلَى دَوَابِّهِمْ فِي جِنَازَةٍ فَقَالَ ‏ "‏ أَلاَ تَسْتَحْيُونَ أَنَّ مَلاَئِكَةَ اللَّهِ يَمْشُونَ عَلَى أَقْدَامِهِمْ وَأَنْتُمْ رُكْبَانٌ ‏"‏ ‏.‏\hadithno{1480}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Thawban, the freed slave of the Messenger of Allah (ﷺ), said:“The Messenger of Allah (ﷺ) saw some people riding on their animals in a funeral (procession). He said: ‘Do you not feel ashamed that the angels of Allah are walking on foot and you are riding?’”}}
\hadithdefcmd{ibnmajah}{1481}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا سَعِيدُ بْنُ عُبَيْدِ اللَّهِ بْنِ جُبَيْرِ بْنِ حَيَّةَ، حَدَّثَنِي زِيَادُ بْنُ جُبَيْرِ بْنِ حَيَّةَ، سَمِعَ الْمُغِيرَةَ بْنَ شُعْبَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الرَّاكِبُ خَلْفَ الْجِنَازَةِ وَالْمَاشِي مِنْهَا حَيْثُ شَاءَ ‏"‏ ‏.‏\hadithno{1481}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Al-Mughirah bin Shu’bah said:“I heard the Messenger of Allah (ﷺ) say: ‘The rider should travel behind the funeral (procession) but the one who is walking may walk wherever he wants.”}}
\hadithdefcmd{ibnmajah}{1482}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَهِشَامُ بْنُ عَمَّارٍ، وَسَهْلُ بْنُ أَبِي سَهْلٍ، قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّبِيَّ ـ صلى الله عليه وسلم ـ وَأَبَا بَكْرٍ وَعُمَرَ يَمْشُونَ أَمَامَ الْجِنَازَةِ ‏.‏\hadithno{1482}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Salim that his father said:“I saw the Prophet (ﷺ), Abu Bakr and ‘Umar walking ahead of the funeral (procession).”}}
\hadithdefcmd{ibnmajah}{1483}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ الْحَمَّالُ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ الْبُرْسَانِيُّ، أَنْبَأَنَا يُونُسُ بْنُ يَزِيدَ الأَيْلِيُّ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَبُو بَكْرٍ وَ عُمَرُ وَعُثْمَانُ يَمْشُونَ أَمَامَ الْجِنَازَةِ ‏.‏\hadithno{1483}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas bin Malik said:“The Messenger of Allah (ﷺ), Abu Bakr, ‘Umar and ‘Uthman used to walk ahead of the funeral (procession).”}}
\hadithdefcmd{ibnmajah}{1484}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ التَّيْمِيِّ، عَنْ أَبِي مَاجِدَةَ الْحَنَفِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ الْجِنَازَةُ مَتْبُوعَةٌ وَلَيْسَتْ بِتَابِعَةٍ لَيْسَ مِنْهَا مَنْ تَقَدَّمَهَا ‏"‏ ‏.‏\hadithno{1484}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah bin Mas’ud that the Messenger of Allah (ﷺ) said:‘The funeral should be followed and should not follow. There should be no one with it who walks ahead of it.”}}
\hadithdefcmd{ibnmajah}{1485}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَخْبَرَنِي عَمْرُو بْنُ النُّعْمَانِ، حَدَّثَنَا عَلِيُّ بْنُ الْحَزَوَّرِ، عَنْ نُفَيْعٍ، عَنْ عِمْرَانَ بْنِ الْحُصَيْنِ، وَأَبِي، بَرْزَةَ قَالاَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي جِنَازَةٍ فَرَأَى قَوْمًا قَدْ طَرَحُوا أَرْدِيَتَهُمْ يَمْشُونَ فِي قُمُصٍ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ أَبِفِعْلِ الْجَاهِلِيَّةِ تَأْخُذُونَ - أَوْ بِصُنْعِ الْجَاهِلِيَّةِ تَشَبَّهُونَ - لَقَدْ هَمَمْتُ أَنْ أَدْعُوَ عَلَيْكُمْ دَعْوَةً تَرْجِعُونَ فِي غَيْرِ صُوَرِكُمْ ‏"‏ ‏.‏ قَالَ فَأَخَذُوا أَرْدِيَتَهُمْ وَلَمْ يَعُودُوا لِذَلِكَ ‏.‏\hadithno{1485}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Imran bin Husain and Abu Barzah said:“We went out with the Messenger of Allah (ﷺ) to attend a funeral, and he saw some people who had cast aside their upper sheets and were walking in their shirts only. The Messenger of Allah (ﷺ) said: ‘Are you adopting the practice of the days of ignorance?’ or; ‘Are you imitating the behavior of the days of ignorance? I was about to supplicate against you that you would return in a different form.’ So they put their sheets back on and never did that again.”}}
\hadithdefcmd{ibnmajah}{1486}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي سَعِيدُ بْنُ عَبْدِ اللَّهِ الْجُهَنِيُّ، أَنَّ مُحَمَّدَ بْنَ عُمَرَ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ، حَدَّثَهُ عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَلِيِّ بْنِ أَبِي طَالِبٍ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ تُؤَخِّرُوا الْجِنَازَةَ إِذَا حَضَرَتْ ‏"‏ ‏.‏\hadithno{1486}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Ali bin Abu Talib that the Messenger of Allah (ﷺ) said:“Do not delay the funeral once it is ready.”}}
\hadithdefcmd{ibnmajah}{1487}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الصَّنْعَانِيُّ، أَنْبَأَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ قَرَأْتُ عَلَى الْفُضَيْلِ بْنِ مَيْسَرَةَ عَنْ أَبِي حَرِيزٍ، أَنَّ أَبَا بُرْدَةَ، حَدَّثَهُ قَالَ أَوْصَى أَبُو مُوسَى الأَشْعَرِيُّ حِينَ حَضَرَهُ الْمَوْتُ فَقَالَ لاَ تُتْبِعُونِي بِمِجْمَرٍ ‏.‏ قَالُوا لَهُ أَوَ سَمِعْتَ فِيهِ شَيْئًا قَالَ نَعَمْ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1487}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hariz that Abu Burdah said:“Abu Musa Ash’ari left instructions, when he was dying, saying: ‘Do not follow me with a censer.’* They said to him: ‘Did you hear something concerning that?’ He said: ‘Yes, from the Messenger of Allah (ﷺ).’”}}
\hadithdefcmd{ibnmajah}{1488}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، أَنْبَأَنَا شَيْبَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَنْ صَلَّى عَلَيْهِ مِائَةٌ مِنَ الْمُسْلِمِينَ غُفِرَ لَهُ ‏"‏ ‏.‏\hadithno{1488}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Whoever has the funeral prayer offered for him by one hundred Muslims, he will be forgiven.”}}
\hadithdefcmd{ibnmajah}{1489}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا بَكْرُ بْنُ سُلَيْمٍ، حَدَّثَنِي حُمَيْدُ بْنُ زِيَادٍ الْخَرَّاطُ، عَنْ كُرَيْبٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ قَالَ هَلَكَ ابْنٌ لِعَبْدِ اللَّهِ بْنِ عَبَّاسٍ فَقَالَ لِي يَا كُرَيْبُ قُمْ فَانْظُرْ هَلِ اجْتَمَعَ لاِبْنِي أَحَدٌ فَقُلْتُ نَعَمْ ‏.‏ فَقَالَ وَيْحَكَ كَمْ تَرَاهُمْ؟ أَرْبَعِينَ؟ قُلْتُ: لاَ. بَلْ هُمْ أَكْثَرُ ‏.‏ قَالَ: فَاخْرُجُوا بِابْنِي فَأَشْهَدُ لَسَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَا مِنْ أَرْبَعِينَ مِنْ مُؤْمِنٍ يَشْفَعُونَ لِمُؤْمِنٍ إِلاَّ شَفَّعَهُمُ اللَّهُ ‏"‏ ‏.‏\hadithno{1489}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Kuraib the freed slave of ‘Abdullah bin ‘Abbas said:“A son of ‘Abdullah bin ‘Abbas died, and he said to me: ‘O Kuraib! Get up and see if anyone has assembled (to pray) for my son.’ I said: ‘Yes.’ He said: ‘Woe to you, how many do you see? Forty?’ I said: ‘No, rather there are more.’ He said: ‘Take my son out, for I bear witness that I hear the Messenger of Allah (ﷺ) say: “No (group of) forty believers intercede for a believer, but Allah will accept their intercession.”}}
\hadithdefcmd{ibnmajah}{1490}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مَرْثَدِ بْنِ عَبْدِ اللَّهِ الْيَزَنِيِّ، عَنْ مَالِكِ بْنِ هُبَيْرَةَ الشَّامِيِّ، - وَكَانَتْ لَهُ صُحْبَةٌ - قَالَ كَانَ إِذَا أُتِيَ بِجِنَازَةٍ فَتَقَالَّ مَنْ تَبِعَهَا جَزَّأَهُمْ ثَلاَثَةَ صُفُوفٍ ثُمَّ صَلَّى عَلَيْهَا وَقَالَ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا صَفَّ صُفُوفٌ ثَلاَثَةٌ مِنَ الْمُسْلِمِينَ عَلَى مَيِّتٍ إِلاَّ أَوْجَبَ ‏"‏ ‏.‏\hadithno{1490}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{Malik bin Hubairah Ash-Shami, who was a Companion of the Prophet (ﷺ), said:“If a funeral procession was brought and the number of people who followed it was considered to be small, they would be organized into three rows, then the funeral prayer would be offered.” He said: “The Messenger of Allah (ﷺ) said: ‘No three rows of Muslims offer the funeral prayer for one who has died, but he will be guaranteed (Paradise).’”}}
\hadithdefcmd{ibnmajah}{1491}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ مُرَّ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ بِجِنَازَةٍ فَأُثْنِيَ عَلَيْهَا خَيْرًا فَقَالَ ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ ثُمَّ مُرَّ عَلَيْهِ بِجِنَازَةٍ فَأُثْنِيَ عَلَيْهَا شَرًّا فَقَالَ ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ فَقِيلَ يَا رَسُولَ اللَّهِ قُلْتَ لِهَذِهِ وَجَبَتْ وَلِهَذِهِ وَجَبَتْ فَقَالَ ‏"‏ شَهَادَةُ الْقَوْمِ وَالْمُؤْمِنُونَ شُهُودُ اللَّهِ فِي الأَرْضِ ‏"‏ ‏.‏\hadithno{1491}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Anas bin Malik said:“A funeral (procession) passed by the Prophet (ﷺ) and they praised (the deceased) and spoke well of him. He said: ‘(Paradise is) guaranteed for him.’ Then another funeral passed by and they spoke badly of him, and he (the Prophet (ﷺ)) said: ‘(Hell is) guaranteed for him.’ It was said: ‘O Messenger of Allah, you said that (Paradise was) guaranteed for this one and that (Hell was) guaranteed for the other one.’ He said: ‘It is the testimony of the people, and the believers are the witnesses of Allah on earth.’”}}
\hadithdefcmd{ibnmajah}{1492}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مُرَّ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ بِجِنَازَةٍ - فَأُثْنِيَ عَلَيْهَا خَيْرًا فِي مَنَاقِبِ الْخَيْرِ فَقَالَ ‏"‏ وَجَبَتْ ‏"‏ ‏.‏ ثُمَّ مَرُّوا عَلَيْهِ بِأُخْرَى فَأُثْنِيَ عَلَيْهَا شَرًّا فِي مَنَاقِبِ الشَّرِّ فَقَالَ ‏"‏ وَجَبَتْ إِنَّكُمْ شُهَدَاءُ اللَّهِ فِي الأَرْضِ ‏"‏ ‏.‏\hadithno{1492}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“A funeral passed by the Prophet (ﷺ) and they praised (the deceased) and spoke well of him and mentioned his good characteristics. He said: ‘(Paradise is) guaranteed for him.’ Then another funeral passed by and they spoke badly of him and mentioned his bad characteristics, and he the Prophet (ﷺ) said: ‘(Hell is) guaranteed for him. You are the witnesses of Allah on earth.’”}}
\hadithdefcmd{ibnmajah}{1493}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ الْحُسَيْنُ بْنُ ذَكْوَانَ أَخْبَرَنِي عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ الأَسْلَمِيِّ، عَنْ سَمُرَةَ بْنِ جُنْدُبٍ الْفَزَارِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ صَلَّى عَلَى امْرَأَةٍ مَاتَتْ فِي نِفَاسِهَا فَقَامَ وَسَطَهَا ‏.‏\hadithno{1493}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Samurah bin Jundab Al-Fazari that the Messenger of Allah (ﷺ) offered the funeral prayer for a woman who had died in nifas* and he stood level with her middle (i.e. her waist).” *The postnatal bleeding period}}
\hadithdefcmd{ibnmajah}{1494}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ، عَنْ هَمَّامٍ، عَنْ أَبِي غَالِبٍ، قَالَ رَأَيْتُ أَنَسَ بْنَ مَالِكٍ صَلَّى عَلَى جِنَازَةِ رَجُلٍ فَقَامَ حِيَالَ رَأْسِهِ فَجِيءَ بِجِنَازَةٍ أُخْرَى بِامْرَأَةٍ فَقَالُوا يَا أَبَا حَمْزَةَ صَلِّ عَلَيْهَا ‏.‏ فَقَامَ حِيَالَ وَسَطِ السَّرِيرِ فَقَالَ لَهُ الْعَلاَءُ بْنُ زِيَادٍ يَا أَبَا حَمْزَةَ هَكَذَا رَأَيْتَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَامَ مِنَ الْجِنَازَةِ مُقَامَكَ مِنَ الرَّجُلِ وَقَامَ مِنَ الْمَرْأَةِ مُقَامَكَ مِنَ الْمَرْأَةِ قَالَ نَعَمْ ‏.‏ فَأَقْبَلَ عَلَيْنَا فَقَالَ احْفَظُوا ‏.‏\hadithno{1494}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Ghalib said:“I saw Anas bin Malik offering the funeral prayer for a man, and he stood level with his head. Then another funeral was brought, that of a woman, and they said: ‘O Abu Hamzah! Offer the funeral prayer for her.’ So he stood level with the middle of the bed (the body was upon). ‘Ala’ bin Ziyad said to him: ‘O Abu Hamzah! Is this how you saw the Messenger of Allah (ﷺ) standing in relation to the body of a man and a woman as you have stood?’ He said: ‘Yes.’ Then he turned to us and said: ‘Remember this.’”}}
\hadithdefcmd{ibnmajah}{1495}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عُثْمَانَ، عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَرَأَ عَلَى الْجِنَازَةِ بِفَاتِحَةِ الْكِتَابِ ‏.‏\hadithno{1495}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) recited the Opening of the Book (Al-Fatihah) in the funeral prayer}}
\hadithdefcmd{ibnmajah}{1496}{حَدَّثَنَا عَمْرُو بْنُ أَبِي عَاصِمٍ النَّبِيلُ، وَإِبْرَاهِيمُ بْنُ الْمُسْتَمِرِّ، قَالاَ حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا حَمَّادُ بْنُ جَعْفَرٍ الْعَبْدِيُّ، حَدَّثَنِي شَهْرُ بْنُ حَوْشَبٍ، حَدَّثَتْنِي أُمُّ شَرِيكٍ الأَنْصَارِيَّةُ، قَالَتْ أَمَرَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ نَقْرَأَ عَلَى الْجِنَازَةِ بِفَاتِحَةِ الْكِتَابِ ‏.‏\hadithno{1496}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Umm Sharik Al-Ansari said:“The Messenger of Allah (ﷺ) commanded us to recite the Opening of the Book (Al-Fatihah) in the funeral prayer.”}}
\hadithdefcmd{ibnmajah}{1497}{حَدَّثَنَا أَبُو عُبَيْدٍ، مُحَمَّدُ بْنُ عُبَيْدِ بْنِ مَيْمُونٍ الْمَدِينِيُّ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْحَرَّانِيُّ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ بْنِ الْحَارِثِ التَّيْمِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ إِذَا صَلَّيْتُمْ عَلَى الْمَيِّتِ فَأَخْلِصُوا لَهُ الدُّعَاءَ ‏"‏ ‏.‏\hadithno{1497}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“I heard the Messenger of Allah (ﷺ) say: ‘When you offer the prayer for the deceased, supplicate sincerely for him.’”}}
\hadithdefcmd{ibnmajah}{1498}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا صَلَّى عَلَى جِنَازَةٍ يَقُولُ ‏ "‏ اللَّهُمَّ اغْفِرْ لِحَيِّنَا وَمَيِّتِنَا وَشَاهِدِنَا وَغَائِبِنَا وَصَغِيرِنَا وَكَبِيرِنَا وَذَكَرِنَا وَأُنْثَانَا اللَّهُمَّ مَنْ أَحْيَيْتَهُ مِنَّا فَأَحْيِهِ عَلَى الإِسْلاَمِ وَمَنْ تَوَفَّيْتَهُ مِنَّا فَتَوَفَّهُ عَلَى الإِيمَانِ اللَّهُمَّ لاَ تَحْرِمْنَا أَجْرَهُ وَلاَ تُضِلَّنَا بَعْدَهُ ‏"‏ ‏.‏\hadithno{1498}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“When the Messenger of Allah (ﷺ) offered the funeral prayer he would say: ‘Allahummaghfir lihayyina wa mayyitina, wa shahidina wa gha’ibina, wa saghirina wa kabirina, wa dhakarina wa unthana. Allahumma man ahyaitahu minna fa'ahyihi ‘alal-Islam, wa man tawaffaytahu minna fa tawaffahu ‘alal- iman. Allahumma la tahrimna ajrahu wa la tudillana ba’dah. [O Allah, forgive our living and our dead, those who are present and those who are absent, our young and our old, our males and our females. O Allah, whomever of us You cause to live, let him live in Islam, and whomever of us You cause to die, let him die in (a state of) faith. O Allah, do not deprive us of his reward, and do not let us go astray after him].’”}}
\hadithdefcmd{ibnmajah}{1499}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا مَرْوَانُ بْنُ جَنَاحٍ، حَدَّثَنِي يُونُسُ بْنُ مَيْسَرَةَ بْنِ حَلْبَسٍ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، قَالَ: صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَى رَجُلٍ مِنَ الْمُسْلِمِينَ فَأَسْمَعُهُ يَقُولُ ‏ "‏ اللَّهُمَّ إِنَّ فُلاَنَ بْنَ فُلاَنٍ فِي ذِمَّتِكَ وَحَبْلِ جِوَارِكَ فَقِهِ مِنْ فِتْنَةِ الْقَبْرِ وَعَذَابِ النَّارِ وَأَنْتَ أَهْلُ الْوَفَاءِ وَالْحَقِّ فَاغْفِرْ لَهُ وَارْحَمْهُ إِنَّكَ أَنْتَ الْغَفُورُ الرَّحِيمُ ‏"‏ ‏.‏\hadithno{1499}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Wathilah bin Asqa’ said:“The Messenger of Allah (ﷺ) offered the funeral prayer for a man among the Muslims and I heard him say: ‘O Allah, so-and-so the son of so-and-so is in Your case and under Your protection. Protect him from the trial of the grave and the torment of the Fire, for You are the One Who keeps the promise and You are the Truth. Forgive him and have mercy on him, for You are the Oft-Forgiving, Most Merciful.”}}
\hadithdefcmd{ibnmajah}{1500}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا فَرَجُ بْنُ الْفَضَالَةِ، حَدَّثَنِي عِصْمَةُ بْنُ رَاشِدٍ، عَنْ حَبِيبِ بْنِ عُبَيْدٍ، عَنْ عَوْفِ بْنِ مَالِكٍ، قَالَ شَهِدْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ صَلَّى عَلَى رَجُلٍ مِنَ الأَنْصَارِ فَسَمِعْتُهُ يَقُولُ ‏ "‏ اللَّهُمَّ صَلِّ عَلَيْهِ وَاغْفِرْ لَهُ وَارْحَمْهُ وَعَافِهِ وَاعْفُ عَنْهُ وَاغْسِلْهُ بِمَاءٍ وَثَلْجٍ وَبَرَدٍ وَنَقِّهِ مِنَ الذُّنُوبِ وَالْخَطَايَا كَمَا يُنَقَّى الثَّوْبُ الأَبْيَضُ مِنَ الدَّنَسِ وَأَبْدِلْهُ بِدَارِهِ دَارًا خَيْرًا مِنْ دَارِهِ وَأَهْلاً خَيْرًا مِنْ أَهْلِهِ وَقِهِ فِتْنَةَ الْقَبْرِ وَعَذَابَ النَّارِ ‏"‏ ‏.‏ قَالَ عَوْفٌ فَلَقَدْ رَأَيْتُنِي فِي مُقَامِي ذَلِكَ أَتَمَنَّى أَنْ أَكُونَ مَكَانَ ذَلِكَ الرَّجُلِ ‏.‏\hadithno{1500}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Awf bin Malik said:“I saw the Messenger of Allah (ﷺ) offering the funeral prayer for a man among the Ansar, and I heard him say: ‘Allahumma salli ‘alayhi waghfirlahu warhamhu, wa ‘afihi wa’fu ‘anhu, waghsilhu bi ma’in wa thaljin wa baradin, wa naqqihi min adh-dhunubi wal-khataya kama yunaqqath-thawbul-abyadu minad-danas, wa abdilhu bi darihi daran khayran min darihi, wa ahlan khayran min ahlili, wa qihi fitnatal-qabri wa ‘adhaban-nar. (O Allah, send blessing upon him, forgive him, have mercy on him, keep him safe and sound, and pardon him; wash him with water and snow and hail, and cleanse him of sins just as a white garment is cleansed of dirt. Give him in exchange for his house that is better than his house, and a family that is better than his family. Protect him from the trial of the grave and the torment of the Fire).’”}}
\hadithdefcmd{ibnmajah}{1501}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ حَجَّاجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ مَا أَبَاحَ لَنَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَلاَ أَبُو بَكْرٍ وَلاَ عُمَرُ فِي شَىْءٍ مَا أَبَاحُوا فِي الصَّلاَةِ عَلَى الْمَيِّتِ ‏.‏ يَعْنِي لَمْ يُوَقِّتْ ‏.‏\hadithno{1501}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:“The Messenger of Allah (ﷺ), Abu Bakr and ‘Umar did not give us so much leeway in anything as they did with regard to the prayer for the deceased,” meaning that there was nothing affixed}}
\hadithdefcmd{ibnmajah}{1502}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا خَالِدُ بْنُ إِلْيَاسَ، عَنْ إِسْمَاعِيلَ بْنِ عَمْرِو بْنِ سَعِيدِ بْنِ الْعَاصِ، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ الْحَكَمِ بْنِ الْحَارِثِ، عَنْ عُثْمَانَ بْنِ عَفَّانَ، ‏.‏ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ صَلَّى عَلَى عُثْمَانَ بْنِ مَظْعُونٍ وَكَبَّرَ عَلَيْهِ أَرْبَعًا ‏.‏\hadithno{1502}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Uthman bin ‘Affan that the Prophet (ﷺ) offered the funeral prayer for ‘Uthman bin Maz’un, and he said four Takbir over him}}
\hadithdefcmd{ibnmajah}{1503}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ الْمُحَارِبِيُّ، حَدَّثَنَا الْهَجَرِيُّ، قَالَ صَلَيْتُ مَعَ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى الأَسْلَمِيِّ صَاحِبِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَى جِنَازَةِ ابْنَةٍ لَهُ فَكَبَّرَ عَلَيْهَا أَرْبَعًا فَمَكَثَ بَعْدَ الرَّابِعَةِ شَيْئًا ‏.‏ قَالَ فَسَمِعْتُ الْقَوْمَ يُسَبِّحُونَ بِهِ مِنْ نَوَاحِي الصُّفُوفِ فَسَلَّمَ ثُمَّ قَالَ أَكُنْتُمْ تُرَوْنَ أَنِّي مُكَبِّرٌ خَمْسًا قَالُوا تَخَوَّفْنَا ذَلِكَ ‏.‏ قَالَ لَمْ أَكُنْ لأَفْعَلَ ‏.‏ وَلَكِنْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يُكَبِّرُ أَرْبَعًا ثُمَّ يَمْكُثُ سَاعَةً فَيَقُولُ مَا شَاءَ اللَّهُ أَنْ يَقُولَ ثُمَّ يُسَلِّمُ ‏.‏\hadithno{1503}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Al-Hajari said:“I prayed with ‘Abdullah bin Abi Awfa Al-Aslami, the Companion of the Messenger of Allah (ﷺ), offering the funeral prayer for a daughter of his. He said Takbir over her four times, and he paused for a while after the fourth. I heard the people saying Subhan- Allah to him throughout the rows. Then he said the Salam and said: ‘Did you think that I was going to say a fifth Takbir?’ They said: ‘We were afraid of that.’ He said: ‘I was not going to do that, but the Messenger of Allah (ﷺ) used to say four Takbir, then pause for a while, and he would say whatever Allah willed he should say, then he would say the Salam.’”}}
\hadithdefcmd{ibnmajah}{1504}{حَدَّثَنَا أَبُو هِشَامٍ الرِّفَاعِيُّ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ قَالُوا حَدَّثَنَا يَحْيَى بْنُ الْيَمَانِ، عَنِ الْمِنْهَالِ بْنِ خَلِيفَةَ، عَنْ حَجَّاجٍ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَبَّرَ أَرْبَعًا ‏.‏\hadithno{1504}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) said Takbir four times}}
\hadithdefcmd{ibnmajah}{1505}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، وَأَبُو دَاوُدَ عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، قَالَ كَانَ زَيْدُ بْنُ أَرْقَمَ يُكَبِّرُ عَلَى جَنَائِزِنَا أَرْبَعًا وَأَنَّهُ كَبَّرَ عَلَى جِنَازَةٍ خَمْسًا فَسَأَلْتُهُ فَقَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُكَبِّرُهَا ‏.‏\hadithno{1505}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Abdur-Rahman bin Abi Laila said:“Zaid bin Arqan used to say the Takbir four times in the funeral prayer, and he said the Takbir five times for one funeral. I asked him (about that) and he said: ‘The Messenger of Allah (ﷺ) used to do that.’”}}
\hadithdefcmd{ibnmajah}{1506}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عَلِيٍّ الرَّافِعِيُّ، عَنْ كَثِيرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَبَّرَ خَمْسًا ‏.‏\hadithno{1506}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Kathir bin ‘Abdullah, from his father, from his grandfather, that the Messenger of Allah (ﷺ) said the Takbir five times}}
\hadithdefcmd{ibnmajah}{1507}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ عُبَيْدِ اللَّهِ بْنِ جُبَيْرِ بْنِ حَيَّةَ، حَدَّثَنِي عَمِّي، زِيَادُ بْنُ جُبَيْرٍ حَدَّثَنِي أَبِي جُبَيْرُ بْنُ حَيَّةَ، أَنَّهُ سَمِعَ الْمُغِيرَةَ بْنَ شُعْبَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ الطِّفْلُ يُصَلَّى عَلَيْهِ ‏"‏ ‏.‏\hadithno{1507}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Jubair bin Hayyah narrated that he heard Mughirah bin Shu’bah say:“I heard the Messenger of Allah (ﷺ) say: ‘The (funeral) prayer should be offered for a child.’”}}
\hadithdefcmd{ibnmajah}{1508}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الرَّبِيعُ بْنُ بَدْرٍ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِذَا اسْتَهَلَّ الصَّبِيُّ صُلِّيَ عَلَيْهِ وَوُرِثَ ‏"‏ ‏.‏\hadithno{1508}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) said:“If a child utters a sound (after being born), the funeral prayer should be offered for him and (his relatives) may inherit from him.”}}
\hadithdefcmd{ibnmajah}{1509}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْبَخْتَرِيُّ بْنُ عُبَيْدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ صَلُّوا عَلَى أَطْفَالِكُمْ فَإِنَّهُمْ مِنْ أَفْرَاطِكُمْ ‏"‏ ‏.‏\hadithno{1509}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Prophet (ﷺ) said: ‘Offer the (funeral) prayer for your children, for they have gone ahead of you (i.e. to prepare your place in Paradise for you).”}}
\hadithdefcmd{ibnmajah}{1510}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، قَالَ قُلْتُ لِعَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى رَأَيْتَ إِبْرَاهِيمَ ابْنَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ مَاتَ وَهُوَ صَغِيرٌ وَلَوْ قُضِيَ أَنْ يَكُونَ بَعْدَ مُحَمَّدٍ ـ صلى الله عليه وسلم ـ نَبِيٌّ لَعَاشَ ابْنُهُ وَلَكِنْ لاَ نَبِيَّ بَعْدَهُ ‏.‏\hadithno{1510}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Isma’il bin Abu Khalid said:“I said to ‘Abdullah bin Abi Awfa: ‘Did you see Ibrahim, the son of the Messenger of Allah (ﷺ)?’ He said: ‘He died when he was small, and if it had been decreed that there should be any Prophet after Muhammad (ﷺ), his son would have lived. But there is no Prophet after him.’”}}
\hadithdefcmd{ibnmajah}{1511}{حَدَّثَنَا عَبْدُ الْقُدُّوسِ بْنُ مُحَمَّدٍ، حَدَّثَنَا دَاوُدُ بْنُ شَبِيبٍ الْبَاهِلِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ عُثْمَانَ، حَدَّثَنَا الْحَكَمُ بْنُ عُتَيْبَةَ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا مَاتَ إِبْرَاهِيمُ ابْنُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ صَلَّى عَلَيْهِ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَقَالَ ‏ "‏ إِنَّ لَهُ مُرْضِعًا فِي الْجَنَّةِ وَلَوْ عَاشَ لَكَانَ صِدِّيقًا نَبِيًّا ‏.‏ وَلَوْ عَاشَ لَعَتَقَتْ أَخْوَالُهُ الْقِبْطُ وَمَا اسْتُرِقَّ قِبْطِيٌّ ‏"‏ ‏.‏\hadithno{1511}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“Then Ibrahim the son of the Messenger of Allah (ﷺ) died, the Messenger of Allah (ﷺ) prayed and said: ‘He has a wet-nurse in Paradise, and if he had lived he would have been a Siddiq and a Prophet. If he had lived his maternal uncles, the Egyptians, would have been set free and no Egyptian would ever have been enslaved.’”}}
\hadithdefcmd{ibnmajah}{1512}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عِمْرَانَ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا هِشَامُ بْنُ أَبِي الْوَلِيدِ، عَنْ أُمِّهِ، عَنْ فَاطِمَةَ بِنْتِ الْحُسَيْنِ، عَنْ أَبِيهَا الْحُسَيْنِ بْنِ عَلِيٍّ، قَالَ لَمَّا تُوُفِّيَ الْقَاسِمُ ابْنُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَتْ خَدِيجَةُ يَا رَسُولَ اللَّهِ دَرَّتْ لُبَيْنَةُ الْقَاسِمِ فَلَوْ كَانَ اللَّهُ أَبْقَاهُ حَتَّى يَسْتَكْمِلَ رَضَاعَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ تَمَامَ رَضَاعِهِ فِي الْجَنَّةِ ‏"‏ ‏.‏ قَالَتْ لَوْ أَعْلَمُ ذَلِكَ يَا رَسُولَ اللَّهِ لَهَوَّنَ عَلَىَّ أَمْرَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنْ شِئْتِ دَعَوْتُ اللَّهَ تَعَالَى فَأَسْمَعَكِ صَوْتَهُ ‏"‏ ‏.‏ قَالَتْ يَا رَسُولَ اللَّهِ بَلْ أُصَدِّقُ اللَّهَ وَرَسُولَهُ ‏.‏\hadithno{1512}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{Husain bin ‘Ali said:“When Qasim the son of the Messenger of Allah (ﷺ) died, Khadijah said: ‘O Messenger of Allah, the milk of Qasim’s mother is overflowing. Would that Allah had let him live until he had finished breastfeeding.’ The Messenger of Allah (ﷺ) said: ‘He will complete his breastfeeding in Paradise.’ She said: ‘If I know that, O Messenger of Allah, it makes it easier for me to bear.’ The Messenger of Allah (ﷺ) said: ‘If you wish, I will pray to Allah to let you hear his voice.’ She said: ‘O Messenger of Allah, rather I believe Allah and His Messenger.’”}}
\hadithdefcmd{ibnmajah}{1513}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أُتِيَ بِهِمْ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَوْمَ أُحُدٍ فَجَعَلَ يُصَلِّي عَلَى عَشَرَةٍ عَشَرَةٍ وَحَمْزَةُ هُوَ كَمَا هُوَ يُرْفَعُونَ وَهُوَ كَمَا هُوَ مَوْضُوعٌ ‏.‏\hadithno{1513}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn ‘Abbas said:“They (the martyrs) were brought to the Messenger of Allah (ﷺ) on the Day of Uhud, and he started to offer the funeral prayer for them, ten by ten. Hamzah lay where he lay, and they were taken away but he was left where he was.”}}
\hadithdefcmd{ibnmajah}{1514}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَجْمَعُ بَيْنَ الرَّجُلَيْنِ وَالثَّلاَثَةِ مِنْ قَتْلَى أُحُدٍ فِي ثَوْبٍ وَاحِدٍ ثُمَّ يَقُولُ ‏"‏ أَيُّهُمْ أَكْثَرُ أَخْذًا لِلْقُرْآنِ ‏"‏ ‏.‏ فَإِذَا أُشِيرَ لَهُ إِلَى أَحَدِهِمْ قَدَّمَهُ فِي اللَّحْدِ وَقَالَ ‏"‏ أَنَا شَهِيدٌ عَلَى هَؤُلاَءِ ‏"‏ ‏.‏ وَأَمَرَ بِدَفْنِهِمْ فِي دِمَائِهِمْ وَلَمْ يُصَلِّ عَلَيْهِمْ وَلَمْ يُغَسَّلُوا ‏.‏\hadithno{1514}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) used to put two or three of the slain of Uhud in one shroud. He would ask:“Which of them had memorized more Qur’an?” And if one of them was pointed out to him, he would put him in the niche-grave first. And he said: “I am a witness over them.” He commanded that they should be buried with their blood, and that the funeral prayer should not be offered for them and they should not be washed}}
\hadithdefcmd{ibnmajah}{1515}{حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، حَدَّثَنَا عَلِيُّ بْنُ عَاصِمٍ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَمَرَ بِقَتْلَى أُحُدٍ أَنْ يُنْزَعَ عَنْهُمُ الْحَدِيدُ وَالْجُلُودُ وَأَنْ يُدْفَنُوا فِي ثِيَابِهِمْ بِدِمَائِهِمْ ‏.‏\hadithno{1515}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) commanded that the weapons and armor should be removed from the slain of Uhud, and they should be buried in their clothes stained with blood}}
\hadithdefcmd{ibnmajah}{1516}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَسَهْلُ بْنُ أَبِي سَهْلٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، سَمِعَ نُبَيْحًا الْعَنَزِيَّ، يَقُولُ سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ إِنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَمَرَ بِقَتْلَى أُحُدٍ أَنْ يُرَدُّوا إِلَى مَصَارِعِهِمْ وَكَانُوا نُقِلُوا إِلَى الْمَدِينَةِ ‏.‏\hadithno{1516}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Aswad bin Qais that he heard Nubaih Al-‘Anazi say:“I heard Jabir bin ‘Abdullah say: ‘The Messenger of Allah (ﷺ) commanded that the slain of the battle of Uhud should be returned to the battlefield; they had been moved to Al-Madinah.’”}}
\hadithdefcmd{ibnmajah}{1517}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنْ صَالِحٍ، مَوْلَى التَّوْأَمَةِ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ صَلَّى عَلَى جِنَازَةٍ فِي الْمَسْجِدِ فَلَيْسَ لَهُ شَىْءٌ ‏"‏ ‏.‏\hadithno{1517}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) said: ‘Whoever offers the funeral prayer in the mosque will have nothing (i.e., no reward).’”}}
\hadithdefcmd{ibnmajah}{1518}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، عَنْ صَالِحِ بْنِ عَجْلاَنَ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ وَاللَّهِ مَا صَلَّى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَلَى سُهَيْلِ ابْنِ بَيْضَاءَ إِلاَّ فِي الْمَسْجِدِ ‏.‏ قَالَ ابْنُ مَاجَهْ حَدِيثُ عَائِشَةَ أَقْوَى ‏.‏\hadithno{1518}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said:“By Allah! The Messenger of Allah (ﷺ) did not offer the funeral prayer for Suhail bin Baida’ anywhere but in the mosque.”}}
\hadithdefcmd{ibnmajah}{1519}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، جَمِيعًا عَنْ مُوسَى بْنِ عُلَىِّ بْنِ رَبَاحٍ، قَالَ سَمِعْتُ أَبِي يَقُولُ، سَمِعْتُ عُقْبَةَ بْنَ عَامِرٍ الْجُهَنِيَّ، يَقُولُ: ثَلاَثُ سَاعَاتٍ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَنْهَانَا أَنْ نُصَلِّيَ فِيهِنَّ أَوْ نَقْبِرَ فِيهِنَّ مَوْتَانَا حِينَ تَطْلُعُ الشَّمْسُ بَازِغَةً، وَحِينَ يَقُومُ قَائِمُ الظَّهِيرَةِ حَتَّى تَمِيلَ الشَّمْسُ، وَحِينَ تَضَيَّفُ لِلْغُرُوبِ حَتَّى تَغْرُبَ ‏.‏\hadithno{1519}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{‘Uqbah bin ‘Amir Al-Juhani said:“There are three times during the day when the Messenger of Allah (ﷺ) forbade us to offer the funeral prayer or bury our dead: When the sun has fully risen (until it is higher up in the sky), when it is overhead at noon until it has passed the meridian, and when it is starting to set until it has set.”}}
\hadithdefcmd{ibnmajah}{1520}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا يَحْيَى بْنُ الْيَمَانِ، عَنْ مِنْهَالِ بْنِ خَلِيفَةَ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَدْخَلَ رَجُلاً قَبْرَهُ لَيْلاً وَأَسْرَجَ فِي قَبْرِهِ ‏.‏\hadithno{1520}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) placed a man in his grave at night, and he lit a lamp in his grave}}
\hadithdefcmd{ibnmajah}{1521}{حَدَّثَنَا عَمْرُو بْنُ عَبْدِ اللَّهِ الأَوْدِيُّ، حَدَّثَنَا وَكِيعٌ، عَنْ إِبْرَاهِيمَ بْنِ يَزِيدَ الْمَكِّيِّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ تَدْفِنُوا مَوْتَاكُمْ بِاللَّيْلِ إِلاَّ أَنْ تُضْطَرُّوا ‏"‏ ‏.‏\hadithno{1521}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Messenger of Allah (ﷺ) said:“Do not bury your dead at night unless you are forced to.”}}
\hadithdefcmd{ibnmajah}{1522}{حَدَّثَنَا الْعَبَّاسُ بْنُ عُثْمَانَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ ابْنِ لَهِيعَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ صَلُّوا عَلَى مَوْتَاكُمْ بِاللَّيْلِ وَالنَّهَارِ ‏"‏ ‏.‏\hadithno{1522}\hadithgrade{Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Prophet (ﷺ) said:“Offer the funeral prayer for your dead by night or by day.”}}
\hadithdefcmd{ibnmajah}{1523}{حَدَّثَنَا أَبُو بِشْرٍ، بَكْرُ بْنُ خَلَفٍ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ لَمَّا تُوُفِّيَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ جَاءَ ابْنُهُ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ أَعْطِنِي قَمِيصَكَ أُكَفِّنْهُ فِيهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ آذِنُونِي بِهِ ‏"‏ ‏.‏ فَلَمَّا أَرَادَ النَّبِيُّ ـ صلى الله عليه وسلم ـ أَنْ يُصَلِّيَ عَلَيْهِ قَالَ لَهُ عُمَرُ بْنُ الْخَطَّابِ مَا ذَاكَ لَكَ ‏.‏ فَصَلَّى عَلَيْهِ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَقَالَ لَهُ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ أَنَا بَيْنَ خِيرَتَيْنِ ‏\{اسْتَغْفِرْ لَهُمْ أَوْ لاَ تَسْتَغْفِرْ لَهُمْ \}‏ ‏"‏ ‏.‏ فَأَنْزَلَ اللَّهُ سُبْحَانَهُ ‏\{وَلاَ تُصَلِّ عَلَى أَحَدٍ مِنْهُمْ مَاتَ أَبَدًا وَلاَ تَقُمْ عَلَى قَبْرِهِ\}‏ ‏.‏\hadithno{1523}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Ibn ‘Umar said:“When ‘Abdullah bin Ubayy died, his son came to the Prophet (ﷺ) and said: ‘O Messenger of Allah, give me your shirt so that I may shroud him in it.’ The Messenger of Allah (ﷺ) said: ‘Notify me when he is ready (i.e., when he has been washed and shrouded).’ When the Prophet (ﷺ) wanted to offer the funeral prayer for him: ‘You should not do that.’ The Prophet (ﷺ) offered the funeral prayer for him, and the Prophet (ﷺ) said to him: ‘I have been given two choices: “...ask forgiveness for them (hypocrites) or ask not forgiveness for them...’” [9:80] Then Allah revealed: ‘And never pray (the funeral prayer) for any of them (hypocrites) who dies, nor stand at his grave.’” [9:]}}
\hadithdefcmd{ibnmajah}{1524}{حَدَّثَنَا عَمَّارُ بْنُ خَالِدٍ الْوَاسِطِيُّ، وَسَهْلُ بْنُ أَبِي سَهْلٍ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ مُجَالِدٍ، عَنْ عَامِرٍ، عَنْ جَابِرٍ، قَالَ مَاتَ رَأْسُ الْمُنَافِقِينَ بِالْمَدِينَةِ وَأَوْصَى أَنْ يُصَلِّيَ عَلَيْهِ النَّبِيُّ ـ صلى الله عليه وسلم ـ وَأَنْ يُكَفِّنَهُ فِي قَمِيصِهِ فَصَلَّى عَلَيْهِ وَكَفَّنَهُ فِي قَمِيصِهِ وَقَامَ عَلَى قَبْرِهِ فَأَنْزَلَ اللَّهُ ‏\{وَلاَ تُصَلِّ عَلَى أَحَدٍ مِنْهُمْ مَاتَ أَبَدًا وَلاَ تَقُمْ عَلَى قَبْرِهِ\}‏ ‏.‏\hadithno{1524}\hadithgrade{Al-Albani: Munkar; Muhammad Fouad Abd al-Baqi: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jabir said:“The leader of the hypocrites in Al- Madinah died, and left instructions that the Prophet (ﷺ) should offer the funeral prayer for him and shroud him in his shirt. He offered the funeral prayer for him and shrouded him in his shirt, and stood by his grave. Then Allah revealed the words: ‘And never pray (the funeral prayer) for any of them (hypocrites) who dies, nor stand at his grave.” [9:]}}
\hadithdefcmd{ibnmajah}{1525}{حَدَّثَنَا أَحْمَدُ بْنُ يُوسُفَ السُّلَمِيُّ، حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا الْحَارِثُ بْنُ نَبْهَانَ، حَدَّثَنَا عُتْبَةُ بْنُ يَقْظَانَ، عَنْ أَبِي سَعِيدٍ، عَنْ مَكْحُولٍ، عَنْ وَاثِلَةَ بْنِ الأَسْقَعِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ صَلُّوا عَلَى كُلِّ مَيِّتٍ وَجَاهِدُوا مَعَ كُلِّ أَمِيرٍ ‏"‏ ‏.‏\hadithno{1525}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Wathilah bin Asqa’ that the Messenger of Allah (ﷺ) said:‘Offer prayer for everyone who dies, and strive in Jihad under every chief.”}}
\hadithdefcmd{ibnmajah}{1526}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَامِرِ بْنِ زُرَارَةَ، حَدَّثَنَا شَرِيكُ بْنُ عَبْدِ اللَّهِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، أَنَّ رَجُلاً، مِنْ أَصْحَابِ النَّبِيِّ ـ صلى الله عليه وسلم ـ جُرِحَ فَآذَتْهُ الْجِرَاحَةُ فَدَبَّ إِلَى مَشَاقِصِهِ فَذَبَحَ بِهِ نَفْسَهُ فَلَمْ يُصَلِّ عَلَيْهِ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ وَكَانَ ذَلِكَ أَدَبًا مِنْهُ ‏.‏\hadithno{1526}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir bin Samurah that a man from among the Companions of the Prophet (ﷺ) was wounded, and the wound caused him a great deal of pain. He went and took a spearhead, and slaughtered himself with it. The Prophet (ﷺ) did not offer the funeral prayer for him, and that was as an admonition for others}}
\hadithdefcmd{ibnmajah}{1527}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا ثَابِتٌ، عَنْ أَبِي رَافِعٍ، عَنْ أَبِي هُرَيْرَةَ، ‏.‏ أَنَّ امْرَأَةً، سَوْدَاءَ كَانَتْ تَقُمُّ الْمَسْجِدَ فَفَقَدَهَا رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَسَأَلَ عَنْهَا بَعْدَ أَيَّامٍ فَقِيلَ لَهُ إِنَّهَا مَاتَتْ ‏.‏ قَالَ ‏ "‏ فَهَلاَّ آذَنْتُمُونِي ‏"‏ ‏.‏ فَأَتَى قَبْرَهَا فَصَلَّى عَلَيْهَا ‏.‏\hadithno{1527}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that a black woman used to sweep the mosque. The Messenger of Allah (ﷺ) noticed she was missing and he asked about her after a few days. He was told that she had died. He said:“Why did you not tell me?” Then he went to her grave and offered the funeral prayer for her}}
\hadithdefcmd{ibnmajah}{1528}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، حَدَّثَنَا خَارِجَةُ بْنُ زَيْدِ بْنِ ثَابِتٍ، عَنْ يَزِيدَ بْنِ ثَابِتٍ، وَكَانَ، أَكْبَرَ مِنْ زَيْدٍ قَالَ خَرَجْنَا مَعَ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَلَمَّا وَرَدَ الْبَقِيعَ فَإِذَا هُوَ بِقَبْرٍ جَدِيدٍ فَسَأَلَ عَنْهُ فَقَالُوا فُلاَنَةُ ‏.‏ قَالَ فَعَرَفَهَا وَقَالَ ‏"‏ أَلاَ آذَنْتُمُونِي بِهَا ‏"‏ ‏.‏ قَالُوا كُنْتَ قَائِلاً صَائِمًا فَكَرِهْنَا أَنْ نُؤْذِيَكَ ‏.‏ قَالَ ‏"‏ فَلاَ تَفْعَلُوا لاَ أَعْرِفَنَّ مَا مَاتَ فِيكُمْ مَيِّتٌ مَا كُنْتُ بَيْنَ أَظْهُرِكُمْ إِلاَّ آذَنْتُمُونِي بِهِ فَإِنَّ صَلاَتِي عَلَيْهِ لَهُ رَحْمَةٌ ‏"‏ ‏.‏ ثُمَّ أَتَى الْقَبْرَ فَصَفَّنَا خَلْفَهُ فَكَبَّرَ عَلَيْهِ أَرْبَعًا ‏.‏\hadithno{1528}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Kharijah bin Zaid bin Thabit narrated that Yazid bin Thabit, who was older than Zaid, said:“We went out with the Prophet (ﷺ) and when we reached Al-Baqi’, we saw a new grave. He asked about it and they said: ‘(It is) so-and-so (a woman).’ He recognized the name and said: ‘Why did you not tell me about her?’ They said: ‘You were taking a nap and you were fasting, and we did not like to disturb you.’ He said: ‘Do not do that; I do not want to see it happen again that one of you dies, while I am still among you, and you do not tell me, for my prayer for him is a mercy.’ Then he went to the grave and we lined up in rows behind him, and he said four Takbir (i.e. for the funeral prayer).”}}
\hadithdefcmd{ibnmajah}{1529}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، عَنْ مُحَمَّدِ بْنِ زَيْدِ بْنِ الْمُهَاجِرِ بْنِ قُنْفُذٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، عَنْ أَبِيهِ، أَنَّ امْرَأَةً، سَوْدَاءَ مَاتَتْ و لَمْ يُؤْذَنْ بِهَا النَّبِيُّ ـ صلى الله عليه وسلم ـ فَأُخْبِرَ بِذَلِكَ فَقَالَ ‏"‏ هَلاَّ آذَنْتُمُونِي بِهَا ‏"‏ ‏.‏ ثُمَّ قَالَ لأَصْحَابِهِ ‏"‏ صُفُّوا عَلَيْهَا ‏"‏ ‏.‏ فَصَلَّى عَلَيْهَا ‏.‏\hadithno{1529}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Abdullah bin ‘Amir bin Rabi’ah, from his father, that a black woman died and the Prophet (ﷺ) was not told about that. Then he was informed of it, and he said:“Why did you not tell me?” Then he said to his Companions: “Line up in rows to pray for her,” and he offered the funeral prayer for her}}
\hadithdefcmd{ibnmajah}{1530}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ أَبِي إِسْحَاقَ الشَّيْبَانِيِّ، عَنِ الشَّعْبِيِّ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَاتَ رَجُلٌ وَكَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَعُودُهُ. فَدَفَنُوهُ بِاللَّيْلِ. فَلَمَّا أَصْبَحَ أَعْلَمُوهُ. فَقَالَ ‏ "‏ مَا مَنَعَكُمْ أَنْ تُعْلِمُونِي ‏"‏ ‏.‏ قَالُوا كَانَ اللَّيْلُ وَكَانَتِ الظُّلْمَةُ فَكَرِهْنَا أَنْ نَشُقَّ عَلَيْكَ ‏.‏ فَأَتَى قَبْرَهُ، فَصَلَّى عَلَيْهِ ‏.‏\hadithno{1530}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Ibn ‘Abbas said:“A man died whom the Messenger of Allah (ﷺ) used to visit, and they buried him at night. When morning came, they told him. He said: ‘What kept you from telling me?’ They said: ‘It was night and it was dark, and we did not like to cause you any inconvenience.’ Then he went to the grave and offered the funeral prayer for him.”}}
\hadithdefcmd{ibnmajah}{1531}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ صَلَّى عَلَى قَبْرٍ بَعْدَ مَا قُبِرَ ‏.‏\hadithno{1531}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Anas that the Prophet (ﷺ) offered the funeral prayer at a grave after the burial}}
\hadithdefcmd{ibnmajah}{1532}{حَدَّثَنَا مُحَمَّدُ بْنُ حُمَيْدٍ، حَدَّثَنَا مِهْرَانُ بْنُ أَبِي عُمَرَ، عَنْ أَبِي سِنَانٍ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ صَلَّى عَلَى مَيِّتٍ بَعْدَ مَا دُفِنَ ‏.‏\hadithno{1532}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn Buraidah from his father that the Prophet (ﷺ) offered the funeral prayer for a deceased person after he had been buried}}
\hadithdefcmd{ibnmajah}{1533}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا سَعِيدُ بْنُ شُرَحْبِيلَ، عَنِ ابْنِ لَهِيعَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ الْمُغِيرَةِ، عَنْ أَبِي الْهَيْثَمِ، عَنْ أَبِي سَعِيدٍ، قَالَ كَانَتْ سَوْدَاءُ تَقُمُّ الْمَسْجِدَ فَتُوُفِّيَتْ لَيْلاً فَلَمَّا أَصْبَحَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أُخْبِرَ بِمَوْتِهَا فَقَالَ ‏ "‏ أَلاَ آذَنْتُمُونِي بِهَا ‏"‏ ‏.‏ فَخَرَجَ بِأَصْحَابِهِ فَوَقَفَ عَلَى قَبْرِهَا فَكَبَّرَ عَلَيْهَا وَالنَّاسُ مِنْ خَلْفِهِ وَدَعَا لَهَا ثُمَّ انْصَرَفَ ‏.‏\hadithno{1533}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih Lighairihi; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Sa’eed said:“There was a black woman who used to sweep the mosque, and she passed away at night. The following morning the Messenger of Allah (ﷺ) was told of her death. He said: ‘Why did you not call me?’ Then he went out with his Companions and stood at her grave, and said Takbir over her, with the people behind him, and he supplicated for her, then he went away.’”}}
\hadithdefcmd{ibnmajah}{1534}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ النَّجَاشِيَّ قَدْ مَاتَ ‏"‏ ‏.‏ فَخَرَجَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَصْحَابُهُ إِلَى الْبَقِيعِ ‏.‏ فَصَفَّنَا خَلْفَهُ وَتَقَدَّمَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَكَبَّرَ أَرْبَعَ تَكْبِيرَاتٍ ‏.‏\hadithno{1534}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah:“The Messenger of Allah (ﷺ) said: ‘Najashi has died.’ The Messenger of Allah (ﷺ) and his Companions went out to Al-Baqi’, and we lined up in rows behind him, and the Messenger of Allah (ﷺ) went forward, then he said four Takbir.”}}
\hadithdefcmd{ibnmajah}{1535}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ، وَمُحَمَّدُ بْنُ زِيَادٍ، قَالاَ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، ح وَحَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، حَدَّثَنَا هُشَيْمٌ، جَمِيعًا عَنْ يُونُسَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ الْحُصَيْنِ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ أَخَاكُمُ النَّجَاشِيَّ قَدْ مَاتَ فَصَلُّوا عَلَيْهِ ‏"‏ ‏.‏ قَالَ فَقَامَ فَصَلَّيْنَا خَلْفَهُ وَإِنِّي لَفِي الصَّفِّ الثَّانِي فَصَلَّى عَلَيْهِ صفَّين‏.‏\hadithno{1535}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Imran bin Husain:“The Messenger of Allah (ﷺ) said: ‘Your brother Najashi has died, so offer the funeral prayer for him.” Then he stood and we prayed behind him. I was in the second row and two rows prayed for him.”}}
\hadithdefcmd{ibnmajah}{1536}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، حَدَّثَنَا سُفْيَانُ، عَنْ حُمْرَانَ بْنِ أَعْيَنَ، عَنْ أَبِي الطُّفَيْلِ، عَنْ مُجَمِّعِ بْنِ جَارِيَةَ الأَنْصَارِيِّ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ إِنَّ أَخَاكُمُ النَّجَاشِيَّ قَدْ مَاتَ فَقُومُوا فَصَلُّوا عَلَيْهِ ‏"‏ ‏.‏ فَصَففنَا خَلْفَهُ صَفَّيْنِ ‏.‏\hadithno{1536}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Mujammi’ bin Jariyah Al-Ansari that the Messenger of Allah (ﷺ) said:“Your brother Najashi has died, so stand and pray for him.” So we formed two rows behind him}}
\hadithdefcmd{ibnmajah}{1537}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنِ الْمُثَنَّى بْنِ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَبِي الطُّفَيْلِ، عَنْ حُذَيْفَةَ بْنِ أَسِيدٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ خَرَجَ بِهِمْ فَقَالَ ‏"‏ صَلُّوا عَلَى أَخٍ لَكُمْ مَاتَ بِغَيْرِ أَرْضِكُمْ ‏"‏ ‏.‏ قَالُوا: مَنْ هُوَ؟ قَالَ: ‏"‏ النَّجَاشِيُّ ‏"‏ ‏.‏\hadithno{1537}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Hudhaifah bin Asid that the Prophet (ﷺ) led them out and said:“Pray for a brother of yours who has died in a land other than yours.” They said: “Who is he?” He said: “Najashi.”}}
\hadithdefcmd{ibnmajah}{1538}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا مَكِّيُّ بْنُ إِبْرَاهِيمَ أَبُو السَّكَنِ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ صَلَّى عَلَى النَّجَاشِيِّ فَكَبَّرَ أَرْبَعًا ‏.‏\hadithno{1538}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) offered the funeral prayer for Najashi and said four Takbir}}
\hadithdefcmd{ibnmajah}{1539}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ مَنْ صَلَّى عَلَى جِنَازَةٍ فَلَهُ قِيرَاطٌ وَمَنِ انْتَظَرَ حَتَّى يُفْرَغَ مِنْهَا فَلَهُ قِيرَاطَانِ ‏"‏ ‏.‏ قَالُوا وَمَا الْقِيرَاطَانِ قَالَ ‏"‏ مِثْلُ الْجَبَلَيْنِ ‏"‏ ‏.‏\hadithno{1539}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“Whoever offers the funeral prayer will have one Qirat and whoever awaits until (the burial) is finished will have two Qirat.” They said: ‘What are these two Qirat?’ He said: ‘Like two mountains.’”}}
\hadithdefcmd{ibnmajah}{1540}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، حَدَّثَنِي سَالِمُ بْنُ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَنْ صَلَّى عَلَى جِنَازَةٍ فَلَهُ قِيرَاطٌ وَمَنْ شَهِدَ دَفْنَهَا فَلَهُ قِيرَاطَانِ ‏"‏ ‏.‏ قَالَ: فَسُئِلَ نَبِيُّ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْقِيرَاطِ؟ فَقَالَ ‏"‏ مِثْلُ أُحُدٍ ‏"‏ ‏.‏\hadithno{1540}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Thawban that the Messenger of Allah (ﷺ) said:“Whoever offers the funeral prayer will have one Qirat and whoever attends the burial will have two Qirat.” The Prophet (ﷺ) was asked about the Qirat and he said: “(It is) like Uhud.”}}
\hadithdefcmd{ibnmajah}{1541}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ الْمُحَارِبِيُّ، عَنْ حَجَّاجِ بْنِ أَرْطَاةَ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ زِرِّ بْنِ حُبَيْشٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ صَلَّى عَلَى جِنَازَةٍ فَلَهُ قِيرَاطٌ وَمَنْ شَهِدَهَا حَتَّى تُدْفَنَ فَلَهُ قِيرَاطَانِ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ الْقِيرَاطُ أَعْظَمُ مِنْ أُحُدٍ هَذَا ‏"‏ ‏.‏\hadithno{1541}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ubayy bin Ka’b that the Messenger of Allah (ﷺ) said:‘Whoever offers the funeral prayer will have one Qirat; and whoever attends until the burial is over, will have two Qirat. By the One in Whose Hand is the soul of Muhammad! The Qirat is greater than this (mountain of) Uhud.”}}
\hadithdefcmd{ibnmajah}{1542}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ عَامِرِ بْنِ رَبِيعَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ح: وَحَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنْ عَامِرِ بْنِ رَبِيعَةَ، سَمِعَهُ يُحَدِّثُ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ: ‏ "‏ إِذَا رَأَيْتُمُ الْجِنَازَةَ فَقُومُوا لَهَا حَتَّى تُخَلِّفَكُمْ أَوْ تُوضَعَ ‏"‏ ‏.‏\hadithno{1542}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from ‘Amir bin Rabi’ah that the Prophet (ﷺ) said:“When you see a funeral (procession) stand up for it until it has passed by or it is placed on the ground.”}}
\hadithdefcmd{ibnmajah}{1543}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهَنَّادُ بْنُ السَّرِيِّ، قَالاَ حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مُرَّ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ بِجِنَازَةٍ فَقَامَ وَقَالَ ‏ "‏ قُومُوا فَإِنَّ لِلْمَوْتِ فَزَعًا ‏"‏ ‏.‏\hadithno{1543}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“A funeral has passed by the Prophet (ﷺ) and he stood up and said: ‘Stand up out of recognition of the enormity of death.’”}}
\hadithdefcmd{ibnmajah}{1544}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ مَسْعُودِ بْنِ الْحَكَمِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ قَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ لِجِنَازَةٍ فَقُمْنَا حَتَّى جَلَسَ فَجَلَسْنَا ‏.‏\hadithno{1544}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Ali bin Abu Talib said:“The Messenger of Allah (ﷺ) stood up for a funeral, and we stood up, until he sat down, then we sat down.”}}
\hadithdefcmd{ibnmajah}{1545}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَعُقْبَةُ بْنُ مُكْرَمٍ، قَالاَ حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، حَدَّثَنَا بِشْرُ بْنُ رَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ سُلَيْمَانَ بْنِ جُنَادَةَ بْنِ أَبِي أُمَيَّةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا اتَّبَعَ جِنَازَةً لَمْ يَقْعُدْ حَتَّى تُوضَعَ فِي اللَّحْدِ فَعَرَضَ لَهُ حَبْرٌ فَقَالَ هَكَذَا نَصْنَعُ يَا مُحَمَّدُ ‏.‏ فَجَلَسَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَقَالَ ‏ "‏ خَالِفُوهُمْ ‏"‏ ‏.‏\hadithno{1545}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ubadah bin Samit said:“When the Messenger of Allah (ﷺ) followed a funeral, he would not sit down until it had been placed in the niche-grave. A rabbi came to him and said: ‘This is what we do, O Muhammad!’ So the Messenger of Allah (ﷺ) sat down and said: ‘Be different from them.’”}}
\hadithdefcmd{ibnmajah}{1546}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى، حَدَّثَنَا شَرِيكُ بْنُ عَبْدِ اللَّهِ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، عَنْ عَائِشَةَ، قَالَتْ فَقَدْتُهُ - تَعْنِي النَّبِيَّ ـ صلى الله عليه وسلم ـ - فَإِذَا هُوَ بِالْبَقِيعِ فَقَالَ ‏ "‏ السَّلاَمُ عَلَيْكُمْ دَارَ قَوْمٍ مُؤْمِنِينَ أَنْتُمْ لَنَا فَرَطٌ وَإِنَّا بِكُمْ لاَحِقُونَ اللَّهُمَّ لاَ تَحْرِمْنَا أَجْرَهُمْ وَلاَ تَفْتِنَّا بَعْدَهُمْ ‏"‏ ‏.‏\hadithno{1546}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“I could not find him, meaning the Prophet (ﷺ), and he was in Al-Baqi’. He said: “As-salamu ‘alaykum dara qawmin mu’minin. Antum lana faratun wa inna bikum lahiqun. Allahumma la tahrimna ajrahum wa la taftinna ba’dahum. (Peace be upon you, O abode of believing people. You have gone ahead of us and verily we will join you soon. O Allah, do not deprive us of their reward and do not put us to trial after them).”}}
\hadithdefcmd{ibnmajah}{1547}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادِ بْنِ آدَمَ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يُعَلِّمُهُمْ إِذَا خَرَجُوا إِلَى الْمَقَابِرِ. كَانَ قَائِلُهُمْ يَقُولُ: السَّلاَمُ عَلَيْكُمْ أَهْلَ الدِّيَارِ مِنَ الْمُؤْمِنِينَ وَالْمُسْلِمِينَ وَإِنَّا إِنْ شَاءَ اللَّهُ بِكُمْ لاَحِقُونَ نَسْأَلُ اللَّهَ لَنَا وَلَكُمُ الْعَافِيَةَ ‏.‏\hadithno{1547}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Sulaiman bin Buraidah that his father said:“The Messenger of Allah (ﷺ) used to teach them, when they went out to the graveyard, to say: As-salamu ‘alaykum ahlad-diyar minal-mu’minina wal- muslimin, wa inna insha’ Allah bikum lahiqun, nas’alul-laha lana wa lakumul-‘afiyah (Peace be upon you, O inhabitants of the abodes, believers and Muslims, and we will join you soon if Allah wills. We ask Allah for well-being for us and for you).’”}}
\hadithdefcmd{ibnmajah}{1548}{حَدَّثَنَا مُحَمَّدُ بْنُ زِيَادٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ يُونُسَ بْنِ خَبَّابٍ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ زَاذَانَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي جِنَازَةٍ فَقَعَدَ حِيَالَ الْقِبْلَةِ ‏.‏\hadithno{1548}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Bara’ bin ‘Azib said:“We went out with the Messenger of Allah (ﷺ) for a funeral, and he sat facing the Qiblah (prayer direction).”}}
\hadithdefcmd{ibnmajah}{1549}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ عَمْرِو بْنِ قَيْسٍ، عَنِ الْمِنْهَالِ بْنِ عَمْرٍو، عَنْ زَاذَانَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فِي جِنَازَةٍ فَانْتَهَيْنَا إِلَى الْقَبْرِ فَجَلَسَ وَجَلَسْنَا كَأَنَّ عَلَى رُءُوسِنَا الطَّيْرَ ‏.‏\hadithno{1549}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Bara’ bin ‘Azib said:“We went out with the Messenger of Allah (ﷺ) for a funeral, and we came to a grave. He sat down and we sat down, as if there were birds on our heads.”}}
\hadithdefcmd{ibnmajah}{1550}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا لَيْثُ بْنُ أَبِي سُلَيْمٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، حَدَّثَنَا الْحَجَّاجُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِذَا أُدْخِلَ الْمَيِّتُ الْقَبْرَ قَالَ ‏"‏ بِسْمِ اللَّهِ وَعَلَى مِلَّةِ رَسُولِ اللَّهِ ‏"‏ ‏.‏ وَقَالَ أَبُو خَالِدٍ مَرَّةً إِذَا وُضِعَ الْمَيِّتُ فِي لَحْدِهِ قَالَ ‏"‏ بِسْمِ اللَّهِ وَعَلَى سُنَّةِ رَسُولِ اللَّهِ ‏"‏ ‏.‏ وَقَالَ هِشَامٌ فِي حَدِيثِهِ ‏"‏ بِسْمِ اللَّهِ وَفِي سَبِيلِ اللَّهِ وَعَلَى مِلَّةِ رَسُولِ اللَّهِ ‏"‏ ‏.‏\hadithno{1550}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“When the deceased was placed in the grave, the Prophet (ﷺ) would say: ‘Bismillah, wa ‘ala millati rasul-illah (In the Name of Allah and according to the religion of the Messenger of Allah).’” Abu Khalid said on one occasion, when the deceased was placed in the grave: “Bismillah wa ‘ala sunnati rasul- illah (In the Name of Allah and according to the Sunnah of the Messenger of Allah).” Hisham said in his narration: “Bismillah, wa fi sabil-illah, wa ‘ala millati rasul-illah (In the Name of Allah, for the sake of Allah and according to the religion of the Messenger of Allah).”}}
\hadithdefcmd{ibnmajah}{1551}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ مُحَمَّدٍ الرَّقَاشِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْخَطَّابِ، حَدَّثَنَا مِنْدَلُ بْنُ عَلِيٍّ، أَخْبَرَنِي مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ أَبِيهِ، عَنْ أَبِي رَافِعٍ، قَالَ سَلَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ سَعْدًا وَرَشَّ عَلَى قَبْرِهِ مَاءً ‏.‏\hadithno{1551}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu Rafi’ said:“The Messenger of Allah (ﷺ) placed Sa’d gently in his grave and sprinkled water on it.”}}
\hadithdefcmd{ibnmajah}{1552}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنْ عَمْرِو بْنِ قَيْسٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أُخِذَ مِنْ قِبَلِ الْقِبْلَةِ وَاسْتُقْبِلَ اسْتِقْبَالاً وَاسْتُلَّ اسْتِلاَلاً ‏.‏\hadithno{1552}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa’eed that the Messenger of Allah (ﷺ) was brought into his grave from the direction of the Qiblah, and he was placed in his grave gently}}
\hadithdefcmd{ibnmajah}{1553}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا حَمَّادُ بْنُ عَبْدِ الرَّحْمَنِ الْكَلْبِيُّ، حَدَّثَنَا إِدْرِيسُ الأَوْدِيُّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، قَالَ حَضَرْتُ ابْنَ عُمَرَ فِي جِنَازَةٍ فَلَمَّا وَضَعَهَا فِي اللَّحْدِ قَالَ بِسْمِ اللَّهِ وَفِي سَبِيلِ اللَّهِ وَعَلَى مِلَّةِ رَسُولِ اللَّهِ ‏.‏ فَلَمَّا أُخِذَ فِي تَسْوِيَةِ اللَّبِنِ عَلَى اللَّحْدِ قَالَ اللَّهُمَّ أَجِرْهَا مِنَ الشَّيْطَانِ وَمِنْ عَذَابِ الْقَبْرِ اللَّهُمَّ جَافِ الأَرْضَ عَنْ جَنْبَيْهَا وَصَعِّدْ رُوحَهَا وَلَقِّهَا مِنْكَ رِضْوَانًا ‏.‏ قُلْتُ يَا ابْنَ عُمَرَ أَشَىْءٌ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَمْ قُلْتَهُ بِرَأْيِكَ قَالَ إِنِّي إِذًا لَقَادِرٌ عَلَى الْقَوْلِ بَلْ شَىْءٌ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1553}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{(It was narrated that Sa’eed bin Musayyab said:“I was present with Ibn ‘Umar at a funeral. When the body was placed in the niche-grave) he said, ‘Bismillah wa fi sabil-illah wa ‘ala millati rasul-illah’ (In the Name of Allah, for the sake of Allah and according to the religion of the Messenger of Allah). When he started to place bricks in the niche-grave he said: ‘Allahumma ajirha min ash-shaitani wa min ‘adhabil-qabr. Allahumma Jafil-arda ‘an janbaiha, wa sa’id ruhaha, wa laqqiha minka ridwana (O Allah, protect him from Satan and from the torment of the grave; O Allah, keep the earth away from his two sides and take his soul up and grant him pleasure from Yourself).’ I said: ‘O Ibn ‘Umar, is this something that you heard from the Messenger of Allah (ﷺ) or is it your own words?’ He said: ‘I could have said something like that, but this is something that I heard from the Messenger of Allah (ﷺ).’”}}
\hadithdefcmd{ibnmajah}{1554}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا حَكَّامُ بْنُ سَلْمٍ الرَّازِيُّ، قَالَ سَمِعْتُ عَلِيَّ بْنَ عَبْدِ الأَعْلَى، يَذْكُرُ عَنْ أَبِيهِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اللَّحْدُ لَنَا وَالشَّقُّ لِغَيْرِنَا ‏"‏ ‏.‏\hadithno{1554}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) said: ‘The niche-grave is for us and the ditch-grave is for others.”}}
\hadithdefcmd{ibnmajah}{1555}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى السُّدِّيُّ، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي الْيَقْظَانِ، عَنْ زَاذَانَ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ الْبَجَلِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اللَّحْدُ لَنَا وَالشَّقُّ لِغَيْرِنَا ‏"‏ ‏.‏\hadithno{1555}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jarir bin ‘Abdullah Al-Bajali said:“The Messenger of Allah (ﷺ) said: ‘The niche-grave is for us and the ditch-grave is for others.’”}}
\hadithdefcmd{ibnmajah}{1556}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الزُّهْرِيُّ، عَنْ إِسْمَاعِيلَ بْنِ مُحَمَّدِ بْنِ سَعْدٍ، عَنْ عَامِرِ بْنِ سَعْدٍ، عَنْ سَعْدٍ، أَنَّهُ قَالَ: أَلْحِدُوا لِي لَحْدًا وَانْصِبُوا عَلَىَّ اللَّبِنَ نَصْبًا كَمَا فُعِلَ بِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1556}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Sa’d said:“Make a niche-grave for me, and block it up with bricks as was done for the Messenger of Allah (ﷺ).”}}
\hadithdefcmd{ibnmajah}{1557}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، حَدَّثَنَا مُبَارَكُ بْنُ فَضَالَةَ، حَدَّثَنِي حُمَيْدٌ الطَّوِيلُ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ: لَمَّا تُوُفِّيَ النَّبِيُّ ـ صلى الله عليه وسلم ـ كَانَ بِالْمَدِينَةِ رَجُلٌ يَلْحَدُ وَآخَرُ يَضْرَحُ. فَقَالُوا: نَسْتَخِيرُ رَبَّنَا وَنَبْعَثُ إِلَيْهِمَا فَأَيُّهُمَا سَبَقَ تَرَكْنَاهُ ‏.‏ فَأُرْسِلَ إِلَيْهِمَا فَسَبَقَ صَاحِبُ اللَّحْدِ. فَلَحَدُوا لِلنَّبِيِّ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1557}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Anas bin Malik said:“When the Prophet (ﷺ) died, there was a man in Al-Madinah who used to make a niche in the grave and another who used to dig graves without a niche. They said: ‘Let us pray Istikharah to our Lord and call for them both, and whichever of them comes first, we will let him do it.’ So they were both sent for, and the one who used to make the niche-grave came first, so they made a niche-grave for the Prophet (ﷺ).”}}
\hadithdefcmd{ibnmajah}{1558}{حَدَّثَنَا عُمَرُ بْنُ شَبَّةَ بْنِ عُبَيْدَةَ بْنِ زَيْدٍ، حَدَّثَنَا عُبَيْدُ بْنُ طُفَيْلٍ الْمُقْرِئُ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ أَبِي مُلَيْكَةَ الْقُرَشِيُّ، حَدَّثَنَا ابْنُ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا مَاتَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ اخْتَلَفُوا فِي اللَّحْدِ وَالشَّقِّ حَتَّى تَكَلَّمُوا فِي ذَلِكَ وَارْتَفَعَتْ أَصْوَاتُهُمْ ‏.‏ فَقَالَ: عُمَرُ لاَ تَصْخَبُوا عِنْدَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ حَيًّا وَلاَ مَيِّتًا أَوْ كَلِمَةً نَحْوَهَا ‏.‏ فَأَرْسَلُوا إِلَى الشَّقَّاقِ وَاللاَّحِدِ جَمِيعًا فَجَاءَ اللاَّحِدُ فَلَحَدَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ثُمَّ دُفِنَ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1558}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Aishah said:“When the Messenger of Allah (ﷺ) died, they differed as to whether his grave should have a niche or a ditch in the ground, until they spoke and raised their voices concerning that. Then ‘Umar said: ‘Do not shout in the presence of the Messenger of Allah (ﷺ), living or dead,’ or words to that effect. So they sent for both the one who made a niche and the one who dug graves without a niche, and the one who used to make a niche came and dug a grave with a niche for the Messenger of Allah (ﷺ), then he (ﷺ) was buried.”}}
\hadithdefcmd{ibnmajah}{1559}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنَا مُوسَى بْنُ عُبَيْدَةَ، حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، عَنِ الأَدْرَعِ السُّلَمِيِّ، قَالَ جِئْتُ لَيْلَةً أَحْرُسُ النَّبِيَّ ـ صلى الله عليه وسلم ـ فَإِذَا رَجُلٌ قِرَاءَتُهُ عَالِيَةٌ فَخَرَجَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَقُلْتُ يَا رَسُولَ اللَّهِ هَذَا مُرَاءٍ ‏.‏ قَالَ فَمَاتَ بِالْمَدِينَةِ فَفَرَغُوا مِنْ جِهَازِهِ فَحَمَلُوا نَعْشَهُ فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏"‏ ارْفُقُوا بِهِ رَفَقَ اللَّهُ بِهِ إِنَّهُ كَانَ يُحِبُّ اللَّهَ وَرَسُولَهُ ‏"‏ ‏.‏ قَالَ وَحَفَرَ حُفْرَتَهُ فَقَالَ ‏"‏ أَوْسِعُوا لَهُ وَسَّعَ اللَّهُ عَلَيْهِ ‏"‏ ‏.‏ فَقَالَ بَعْضُ أَصْحَابِهِ يَا رَسُولَ اللَّهِ لَقَدْ حَزِنْتَ عَلَيْهِ ‏.‏ فَقَالَ ‏"‏ أَجَلْ إِنَّهُ كَانَ يُحِبُّ اللَّهَ وَرَسُولَهُ ‏"‏ ‏.‏\hadithno{1559}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Adra’ As-Sulami said:“I came one night to guard the Prophet (ﷺ), and there was a man reciting loudly. The Prophet (ﷺ) came out and I said: ‘O Messenger of Allah, this man is showing off.’ Then he died in Al-Madinah, and they finished preparing him, then they carried his dead body. The Prophet (ﷺ) said: ‘Be gentle with him, may Allah be gentle with him, for he loved Allah and His Messenger.’ Then his grave was dug and he (the Prophet (ﷺ)) said: ‘Make it spacious for him, and may Allah make it spacious for him.’ Some of his Companions said: ‘O Messenger of Allah, you are grieving for him.’ He said: ‘Yes indeed, for he loved Allah and His Messenger.’”}}
\hadithdefcmd{ibnmajah}{1560}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، حَدَّثَنَا أَيُّوبُ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَبِي الدَّهْمَاءِ، عَنْ هِشَامِ بْنِ عَامِرٍ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ احْفِرُوا وَأَوْسِعُوا وَأَحْسِنُوا ‏"‏ ‏.‏\hadithno{1560}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Hisham bin ‘Amir that the Messenger of Allah (ﷺ) said:“Dig the grave deep, make it spacious and prepare it well.”}}
\hadithdefcmd{ibnmajah}{1561}{حَدَّثَنَا الْعَبَّاسُ بْنُ جَعْفَرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ أَيُّوبَ أَبُو هُرَيْرَةَ الْوَاسِطِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ كَثِيرِ بْنِ زَيْدٍ، عَنْ زَيْنَبَ بِنْتِ نُبَيْطٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ أَعْلَمَ قَبْرَ عُثْمَانَ بْنِ مَظْعُونٍ بِصَخْرَةٍ ‏.‏\hadithno{1561}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) marked the grave of ‘Uthman bin Maz’un with a rock}}
\hadithdefcmd{ibnmajah}{1562}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ، وَمُحَمَّدُ بْنُ زِيَادٍ، قَالاَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَيُّوبَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنْ تَقْصِيصِ الْقُبُورِ ‏.‏\hadithno{1562}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:“The Messenger of Allah (ﷺ) forbade plastering over graves.”}}
\hadithdefcmd{ibnmajah}{1563}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ جَابِرٍ، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ يُكْتَبَ عَلَى الْقَبْرِ شَىْءٌ ‏.‏\hadithno{1563}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Jabir said:“The Messenger of Allah (ﷺ) forbade writing anything on graves.”}}
\hadithdefcmd{ibnmajah}{1564}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الرَّقَاشِيُّ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ بْنِ جَابِرٍ، عَنِ الْقَاسِمِ بْنِ مُخَيْمِرَةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ نَهَى أَنْ يُبْنَى عَلَى الْقَبْرِ ‏.‏\hadithno{1564}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa’eed that the Prophet (ﷺ) forbade building structures over graves}}
\hadithdefcmd{ibnmajah}{1565}{حَدَّثَنَا الْعَبَّاسُ بْنُ الْوَلِيدِ الدِّمَشْقِيُّ، حَدَّثَنَا يَحْيَى بْنُ صَالِحٍ، حَدَّثَنَا سَلَمَةُ بْنُ كُلْثُومٍ، حَدَّثَنَا الأَوْزَاعِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ صَلَّى عَلَى جِنَازَةٍ ثُمَّ أَتَى قَبْرَ الْمَيِّتِ فَحَثَى عَلَيْهِ مِنْ قِبَلِ رَأْسِهِ ثَلاَثًا ‏.‏\hadithno{1565}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) offered the funeral prayer, then he came to the grave of the deceased and scattered three handfuls of earth from the side of (the deceased’s) head}}
\hadithdefcmd{ibnmajah}{1566}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لأَنْ يَجْلِسَ أَحَدُكُمْ عَلَى جَمْرَةٍ تُحْرِقُهُ خَيْرٌ لَهُ مِنْ أَنْ يَجْلِسَ عَلَى قَبْرٍ ‏"‏ ‏.‏\hadithno{1566}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah said:The Messenger of Allah (ﷺ) said: “If one of you were to sit on a live coal that burns him, that would be better for him than if he were to sit on a grave.”}}
\hadithdefcmd{ibnmajah}{1567}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ سَمُرَةَ، حَدَّثَنَا الْمُحَارِبِيُّ، عَنِ اللَّيْثِ بْنِ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، مَرْثَدِ بْنِ عَبْدِ اللَّهِ الْيَزَنِيِّ عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لأَنْ أَمْشِيَ عَلَى جَمْرَةٍ أَوْ سَيْفٍ أَوْ أَخْصِفَ نَعْلِي بِرِجْلِي أَحَبُّ إِلَىَّ مِنْ أَنْ أَمْشِيَ عَلَى قَبْرِ مُسْلِمٍ وَمَا أُبَالِي أَوَسَطَ الْقُبُورِ قَضَيْتُ حَاجَتِي أَوْ وَسَطَ السُّوقِ ‏"‏ ‏.‏\hadithno{1567}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Uqbah bin ‘Amir that the Messenger of Allah (ﷺ) said:‘If I were to walk on a live coal or a sword, or if I were to sew shows to my feet, that would be better for me than walking on the grave of a Muslim. And I see no difference between relieving myself in the midst of graves or in the middle of the marketplace.”}}
\hadithdefcmd{ibnmajah}{1568}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَسْوَدُ بْنُ شَيْبَانَ، عَنْ خَالِدِ بْنِ سُمَيْرٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ بَشِيرِ بْنِ الْخَصَاصِيَةِ، قَالَ بَيْنَمَا أَنَا أَمْشِي، مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ يَا ابْنَ الْخَصَاصِيَةِ مَا تَنْقِمُ عَلَى اللَّهِ أَصْبَحْتَ تُمَاشِي رَسُولَ اللَّهِ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ مَا أَنْقِمُ عَلَى اللَّهِ شَيْئًا كُلُّ خَيْرٍ قَدْ أَتَانِيهِ اللَّهُ ‏.‏ فَمَرَّ عَلَى مَقَابِرِ الْمُسْلِمِينَ فَقَالَ ‏"‏ أَدْرَكَ هَؤُلاَءِ خَيْرًا كَثِيرًا ‏"‏ ‏.‏ ثُمَّ مَرَّ عَلَى مَقَابِرِ الْمُشْرِكِينَ فَقَالَ ‏"‏ سَبَقَ هَؤُلاَءِ خَيْرٌ كَثِيرٌ ‏"‏ ‏.‏ قَالَ فَالْتَفَتَ فَرَأَى رَجُلاً يَمْشِي بَيْنَ الْمَقَابِرِ فِي نَعْلَيْهِ فَقَالَ ‏"‏ يَا صَاحِبَ السِّبْتِيَّتَيْنِ أَلْقِهِمَا ‏"‏ ‏.‏ حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ قَالَ كَانَ عَبْدُ اللَّهِ بْنُ عُثْمَانَ يَقُولُ حَدِيثٌ جَيِّدٌ وَرَجُلٌ ثِقَةٌ ‏.‏\hadithno{1568}\hadithgrade{Al-Albani: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Bashir bin Khasasiyyah said:“While I was walking with the Messenger of Allah (ﷺ) he said: ‘O son of Khasasiyyah, why are you angry with Allah when you are walking with the Messenger of Allah?’ I said: ‘O Messenger of Allah! I am not angry with Allah at all. Allah has bestowed all good on me.’ Then he passed by the graves of the Muslims and said: ‘They have caught up with a great deal of good.’ Then he passed by the graves of the idolaters and said: ‘They died before a great deal of good came to them.’ Then he turned and saw a man walking between the graves in his shoes and he said: ‘O you with the shoes, take them off.’” Muhammad bin Bashar narrated from Abdur-Rahman bin Mahdi that he said: Abdullah bin Uthman used to say (about this hadith): "A good hadith and a reliable narrator}}
\hadithdefcmd{ibnmajah}{1569}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، عَنْ يَزِيدَ بْنِ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ زُورُوا الْقُبُورَ فَإِنَّهَا تُذَكِّرُكُمُ الآخِرَةَ ‏"‏ ‏.‏\hadithno{1569}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Visit the graves, for they will remind you of the Hereafter.”}}
\hadithdefcmd{ibnmajah}{1570}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا بِسْطَامُ بْنُ مُسْلِمٍ، قَالَ سَمِعْتُ أَبَا التَّيَّاحِ، قَالَ سَمِعْتُ ابْنَ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ رَخَّصَ فِي زِيَارَةِ الْقُبُورِ ‏.‏\hadithno{1570}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) gave permission for visiting the graves}}
\hadithdefcmd{ibnmajah}{1571}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَنْبَأَنَا ابْنُ جُرَيْجٍ، عَنْ أَيُّوبَ بْنِ هَانِئٍ، عَنْ مَسْرُوقِ بْنِ الأَجْدَعِ، عَنِ ابْنِ مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كُنْتُ نَهَيْتُكُمْ عَنْ زِيَارَةِ الْقُبُورِ فَزُورُوا الْقُبُورَ فَإِنَّهَا تُزَهِّدُ فِي الدُّنْيَا وَتُذَكِّرُ الآخِرَةَ ‏"‏ ‏.‏\hadithno{1571}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn Mas’ud that the Messenger of Allah (ﷺ) said, “I used to forbid you to visit the graves, but now visit them, for they will draw your attention away from this world and remind you of the Hereafter.”}}
\hadithdefcmd{ibnmajah}{1572}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا يَزِيدُ بْنُ كَيْسَانَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ زَارَ النَّبِيُّ ـ صلى الله عليه وسلم ـ قَبْرَ أُمِّهِ فَبَكَى وَأَبْكَى مَنْ حَوْلَهُ فَقَالَ: ‏ "‏ اسْتَأْذَنْتُ رَبِّي فِي أَنْ أَسْتَغْفِرَ لَهَا فَلَمْ يَأْذَنْ لِي وَاسْتَأْذَنْتُ رَبِّي فِي أَنْ أَزُورَ قَبْرَهَا فَأَذِنَ لِي فَزُورُوا الْقُبُورَ فَإِنَّهَا تُذَكِّرُكُمُ الْمَوْتَ ‏"‏ ‏.‏\hadithno{1572}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“The Prophet (ﷺ) visited the grave of his mother and wept, causing the people around him to weep. Then he said: ‘I asked my Lord for permission to seek forgiveness for her, but He did not give me permission. Then I asked my Lord for permission to visit her grave and He gave me permission. So visit the graves, for they will remind you of death.’”}}
\hadithdefcmd{ibnmajah}{1573}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ الْبَخْتَرِيِّ الْوَاسِطِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ إِبْرَاهِيمَ بْنِ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أَبِي كَانَ يَصِلُ الرَّحِمَ وَكَانَ وَكَانَ. فَأَيْنَ هُوَ قَالَ ‏"‏ فِي النَّارِ ‏"‏ ‏.‏ قَالَ فَكَأَنَّهُ وَجَدَ مِنْ ذَلِكَ فَقَالَ يَا رَسُولَ اللَّهِ فَأَيْنَ أَبُوكَ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ حَيْثُمَا مَرَرْتَ بِقَبْرِ كَافِرٍ فَبَشِّرْهُ بِالنَّارِ ‏"‏ ‏.‏ قَالَ فَأَسْلَمَ الأَعْرَابِيُّ بَعْدُ وَقَالَ لَقَدْ كَلَّفَنِي رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ تَعَبًا مَا مَرَرْتُ بِقَبْرِ كَافِرٍ إِلاَّ بَشَّرْتُهُ بِالنَّارِ ‏.‏\hadithno{1573}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Salim that his father said:“A Bedouin came to the Prophet (ﷺ) and said: ‘O Messenger of Allah, my father used to uphold the ties of kinship, and so and so forth, where is he?’ He said: ‘In the Fire.’ It was as if he found that difficult to bear. Then he said: ‘O Messenger of Allah. Where is your father?’ The Messenger of Allah (ﷺ) said: ‘Whenever you pass by the grave of an idolater, give him the tidings of Hell-fire.’ The Bedouin later became Muslim, and he said: ‘The Messenger of Allah (ﷺ) gave me a difficult task. I never passed the grave of an idolater but I gave him the tidings of Hell-fire.’”}}
\hadithdefcmd{ibnmajah}{1574}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو بِشْرٍ قَالاَ حَدَّثَنَا قَبِيصَةُ، ح: وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عُبَيْدُ بْنُ سَعِيدٍ، ح: وَحَدَّثَنَا مُحَمَّدُ بْنُ خَلَفٍ الْعَسْقَلاَنِيُّ، حَدَّثَنَا الْفِرْيَابِيُّ، وَقَبِيصَةُ، كُلُّهُمْ عَنْ سُفْيَانَ، عَنْ عَبْدِ اللَّهِ بْنِ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ بَهْمَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ حَسَّانَ بْنِ ثَابِتٍ، عَنْ أَبِيهِ، قَالَ: لَعَنَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ زُوَّارَاتِ الْقُبُورِ ‏.‏\hadithno{1574}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from ‘Abdur-Rahman bin Hassan bin Thabit that his father said:“The Messenger of Allah (ﷺ) cursed women who visit graves.”}}
\hadithdefcmd{ibnmajah}{1575}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا مُحَمَّدُ بْنُ جُحَادَةَ، عَنْ أَبِي صَالِحٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ: لَعَنَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ زُوَّارَاتِ الْقُبُورِ ‏.‏\hadithno{1575}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Messenger of Allah (ﷺ) cursed women who visit graves.”}}
\hadithdefcmd{ibnmajah}{1576}{حَدَّثَنَا مُحَمَّدُ بْنُ خَلَفٍ الْعَسْقَلاَنِيُّ أَبُو نَصْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ طَالِبٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ: لَعَنَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ زُوَّارَاتِ الْقُبُورِ ‏.‏\hadithno{1576}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) cursed women who visit graves.”}}
\hadithdefcmd{ibnmajah}{1577}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ: نُهِينَا عَنِ اتِّبَاعِ الْجَنَائِزِ، وَلَمْ يُعْزَمْ عَلَيْنَا ‏.‏\hadithno{1577}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Umm ‘Atiyyah said:“We were prevented from following the funeral, but that was not made binding on us.”}}
\hadithdefcmd{ibnmajah}{1578}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُصَفَّى الْحِمْصِيُّ، حَدَّثَنَا أَحْمَدُ بْنُ خَالِدٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ إِسْمَاعِيلَ بْنِ سَلْمَانَ، عَنْ دِينَارٍ أَبِي عُمَرَ، عَنِ ابْنِ الْحَنَفِيَّةِ، عَنْ عَلِيٍّ، قَالَ خَرَجَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَإِذَا نِسْوَةٌ جُلُوسٌ فَقَالَ ‏"‏ مَا يُجْلِسُكُنَّ ‏"‏ ‏.‏ قُلْنَ نَنْتَظِرُ الْجِنَازَةَ ‏.‏ قَالَ ‏"‏ هَلْ تَغْسِلْنَ ‏"‏ ‏.‏ قُلْنَ لاَ ‏.‏ قَالَ ‏"‏ هَلْ تَحْمِلْنَ ‏"‏ ‏.‏ قُلْنَ لاَ ‏.‏ قَالَ ‏"‏ هَلْ تُدْلِينَ فِيمَنْ يُدْلِي ‏"‏ ‏.‏ قُلْنَ لاَ ‏.‏ قَالَ ‏"‏ فَارْجِعْنَ مَأْزُورَاتٍ غَيْرَ مَأْجُورَاتٍ ‏"‏ ‏.‏\hadithno{1578}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali said:“The Messenger of Allah (ﷺ) went out and saw some women sitting, and he said: ‘What are you sitting here for?’ They said: ‘We are waiting for the funeral.’ He said: ‘Are you going to wash the deceased?’ They said: ‘No.’ He said: ‘Are you going to lower him into the grave?’ They said: ‘No.’ He said: ‘Then go back with a burden of sin and not rewarded.’”}}
\hadithdefcmd{ibnmajah}{1579}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ، مَوْلَى الصَّهْبَاءِ عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أُمِّ سَلَمَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ ‏\{وَلاَ يَعْصِينَكَ فِي مَعْرُوفٍ\}‏ قَالَ: ‏"‏ النَّوْحُ ‏"‏ ‏.‏\hadithno{1579}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Umm Salamah from the Prophet (ﷺ) regarding:“And that they will not disobey you in Ma’ruf (all that is good in Islam);” he said: “(It is about) wailing.”}}
\hadithdefcmd{ibnmajah}{1580}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دِينَارٍ، حَدَّثَنَا حَرِيزٌ، مَوْلَى مُعَاوِيَةَ قَالَ خَطَبَ مُعَاوِيَةُ بِحِمْصَ فَذَكَرَ فِي خُطْبَتِهِ أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ نَهَى عَنِ النَّوْحِ ‏.‏\hadithno{1580}\hadithgrade{Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{Jarir, the freed slave of Mu’awiyah, said:“Mu’awiyah delivered a sermon in Hims, and in his sermon he mentioned that the Messenger of Allah (ﷺ) forbade wailing.”}}
\hadithdefcmd{ibnmajah}{1581}{حَدَّثَنَا الْعَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ الْعَنْبَرِيُّ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا مَعْمَرٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنِ ابْنِ مُعَانِقٍ، عَنْ أَبِي مَالِكٍ الأَشْعَرِيِّ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ النِّيَاحَةُ مِنْ أَمْرِ الْجَاهِلِيَّةِ وَإِنَّ النَّائِحَةَ إِذَا مَاتَتْ وَلَمْ تَتُبْ قَطَعَ اللَّهُ لَهَا ثِيَابًا مِنْ قَطِرَانٍ وَدِرْعًا مِنْ لَهَبِ النَّارِ ‏"‏ ‏.‏\hadithno{1581}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Malik Ash’ari that the Messenger of Allah (ﷺ) said:‘Wailing is one of the affairs of the Days of Ignorance, and if the woman who wails dies without having repented, Allah will cut a garment of pitch (tar) for her and a shirt of flaming fire.’”}}
\hadithdefcmd{ibnmajah}{1582}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا عُمَرُ بْنُ رَاشِدٍ الْيَمَامِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ النِّيَاحَةُ عَلَى الْمَيِّتِ مِنْ أَمْرِ الْجَاهِلِيَّةِ فَإِنَّ النَّائِحَةَ إِنْ لَمْ تَتُبْ قَبْلَ أَنْ تَمُوتَ فَإِنَّهَا تُبْعَثُ يَوْمَ الْقِيَامَةِ عَلَيْهَا سَرَابِيلُ مِنْ قَطِرَانٍ ثُمَّ يُعْلَى عَلَيْهَا بِدُرُوعٍ مِنْ لَهَبِ النَّارِ ‏"‏ ‏.‏\hadithno{1582}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:“Wailing over the dead is one of the affairs of the Days of Ignorance and if the woman who wails does not repent before she dies, she will be resurrected on the Day of Resurrection wearing a shirt of pitch (tar), over which she will wear a shirt of flaming fire.”}}
\hadithdefcmd{ibnmajah}{1583}{حَدَّثَنَا أَحْمَدُ بْنُ يُوسُفَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، أَنْبَأَنَا إِسْرَائِيلُ، عَنْ أَبِي يَحْيَى، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عُمَرَ، قَالَ: نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ أَنْ تُتْبَعَ جِنَازَةٌ مَعَهَا رَانَّةٌ ‏.‏\hadithno{1583}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) forbade following a funeral that was accompanied by a wailing woman.”}}
\hadithdefcmd{ibnmajah}{1584}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَعَبْدُ الرَّحْمَنِ، جَمِيعًا عَنْ سُفْيَانَ، عَنْ زُبَيْدٍ، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، ح وَحَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ قَالاَ: حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَيْسَ مِنَّا مَنْ شَقَّ الْجُيُوبَ وَضَرَبَ الْخُدُودَ وَدَعَا بِدَعْوَى الْجَاهِلِيَّةِ ‏"‏ ‏.‏\hadithno{1584}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from ‘Abdullah that the Messenger of Allah (ﷺ) said:“He is not one of us who tears his garments, strikes his cheeks, and cries with the cry of the Days of Ignorance.’”}}
\hadithdefcmd{ibnmajah}{1585}{حَدَّثَنَا مُحَمَّدُ بْنُ جَابِرٍ الْمُحَارِبِيُّ، وَمُحَمَّدُ بْنُ كَرَامَةَ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ، عَنْ مَكْحُولٍ، وَالْقَاسِمِ، عَنْ أَبِي أُمَامَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ لَعَنَ الْخَامِشَةَ وَجْهَهَا وَالشَّاقَّةَ جَيْبَهَا وَالدَّاعِيَةَ بِالْوَيْلِ وَالثُّبُورِ ‏.‏\hadithno{1585}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Abu Umamah that the Messenger of Allah (ﷺ) cursed the woman who scratches her face and rends her garment and cries that she is doomed (i.e. because of the death of this person)}}
\hadithdefcmd{ibnmajah}{1586}{حَدَّثَنَا أَحْمَدُ بْنُ عُثْمَانَ بْنِ حَكِيمٍ الأَوْدِيُّ، حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، عَنْ أَبِي الْعُمَيْسِ، قَالَ سَمِعْتُ أَبَا صَخْرَةَ، يَذْكُرُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، وَأَبِي، بُرْدَةَ قَالاَ: لَمَّا ثَقُلَ أَبُو مُوسَى أَقْبَلَتِ امْرَأَتُهُ أُمُّ عَبْدِ اللَّهِ تَصِيحُ بِرَنَّةٍ فَأَفَاقَ فَقَالَ لَهَا: أَوَ مَا عَلِمْتِ أَنِّي بَرِيءٌ مِمَّنْ بَرِئَ مِنْهُ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَكَانَ يُحَدِّثُهَا أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ قَالَ: ‏ "‏ أَنَا بَرِيءٌ مِمَّنْ حَلَقَ وَسَلَقَ وَخَرَقَ ‏"‏ ‏.‏\hadithno{1586}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{‘Abdur-Rahman bin Yazid and Abu Burdah said:“When Abu Musa fell sick, his wife Umm ‘Abdullah started to wail loudly. He woke up and said to her: ‘Do you not know that I am innocent of those whom the Messenger of Allah (ﷺ) declared innocence of?’ And he told her that the Messenger of Allah (ﷺ) said: ‘I am innocent of those who shave their heads, raise their voices and tear their garments (at times of calamity).’”}}
\hadithdefcmd{ibnmajah}{1587}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ كَانَ فِي جِنَازَةٍ فَرَأَى عُمَرُ امْرَأَةً فَصَاحَ بِهَا فَقَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ دَعْهَا يَا عُمَرُ فَإِنَّ الْعَيْنَ دَامِعَةٌ وَالنَّفْسَ مُصَابَةٌ وَالْعَهْدَ قَرِيبٌ ‏"‏ ‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ عَطَاءٍ، عَنْ سَلَمَةَ بْنِ الأَزْرَقِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ بِنَحْوِهِ ‏.‏\hadithno{1587}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) was attending a funeral. ‘Umar saw a woman and shouted at her, but the Prophet (ﷺ) said, “Leave her alone, O ‘Umar, for the eye weeps and the heart is afflicted, and the bereavement is recent.”}}
\hadithdefcmd{ibnmajah}{1588}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا عَاصِمٌ الأَحْوَلُ، عَنْ أَبِي عُثْمَانَ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ كَانَ ابْنٌ لِبَعْضِ بَنَاتِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ يَقْضِي فَأَرْسَلَتْ إِلَيْهِ أَنْ يَأْتِيَهَا فَأَرْسَلَ إِلَيْهَا أَنَّ ‏"‏ لِلَّهِ مَا أَخَذَ وَلَهُ مَا أَعْطَى وَكُلُّ شَىْءٍ عِنْدَهُ إِلَى أَجَلٍ مُسَمًّى فَلْتَصْبِرْ وَلْتَحْتَسِبْ ‏"‏ ‏.‏ فَأَرْسَلَتْ إِلَيْهِ فَأَقْسَمَتْ عَلَيْهِ فَقَامَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَقُمْتُ مَعَهُ وَمَعَهُ مُعَاذُ بْنُ جَبَلٍ وَأُبَىُّ بْنُ كَعْبٍ وَعُبَادَةُ بْنُ الصَّامِتِ فَلَمَّا دَخَلْنَا نَاوَلُوا الصَّبِيَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَرُوحُهُ تَقَلْقَلُ فِي صَدْرِهِ ‏.‏ قَالَ حَسِبْتُهُ قَالَ كَأَنَّهُ شَنَّةٌ ‏.‏ قَالَ فَبَكَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ لَهُ عُبَادَةُ بْنُ الصَّامِتِ: مَا هَذَا يَا رَسُولَ اللَّهِ؟ قَالَ: ‏"‏ الرَّحْمَةُ الَّتِي جَعَلَهَا اللَّهُ فِي بَنِي آدَمَ وَإِنَّمَا يَرْحَمُ اللَّهُ مِنْ عِبَادِهِ الرُّحَمَاءَ ‏"‏ ‏.‏\hadithno{1588}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Usamah bin Zaid said:“The son of one of the daughters of the Messenger of Allah (ﷺ) was dying. She sent for him, asking him to come to her, and he sent word to her, saying: ‘To Allah belongs what He has taken and to Him belongs what He has given. Everything has an appointed time with Him, so be patient and seek reward.’ But she sent for him again, adjuring him to come. So the Messenger of Allah (ﷺ) got up, and I got up with him, as did Mu’adh bin Jabal, Ubayy bin Ka’b and ‘Ubadah bin Samit. When we entered they handed the child to the Messenger of Allah (ﷺ), and his soul was rattling in his chest.” I think he was that it was like a water skin. “The Messenger of Allah (ﷺ) wept, and ‘Ubadah bin Samit said to him: ‘What is this, O Messenger of Allah?’ He said: ‘It is compassion which Allah has created in the son of Adam. Allah only shows mercy to those of His slaves who are compassionate.’”}}
\hadithdefcmd{ibnmajah}{1589}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، عَنِ ابْنِ خُثَيْمٍ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَسْمَاءَ بِنْتِ يَزِيدَ، قَالَتْ لَمَّا تُوُفِّيَ ابْنُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِبْرَاهِيمُ بَكَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ لَهُ الْمُعَزِّي - إِمَّا أَبُو بَكْرٍ وَإِمَّا عُمَرُ - أَنْتَ أَحَقُّ مَنْ عَظَّمَ اللَّهَ حَقَّهُ ‏.‏ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ تَدْمَعُ الْعَيْنُ وَيَحْزَنُ الْقَلْبُ وَلاَ نَقُولُ مَا يُسْخِطُ الرَّبَّ لَوْلاَ أَنَّهُ وَعْدٌ صَادِقٌ وَمَوْعُودٌ جَامِعٌ وَأَنَّ الآخِرَ تَابِعٌ لِلأَوَّلِ لَوَجَدْنَا عَلَيْكَ يَا إِبْرَاهِيمُ أَفْضَلَ مِمَّا وَجَدْنَا وَإِنَّا بِكَ لَمَحْزُونُونَ ‏"‏ ‏.‏\hadithno{1589}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Asma’ bint Yazid said:“When Ibrahim, the son of the Messenger of Allah (ﷺ), died, the Messenger of Allah (ﷺ) wept. The one who was consoling him, either Abu Bakr or ‘Umar, said to him: ‘You are indeed the best of those who glorify Allah with what is due to him.’ The Messenger of Allah (ﷺ) said: ‘The eye weeps and the heart grieves, but we do not say anything that angers the Lord. Were it not that death is something that inevitably comes to all, and that the latter will surely join the former, then we would have been more than we are, verily we grieve for you.’”}}
\hadithdefcmd{ibnmajah}{1590}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا إِسْحَاقُ بْنُ مُحَمَّدٍ الْفَرْوِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ، عَنْ إِبْرَاهِيمَ بْنِ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ بْنِ جَحْشٍ، عَنْ أَبِيهِ، عَنْ حَمْنَةَ بِنْتِ جَحْشٍ، أَنَّهُ قِيلَ لَهَا قُتِلَ أَخُوكِ ‏.‏ فَقَالَتْ رَحِمَهُ اللَّهُ وَإِنَّا لِلَّهِ وَإِنَّا إِلَيْهِ رَاجِعُونَ ‏.‏ قَالُوا قُتِلَ زَوْجُكِ ‏.‏ قَالَتْ وَاحُزْنَاهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ لِلزَّوْجِ مِنَ الْمَرْأَةِ لَشُعْبَةً مَا هِيَ لِشَىْءٍ ‏"‏ ‏.‏\hadithno{1590}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Hamnah bint Jahsh that it was said to her:“Your brother has been killed.” She said: “May Allah have mercy on him. Inna lillahi wa inna ilayhi raji’un (Truly, to Allah we belong and truly, to Him we shall return).” They said: “Your husband has been killed.” She said: “O grief!” The Messenger of Allah (ﷺ) said: “The woman has a strong love for her husband, which she does not have for anything else.”}}
\hadithdefcmd{ibnmajah}{1591}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَنْبَأَنَا أُسَامَةُ بْنُ زَيْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ مَرَّ بِنِسَاءِ عَبْدِ الأَشْهَلِ يَبْكِينَ هَلْكَاهُنَّ يَوْمَ أُحُدٍ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ لَكِنَّ حَمْزَةَ لاَ بَوَاكِيَ لَهُ ‏"‏ ‏.‏ فَجَاءَ نِسَاءُ الأَنْصَارِ يَبْكِينَ حَمْزَةَ فَاسْتَيْقَظَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ ‏"‏ وَيْحَهُنَّ مَا انْقَلَبْنَ بَعْدُ؟ مُرُوهُنَّ فَلْيَنْقَلِبْنَ وَلاَ يَبْكِينَ عَلَى هَالِكٍ بَعْدَ الْيَوْمِ ‏"‏ ‏.‏\hadithno{1591}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) passed by some women of ‘Abdul-Ashhal who were weeping for their slain on the Day of Uhud. The Messenger of Allah (ﷺ) said:“But there is no one to weep for Hamzah.” So the women of Ansar started to weep for Hamzah. The Messenger of Allah (ﷺ) woke up and said, ‘Woe to them, have they not gone home yet? Tell them to go home and not to weep for anyone who dies after this day.’”}}
\hadithdefcmd{ibnmajah}{1592}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ، عَنْ إِبْرَاهِيمَ الْهَجَرِيِّ، عَنِ ابْنِ أَبِي أَوْفَى، قَالَ نَهَى رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ عَنِ الْمَرَاثِي ‏.‏\hadithno{1592}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn Abi Awfa said:“The Messenger of Allah (ﷺ) forbade eulogies.”}}
\hadithdefcmd{ibnmajah}{1593}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا شَاذَانُ، ح: وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ الْوَلِيدِ، قَالاَ: حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح: وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الصَّمَدِ، وَوَهْبُ بْنُ جَرِيرٍ، قَالُوا: حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنِ ابْنِ عُمَرَ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ: ‏ "‏ الْمَيِّتُ يُعَذَّبُ بِمَا نِيحَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{1593}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from ‘Umar bin Khattab that the Prophet (ﷺ) said:“The deceased is punished for the wailing over him.”}}
\hadithdefcmd{ibnmajah}{1594}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، حَدَّثَنَا أَسِيدُ بْنُ أَبِي أَسِيدٍ، عَنْ مُوسَى بْنِ أَبِي مُوسَى الأَشْعَرِيِّ، عَنْ أَبِيهِ، ‏.‏ أَنَّ النَّبِيَّ ـ صلى الله عليه وسلم ـ قَالَ ‏"‏ الْمَيِّتُ يُعَذَّبُ بِبُكَاءِ الْحَىِّ إِذَا قَالُوا وَاعَضُدَاهْ وَاكَاسِيَاهْ ‏.‏ وَانَاصِرَاهْ وَاجَبَلاَهْ وَنَحْوَ هَذَا - يُتَعْتَعُ وَيُقَالُ أَنْتَ كَذَلِكَ أَنْتَ كَذَلِكَ ‏"‏ ‏.‏ قَالَ أَسِيدٌ فَقُلْتُ سُبْحَانَ اللَّهِ إِنَّ اللَّهَ يَقُولُ ‏\{وَلاَ تَزِرُ وَازِرَةٌ وِزْرَ أُخْرَى \}‏ ‏.‏ قَالَ وَيْحَكَ أُحَدِّثُكَ أَنَّ أَبَا مُوسَى حَدَّثَنِي عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَتَرَى أَنَّ أَبَا مُوسَى كَذَبَ عَلَى النَّبِيِّ ـ صلى الله عليه وسلم ـ أَوْ تَرَى أَنِّي كَذَبْتُ عَلَى أَبِي مُوسَى؟\hadithno{1594}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Asid bin Abu Asid, from Musa bin Abu Musa Ash’ari, from his father that the Prophet (ﷺ) said:“The deceased is punished for the weeping of the living. If they say: ‘O my strength, O he who clothed us, O my help, O my rock,’ and so on, he is rebuked and it is said: ‘Were you really like that? Were you really like that?’” Asid said: "I said: 'Subhan-Allah! Allah says: "And no bearer of burdens shall another's burden (35:18)." He said: "Woe to you, I tell you that Abu Musa narrated to me from the Messenger of Allah (ﷺ), and you think that Abu Musa was telling lies about the Prophet (ﷺ)? Or do you think that I am telling lies about Abu Musa?}}
\hadithdefcmd{ibnmajah}{1595}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ إِنَّمَا كَانَتْ يَهُودِيَّةٌ مَاتَتْ. فَسَمِعَهُمُ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَبْكُونَ عَلَيْهَا قَالَ: ‏ "‏ فَإِنَّ أَهْلَهَا يَبْكُونَ عَلَيْهَا وَإِنَّهَا تُعَذَّبُ فِي قَبْرِهَا ‏"‏ ‏.‏\hadithno{1595}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Aishah said:“A Jewish woman had died, and the Prophet (ﷺ) heard the weeping for her. He said: ‘Her family is weeping for her, and she is being punished in her grave.’”}}
\hadithdefcmd{ibnmajah}{1596}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ سَعْدِ بْنِ سِنَانٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّمَا الصَّبْرُ عِنْدَ الصَّدْمَةِ الأُولَى ‏"‏ ‏.‏\hadithno{1596}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:"Patience should come with the first shock}}
\hadithdefcmd{ibnmajah}{1597}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنَا ثَابِتُ بْنُ عَجْلاَنَ، عَنِ الْقَاسِمِ، عَنْ أَبِي أُمَامَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ: ‏ "‏ يَقُولُ اللَّهُ سُبْحَانَهُ: ابْنَ آدَمَ إِنْ صَبَرْتَ وَاحْتَسَبْتَ عِنْدَ الصَّدْمَةِ الأُولَى لَمْ أَرْضَ لَكَ ثَوَابًا دُونَ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{1597}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Umamah that the Prophet (ﷺ) said:“Allah says: ‘O son of Adam! If you are patient and seek reward at the moment of first shock, I will not approve of any reward for you less than Paradise.’”}}
\hadithdefcmd{ibnmajah}{1598}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا عَبْدُ الْمَلِكِ بْنُ قُدَامَةَ الْجُمَحِيُّ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ أَبَا سَلَمَةَ، حَدَّثَهَا أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ: ‏ "‏ مَا مِنْ مُسْلِمٍ يُصَابُ بِمُصِيبَةٍ فَيَفْزَعُ إِلَى مَا أَمَرَ اللَّهُ بِهِ مِنْ قَوْلِهِ: إِنَّا لِلَّهِ وَإِنَّا إِلَيْهِ رَاجِعُونَ اللَّهُمَّ عِنْدَكَ احْتَسَبْتُ مُصِيبَتِي فَأْجُرْنِي فِيهَا وَعُضْنِي مِنْهَا - إِلاَّ آجَرَهُ اللَّهُ عَلَيْهَا وَعَاضَهُ خَيْرًا مِنْهَا ‏"‏ ‏.‏ قَالَتْ: فَلَمَّا تُوُفِّيَ أَبُو سَلَمَةَ ذَكَرْتُ الَّذِي حَدَّثَنِي عَنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقُلْتُ: إِنَّا لِلَّهِ وَإِنَّا إِلَيْهِ رَاجِعُونَ اللَّهُمَّ عِنْدَكَ احْتَسَبْتُ مُصِيبَتِي هَذِهِ فَأْجُرْنِي عَلَيْهَا ‏.‏ فَإِذَا أَرَدْتُ أَنْ أَقُولَ وَعُضْنِي خَيْرًا مِنْهَا قُلْتُ فِي نَفْسِي: أُعَاضُ خَيْرًا مِنْ أَبِي سَلَمَةَ ؟ ثُمَّ قُلْتُهَا فَعَاضَنِي اللَّهُ مُحَمَّدًا ـ صلى الله عليه وسلم ـ ‏.‏ وَآجَرَنِي فِي مُصِيبَتِي ‏.‏\hadithno{1598}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Umm Salamah that Abu Salamah told her that he heard the Messenger of Allah (ﷺ) say:“There is no Muslim who is stricken with a calamity and reacts by saying as Allah has commanded: ‘Inna lillahi, wa inna ilayhi raji’un. Allahumma indaka ahtasabtu musibati, fajurni fiha, wa ‘awwidni minha (Truly, to Allah we belong and truly, to Him we shall return. O Allah, with You I seek reward for my calamity, so reward me for it and compensate me),’ but Allah will reward him for that and compensate him with something better than it.” She said: “When Abu Salamah died, I remembered what he had told me from the Messenger of Allah (ﷺ) and I said: ‘Inna lillahi, wa inna ilayhi raji’un. Allahumma indaka ahtasabtu musibati, fajurni alaiha (Truly, to Allah we belong and truly, to Him we shall return. O Allah, with You I seek reward for my calamity, so reward me for it).’ But when I wanted to say wa ‘awwidni minha (and compensate me with better), I said to myself: ‘How can I be compensated with something better than Abu Salamah?’ Then I said it, and Allah compensated me with Muhammad (ﷺ) and rewarded me for my calamity.”}}
\hadithdefcmd{ibnmajah}{1599}{حَدَّثَنَا الْوَلِيدُ بْنُ عَمْرِو بْنِ السُّكَيْنِ، حَدَّثَنَا أَبُو هَمَّامٍ، حَدَّثَنَا مُوسَى بْنُ عُبَيْدَةَ، حَدَّثَنَا مُصْعَبُ بْنُ مُحَمَّدٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ فَتَحَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بَابًا بَيْنَهُ وَبَيْنَ النَّاسِ أَوْ كَشَفَ سِتْرًا فَإِذَا النَّاسُ يُصَلُّونَ وَرَاءَ أَبِي بَكْرٍ فَحَمِدَ اللَّهَ عَلَى مَا رَأَى مِنْ حُسْنِ حَالِهِمْ رَجَاءَ أَنْ يَخْلُفَهُ اللَّهُ فِيهِمْ بِالَّذِي رَآهُمْ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ أَيُّمَا أَحَدٍ مِنَ النَّاسِ أَوْ مِنَ الْمُؤْمِنِينَ أُصِيبَ بِمُصِيبَةٍ فَلْيَتَعَزَّ بِمُصِيبَتِهِ بِي عَنِ الْمُصِيبَةِ الَّتِي تُصِيبُهُ بِغَيْرِي فَإِنَّ أَحَدًا مِنْ أُمَّتِي لَنْ يُصَابَ بِمُصِيبَةٍ بَعْدِي أَشَدَّ عَلَيْهِ مِنْ مُصِيبَتِي ‏"‏ ‏.‏\hadithno{1599}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“The Messenger of Allah (ﷺ) opened a door that was between him and the people or drew back a curtain and he saw the people praying behind Abu Bakr. He praised Allah for what he saw of their good situation and hoped that Allah succeed him by what he saw in them.* He said: ‘O people, whoever among the people or among the believers is stricken with a calamity, then let him console himself with the loss of me, for no one among my nation will be stricken with any calamity worse than my loss.’”}}
\hadithdefcmd{ibnmajah}{1600}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، عَنْ هِشَامِ بْنِ زِيَادٍ، عَنْ أُمِّهِ، عَنْ فَاطِمَةَ بِنْتِ الْحُسَيْنِ، عَنْ أَبِيهَا، قَالَ قَالَ النَّبِيُّ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ أُصِيبَ بِمُصِيبَةٍ فَذَكَرَ مُصِيبَتَهُ فَأَحْدَثَ اسْتِرْجَاعًا - وَإِنْ تَقَادَمَ عَهْدُهَا - كَتَبَ اللَّهُ لَهُ مِنَ الأَجْرِ مِثْلَهُ يَوْمَ أُصِيبَ ‏"‏ ‏.‏\hadithno{1600}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Fatimah bint Husain that her father said:The Prophet (ﷺ) said: “Whoever was stricken with a calamity and when he remembers it he says ‘Inna lillahi, wa inna ilayhi raji’un (Truly, to Allah we belong and truly, to Him we shall return),’ even though it happened a long time ago, Allah will record for him a reward like that of the day it befell him.”}}
\hadithdefcmd{ibnmajah}{1601}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنِي قَيْسٌ أَبُو عُمَارَةَ، مَوْلَى الأَنْصَارِ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهُ قَالَ ‏ "‏ مَا مِنْ مُؤْمِنٍ يُعَزِّي أَخَاهُ بِمُصِيبَةٍ إِلاَّ كَسَاهُ اللَّهُ سُبْحَانَهُ مِنْ حُلَلِ الْكَرَامَةِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{1601}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Qais, Abu ‘Umarah, the freed slave of the Ansar, said:“I heard ‘Abdullah bin Abu Bakr bin Muhammad bin ‘Amr bin Hazm narrating from his father, from his grandfather, that the Prophet (ﷺ) said: ‘There is no believer who consoles for his brother for a calamity, but Allah will clothe him with garments of honor on the Day of Resurrection.’”}}
\hadithdefcmd{ibnmajah}{1602}{حَدَّثَنَا عَمْرُو بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَلِيُّ بْنُ عَاصِمٍ، عَنْ مُحَمَّدِ بْنِ سُوقَةَ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ عَزَّى مُصَابًا فَلَهُ مِثْلُ أَجْرِهِ ‏"‏ ‏.‏\hadithno{1602}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah said:“The Messenger of Allah (ﷺ) said: ‘Whoever consoles a person stricken by calamity will have a reward equal to his.’”}}
\hadithdefcmd{ibnmajah}{1603}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ لاَ يَمُوتُ لِرَجُلٍ ثَلاَثَةٌ مِنَ الْوَلَدِ فَيَلِجَ النَّارَ إِلاَّ تَحِلَّةَ الْقَسَمِ ‏"‏ ‏.‏\hadithno{1603}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“No man who loses three of his children will ever enter the Fire, except in fulfillment of the oath (of Allah).”}}
\hadithdefcmd{ibnmajah}{1604}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، قَالَ حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ، حَدَّثَنَا حَرِيزُ بْنُ عُثْمَانَ، عَنْ شُرَحْبِيلَ بْنِ شُفْعَةَ، قَالَ لَقِيَنِي عُتْبَةُ بْنُ عَبْدٍ السُّلَمِيُّ فَقَالَ: سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ: ‏ "‏ مَا مِنْ مُسْلِمٍ يَمُوتُ لَهُ ثَلاَثَةٌ مِنَ الْوَلَدِ لَمْ يَبْلُغُوا الْحِنْثَ إِلاَّ تَلَقَّوْهُ مِنْ أَبْوَابِ الْجَنَّةِ الثَّمَانِيَةِ مِنْ أَيِّهَا شَاءَ دَخَلَ ‏"‏ ‏.‏\hadithno{1604}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{‘Utbah bin ‘Abd Sulami said:“I heard the Messenger of Allah (ﷺ) say: ‘There is no Muslim, three of whose children die before reaching the age of puberty, but they will meet him at the eight gates of Paradise and whichever one he wants he will enter through it.’”}}
\hadithdefcmd{ibnmajah}{1605}{حَدَّثَنَا يُوسُفُ بْنُ حَمَّادٍ الْمَعْنِيُّ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ مَا مِنْ مُسْلِمَيْنِ يُتَوَفَّى لَهُمَا ثَلاَثَةٌ مِنَ الْوَلَدِ لَمْ يَبْلُغُوا الْحِنْثَ إِلاَّ أَدْخَلَهُمُ اللَّهُ الْجَنَّةَ بِفَضْلِ رَحْمَةِ اللَّهِ إِيَّاهُمْ ‏"‏ ‏.‏\hadithno{1605}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas bin Malik that the Prophet (ﷺ) said:“There are no two Muslims (mother and father), three of whose children die before reaching the age of puberty, but Allah will admit them to Paradise by virtue of His mercy towards them.”}}
\hadithdefcmd{ibnmajah}{1606}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا إِسْحَاقُ بْنُ يُوسُفَ، عَنِ الْعَوَّامِ بْنِ حَوْشَبٍ، عَنْ أَبِي مُحَمَّدٍ، مَوْلَى عُمَرَ بْنِ الْخَطَّابِ عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ مَنْ قَدَّمَ ثَلاَثَةً مِنَ الْوَلَدِ لَمْ يَبْلُغُوا الْحِنْثَ كَانُوا لَهُ حِصْنًا حَصِينًا مِنَ النَّارِ ‏"‏ ‏.‏ فَقَالَ أَبُو ذَرٍّ: قَدَّمْتُ اثْنَيْنِ ‏.‏ قَالَ: ‏"‏ وَاثْنَيْنِ ‏"‏ ‏.‏ فَقَالَ أُبَىُّ بْنُ كَعْبٍ أَبُو الْمُنْذِرِ سَيِّدُ الْقُرَّاءِ: قَدَّمْتُ وَاحِدًا ‏.‏ قَالَ" ‏"‏ وَوَاحِدًا ‏"‏ ‏.‏\hadithno{1606}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Abdullah that the Messenger of Allah (ﷺ) said:“Whoever sends fourth three of his children who had not reached the age of puberty, they will be a strong fortification for him against the Fire.” Abu Dharr said: “I sent forth two.” He said: “And two” Ubayy bin Ka’b, the chief of the reciters, said: “I sent forth one.” He said: “Even one.”}}
\hadithdefcmd{ibnmajah}{1607}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا يَزِيدُ بْنُ عَبْدِ الْمَلِكِ النَّوْفَلِيُّ، عَنْ يَزِيدَ بْنِ رُومَانَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لَسِقْطٌ أُقَدِّمُهُ بَيْنَ يَدَىَّ أَحَبُّ إِلَىَّ مِنْ فَارِسٍ أُخَلِّفُهُ خَلْفِي ‏"‏ ‏.‏\hadithno{1607}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:‘A miscarried fetus sent before me is dearer to me than a horseman whom I leave behind.”}}
\hadithdefcmd{ibnmajah}{1608}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ إِسْحَاقَ أَبُو بَكْرٍ الْبَكَّائِيُّ، قَالاَ حَدَّثَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنَا مِنْدَلٌ، عَنِ الْحَسَنِ بْنِ الْحَكَمِ النَّخَعِيِّ، عَنْ أَسْمَاءَ بِنْتِ عَابِسِ بْنِ رَبِيعَةَ، عَنْ أَبِيهَا، عَنْ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ إِنَّ السِّقْطَ لَيُرَاغِمُ رَبَّهُ إِذَا أَدْخَلَ أَبَوَيْهِ النَّارَ ‏.‏ فَيُقَالُ أَيُّهَا السِّقْطُ الْمُرَاغِمُ رَبَّهُ أَدْخِلْ أَبَوَيْكَ الْجَنَّةَ ‏.‏ فَيَجُرُّهُمَا بِسَرَرِهِ حَتَّى يُدْخِلَهُمَا الْجَنَّةَ ‏"‏ ‏.‏\hadithno{1608}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali said:“The Messenger of Allah (ﷺ) said: ‘The miscarried fetus will plead with his Lord if his parents are admitted to Hell. It will be said: “O fetus who pleads with your Lord! Admit your parents to Paradise.” So he will drag them out with his umbilical cord until he admits them to Paradise.’”}}
\hadithdefcmd{ibnmajah}{1609}{حَدَّثَنَا عَلِيُّ بْنُ هَاشِمِ بْنِ مَرْزُوقٍ، حَدَّثَنَا عَبِيدَةُ بْنُ حُمَيْدٍ، حَدَّثَنَا يَحْيَى بْنُ عُبَيْدِ اللَّهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ مُسْلِمٍ الْحَضْرَمِيِّ، عَنْ مُعَاذِ بْنِ جَبَلٍ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّ السِّقْطَ لَيَجُرُّ أُمَّهُ بِسَرَرِهِ إِلَى الْجَنَّةِ إِذَا احْتَسَبَتْهُ ‏"‏ ‏.‏\hadithno{1609}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Mu’adh bin Jabal that the Prophet (ﷺ) said:“By the One in Whose Hand is my soul! The miscarried fetus will drag his mother by his umbilical cord to Paradise, if she (was patient and) sought reward (for her loss).”}}
\hadithdefcmd{ibnmajah}{1610}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ جَعْفَرِ بْنِ خَالِدٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ جَعْفَرٍ، قَالَ لَمَّا جَاءَ نَعْىُ جَعْفَرٍ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ اصْنَعُوا لآلِ جَعْفَرٍ طَعَامًا. فَقَدْ أَتَاهُمْ مَا يَشْغَلُهُمْ أَوْ أَمْرٌ يَشْغَلُهُمْ ‏"‏ ‏.‏\hadithno{1610}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Abdullah bin Ja’far said:“When news of the death of Ja’far was brought, the Messenger of Allah (ﷺ) said: ‘Prepare food for the family of Ja’far, for there has come to them that which is keeping them busy or something which is keeping them busy.”}}
\hadithdefcmd{ibnmajah}{1611}{حَدَّثَنَا يَحْيَى بْنُ خَلَفٍ أَبُو سَلَمَةَ، قَالَ حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ أَبِي بَكْرٍ، عَنْ أُمِّ عِيسَى الْجَزَّارِ، قَالَتْ حَدَّثَتْنِي أُمُّ عَوْنٍ ابْنَةُ مُحَمَّدِ بْنِ جَعْفَرٍ، عَنْ جَدَّتِهَا، أَسْمَاءَ بِنْتِ عُمَيْسٍ قَالَتْ لَمَّا أُصِيبَ جَعْفَرٌ رَجَعَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ إِلَى أَهْلِهِ فَقَالَ ‏ "‏ إِنَّ آلَ جَعْفَرٍ قَدْ شُغِلُوا بِشَأْنِ مَيِّتِهِمْ فَاصْنَعُوا لَهُمْ طَعَامًا ‏"‏ ‏.‏ قَالَ عَبْدُ اللَّهِ فَمَا زَالَتْ سُنَّةً حَتَّى كَانَ حَدِيثًا فَتُرِكَ ‏.‏\hadithno{1611}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Asma’ bint ‘Umais said:“When Ja’far was killed, the Messenger of Allah (ﷺ) went to his family and said: ‘The family of Ja’far are busy with the matter of their deceased, so prepare food for them.’” (One of the narrators) Abdullah said: "That continued to be the Sunnah, until innovations were introduced, then it was abandoned}}
\hadithdefcmd{ibnmajah}{1612}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا هُشَيْمٌ، ح وَحَدَّثَنَا شُجَاعُ بْنُ مَخْلَدٍ أَبُو الْفَضْلِ، قَالَ حَدَّثَنَا هُشَيْمٌ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ الْبَجَلِيِّ، قَالَ كُنَّا نَرَى الاِجْتِمَاعَ إِلَى أَهْلِ الْمَيِّتِ وَصَنْعَةَ الطَّعَامِ مِنَ النِّيَاحَةِ ‏.‏\hadithno{1612}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Jarir bin ‘Abdullah Al-Bajali said:“We used to think that gathering with the family of the deceased and preparing food was a form of wailing.”}}
\hadithdefcmd{ibnmajah}{1613}{حَدَّثَنَا جَمِيلُ بْنُ الْحَسَنِ، قَالَ حَدَّثَنَا أَبُو الْمُنْذِرِ الْهُذَيْلُ بْنُ الْحَكَمِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي رَوَّادٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَوْتُ غُرْبَةٍ شَهَادَةٌ ‏"‏ ‏.‏\hadithno{1613}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) said:Dying in a strange land is martyrdom.”}}
\hadithdefcmd{ibnmajah}{1614}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي حُيَىُّ بْنُ عَبْدِ اللَّهِ الْمَعَافِرِيُّ، عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ تُوُفِّيَ رَجُلٌ بِالْمَدِينَةِ مِمَّنْ وُلِدَ بِالْمَدِينَةِ فَصَلَّى عَلَيْهِ النَّبِيُّ ـ صلى الله عليه وسلم ـ فَقَالَ: ‏"‏ يَا لَيْتَهُ مَاتَ فِي غَيْرِ مَوْلِدِهِ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ النَّاسِ وَلِمَ يَا رَسُولَ اللَّهِ؟ قَالَ: ‏"‏ إِنَّ الرَّجُلَ إِذَا مَاتَ فِي غَيْرِ مَوْلِدِهِ قِيسَ لَهُ مِنْ مَوْلِدِهِ إِلَى مُنْقَطَعِ أَثَرِهِ فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{1614}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Abdullah bin ‘Amr said:“A man died in Al- Madinah, and he was one of those who were born in Al-Madinah. The Prophet (ﷺ) offered the funeral prayer for him and said: “Would that he had died somewhere other than his birthplace.” A man among the people said: “Why, O Messenger of Allah?” He said: “If a man dies somewhere other than his birthplace, a space will be measured for him in Paradise (as big as the distance) from the place where he was born to the place where he died.”}}
\hadithdefcmd{ibnmajah}{1615}{حَدَّثَنَا أَحْمَدُ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَنْبَأَنَا ابْنُ جُرَيْجٍ، ح وَحَدَّثَنَا أَبُو عُبَيْدَةَ بْنُ أَبِي السَّفَرِ، قَالَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي إِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ أَبِي عَطَاءٍ، عَنْ مُوسَى بْنِ وَرْدَانَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ مَنْ مَاتَ مَرِيضًا مَاتَ شَهِيدًا وَوُقِيَ فِتْنَةَ الْقَبْرِ وَغُدِيَ وَرِيحَ عَلَيْهِ بِرِزْقِهِ مِنَ الْجَنَّةِ ‏"‏ ‏.‏\hadithno{1615}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever dies from a sickness dies as a martyr. He is protected from the torment of the grave and he is granted provision from Paradise morning and evening.”}}
\hadithdefcmd{ibnmajah}{1616}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ الدَّرَاوَرْدِيُّ، قَالَ حَدَّثَنَا سَعْدُ بْنُ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ: قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ كَسْرُ عَظْمِ الْمَيِّتِ كَكَسْرِهِ حَيًّا ‏"‏ ‏.‏\hadithno{1616}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) said:“Breaking the bones of the deceased is like breaking his bones when he is alive.”}}
\hadithdefcmd{ibnmajah}{1617}{حَدَّثَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ زِيَادٍ، أَخْبَرَنِي أَبُو عُبَيْدَةَ بْنُ عَبْدِ اللَّهِ بْنِ زَمْعَةَ، عَنْ أُمِّهِ، عَنْ أُمِّ سَلَمَةَ، عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ قَالَ ‏ "‏ كَسْرُ عَظْمِ الْمَيِّتِ كَكَسْرِ عَظْمِ الْحَىِّ فِي الإِثْمِ ‏"‏ ‏.‏\hadithno{1617}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif}\hadithtrans{It was narrated from Umm Salamah that the Prophet (ﷺ) said:“Breaking the bones of the deceased is, in sin, like breaking his bones when he is alive.”}}
\hadithdefcmd{ibnmajah}{1618}{حَدَّثَنَا سَهْلُ بْنُ أَبِي سَهْلٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، قَالَ: سَأَلْتُ عَائِشَةَ فَقُلْتُ: أَىْ أُمَّهْ أَخْبِرِينِي عَنْ مَرَضِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَتِ: اشْتَكَى فَعَلَقَ يَنْفُثُ فَجَعَلْنَا نُشَبِّهُ نَفْثَهُ بِنَفْثَةِ آكِلِ الزَّبِيبِ وَكَانَ يَدُورُ عَلَى نِسَائِهِ فَلَمَّا ثَقُلَ اسْتَأْذَنَهُنَّ أَنْ يَكُونَ فِي بَيْتِ عَائِشَةَ وَأَنْ يَدُرْنَ عَلَيْهِ ‏.‏ قَالَتْ: فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ بَيْنَ رَجُلَيْنِ وَرِجْلاَهُ تَخُطَّانِ بِالأَرْضِ أَحَدُهُمَا الْعَبَّاسُ فَحَدَّثْتُ بِهِ ابْنَ عَبَّاسٍ فَقَالَ: أَتَدْرِي مَنِ الرَّجُلُ الَّذِي لَمْ تُسَمِّهِ عَائِشَةُ؟ هُوَ عَلِيُّ بْنُ أَبِي طَالِبٍ ‏.‏\hadithno{1618}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Ubaidullah bin ‘Abdullah said:“I asked ‘Aishah: ‘O mother! Tell me about the sickness of the Messenger of Allah (ﷺ).’ She said: ‘He felt pain and started to spit (over his body), and we began to compare his spittle to the spittle of a person eating raisins. Like a person eating raisins and spitting out the seeds. He used to go around among his wives, but when he became ill, he asked them permission to stay in the house of ‘Aishah and that they should come to him in turns.’ She said: ‘The Messenger of Allah (ﷺ) entered upon me, (supported) between two men, with his feet making lines along the ground. One of them was ‘Abbas.’ I told Ibn ‘Abbas this Hadith and he said: ‘Do you know who the other man was whom ‘Aishah did not name? He was ‘Ali bin Abu Talib.’”}}
\hadithdefcmd{ibnmajah}{1619}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ: كَانَ النَّبِيُّ ـ صلى الله عليه وسلم ـ يَتَعَوَّذُ بِهَؤُلاَءِ الْكَلِمَاتِ ‏"‏ أَذْهِبِ الْبَاسَ رَبَّ النَّاسِ ‏.‏ وَاشْفِ أَنْتَ الشَّافِي لاَ شِفَاءَ إِلاَّ شِفَاؤُكَ شِفَاءً لاَ يُغَادِرُ سَقَمًا ‏"‏ ‏.‏ فَلَمَّا ثَقُلَ النَّبِيُّ ـ صلى الله عليه وسلم ـ فِي مَرَضِهِ الَّذِي مَاتَ فِيهِ أَخَذْتُ بِيَدِهِ فَجَعَلْتُ أَمْسَحُهُ وَأَقُولُهَا ‏.‏ فَنَزَعَ يَدَهُ مِنْ يَدِي ثُمَّ قَالَ: ‏"‏ اللَّهُمَّ اغْفِرْ لِي وَأَلْحِقْنِي بِالرَّفِيقِ الأَعْلَى ‏"‏ ‏.‏ قَالَتْ: فَكَانَ هَذَا آخِرَ مَا سَمِعْتُ مِنْ كَلاَمِهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1619}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The Prophet (ﷺ) used to seek refuge using the following words: ‘Adhhibil-ba’s, Rabbin-nas, washfi Antash-shafi, la shifa’a illa shifa’uka, shifa’an la yughadiru saqaman (Take away the affliction, O Lord of mankind, and grant healing, for You are the Healer and there is no healing that leaves no sickness).’ When the Prophet (ﷺ) fell sick with the sickness that would be his last, I took his hand and wiped it over his body and recited these words. He withdrew his hand from mine and said: ‘O Allah, forgive me and let me meet the exalted companions (i.e., those who occupy high positions in Paradise).’ Those were the last words of his that I heard.”}}
\hadithdefcmd{ibnmajah}{1620}{حَدَّثَنَا أَبُو مَرْوَانَ الْعُثْمَانِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏"‏ مَا مِنْ نَبِيٍّ يَمْرَضُ إِلاَّ خُيِّرَ بَيْنَ الدُّنْيَا وَالآخِرَةِ ‏"‏ ‏.‏ قَالَتْ فَلَمَّا كَانَ مَرَضُهُ الَّذِي قُبِضَ فِيهِ أَخَذَتْهُ بُحَّةٌ فَسَمِعْتُهُ يَقُولُ ‏"‏ مَعَ الَّذِينَ أَنْعَمَ اللَّهُ عَلَيْهِمْ مِنَ النَّبِيِّينَ وَالصِّدِّيقِينَ وَالشُّهَدَاءِ وَالصَّالِحِينَ ‏"‏ ‏.‏ فَعَلِمْتُ أَنَّهُ خُيِّرَ ‏.‏\hadithno{1620}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“I heard the Messenger of Allah (ﷺ) say: ‘There is no Prophet who fell sick but he was given the choice between this world and the Hereafter.’ She said: ‘When he became sick with the illness that would be his last, (his voice) became hoarse and I heard him say, “In the company of those on whom Allah has bestowed His grace, of the Prophets, the true believers, the martyrs, and the righteous.’” [4:69] Then I knew that he had been given the choice.”}}
\hadithdefcmd{ibnmajah}{1621}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ زَكَرِيَّا، عَنْ فِرَاسٍ، عَنْ عَامِرٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتِ اجْتَمَعْنَ نِسَاءُ النَّبِيِّ ـ صلى الله عليه وسلم ـ فَلَمْ تُغَادِرْ مِنْهُنَّ امْرَأَةٌ فَجَاءَتْ فَاطِمَةُ كَأَنَّ مِشْيَتَهَا مِشْيَةُ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ فَقَالَ: ‏"‏ مَرْحَبًا بِابْنَتِي ‏"‏ ‏.‏ ثُمَّ أَجْلَسَهَا عَنْ شِمَالِهِ ثُمَّ إِنَّهُ أَسَرَّ إِلَيْهَا حَدِيثًا فَبَكَتْ فَاطِمَةُ. ثُمَّ إِنَّهُ سَارَّهَا. فَضَحِكَتْ أَيْضًا فَقُلْتُ لَهَا: مَا يُبْكِيكِ؟ قَالَتْ: مَا كُنْتُ لأُفْشِيَ سِرَّ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ فَقُلْتُ: مَا رَأَيْتُ كَالْيَوْمِ فَرَحًا أَقْرَبَ مِنْ حُزْنٍ ‏.‏ فَقُلْتُ لَهَا حِينَ بَكَتْ: أَخَصَّكِ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ بِحَدِيثٍ دُونَنَا ثُمَّ تَبْكِينَ؟ وَسَأَلْتُهَا عَمَّا قَالَ ‏.‏ فَقَالَتْ: مَا كُنْتُ لأُفْشِيَ سِرَّ رَسُولِ اللَّهِ -صلى الله عليه وسلم - ‏.‏ حَتَّى إِذَا قُبِضَ سَأَلْتُهَا عَمَّا قَالَ. فَقَالَتْ: إِنَّهُ كَانَ يُحَدِّثُنِي أَنَّ جِبْرَائِيلَ كَانَ يُعَارِضُهُ بِالْقُرْآنِ فِي كُلِّ عَامٍ مَرَّةً وَأَنَّهُ عَارَضَهُ بِهِ الْعَامَ مَرَّتَيْنِ ‏"‏ وَلاَ أُرَانِي إِلاَّ قَدْ حَضَرَ أَجَلِي وَأَنَّكِ أَوَّلُ أَهْلِي لُحُوقًا بِي وَنِعْمَ السَّلَفُ أَنَا لَكِ ‏"‏ ‏.‏ فَبَكَيْتُ ثُمَّ إِنَّهُ سَارَّنِي فَقَالَ: ‏"‏ أَلاَ تَرْضَيْنَ أَنْ تَكُونِي سَيِّدَةَ نِسَاءِ الْمُؤْمِنِينَ - أَوْ نِسَاءِ هَذِهِ الأُمَّةِ - ‏"‏ ‏.‏ فَضَحِكْتُ لِذَلِكَ ‏.‏\hadithno{1621}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that ‘Aishah said:“The wives of the Prophet (ﷺ) gathered together and not one of them lagged behind. Fatimah came, and her gait was like that of the Messenger of Allah (ﷺ). He said, ‘Welcome to my daughter.’ Then he made her sit to his left, and he whispered something to her, and she smiled. I said to her: ‘What made you weep?’ She said: ‘I will not disclose the secret of the Messenger of Allah (ﷺ).’ I said: ‘I never saw joy so close to grief as I saw today.’ When she wept I said: ‘Did the Messenger of Allah (ﷺ) tell you some special words that were not for us, then you wept?’ And I asked her about what he had said. She said: ‘I will not disclose the secret of the Messenger of Allah (ﷺ).’ After he died I asked her what he had said, and she said: ‘He told me that Jibra’il used to review the Qur’an with him once each year, but he had reviewed it with him twice that year, (and he said:) “I do not think but that my time is near. You will be the first of my family to join me, and what a good predecessor I am for you.” So I wept. Then he whispered to me and said: “Will you not be pleased to be the leader of the women of this Ummah?” So I smiled.’”}}
\hadithdefcmd{ibnmajah}{1622}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُصْعَبُ بْنُ الْمِقْدَامِ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، قَالَ: قَالَتْ عَائِشَةُ: مَا رَأَيْتُ أَحَدًا أَشَدَّ عَلَيْهِ الْوَجَعُ مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1622}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{‘Aishah said:“I never saw anyone suffer more pain than the Messenger of Allah (ﷺ).”}}
\hadithdefcmd{ibnmajah}{1623}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا لَيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مُوسَى بْنِ سَرْجِسَ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ رَأَيْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ وَهُوَ يَمُوتُ وَعِنْدَهُ قَدَحٌ فِيهِ مَاءٌ فَيُدْخِلُ يَدَهُ فِي الْقَدَحِ ثُمَّ يَمْسَحُ وَجْهَهُ بِالْمَاءِ ثُمَّ يَقُولُ: ‏ "‏ اللَّهُمَّ أَعِنِّي عَلَى سَكَرَاتِ الْمَوْتِ ‏"‏ ‏.‏\hadithno{1623}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Aishah said:“I saw the Messenger of Allah (ﷺ) when he was dying, and there was a bowl of water next to him. He put his hand in the vessel and wiped his face with the water, and said: ‘O Allah, help me to bear the agonies of death.’”}}
\hadithdefcmd{ibnmajah}{1624}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ آخِرُ نَظْرَةٍ نَظَرْتُهَا إِلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ كَشْفُ السِّتَارَةِ يَوْمَ الاِثْنَيْنِ فَنَظَرْتُ إِلَى وَجْهِهِ كَأَنَّهُ وَرَقَةُ مُصْحَفٍ وَالنَّاسُ خَلْفَ أَبِي بَكْرٍ فِي الصَّلاَةِ فَأَرَادَ أَنْ يَتَحَرَّكَ فَأَشَارَ إِلَيْهِ أَنِ اثْبُتْ وَأَلْقَى السِّجْفَ وَمَاتَ مِنْ آخِرِ ذَلِكَ الْيَوْمِ ‏.‏\hadithno{1624}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Zuhri heard Anas bin Malik say:“The last glance that I had of the Messenger of Allah (ﷺ) was when he drew back the curtain on Monday, and I saw his face as if it was a page of the Mushaf (Qur’an), and the people were praying behind Abu Bakr. He (Abu Bakr) wanted to move, but he (the Prophet (ﷺ)) gestured to him to stand firm. Then he let the curtain fall, and he died at the end of that day.”}}
\hadithdefcmd{ibnmajah}{1625}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ صَالِحٍ أَبِي الْخَلِيلِ، عَنْ سَفِينَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ كَانَ يَقُولُ فِي مَرَضِهِ الَّذِي تُوُفِّيَ فِيهِ ‏ "‏ الصَّلاَةَ وَمَا مَلَكَتْ أَيْمَانُكُمْ ‏"‏ ‏.‏ فَمَا زَالَ يَقُولُهَا حَتَّى مَا يَفِيضَ بِهَا لِسَانُهُ ‏.‏\hadithno{1625}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Umm Salamah that the Messenger of Allah (ﷺ) used to say, during the illness that would be his last:“The prayer, and those whom your hands possess.”* And he kept on saying it until his tongue could no longer utter any words}}
\hadithdefcmd{ibnmajah}{1626}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنِ ابْنِ عَوْنٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، قَالَ: ذَكَرُوا عِنْدَ عَائِشَةَ أَنَّ عَلِيًّا كَانَ وَصِيًّا ‏.‏ فَقَالَتْ: مَتَى أَوْصَى إِلَيْهِ؟ فَلَقَدْ كُنْتُ مُسْنِدَتَهُ إِلَى صَدْرِي - أَوْ إِلَى حِجْرِي فَدَعَا بِطَسْتٍ فَلَقَدِ انْخَنَثَ فِي حِجْرِي فَمَاتَ وَمَا شَعَرْتُ بِهِ. فَمَتَى أَوْصَى ـ صلى الله عليه وسلم ـ؟ ‏\hadithno{1626}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{It was narrated that Aswad said:“They said in ‘Aishah’s presence that ‘Ali was appointed (by the Prophet (ﷺ) before he died), and she said: ‘When was he appointed? He (the Prophet (ﷺ)) was resting against my bosom, or in my lap, and he called for a basin, then he became limp in my lap and died, and I did not realize it. So when did he (ﷺ) appoint him?’”}}
\hadithdefcmd{ibnmajah}{1627}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا قُبِضَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَأَبُو بَكْرٍ عِنْدَ امْرَأَتِهِ ابْنَةِ خَارِجَةَ بِالْعَوَالِي فَجَعَلُوا يَقُولُونَ لَمْ يَمُتِ النَّبِيُّ ـ صلى الله عليه وسلم ـ إِنَّمَا هُوَ بَعْضُ مَا كَانَ يَأْخُذُهُ عِنْدَ الْوَحْىِ ‏.‏ فَجَاءَ أَبُو بَكْرٍ فَكَشَفَ عَنْ وَجْهِهِ وَقَبَّلَ بَيْنَ عَيْنَيْهِ وَقَالَ أَنْتَ أَكْرَمُ عَلَى اللَّهِ مِنْ أَنْ يُمِيتَكَ مَرَّتَيْنِ قَدْ وَاللَّهِ مَاتَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ وَعُمَرُ فِي نَاحِيَةِ الْمَسْجِدِ يَقُولُ وَاللَّهِ مَا مَاتَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَلاَ يَمُوتُ حَتَّى يَقْطَعَ أَيْدِيَ أُنَاسٍ مِنَ الْمُنَافِقِينَ كَثِيرٍ وَأَرْجُلَهُمْ ‏.‏ فَقَامَ أَبُو بَكْرٍ فَصَعِدَ الْمِنْبَرَ فَقَالَ مَنْ كَانَ يَعْبُدُ اللَّهَ فَإِنَّ اللَّهَ حَىٌّ لَمْ يَمُتْ وَمَنْ كَانَ يَعْبُدُ مُحَمَّدًا فَإِنَّ مُحَمَّدًا قَدْ مَاتَ ‏\{وَمَا مُحَمَّدٌ إِلاَّ رَسُولٌ قَدْ خَلَتْ مِنْ قَبْلِهِ الرُّسُلُ أَفَإِنْ مَاتَ أَوْ قُتِلَ انْقَلَبْتُمْ عَلَى أَعْقَابِكُمْ وَمَنْ يَنْقَلِبْ عَلَى عَقِبَيْهِ فَلَنْ يَضُرَّ اللَّهَ شَيْئًا وَسَيَجْزِي اللَّهُ الشَّاكِرِينَ\}‏ ‏.‏ قَالَ عُمَرُ فَلَكَأَنِّي لَمْ أَقْرَأْهَا إِلاَّ يَوْمَئِذٍ ‏.‏\hadithno{1627}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Aishah said:“When the Messenger of Allah (ﷺ) passed away, Abu Bakr was with his wife, the daughter of Kharijah, in villages surrounding Al-Madinah. They started to say: ‘The Prophet (ﷺ) has not died, rather he has been overcome with what used to overcome him at the time of Revelation.’ Then Abu Bakr came and uncovered his (the Prophet’s (ﷺ)) face, kissed him between the eyes and said: ‘You are too noble before Allah for Him to cause you to die twice. By Allah, the Messenger of Allah (ﷺ) has indeed died.’ ‘Umar was in a corner of the mosque saying: ‘By Allah, the Messenger of Allah (ﷺ) has not died and he will never die until the hands and feet of most of the hypocrites are cut off.’ Then Abu Bakr stood up, ascended the pulpit and said: ‘Whoever used to worship Allah, Allah is alive and will never die. Whoever used to worship Muhammad, Muhammad is dead. “Muhammad is no more than a Messenger, and indeed (many) Messengers have passed away before him. If he dies or is killed, will you then turn back on your heels (as disbelievers)? And he who turns back on his heels, not the least harm will he do to Allah; and Allah will give reward to those who are grateful.’” [3:144] ‘Umar said: ‘It was as if I had never read (that Verse) before that day.’”}}
\hadithdefcmd{ibnmajah}{1628}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، أَنْبَأَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي حُسَيْنُ بْنُ عَبْدِ اللَّهِ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا أَرَادُوا أَنْ يَحْفِرُوا، لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ بَعَثُوا إِلَى أَبِي عُبَيْدَةَ بْنِ الْجَرَّاحِ وَكَانَ يَضْرَحُ كَضَرِيحِ أَهْلِ مَكَّةَ وَبَعَثُوا إِلَى أَبِي طَلْحَةَ وَكَانَ هُوَ الَّذِي يَحْفِرُ لأَهْلِ الْمَدِينَةِ وَكَانَ يَلْحَدُ فَبَعَثُوا إِلَيْهِمَا رَسُولَيْنِ وَقَالُوا اللَّهُمَّ خِرْ لِرَسُولِكَ ‏.‏ فَوَجَدُوا أَبَا طَلْحَةَ فَجِيءَ بِهِ وَلَمْ يُوجَدْ أَبُو عُبَيْدَةَ فَلَحَدَ لِرَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ فَلَمَّا فَرَغُوا مِنْ جِهَازِهِ يَوْمَ الثُّلاَثَاءِ وُضِعَ عَلَى سَرِيرِهِ فِي بَيْتِهِ ‏.‏ ثُمَّ دَخَلَ النَّاسُ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَرْسَالاً ‏.‏ يُصَلُّونَ عَلَيْهِ حَتَّى إِذَا فَرَغُوا أَدْخَلُوا النِّسَاءَ حَتَّى إِذَا فَرَغُوا أَدْخَلُوا الصِّبْيَانَ وَلَمْ يَؤُمَّ النَّاسَ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ أَحَدٌ ‏.‏ لَقَدِ اخْتَلَفَ الْمُسْلِمُونَ فِي الْمَكَانِ الَّذِي يُحْفَرُ لَهُ فَقَالَ قَائِلُونَ يُدْفَنُ فِي مَسْجِدِهِ ‏.‏ وَقَالَ قَائِلُونَ يُدْفَنُ مَعَ أَصْحَابِهِ ‏.‏ فَقَالَ أَبُو بَكْرٍ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ ـ صلى الله عليه وسلم ـ يَقُولُ ‏ "‏ مَا قُبِضَ نَبِيٌّ إِلاَّ دُفِنَ حَيْثُ يُقْبَضُ ‏"‏ ‏.‏ قَالَ فَرَفَعُوا فِرَاشَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ الَّذِي تُوُفِّيَ عَلَيْهِ فَحَفَرُوا لَهُ ثُمَّ دُفِنَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَسْطَ اللَّيْلِ مِنْ لَيْلَةِ الأَرْبِعَاءِ ‏.‏ وَنَزَلَ فِي حُفْرَتِهِ عَلِيُّ بْنُ أَبِي طَالِبٍ وَالْفَضْلُ وَقُثَمُ ابْنَا الْعَبَّاسِ وَشُقْرَانُ مَوْلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ وَقَالَ أَوْسُ بْنُ خَوْلِيٍّ وَهُوَ أَبُو لَيْلَى لِعَلِيِّ بْنِ أَبِي طَالِبٍ أَنْشُدُكَ اللَّهَ وَحَظَّنَا مِنْ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ قَالَ لَهُ عَلِيٌّ انْزِلْ ‏.‏ وَكَانَ شُقْرَانُ مَوْلاَهُ أَخَذَ قَطِيفَةً كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَلْبَسُهَا فَدَفَنَهَا فِي الْقَبْرِ وَقَالَ وَاللَّهِ لاَ يَلْبَسُهَا أَحَدٌ بَعْدَكَ أَبَدًا ‏.‏ فَدُفِنَتْ مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏\hadithno{1628}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ibn ‘Abbas said:“When they wanted to dig a grave for the Messenger of Allah (ﷺ), they sent for Abu ‘Ubaidah bin Jarrah, who used to dig graves in the manner of the people of Makkah, and they sent for Abu Talhah, who used to dig graves for the people of Al-Madinah, and he used to make a niche in the grave. They sent two messengers to both of them, and they said: ‘O Allah, choose what is best for Your Messenger.’ They found Abu Talhah and brought him, but they did not find Abu ‘Ubaidah. So he dug a grave with a niche for the Messenger of Allah (ﷺ). When they had finished preparing him, on Tuesday, he was placed on his bed in his house. Then the people entered upon the Messenger of Allah (ﷺ) in groups and offered the funeral prayer for him, and when they finished the women entered, and when they finished the children entered, and no one led the people in offering the funeral prayer for the Messenger of Allah (ﷺ). The Muslims differed concerning the place where he should be buried. Some said that he should be buried in his mosque. Others said that he should be buried with his Companions. Then Abu Bakr said: ‘I heard the Messenger of Allah (ﷺ) say: “No Prophet ever passed away but he was buried where he died.” So they lifted up the bed of the Messenger of Allah (ﷺ) on which he had died, and dug the grave for him, then he (ﷺ) was buried in the middle of Tuesday night. ‘Ali bin Abu Talib, Fadl bin ‘Abbas and his brother Qutham, and Shuqran the freed slave of the Messenger of Allah (ﷺ) went down in his grave. Aws bin Khawli, who was Abu Laila, said to ‘Ali bin Abi Talib: ‘I adjure you by Allah! Give us our share of the Messenger of Allah (ﷺ).’ So ‘Ali said to him: ‘Come down.’ Shuqran, his freed slave, had taken a Qatifah which the Messenger of Allah (ﷺ) used to wear. He buried it in his grave and said, ‘By Allah, no one will ever wear it after you.’ So it was buried with the Messenger of Allah (ﷺ).”}}
\hadithdefcmd{ibnmajah}{1629}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الزُّبَيْرِ أَبُو الزُّبَيْرِ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا وَجَدَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ مِنْ كَرْبِ الْمَوْتِ مَا وَجَدَ قَالَتْ فَاطِمَةُ وَاكَرْبَ أَبَتَاهْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏ "‏ لاَ كَرْبَ عَلَى أَبِيكِ بَعْدَ الْيَوْمِ إِنَّهُ قَدْ حَضَرَ مِنْ أَبِيكِ مَا لَيْسَ بِتَارِكٍ مِنْهُ أَحَدًا الْمُوَافَاةُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{1629}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Anas bin Malik said:“When the Messenger of Allah (ﷺ) suffered the agonies of death that he suffered, Fatimah said: ‘O my father, what a severe agony!’ The Messenger of Allah (ﷺ) said: ‘Your father will suffer no more agony after this day. There has come to your father that which no one can avoid, the death that everyone will encounter until the Day of Resurrection.’”}}
\hadithdefcmd{ibnmajah}{1630}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنِي حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنِي ثَابِتٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَتْ لِي فَاطِمَةُ يَا أَنَسُ كَيْفَ سَخَتْ أَنْفُسُكُمْ أَنْ تَحْثُوا التُّرَابَ عَلَى رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ ‏.‏ وَحَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ فَاطِمَةَ، قَالَتْ حِينَ قُبِضَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ وَا أَبَتَاهْ إِلَى جِبْرَائِيلَ أَنْعَاهْ وَا أَبَتَاهْ مِنْ رَبِّهِ مَا أَدْنَاهْ وَا أَبَتَاهْ جَنَّةُ الْفِرْدَوْسِ مَأْوَاهْ وَا أَبَتَاهْ أَجَابَ رَبًّا دَعَاهْ ‏.‏ قَالَ حَمَّادٌ فَرَأَيْتُ ثَابِتًا حِينَ حَدَّثَ بِهَذَا الْحَدِيثِ بَكَى حَتَّى رَأَيْتُ أَضْلاَعَهُ تَخْتَلِفُ ‏.‏\hadithno{1630}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas bin Malik said:“Fatimah said to me: ‘O Anas, how did you manage to scatter dust on the Messenger of Allah (ﷺ)?’” And Thabit narrated to us from Anas that Fatimah said: “When the Messenger of Allah (ﷺ) passed away: ‘O my father! To Jibra’il we announce his death; O my father, how much closer he is now to his Lord; O my father, the Paradise of Firdaws is his abode; O my father, he has answered the call of his Lord.” (One of the narrators) Hammad said: "I saw Thabit, when he narrated this Hadith, weeping until I could see his ribs moving up and down}}
\hadithdefcmd{ibnmajah}{1631}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الصَّوَّافُ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ الضُّبَعِيُّ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، قَالَ لَمَّا كَانَ الْيَوْمُ الَّذِي دَخَلَ فِيهِ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ الْمَدِينَةَ أَضَاءَ مِنْهَا كُلُّ شَىْءٍ فَلَمَّا كَانَ الْيَوْمُ الَّذِي مَاتَ فِيهِ أَظْلَمَ مِنْهَا كُلُّ شَىْءٍ ‏.‏ وَمَا نَفَضْنَا عَنِ النَّبِيِّ ـ صلى الله عليه وسلم ـ الأَيْدِيَ حَتَّى أَنْكَرْنَا قُلُوبَنَا ‏.‏\hadithno{1631}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Anas said:“On the day when the Messenger of Allah (ﷺ) entered Al-Madinah, everything was lit up, and on the day when he died, everything went dark, and no sooner had we dusted off our hands (after burying him) but we felt that our hearts had changed.”}}
\hadithdefcmd{ibnmajah}{1632}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ كُنَّا نَتَّقِي الْكَلاَمَ وَالاِنْبِسَاطَ إِلَى نِسَائِنَا عَلَى عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ مَخَافَةَ أَنْ يُنْزَلَ فِينَا الْقُرْآنُ فَلَمَّا مَاتَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ تَكَلَّمْنَا ‏.‏\hadithno{1632}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn ‘Umar said:“We used to be guarded in our speech even with our wives at the time of the Messenger of Allah (ﷺ), fearing that Qur’an may be revealed amongst us, but when the Messenger of Allah (ﷺ) died, we began to speak freely.”}}
\hadithdefcmd{ibnmajah}{1633}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَنْبَأَنَا عَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ الْعِجْلِيُّ، عَنِ ابْنِ عَوْنٍ، عَنِ الْحَسَنِ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ وَإِنَّمَا وَجْهُنَا وَاحِدٌ فَلَمَّا قُبِضَ نَظَرْنَا هَكَذَا وَهَكَذَا ‏.‏\hadithno{1633}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ubayy bin Ka’b said:“We were with the Messenger of Allah (ﷺ) and we all had a single focus, but when he passed away we started to look here and there (i.e., have different interests).”}}
\hadithdefcmd{ibnmajah}{1634}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحِزَامِيُّ، حَدَّثَنَا خَالِي، مُحَمَّدُ بْنُ إِبْرَاهِيمَ بْنِ الْمُطَّلِبِ بْنِ السَّائِبِ بْنِ أَبِي وَدَاعَةَ السَّهْمِيُّ حَدَّثَنِي مُوسَى بْنُ عَبْدِ اللَّهِ بْنِ أَبِي أُمَيَّةَ الْمَخْزُومِيُّ، حَدَّثَنِي مُصْعَبُ بْنُ عَبْدِ اللَّهِ، عَنْ أُمِّ سَلَمَةَ بِنْتِ أَبِي أُمَيَّةَ، زَوْجِ النَّبِيِّ ـ صلى الله عليه وسلم ـ أَنَّهَا قَالَتْ كَانَ النَّاسُ فِي عَهْدِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ إِذَا قَامَ الْمُصَلِّي يُصَلِّي لَمْ يَعْدُ بَصَرُ أَحَدِهِمْ مَوْضِعَ قَدَمَيْهِ فَتُوُفِّيَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ فَكَانَ النَّاسُ إِذَا قَامَ أَحَدُهُمْ يُصَلِّي لَمْ يَعْدُ بَصَرُ أَحَدِهِمْ مَوْضِعَ جَبِينِهِ فَتُوُفِّيَ أَبُو بَكْرٍ وَكَانَ عُمَرُ فَكَانَ النَّاسُ إِذَا قَامَ أَحَدُهُمْ يُصَلِّي لَمْ يَعْدُ بَصَرُ أَحَدِهِمْ مَوْضِعَ الْقِبْلَةِ وَكَانَ عُثْمَانُ بْنُ عَفَّانَ فَكَانَتِ الْفِتْنَةُ فَتَلَفَّتَ النَّاسُ يَمِينًا وَشِمَالاً ‏.‏\hadithno{1634}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Umm Salamah bint Abi Umayyah, the wife of the Prophet (ﷺ), said:“At the time of the Messenger of Allah (ﷺ), if a person stood to pray, his gaze would not go beyond his feet. When the Messenger of Allah (ﷺ) died, if a person stood to pray, his gaze would not go beyond the place where he put his forehead when prostrating. Then Abu Bakr died and it was ‘Umar (the caliph). So, when any person stood to pray his gaze would not go beyond the Qiblah. Then came the time of ‘Uthman bin ‘Affan, and there was Fitnah (tribulation, turmoil), and the people started to look right and left.”}}
\hadithdefcmd{ibnmajah}{1635}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ قَالَ أَبُو بَكْرٍ بَعْدَ وَفَاةِ رَسُولِ اللَّهِ ـ صلى الله عليه وسلم ـ لِعُمَرَ انْطَلِقْ بِنَا إِلَى أُمِّ أَيْمَنَ نَزُورُهَا كَمَا كَانَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ يَزُورُهَا ‏.‏ قَالَ: فَلَمَّا انْتَهَيْنَا إِلَيْهَا بَكَتْ فَقَالاَ لَهَا: مَا يُبْكِيكِ؟ فَمَا عِنْدَ اللَّهِ خَيْرٌ لِرَسُولِهِ ‏.‏ قَالَتْ: إِنِّي لأَعْلَمُ أَنَّ مَا عِنْدَ اللَّهِ خَيْرٌ لِرَسُولِهِ وَلَكِنْ أَبْكِي أَنَّ الْوَحْىَ قَدِ انْقَطَعَ مِنَ السَّمَاءِ ‏.‏ قَالَ: فَهَيَّجَتْهُمَا عَلَى الْبُكَاءِ فَجَعَلاَ يَبْكِيَانِ مَعَهَا ‏.‏\hadithno{1635}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Anas said:“After the Messenger of Allah (ﷺ) had died, Abu Bakr said to ‘Umar: ‘Let us go and visit Umm Ayman as the Messenger of Allah (ﷺ) used to visit her.’ He said: ‘When we reached her she wept.’ They said: ‘Why are you weeping? What is with Allah is better for His Messenger.’ She said: ‘I know that what is with Allah is better for His Messenger, but I am weeping because the Revelation from heaven has ceased.’ She moved them to tears and they started to weep with her.”}}
\hadithdefcmd{ibnmajah}{1636}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيٍّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ، عَنْ أَبِي الأَشْعَثِ الصَّنْعَانِيِّ، عَنْ أَوْسِ بْنِ أَوْسٍ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ إِنَّ مِنْ أَفْضَلِ أَيَّامِكُمْ يَوْمَ الْجُمُعَةِ فِيهِ خُلِقَ آدَمُ وَفِيهِ النَّفْخَةُ وَفِيهِ الصَّعْقَةُ فَأَكْثِرُوا عَلَىَّ مِنَ الصَّلاَةِ فِيهِ فَإِنَّ صَلاَتَكُمْ مَعْرُوضَةٌ عَلَىَّ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ كَيْفَ تُعْرَضُ صَلاَتُنَا عَلَيْكَ وَقَدْ أَرَمْتَ - يَعْنِي بَلِيتَ - قَالَ ‏"‏ إِنَّ اللَّهَ حَرَّمَ عَلَى الأَرْضِ أَنْ تَأْكُلَ أَجْسَادَ الأَنْبِيَاءِ ‏"‏ ‏.‏\hadithno{1636}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Aws bin Aws that the Messenger of Allah (ﷺ) said:‘The best of your days is Friday. On it Adam was created; on it shall be the Nafakhah,* on it all creation will swoon. So send a great deal of blessing upon me on this day, for your blessing will be presented to me.’ A man said: “O Messenger of Allah! How will our blessing be presented to you when you have disintegrated?” He said: “Allah has forbidden the earth to consume the bodies of the Prophets.”}}
\hadithdefcmd{ibnmajah}{1637}{حَدَّثَنَا عَمْرُو بْنُ سَوَّادٍ الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ زَيْدِ بْنِ أَيْمَنَ، عَنْ عُبَادَةَ بْنِ نُسَىٍّ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ قَالَ رَسُولُ اللَّهِ ـ صلى الله عليه وسلم ـ ‏"‏ أَكْثِرُوا الصَّلاَةَ عَلَىَّ يَوْمَ الْجُمُعَةِ فَإِنَّهُ مَشْهُودٌ تَشْهَدُهُ الْمَلاَئِكَةُ وَإِنَّ أَحَدًا لَنْ يُصَلِّيَ عَلَىَّ إِلاَّ عُرِضَتْ عَلَىَّ صَلاَتُهُ حَتَّى يَفْرُغَ مِنْهَا ‏"‏ ‏.‏ قَالَ قُلْتُ وَبَعْدَ الْمَوْتِ قَالَ ‏"‏ وَبَعْدَ الْمَوْتِ إِنَّ اللَّهَ حَرَّمَ عَلَى الأَرْضِ أَنْ تَأْكُلَ أَجْسَادَ الأَنْبِيَاءِ ‏"‏ ‏.‏ فَنَبِيُّ اللَّهِ حَىٌّ يُرْزَقُ ‏.‏\hadithno{1637}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Darda’ that the Messenger of Allah (ﷺ) said:“Send a great deal of blessing upon me on Fridays, for it is witnessed by the angels. No one sends blessing upon me but his blessing will be presented to me, until he finishes them.” A man said: “Even after death?” He said: “Even after death, for Allah has forbidden the earth to consume the bodies of the Prophets, so the Prophet of Allah is alive and receives provision.’”}}
