% Auto-generated chapter 54 for muslim
% Hadiths in this chapter: 158

\hadithdefcmd{muslim}{7235}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ زَيْنَبَ، بِنْتِ أُمِّ سَلَمَةَ عَنْ أُمِّ حَبِيبَةَ، عَنْ زَيْنَبَ بِنْتِ جَحْشٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اسْتَيْقَظَ مِنْ نَوْمِهِ وَهُوَ يَقُولُ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَيْلٌ لِلْعَرَبِ مِنْ شَرٍّ قَدِ اقْتَرَبَ فُتِحَ الْيَوْمَ مِنْ رَدْمِ يَأْجُوجَ وَمَأْجُوجَ مِثْلُ هَذِهِ ‏"‏ ‏.‏ وَعَقَدَ سُفْيَانُ بِيَدِهِ عَشَرَةً ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ أَنَهْلِكُ وَفِينَا الصَّالِحُونَ قَالَ ‏"‏ نَعَمْ إِذَا كَثُرَ الْخَبَثُ ‏"‏ ‏.‏\hadithno{7235}\hadithtrans{Zainab bint Jahsh reported that Allah's Apostle (ﷺ) got up from sleep saying:There is no being worthy of worship except Allah; there is a destruction in store for Arabia because of turmoil which is at hand, the barrier of Gog and Magog has opened so much. And Sufyan made a sign of ten with the help of his hand (in order to indicate the width of the gap) and I said: Allah's Messenger, would we be perished in spite of the fact that there would be good people amongst us? Thereupon he said: Of course, but only when the evil predominates}}
\hadithdefcmd{muslim}{7236}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَسَعِيدُ بْنُ عَمْرٍو الأَشْعَثِيُّ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، أَبِي عُمَرَ قَالُوا حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ وَزَادُوا فِي الإِسْنَادِ عَنْ سُفْيَانَ، فَقَالُوا عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ حَبِيبَةَ، عَنْ أُمِّ حَبِيبَةَ، عَنْ زَيْنَبَ بِنْتِ جَحْشٍ، ‏.‏\hadithno{7236}\hadithtrans{This hadith has been narrated on the authority of Zainab bint Jahsh with a slight variation in the chain of transmitters}}
\hadithdefcmd{muslim}{7237}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ زَيْنَبَ بِنْتَ أَبِي سَلَمَةَ، أَخْبَرَتْهُ أَنَّ أُمَّ حَبِيبَةَ بِنْتَ أَبِي سُفْيَانَ أَخْبَرَتْهَا أَنَّ زَيْنَبَ بِنْتَ جَحْشٍ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا فَزِعًا مُحْمَرًّا وَجْهُهُ يَقُولُ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ وَيْلٌ لِلْعَرَبِ مِنْ شَرٍّ قَدِ اقْتَرَبَ فُتِحَ الْيَوْمَ مِنْ رَدْمِ يَأْجُوجَ وَمَأْجُوجَ مِثْلُ هَذِهِ ‏"‏ ‏.‏ وَحَلَّقَ بِإِصْبَعِهِ الإِبْهَامِ وَالَّتِي تَلِيهَا ‏.‏ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ أَنَهْلِكُ وَفِينَا الصَّالِحُونَ قَالَ ‏"‏ نَعَمْ إِذَا كَثُرَ الْخَبَثُ ‏"‏ ‏.‏\hadithno{7237}\hadithtrans{Zainab bint Jahsh, the wife of Allah's Apostle (ﷺ), reported that one day Allah's Messenger (ﷺ) came out in a state of excitement with his face quite red. And he was saying:There is no god but Allah; there is a destruction in store for Arabia because of the turmoil which is near at hand as the barrier of Gog and Magog has been opened like it, and he (in order to explain it) made a ring with the help of his thumb and forefinger. I said: Allah's Messenger, would we be destroyed despite the fact that there would be pious people amongst us? He said: Yes, when evil would be predominant}}
\hadithdefcmd{muslim}{7238}{وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ، خَالِدٍ ح وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، كِلاَهُمَا عَنِ ابْنِ شِهَابٍ، بِمِثْلِ حَدِيثِ يُونُسَ عَنِ الزُّهْرِيِّ، بِإِسْنَادِهِ ‏.‏\hadithno{7238}\hadithtrans{This hadith has been narrated on the authority of Zuhri with a different chain of transmitters}}
\hadithdefcmd{muslim}{7239}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَحْمَدُ بْنُ إِسْحَاقَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَبْدُ، اللَّهِ بْنُ طَاوُسٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ فُتِحَ الْيَوْمَ مِنْ رَدْمِ يَأْجُوجَ وَمَأْجُوجَ مِثْلُ هَذِهِ ‏"‏ ‏.‏ وَعَقَدَ وُهَيْبٌ بِيَدِهِ تِسْعِينَ ‏.‏\hadithno{7239}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:Today the wall (barrier) of Gog and Magog has been opened so much, and Wuhaib (in order to explain it) made the figure of ninety with the help of his hand}}
\hadithdefcmd{muslim}{7240}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ - وَاللَّفْظُ لِقُتَيْبَةَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ عُبَيْدِ اللَّهِ ابْنِ الْقِبْطِيَّةِ، قَالَ دَخَلَ الْحَارِثُ بْنُ أَبِي رَبِيعَةَ وَعَبْدُ اللَّهِ بْنُ صَفْوَانَ وَأَنَا مَعَهُمَا، عَلَى أُمِّ سَلَمَةَ أُمِّ الْمُؤْمِنِينَ فَسَأَلاَهَا عَنِ الْجَيْشِ الَّذِي يُخْسَفُ بِهِ وَكَانَ ذَلِكَ فِي أَيَّامِ ابْنِ الزُّبَيْرِ فَقَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَعُوذُ عَائِذٌ بِالْبَيْتِ فَيُبْعَثُ إِلَيْهِ بَعْثٌ فَإِذَا كَانُوا بِبَيْدَاءَ مِنَ الأَرْضِ خُسِفَ بِهِمْ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ فَكَيْفَ بِمَنْ كَانَ كَارِهًا قَالَ ‏"‏ يُخْسَفُ بِهِ مَعَهُمْ وَلَكِنَّهُ يُبْعَثُ يَوْمَ الْقِيَامَةِ عَلَى نِيَّتِهِ ‏"‏ ‏.‏ وَقَالَ أَبُو جَعْفَرٍ هِيَ بَيْدَاءُ الْمَدِينَةِ ‏.‏\hadithno{7240}\hadithtrans{Harith b Abi Rabi'a and 'Abdullah b. Safwan both went to Umm Salama, the Mother of the Faithful, and they asked her about the army which would be sunk in the earth, and this relates to the time when Ibn Zubair (was the governor of Mecca). She reported that Allah's Messenger (ﷺ) had said that a seeker of refuge would seek refuge in the Sacred House and an army would be sent to him (in order to kill him) and when it would enter a plain ground, it would be made to sink. I said:Allah's Messenger, what about him who would be made to accompany this army willy nilly? Thereupon he said: He would be made to sink along with them but he would be raised on the Day of Resurrection on the basis of his intention. Abu Ja'far said. ' This plain, ground means the plain ground of Medina}}
\hadithdefcmd{muslim}{7241}{حَدَّثَنَاهُ أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ رُفَيْعٍ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِهِ قَالَ فَلَقِيتُ أَبَا جَعْفَرٍ فَقُلْتُ إِنَّهَا إِنَّمَا قَالَتْ بِبَيْدَاءَ مِنَ الأَرْضِ فَقَالَ أَبُو جَعْفَرٍ كَلاَّ وَاللَّهِ إِنَّهَا لَبَيْدَاءُ الْمَدِينَةِ ‏.‏\hadithno{7241}\hadithtrans{This hadith has been narrated on the authority of 'Abdullah b. Rufai, with the same chain of transmitters (but with the addition of these words):" When I met Abu Ja'far I told him that she (simply) meant the plain ground. Thereupon Abu Ja'far said: No, by God, she meant the plain ground of Medina}}
\hadithdefcmd{muslim}{7242}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لِعَمْرٍو - قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ، عُيَيْنَةَ عَنْ أُمَيَّةَ بْنِ صَفْوَانَ، سَمِعَ جَدَّهُ عَبْدَ اللَّهِ بْنَ صَفْوَانَ، يَقُولُ أَخْبَرَتْنِي حَفْصَةُ، أَنَّهَا سَمِعَتِ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَيَؤُمَّنَّ هَذَا الْبَيْتَ جَيْشٌ يَغْزُونَهُ حَتَّى إِذَا كَانُوا بِبَيْدَاءَ مِنَ الأَرْضِ يُخْسَفُ بِأَوْسَطِهِمْ وَيُنَادِي أَوَّلُهُمْ آخِرَهُمْ ثُمَّ يُخْسَفُ بِهِمْ فَلاَ يَبْقَى إِلاَّ الشَّرِيدُ الَّذِي يُخْبِرُ عَنْهُمْ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ أَشْهَدُ عَلَيْكَ أَنَّكَ لَمْ تَكْذِبْ عَلَى حَفْصَةَ وَأَشْهَدُ عَلَى حَفْصَةَ أَنَّهَا لَمْ تَكْذِبْ عَلَى النَّبِيِّ صلى الله عليه وسلم\hadithno{7242}\hadithtrans{Abdullah b. Safwan reported that Hafsa told him that she had heard Allah's Apostle (ﷺ) as saying:An army would attack this House in order to fight against the inhabitants of this House and when it would be at the plain ground the ranks in the centre of the army would be sunk and the vanguard would call the rear flanks of the army and they would also be sunk and no flank would be left except some people who would go to inform them (their kith and kin). A person (who had been listening to this hadith from Abdullah b. Safwan) said: I bear testimony in regard to you that you are not imputing a lie to Hafsa. And I bear testimony to the fact that Hafsa is not telling a lie about Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{7243}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمِ بْنِ مَيْمُونٍ، حَدَّثَنَا الْوَلِيدُ بْنُ صَالِحٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ، عَمْرٍو حَدَّثَنَا زَيْدُ بْنُ أَبِي أُنَيْسَةَ، عَنْ عَبْدِ الْمَلِكِ الْعَامِرِيِّ، عَنْ يُوسُفَ بْنِ مَاهَكَ، أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ صَفْوَانَ، عَنْ أُمِّ الْمُؤْمِنِينَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ سَيَعُوذُ بِهَذَا الْبَيْتِ - يَعْنِي الْكَعْبَةَ - قَوْمٌ لَيْسَتْ لَهُمْ مَنَعَةٌ وَلاَ عَدَدٌ وَلاَ عُدَّةٌ يُبْعَثُ إِلَيْهِمْ جَيْشٌ حَتَّى إِذَا كَانُوا بِبَيْدَاءَ مِنَ الأَرْضِ خُسِفَ بِهِمْ ‏"‏ ‏.‏ قَالَ يُوسُفُ وَأَهْلُ الشَّأْمِ يَوْمَئِذٍ يَسِيرُونَ إِلَى مَكَّةَ فَقَالَ عَبْدُ اللَّهِ بْنُ صَفْوَانَ أَمَا وَاللَّهِ مَا هُوَ بِهَذَا الْجَيْشِ ‏.‏ قَالَ زَيْدٌ وَحَدَّثَنِي عَبْدُ الْمَلِكِ الْعَامِرِيُّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَابِطٍ، عَنِ الْحَارِثِ، بْنِ أَبِي رَبِيعَةَ عَنْ أُمِّ الْمُؤْمِنِينَ، ‏.‏ بِمِثْلِ حَدِيثِ يُوسُفَ بْنِ مَاهَكٍ غَيْرَ أَنَّهُ لَمْ يَذْكُرْ فِيهِ الْجَيْشَ الَّذِي ذَكَرَهُ عَبْدُ اللَّهِ بْنُ صَفْوَانَ ‏.‏\hadithno{7243}\hadithtrans{Abdullah b. Safwan reported the Mother of the Faithful as saying that Allah's Messenger (ﷺ) said:They would soon seek protection in this House, viz. Ka'ba (the defenceless), people who would have nothing to protect themselves in the shape of weapons or the strength of the people. An army would be sent to fight (and kill) them and when they would enter a plain ground the army would be sunk in it. Yusuf (one of the narrators) said: It was a people of Syria (hordes of Hajjaj) who had been on that day coming towards Mecca for an attack (on 'Abdulllah b. Zubair) and Abdullah b. Safwan said: By God, it does not imply this army}}
\hadithdefcmd{muslim}{7244}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا الْقَاسِمُ بْنُ الْفَضْلِ، الْحُدَّانِيُّ عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَنَّ عَائِشَةَ، قَالَتْ عَبِثَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مَنَامِهِ فَقُلْنَا يَا رَسُولَ اللَّهِ صَنَعْتَ شَيْئًا فِي مَنَامِكَ لَمْ تَكُنْ تَفْعَلُهُ ‏.‏ فَقَالَ ‏"‏ الْعَجَبُ إِنَّ نَاسًا مِنْ أُمَّتِي يَؤُمُّونَ بِالْبَيْتِ بِرَجُلٍ مِنْ قُرَيْشٍ قَدْ لَجَأَ بِالْبَيْتِ حَتَّى إِذَا كَانُوا بِالْبَيْدَاءِ خُسِفَ بِهِمْ ‏"‏ ‏.‏ فَقُلْنَا يَا رَسُولَ اللَّهِ إِنَّ الطَّرِيقَ قَدْ يَجْمَعُ النَّاسَ ‏.‏ قَالَ ‏"‏ نَعَمْ فِيهِمُ الْمُسْتَبْصِرُ وَالْمَجْبُورُ وَابْنُ السَّبِيلِ يَهْلِكُونَ مَهْلَكًا وَاحِدًا وَيَصْدُرُونَ مَصَادِرَ شَتَّى يَبْعَثُهُمُ اللَّهُ عَلَى نِيَّاتِهِمْ ‏"‏ ‏.‏\hadithno{7244}\hadithtrans{A'isha reported that Allah's Messenger (ﷺ) was startled in the state of sleep. We said:Allah's Messenger, you have done something in the state of your sleep which you never did before, Thereupon he said: Strange it is that some people of my Ummah would attack the House (Ka'ba) (for killing) a person who would belong to the tribe of the Quraish and he would try to seek protection in the House. And when they would reach the plain ground they would be sunk. We said: Allah's Messenger, all sorts of people throng the path. Thereupon he said: Yes, there would be amongst them people who would come with definite designs and those who would come under duress and there would be travellers also, but they would all be destroyed through one (stroke) of destruction. though they would be raised in different states (on the Day of Resurrection). Allah would, however, raise them according to their intention}}
\hadithdefcmd{muslim}{7245}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لاِبْنِ أَبِي شَيْبَةَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ أُسَامَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَشْرَفَ عَلَى أُطُمٍ مِنْ آطَامِ الْمَدِينَةِ ثُمَّ قَالَ ‏ "‏ هَلْ تَرَوْنَ مَا أَرَى إِنِّي لأَرَى مَوَاقِعَ الْفِتَنِ خِلاَلَ بُيُوتِكُمْ كَمَوَاقِعِ الْقَطْرِ ‏"‏ ‏.‏\hadithno{7245}\hadithtrans{Usama reported that Allah's Messenger (ﷺ) climbed up a battlement amongst the battlements of Medina and then said:You do not see what I am seeing and I am seeing the places of turmoil between your houses as the places of rainfall}}
\hadithdefcmd{muslim}{7246}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{7246}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{7247}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَالْحَسَنُ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنِي وَقَالَ، الآخَرَانِ حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ، شِهَابٍ حَدَّثَنِي ابْنُ الْمُسَيَّبِ، وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سَتَكُونُ فِتَنٌ الْقَاعِدُ فِيهَا خَيْرٌ مِنَ الْقَائِمِ وَالْقَائِمُ فِيهَا خَيْرٌ مِنَ الْمَاشِي وَالْمَاشِي فِيهَا خَيْرٌ مِنَ السَّاعِي مَنْ تَشَرَّفَ لَهَا تَسْتَشْرِفُهُ وَمَنْ وَجَدَ فِيهَا مَلْجَأً فَلْيَعُذْ بِهِ ‏"‏ ‏.‏\hadithno{7247}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There will be soon a period of turmoil in which the one who sits will be better than one who stands and the one who stands will be better than one who walks and the one who walks will be better than one who runs. He who would watch them will be drawn by them. So he who finds a refuge or shelter against it should make it as his resort}}
\hadithdefcmd{muslim}{7248}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَالْحَسَنُ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنِي وَقَالَ، الآخَرَانِ حَدَّثَنَا يَعْقُوبُ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي أَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مُطِيعِ بْنِ الأَسْوَدِ، عَنْ نَوْفَلِ بْنِ مُعَاوِيَةَ، ‏.‏ مِثْلَ حَدِيثِ أَبِي هُرَيْرَةَ هَذَا إِلاَّ أَنَّ أَبَا بَكْرٍ، يَزِيدُ ‏ "‏ مِنَ الصَّلاَةِ صَلاَةٌ مَنْ فَاتَتْهُ فَكَأَنَّمَا وُتِرَ أَهْلَهُ وَمَالَهُ ‏"‏ ‏.‏\hadithno{7248}\hadithtrans{This hadith has been transmitted on the authority of Abu Huraira but with this variation of wording that in the hadith transmitted on the authority of Abu Bakr, there is an addition of these words:" There is a prayer among prayers ('Asr) and one who misses it is as if his family and property have been ruined}}
\hadithdefcmd{muslim}{7249}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ تَكُونُ فِتْنَةٌ النَّائِمُ فِيهَا خَيْرٌ مِنَ الْيَقْظَانِ وَالْيَقْظَانُ فِيهَا خَيْرٌ مِنَ الْقَائِمِ وَالْقَائِمُ فِيهَا خَيْرٌ مِنَ السَّاعِي فَمَنْ وَجَدَ مَلْجَأً أَوْ مَعَاذًا فَلْيَسْتَعِذْ ‏"‏ ‏.‏\hadithno{7249}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:There would be turmoil and the one who would sleep would be better than who would be awake and the one who would be awake would be better than one who would stand and one who would stand would be better than one who would run. So he who finds refuge or shelter should take that refuge or shelter}}
\hadithdefcmd{muslim}{7250}{حَدَّثَنِي أَبُو كَامِلٍ الْجَحْدَرِيُّ، فُضَيْلُ بْنُ حُسَيْنٍ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا عُثْمَانُ، الشَّحَّامُ قَالَ انْطَلَقْتُ أَنَا وَفَرْقَدٌ السَّبَخِيُّ، إِلَى مُسْلِمِ بْنِ أَبِي بَكْرَةَ وَهُوَ فِي أَرْضِهِ فَدَخَلْنَا عَلَيْهِ فَقُلْنَا هَلْ سَمِعْتَ أَبَاكَ يُحَدِّثُ فِي الْفِتَنِ حَدِيثًا قَالَ نَعَمْ سَمِعْتُ أَبَا بَكْرَةَ يُحَدِّثُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهَا سَتَكُونُ فِتَنٌ أَلاَ ثُمَّ تَكُونُ فِتْنَةٌ الْقَاعِدُ فِيهَا خَيْرٌ مِنَ الْمَاشِي فِيهَا وَالْمَاشِي فِيهَا خَيْرٌ مِنَ السَّاعِي إِلَيْهَا أَلاَ فَإِذَا نَزَلَتْ أَوْ وَقَعَتْ فَمَنْ كَانَ لَهُ إِبِلٌ فَلْيَلْحَقْ بِإِبِلِهِ وَمَنْ كَانَتْ لَهُ غَنَمٌ فَلْيَلْحَقْ بِغَنَمِهِ وَمَنْ كَانَتْ لَهُ أَرْضٌ فَلْيَلْحَقْ بِأَرْضِهِ ‏"‏ ‏.‏ قَالَ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَرَأَيْتَ مَنْ لَمْ يَكُنْ لَهُ إِبِلٌ وَلاَ غَنَمٌ وَلاَ أَرْضٌ قَالَ ‏"‏ يَعْمِدُ إِلَى سَيْفِهِ فَيَدُقُّ عَلَى حَدِّهِ بِحَجَرٍ ثُمَّ لْيَنْجُ إِنِ اسْتَطَاعَ النَّجَاءَ اللَّهُمَّ هَلْ بَلَّغْتُ اللَّهُمَّ هَلْ بَلَّغْتُ اللَّهُمَّ هَلْ بَلَّغْتُ ‏"‏ ‏.‏ قَالَ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَرَأَيْتَ إِنْ أُكْرِهْتُ حَتَّى يُنْطَلَقَ بِي إِلَى أَحَدِ الصَّفَّيْنِ أَوْ إِحْدَى الْفِئَتَيْنِ فَضَرَبَنِي رَجُلٌ بِسَيْفِهِ أَوْ يَجِيءُ سَهْمٌ فَيَقْتُلُنِي قَالَ ‏"‏ يَبُوءُ بِإِثْمِهِ وَإِثْمِكَ وَيَكُونُ مِنْ أَصْحَابِ النَّارِ ‏"‏ ‏.‏\hadithno{7250}\hadithtrans{Abu Bakra reported Allah's Messenger (ﷺ) as saying:There would soon be turmoil. Behold! there would be turmoil in which the one who would be seated would be better than one who would stand and the one who would stand would be better than one who would run. Behold! when the turmoil comes or it appears, the one who has camel should stick to his camel and he who has sheep or goat should stick to his sheep and goat and he who has land should stick to the land. A person said: 'Allah's Messenger, what is your opinion about one who has neither camel nor sheep nor land? Thereupon, he said: He should take hold of his sword and beat its edge with the help of stone and then try to find a way of escape. O Allah, I have conveyed (Thy Message) ; O Allah, I have conveyed (Thy Message) ; O Allah, I have conveyed (Thy Message). A person said: Allah's Messenger, what is your opinion if I am drawn to a rank in spite of myself, or in one of the groups and made to march and a man strikes with his sword or there comes an arrow and kills me? Thereupon he said: He will bear the punishment of his sin and that of yours and he would be one amongst the denizens of Hell}}
\hadithdefcmd{muslim}{7251}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنِي مُحَمَّدُ، بْنُ الْمُثَنَّى حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، كِلاَهُمَا عَنْ عُثْمَانَ الشَّحَّامِ، بِهَذَا الإِسْنَادِ ‏.‏ حَدِيثُ ابْنِ أَبِي عَدِيٍّ نَحْوَ حَدِيثِ حَمَّادٍ إِلَى آخِرِهِ وَانْتَهَى حَدِيثُ وَكِيعٍ عِنْدَ قَوْلِهِ ‏ "‏ إِنِ اسْتَطَاعَ النَّجَاءَ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ مَا بَعْدَهُ ‏.‏\hadithno{7251}\hadithtrans{This hadith has been transmitted on the authority of Waki' with a slight variation of wording}}
\hadithdefcmd{muslim}{7252}{حَدَّثَنِي أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، وَيُونُسَ عَنِ الْحَسَنِ، عَنِ الأَحْنَفِ بْنِ قَيْسٍ، قَالَ خَرَجْتُ وَأَنَا أُرِيدُ، هَذَا الرَّجُلَ فَلَقِيَنِي أَبُو بَكْرَةَ فَقَالَ أَيْنَ تُرِيدُ يَا أَحْنَفُ قَالَ قُلْتُ أُرِيدُ نَصْرَ ابْنِ عَمِّ رَسُولِ اللَّهِ صلى الله عليه وسلم - يَعْنِي عَلِيًّا - قَالَ فَقَالَ لِي يَا أَحْنَفُ ارْجِعْ فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِذَا تَوَاجَهَ الْمُسْلِمَانِ بِسَيْفَيْهِمَا فَالْقَاتِلُ وَالْمَقْتُولُ فِي النَّارِ ‏"‏ ‏.‏ قَالَ فَقُلْتُ أَوْ قِيلَ يَا رَسُولَ اللَّهِ هَذَا الْقَاتِلُ فَمَا بَالُ الْمَقْتُولِ قَالَ ‏"‏ إِنَّهُ قَدْ أَرَادَ قَتْلَ صَاحِبِهِ ‏"‏ ‏.‏\hadithno{7252}\hadithtrans{Ahnaf b. Qais reported:I set out with the intention of helping this person (Hadrat 'Ali) when Abu Bakra met me. He said: Ahnaf, where do you intend to go? I said: I intend to help the cousin of Allah's Messenger (ﷺ), viz. 'Ali. Thereupon he said to me: Ahnaf, go back, for I heard Allah's Messenger (ﷺ) as saying: When two Muslims confront one another with swords (in hand) both the slayer and the slain would be in Fire. He (Ahnaf) said: I said, or it was said: Allah's Messenger, it may be the case of one who kills. but what about the slain (why he would be put in Hell-Fire)? Thereupon he said: He also intended to kill his companion}}
\hadithdefcmd{muslim}{7253}{وَحَدَّثَنَاهُ أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، وَيُونُسَ، وَالْمُعَلَّى بْنِ زِيَادٍ، عَنِ الْحَسَنِ، عَنِ الأَحْنَفِ بْنِ قَيْسٍ، عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا الْتَقَى الْمُسْلِمَانِ بِسَيْفَيْهِمَا فَالْقَاتِلُ وَالْمَقْتُولُ فِي النَّارِ ‏"‏ ‏.‏\hadithno{7253}\hadithtrans{Ahnaf b. Qais reported on the authority of Abu Bakra that Allah's Messenger (ﷺ) said:When two Muslims confront each other with their swords, both the slayer and the slain are doomed to Hell-Fire}}
\hadithdefcmd{muslim}{7254}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، مِنْ كِتَابِهِ أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِ أَبِي كَامِلٍ عَنْ حَمَّادٍ، إِلَى آخِرِهِ ‏.‏\hadithno{7254}\hadithtrans{This hadith has been narrated on the authority of Hammad through another chain of transmitters}}
\hadithdefcmd{muslim}{7255}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ أَبِي بَكْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا الْمُسْلِمَانِ حَمَلَ أَحَدُهُمَا عَلَى أَخِيهِ السِّلاَحَ فَهُمَا فِي جُرُفِ جَهَنَّمَ فَإِذَا قَتَلَ أَحَدُهُمَا صَاحِبَهُ دَخَلاَهَا جَمِيعًا ‏"‏ ‏.‏\hadithno{7255}\hadithtrans{Abu Bakra reported Allah's Messenger (ﷺ) as saying:When two Muslims (confront each other) and the one amongst them attacks his brother with a weapon, both of them are at the brink of Hell-Fire. And when one of them kills his companion, both of them get into Hell-Fire}}
\hadithdefcmd{muslim}{7257}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَكْثُرَ الْهَرْجُ ‏"‏ ‏.‏ قَالُوا وَمَا الْهَرْجُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الْقَتْلُ الْقَتْلُ ‏"‏ ‏.‏\hadithno{7257}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The last Hour will not come unless there is much bloodshed. They said: What is harj? Thereupon he said: Bloodshed. bloodshed}}
\hadithdefcmd{muslim}{7258}{حَدَّثَنَا أَبُو الرَّبِيعِ الْعَتَكِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، كِلاَهُمَا عَنْ حَمَّادِ بْنِ زَيْدٍ، - وَاللَّفْظُ لِقُتَيْبَةَ - حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ زَوَى لِيَ الأَرْضَ فَرَأَيْتُ مَشَارِقَهَا وَمَغَارِبَهَا وَإِنَّ أُمَّتِي سَيَبْلُغُ مُلْكُهَا مَا زُوِيَ لِي مِنْهَا وَأُعْطِيتُ الْكَنْزَيْنِ الأَحْمَرَ وَالأَبْيَضَ وَإِنِّي سَأَلْتُ رَبِّي لأُمَّتِي أَنْ لاَ يُهْلِكَهَا بِسَنَةٍ بِعَامَّةٍ وَأَنْ لاَ يُسَلِّطَ عَلَيْهِمْ عَدُوًّا مِنْ سِوَى أَنْفُسِهِمْ فَيَسْتَبِيحَ بَيْضَتَهُمْ وَإِنَّ رَبِّي قَالَ يَا مُحَمَّدُ إِنِّي إِذَا قَضَيْتُ قَضَاءً فَإِنَّهُ لاَ يُرَدُّ وَإِنِّي أَعْطَيْتُكَ لأُمَّتِكَ أَنْ لاَ أُهْلِكَهُمْ بِسَنَةٍ بِعَامَّةٍ وَأَنْ لاَ أُسَلِّطَ عَلَيْهِمْ عَدُوًّا مِنْ سِوَى أَنْفُسِهِمْ يَسْتَبِيحُ بَيْضَتَهُمْ وَلَوِ اجْتَمَعَ عَلَيْهِمْ مَنْ بِأَقْطَارِهَا - أَوْ قَالَ مَنْ بَيْنَ أَقْطَارِهَا - حَتَّى يَكُونَ بَعْضُهُمْ يُهْلِكُ بَعْضًا وَيَسْبِي بَعْضُهُمْ بَعْضًا ‏"‏ ‏.‏\hadithno{7258}\hadithtrans{Thauban reported that Allah's Messenger (ﷺ) said:Allah drew the ends of the world near one another for my sake. And I have seen its eastern and western ends. And the dominion of my Ummah would reach those ends which have been drawn near me and I have been granted the red and the white treasure and I begged my Lord for my Ummah that it should not be destroyed because of famine, nor be dominated by an enemy who is not amongst them to take their lives and destroy them root and branch, and my Lord said: Muhammad, whenever I make a decision, there is none to change it. I grant you for your Ummah that it would not be destroyed by famine and it would not be dominated by an enemy who would not be amongst it and would take their lives and destroy them root and branch even if all the people from the different parts of the world join hands together (for this purpose), but it would be from amongst them, viz. your Ummah, that some people would kill the others or imprison the others}}
\hadithdefcmd{muslim}{7259}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ الرَّحَبِيِّ، عَنْ ثَوْبَانَ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ تَعَالَى زَوَى لِيَ الأَرْضَ حَتَّى رَأَيْتُ مَشَارِقَهَا وَمَغَارِبَهَا وَأَعْطَانِي الْكَنْزَيْنِ الأَحْمَرَ وَالأَبْيَضَ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ نَحْوَ حَدِيثِ أَيُّوبَ عَنْ أَبِي قِلاَبَةَ ‏.‏\hadithno{7259}\hadithtrans{Thauban reported that Allah's Messenger (ﷺ) said. Verily, Allah drew the ends of the world near me until I saw its east and west, and He bestowed upon me two treasures, the red and the white. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{7260}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ، أَخْبَرَنِي عَامِرُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَقْبَلَ ذَاتَ يَوْمٍ مِنَ الْعَالِيَةِ حَتَّى إِذَا مَرَّ بِمَسْجِدِ بَنِي مُعَاوِيَةَ دَخَلَ فَرَكَعَ فِيهِ رَكْعَتَيْنِ وَصَلَّيْنَا مَعَهُ وَدَعَا رَبَّهُ طَوِيلاً ثُمَّ انْصَرَفَ إِلَيْنَا فَقَالَ صلى الله عليه وسلم ‏ "‏ سَأَلْتُ رَبِّي ثَلاَثًا فَأَعْطَانِي ثِنْتَيْنِ وَمَنَعَنِي وَاحِدَةً سَأَلْتُ رَبِّي أَنْ لاَ يُهْلِكَ أُمَّتِي بِالسَّنَةِ فَأَعْطَانِيهَا وَسَأَلْتُهُ أَنْ لاَ يُهْلِكَ أُمَّتِي بِالْغَرَقِ فَأَعْطَانِيهَا وَسَأَلْتُهُ أَنْ لاَ يَجْعَلَ بَأْسَهُمْ بَيْنَهُمْ فَمَنَعَنِيهَا ‏"‏ ‏.‏\hadithno{7260}\hadithtrans{Amir b. Sa'd reported on the authority of his father that one day Allah's Messenger (ﷺ) came from a high, land. He passed by the mosque of Banu Mu'awiya, went in and observed two rak'ahs there and we also observed prayer along with him and he made a long supplication to his Lord. He then came to us and said:I asked my Lord three things and He has granted me two but has withheld one. I begged my Lord that my Ummah should not be destroyed because of famine and He granted me this. And I begged my Lord that my Ummah should not be destroyed by drowning (by deluge) and He granted me this. And I begged my Lord that there should be no bloodshed among the people of my Ummah, but He did not grant it}}
\hadithdefcmd{muslim}{7261}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا عُثْمَانُ بْنُ حَكِيمٍ الأَنْصَارِيُّ، أَخْبَرَنِي عَامِرُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، أَنَّهُ أَقْبَلَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي طَائِفَةٍ مِنْ أَصْحَابِهِ فَمَرَّ بِمَسْجِدِ بَنِي مُعَاوِيَةَ ‏.‏ بِمِثْلِ حَدِيثِ ابْنِ نُمَيْرٍ ‏.‏\hadithno{7261}\hadithtrans{Amir b. Sa'd reported on the authority of his father that Allah's Messenger (ﷺ) came with a group of his Companions and he passed by the mosque of Banu Mu'awiya. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{7262}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ أَبَا إِدْرِيسَ الْخَوْلاَنِيَّ، كَانَ يَقُولُ قَالَ حُذَيْفَةُ بْنُ الْيَمَانِ وَاللَّهِ إِنِّي لأَعْلَمُ النَّاسِ بِكُلِّ فِتْنَةٍ هِيَ كَائِنَةٌ فِيمَا بَيْنِي وَبَيْنَ السَّاعَةِ وَمَا بِي إِلاَّ أَنْ يَكُونَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَسَرَّ إِلَىَّ فِي ذَلِكَ شَيْئًا لَمْ يُحَدِّثْهُ غَيْرِي وَلَكِنْ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ وَهُوَ يُحَدِّثُ مَجْلِسًا أَنَا فِيهِ عَنِ الْفِتَنِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ يَعُدُّ الْفِتَنَ ‏ "‏ مِنْهُنَّ ثَلاَثٌ لاَ يَكَدْنَ يَذَرْنَ شَيْئًا وَمِنْهُنَّ فِتَنٌ كَرِيَاحِ الصَّيْفِ مِنْهَا صِغَارٌ وَمِنْهَا كِبَارٌ ‏"‏ ‏.‏ قَالَ حُذَيْفَةُ فَذَهَبَ أُولَئِكَ الرَّهْطُ كُلُّهُمْ غَيْرِي ‏.‏\hadithno{7262}\hadithtrans{Hudhaifa b. al-Yaman reported:By Allah, I have the best knowledge amongst people about every turmoil which is going to appear in the period intervening me and the Last Hour; and it is not for the fact that Allah's Messenger (ﷺ) told me something confidentially pertaining to it and he did not tell anybody else about it, but it is because of the fact that I was present in the assembly in which he had been describing the turmoil. and he especially made a mention of three turmoils which would not spare anything and amongst these there would be turmoils like storms in the hot season. Some of them would be violent and some of them would be comparatively mild. Hudhaifa said: All (who were present) except I have gone (to the next world)}}
\hadithdefcmd{muslim}{7263}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ عُثْمَانُ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ حُذَيْفَةَ، قَالَ قَامَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم مَقَامًا مَا تَرَكَ شَيْئًا يَكُونُ فِي مَقَامِهِ ذَلِكَ إِلَى قِيَامِ السَّاعَةِ إِلاَّ حَدَّثَ بِهِ حَفِظَهُ مَنْ حَفِظَهُ وَنَسِيَهُ مَنْ نَسِيَهُ قَدْ عَلِمَهُ أَصْحَابِي هَؤُلاَءِ وَإِنَّهُ لَيَكُونُ مِنْهُ الشَّىْءُ قَدْ نَسِيتُهُ فَأَرَاهُ فَأَذْكُرُهُ كَمَا يَذْكُرُ الرَّجُلُ وَجْهَ الرَّجُلِ إِذَا غَابَ عَنْهُ ثُمَّ إِذَا رَآهُ عَرَفَهُ ‏.‏\hadithno{7263}\hadithtrans{Hudhaifa reported that Allah's Messenger (ﷺ) stood before us one day and he did not leave anything unsaid (that he had to say) at that very spot which would happen (in the shape of turmoil) up to the Last Hour. Those who had to remember them preserved them in their minds and those who could not remember them forgot them. My friends knew them and there are certain things which slip out of my mind, but I recapitulate them when anyone makes a mention of them just as a person is lost from one's mind but is recalled to him on seeing his face}}
\hadithdefcmd{muslim}{7264}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ إِلَى قَوْلِهِ وَنَسِيَهُ مَنْ نَسِيَهُ ‏.‏ وَلَمْ يَذْكُرْ مَا بَعْدَهُ ‏.‏\hadithno{7264}\hadithtrans{This hadith has been narrated on the authority of A'mash with the same chain of transmitters up to the words:And he forgot who had to forget that and. he did not make a mention of what follows after this}}
\hadithdefcmd{muslim}{7265}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنِي أَبُو بَكْرِ، بْنُ نَافِعٍ حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ حُذَيْفَةَ، أَنَّهُ قَالَ أَخْبَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَا هُوَ كَائِنٌ إِلَى أَنْ تَقُومَ السَّاعَةُ فَمَا مِنْهُ شَىْءٌ إِلاَّ قَدْ سَأَلْتُهُ إِلاَّ أَنِّي لَمْ أَسْأَلْهُ مَا يُخْرِجُ أَهْلَ الْمَدِينَةِ مِنَ الْمَدِينَةِ\hadithno{7265}\hadithtrans{Hudhaifa reported:Allah's Messenger (ﷺ) informed me of what is going to happen before the approach of the Last Hour. And there is nothing that I did not ask him in this connection except this that I did not ask him as to what would turn the people of Medina out from Medina}}
\hadithdefcmd{muslim}{7266}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي وَهْبُ بْنُ جَرِيرٍ، أَخْبَرَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{7266}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{7267}{وَحَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، وَحَجَّاجُ بْنُ الشَّاعِرِ، جَمِيعًا عَنْ أَبِي عَاصِمٍ، - قَالَ حَجَّاجٌ حَدَّثَنَا أَبُو عَاصِمٍ، - أَخْبَرَنَا عَزْرَةُ بْنُ ثَابِتٍ، أَخْبَرَنَا عِلْبَاءُ بْنُ أَحْمَرَ، حَدَّثَنِي أَبُو زَيْدٍ، - يَعْنِي عَمْرَو بْنَ أَخْطَبَ - قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم الْفَجْرَ وَصَعِدَ الْمِنْبَرَ فَخَطَبَنَا حَتَّى حَضَرَتِ الظُّهْرُ فَنَزَلَ فَصَلَّى ثُمَّ صَعِدَ الْمِنْبَرَ فَخَطَبَنَا حَتَّى حَضَرَتِ الْعَصْرُ ثُمَّ نَزَلَ فَصَلَّى ثُمَّ صَعِدَ الْمِنْبَرَ فَخَطَبَنَا حَتَّى غَرَبَتِ الشَّمْسُ فَأَخْبَرَنَا بِمَا كَانَ وَبِمَا هُوَ كَائِنٌ فَأَعْلَمُنَا أَحْفَظُنَا ‏.‏\hadithno{7267}\hadithtrans{Abu Zaid (viz. Amr b. Akhtab) reported:Allah's Messenger (ﷺ) led us in the dawn prayer and then mounted the pulpit and addressed us until it was (time for the) noon prayer. He then came down the pulpit and observed prayer and then again mounted the pulpit and again addressed us until it was time for the 'Asr prayer. He then again came down and observed the prayer and again mounted the pulpit and addressed us until the sun was set and he informed (about) everything (pertaining to turmoil) that lay hidden in the past and what lies in (the womb) of) the future and the most learned amongst us is one who remembers them well}}
\hadithdefcmd{muslim}{7268}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَمُحَمَّدُ بْنُ الْعَلاَءِ أَبُو كُرَيْبٍ، جَمِيعًا عَنْ أَبِي، مُعَاوِيَةَ قَالَ ابْنُ الْعَلاَءِ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ حُذَيْفَةَ، قَالَ كُنَّا عِنْدَ عُمَرَ فَقَالَ أَيُّكُمْ يَحْفَظُ حَدِيثَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْفِتْنَةِ كَمَا قَالَ قَالَ فَقُلْتُ أَنَا ‏.‏ قَالَ إِنَّكَ لَجَرِيءٌ وَكَيْفَ قَالَ قَالَ قُلْتُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ فِتْنَةُ الرَّجُلِ فِي أَهْلِهِ وَمَالِهِ وَنَفْسِهِ وَوَلَدِهِ وَجَارِهِ يُكَفِّرُهَا الصِّيَامُ وَالصَّلاَةُ وَالصَّدَقَةُ وَالأَمْرُ بِالْمَعْرُوفِ وَالنَّهْىُ عَنِ الْمُنْكَرِ ‏"‏ ‏.‏ فَقَالَ عُمَرُ لَيْسَ هَذَا أُرِيدُ إِنَّمَا أُرِيدُ الَّتِي تَمُوجُ كَمَوْجِ الْبَحْرِ - قَالَ - فَقُلْتُ مَا لَكَ وَلَهَا يَا أَمِيرَ الْمُؤْمِنِينَ إِنَّ بَيْنَكَ وَبَيْنَهَا بَابًا مُغْلَقًا قَالَ أَفَيُكْسَرُ الْبَابُ أَمْ يُفْتَحُ قَالَ قُلْتُ لاَ بَلْ يُكْسَرُ ‏.‏ قَالَ ذَلِكَ أَحْرَى أَنْ لاَ يُغْلَقَ أَبَدًا ‏.‏ قَالَ فَقُلْنَا لِحُذَيْفَةَ هَلْ كَانَ عُمَرُ يَعْلَمُ مَنِ الْبَابُ قَالَ نَعَمْ كَمَا يَعْلَمُ أَنَّ دُونَ غَدٍ اللَّيْلَةَ إِنِّي حَدَّثْتُهُ حَدِيثًا لَيْسَ بِالأَغَالِيطِ ‏.‏ قَالَ فَهِبْنَا أَنْ نَسْأَلَ حُذَيْفَةَ مَنِ الْبَابُ فَقُلْنَا لِمَسْرُوقٍ سَلْهُ فَسَأَلَهُ فَقَالَ عُمَرُ ‏.‏\hadithno{7268}\hadithtrans{Hudhaifa reported:We were one day in the company of 'Umar that he said: Who amongst you has preserved in his mind most perfectly the hadith of Allah's Messenger (ﷺ) in regard to the turmoil as he told about it? I said: It is I. Thereupon he said: You are bold (enough to make this claim). And he further said: How? I said: I heard Allah's Messenger (ﷺ) as saying: There would (first) be turmoil for a person in regard to his family, his property, his own self, his children, his neighbours (and the sins committed in their connection) would be expiated by fasting, prayer, charity, enjoining good and prohibiting evil. Thereupon 'Umar said: I do not mean (that turmoil on a small scale) but that one which would emerge like the mounting waves of the ocean. I said: Commander of the Faithful, you have nothing to do with it, for the door is closed between you and that. He said: Would that door be broken or opened? I said: No, it would be broken. Thereupon he said: Then it would not be closed despite best efforts. We said to Hudhaifa: Did Umar know the door? Thereupon he said: Yes, he knew it (for certain) just as one knows that night precedes the next day. And I narrated to him something in which there was nothing fabricated. Shaqiq (one of the narrators) said: We dared not ask Hudhaifa about that door. So we requested Masruq to ask him. So he asked him and he said: (By that door, he meant) 'Umar}}
\hadithdefcmd{muslim}{7269}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا يَحْيَى بْنُ عِيسَى، كُلُّهُمْ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ أَبِي مُعَاوِيَةَ وَفِي حَدِيثِ عِيسَى عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، قَالَ سَمِعْتُ حُذَيْفَةَ، يَقُولُ ‏.‏\hadithno{7269}\hadithtrans{This hadith has been narrated on the authority of Hudhaifa through other chains of transmitters also}}
\hadithdefcmd{muslim}{7270}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ جَامِعِ بْنِ أَبِي رَاشِدٍ، وَالأَعْمَشُ، عَنْ أَبِي وَائِلٍ، عَنْ حُذَيْفَةَ، قَالَ قَالَ عُمَرُ مَنْ يُحَدِّثُنَا عَنِ الْفِتْنَةِ، وَاقْتَصَّ الْحَدِيثَ، بِنَحْوِ حَدِيثِهِمْ ‏.‏\hadithno{7270}\hadithtrans{Hudhaifa reported that Umar said:Who would narrate to us (the ahadith pertaining to turmoil) and he reported a hadith similar to these ahadith}}
\hadithdefcmd{muslim}{7271}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ حَاتِمٍ، قَالاَ حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، حَدَّثَنَا ابْنُ، عَوْنٍ عَنْ مُحَمَّدٍ، قَالَ قَالَ جُنْدُبٌ جِئْتُ يَوْمَ الْجَرَعَةِ فَإِذَا رَجُلٌ جَالِسٌ فَقُلْتُ لَيُهَرَاقَنَّ الْيَوْمَ هَا هُنَا دِمَاءٌ ‏.‏ فَقَالَ ذَاكَ الرَّجُلُ كَلاَّ وَاللَّهِ ‏.‏ قُلْتُ بَلَى وَاللَّهِ ‏.‏ قَالَ كَلاَّ وَاللَّهِ ‏.‏ قُلْتُ بَلَى وَاللَّهِ ‏.‏ قَالَ كَلاَّ وَاللَّهِ إِنَّهُ لَحَدِيثُ رَسُولِ اللَّهِ صلى الله عليه وسلم حَدَّثَنِيهِ ‏.‏ قُلْتُ بِئْسَ الْجَلِيسُ لِي أَنْتَ مُنْذُ الْيَوْمِ تَسْمَعُنِي أُخَالِفُكَ وَقَدْ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلاَ تَنْهَانِي ثُمَّ قُلْتُ مَا هَذَا الْغَضَبُ فَأَقْبَلْتُ عَلَيْهِ وَأَسْأَلُهُ فَإِذَا الرَّجُلُ حُذَيْفَةُ ‏.‏\hadithno{7271}\hadithtrans{Jundub reported:I came on the day of Jara`a that a person was (found) sitting. I said: They would shed their blood today. That person said: By Allah. not at all. I said: By Allah, of course, they would do it. He said: By Allah, they would not do it. I said: By Allah, of course, they would do it. He said: By Allah, they would not do it, and I have heard a hadith of Allah's Messenger (ﷺ) which I am narrating to you in this connection. I said: You are a bad seat fellow. I have been opposing you since morning and you are listening to me in spite of the fact that you have heard a hadith from Allah's Apostle (ﷺ) (contrary to my statement). I myself felt that there was no use of this annoyance. (He could tell me earlier that it was a hadith of the Prophet (may peace be upon him], and I would not have opposed him at all.) I turned my face toward him and asked him and he was Hadrat Hudhaifa}}
\hadithdefcmd{muslim}{7272}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَحْسِرَ الْفُرَاتُ عَنْ جَبَلٍ مِنْ ذَهَبٍ يَقْتَتِلُ النَّاسُ عَلَيْهِ فَيُقْتَلُ مِنْ كُلِّ مِائَةٍ تِسْعَةٌ وَتِسْعُونَ وَيَقُولُ كُلُّ رَجُلٍ مِنْهُمْ لَعَلِّي أَكُونُ أَنَا الَّذِي أَنْجُو ‏"‏ ‏.‏\hadithno{7272}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The Last Hour would not come before the Euphrates uncovers a mountain of gold, for which people would fight. Ninety-nine out of each one hundred would die but every man amongst them would say that perhaps he would be the one who would be saved (and thus possess this gold)}}
\hadithdefcmd{muslim}{7273}{وَحَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا رَوْحٌ، عَنْ سُهَيْلٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ وَزَادَ فَقَالَ أَبِي إِنْ رَأَيْتَهُ فَلاَ تَقْرَبَنَّهُ ‏.‏\hadithno{7273}\hadithtrans{This hadith has been narrated on the authority of Suhail with the same chain of transmitters but with this addition:" My father said: If you see that, do not even go near it}}
\hadithdefcmd{muslim}{7274}{حَدَّثَنَا أَبُو مَسْعُودٍ، سَهْلُ بْنُ عُثْمَانَ حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ السَّكُونِيُّ، عَنْ عُبَيْدِ، اللَّهِ عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُوشِكُ الْفُرَاتُ أَنْ يَحْسِرَ عَنْ كَنْزٍ مِنْ ذَهَبٍ فَمَنْ حَضَرَهُ فَلاَ يَأْخُذْ مِنْهُ شَيْئًا ‏"‏ ‏.‏\hadithno{7274}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The Last Hour would not come unless the Euphrates would uncover a treasure of gold, so he who finds it should not take anything out of that}}
\hadithdefcmd{muslim}{7275}{حَدَّثَنَا سَهْلُ بْنُ عُثْمَانَ، حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ أَبِي الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُوشِكُ الْفُرَاتُ أَنْ يَحْسِرَ عَنْ جَبَلٍ مِنْ ذَهَبٍ فَمَنْ حَضَرَهُ فَلاَ يَأْخُذْ مِنْهُ شَيْئًا ‏"‏ ‏.‏\hadithno{7275}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The Euphrates would soon uncover a mountain of gold but he who is present there should not take anything from that}}
\hadithdefcmd{muslim}{7276}{حَدَّثَنَا أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ وَأَبُو مَعْنٍ الرَّقَاشِيُّ - وَاللَّفْظُ لأَبِي مَعْنٍ - قَالاَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، أَخْبَرَنِي أَبِي، عَنْ سُلَيْمَانَ بْنِ، يَسَارٍ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ نَوْفَلٍ، قَالَ كُنْتُ وَاقِفًا مَعَ أُبَىِّ بْنِ كَعْبٍ فَقَالَ لاَ يَزَالُ النَّاسُ مُخْتَلِفَةً أَعْنَاقُهُمْ فِي طَلَبِ الدُّنْيَا ‏.‏ قُلْتُ أَجَلْ ‏.‏ قَالَ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يُوشِكُ الْفُرَاتُ أَنْ يَحْسِرَ عَنْ جَبَلٍ مِنْ ذَهَبٍ فَإِذَا سَمِعَ بِهِ النَّاسُ سَارُوا إِلَيْهِ فَيَقُولُ مَنْ عِنْدَهُ لَئِنْ تَرَكْنَا النَّاسَ يَأْخُذُونَ مِنْهُ لَيُذْهَبَنَّ بِهِ كُلِّهِ قَالَ فَيَقْتَتِلُونَ عَلَيْهِ فَيُقْتَلُ مِنْ كُلِّ مِائَةٍ تِسْعَةٌ وَتِسْعُونَ ‏"‏ ‏.‏ قَالَ أَبُو كَامِلٍ فِي حَدِيثِهِ قَالَ وَقَفْتُ أَنَا وَأُبَىُّ بْنُ كَعْبٍ فِي ظِلِّ أُجُمِ حَسَّانَ ‏.‏\hadithno{7276}\hadithtrans{Abdullah b. Harith b. Naufal reported:I was standing along with Ubayy b. Ka`b and he said: The opinions of the people differ in regard to the achievement of worldly ends. I said: Yes, of course. Thereupon he said: I heard Allah's Messenger (ﷺ) as saying: The Euphrates would soon uncover a mountain of gold and when the people would bear of it they would flock towards it but the people who would possess that (treasure) (would say): If we allow these persons to take out of it they would take away the whole of it. So they would fight and ninety-nine out of one hundred would be killed. Abu Kamil in his narration said: I and Ubayy b. Ka`b stood under the shade of the battlement of Hassan}}
\hadithdefcmd{muslim}{7277}{حَدَّثَنَا عُبَيْدُ بْنُ يَعِيشَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِعُبَيْدٍ - قَالاَ حَدَّثَنَا يَحْيَى، بْنُ آدَمَ بْنِ سُلَيْمَانَ مَوْلَى خَالِدِ بْنِ خَالِدٍ حَدَّثَنَا زُهَيْرٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنَعَتِ الْعِرَاقُ دِرْهَمَهَا وَقَفِيزَهَا وَمَنَعَتِ الشَّأْمُ مُدْيَهَا وَدِينَارَهَا وَمَنَعَتْ مِصْرُ إِرْدَبَّهَا وَدِينَارَهَا وَعُدْتُمْ مِنْ حَيْثُ بَدَأْتُمْ وَعُدْتُمْ مِنْ حَيْثُ بَدَأْتُمْ وَعُدْتُمْ مِنْ حَيْثُ بَدَأْتُمْ ‏"‏ ‏.‏ شَهِدَ عَلَى ذَلِكَ لَحْمُ أَبِي هُرَيْرَةَ وَدَمُهُ ‏.‏\hadithno{7277}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Iraq would withhold its dirhams and qafiz; Syria would withhold its mudd and dinar and Egypt would withhold its irdab and dinar and you would recoil to that position from where you started and you would recoil to that position from where you started and you would recoil to that position from where you started, the flesh and blood of Abu Huraira would bear testimony to it}}
\hadithdefcmd{muslim}{7278}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا مُعَلَّى بْنُ مَنْصُورٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، حَدَّثَنَا سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَنْزِلَ الرُّومُ بِالأَعْمَاقِ أَوْ بِدَابِقَ فَيَخْرُجُ إِلَيْهِمْ جَيْشٌ مِنَ الْمَدِينَةِ مِنْ خِيَارِ أَهْلِ الأَرْضِ يَوْمَئِذٍ فَإِذَا تَصَافُّوا قَالَتِ الرُّومُ خَلُّوا بَيْنَنَا وَبَيْنَ الَّذِينَ سَبَوْا مِنَّا نُقَاتِلْهُمْ ‏.‏ فَيَقُولُ الْمُسْلِمُونَ لاَ وَاللَّهِ لاَ نُخَلِّي بَيْنَكُمْ وَبَيْنَ إِخْوَانِنَا ‏.‏ فَيُقَاتِلُونَهُمْ فَيَنْهَزِمُ ثُلُثٌ لاَ يَتُوبُ اللَّهُ عَلَيْهِمْ أَبَدًا وَيُقْتَلُ ثُلُثُهُمْ أَفْضَلُ الشُّهَدَاءِ عِنْدَ اللَّهِ وَيَفْتَتِحُ الثُّلُثُ لاَ يُفْتَنُونَ أَبَدًا فَيَفْتَتِحُونَ قُسْطُنْطِينِيَّةَ فَبَيْنَمَا هُمْ يَقْتَسِمُونَ الْغَنَائِمَ قَدْ عَلَّقُوا سُيُوفَهُمْ بِالزَّيْتُونِ إِذْ صَاحَ فِيهِمُ الشَّيْطَانُ إِنَّ الْمَسِيحَ قَدْ خَلَفَكُمْ فِي أَهْلِيكُمْ ‏.‏ فَيَخْرُجُونَ وَذَلِكَ بَاطِلٌ فَإِذَا جَاءُوا الشَّأْمَ خَرَجَ فَبَيْنَمَا هُمْ يُعِدُّونَ لِلْقِتَالِ يُسَوُّونَ الصُّفُوفَ إِذْ أُقِيمَتِ الصَّلاَةُ فَيَنْزِلُ عِيسَى ابْنُ مَرْيَمَ فَأَمَّهُمْ فَإِذَا رَآهُ عَدُوُّ اللَّهِ ذَابَ كَمَا يَذُوبُ الْمِلْحُ فِي الْمَاءِ فَلَوْ تَرَكَهُ لاَنْذَابَ حَتَّى يَهْلِكَ وَلَكِنْ يَقْتُلُهُ اللَّهُ بِيَدِهِ فَيُرِيهِمْ دَمَهُ فِي حَرْبَتِهِ ‏"‏ ‏.‏\hadithno{7278}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The Last Hour would not come until the Romans would land at al-A'maq or in Dabiq. An army consisting of the best (soldiers) of the people of the earth at that time will come from Medina (to counteract them). When they will arrange themselves in ranks, the Romans would say: Do not stand between us and those (Muslims) who took prisoners from amongst us. Let us fight with them; and the Muslims would say: Nay, by Allah, we would never get aside from you and from our brethren that you may fight them. They will then fight and a third (part) of the army would run away, whom Allah will never forgive. A third (part of the army) which would be constituted of excellent martyrs in Allah's eye, would be killed and the third who would never be put to trial would win and they would be conquerors of Constantinople. And as they would be busy in distributing the spoils of war (amongst themselves) after hanging their swords by the olive trees, the Satan would cry: The Dajjal has taken your place among your family. They would then come out, but it would be of no avail. And when they would come to Syria, he would come out while they would be still preparing themselves for battle drawing up the ranks. Certainly, the time of prayer shall come and then Jesus (peace be upon him) son of Mary would descend and would lead them. When the enemy of Allah would see him, it would (disappear) just as the salt dissolves itself in water and if he (Jesus) were not to confront them at all, even then it would dissolve completely, but Allah would kill them by his hand and he would show them their blood on his lance (the lance of Jesus Christ)}}
\hadithdefcmd{muslim}{7279}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي اللَّيْثُ، بْنُ سَعْدٍ حَدَّثَنِي مُوسَى بْنُ عُلَىٍّ، عَنْ أَبِيهِ، قَالَ قَالَ الْمُسْتَوْرِدُ الْقُرَشِيُّ عِنْدَ عَمْرِو بْنِ الْعَاصِ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تَقُومُ السَّاعَةُ وَالرُّومُ أَكْثَرُ النَّاسِ ‏"‏ ‏.‏ فَقَالَ لَهُ عَمْرٌو أَبْصِرْ مَا تَقُولُ ‏.‏ قَالَ أَقُولُ مَا سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ لَئِنْ قُلْتَ ذَلِكَ إِنَّ فِيهِمْ لَخِصَالاً أَرْبَعًا إِنَّهُمْ لأَحْلَمُ النَّاسِ عِنْدَ فِتْنَةٍ وَأَسْرَعُهُمْ إِفَاقَةً بَعْدَ مُصِيبَةٍ وَأَوْشَكُهُمْ كَرَّةً بَعْدَ فَرَّةٍ وَخَيْرُهُمْ لِمِسْكِينٍ وَيَتِيمٍ وَضَعِيفٍ وَخَامِسَةٌ حَسَنَةٌ جَمِيلَةٌ وَأَمْنَعُهُمْ مِنْ ظُلْمِ الْمُلُوكِ ‏.‏\hadithno{7279}\hadithtrans{Mustaurid al-Qurashi reported:I heard Allah's Messenger (ﷺ) as saying: The Last Hour would come (when) the Romans would form a majority amongst people. 'Amr said to him (Mustaurid Qurashi): See what you are saying? He said: I say what I heard from Allah's Messenger (ﷺ). Thereupon he said: If you say that, it is a fact for they have four qualities. They have the patience to undergo a trial and immediately restore themselves to sanity after trouble and attack again after flight. They (have the quality) of being good to the destitute and the orphans, to the weak and, fifthly, the good quality in them is that they put resistance against the oppression of kings}}
\hadithdefcmd{muslim}{7280}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي أَبُو شُرَيْحٍ، أَنَّ عَبْدَ الْكَرِيمِ بْنَ الْحَارِثِ، حَدَّثَهُ أَنَّ الْمُسْتَوْرِدَ الْقُرَشِيَّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تَقُومُ السَّاعَةُ وَالرُّومُ أَكْثَرُ النَّاسِ ‏"‏ ‏.‏ قَالَ فَبَلَغَ ذَلِكَ عَمْرَو بْنَ الْعَاصِ فَقَالَ مَا هَذِهِ الأَحَادِيثُ الَّتِي تُذْكَرُ عَنْكَ أَنَّكَ تَقُولُهَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ الْمُسْتَوْرِدُ قُلْتُ الَّذِي سَمِعْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَقَالَ عَمْرٌو لَئِنْ قُلْتَ ذَلِكَ إِنَّهُمْ لأَحْلَمُ النَّاسِ عِنْدَ فِتْنَةٍ وَأَجْبَرُ النَّاسِ عِنْدَ مُصِيبَةٍ وَخَيْرُ النَّاسِ لِمَسَاكِينِهِمْ وَضُعَفَائِهِمْ ‏.‏\hadithno{7280}\hadithtrans{Mustaurid Qurashi reported:I heard Allah's Messenger (ﷺ) as saying: The Last Hour would come when the Romans would form a majority amongst people. This reached 'Amr b. al-'As and he said: What are these ahadith which are being transmitted from you and which you claim to have heard from Allah's Messenger (ﷺ)? Mustaurid said to him: I stated only that which I heard from Allah's Messenger (ﷺ). Thereupon 'Amr said: If you state this (it is true), for they have the power of tolerance amongst people at the time of turmoil and restore themselves to sanity after trouble, and are good amongst people so far as the destitute and the weak are concerned}}
\hadithdefcmd{muslim}{7281}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ حُجْرٍ، كِلاَهُمَا عَنِ ابْنِ عُلَيَّةَ، - وَاللَّفْظُ لاِبْنِ حُجْرٍ - حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ أَيُّوبَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَبِي قَتَادَةَ، الْعَدَوِيِّ عَنْ يُسَيْرِ بْنِ جَابِرٍ، قَالَ هَاجَتْ رِيحٌ حَمْرَاءُ بِالْكُوفَةِ فَجَاءَ رَجُلٌ لَيْسَ لَهُ هِجِّيرَى إِلاَّ يَا عَبْدَ اللَّهِ بْنَ مَسْعُودٍ جَاءَتِ السَّاعَةُ ‏.‏ قَالَ فَقَعَدَ وَكَانَ مُتَّكِئًا فَقَالَ إِنَّ السَّاعَةَ لاَ تَقُومُ حَتَّى لاَ يُقْسَمَ مِيرَاثٌ وَلاَ يُفْرَحَ بِغَنِيمَةٍ ‏.‏ ثُمَّ قَالَ بِيَدِهِ هَكَذَا - وَنَحَّاهَا نَحْوَ الشَّأْمِ - فَقَالَ عَدُوٌّ يَجْمَعُونَ لأَهْلِ الإِسْلاَمِ وَيَجْمَعُ لَهُمْ أَهْلُ الإِسْلاَمِ ‏.‏ قُلْتُ الرُّومَ تَعْنِي قَالَ نَعَمْ وَتَكُونُ عِنْدَ ذَاكُمُ الْقِتَالِ رَدَّةٌ شَدِيدَةٌ فَيَشْتَرِطُ الْمُسْلِمُونَ شُرْطَةً لِلْمَوْتِ لاَ تَرْجِعُ إِلاَّ غَالِبَةً فَيَقْتَتِلُونَ حَتَّى يَحْجُزَ بَيْنَهُمُ اللَّيْلُ فَيَفِيءُ هَؤُلاَءِ وَهَؤُلاَءِ كُلٌّ غَيْرُ غَالِبٍ وَتَفْنَى الشُّرْطَةُ ثُمَّ يَشْتَرِطُ الْمُسْلِمُونَ شُرْطَةً لِلْمَوْتِ لاَ تَرْجِعُ إِلاَّ غَالِبَةً فَيَقْتَتِلُونَ حَتَّى يَحْجُزَ بَيْنَهُمُ اللَّيْلُ فَيَفِيءُ هَؤُلاَءِ وَهَؤُلاَءِ كُلٌّ غَيْرُ غَالِبٍ وَتَفْنَى الشُّرْطَةُ ثُمَّ يَشْتَرِطُ الْمُسْلِمُونَ شُرْطَةً لِلْمَوْتِ لاَ تَرْجِعُ إِلاَّ غَالِبَةً فَيَقْتَتِلُونَ حَتَّى يُمْسُوا فَيَفِيءُ هَؤُلاَءِ وَهَؤُلاَءِ كُلٌّ غَيْرُ غَالِبٍ وَتَفْنَى الشُّرْطَةُ فَإِذَا كَانَ يَوْمُ الرَّابِعِ نَهَدَ إِلَيْهِمْ بَقِيَّةُ أَهْلِ الإِسْلاَمِ فَيَجْعَلُ اللَّهُ الدَّبْرَةَ عَلَيْهِمْ فَيَقْتُلُونَ مَقْتَلَةً - إِمَّا قَالَ لاَ يُرَى مِثْلُهَا وَإِمَّا قَالَ لَمْ يُرَ مِثْلُهَا - حَتَّى إِنَّ الطَّائِرَ لَيَمُرُّ بِجَنَبَاتِهِمْ فَمَا يُخَلِّفُهُمْ حَتَّى يَخِرَّ مَيْتًا فَيَتَعَادُّ بَنُو الأَبِ كَانُوا مِائَةً فَلاَ يَجِدُونَهُ بَقِيَ مِنْهُمْ إِلاَّ الرَّجُلُ الْوَاحِدُ فَبِأَىِّ غَنِيمَةٍ يُفْرَحُ أَوْ أَىُّ مِيرَاثٍ يُقَاسَمُ فَبَيْنَمَا هُمْ كَذَلِكَ إِذْ سَمِعُوا بِبَأْسٍ هُوَ أَكْبَرُ مِنْ ذَلِكَ فَجَاءَهُمُ الصَّرِيخُ إِنَّ الدَّجَّالَ قَدْ خَلَفَهُمْ فِي ذَرَارِيِّهِمْ فَيَرْفُضُونَ مَا فِي أَيْدِيهِمْ وَيُقْبِلُونَ فَيَبْعَثُونَ عَشَرَةَ فَوَارِسَ طَلِيعَةً ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنِّي لأَعْرِفُ أَسْمَاءَهُمْ وَأَسْمَاءَ آبَائِهِمْ وَأَلْوَانَ خُيُولِهِمْ هُمْ خَيْرُ فَوَارِسَ عَلَى ظَهْرِ الأَرْضِ يَوْمَئِذٍ أَوْ مِنْ خَيْرِ فَوَارِسَ عَلَى ظَهْرِ الأَرْضِ يَوْمَئِذٍ ‏"‏ ‏.‏ قَالَ ابْنُ أَبِي شَيْبَةَ فِي رِوَايَتِهِ عَنْ أُسَيْرِ بْنِ جَابِرٍ ‏.‏\hadithno{7281}\hadithtrans{Yusair b. Jabir reported:Once there blew a red storm in Kufah that there came a person who had nothing to say but (these words): `Abdullah b. Mas`ud, the Last Hour has come. He (`Abdullah b. Mas`ud) was sitting reclining against something, and he said: The Last Hour would not come until shares of inheritance are not distributed and there is no rejoicing over spoils of war. Then he said pointing towards Syria, with the gesture of his hand like this: The enemy shall muster strength against Muslims and the Muslims will muster strength against them (Syrians). I said: You mean Rome? And he said: Yes, and there would be a terrible fight and the Muslims would prepare a detachment (for fighting unto death) which would not return but victorious. They will fight until night will intervene them; both the sides will return without being victorious and both will be wiped out. The Muslims will again prepare a detachment for fighting unto death so that they may not return but victorious. When it would be the fourth day, a new detachment out of the remnant of the Muslims would be prepared and Allah will decree that the enemy should be routed. And they would fight such a fight the like of which would not be seen, so much so that even if a bird were to pass their flanks, it would fall down dead before reaching the end of them. (There would be such a large scale massacre) that when counting would be done, (only) one out of a hundred men related to one another would be found alive. So what can be the joy at the spoils of such war and what inheritance would be divided! They would be in this very state that they would hear of a calamity more horrible than this. And a cry would reach them: The Dajjal has taken your place among your offspring. They will, therefore, throw away what would be in their hands and go forward sending ten horsemen, as a scouting party. Allah's Messenger (ﷺ) said: I know their names and the names of their forefathers and the color of their horses. They will be the best horsemen on the surface of the earth on that day or amongst the best horsemen on the surface of the earth on that day}}
\hadithdefcmd{muslim}{7282}{وَحَدَّثَنِي مُحَمَّدُ بْنُ عُبَيْدٍ الْغُبَرِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ حُمَيْدِ بْنِ، هِلاَلٍ عَنْ أَبِي قَتَادَةَ، عَنْ يُسَيْرِ بْنِ جَابِرٍ، قَالَ كُنْتُ عِنْدَ ابْنِ مَسْعُودٍ فَهَبَّتْ رِيحٌ حَمْرَاءُ ‏.‏ وَسَاقَ الْحَدِيثَ بِنَحْوِهِ ‏.‏ وَحَدِيثُ ابْنُ عُلَيَّةَ أَتَمُّ وَأَشْبَعُ ‏.‏\hadithno{7282}\hadithtrans{Jabir reported:I was in the company of Ibn Mas'ud that there blew a red storm. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{7283}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ الْمُغِيرَةِ - حَدَّثَنَا حُمَيْدٌ، - يَعْنِي ابْنَ هِلاَلٍ - عَنْ أَبِي قَتَادَةَ، عَنْ أُسَيْرِ بْنِ جَابِرٍ، قَالَ كُنْتُ فِي بَيْتِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَالْبَيْتُ مَلآنُ - قَالَ - فَهَاجَتْ رِيحٌ حَمْرَاءُ بِالْكُوفَةِ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ ابْنِ عُلَيَّةَ ‏.‏\hadithno{7283}\hadithtrans{Jabir reported:I was in the house of 'Abdullah b. Mas'ud and the house was fully packed that a red storm blew in Kufah}}
\hadithdefcmd{muslim}{7284}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، عَنْ نَافِعِ بْنِ عُتْبَةَ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةٍ - قَالَ - فَأَتَى النَّبِيَّ صلى الله عليه وسلم قَوْمٌ مِنْ قِبَلِ الْمَغْرِبِ عَلَيْهِمْ ثِيَابُ الصُّوفِ فَوَافَقُوهُ عِنْدَ أَكَمَةٍ فَإِنَّهُمْ لَقِيَامٌ وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَاعِدٌ - قَالَ - فَقَالَتْ لِي نَفْسِي ائْتِهِمْ فَقُمْ بَيْنَهُمْ وَبَيْنَهُ لاَ يَغْتَالُونَهُ - قَالَ - ثُمَّ قُلْتُ لَعَلَّهُ نَجِيٌّ مَعَهُمْ ‏.‏ فَأَتَيْتُهُمْ فَقُمْتُ بَيْنَهُمْ وَبَيْنَهُ - قَالَ - فَحَفِظْتُ مِنْهُ أَرْبَعَ كَلِمَاتٍ أَعُدُّهُنَّ فِي يَدِي قَالَ ‏ "‏ تَغْزُونَ جَزِيرَةَ الْعَرَبِ فَيَفْتَحُهَا اللَّهُ ثُمَّ فَارِسَ فَيَفْتَحُهَا اللَّهُ ثُمَّ تَغْزُونَ الرُّومَ فَيَفْتَحُهَا اللَّهُ ثُمَّ تَغْزُونَ الدَّجَّالَ فَيَفْتَحُهُ اللَّهُ ‏"‏ ‏.‏ قَالَ فَقَالَ نَافِعٌ يَا جَابِرُ لاَ نَرَى الدَّجَّالَ يَخْرُجُ حَتَّى تُفْتَحَ الرُّومُ ‏.‏\hadithno{7284}\hadithtrans{Nafi' b. Utba reported:We were with Allah's Messenger (ﷺ) in an expedition that there came a people to Allah's Apostle (ﷺ) from the direction of the west. They were dressed in woollen clothes and they stood near a hillock and they met him as Allah's Messenger (ﷺ) was sitting. I said to myself: Better go to them and stand between him and them that they may not attack him. Then I thought that perhaps there had been going on secret negotiation amongst them. I however, went to them and stood between them and him and I remember four of the words (on that occasion) which I repeat (on the fingers of my hand) that he (Allah's Messenger) said: You will attack Arabia and Allah will enable you to conquer it, then you would attack Persia and He would make you to conquer it. Then you would attack Rome and Allah will enable you to conquer it, then you would attack the Dajjal and Allah will enable you to conquer him. Nafi' said: Jabir, we thought that the Dajjal would appear after Rome (Syrian territory) would be conquered}}
\hadithdefcmd{muslim}{7285}{حَدَّثَنَا أَبُو خَيْثَمَةَ، زُهَيْرُ بْنُ حَرْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ وَابْنُ أَبِي عُمَرَ الْمَكِّيُّ - وَاللَّفْظُ لِزُهَيْرٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ فُرَاتٍ، الْقَزَّازِ عَنْ أَبِي الطُّفَيْلِ، عَنْ حُذَيْفَةَ بْنِ أَسِيدٍ الْغِفَارِيِّ، قَالَ اطَّلَعَ النَّبِيُّ صلى الله عليه وسلم عَلَيْنَا وَنَحْنُ نَتَذَاكَرُ فَقَالَ ‏"‏ مَا تَذَاكَرُونَ ‏"‏ ‏.‏ قَالُوا نَذْكُرُ السَّاعَةَ ‏.‏ قَالَ ‏"‏ إِنَّهَا لَنْ تَقُومَ حَتَّى تَرَوْنَ قَبْلَهَا عَشْرَ آيَاتٍ ‏"‏ ‏.‏ فَذَكَرَ الدُّخَانَ وَالدَّجَّالَ وَالدَّابَّةَ وَطُلُوعَ الشَّمْسِ مِنْ مَغْرِبِهَا وَنُزُولَ عِيسَى ابْنِ مَرْيَمَ صلى الله عليه وسلم وَيَأْجُوجَ وَمَأْجُوجَ وَثَلاَثَةَ خُسُوفٍ خَسْفٌ بِالْمَشْرِقِ وَخَسْفٌ بِالْمَغْرِبِ وَخَسْفٌ بِجَزِيرَةِ الْعَرَبِ وَآخِرُ ذَلِكَ نَارٌ تَخْرُجُ مِنَ الْيَمَنِ تَطْرُدُ النَّاسَ إِلَى مَحْشَرِهِمْ ‏.‏\hadithno{7285}\hadithtrans{Hudhaifa b. Usaid al-Ghifari reported:Allah's Messenger (ﷺ) came to us all of a sudden as we were (busy in a discussion). He said: What do you discuss about? They (the Companions) said. We are discussing about the Last Hour. Thereupon he said: It will not come until you see ten signs before and (in this connection) he made a mention of the smoke, Dajjal, the beast, the rising of the sun from the west, the descent of Jesus son of Mary (Allah be pleased with him), the Gog and Magog, and land-slides in three places, one in the east, one in the west and one in Arabia at the end of which fire would burn forth from the Yemen, and would drive people to the place of their assembly}}
\hadithdefcmd{muslim}{7286}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ فُرَاتٍ الْقَزَّازِ، عَنْ أَبِي الطُّفَيْلِ، عَنْ أَبِي سَرِيحَةَ، حُذَيْفَةَ بْنِ أَسِيدٍ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم فِي غُرْفَةٍ وَنَحْنُ أَسْفَلَ مِنْهُ فَاطَّلَعَ إِلَيْنَا فَقَالَ ‏"‏ مَا تَذْكُرُونَ ‏"‏ ‏.‏ قُلْنَا السَّاعَةَ ‏.‏ قَالَ ‏"‏ إِنَّ السَّاعَةَ لاَ تَكُونُ حَتَّى تَكُونَ عَشْرُ آيَاتٍ خَسْفٌ بِالْمَشْرِقِ وَخَسْفٌ بِالْمَغْرِبِ وَخَسْفٌ فِي جَزِيرَةِ الْعَرَبِ وَالدُّخَانُ وَالدَّجَّالُ وَدَابَّةُ الأَرْضِ وَيَأْجُوجُ وَمَأْجُوجُ وَطُلُوعُ الشَّمْسِ مِنْ مَغْرِبِهَا وَنَارٌ تَخْرُجُ مِنْ قُعْرَةِ عَدَنٍ تَرْحَلُ النَّاسَ ‏"‏ ‏.‏ قَالَ شُعْبَةُ وَحَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ رُفَيْعٍ عَنْ أَبِي الطُّفَيْلِ عَنْ أَبِي سَرِيحَةَ ‏.‏ مِثْلَ ذَلِكَ لاَ يَذْكُرُ النَّبِيَّ صلى الله عليه وسلم وَقَالَ أَحَدُهُمَا فِي الْعَاشِرَةِ نُزُولُ عِيسَى ابْنِ مَرْيَمَ صلى الله عليه وسلم ‏.‏ وَقَالَ الآخَرُ وَرِيحٌ تُلْقِي النَّاسَ فِي الْبَحْرِ ‏.‏\hadithno{7286}\hadithtrans{Hudhaifa b. Usaid reported:Allah's Apostle (ﷺ) was in an apartment and we were beneath that, that he peeped in and said to us: What are you discussing about? We said: (We are discussing about the Last) Hour. Thereupon he said: The Last Hour would not come until the ten signs appear: land-sliding in the east, and land-sliding in the west, and land-sliding in the peninsula of Arabia, the smoke, the Dajjal, the beast of the earth, Gog and Magog, the rising of the sun from the west and the fire which would emit from the lower part of 'Adan. Shu'ba said that 'Abd al-'Aziz b. Rufai' reported on the authority of Abu Tufail who reported on the authority of Abu Sariha a hadith like this that Allah's Apostle (ﷺ) did not make a mention of (the tenth sign) but he said that out of the ten one was the descent of Jesus, son of Mary (peace be upon him), and in another version it is the blowing of the violent gale which would drive the people to the ocean}}
\hadithdefcmd{muslim}{7287}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - حَدَّثَنَا شُعْبَةُ، عَنْ فُرَاتٍ، قَالَ سَمِعْتُ أَبَا الطُّفَيْلِ، يُحَدِّثُ عَنْ أَبِي سَرِيحَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي غُرْفَةٍ وَنَحْنُ تَحْتَهَا نَتَحَدَّثُ ‏.‏ وَسَاقَ الْحَدِيثَ بِمِثْلِهِ ‏.‏ قَالَ شُعْبَةُ وَأَحْسِبُهُ قَالَ تَنْزِلُ مَعَهُمْ إِذَا نَزَلُوا وَتَقِيلُ مَعَهُمْ حَيْثُ قَالُوا ‏.‏ قَالَ شُعْبَةُ وَحَدَّثَنِي رَجُلٌ هَذَا الْحَدِيثَ عَنْ أَبِي الطُّفَيْلِ عَنْ أَبِي سَرِيحَةَ وَلَمْ يَرْفَعْهُ قَالَ أَحَدُ هَذَيْنِ الرَّجُلَيْنِ نُزُولُ عِيسَى ابْنِ مَرْيَمَ وَقَالَ الآخَرُ رِيحٌ تُلْقِيهِمْ فِي الْبَحْرِ ‏.‏\hadithno{7287}\hadithtrans{Abu Sariha reported:Allah's Messenger (ﷺ) was in an (upper) apartment and we were standing lower to him and discussing (about the Last Hour). The rest of the hadith is the same, and Shu'ba said: I think he also said these words: The fire would descend along with them where they would land and where they would take rest (during midday (it would also cool down for a while). Shu'ba said: This hadith has been transmitted to me through Abu Tufail and Abu Sariha and none could trace it back directly to Allah's Apostle (ﷺ). However, there is a mention of the descent of Jesus Christ son of Mary in one version and in the other there is a mention of the blowing of a violent gale which would drive them to the ocean}}
\hadithdefcmd{muslim}{7288}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو النُّعْمَانِ الْحَكَمُ بْنُ عَبْدِ اللَّهِ الْعِجْلِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ فُرَاتٍ، قَالَ سَمِعْتُ أَبَا الطُّفَيْلِ، يُحَدِّثُ عَنْ أَبِي سَرِيحَةَ، قَالَ كُنَّا نَتَحَدَّثُ فَأَشْرَفَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِنَحْوِ حَدِيثِ مُعَاذٍ وَابْنِ جَعْفَرٍ ‏.‏ وَقَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا أَبُو النُّعْمَانِ الْحَكَمُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ، الْعَزِيزِ بْنِ رُفَيْعٍ عَنْ أَبِي الطُّفَيْلِ، عَنْ أَبِي سَرِيحَةَ، بِنَحْوِهِ قَالَ وَالْعَاشِرَةُ نُزُولُ عِيسَى ابْنِ مَرْيَمَ ‏.‏ قَالَ شُعْبَةُ وَلَمْ يَرْفَعْهُ عَبْدُ الْعَزِيزِ ‏.‏\hadithno{7288}\hadithtrans{Another chain of transmitters reports the like of the previous two chains. Abu Sariha reported:We were discussing (the Last Hour) that Allah's Apostle (ﷺ) looked towards us. The rest of the hadith is the same and the tenth (sign) was the descent of Jesus Christ son of Mary, and Shu'ba said: 'Abd al-'Aziz did not trace it directly to Allah's Apostle (ﷺ)}}
\hadithdefcmd{muslim}{7289}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي ابْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ح وَحَدَّثَنِي عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنَا أَبِي، عَنْ جَدِّي، حَدَّثَنِي عُقَيْلُ بْنُ، خَالِدٍ عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ قَالَ ابْنُ الْمُسَيَّبِ أَخْبَرَنِي أَبُو هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَخْرُجَ نَارٌ مِنْ أَرْضِ الْحِجَازِ تُضِيءُ أَعْنَاقَ الإِبِلِ بِبُصْرَى ‏"‏ ‏.‏\hadithno{7289}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said:The Last Hour would not come until fire emits from the earth of Hijaz which would illuminate the necks of the camels of the Busra}}
\hadithdefcmd{muslim}{7290}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا الأَسْوَدُ بْنُ عَامِرٍ، حَدَّثَنَا زُهَيْرٌ، عَنْ سُهَيْلِ بْنِ أَبِي، صَالِحٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَبْلُغُ الْمَسَاكِنُ إِهَابَ أَوْ يَهَابَ ‏"‏ ‏.‏ قَالَ زُهَيْرٌ قُلْتُ لِسُهَيْلٍ فَكَمْ ذَلِكَ مِنَ الْمَدِينَةِ قَالَ كَذَا وَكَذَا مِيلاً ‏.‏\hadithno{7290}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said:(The Last Hour would not come) until the habitations of Medina would extend to Ihab or Yahab. Zubair said: I said to Suhail how far these were from Medina. He said: So and so miles}}
\hadithdefcmd{muslim}{7291}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَتِ السَّنَةُ بِأَنْ لاَ تُمْطَرُوا وَلَكِنِ السَّنَةُ أَنْ تُمْطَرُوا وَتُمْطَرُوا وَلاَ تُنْبِتُ الأَرْضُ شَيْئًا ‏"‏ ‏.‏\hadithno{7291}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The famine would not break out because of drought, but there would be famine despite heavy rainfall as nothing would grow from the earth}}
\hadithdefcmd{muslim}{7292}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ مُسْتَقْبِلُ الْمَشْرِقِ يَقُولُ ‏ "‏ أَلاَ إِنَّ الْفِتْنَةَ هَا هُنَا أَلاَ إِنَّ الْفِتْنَةَ هَا هُنَا مِنْ حَيْثُ يَطْلُعُ قَرْنُ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{7292}\hadithtrans{Ibn 'Umar reported that he heard Allah's Messenger (ﷺ) as saying (in a state) that he had turned his face towards the east:Behold, turmoil would appear from this side, from where the horns of Satan would appear}}
\hadithdefcmd{muslim}{7293}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ، سَعِيدٍ كُلُّهُمْ عَنْ يَحْيَى الْقَطَّانِ، قَالَ الْقَوَارِيرِيُّ حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ، عُمَرَ حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ عِنْدَ بَابِ حَفْصَةَ فَقَالَ بِيَدِهِ نَحْوَ الْمَشْرِقِ ‏ "‏ الْفِتْنَةُ هَا هُنَا مِنْ حَيْثُ يَطْلُعُ قَرْنُ الشَّيْطَانِ ‏"‏ ‏.‏ قَالَهَا مَرَّتَيْنِ أَوْ ثَلاَثًا ‏.‏ وَقَالَ عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ فِي رِوَايَتِهِ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَ بَابِ عَائِشَةَ ‏.‏\hadithno{7293}\hadithtrans{Ibn `Umar reported that Allah's Messenger (ﷺ) stood by the door (of the apartment of) Hafsa and, pointing towards the east, he said:The turmoil would appear from this side, viz. where the horns of Satan would appear, and he uttered these words twice or thrice and `Ubaidullah b. Sa`id in his narration said: The Messenger of Allah (ﷺ) had been standing by the door of `A'isha}}
\hadithdefcmd{muslim}{7294}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ وَهُوَ مُسْتَقْبِلُ الْمَشْرِقِ ‏ "‏ هَا إِنَّ الْفِتْنَةَ هَا هُنَا هَا إِنَّ الْفِتْنَةَ هَا هُنَا هَا إِنَّ الْفِتْنَةَ هَا هُنَا مِنْ حَيْثُ يَطْلُعُ قَرْنُ الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{7294}\hadithtrans{Salim b. Abdullah reported on the authority of his father that Allah's Messenger (ﷺ), while turning his face towards the east, said:The turmoil would appear from this side; verily, the turmoil would appear from this side; verily, the turmoil would appear from this side - the side where appear the horns of Satan}}
\hadithdefcmd{muslim}{7295}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ بَيْتِ عَائِشَةَ فَقَالَ ‏ "‏ رَأْسُ الْكُفْرِ مِنْ هَا هُنَا مِنْ حَيْثُ يَطْلُعُ قَرْنُ الشَّيْطَانِ ‏"‏ ‏.‏ يَعْنِي الْمَشْرِقَ ‏.‏\hadithno{7295}\hadithtrans{Ibn Umar reported that Allah's Messenger (ﷺ) came out from the house of 'Aisha and said:It would be from this side that there would appear the height of unbelief, viz. where appear the horns of Satan, i.e. the east}}
\hadithdefcmd{muslim}{7296}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا إِسْحَاقُ، - يَعْنِي ابْنَ سُلَيْمَانَ - أَخْبَرَنَا حَنْظَلَةُ، قَالَ سَمِعْتُ سَالِمًا، يَقُولُ سَمِعْتُ ابْنَ عُمَرَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُشِيرُ بِيَدِهِ نَحْوَ الْمَشْرِقِ وَيَقُولُ ‏"‏ هَا إِنَّ الْفِتْنَةَ هَا هُنَا هَا إِنَّ الْفِتْنَةَ هَا هُنَا ‏"‏ ‏.‏ ثَلاَثًا ‏"‏ حَيْثُ يَطْلُعُ قَرْنَا الشَّيْطَانِ ‏"‏ ‏.‏\hadithno{7296}\hadithtrans{Ibn Umar reported:I heard Allah's Messenger (ﷺ) as saying while pointing his hands towards the east: The turmoil would appear from this side; verily, the turmoil would appear from this side (he repeated it thrice) where appear the horns of Satan}}
\hadithdefcmd{muslim}{7297}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ بْنِ أَبَانَ، وَوَاصِلُ بْنُ عَبْدِ الأَعْلَى، وَأَحْمَدُ بْنُ عُمَرَ الْوَكِيعِيُّ، - وَاللَّفْظُ لاِبْنِ أَبَانَ - قَالُوا حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ سَالِمَ بْنَ عَبْدِ اللَّهِ، بْنِ عُمَرَ يَقُولُ يَا أَهْلَ الْعِرَاقِ مَا أَسْأَلَكُمْ عَنِ الصَّغِيرَةِ وَأَرْكَبَكُمْ لِلْكَبِيرَةِ سَمِعْتُ أَبِي عَبْدَ اللَّهِ بْنَ عُمَرَ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ الْفِتْنَةَ تَجِيءُ مِنْ هَا هُنَا ‏"‏ ‏.‏ وَأَوْمَأَ بِيَدِهِ نَحْوَ الْمَشْرِقِ ‏"‏ مِنْ حَيْثُ يَطْلُعُ قَرْنَا الشَّيْطَانِ ‏"‏ ‏.‏ وَأَنْتُمْ يَضْرِبُ بَعْضُكُمْ رِقَابَ بَعْضٍ وَإِنَّمَا قَتَلَ مُوسَى الَّذِي قَتَلَ مِنْ آلِ فِرْعَوْنَ خَطَأً فَقَالَ اللَّهُ عَزَّ وَجَلَّ لَهُ ‏\{‏ وَقَتَلْتَ نَفْسًا فَنَجَّيْنَاكَ مِنَ الْغَمِّ وَفَتَنَّاكَ فُتُونًا‏\}‏ قَالَ أَحْمَدُ بْنُ عُمَرَ فِي رِوَايَتِهِ عَنْ سَالِمٍ لَمْ يَقُلْ سَمِعْتُ ‏.‏\hadithno{7297}\hadithtrans{Ibn Fudail reported on the authority of his father that he heard Salim b. `Abdullah b. `Umar as saying:O people of Iraq, how strange it is that you ask about the minor sins but commit major sins? I heard from my father `Abdullah b. `Umar, narrating that he heard Allah's Messenger (ﷺ) as saying while pointing his hand towards the east: Verily, the turmoil would come from this side, from where appear the horns of Satan and you would strike the necks of one another; and Moses killed a person from among the people of Pharaoh unintentionally and Allah, the Exalted and Glorious, said: "You killed a person but We relieved you from the grief and tried you with (many a) trial" (xx. 40). Ahmad b. `Umar reported this hadith from Salim, but he did not make a mention of the words: "I heard}}
\hadithdefcmd{muslim}{7298}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَضْطَرِبَ أَلَيَاتُ نِسَاءِ دَوْسٍ حَوْلَ ذِي الْخَلَصَةِ ‏"‏ ‏.‏ وَكَانَتْ صَنَمًا تَعْبُدُهَا دَوْسٌ فِي الْجَاهِلِيَّةِ بِتَبَالَةَ ‏.‏\hadithno{7298}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The Last Hour would not come until the women of the tribe of Daus would be seen going round Dhi al-Khalasa (for worship) and Dhi al-Khalasa is a place in Tabala, where there was a temple in which the people of the tribe of Daus used to worship the idol}}
\hadithdefcmd{muslim}{7299}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، وَأَبُو مَعْنٍ زَيْدُ بْنُ يَزِيدَ الرَّقَاشِيُّ - وَاللَّفْظُ لأَبِي مَعْنٍ - قَالاَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، عَنِ الأَسْوَدِ بْنِ الْعَلاَءِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يَذْهَبُ اللَّيْلُ وَالنَّهَارُ حَتَّى تُعْبَدَ اللاَّتُ وَالْعُزَّى ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنْ كُنْتُ لأَظُنُّ حِينَ أَنْزَلَ اللَّهُ ‏\{‏ هُوَ الَّذِي أَرْسَلَ رَسُولَهُ بِالْهُدَى وَدِينِ الْحَقِّ لِيُظْهِرَهُ عَلَى الدِّينِ كُلِّهِ وَلَوْ كَرِهَ الْمُشْرِكُونَ‏\}‏ أَنَّ ذَلِكَ تَامًّا قَالَ ‏"‏ إِنَّهُ سَيَكُونُ مِنْ ذَلِكَ مَا شَاءَ اللَّهُ ثُمَّ يَبْعَثُ اللَّهُ رِيحًا طَيِّبَةً فَتَوَفَّى كُلَّ مَنْ فِي قَلْبِهِ مِثْقَالُ حَبَّةِ خَرْدَلٍ مِنْ إِيمَانٍ فَيَبْقَى مَنْ لاَ خَيْرَ فِيهِ فَيَرْجِعُونَ إِلَى دِينِ آبَائِهِمْ ‏"‏ ‏.‏\hadithno{7299}\hadithtrans{A'isha reported:I heard Allah's Messenger (ﷺ) as saying: The (system) of night and day would not end until the people have taken to the worship of Lat and 'Uzza. I said: Allah's Messenger, I think when Allah has revealed this verse:" He it is Who has sent His Messenger with right guidance, and true religion, so that He may cause it to prevail upon all religions, though the polytheists are averse (to it)" (ix. 33), it implies that (this promise) is going to be fulfilled. Thereupon he (Allah's Apostle) said: It would happen as Allah would like. Then Allah would send the sweet fragrant air by which everyone who has even a mustard grain of faith in Him would die and those only would survive who would have no goodness in them. And they would revert to the religion of their forefathers}}
\hadithdefcmd{muslim}{7300}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو بَكْرٍ، - وَهُوَ الْحَنَفِيُّ - حَدَّثَنَا عَبْدُ الْحَمِيدِ، بْنُ جَعْفَرٍ بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{7300}\hadithtrans{This hadith has been narrated on the authority of Ibn Ja'far with the same chain of transmitters}}
\hadithdefcmd{muslim}{7303}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا مَرْوَانُ، عَنْ يَزِيدَ، - وَهُوَ ابْنُ كَيْسَانَ - عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَيَأْتِيَنَّ عَلَى النَّاسِ زَمَانٌ لاَ يَدْرِي الْقَاتِلُ فِي أَىِّ شَىْءٍ قَتَلَ وَلاَ يَدْرِي الْمَقْتُولُ عَلَى أَىِّ شَىْءٍ قُتِلَ ‏"‏ ‏.‏\hadithno{7303}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:By Him in Whose Hand is my life, a time would come when the murderer would not know why he has committed the murder, and the victim would not know why he has been killed}}
\hadithdefcmd{muslim}{7304}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ بْنِ أَبَانَ، وَوَاصِلُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ فُضَيْلٍ عَنْ أَبِي إِسْمَاعِيلَ الأَسْلَمِيِّ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لاَ تَذْهَبُ الدُّنْيَا حَتَّى يَأْتِيَ عَلَى النَّاسِ يَوْمٌ لاَ يَدْرِي الْقَاتِلُ فِيمَ قَتَلَ وَلاَ الْمَقْتُولُ فِيمَ قُتِلَ ‏"‏ ‏.‏ فَقِيلَ كَيْفَ يَكُونُ ذَلِكَ قَالَ ‏"‏ الْهَرْجُ ‏.‏ الْقَاتِلُ وَالْمَقْتُولُ فِي النَّارِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ أَبَانَ قَالَ هُوَ يَزِيدُ بْنُ كَيْسَانَ عَنْ أَبِي إِسْمَاعِيلَ ‏.‏ لَمْ يَذْكُرِ الأَسْلَمِيَّ ‏.‏\hadithno{7304}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The world would not come to an end until a day would come to the people on which the murderer would not know as to why he has killed and the slain would not know as to why he has been murdered. It would be said: Why would It happen? To which he replied: It would be because of general massacre and bloodshed. And the slaughterers and the slain would be in Fire, and in the narration of Ibn Aban, the name of Abu Isma'il has been mentioned}}
\hadithdefcmd{muslim}{7305}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ زِيَادِ بْنِ سَعْدٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ يُخَرِّبُ الْكَعْبَةَ ذُو السُّوَيْقَتَيْنِ مِنَ الْحَبَشَةِ ‏"‏ ‏.‏\hadithno{7305}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The Ka'ba would be destroyed by an Abyssinian having two small shanks}}
\hadithdefcmd{muslim}{7306}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُخَرِّبُ الْكَعْبَةَ ذُو السُّوَيْقَتَيْنِ مِنَ الْحَبَشَةِ ‏"‏ ‏.‏\hadithno{7306}\hadithtrans{(The above mentioned) hadith has been narrated on the authority of Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{7307}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنْ ثَوْرِ بْنِ، زَيْدٍ عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ ذُو السُّوَيْقَتَيْنِ مِنَ الْحَبَشَةِ يُخَرِّبُ بَيْتَ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{7307}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:It would be an Abyssinian having two small shanks who would destroy the House ol Allah, the Exalted and Glorious}}
\hadithdefcmd{muslim}{7308}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، أَخْبَرَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ ثَوْرِ بْنِ، زَيْدٍ عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَخْرُجَ رَجُلٌ مِنْ قَحْطَانَ يَسُوقُ النَّاسَ بِعَصَاهُ ‏"‏ ‏.‏\hadithno{7308}\hadithtrans{Abu Huraira reported Allah's Messengar (ﷺ) as saying:The Last Hour would not come before a person of Qahtan comes forth driving people with his stick}}
\hadithdefcmd{muslim}{7309}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ الْعَبْدِيُّ، حَدَّثَنَا عَبْدُ الْكَبِيرِ بْنُ عَبْدِ الْمَجِيدِ أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْحَكَمِ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَذْهَبُ الأَيَّامُ وَاللَّيَالِي حَتَّى يَمْلِكَ رَجُلٌ يُقَالُ لَهُ الْجَهْجَاهُ ‏"‏ ‏.‏ قَالَ مُسْلِمٌ هُمْ أَرْبَعَةُ إِخْوَةٍ شَرِيكٌ وَعُبَيْدُ اللَّهِ وَعُمَيْرٌ وَعَبْدُ الْكَبِيرِ بَنُو عَبْدِ الْمَجِيدِ ‏.‏\hadithno{7309}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The day and the night would not come to an end before a man called al-Jahjah would occupy the throne}}
\hadithdefcmd{muslim}{7310}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لاِبْنِ أَبِي عُمَرَ - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطْرَقَةُ وَلاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا نِعَالُهُمُ الشَّعَرُ ‏"‏ ‏.‏\hadithno{7310}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The Last Hour would not come unless you fight with people whose faces are like hammered shields and the Last Hour would not come until you would fight against those wearing the shoes of hair}}
\hadithdefcmd{muslim}{7311}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلَكُمْ أُمَّةٌ يَنْتَعِلُونَ الشَّعَرَ وُجُوهُهُمْ مِثْلُ الْمَجَانِّ الْمُطْرَقَةِ ‏"‏ ‏.‏\hadithno{7311}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The Last Hour would not come until a people wearing shoes of hair fight against you having their faces like hammered shields}}
\hadithdefcmd{muslim}{7312}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا نِعَالُهُمُ الشَّعَرُ وَلاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا صِغَارَ الأَعْيُنِ ذُلْفَ الآنُفِ ‏"‏ ‏.‏\hadithno{7312}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The Last Hour would not come until you fight with a people wearing shoes of hair and the Last Hour would not come until you fight with a people having small eyes and broad snub noses}}
\hadithdefcmd{muslim}{7313}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يُقَاتِلَ الْمُسْلِمُونَ التُّرْكَ قَوْمًا وُجُوهُهُمْ كَالْمَجَانِّ الْمُطْرَقَةِ يَلْبَسُونَ الشَّعَرَ وَيَمْشُونَ فِي الشَّعَرِ ‏"‏ ‏.‏\hadithno{7313}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The Last Hour would not come until the Muslims fight with the Turks-a people whose faces would be like hammered shields wearing clothes of hair and walking (with shoes) of hair}}
\hadithdefcmd{muslim}{7314}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، وَأَبُو أُسَامَةَ عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ قَيْسِ، بْنِ أَبِي حَازِمٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تُقَاتِلُونَ بَيْنَ يَدَىِ السَّاعَةِ قَوْمًا نِعَالُهُمُ الشَّعَرُ كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطْرَقَةُ حُمْرُ الْوُجُوهِ صِغَارُ الأَعْيُنِ ‏"‏ ‏.‏\hadithno{7314}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:You shall fight in the hours to come against a nation wearing shoes made of hair and faces like hammered shields, with red complexion and small eyes}}
\hadithdefcmd{muslim}{7315}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعَلِيُّ بْنُ حُجْرٍ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، بْنُ إِبْرَاهِيمَ عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، قَالَ كُنَّا عِنْدَ جَابِرِ بْنِ عَبْدِ اللَّهِ فَقَالَ يُوشِكُ أَهْلُ الْعِرَاقِ أَنْ لاَ يُجْبَى إِلَيْهِمْ قَفِيزٌ وَلاَ دِرْهَمٌ ‏.‏ قُلْنَا مِنْ أَيْنَ ذَاكَ قَالَ مِنْ قِبَلِ الْعَجَمِ يَمْنَعُونَ ذَاكَ ‏.‏ ثُمَّ قَالَ يُوشِكَ أَهْلُ الشَّأْمِ أَنْ لاَ يُجْبَى إِلَيْهِمْ دِينَارٌ وَلاَ مُدْىٌ ‏.‏ قُلْنَا مِنْ أَيْنَ ذَاكَ قَالَ مِنْ قِبَلِ الرُّومِ ‏.‏ ثُمَّ سَكَتَ هُنَيَّةً ثُمَّ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَكُونُ فِي آخِرِ أُمَّتِي خَلِيفَةٌ يَحْثِي الْمَالَ حَثْيًا لاَ يَعُدُّهُ عَدَدًا ‏"‏ ‏.‏ قَالَ قُلْتُ لأَبِي نَضْرَةَ وَأَبِي الْعَلاَءِ أَتَرَيَانِ أَنَّهُ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ فَقَالاَ لاَ ‏.‏\hadithno{7315}\hadithtrans{Abu Nadra reported:"We were in the company of Jabir b. 'Abdullah that he said it may happen that the people of Iraq may not send their qafiz and dirhams (their measures of food stuff and their money). We said: Who would be responsible for it? He said: The non-Arabs would prevent them. He again said: There is the possibility that the people of Syria may not send their dinars and mudds. We said: Who would be responsible for it? He said this prevention would be made by the Romans. He (Jabir b. Abdullah) kept quiet for a while and then reported Allah's Messenger (ﷺ) having said there would be a caliph in the last (period) of my Ummah who would freely give handfuls of wealth to the people without counting it. I said to Abu Nadra and Abu al-'Ala: Do you mean 'Umar b. 'Abd al-Aziz? They said: No (he would be Imam Mahdi)}}
\hadithdefcmd{muslim}{7316}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنَا سَعِيدٌ، - يَعْنِي الْجُرَيْرِيَّ - بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{7316}\hadithtrans{This hadith hab been narrated by Sa'id with the same chain of transmitters}}
\hadithdefcmd{muslim}{7317}{\hadithno{7317}\hadithtrans{}}
\hadithdefcmd{muslim}{7318}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا بِشْرٌ يَعْنِي ابْنَ الْمُفَضَّلِ، ح وَحَدَّثَنَا عَلِيُّ، بْنُ حُجْرٍ السَّعْدِيُّ حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - كِلاَهُمَا عَنْ سَعِيدِ بْنِ يَزِيدَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مِنْ خُلَفَائِكُمْ خَلِيفَةٌ يَحْثُو الْمَالَ حَثْيًا لاَ يَعُدُّهُ عَدَدًا ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ حُجْرٍ ‏"‏ يَحْثِي الْمَالَ ‏"‏ ‏.‏\hadithno{7318}\hadithtrans{Abu Sa'id reported that Allah's Messenger (may peace he upon him) I said:There would be amongst your caliphs a caliph who would give handfuls of wealth to the people, but would not count it. In the narration transmitted on the authority of Ibn Hujr, there is a slight variation of wording}}
\hadithdefcmd{muslim}{7320}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي مَسْلَمَةَ، قَالَ سَمِعْتُ أَبَا نَضْرَةَ، يُحَدِّثُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ أَخْبَرَنِي مَنْ، هُوَ خَيْرٌ مِنِّي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِعَمَّارٍ حِينَ جَعَلَ يَحْفِرُ الْخَنْدَقَ وَجَعَلَ يَمْسَحُ رَأْسَهُ وَيَقُولُ ‏ "‏ بُؤْسَ ابْنِ سُمَيَّةَ تَقْتُلُكَ فِئَةٌ بَاغِيةٌ ‏"‏ ‏.‏\hadithno{7320}\hadithtrans{Abu Sa`id Khudri reported:One who is better than I informed me, that Allah's Messenger (ﷺ) said to `Ammar as he was digging the ditch (on the ocassion of the Battle of the Ditch) wiping over his head: O son of Summayya, you will be involved in trouble and a group of the rebels would kill you}}
\hadithdefcmd{muslim}{7321}{وَحَدَّثَنِي مُحَمَّدُ بْنُ مُعَاذِ بْنِ عَبَّادٍ الْعَنْبَرِيُّ، وَهُرَيْمُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، وَمَحْمُودُ بْنُ غَيْلاَنَ، وَمُحَمَّدُ بْنُ قُدَامَةَ قَالُوا أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، كِلاَهُمَا عَنْ شُعْبَةَ، عَنْ أَبِي مَسْلَمَةَ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ غَيْرَ أَنَّ فِي حَدِيثِ النَّضْرِ أَخْبَرَنِي مَنْ هُوَ خَيْرٌ مِنِّي أَبُو قَتَادَةَ ‏.‏ وَفِي حَدِيثِ خَالِدِ بْنِ الْحَارِثِ قَالَ أُرَاهُ يَعْنِي أَبَا قَتَادَةَ ‏.‏ وَفِي حَدِيثِ خَالِدٍ وَيَقُولُ ‏"‏ وَيْسَ ‏"‏ ‏.‏ أَوْ يَقُولُ ‏"‏ يَا وَيْسَ ابْنِ سُمَيَّةَ ‏"‏ ‏.‏\hadithno{7321}\hadithtrans{This hadith has been transmitted on the same authority but with this variation that the hadith transmitted on the authority of Nabra (the words are):One who is better than I informed me, and he was Abu Qatada, and in the hadith transmitted on the authority of Khalid instead of the word 'bu'us' there is 'wayys' or 'ya wayys', i.e., " how sad it is}}
\hadithdefcmd{muslim}{7322}{وَحَدَّثَنِي مُحَمَّدُ بْنُ عَمْرِو بْنِ جَبَلَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا عُقْبَةُ بْنُ، مُكْرَمٍ الْعَمِّيُّ وَأَبُو بَكْرِ بْنُ نَافِعٍ قَالَ عُقْبَةُ حَدَّثَنَا وَقَالَ أَبُو بَكْرٍ، أَخْبَرَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ خَالِدًا، يُحَدِّثُ عَنْ سَعِيدِ بْنِ أَبِي الْحَسَنِ، عَنْ أُمِّهِ، عَنْ أُمِّ سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِعَمَّارٍ ‏ "‏ تَقْتُلُكَ الْفِئَةُ الْبَاغِيَةُ ‏"‏ ‏.‏\hadithno{7322}\hadithtrans{This hadith has been transmitted on the authority of Umm Salama that Allah's Messenger (ﷺ) said to 'Ammar:A group of rebels would kill you}}
\hadithdefcmd{muslim}{7323}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ سَعِيدِ بْنِ أَبِي الْحَسَنِ، وَالْحَسَنِ، عَنْ أُمِّهِمَا، عَنْ أُمِّ سَلَمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{7323}\hadithtrans{This hadith has been narrated on the authority of Umm Salama through another chain of transmitters}}
\hadithdefcmd{muslim}{7324}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ عَوْنٍ، عَنِ الْحَسَنِ، عَنْ أُمِّهِ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَقْتُلُ عَمَّارًا الْفِئَةُ الْبَاغِيَةُ ‏"‏ ‏.‏\hadithno{7324}\hadithtrans{Umm Salama reported that Allah's Messenger (ﷺ) said:A band of rebels would kill `Ammar}}
\hadithdefcmd{muslim}{7326}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ أَبَا زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ يُهْلِكُ أُمَّتِي هَذَا الْحَىُّ مِنْ قُرَيْشٍ ‏"‏ ‏.‏ قَالُوا فَمَا تَأْمُرُنَا قَالَ ‏"‏ لَوْ أَنَّ النَّاسَ اعْتَزَلُوهُمْ ‏"‏ ‏.‏ وَحَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، وَأَحْمَدُ بْنُ عُثْمَانَ النَّوْفَلِيُّ، قَالاَ حَدَّثَنَا أَبُو دَاوُدَ حَدَّثَنَا شُعْبَةُ، فِي هَذَا الإِسْنَادِ فِي مَعْنَاهُ ‏.‏\hadithno{7326}\hadithtrans{Abu Huraira reported that Allah's Apostle (ﷺ) as saying:This tribe of the Quraish would kill (people) of my Ummah. They (the Companions) said: What do you command us to do (in such a situation)? Thereupon he said: Would that the people remain aside from them (and not besmear their hands with the blood of the Muslim). This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{7327}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لاِبْنِ أَبِي عُمَرَ - قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَدْ مَاتَ كِسْرَى فَلاَ كِسْرَى بَعْدَهُ وَإِذَا هَلَكَ قَيْصَرُ فَلاَ قَيْصَرَ بَعْدَهُ وَالَّذِي نَفْسِي بِيَدِهِ لَتُنْفَقَنَّ كُنُوزُهُمَا فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنِي ابْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ عَنْ عَبْدِ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِإِسْنَادِ سُفْيَانَ وَمَعْنَى حَدِيثِهِ ‏.‏\hadithno{7327}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said:Kisra (Khusrau king of Persia) would die and Qaisar (Ceasar King of Rome) would die; there would be no Qaisar after him, but, by the One in Whose Hand is my life, you would spend their treasures in the cause of Allah. This hadith has been transmitted on the authority of Zuhri}}
\hadithdefcmd{muslim}{7328}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هَلَكَ كِسْرَى ثُمَّ لاَ يَكُونُ كِسْرَى بَعْدَهُ وَقَيْصَرُ لَيَهْلِكَنَّ ثُمَّ لاَ يَكُونُ قَيْصَرُ بَعْدَهُ وَلَتُقْسَمَنَّ كُنُوزُهُمَا فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏\hadithno{7328}\hadithtrans{Hammam b. Munabbih reported:This is what Abu Huraira reported from Allah's messenger (ﷺ) and in this connection he reported so many hadith (and one of them was this): Allah's Messenger (ﷺ) said: Kisra would die and then there would be no Kisra after him. Qaisar would die and there would be no Qaisar after him, but you will distribute their treasures in the cause of Allah}}
\hadithdefcmd{muslim}{7344}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِعُثْمَانَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، عُثْمَانُ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَرَرْنَا بِصِبْيَانٍ فِيهِمُ ابْنُ صَيَّادٍ فَفَرَّ الصِّبْيَانُ وَجَلَسَ ابْنُ صَيَّادٍ فَكَأَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَرِهَ ذَلِكَ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ تَرِبَتْ يَدَاكَ أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ ‏"‏ ‏.‏ فَقَالَ لاَ ‏.‏ بَلْ تَشْهَدُ أَنِّي رَسُولُ اللَّهِ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ ذَرْنِي يَا رَسُولَ اللَّهِ حَتَّى أَقْتُلَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ يَكُنِ الَّذِي تَرَى فَلَنْ تَسْتَطِيعَ قَتْلَهُ ‏"‏ ‏.‏\hadithno{7344}\hadithtrans{Abdullah reported:We were along with Allah's Messenger (ﷺ) that we happened to pass by children amongst whom there was Ibn Sayyad. The children made their way but Ibn Sayyad kept sitting there (and it seemed) as if Allah's Messenger (ﷺ) did not like it (his sitting with the children) and said to him: May your nose he besmeared with dust, don't you bear testimony to the fact that I am the Messenger of Allah? Thereupon he said: No, but you should bear testimony that I am the messenger of Allah. Thereupon 'Umar b. Khattab said: Allah's Messenger, permit me that I should kill him. Thereupon Allah's Messenger (ﷺ) said: If he is that person who is in your mind (Dajjal ), you will not be able to kill him}}
\hadithdefcmd{muslim}{7345}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لأَبِي كُرَيْبٍ - قَالَ ابْنُ نُمَيْرٍ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا نَمْشِي مَعَ النَّبِيِّ صلى الله عليه وسلم فَمَرَّ بِابْنِ صَيَّادٍ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ خَبَأْتُ لَكَ خَبِيئًا ‏"‏ ‏.‏ فَقَالَ دُخٌّ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اخْسَأْ فَلَنْ تَعْدُوَ قَدْرَكَ ‏"‏ ‏.‏ فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ دَعْنِي فَأَضْرِبَ عُنُقَهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ دَعْهُ فَإِنْ يَكُنِ الَّذِي تَخَافُ لَنْ تَسْتَطِيعَ قَتْلَهُ ‏"‏ ‏.‏\hadithno{7345}\hadithtrans{Abdullah reported:We were walking with Allah's Messenger (ﷺ) that Ibn Sayyad happened to pass by him. Allah's Messenger (ﷺ) said to him: I have concealed for you (something to test you, so tell me that). He said: It is Dukh. Thereupon Allah's Messenger (ﷺ) said to him: Be off. You cannot get farther than your rank, whereupon 'Umar said: Allah's Messenger, permit me to strike his neck. Thereupon Allah's Messenger (ﷺ) said: Leave him; if he is that one (Dajjal) whom you apprehend, you will not be able to kill him}}
\hadithdefcmd{muslim}{7346}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا سَالِمُ بْنُ نُوحٍ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ لَقِيَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ وَعُمَرُ فِي بَعْضِ طُرُقِ الْمَدِينَةِ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ ‏"‏ ‏.‏ فَقَالَ هُوَ أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ آمَنْتُ بِاللَّهِ وَمَلاَئِكَتِهِ وَكُتُبِهِ مَا تَرَى ‏"‏ ‏.‏ قَالَ أَرَى عَرْشًا عَلَى الْمَاءِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَرَى عَرْشَ إِبْلِيسَ عَلَى الْبَحْرِ وَمَا تَرَى ‏"‏ ‏.‏ قَالَ أَرَى صَادِقَيْنِ وَكَاذِبًا أَوْ كَاذِبَيْنِ وَصَادِقًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لُبِسَ عَلَيْهِ دَعُوهُ ‏"‏ ‏.‏\hadithno{7346}\hadithtrans{Abu Sa'id reported that Allah's Messenger (ﷺ) met him (Ibn Sayyad) and so did Abu Bakr and 'Umar on some of the roads of Medina. Allah's Messenger (ﷺ) said:Do you bear testimony to the fact that I am the Messenger of Allah? Thereupon he said: Do you bear testimony to the fact that I am the messenger of Allah? Thereupon Allah's Messenger (ﷺ) said: I affirm my faith in Allah and in His Angels and in His Books, and what do you see? He said: I see the throne over water. Whereupon Allah's Messenger (ﷺ) said: You see the throne of Iblis upon the water, and what else do you see? He said: I see two truthfuls and a liar or two liars and one truthful. Thereupon Allah's Messenger (ﷺ) said: Leave him He has been confounded}}
\hadithdefcmd{muslim}{7347}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي قَالَ، حَدَّثَنَا أَبُو نَضْرَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ لَقِيَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ابْنَ صَائِدٍ وَمَعَهُ أَبُو بَكْرٍ وَعُمَرُ وَابْنُ صَائِدٍ مَعَ الْغِلْمَانِ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ الْجُرَيْرِيِّ ‏.‏\hadithno{7347}\hadithtrans{Jabir b 'Abdullah reported that Allah's Messenger (ﷺ) met Ibn Sa'id (Sayyad) and there were with him Abu Bakr and 'Umar and Ibn Sayyad was in the company of children. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{7348}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا دَاوُدُ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ صَحِبْتُ ابْنَ صَائِدٍ إِلَى مَكَّةَ فَقَالَ لِي أَمَا قَدْ لَقِيتُ مِنَ النَّاسِ يَزْعُمُونَ أَنِّي الدَّجَّالُ أَلَسْتَ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّهُ لاَ يُولَدُ لَهُ ‏"‏ ‏.‏ قَالَ قُلْتُ بَلَى ‏.‏ قَالَ فَقَدْ وُلِدَ لِي ‏.‏ أَوَلَيْسَ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ يَدْخُلُ الْمَدِينَةَ وَلاَ مَكَّةَ ‏"‏ ‏.‏ قُلْتُ بَلَى ‏.‏ قَالَ فَقَدْ وُلِدْتُ بِالْمَدِينَةِ وَهَذَا أَنَا أُرِيدُ مَكَّةَ - قَالَ - ثُمَّ قَالَ لِي فِي آخِرِ قَوْلِهِ أَمَا وَاللَّهِ إِنِّي لأَعْلَمُ مَوْلِدَهُ وَمَكَانَهُ وَأَيْنَ هُوَ ‏.‏ قَالَ فَلَبَسَنِي ‏.‏\hadithno{7348}\hadithtrans{Abu Sa'id reported:I accompanied Ibn Sayyad to Mecca and he said to me: What I have gathered from people is that they think that I am Dajjal. Have you not heard Allah's Messenger (may peace upon him) as saying: He will have no children, I said: Yes, of course. Thereupon he said: But I have children. Have you not heard Allah's Messenger (ﷺ) as saying: He would not enter Mecca and Medina? I said: Yes, of course. Thereupon he said I have been once in Medina and now I intend to go to Mecca. And he said to me at the end of his talk: By Allah, I know his place of birth his abode where he is just now. He (Abu Sa'id) said: This caused confusion in my mind (in regard to his identity)}}
\hadithdefcmd{muslim}{7349}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ لِيَ ابْنُ صَائِدٍ وَأَخَذَتْنِي مِنْهُ ذَمَامَةٌ هَذَا عَذَرْتُ النَّاسَ مَا لِي وَلَكُمْ يَا أَصْحَابَ مُحَمَّدٍ أَلَمْ يَقُلْ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّهُ يَهُودِيٌّ ‏"‏ ‏.‏ وَقَدْ أَسْلَمْتُ ‏.‏ قَالَ ‏"‏ وَلاَ يُولَدُ لَهُ ‏"‏ ‏.‏ وَقَدْ وُلِدَ لِي ‏.‏ وَقَالَ ‏"‏ إِنَّ اللَّهَ قَدْ حَرَّمَ عَلَيْهِ مَكَّةَ ‏"‏ ‏.‏ وَقَدْ حَجَجْتُ ‏.‏ قَالَ فَمَا زَالَ حَتَّى كَادَ أَنْ يَأْخُذَ فِيَّ قَوْلُهُ ‏.‏ قَالَ فَقَالَ لَهُ أَمَا وَاللَّهِ إِنِّي لأَعْلَمُ الآنَ حَيْثُ هُوَ وَأَعْرِفُ أَبَاهُ وَأُمَّهُ ‏.‏ قَالَ وَقِيلَ لَهُ أَيَسُرُّكَ أَنَّكَ ذَاكَ الرَّجُلُ قَالَ فَقَالَ لَوْ عُرِضَ عَلَىَّ مَا كَرِهْتُ ‏.‏\hadithno{7349}\hadithtrans{Abu Sa'id Khudri reported:Ibn Sa'id said to me something for which I felt ashamed. He said: I can excuse others; but what has gone wrong with you, O Companions of Muhammad, that you take me as Dajjal? Has Allah's Apostle (ﷺ) not said that he would be a Jew whereas I am a Muslim and he also said that he would not have children, whereas I have children, and he also said: verily, Allah has prohibited him to enter Mecca whereas I have performed Pilgrimage, and he went on saying this that I was about to be impressed by his talk. He (however) said this also: I know where he (Dajjal) is and I know his father and mother, and it was said to him: Won't you feel pleased if you would be the same person? Thereupon he said: If this offer is made to me, I would not resent that}}
\hadithdefcmd{muslim}{7350}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا سَالِمُ بْنُ نُوحٍ، أَخْبَرَنِي الْجُرَيْرِيُّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ خَرَجْنَا حُجَّاجًا أَوْ عُمَّارًا وَمَعَنَا ابْنُ صَائِدٍ - قَالَ - فَنَزَلْنَا مَنْزِلاً فَتَفَرَّقَ النَّاسُ وَبَقِيتُ أَنَا وَهُوَ فَاسْتَوْحَشْتُ مِنْهُ وَحْشَةً شَدِيدَةً مِمَّا يُقَالُ عَلَيْهِ - قَالَ - وَجَاءَ بِمَتَاعِهِ فَوَضَعَهُ مَعَ مَتَاعِي ‏.‏ فَقُلْتُ إِنَّ الْحَرَّ شَدِيدٌ فَلَوْ وَضَعْتَهُ تَحْتَ تِلْكَ الشَّجَرَةِ - قَالَ - فَفَعَلَ - قَالَ - فَرُفِعَتْ لَنَا غَنَمٌ فَانْطَلَقَ فَجَاءَ بِعُسٍّ فَقَالَ اشْرَبْ أَبَا سَعِيدٍ ‏.‏ فَقُلْتُ إِنَّ الْحَرَّ شَدِيدٌ وَاللَّبَنُ حَارٌّ ‏.‏ مَا بِي إِلاَّ أَنِّي أَكْرَهُ أَنْ أَشْرَبَ عَنْ يَدِهِ - أَوْ قَالَ آخُذَ عَنْ يَدِهِ - فَقَالَ أَبَا سَعِيدٍ لَقَدْ هَمَمْتُ أَنْ آخُذَ حَبْلاً فَأُعَلِّقَهُ بِشَجَرَةٍ ثُمَّ أَخْتَنِقَ مِمَّا يَقُولُ لِيَ النَّاسُ يَا أَبَا سَعِيدٍ مَنْ خَفِيَ عَلَيْهِ حَدِيثُ رَسُولِ اللَّهِ صلى الله عليه وسلم مَا خَفِيَ عَلَيْكُمْ مَعْشَرَ الأَنْصَارِ أَلَسْتَ مِنْ أَعْلَمِ النَّاسِ بِحَدِيثِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَلَيْسَ قَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هُوَ كَافِرٌ ‏"‏ ‏.‏ وَأَنَا مُسْلِمٌ أَوَلَيْسَ قَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هُوَ عَقِيمٌ لاَ يُولَدُ لَهُ ‏"‏ ‏.‏ وَقَدْ تَرَكْتُ وَلَدِي بِالْمَدِينَةِ أَوَ لَيْسَ قَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ يَدْخُلُ الْمَدِينَةَ وَلاَ مَكَّةَ ‏"‏ ‏.‏ وَقَدْ أَقْبَلْتُ مِنَ الْمَدِينَةِ وَأَنَا أُرِيدُ مَكَّةَ قَالَ أَبُو سَعِيدٍ الْخُدْرِيُّ حَتَّى كِدْتُ أَنْ أَعْذِرَهُ ‏.‏ ثُمَّ قَالَ أَمَا وَاللَّهِ إِنِّي لأَعْرِفُهُ وَأَعْرِفُ مَوْلِدَهُ وَأَيْنَ هُوَ الآنَ ‏.‏ قَالَ قُلْتُ لَهُ تَبًّا لَكَ سَائِرَ الْيَوْمِ ‏.‏\hadithno{7350}\hadithtrans{Abu Sa`id al-Khudri reported:We came back after having performed Pilgrimage or `Umra and lbn Sa'id was along with us. And we encamped at a place and the people dispersed and I and he were left behind. I felt terribly frightend from him as it was said about him that he was the Dajjal. He brought his goods and placed them by my luggage and I said: It is intense heat. Would you not place that under that tree? And he did that. Then there appeared before us a flock of sheep. He went and brought a cup of milk and said: Abu Sa`id, drink that. I said it is intense heat and the milk is also hot (whereas the fact was) that I did not like to drink from his hands or to take it from his hand and he said: Abu Sa`id, I think that I should take a rope and suspend it by the tree and then commit suicide because of the talks of the people, and he further said. Abu Sa`id he who is ignorant of the saying of Allah's Messenger (ﷺ) (he is to be pardoned), but O people of Ansar, is this hadith of Allah's Messenger (ﷺ) concealed from you whereas you have the best knowledge of the hadith of Allah's Messenger (ﷺ) amongst people? Did Allah's Messenger (ﷺ) not say that he (Dajjal) would be a non believer whereas I am a believer? Did Allah's Messenger (ﷺ) not say he would be barren and no child would be born to him, whereas I have left my children in Medina? Did Allah's Messenger (may peace upon him) not say: He would not get into Medina and Mecca whereas I have been coming from Medina and now I intend to go to Mecca? Abu Sa`id said: I was about to accept the excuse put forward by him. Then he said: I know the place where he would be born and where he is now. So I said to him: May your whole day be spent}}
\hadithdefcmd{muslim}{7351}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ مُفَضَّلٍ - عَنْ أَبِي مَسْلَمَةَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاِبْنِ صَائِدٍ ‏"‏ مَا تُرْبَةُ الْجَنَّةِ ‏"‏ ‏.‏ قَالَ دَرْمَكَةٌ بَيْضَاءُ مِسْكٌ يَا أَبَا الْقَاسِمِ ‏.‏ قَالَ ‏"‏ صَدَقْتَ ‏"‏ ‏.‏\hadithno{7351}\hadithtrans{This hadith has transmitted on the authority of Abu Sa'id that Allah's Messenger (ﷺ) asked Ibn Sa'id about the earth of Paradise. Thereupon he said:Abu'l-Qasim, It is like a fine white musk, whereupon he (the Holy Prophet) said: 'You have told the the truth}}
\hadithdefcmd{muslim}{7352}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ ابْنَ صَيَّادٍ، سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنْ تُرْبَةِ الْجَنَّةِ فَقَالَ ‏ "‏ دَرْمَكَةٌ بَيْضَاءُ مِسْكٌ خَالِصٌ ‏"‏ ‏.‏\hadithno{7352}\hadithtrans{Abu Sa'id reported that Ibn Sayyad asked Allah's Messenger (ﷺ) about the earth of Paradise. Whereupon he said:It is like white shining pure musk}}
\hadithdefcmd{muslim}{7353}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، قَالَ رَأَيْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ يَحْلِفُ بِاللَّهِ أَنَّ ابْنَ صَائِدٍ الدَّجَّالُ، فَقُلْتُ أَتَحْلِفُ بِاللَّهِ قَالَ إِنِّي سَمِعْتُ عُمَرَ يَحْلِفُ عَلَى ذَلِكَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَلَمْ يُنْكِرْهُ النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{7353}\hadithtrans{Muhammad b. Munkadir reported:As I saw Jabir b. 'Abdullah taking an oath in the name of Allah that it was Ibn Sa'id who was the Dajjal I said: Do you take an oath in the name of Allah? Thereupon he said: I heard 'Umar taking an oath in the presence of Allah's Apostle (ﷺ) to this effect but Allah's Apostle (ﷺ) did not disapprove of it}}
\hadithdefcmd{muslim}{7356}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ حَرْمَلَةَ بْنِ عِمْرَانَ التُّجِيبِيُّ، أَخْبَرَنِي ابْنُ، وَهْبٍ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ أَخْبَرَهُ أَنَّ عُمَرَ بْنَ الْخَطَّابِ انْطَلَقَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَهْطٍ قِبَلَ ابْنِ صَيَّادٍ حَتَّى وَجَدَهُ يَلْعَبُ مَعَ الصِّبْيَانِ عِنْدَ أُطُمِ بَنِي مَغَالَةَ وَقَدْ قَارَبَ ابْنُ صَيَّادٍ يَوْمَئِذٍ الْحُلُمَ فَلَمْ يَشْعُرْ حَتَّى ضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ظَهْرَهُ بِيَدِهِ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاِبْنِ صَيَّادٍ ‏"‏ أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ ‏"‏ ‏.‏ فَنَظَرَ إِلَيْهِ ابْنُ صَيَّادٍ فَقَالَ أَشْهَدُ أَنَّكَ رَسُولُ الأُمِّيِّينَ ‏.‏ فَقَالَ ابْنُ صَيَّادٍ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَتَشْهَدُ أَنِّي رَسُولُ اللَّهِ فَرَفَضَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ آمَنْتُ بِاللَّهِ وَبِرُسُلِهِ ‏"‏ ‏.‏ ثُمَّ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَاذَا تَرَى ‏"‏ ‏.‏ قَالَ ابْنُ صَيَّادٍ يَأْتِينِي صَادِقٌ وَكَاذِبٌ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خُلِّطَ عَلَيْكَ الأَمْرُ ‏"‏ ‏.‏ ثُمَّ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي قَدْ خَبَأْتُ لَكَ خَبِيئًا ‏"‏ ‏.‏ فَقَالَ ابْنُ صَيَّادٍ ‏"‏ هُوَ الدُّخُّ ‏"‏ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اخْسَأْ فَلَنْ تَعْدُوَ قَدْرَكَ ‏"‏ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ ذَرْنِي يَا رَسُولَ اللَّهِ أَضْرِبْ عُنُقَهُ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنْ يَكُنْهُ فَلَنْ تُسَلَّطَ عَلَيْهِ وَإِنْ لَمْ يَكُنْهُ فَلاَ خَيْرَ لَكَ فِي قَتْلِهِ ‏"‏ ‏.‏ وَقَالَ سَالِمُ بْنُ عَبْدِ اللَّهِ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ انْطَلَقَ بَعْدَ ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأُبَىُّ بْنُ كَعْبٍ الأَنْصَارِيُّ إِلَى النَّخْلِ الَّتِي فِيهَا ابْنُ صَيَّادٍ حَتَّى إِذَا دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّخْلَ طَفِقَ يَتَّقِي بِجُذُوعِ النَّخْلِ وَهُوَ يَخْتِلُ أَنْ يَسْمَعَ مِنِ ابْنِ صَيَّادٍ شَيْئًا قَبْلَ أَنْ يَرَاهُ ابْنُ صَيَّادٍ فَرَآهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ مُضْطَجِعٌ عَلَى فِرَاشٍ فِي قَطِيفَةٍ لَهُ فِيهَا زَمْزَمَةٌ فَرَأَتْ أُمُّ ابْنِ صَيَّادٍ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يَتَّقِي بِجُذُوعِ النَّخْلِ فَقَالَتْ لاِبْنِ صَيَّادٍ يَا صَافِ - وَهُوَ اسْمُ ابْنِ صَيَّادٍ - هَذَا مُحَمَّدٌ ‏.‏ فَثَارَ ابْنُ صَيَّادٍ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَوْ تَرَكَتْهُ بَيَّنَ ‏"‏ ‏.‏ قَالَ سَالِمٌ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّاسِ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ ثُمَّ ذَكَرَ الدَّجَّالَ فَقَالَ ‏"‏ إِنِّي لأُنْذِرُكُمُوهُ مَا مِنْ نَبِيٍّ إِلاَّ وَقَدْ أَنْذَرَهُ قَوْمَهُ لَقَدْ أَنْذَرَهُ نُوحٌ قَوْمَهُ وَلَكِنْ أَقُولُ لَكُمْ فِيهِ قَوْلاً لَمْ يَقُلْهُ نَبِيٌّ لِقَوْمِهِ تَعَلَّمُوا أَنَّهُ أَعْوَرُ وَأَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى لَيْسَ بِأَعْوَرَ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ وَأَخْبَرَنِي عُمَرُ بْنُ ثَابِتٍ الأَنْصَارِيُّ أَنَّهُ أَخْبَرَهُ بَعْضُ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ يَوْمَ حَذَّرَ النَّاسَ الدَّجَّالَ ‏"‏ إِنَّهُ مَكْتُوبٌ بَيْنَ عَيْنَيْهِ كَافِرٌ يَقْرَؤُهُ مَنْ كَرِهَ عَمَلَهُ أَوْ يَقْرَؤُهُ كُلُّ مُؤْمِنٍ ‏"‏ ‏.‏ وَقَالَ ‏"‏ تَعَلَّمُوا أَنَّهُ لَنْ يَرَى أَحَدٌ مِنْكُمْ رَبَّهُ عَزَّ وَجَلَّ حَتَّى يَمُوتَ ‏"‏ ‏.‏\hadithno{7356}\hadithtrans{Abdullah b. Umar reported:'Umar b. Khattab went along with Allah's Messenger (ﷺ) in the company of some persons to Ibn Sayyad that he found him playing with children near the battlement of Bani Maghala and Ibn Sayyad was at that time just at the threshold of adolescence and he did not perceive (the presence of Holy Prophet) until Allah's Messenger (ﷺ) struck his back with his hands. Allah's Messenger (ﷺ) said: Ibn Sayyad, don't you bear witness that I am the messenger of Allah? Ibn Sayyad looked toward him and he said: I bear witness to the fact that you the messenger of the unlettered. Ibn Sayyad said to the Allah's Messenger (ﷺ): Do you bear witness to the fact that I am the messenger of Allah? Allah's Messenger (ﷺ) rejected this and said: I affirm my faith in Allah and in His messengers. Then Allah's Messenger (ﷺ) said to him: What do you see? Ibn Sayyad said: It is a Dukh. Thereupon Allah's Messenger (ﷺ) said: May you be disgraced and dishonoured, you would not not be able to go beyond your rank. 'Umar b. Khattab said: Allah's Messenger, permit me that I should strike his neck. Thereupon Allah's Messenger (ﷺ) said: If he is the same (Dajjal) who would appear near the Last Hour, you would not be able to overpower him, and if he is not that there is no good for you to kill him. 'Abdullah b. 'Umar further narrated that after some time Allah's Messenger (ﷺ) and Ubayy b. Ka'b went towards the palm trees where Ibn Sayyad was. When Allah's Messenger (ﷺ) went near the tree he hid himself behind a tree with the intention of hearing something from Ibn sayyad before Ibn Sayyad could see him, but Allah's Messenger (ﷺ) saw him on a bed with a blanket around him from which a murmuring sound was being heard and Ibn Sayyad's mother saw Allah's Messenger (ﷺ) behind the trunk of the palm tree. She said to Ibn Sayyad: Saf (that being his name), here is Muhammad. Thereupon Ibn Sayyad jumped up murmuring and Allah's Messenger (ﷺ) said: If she had left him alone he would have made things clear. Abdullah b. Umar told that Allah's Messenger (ﷺ) stood up amongst the people and lauded Allah as He deserved, then he made a mention of the Dajjal and said: I warn you of him and there is no Prophet who has not warned his people against the Dajjal. Even Noah warned (against him) but I am going to tell you a thing which no Prophet told his people. You must know that he (the Dajjal) is one-eyed and Allah, the Exalted and Glorious, is not one-eyed. Ibn Shihab said: 'Umar b. Thabit al-Ansari informed me that some of the Companions of Allah's Messenger (ﷺ) informed him that the day when Allah's Messenger (ﷺ) warned people against the Dajjal, he also said: There would be written between his two eyes (the word) Kafir (infidel) and everyone who would resent his deeds would be able to read or every Muslim would be about to read, and he also said: Bear this thing in mind that none amongst you would be able to see Allah, the Exalted and Glorious, until he dies}}
\hadithdefcmd{muslim}{7357}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّالله عليه وسلم وَمَعَهُ رَهْطٌ مِنْ أَصْحَابِهِ فِيهِمْ عُمَرُ بْنُ الْخَطَّابِ حَتَّى وَجَدَ ابْنَ صَيَّادٍ غُلاَمًا قَدْ نَاهَزَ الْحُلُمَ يَلْعَبُ مَعَ الْغِلْمَانِ عِنْدَ أُطُمِ بَنِي مُعَاوِيَةَ ‏.‏ وَسَاقَ الْحَدِيثَ بِمِثْلِ حَدِيثِ يُونُسَ إِلَى مُنْتَهَى حَدِيثِ عُمَرَ بْنِ ثَابِتٍ وَفِي الْحَدِيثِ عَنْ يَعْقُوبَ قَالَ قَالَ أُبَىٌّ - يَعْنِي فِي قَوْلِهِ لَوْ تَرَكَتْهُ بَيَّنَ - قَالَ لَوْ تَرَكَتْهُ أُمُّهُ بَيَّنَ أَمْرَهُ ‏.‏\hadithno{7357}\hadithtrans{Abdullah b. Umar reported that Allah's Messenger (ﷺ) went along with him in the company of some persons and there was Umar b. Khattab also amongst them till they saw Ibn Sayyad as a young boy just on the threshold of adolescence playing with children near the battlement of Bani Mu'awiya; the rest of the hadith is the same but with these concluding words:" Had his mother left him (to murmur) his matter would have become clear}}
\hadithdefcmd{muslim}{7358}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، وَسَلَمَةُ بْنُ شَبِيبٍ، جَمِيعًا عَنْ عَبْدِ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِابْنِ صَيَّادٍ فِي نَفَرٍ مِنْ أَصْحَابِهِ فِيهِمْ عُمَرُ بْنُ الْخَطَّابِ وَهُوَ يَلْعَبُ مَعَ الْغِلْمَانِ عِنْدَ أُطُمِ بَنِي مَغَالَةَ وَهُوَ غُلاَمٌ ‏.‏ بِمَعْنَى حَدِيثِ يُونُسَ وَصَالِحٍ غَيْرَ أَنَّ عَبْدَ بْنَ حُمَيْدٍ لَمْ يَذْكُرْ حَدِيثَ ابْنِ عُمَرَ فِي انْطِلاَقِ النَّبِيِّ صلى الله عليه وسلم مَعَ أُبَىِّ بْنِ كَعْبٍ إِلَى النَّخْلِ ‏.‏\hadithno{7358}\hadithtrans{Ibn 'Umar reported that Allah's Messenger (ﷺ) happened to pass by Ibn Sayyad along with his Companions including 'Umar b. Khattab as he was playing with children near the battlement of Bani Maghala and he was also a child by that time. The rest of the hadith is the same as narrated by Ibn Umar (in which there is a mention of) setting out of Allah's Apostle (ﷺ) along with Ubayy b. Ka'b towards the date-palm trees}}
\hadithdefcmd{muslim}{7359}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، قَالَ لَقِيَ ابْنُ عُمَرَ ابْنَ صَائِدٍ فِي بَعْضِ طُرُقِ الْمَدِينَةِ فَقَالَ لَهُ قَوْلاً أَغْضَبَهُ فَانْتَفَخَ حَتَّى مَلأَ السِّكَّةَ فَدَخَلَ ابْنُ عُمَرَ عَلَى حَفْصَةَ وَقَدْ بَلَغَهَا فَقَالَتْ لَهُ رَحِمَكَ اللَّهُ مَا أَرَدْتَ مِنِ ابْنِ صَائِدٍ أَمَا عَلِمْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا يَخْرُجُ مِنْ غَضْبَةٍ يَغْضَبُهَا ‏"‏ ‏.‏\hadithno{7359}\hadithtrans{Nafi' reported that Ibn 'Umar met Ibn Si'id on some of the paths of Medina and he said to him a word which enraged him and he was so much swollen with anger that the way was blocked. Ibn 'Umar went to Hafsa and informed her about this. Thereupon she said:May Allah have mercy upon you, why did you incite Ibn Sayyad in spite of the fact that you knew it would be the extreme anger which would make Dajjal appear in the world?}}
\hadithdefcmd{muslim}{7360}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا حُسَيْنٌ، - يَعْنِي ابْنَ حَسَنِ بْنِ يَسَارٍ - حَدَّثَنَا ابْنُ، عَوْنٍ عَنْ نَافِعٍ، قَالَ كَانَ نَافِعٌ يَقُولُ ابْنُ صَيَّادٍ ‏.‏ قَالَ قَالَ ابْنُ عُمَرَ لَقِيتُهُ مَرَّتَيْنِ - قَالَ - فَلَقِيتُهُ فَقُلْتُ لِبَعْضِهِمْ هَلْ تَحَدَّثُونَ أَنَّهُ هُوَ قَالَ لاَ وَاللَّهِ - قَالَ - قُلْتُ كَذَبْتَنِي وَاللَّهِ لَقَدْ أَخْبَرَنِي بَعْضُكُمْ أَنَّهُ لَنْ يَمُوتَ حَتَّى يَكُونَ أَكْثَرَكُمْ مَالاً وَوَلَدًا فَكَذَلِكَ هُوَ زَعَمُوا الْيَوْمَ - قَالَ - فَتَحَدَّثْنَا ثُمَّ فَارَقْتُهُ - قَالَ - فَلَقِيتُهُ لَقْيَةً أُخْرَى وَقَدْ نَفَرَتْ عَيْنُهُ - قَالَ - فَقُلْتُ مَتَى فَعَلَتْ عَيْنُكَ مَا أَرَى قَالَ لاَ أَدْرِي - قَالَ - قُلْتُ لاَ تَدْرِي وَهِيَ فِي رَأْسِكَ قَالَ إِنْ شَاءَ اللَّهُ خَلَقَهَا فِي عَصَاكَ هَذِهِ ‏.‏ قَالَ فَنَخَرَ كَأَشَدِّ نَخِيرِ حِمَارٍ سَمِعْتُ - قَالَ - فَزَعَمَ بَعْضُ أَصْحَابِي أَنِّي ضَرَبْتُهُ بِعَصًا كَانَتْ مَعِيَ حَتَّى تَكَسَّرَتْ وَأَمَّا أَنَا فَوَاللَّهِ مَا شَعَرْتُ - قَالَ - وَجَاءَ حَتَّى دَخَلَ عَلَى أُمِّ الْمُؤْمِنِينَ فَحَدَّثَهَا فَقَالَتْ مَا تُرِيدُ إِلَيْهِ أَلَمْ تَعْلَمْ أَنَّهُ قَدْ قَالَ ‏ "‏ إِنَّ أَوَّلَ مَا يَبْعَثُهُ عَلَى النَّاسِ غَضَبٌ يَغْضَبُهُ ‏"‏ ‏.‏\hadithno{7360}\hadithtrans{Nafi' reported that Ibn 'Umar said:I met lbn Sayyad twice and said to some of them (his friends): You state that it was he (the Dajjal). He said: By Allah, it is not so. I said: You have not told me the truth; by Allah some of you informed me that he would not die until he would have the largest number of offspring and huge wealth and it is he about whom it is thought so. Then Ibn Sayyad talked to us. I then departed and met him again for the second time and his eye had been swollen. I said: What has happened to your eye? He said: I do not know. I said: This is in your head and you do not know about it? He said: If Allah so wills He can create it (eye) in your staff. He then produced a sound like the braying of a donkey. Some of my companions thought that I had struck him with the staff as he was with me that the staff broke into pieces, but, by Allah, I was not conscious of it. He then came to the Mother of the Faithful (Hafsa) and narrated it to her and she said: What concern you have with him? Don't you know that Allah's Apostle (ﷺ) said that the first thing (by the incitement of which) he would come out before the public would be his anger?}}
\hadithdefcmd{muslim}{7361}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، وَمُحَمَّدُ بْنُ بِشْرٍ، قَالاَ حَدَّثَنَا عُبَيْدُ، اللَّهِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَكَرَ الدَّجَّالَ بَيْنَ ظَهْرَانَىِ النَّاسِ فَقَالَ ‏ "‏ إِنَّ اللَّهَ تَعَالَى لَيْسَ بِأَعْوَرَ ‏.‏ أَلاَ وَإِنَّ الْمَسِيحَ الدَّجَّالَ أَعْوَرُ الْعَيْنِ الْيُمْنَى كَأَنَّ عَيْنَهُ عِنَبَةٌ طَافِئَةٌ ‏"‏ ‏.‏\hadithno{7361}\hadithtrans{Ibn Umar reported that Allah's Messenger (ﷺ). made a mention of Dajjal in the presence of the people and said:Allah is not one-eyed and behold that Dajjal is blind of the right eye and his eye would be like a floating grape}}
\hadithdefcmd{muslim}{7362}{حَدَّثَنِي أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، - وَهُوَ ابْنُ زَيْدٍ - عَنْ أَيُّوبَ، وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ - عَنْ مُوسَى بْنِ عُقْبَةَ، كِلاَهُمَا عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{7362}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Umar through another chain of transmitters}}
\hadithdefcmd{muslim}{7363}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ نَبِيٍّ إِلاَّ وَقَدْ أَنْذَرَ أُمَّتَهُ الأَعْوَرَ الْكَذَّابَ أَلاَ إِنَّهُ أَعْوَرُ وَإِنَّ رَبَّكُمْ لَيْسَ بِأَعْوَرَ وَمَكْتُوبٌ بَيْنَ عَيْنَيْهِ ك ف ر ‏"‏ ‏.‏\hadithno{7363}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said:There is never a prophet who has not warned the Ummah of that one-eyed liar; behold he is one-eyed and your Lord is not one-eyed. On his forehead are the letters k f. r. (Kafir)}}
\hadithdefcmd{muslim}{7364}{حَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الدَّجَّالُ مَكْتُوبٌ بَيْنَ عَيْنَيْهِ ك ف ر أَىْ كَافِرٌ ‏"‏ ‏.‏\hadithno{7364}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said:There would be written three letters k. f. r., i. e. Kafir, between the eyes of the Dajjal}}
\hadithdefcmd{muslim}{7365}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ شُعَيْبِ بْنِ الْحَبْحَابِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الدَّجَّالُ مَمْسُوحُ الْعَيْنِ مَكْتُوبٌ بَيْنَ عَيْنَيْهِ كَافِرٌ ‏"‏ ‏.‏ ثُمَّ تَهَجَّاهَا ك ف ر ‏"‏ يَقْرَؤُهُ كُلُّ مُسْلِمٍ ‏"‏ ‏.‏\hadithno{7365}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said:Dajjal is blind of one eye and there is written between his eyes the word" Kafir". He then spelled the word as k. f. r., which every Muslim would be able to read}}
\hadithdefcmd{muslim}{7366}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الدَّجَّالُ أَعْوَرُ الْعَيْنِ الْيُسْرَى جُفَالُ الشَّعَرِ مَعَهُ جَنَّةٌ وَنَارٌ فَنَارُهُ جَنَّةٌ وَجَنَّتُهُ نَارٌ ‏"‏ ‏.‏\hadithno{7366}\hadithtrans{Hudhaifa reported that Allah's Messenger (ﷺ) said:Dajjal is blind of left eye with thick hair and there would be a garden and fire with him and his fire would be a garden and his garden would be fire}}
\hadithdefcmd{muslim}{7367}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنَا أَعْلَمُ بِمَا مَعَ الدَّجَّالِ مِنْهُ مَعَهُ نَهْرَانِ يَجْرِيَانِ أَحَدُهُمَا رَأْىَ الْعَيْنِ مَاءٌ أَبْيَضُ وَالآخَرُ رَأْىَ الْعَيْنِ نَارٌ تَأَجَّجُ فَإِمَّا أَدْرَكَنَّ أَحَدٌ فَلْيَأْتِ النَّهْرَ الَّذِي يَرَاهُ نَارًا وَلْيُغَمِّضْ ثُمَّ لْيُطَأْطِئْ رَأْسَهُ فَيَشْرَبَ مِنْهُ فَإِنَّهُ مَاءٌ بَارِدٌ وَإِنَّ الدَّجَّالَ مَمْسُوحُ الْعَيْنِ عَلَيْهَا ظَفَرَةٌ غَلِيظَةٌ مَكْتُوبٌ بَيْنَ عَيْنَيْهِ كَافِرٌ يَقْرَؤُهُ كُلُّ مُؤْمِنٍ كَاتِبٍ وَغَيْرِ كَاتِبٍ ‏"‏ ‏.‏\hadithno{7367}\hadithtrans{It was narrated that Hudhaifah said:The Messenger of Allah said: 'I know what the Dajjal will have with him. He will have two flowing rivers, one that appears to the eye to be clear water, and one that appears to the eye to be flaming fire. If anyone sees that, let him go to the river which he thinks is fire and close his eyes, then lower his head and drink from it, for it is cool water. The Dajjal has one blind eye, with a layer of thick skin over it, and between his eyes is written "disbeliever," which every believer will read, whether he is literate or illiterate}}
\hadithdefcmd{muslim}{7369}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا شُعَيْبُ بْنُ صَفْوَانَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ رِبْعِيِّ، بْنِ حِرَاشٍ عَنْ عُقْبَةَ بْنِ عَمْرٍو أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ انْطَلَقْتُ مَعَهُ إِلَى حُذَيْفَةَ بْنِ الْيَمَانِ فَقَالَ لَهُ عُقْبَةُ حَدِّثْنِي مَا سَمِعْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الدَّجَّالِ ‏.‏ قَالَ ‏ "‏ إِنَّ الدَّجَّالَ يَخْرُجُ وَإِنَّ مَعَهُ مَاءً وَنَارًا فَأَمَّا الَّذِي يَرَاهُ النَّاسُ مَاءً فَنَارٌ تُحْرِقُ وَأَمَّا الَّذِي يَرَاهُ النَّاسُ نَارًا فَمَاءٌ بَارِدٌ عَذْبٌ فَمَنْ أَدْرَكَ ذَلِكَ مِنْكُمْ فَلْيَقَعْ فِي الَّذِي يَرَاهُ نَارًا فَإِنَّهُ مَاءٌ عَذْبٌ طَيِّبٌ ‏"‏ ‏.‏ فَقَالَ عُقْبَةُ وَأَنَا قَدْ، سَمِعْتُهُ تَصْدِيقًا، لِحُذَيْفَةَ ‏.‏\hadithno{7369}\hadithtrans{Uqba b. 'Amr Abu Mas'ud al-Ansari reported:I went to Hudhaifa b. Yaman and said to him: Narrate what you have heard from Allah's Messenger (ﷺ) pertaining to the Dajjal. He said that the Dajjal would appear and there would be along with him water and fire and what the people would see as water that would be fire and that would burn and what would appear as fire that would be water and any one of you who would see that should plunge in that which he sees as fire for it would be sweet, pure water, and 'Uqba said: I also heard it, testifying Hudhaifa}}
\hadithdefcmd{muslim}{7370}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لاِبْنِ حُجْرٍ قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ ابْنُ حُجْرٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الْمُغِيرَةِ، عَنْ نُعَيْمِ بْنِ أَبِي هِنْدٍ، عَنْ رِبْعِيِّ، بْنِ حِرَاشٍ قَالَ اجْتَمَعَ حُذَيْفَةُ وَأَبُو مَسْعُودٍ فَقَالَ حُذَيْفَةُ ‏ "‏ لأَنَا بِمَا مَعَ الدَّجَّالِ أَعْلَمُ مِنْهُ إِنَّ مَعَهُ نَهْرًا مِنْ مَاءٍ وَنَهْرًا مِنْ نَارٍ فَأَمَّا الَّذِي تَرَوْنَ أَنَّهُ نَارٌ مَاءٌ وَأَمَّا الَّذِي تَرَوْنَ أَنَّهُ مَاءٌ نَارٌ فَمَنْ أَدْرَكَ ذَلِكَ مِنْكُمْ فَأَرَادَ الْمَاءَ فَلْيَشْرَبْ مِنَ الَّذِي يَرَاهُ أَنَّهُ نَارٌ فَإِنَّهُ سَيَجِدُهُ مَاءً ‏"‏ ‏.‏ قَالَ أَبُو مَسْعُودٍ هَكَذَا سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏.‏\hadithno{7370}\hadithtrans{Hudhaifa and Ibn Mas'ud met together. Hudhaifa said:I know more than you as to what there would be along with the Dajjal. There would be along with him two canals (one flowing with water) and the other one (having) fire (within it), and what you would see as fire would be water and what you would see as water would be fire. So he who amongst you is able to see that and is desirous of water should drink out of that which he sees as fire}}
\hadithdefcmd{muslim}{7372}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا حُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي، سَلَمَةَ قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ أُخْبِرُكُمْ عَنِ الدَّجَّالِ حَدِيثًا مَا حَدَّثَهُ نَبِيٌّ قَوْمَهُ إِنَّهُ أَعْوَرُ وَإِنَّهُ يَجِيءُ مَعَهُ مِثْلُ الْجَنَّةِ وَالنَّارِ فَالَّتِي يَقُولُ إِنَّهَا الْجَنَّةُ هِيَ النَّارُ وَإِنِّي أَنْذَرْتُكُمْ بِهِ كَمَا أَنْذَرَ بِهِ نُوحٌ قَوْمَهُ ‏"‏ ‏.‏\hadithno{7372}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:May I not inform you about the Dajjal what no Apostle of Allah narrated to his people? He would be blind and he would bring along with him an Image of Paradise and Hell-Fire and what he would call as Paradise that would be Hell-Fire and I warn you as Noah warned his people}}
\hadithdefcmd{muslim}{7373}{حَدَّثَنَا أَبُو خَيْثَمَةَ، زُهَيْرُ بْنُ حَرْبٍ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ، بْنُ يَزِيدَ بْنِ جَابِرٍ حَدَّثَنِي يَحْيَى بْنُ جَابِرٍ الطَّائِيُّ، قَاضِي حِمْصَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ، جُبَيْرٍ عَنْ أَبِيهِ، جُبَيْرِ بْنِ نُفَيْرٍ الْحَضْرَمِيِّ أَنَّهُ سَمِعَ النَّوَّاسَ بْنَ سَمْعَانَ الْكِلاَبِيَّ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ يَزِيدَ بْنِ جَابِرٍ، عَنْ يَحْيَى بْنِ جَابِرٍ الطَّائِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ، نُفَيْرٍ عَنْ أَبِيهِ، جُبَيْرِ بْنِ نُفَيْرٍ عَنِ النَّوَّاسِ بْنِ سَمْعَانَ، قَالَ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم الدَّجَّالَ ذَاتَ غَدَاةٍ فَخَفَّضَ فِيهِ وَرَفَّعَ حَتَّى ظَنَنَّاهُ فِي طَائِفَةِ النَّخْلِ فَلَمَّا رُحْنَا إِلَيْهِ عَرَفَ ذَلِكَ فِينَا فَقَالَ ‏"‏ مَا شَأْنُكُمْ ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ ذَكَرْتَ الدَّجَّالَ غَدَاةً فَخَفَّضْتَ فِيهِ وَرَفَّعْتَ حَتَّى ظَنَنَّاهُ فِي طَائِفَةِ النَّخْلِ ‏.‏ فَقَالَ ‏"‏ غَيْرُ الدَّجَّالِ أَخْوَفُنِي عَلَيْكُمْ إِنْ يَخْرُجْ وَأَنَا فِيكُمْ فَأَنَا حَجِيجُهُ دُونَكُمْ وَإِنْ يَخْرُجْ وَلَسْتُ فِيكُمْ فَامْرُؤٌ حَجِيجُ نَفْسِهِ وَاللَّهُ خَلِيفَتِي عَلَى كُلِّ مُسْلِمٍ إِنَّهُ شَابٌّ قَطَطٌ عَيْنُهُ طَافِئَةٌ كَأَنِّي أُشَبِّهُهُ بِعَبْدِ الْعُزَّى بْنِ قَطَنٍ فَمَنْ أَدْرَكَهُ مِنْكُمْ فَلْيَقْرَأْ عَلَيْهِ فَوَاتِحَ سُورَةِ الْكَهْفِ إِنَّهُ خَارِجٌ خَلَّةً بَيْنَ الشَّأْمِ وَالْعِرَاقِ فَعَاثَ يَمِينًا وَعَاثَ شِمَالاً يَا عِبَادَ اللَّهِ فَاثْبُتُوا ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ وَمَا لَبْثُهُ فِي الأَرْضِ قَالَ ‏"‏ أَرْبَعُونَ يَوْمًا يَوْمٌ كَسَنَةٍ وَيَوْمٌ كَشَهْرٍ وَيَوْمٌ كَجُمُعَةٍ وَسَائِرُ أَيَّامِهِ كَأَيَّامِكُمْ ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ فَذَلِكَ الْيَوْمُ الَّذِي كَسَنَةٍ أَتَكْفِينَا فِيهِ صَلاَةُ يَوْمٍ قَالَ ‏"‏ لاَ اقْدُرُوا لَهُ قَدْرَهُ ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ وَمَا إِسْرَاعُهُ فِي الأَرْضِ قَالَ ‏"‏ كَالْغَيْثِ اسْتَدْبَرَتْهُ الرِّيحُ فَيَأْتِي عَلَى الْقَوْمِ فَيَدْعُوهُمْ فَيُؤْمِنُونَ بِهِ وَيَسْتَجِيبُونَ لَهُ فَيَأْمُرُ السَّمَاءَ فَتُمْطِرُ وَالأَرْضَ فَتُنْبِتُ فَتَرُوحُ عَلَيْهِمْ سَارِحَتُهُمْ أَطْوَلَ مَا كَانَتْ ذُرًا وَأَسْبَغَهُ ضُرُوعًا وَأَمَدَّهُ خَوَاصِرَ ثُمَّ يَأْتِي الْقَوْمَ فَيَدْعُوهُمْ فَيَرُدُّونَ عَلَيْهِ قَوْلَهُ فَيَنْصَرِفُ عَنْهُمْ فَيُصْبِحُونَ مُمْحِلِينَ لَيْسَ بِأَيْدِيهِمْ شَىْءٌ مِنْ أَمْوَالِهِمْ وَيَمُرُّ بِالْخَرِبَةِ فَيَقُولُ لَهَا أَخْرِجِي كُنُوزَكِ ‏.‏ فَتَتْبَعُهُ كُنُوزُهَا كَيَعَاسِيبِ النَّحْلِ ثُمَّ يَدْعُو رَجُلاً مُمْتَلِئًا شَبَابًا فَيَضْرِبُهُ بِالسَّيْفِ فَيَقْطَعُهُ جَزْلَتَيْنِ رَمْيَةَ الْغَرَضِ ثُمَّ يَدْعُوهُ فَيُقْبِلُ وَيَتَهَلَّلُ وَجْهُهُ يَضْحَكُ فَبَيْنَمَا هُوَ كَذَلِكَ إِذْ بَعَثَ اللَّهُ الْمَسِيحَ ابْنَ مَرْيَمَ فَيَنْزِلُ عِنْدَ الْمَنَارَةِ الْبَيْضَاءِ شَرْقِيَّ دِمَشْقَ بَيْنَ مَهْرُودَتَيْنِ وَاضِعًا كَفَّيْهِ عَلَى أَجْنِحَةِ مَلَكَيْنِ إِذَا طَأْطَأَ رَأَسَهُ قَطَرَ وَإِذَا رَفَعَهُ تَحَدَّرَ مِنْهُ جُمَانٌ كَاللُّؤْلُؤِ فَلاَ يَحِلُّ لِكَافِرٍ يَجِدُ رِيحَ نَفَسِهِ إِلاَّ مَاتَ وَنَفَسُهُ يَنْتَهِي حَيْثُ يَنْتَهِي طَرْفُهُ فَيَطْلُبُهُ حَتَّى يُدْرِكَهُ بِبَابِ لُدٍّ فَيَقْتُلُهُ ثُمَّ يَأْتِي عِيسَى ابْنَ مَرْيَمَ قَوْمٌ قَدْ عَصَمَهُمُ اللَّهُ مِنْهُ فَيَمْسَحُ عَنْ وُجُوهِهِمْ وَيُحَدِّثُهُمْ بِدَرَجَاتِهِمْ فِي الْجَنَّةِ فَبَيْنَمَا هُوَ كَذَلِكَ إِذْ أَوْحَى اللَّهُ إِلَى عِيسَى إِنِّي قَدْ أَخْرَجْتُ عِبَادًا لِي لاَ يَدَانِ لأَحَدٍ بِقِتَالِهِمْ فَحَرِّزْ عِبَادِي إِلَى الطُّورِ ‏.‏ وَيَبْعَثُ اللَّهُ يَأْجُوجَ وَمَأْجُوجَ وَهُمْ مِنْ كُلِّ حَدَبٍ يَنْسِلُونَ فَيَمُرُّ أَوَائِلُهُمْ عَلَى بُحَيْرَةِ طَبَرِيَّةَ فَيَشْرَبُونَ مَا فِيهَا وَيَمُرُّ آخِرُهُمْ فَيَقُولُونَ لَقَدْ كَانَ بِهَذِهِ مَرَّةً مَاءٌ ‏.‏ وَيُحْصَرُ نَبِيُّ اللَّهُ عِيسَى وَأَصْحَابُهُ حَتَّى يَكُونَ رَأْسُ الثَّوْرِ لأَحَدِهِمْ خَيْرًا مِنْ مِائَةِ دِينَارٍ لأَحَدِكُمُ الْيَوْمَ فَيَرْغَبُ نَبِيُّ اللَّهِ عِيسَى وَأَصْحَابُهُ فَيُرْسِلُ اللَّهُ عَلَيْهُمُ النَّغَفَ فِي رِقَابِهِمْ فَيُصْبِحُونَ فَرْسَى كَمَوْتِ نَفْسٍ وَاحِدَةٍ ثُمَّ يَهْبِطُ نَبِيُّ اللَّهِ عِيسَى وَأَصْحَابُهُ إِلَى الأَرْضِ فَلاَ يَجِدُونَ فِي الأَرْضِ مَوْضِعَ شِبْرٍ إِلاَّ مَلأَهُ زَهَمُهُمْ وَنَتْنُهُمْ فَيَرْغَبُ نَبِيُّ اللَّهِ عِيسَى وَأَصْحَابُهُ إِلَى اللَّهِ فَيُرْسِلُ اللَّهُ طَيْرًا كَأَعْنَاقِ الْبُخْتِ فَتَحْمِلُهُمْ فَتَطْرَحُهُمْ حَيْثُ شَاءَ اللَّهُ ثُمَّ يُرْسِلُ اللَّهُ مَطَرًا لاَ يَكُنُّ مِنْهُ بَيْتُ مَدَرٍ وَلاَ وَبَرٍ فَيَغْسِلُ الأَرْضَ حَتَّى يَتْرُكَهَا كَالزَّلَفَةِ ثُمَّ يُقَالُ لِلأَرْضِ أَنْبِتِي ثَمَرَتَكِ وَرُدِّي بَرَكَتَكِ ‏.‏ فَيَوْمَئِذٍ تَأْكُلُ الْعِصَابَةُ مِنَ الرُّمَّانَةِ وَيَسْتَظِلُّونَ بِقِحْفِهَا وَيُبَارَكُ فِي الرِّسْلِ حَتَّى أَنَّ اللِّقْحَةَ مِنَ الإِبِلِ لَتَكْفِي الْفِئَامَ مِنَ النَّاسِ وَاللِّقْحَةَ مِنَ الْبَقَرِ لَتَكْفِي الْقَبِيلَةَ مِنَ النَّاسِ وَاللِّقْحَةَ مِنَ الْغَنَمِ لَتَكْفِي الْفَخِذَ مِنَ النَّاسِ فَبَيْنَمَا هُمْ كَذَلِكَ إِذْ بَعَثَ اللَّهُ رِيحًا طَيِّبَةً فَتَأْخُذُهُمْ تَحْتَ آبَاطِهِمْ فَتَقْبِضُ رُوحَ كُلِّ مُؤْمِنٍ وَكُلِّ مُسْلِمٍ وَيَبْقَى شِرَارُ النَّاسِ يَتَهَارَجُونَ فِيهَا تَهَارُجَ الْحُمُرِ فَعَلَيْهِمْ تَقُومُ السَّاعَةُ ‏"‏ ‏.‏\hadithno{7373}\hadithtrans{An-Nawwas b. Sam`an reported that Allah's Messenger (ﷺ) made a mention of the Dajjal one day in the morning. He (ﷺ) sometimes described him to be insignificant and sometimes described (his turmoil) as very significant (and we felt) as if he were in the cluster of the date-palm trees. When we went to him (to the Holy Prophet) in the evening and he read (the signs of fear) in our faces, he (ﷺ) said:What is the matter with you? We said: Allah's Messenger, you made a mention of the Dajjal in the morning (sometimes describing him) to be insignificant and sometimes very important, until we began to think as if he were present in some (near) part of the cluster of the date-palm trees. Thereupon he (ﷺ) said: I harbor fear in regard to you in so many other things besides the Dajjal. If he comes forth while I am among you, I shall contend with him on your behalf, but if he comes forth while I am not amongst you, a man must contend on his own behalf and Allah would take care of every Muslim on my behalf (and safeguard him against his evil). He (Dajjal) would be a young man with twisted, contracted hair, and a blind eye. I compare him to `Abd-ul-`Uzza b. Qatan. He who amongst you would survive to see him should recite over him the opening verses of Sura Kahf (xviii). He would appear on the way between Syria and Iraq and would spread mischief right and left. O servant of Allah! adhere (to the path of Truth). We said: Allah's Messenger, how long would he stay on the earth? He (ﷺ) said: For forty days, one day like a year and one day like a month and one day like a week and the rest of the days would be like your days. We said: Allah's Messenger, would one day's prayer suffice for the prayers of day equal to one year? Thereupon he (ﷺ) said: No, but you must make an estimate of time (and then observe prayer). We said: Allah's Messenger, how quickly would he walk upon the earth? Thereupon he (ﷺ) said: Like cloud driven by the wind. He would come to the people and invite them (to a wrong religion) and they would affirm their faith in him and respond to him. He would then give command to the sky and there would be rainfall upon the earth and it would grow crops. Then in the evening, their pasturing animals would come to them with their humps very high and their udders full of milk and their flanks stretched. He would then come to another people and invite them. But they would reject him and he would go away from them and there would be drought for them and nothing would be left with them in the form of wealth. He would then walk through the waste land and say to it: Bring forth your treasures, and the treasures would come out and collect (themselves) before him like the swarm of bees. He would then call a person brimming with youth and strike him with the sword and cut him into two pieces and (make these pieces lie at a distance which is generally) between the archer and his target. He would then call (that young man) and he will come forward laughing with his face gleaming (with happiness) and it would be at this very time that Allah would send Jesus, son of Mary, and he will descend at the white minaret in the eastern side of Damascus wearing two garments lightly dyed with saffron and placing his hands on the wings of two Angels. When he would lower his head, there would fall beads of perspiration from his head, and when he would raise it up, beads like pearls would scatter from it. Every non-believer who would smell the odor of his self would die and his breath would reach as far as he would be able to see. He would then search for him (Dajjal) until he would catch hold of him at the gate of Ludd and would kill him. Then a people whom Allah had protected would come to Jesus, son of Mary, and he would wipe their faces and would inform them of their ranks in Paradise and it would be under such conditions that Allah would reveal to Jesus these words: I have brought forth from amongst My servants such people against whom none would be able to fight; you take these people safely to Tur. And then Allah would send Gog and Magog and they would swarm down from every slope. The first of them would pass the lake of Tiberias and drink out of it. And when the last of them would pass, he would say: There was once water there. Jesus and his companions would then be besieged here (at Tur, and they would be so much hard pressed) that the head of the ox would be dearer to them than one hundred dinars and Allah's Apostle, Jesus, and his companions would supplicate Allah, Who would send to them insects (which would attack their necks) and in the morning they would perish like one single person. Allah's Apostle, Jesus, and his companions would then come down to the earth and they would not find in the earth as much space as a single span which is not filled with their putrefaction and stench. Allah's Apostle, Jesus, and his companions would then again beseech Allah, Who would send birds whose necks would be like those of Bactrian camels and they would carry them and throw them where God would will. Then Allah would send rain which no house of clay or (the tent of) camels' hairs would keep out and it would wash away the earth until it could appear to be a mirror. Then the earth would be told to bring forth its fruit and restore its blessing and, as a result thereof, there would grow (such a big) pomegranate that a group of persons would be able to eat that, and seek shelter under its skin and milch cow would give so much milk that a whole party would be able to drink it. And the milch camel would give such (a large quantity of) milk that the whole tribe would be able to drink out of that and the milch sheep would give so much milk that the whole family would be able to drink out of that and at that time Allah would send a pleasant wind which would soothe (people) even under their armpits, and would take the life of every Muslim and only the wicked would survive who would commit adultery like asses and the Last Hour would come to them}}
\hadithdefcmd{muslim}{7374}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ، وَالْوَلِيدُ بْنُ مُسْلِمٍ - قَالَ ابْنُ حُجْرٍ دَخَلَ حَدِيثُ أَحَدِهِمَا فِي حَدِيثِ الآخَرِ - عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ بْنِ جَابِرٍ بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ مَا ذَكَرْنَا وَزَادَ بَعْدَ قَوْلِهِ ‏"‏ لَقَدْ كَانَ بِهَذِهِ مَرَّةً مَاءٌ ثُمَّ يَسِيرُونَ حَتَّى يَنْتَهُوا إِلَى جَبَلِ الْخَمَرِ وَهُوَ جَبَلُ بَيْتِ الْمَقْدِسِ فَيَقُولُونَ لَقَدْ قَتَلْنَا مَنْ فِي الأَرْضِ هَلُمَّ فَلْنَقْتُلْ مَنْ فِي السَّمَاءِ ‏.‏ فَيَرْمُونَ بِنُشَّابِهِمْ إِلَى السَّمَاءِ فَيَرُدُّ اللَّهُ عَلَيْهِمْ نُشَّابَهُمْ مَخْضُوبَةً دَمًا ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ حُجْرٍ ‏"‏ فَإِنِّي قَدْ أَنْزَلْتُ عِبَادًا لِي لاَ يَدَىْ لأَحَدٍ بِقِتَالِهِمْ ‏"‏ ‏.‏\hadithno{7374}\hadithtrans{This hadith has been narrated on the authority of Jabir with the same chain of transmitters but with this addition that Gog and Magog would walk until they would reach the mountain of al-Khamar and it is a mountain of Bait-ul-Maqdis and they would say:We have killed those who are upon the earth. Let us now kill those who are In the sky and they would throw their arrows towards the sky and the arrows would return to them besmeared with blood. And in the narration of Ibn Hujr (the words are):" I have sent such persons (Gog and Magog) that none would dare fight against them}}
\hadithdefcmd{muslim}{7375}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَالْحَسَنُ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَأَلْفَاظُهُمْ مُتَقَارِبَةٌ وَالسِّيَاقُ لِعَبْدٍ - قَالَ حَدَّثَنِي وَقَالَ الآخَرَانِ، حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ، قَالَ حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا حَدِيثًا طَوِيلاً عَنِ الدَّجَّالِ فَكَانَ فِيمَا حَدَّثَنَا قَالَ ‏ "‏ يَأْتِي وَهُوَ مُحَرَّمٌ عَلَيْهِ أَنْ يَدْخُلَ نِقَابَ الْمَدِينَةِ فَيَنْتَهِي إِلَى بَعْضِ السِّبَاخِ الَّتِي تَلِي الْمَدِينَةَ فَيَخْرُجُ إِلَيْهِ يَوْمَئِذٍ رَجُلٌ هُوَ خَيْرُ النَّاسِ - أَوْ مِنْ خَيْرِ النَّاسِ - فَيَقُولُ لَهُ أَشْهَدُ أَنَّكَ الدَّجَّالُ الَّذِي حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم حَدِيثَهُ فَيَقُولُ الدَّجَّالُ أَرَأَيْتُمْ إِنْ قَتَلْتُ هَذَا ثُمَّ أَحْيَيْتُهُ أَتَشُكُّونَ فِي الأَمْرِ فَيَقُولُونَ لاَ ‏.‏ قَالَ فَيَقْتُلُهُ ثُمَّ يُحْيِيهِ فَيَقُولُ حِينَ يُحْيِيهِ وَاللَّهِ مَا كُنْتُ فِيكَ قَطُّ أَشَدَّ بَصِيرَةً مِنِّي الآنَ - قَالَ - فَيُرِيدُ الدَّجَّالُ أَنْ يَقْتُلَهُ فَلاَ يُسَلَّطُ عَلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو إِسْحَاقَ يُقَالُ إِنَّ هَذَا الرَّجُلَ هُوَ الْخَضِرُ عَلَيْهِ السَّلاَمُ ‏.‏\hadithno{7375}\hadithtrans{Abu Sa'id al-Khudri reported that Allah's Messenger (ﷺ) one day gave a detailed account of the Dajjal and in that it was also included:He would come but would not be allowed to enter the mountain passes to Medina. So he will alight at some of the barren tracts near Medina, and a person who would be the best of men or one from amongst the best of men would say to him: I bear testimony to the fact that you are Dajjal about whom Allah's Messenger (ﷺ) had informed us. The Dajjal would say: What is your opinion if I kill this (person), then I bring him back to life; even then will you harbour doubt in this matter? They would say: No. He would then kill (the man) and then bring him back to life. When he would bring that person to life, he would say: By Allah, I had no better proof of the fact (that you are a Dajjal) than at the present time (that you are actually so). The Dajjal would then make an attempt to kill him (again) but he would not be able to do that. Abu Ishaq reported that it was said: That person would be Khadir (Allah be pleased with him)}}
\hadithdefcmd{muslim}{7376}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، فِي هَذَا الإِسْنَادِ بِمِثْلِهِ ‏.‏\hadithno{7376}\hadithtrans{This hadith has been narrated by Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{7377}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ قُهْزَاذَ، مِنْ أَهْلِ مَرْوَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ، عَنْ أَبِي حَمْزَةَ، عَنْ قَيْسِ بْنِ وَهْبٍ، عَنْ أَبِي الْوَدَّاكِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَخْرُجُ الدَّجَّالُ فَيَتَوَجَّهُ قِبَلَهُ رَجُلٌ مِنَ الْمُؤْمِنِينَ فَتَلْقَاهُ الْمَسَالِحُ مَسَالِحُ الدَّجَّالِ فَيَقُولُونَ لَهُ أَيْنَ تَعْمِدُ فَيَقُولُ أَعْمِدُ إِلَى هَذَا الَّذِي خَرَجَ - قَالَ - فَيَقُولُونَ لَهُ أَوَمَا تُؤْمِنُ بِرَبِّنَا فَيَقُولُ مَا بِرَبِّنَا خَفَاءٌ ‏.‏ فَيَقُولُونَ اقْتُلُوهُ ‏.‏ فَيَقُولُ بَعْضُهُمْ لِبَعْضٍ أَلَيْسَ قَدْ نَهَاكُمْ رَبُّكُمْ أَنْ تَقْتُلُوا أَحَدًا دُونَهُ - قَالَ - فَيَنْطَلِقُونَ بِهِ إِلَى الدَّجَّالِ فَإِذَا رَآهُ الْمُؤْمِنُ قَالَ يَا أَيُّهَا النَّاسُ هَذَا الدَّجَّالُ الَّذِي ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ فَيَأْمُرُ الدَّجَّالُ بِهِ فَيُشَبَّحُ فَيَقُولُ خُذُوهُ وَشُجُّوهُ ‏.‏ فَيُوسَعُ ظَهْرُهُ وَبَطْنُهُ ضَرْبًا - قَالَ - فَيَقُولُ أَوَمَا تُؤْمِنُ بِي قَالَ فَيَقُولُ أَنْتَ الْمَسِيحُ الْكَذَّابُ - قَالَ - فَيُؤْمَرُ بِهِ فَيُؤْشَرُ بِالْمِئْشَارِ مِنْ مَفْرِقِهِ حَتَّى يُفَرَّقَ بَيْنَ رِجْلَيْهِ - قَالَ - ثُمَّ يَمْشِي الدَّجَّالُ بَيْنَ الْقِطْعَتَيْنِ ثُمَّ يَقُولُ لَهُ قُمْ ‏.‏ فَيَسْتَوِي قَائِمًا - قَالَ - ثُمَّ يَقُولُ لَهُ أَتُؤْمِنُ بِي فَيَقُولُ مَا ازْدَدْتُ فِيكَ إِلاَّ بَصِيرَةً - قَالَ - ثُمَّ يَقُولُ يَا أَيُّهَا النَّاسُ إِنَّهُ لاَ يَفْعَلُ بَعْدِي بِأَحَدٍ مِنَ النَّاسِ - قَالَ - فَيَأْخُذُهُ الدَّجَّالُ لِيَذْبَحَهُ فَيُجْعَلَ مَا بَيْنَ رَقَبَتِهِ إِلَى تَرْقُوَتِهِ نُحَاسًا فَلاَ يَسْتَطِيعُ إِلَيْهِ سَبِيلاً - قَالَ - فَيَأْخُذُ بِيَدَيْهِ وَرِجْلَيْهِ فَيَقْذِفُ بِهِ فَيَحْسِبُ النَّاسُ أَنَّمَا قَذَفَهُ إِلَى النَّارِ وَإِنَّمَا أُلْقِيَ فِي الْجَنَّةِ ‏"‏ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا أَعْظَمُ النَّاسِ شَهَادَةً عِنْدَ رَبِّ الْعَالَمِينَ ‏"‏ ‏.‏\hadithno{7377}\hadithtrans{Abu Sa'id al-Khudri reported Allah's Messenger (ﷺ) as saying:The Dajjal would come forth and a person from amongst the believers would go towards him and the armed men of the Dajjal would meet him and they would say to him: Where do you intend to go? He would say: I intend to go to this one who is coming forth. They would say to him: Don't you believe in our Lord? He would say: There is nothing hidden about our Lord. They would say: Kill him. Then some amongst them would say: Has your master (Dajjal) not forbidden you to kill anyone without (his consent)? And so they would take him to the Dajjal and when the believer would see him, he would say: O people. he is the Dajjil about whom Allah's Messenger (ﷺ) has informed (us). The Dajjal would then order for breaking his head and utter (these words): Catch hold of him and break his head. He would be struck even on his back and on his stomach. Then the Dajjal would ask him: Don't you believe in me? He would say: You are a false Masih. He would then order him to be torn (into pieces) with a saw from the parting of his hair up to his legs. After that the Dajjal would walk between the two pieces. He would then say to him: Stand, and he would stand erect. He would then say to him: Don't you believe in me? And the person would say: It has only added to my insight concerning you (that you are really the Dajjal). He would then say: O people, he would not behave with anyone amongst people (in such a manner) after me. The Dajjal would try to catch hold of him so that he should kill him (again). The space between his neck and collar bone would be turned into copper and he would find no means to kill him. So he would catch hold of him by his hand and feet and throw him (into the air) and the people would think as if he had been thrown in the Hell-Fire whereas he would be thrown in Paradise. Thereupon Allah's Messenger (ﷺ) said: He would be the most eminent amongst persons in regard to martyrdom in the eye of the Lord of the world}}
\hadithdefcmd{muslim}{7378}{حَدَّثَنَا شِهَابُ بْنُ عَبَّادٍ الْعَبْدِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ حُمَيْدٍ الرُّؤَاسِيُّ، عَنْ إِسْمَاعِيلَ، بْنِ أَبِي خَالِدٍ عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنِ الْمُغِيرَةِ بْنِ شُعْبَةَ، قَالَ مَا سَأَلَ أَحَدٌ النَّبِيَّ صلى الله عليه وسلم عَنِ الدَّجَّالِ أَكْثَرَ مِمَّا سَأَلْتُ قَالَ ‏"‏ وَمَا يُنْصِبُكَ مِنْهُ إِنَّهُ لاَ يَضُرُّكَ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّهُمْ يَقُولُونَ إِنَّ مَعَهُ الطَّعَامَ وَالأَنْهَارَ قَالَ ‏"‏ هُوَ أَهْوَنُ عَلَى اللَّهِ مِنْ ذَلِكَ ‏"‏ ‏.‏\hadithno{7378}\hadithtrans{Mughira b. Shu'ba reported:No one asked Allah's Messenger (ﷺ) more about Dajjil than I asked him. He said: He should not be a source of worry to you for he would not be able to do any harm to you. I said: Allah's Messenger, it is alleged that he would have along with him (abundance of) food and water. Thereupon he said: He would be very insignificant in the eye of Allah (even) with all this}}
\hadithdefcmd{muslim}{7379}{حَدَّثَنَا سُرَيْجُ بْنُ يُونُسَ، حَدَّثَنَا هُشَيْمٌ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنِ الْمُغِيرَةِ، بْنِ شُعْبَةَ قَالَ مَا سَأَلَ أَحَدٌ النَّبِيَّ صلى الله عليه وسلم عَنِ الدَّجَّالِ أَكْثَرَ مِمَّا سَأَلْتُهُ قَالَ ‏"‏ وَمَا سُؤَالُكَ ‏"‏ ‏.‏ قَالَ قُلْتُ إِنَّهُمْ يَقُولُونَ مَعَهُ جِبَالٌ مِنْ خُبْزٍ وَلَحْمٍ وَنَهَرٌ مِنْ مَاءٍ ‏.‏ قَالَ ‏"‏ هُوَ أَهْوَنُ عَلَى اللَّهِ مِنْ ذَلِكَ ‏"‏ ‏.‏\hadithno{7379}\hadithtrans{Mughira b. Shu'ba reported that none asked Allah's Apostle (ﷺ) about Dajjal more than I asked him. I (one of the narrators other than Mughira b. Shu'ba) said:What did you ask? Mughira replied: I said that the people alleged that he would have a mountain load of bread and mutton and rivers of water. Thereupon he said: He would be more insignificant in the eye of Allah compared with all this}}
\hadithdefcmd{muslim}{7380}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا إِسْحَاقُ، بْنُ إِبْرَاهِيمَ أَخْبَرَنَا جَرِيرٌ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ، أَبِي شَيْبَةَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو أُسَامَةَ، كُلُّهُمْ عَنْ إِسْمَاعِيلَ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَ حَدِيثِ إِبْرَاهِيمَ بْنِ حُمَيْدٍ وَزَادَ فِي حَدِيثِ يَزِيدَ فَقَالَ لِي ‏ "‏ أَىْ بُنَىَّ ‏"‏ ‏.‏\hadithno{7380}\hadithtrans{This hadith has been narrated on the authority of Isma'il through other chains of transmitters with a slight variation of wording}}
\hadithdefcmd{muslim}{7381}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنِ النُّعْمَانِ بْنِ سَالِمٍ، قَالَ سَمِعْتُ يَعْقُوبَ بْنَ عَاصِمِ بْنِ عُرْوَةَ بْنِ مَسْعُودٍ الثَّقَفِيَّ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو، وَجَاءَهُ رَجُلٌ فَقَالَ مَا هَذَا الْحَدِيثُ الَّذِي تُحَدِّثُ بِهِ تَقُولُ إِنَّ السَّاعَةَ تَقُومُ إِلَى كَذَا وَكَذَا ‏.‏ فَقَالَ سُبْحَانَ اللَّهِ - أَوْ لاَ إِلَهَ إِلاَّ اللَّهُ أَوْ كَلِمَةً نَحْوَهُمَا - لَقَدْ هَمَمْتُ أَنْ لاَ أُحَدِّثَ أَحَدًا شَيْئًا أَبَدًا إِنَّمَا قُلْتُ إِنَّكُمْ سَتَرَوْنَ بَعْدَ قَلِيلٍ أَمْرًا عَظِيمًا يُحَرَّقُ الْبَيْتُ وَيَكُونُ وَيَكُونُ ثُمَّ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَخْرُجُ الدَّجَّالُ فِي أُمَّتِي فَيَمْكُثُ أَرْبَعِينَ - لاَ أَدْرِي أَرْبَعِينَ يَوْمًا أَوْ أَرْبَعِينَ شَهْرًا أَوْ أَرْبَعِينَ عَامًا - فَيَبْعَثُ اللَّهُ عِيسَى ابْنَ مَرْيَمَ كَأَنَّهُ عُرْوَةُ بْنُ مَسْعُودٍ فَيَطْلُبُهُ فَيُهْلِكُهُ ثُمَّ يَمْكُثُ النَّاسُ سَبْعَ سِنِينَ لَيْسَ بَيْنَ اثْنَيْنِ عَدَاوَةٌ ثُمَّ يُرْسِلُ اللَّهُ رِيحًا بَارِدَةً مِنْ قِبَلِ الشَّأْمِ فَلاَ يَبْقَى عَلَى وَجْهِ الأَرْضِ أَحَدٌ فِي قَلْبِهِ مِثْقَالُ ذَرَّةٍ مِنْ خَيْرٍ أَوْ إِيمَانٍ إِلاَّ قَبَضَتْهُ حَتَّى لَوْ أَنَّ أَحَدَكُمْ دَخَلَ فِي كَبَدِ جَبَلٍ لَدَخَلَتْهُ عَلَيْهِ حَتَّى تَقْبِضَهُ ‏"‏ ‏.‏ قَالَ سَمِعْتُهَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ فَيَبْقَى شِرَارُ النَّاسِ فِي خِفَّةِ الطَّيْرِ وَأَحْلاَمِ السِّبَاعِ لاَ يَعْرِفُونَ مَعْرُوفًا وَلاَ يُنْكِرُونَ مُنْكَرًا فَيَتَمَثَّلُ لَهُمُ الشَّيْطَانُ فَيَقُولُ أَلاَ تَسْتَجِيبُونَ فَيَقُولُونَ فَمَا تَأْمُرُنَا فَيَأْمُرُهُمْ بِعِبَادَةِ الأَوْثَانِ وَهُمْ فِي ذَلِكَ دَارٌّ رِزْقُهُمْ حَسَنٌ عَيْشُهُمْ ثُمَّ يُنْفَخُ فِي الصُّورِ فَلاَ يَسْمَعُهُ أَحَدٌ إِلاَّ أَصْغَى لِيتًا وَرَفَعَ لِيتًا - قَالَ - وَأَوَّلُ مَنْ يَسْمَعُهُ رَجُلٌ يَلُوطُ حَوْضَ إِبِلِهِ - قَالَ - فَيَصْعَقُ وَيَصْعَقُ النَّاسُ ثُمَّ يُرْسِلُ اللَّهُ - أَوْ قَالَ يُنْزِلُ اللَّهُ - مَطَرًا كَأَنَّهُ الطَّلُّ أَوِ الظِّلُّ - نُعْمَانُ الشَّاكُّ - فَتَنْبُتُ مِنْهُ أَجْسَادُ النَّاسِ ثُمَّ يُنْفَخُ فِيهِ أُخْرَى فَإِذَا هُمْ قِيَامٌ يَنْظُرُونَ ثُمَّ يُقَالُ يَا أَيُّهَا النَّاسُ هَلُمَّ إِلَى رَبِّكُمْ ‏.‏ وَقِفُوهُمْ إِنَّهُمْ مَسْئُولُونَ - قَالَ - ثُمَّ يُقَالُ أَخْرِجُوا بَعْثَ النَّارِ فَيُقَالُ مِنْ كَمْ فَيُقَالُ مِنْ كُلِّ أَلْفٍ تِسْعَمِائَةٍ وَتِسْعَةً وَتِسْعِينَ - قَالَ - فَذَاكَ يَوْمَ يَجْعَلُ الْوِلْدَانَ شِيبًا وَذَلِكَ يَوْمَ يُكْشَفُ عَنْ سَاقٍ ‏"‏ ‏.‏\hadithno{7381}\hadithtrans{Abdullah b. 'Amr reported that a person came to him and said:What is this hadith that you narrate that the Last Hour would come at such and such time? Thereupon he said: Hallowed be Allah, there is no god but Allah (or the words to the same effect). I have decided that I would not narrate anything to anyone now. I had only said that you would see after some time an important event that the (sacred) House (Ka'ba) would be burnt and it would happen and definitely happen. He then reported that Allah's Messenger (ﷺ) said: The Dajjal would appear in my Ummah and he would stay (in the world) for forty - I cannot say whether he meant forty days, forty months or forty years. And Allah would then send Jesus son of Mary who would resemble 'Urwa b Mas'ud. He (Jesus Christ) would chase him and kill him. Then people would live for seven years that there would be no rancour between two persons. Then Allah would send cold wind from the side of Syria that none would survive upon the earth having a speck of good in him or faith in him but he would die, so much so that even if some amongst you were to enter the innermost part of the mountain, this wind would reach that place also and that would cause his death. I heard Allah's Messenger (ﷺ) as saying: Only the wicked people would survive and they would be as careless as birds with the characteristics of beasts. They would never appreciate the good nor condemn evil. Then Satan would come to them in human form and would say: Don't you respond? And they would say: What do you order us? And he would command them to worship the idols but, in spite of this, they would have abundance of sustenance and lead comfortable lives. Then the trumpet would be blown and no one would hear that but he would bend his neck to one side and raise it from the other side and the first one to hear that trumpet would be the person who would be busy in setting right the tank meant for providing water to the camels. He would swoon and the other people would also swoon, then Allah would send or He would cause to send rain which would be like dew and there would grow out of it the bodies of the people. Then the second trumpet would be blown and they would stand up and begin to look (around). Then it would be said: O people, go to your Lord, and make them stand there. And they would be questioned. Then it would be said: Bring out a group (out of them) for the Hell-Fire. And then it would be asked: How much? It would be said: Nine hundred and ninty-nine out of one thousand for the Hell-Fire and that would be the day which would make the children old because of its terror and that would be the day about which it has been said: "On the day when the shank would be uncovered" (lxviii)}}
\hadithdefcmd{muslim}{7382}{وَحَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ النُّعْمَانِ بْنِ، سَالِمٍ قَالَ سَمِعْتُ يَعْقُوبَ بْنَ عَاصِمِ بْنِ عُرْوَةَ بْنِ مَسْعُودٍ، قَالَ سَمِعْتُ رَجُلاً، قَالَ لِعَبْدِ اللَّهِ بْنِ عَمْرٍو إِنَّكَ تَقُولُ إِنَّ السَّاعَةَ تَقُومُ إِلَى كَذَا وَكَذَا فَقَالَ لَقَدْ هَمَمْتُ أَنْ لاَ أُحَدِّثَكُمْ بِشَىْءٍ إِنَّمَا قُلْتُ إِنَّكُمْ تَرَوْنَ بَعْدَ قَلِيلٍ أَمْرًا عَظِيمًا ‏.‏ فَكَانَ حَرِيقَ الْبَيْتِ - قَالَ شُعْبَةُ هَذَا أَوْ نَحْوَهُ - قَالَ عَبْدُ اللَّهِ بْنُ عَمْرٍو قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَخْرُجُ الدَّجَّالُ فِي أُمَّتِي ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ بِمِثْلِ حَدِيثِ مُعَاذٍ وَقَالَ فِي حَدِيثِهِ ‏"‏ فَلاَ يَبْقَى أَحَدٌ فِي قَلْبِهِ مِثْقَالُ ذَرَّةٍ مِنْ إِيمَانٍ إِلاَّ قَبَضَتْهُ ‏"‏ ‏.‏ قَالَ مُحَمَّدُ بْنُ جَعْفَرٍ حَدَّثَنِي شُعْبَةُ بِهَذَا الْحَدِيثِ مَرَّاتٍ وَعَرَضْتُهُ عَلَيْهِ ‏.‏\hadithno{7382}\hadithtrans{Ya'qub b. 'Asim b. Urwa b. Mas'ud reported:I heard a person saying to 'Abdullah b. Amr: You say that the Last Hour would come at such and such time, whereupon he said: I had made up my mind that I would not narrate anything to you. I only said: But you would soon see after some time a very significant affair, for example the burning of the House (Ka'ba). Shu'ba said like this and 'Abdullah b Amr reported Allah's Messenger (ﷺ) having said: The Dajjal would appear in my Ummah. And in another hadith (the words are): None would survive who would have even a speck of faith in his heart, but he would be dead. Muhammad b. Ja'far reported that Shu'ba narrated to him this hadith many a time and I also read it out to him many a time}}
\hadithdefcmd{muslim}{7383}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، عَنْ أَبِي حَيَّانَ، عَنْ أَبِي زُرْعَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ حَفِظْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم حَدِيثًا لَمْ أَنْسَهُ بَعْدُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ أَوَّلَ الآيَاتِ خُرُوجًا طُلُوعُ الشَّمْسِ مِنْ مَغْرِبِهَا وَخُرُوجُ الدَّابَّةِ عَلَى النَّاسِ ضُحًى وَأَيُّهُمَا مَا كَانَتْ قَبْلَ صَاحِبَتِهَا فَالأُخْرَى عَلَى إِثْرِهَا قَرِيبًا ‏"‏ ‏.‏\hadithno{7383}\hadithtrans{Abdullah b. `Amr reported:I committed to memory a hadith from Allah's Messenger (ﷺ) and I did not forget it after I had heard Allah's Messenger (ﷺ) as saying: The first sign (out of the signs of the appearance of the Dajjal) would be the appearance of the sun from the west, the appearance of the beast before the people in the forenoon and which of the two happens first, the second one would follow immediately after that}}
\hadithdefcmd{muslim}{7384}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا أَبُو حَيَّانَ، عَنْ أَبِي زُرْعَةَ، قَالَ جَلَسَ إِلَى مَرْوَانَ بْنِ الْحَكَمِ بِالْمَدِينَةِ ثَلاَثَةُ نَفَرٍ مِنَ الْمُسْلِمِينَ فَسَمِعُوهُ وَهُوَ، يُحَدِّثُ عَنِ الآيَاتِ، أَنَّ أَوَّلَهَا، خُرُوجًا الدَّجَّالُ فَقَالَ عَبْدُ اللَّهِ بْنُ عَمْرٍو لَمْ يَقُلْ مَرْوَانُ شَيْئًا قَدْ حَفِظْتُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم حَدِيثًا لَمْ أَنْسَهُ بَعْدُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏ فَذَكَرَ بِمِثْلِهِ ‏.‏\hadithno{7384}\hadithtrans{Abu Zur'a reported that three persons amongst Muslims had been sitting in Medina in the presence of Marwan b. Hakam and they heard him narrate these signs from him and the first amongst them was the appearance of the Dajjal. 'Abdullah b. 'Amr reported that Marwin said nothing (particular in this connection). I, however, heard a hadith from Allah's Messenger (ﷺ) and I did not forget that after I had heard that from Allah's Apostle (ﷺ) and he reported a hadith like the foregoing}}
\hadithdefcmd{muslim}{7385}{وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي حَيَّانَ، عَنْ أَبِي زُرْعَةَ، قَالَ تَذَاكَرُوا السَّاعَةَ عِنْدَ مَرْوَانَ فَقَالَ عَبْدُ اللَّهِ بْنُ عَمْرٍو سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏ بِمِثْلِ حَدِيثِهِمَا وَلَمْ يَذْكُرْ ضُحًى ‏.‏\hadithno{7385}\hadithtrans{Abu Zur'a reported that there was a discussion in the presence of Marwan about the Last Hour, and Abdullah b. 'Amr said:I heard Allah's Messenger (ﷺ) as saying. The rest of the hadith is the same, but there is no mention of forenoon}}
\hadithdefcmd{muslim}{7386}{حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ عَبْدِ الصَّمَدِ بْنِ عَبْدِ الْوَارِثِ، وَحَجَّاجُ بْنُ الشَّاعِرِ، كِلاَهُمَا عَنْ عَبْدِ الصَّمَدِ، - وَاللَّفْظُ لِعَبْدِ الْوَارِثِ بْنِ عَبْدِ الصَّمَدِ - حَدَّثَنَا أَبِي، عَنْ جَدِّي، عَنِ الْحُسَيْنِ، بْنِ ذَكْوَانَ حَدَّثَنَا ابْنُ بُرَيْدَةَ، حَدَّثَنِي عَامِرُ بْنُ شَرَاحِيلَ الشَّعْبِيُّ، شَعْبُ هَمْدَانَ أَنَّهُ سَأَلَ فَاطِمَةَ بِنْتَ قَيْسٍ أُخْتَ الضَّحَّاكِ بْنِ قَيْسٍ وَكَانَتْ مِنَ الْمُهَاجِرَاتِ الأُوَلِ فَقَالَ حَدِّثِينِي حَدِيثًا سَمِعْتِيهِ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم لاَ تُسْنِدِيهِ إِلَى أَحَدٍ غَيْرِهِ فَقَالَتْ لَئِنْ شِئْتَ لأَفْعَلَنَّ فَقَالَ لَهَا أَجَلْ حَدِّثِينِي ‏.‏ فَقَالَتْ نَكَحْتُ ابْنَ الْمُغِيرَةِ وَهُوَ مِنْ خِيَارِ شَبَابِ قُرَيْشٍ يَوْمَئِذٍ فَأُصِيبَ فِي أَوَّلِ الْجِهَادِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا تَأَيَّمْتُ خَطَبَنِي عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ فِي نَفَرٍ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَخَطَبَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى مَوْلاَهُ أُسَامَةَ بْنِ زَيْدٍ وَكُنْتُ قَدْ حُدِّثْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَحَبَّنِي فَلْيُحِبَّ أُسَامَةَ ‏"‏ ‏.‏ فَلَمَّا كَلَّمَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم قُلْتُ أَمْرِي بِيَدِكَ فَأَنْكِحْنِي مَنْ شِئْتَ فَقَالَ ‏"‏ انْتَقِلِي إِلَى أُمِّ شَرِيكٍ ‏"‏ ‏.‏ وَأُمُّ شَرِيكٍ امْرَأَةٌ غَنِيَّةٌ مِنَ الأَنْصَارِ عَظِيمَةُ النَّفَقَةِ فِي سَبِيلِ اللَّهِ يَنْزِلُ عَلَيْهَا الضِّيفَانُ فَقُلْتُ سَأَفْعَلُ فَقَالَ ‏"‏ لاَ تَفْعَلِي إِنَّ أُمَّ شَرِيكٍ امْرَأَةٌ كَثِيرَةُ الضِّيفَانِ فَإِنِّي أَكْرَهُ أَنْ يَسْقُطَ عَنْكِ خِمَارُكِ أَوْ يَنْكَشِفَ الثَّوْبُ عَنْ سَاقَيْكِ فَيَرَى الْقَوْمُ مِنْكِ بَعْضَ مَا تَكْرَهِينَ وَلَكِنِ انْتَقِلِي إِلَى ابْنِ عَمِّكِ عَبْدِ اللَّهِ بْنِ عَمْرٍو ابْنِ أُمِّ مَكْتُومٍ ‏"‏ ‏.‏ - وَهُوَ رَجُلٌ مِنْ بَنِي فِهْرٍ فِهْرِ قُرَيْشٍ وَهُوَ مِنَ الْبَطْنِ الَّذِي هِيَ مِنْهُ - فَانْتَقَلْتُ إِلَيْهِ فَلَمَّا انْقَضَتْ عِدَّتِي سَمِعْتُ نِدَاءَ الْمُنَادِي مُنَادِي رَسُولِ اللَّهِ صلى الله عليه وسلم يُنَادِي الصَّلاَةَ جَامِعَةً ‏.‏ فَخَرَجْتُ إِلَى الْمَسْجِدِ فَصَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَكُنْتُ فِي صَفِّ النِّسَاءِ الَّتِي تَلِي ظُهُورَ الْقَوْمِ فَلَمَّا قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَتَهُ جَلَسَ عَلَى الْمِنْبَرِ وَهُوَ يَضْحَكُ فَقَالَ ‏"‏ لِيَلْزَمْ كُلُّ إِنْسَانٍ مُصَلاَّهُ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ أَتَدْرُونَ لِمَ جَمَعْتُكُمْ ‏"‏ ‏.‏ قَالُوا اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ إِنِّي وَاللَّهِ مَا جَمَعْتُكُمْ لِرَغْبَةٍ وَلاَ لِرَهْبَةٍ وَلَكِنْ جَمَعْتُكُمْ لأَنَّ تَمِيمًا الدَّارِيَّ كَانَ رَجُلاً نَصْرَانِيًّا فَجَاءَ فَبَايَعَ وَأَسْلَمَ وَحَدَّثَنِي حَدِيثًا وَافَقَ الَّذِي كُنْتُ أُحَدِّثُكُمْ عَنْ مَسِيحِ الدَّجَّالِ حَدَّثَنِي أَنَّهُ رَكِبَ فِي سَفِينَةٍ بَحْرِيَّةٍ مَعَ ثَلاَثِينَ رَجُلاً مِنْ لَخْمٍ وَجُذَامَ فَلَعِبَ بِهِمُ الْمَوْجُ شَهْرًا فِي الْبَحْرِ ثُمَّ أَرْفَئُوا إِلَى جَزِيرَةٍ فِي الْبَحْرِ حَتَّى مَغْرِبِ الشَّمْسِ فَجَلَسُوا فِي أَقْرُبِ السَّفِينَةِ فَدَخَلُوا الْجَزِيرَةَ فَلَقِيَتْهُمْ دَابَّةٌ أَهْلَبُ كَثِيرُ الشَّعَرِ لاَ يَدْرُونَ مَا قُبُلُهُ مِنْ دُبُرِهِ مِنْ كَثْرَةِ الشَّعَرِ فَقَالُوا وَيْلَكِ مَا أَنْتِ فَقَالَتْ أَنَا الْجَسَّاسَةُ ‏.‏ قَالُوا وَمَا الْجَسَّاسَةُ قَالَتْ أَيُّهَا الْقَوْمُ انْطَلِقُوا إِلَى هَذَا الرَّجُلِ فِي الدَّيْرِ فَإِنَّهُ إِلَى خَبَرِكُمْ بِالأَشْوَاقِ ‏.‏ قَالَ لَمَّا سَمَّتْ لَنَا رَجُلاً فَرِقْنَا مِنْهَا أَنْ تَكُونَ شَيْطَانَةً - قَالَ - فَانْطَلَقْنَا سِرَاعًا حَتَّى دَخَلْنَا الدَّيْرَ فَإِذَا فِيهِ أَعْظَمُ إِنْسَانٍ رَأَيْنَاهُ قَطُّ خَلْقًا وَأَشَدُّهُ وِثَاقًا مَجْمُوعَةٌ يَدَاهُ إِلَى عُنُقِهِ مَا بَيْنَ رُكْبَتَيْهِ إِلَى كَعْبَيْهِ بِالْحَدِيدِ قُلْنَا وَيْلَكَ مَا أَنْتَ قَالَ قَدْ قَدَرْتُمْ عَلَى خَبَرِي فَأَخْبِرُونِي مَا أَنْتُمْ قَالُوا نَحْنُ أُنَاسٌ مِنَ الْعَرَبِ رَكِبْنَا فِي سَفِينَةٍ بَحْرِيَّةٍ فَصَادَفْنَا الْبَحْرَ حِينَ اغْتَلَمَ فَلَعِبَ بِنَا الْمَوْجُ شَهْرًا ثُمَّ أَرْفَأْنَا إِلَى جَزِيرَتِكَ هَذِهِ فَجَلَسْنَا فِي أَقْرُبِهَا فَدَخَلْنَا الْجَزِيرَةَ فَلَقِيَتْنَا دَابَّةٌ أَهْلَبُ كَثِيرُ الشَّعَرِ لاَ يُدْرَى مَا قُبُلُهُ مِنْ دُبُرِهِ مِنْ كَثْرَةِ الشَّعَرِ فَقُلْنَا وَيْلَكِ مَا أَنْتِ فَقَالَتْ أَنَا الْجَسَّاسَةُ ‏.‏ قُلْنَا وَمَا الْجَسَّاسَةُ قَالَتِ اعْمِدُوا إِلَى هَذَا الرَّجُلِ فِي الدَّيْرِ فَإِنَّهُ إِلَى خَبَرِكُمْ بِالأَشْوَاقِ فَأَقْبَلْنَا إِلَيْكَ سِرَاعًا وَفَزِعْنَا مِنْهَا وَلَمْ نَأْمَنْ أَنْ تَكُونَ شَيْطَانَةً فَقَالَ أَخْبِرُونِي عَنْ نَخْلِ بَيْسَانَ قُلْنَا عَنْ أَىِّ شَأْنِهَا تَسْتَخْبِرُ قَالَ أَسْأَلُكُمْ عَنْ نَخْلِهَا هَلْ يُثْمِرُ قُلْنَا لَهُ نَعَمْ ‏.‏ قَالَ أَمَا إِنَّهُ يُوشِكُ أَنْ لاَ تُثْمِرَ قَالَ أَخْبِرُونِي عَنْ بُحَيْرَةِ الطَّبَرِيَّةِ ‏.‏ قُلْنَا عَنْ أَىِّ شَأْنِهَا تَسْتَخْبِرُ قَالَ هَلْ فِيهَا مَاءٌ قَالُوا هِيَ كَثِيرَةُ الْمَاءِ ‏.‏ قَالَ أَمَا إِنَّ مَاءَهَا يُوشِكُ أَنْ يَذْهَبَ ‏.‏ قَالَ أَخْبِرُونِي عَنْ عَيْنِ زُغَرَ ‏.‏ قَالُوا عَنْ أَىِّ شَأْنِهَا تَسْتَخْبِرُ قَالَ هَلْ فِي الْعَيْنِ مَاءٌ وَهَلْ يَزْرَعُ أَهْلُهَا بِمَاءِ الْعَيْنِ قُلْنَا لَهُ نَعَمْ هِيَ كَثِيرَةُ الْمَاءِ وَأَهْلُهَا يَزْرَعُونَ مِنْ مَائِهَا ‏.‏ قَالَ أَخْبِرُونِي عَنْ نَبِيِّ الأُمِّيِّينَ مَا فَعَلَ قَالُوا قَدْ خَرَجَ مِنْ مَكَّةَ وَنَزَلَ يَثْرِبَ ‏.‏ قَالَ أَقَاتَلَهُ الْعَرَبُ قُلْنَا نَعَمْ ‏.‏ قَالَ كَيْفَ صَنَعَ بِهِمْ فَأَخْبَرْنَاهُ أَنَّهُ قَدْ ظَهَرَ عَلَى مَنْ يَلِيهِ مِنَ الْعَرَبِ وَأَطَاعُوهُ قَالَ لَهُمْ قَدْ كَانَ ذَلِكَ قُلْنَا نَعَمْ ‏.‏ قَالَ أَمَا إِنَّ ذَاكَ خَيْرٌ لَهُمْ أَنْ يُطِيعُوهُ وَإِنِّي مُخْبِرُكُمْ عَنِّي إِنِّي أَنَا الْمَسِيحُ وَإِنِّي أُوشِكُ أَنْ يُؤْذَنَ لِي فِي الْخُرُوجِ فَأَخْرُجَ فَأَسِيرَ فِي الأَرْضِ فَلاَ أَدَعَ قَرْيَةً إِلاَّ هَبَطْتُهَا فِي أَرْبَعِينَ لَيْلَةً غَيْرَ مَكَّةَ وَطَيْبَةَ فَهُمَا مُحَرَّمَتَانِ عَلَىَّ كِلْتَاهُمَا كُلَّمَا أَرَدْتُ أَنْ أَدْخُلَ وَاحِدَةً أَوْ وَاحِدًا مِنْهُمَا اسْتَقْبَلَنِي مَلَكٌ بِيَدِهِ السَّيْفُ صَلْتًا يَصُدُّنِي عَنْهَا وَإِنَّ عَلَى كُلِّ نَقْبٍ مِنْهَا مَلاَئِكَةً يَحْرُسُونَهَا قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَطَعَنَ بِمِخْصَرَتِهِ فِي الْمِنْبَرِ ‏"‏ هَذِهِ طَيْبَةُ هَذِهِ طَيْبَةُ هَذِهِ طَيْبَةُ ‏"‏ ‏.‏ يَعْنِي الْمَدِينَةَ ‏"‏ أَلاَ هَلْ كُنْتُ حَدَّثْتُكُمْ ذَلِكَ ‏"‏ ‏.‏ فَقَالَ النَّاسُ نَعَمْ ‏"‏ فَإِنَّهُ أَعْجَبَنِي حَدِيثُ تَمِيمٍ أَنَّهُ وَافَقَ الَّذِي كُنْتُ أُحَدِّثُكُمْ عَنْهُ وَعَنِ الْمَدِينَةِ وَمَكَّةَ أَلاَ إِنَّهُ فِي بَحْرِ الشَّامِ أَوْ بَحْرِ الْيَمَنِ لاَ بَلْ مِنْ قِبَلِ الْمَشْرِقِ ما هُوَ مِنْ قِبَلِ الْمَشْرِقِ مَا هُوَ مِنْ قِبَلِ الْمَشْرِقِ مَا هُوَ ‏"‏ ‏.‏ وَأَوْمَأَ بِيَدِهِ إِلَى الْمَشْرِقِ ‏.‏ قَالَتْ فَحَفِظْتُ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{7386}\hadithtrans{Amir b. Sharahil Sha'bi Sha'b Hamdan reported that he asked Fatima, daughter of Qais and sister of ad-Dahhak b. Qais and she was the first amongst the emigrant women:Narrate to me a hadith which you had heard directly from Allah's Messenger (ﷺ) and there is no extra link in between them. She said: Very well, if you like, I am prepared to do that, and he said to her: Well, do It and narrate that to me. She said: I married the son of Mughira and he was a chosen young man of Quraish at that time, but he fell as a martyr in the first Jihad (fighting) on the side of Allah's Messenger (ﷺ). When I became a widow, 'Abd al-Rahman b. Auf, one amongst the group of the Companions of Allah's Messenger (ﷺ), sent me the proposal of marriage. Allah's Messenger (ﷺ) also sent me such a message for his freed slave Usama b. Zaid. And it had been conveyed to me that Allah's Messenger (ﷺ) had said (about Usama): He who loves me should also love Usama. When Allah's Messenger (ﷺ) talked to me (about this matter), I said: My affairs are in your hand. You may marry me to anyone whom you like. He said: You better shift now to the house of Umm Sharik, and Umm Sharik was a rich lady from amongst the Ansar. She spent generously for the cause of Allah and entertained guests very hospitably. I said: Well, I will do as you like. He said: Do not do that for Umm Sharik is a woman who is very frequently visited by guests and I do not like that your head may be uncovered or the cloth may be removed from your shank and the strangers may catch sight of them which you abhor. You better shift to the house of your cousin 'Abdullah b. 'Amr b. Umm Maktum and he is a person of the Bani Fihr branch of the Quraish, and he belonged to that tribe (to which Fatima) belonged. So I shifted to that house, and when my period of waiting was over, I heard the voice of an announcer making an announcement that the prayer would be observed in the mosque (where) congregational prayer (is observed). So I set out towards that mosque and observed prayer along with Allah's Messenger (ﷺ) and I was in the row of the women which was near the row of men. When Allah's Messenger (ﷺ) had finished his prayer, he sat on the pulpit smiling and said: Every worshipper should keep sitting at his place. He then said: Do you know why I had asked you to assemble? They said: Allah and His Messenger know best. He said: By Allah. I have not made you assemble for exhortation or for a warning, but I have detained you here, for Tamim Dari, a Christian, who came and accepted Islam, told me something, which agrees with what I was telling, you about the Dajjal. He narrated to me that he had sailed in a ship along with thirty men of Bani Lakhm and Bani Judham and had been tossed by waves in the ocean for a month. Then these (waves) took them (near) the land within the ocean (island) at the time of sunset. They sat in a small side-boat and entered that island. There was a beast with long thick hair (and because of these) they could not distinguish his face from his back. They said: Woe to you, who can you be? Thereupon it said: I am al-Jassasa. They said: What is al-Jassasa? And it said: O people, go to this person in the monastery as he is very much eager to know about you. He (the narrator) said: When it named a person for us we were afraid of it lest it should be a devil. Then we hurriedly went on till we came to that monastery and found a well-built person there with his hands tied to his neck and having iron shackles between his two legs up to the ankles. We said: Woe be upon thee, who are you? And he said: You would soon come to know about me. but tell me who are you. We said: We are people from Arabia and we embarked upon a boat but the sea-waves had been driving us for one month and they brought as near this island. We got Into the side-boats and entered this island and here a beast met us with profusely thick hair and because of the thickness of his hair his face could not be distinguished from his back. We said: Woe be to thee, who are you? It said: I am al- Jassasa. We said: What is al-Jassasa? And it said: You go to this very person in the monastery for he is eagerly waiting for you to know about you. So we came to you in hot haste fearing that that might be the Devil. He (that chained person) said: Tell me about the date-palm trees of Baisan. We said: About what aspect of theirs do you seek information? He said: I ask you whether these trees bear fruit or not. We said: yes. Thereupon he said: I think these would not bear fruits. He said: Inform me about the lake of Tabariyya? We said: Which aspect of it do you want to know? He said: Is there water in it? They said: There is abundance of water in it. Thereupon he said: I think it would soon become dry. He again said: Inform me about the spring of Zughar. They said: Which aspect of it you want to know? He (the chained person) said: Is there water in it and does it irrigate (the land)? We said to him: Yes, there is abundance of water in it and the inhabitants (of Medina) irrigate (land) with the help of it, He said: Inform me about the unlettered Prophet; what has he done? We said: He has come out from Mecca and has settled In Yathrib (Medina). He said: Do the Arabs fight against him? We said: Yes. He said: How did he deal with them? We informed him that he had overcome those in his neighbourhood and they had submitted themselves before him. Thereupon he said to us: Has it actually happened? We said: Yes. Thereupon he said: If it is so that is better for them that they should show obedience to him. I am going to tell you about myself and I am Dajjal and would be soon permitted to get out and so I shall get out and travel in the land, and will not spare any town where I would not stay for forty nights except Mecca and Medina as these two (places) are prohibited (areas) for me and I would not make an attempt to enter any one of these two. An angel with a sword in his hand would confront me and would bar my way and there would be angels to guard every passage leading to it; then Allah's Messenger (ﷺ) striking the pulpit with the help of the end of his staff said: This implies Taiba meaning Medina. Have I not, told you an account (of the Dajjal) like this? 'The people said: Yes, and this account narrated by Tamim Dari was liked by me for it corroborates the account which I gave to you in regard to him (Dajjal) at Medina and Mecca. Behold he (Dajjal) is in the Syrian sea (Mediterranean) or the Yemen sea (Arabian sea). Nay, on the contrary, he is in the east, he is in the east, he is in the east, and he pointed with his hand towards the east. I (Fatima bint Qais) said: I preserved it in my mind (this narration from Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{7387}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ الْهُجَيْمِيُّ أَبُو عُثْمَانَ، حَدَّثَنَا قُرَّةُ، حَدَّثَنَا سَيَّارٌ أَبُو الْحَكَمِ، حَدَّثَنَا الشَّعْبِيُّ، قَالَ دَخَلْنَا عَلَى فَاطِمَةَ بِنْتِ قَيْسٍ فَأَتْحَفَتْنَا بِرُطَبٍ يُقَالُ لَهُ رُطَبُ ابْنِ طَابٍ وَأَسْقَتْنَا سَوِيقَ سُلْتٍ فَسَأَلْتُهَا عَنِ الْمُطَلَّقَةِ، ثَلاَثًا أَيْنَ تَعْتَدُّ قَالَتْ طَلَّقَنِي بَعْلِي ثَلاَثًا فَأَذِنَ لِيَ النَّبِيُّ صلى الله عليه وسلم أَنْ أَعْتَدَّ فِي أَهْلِي - قَالَتْ - فَنُودِيَ فِي النَّاسِ إِنَّ الصَّلاَةَ جِامِعَةً - قَالَتْ - فَانْطَلَقْتُ فِيمَنِ انْطَلَقَ مِنَ النَّاسِ - قَالَتْ - فَكُنْتُ فِي الصَّفِّ الْمُقَدَّمِ مِنَ النِّسَاءِ وَهُوَ يَلِي الْمُؤَخَّرَ مِنَ الرِّجَالِ - قَالَتْ - فَسَمِعْتُ النَّبِيَّ صلى الله عليه وسلم وَهُوَ عَلَى الْمِنْبَرِ يَخْطُبُ فَقَالَ ‏"‏ إِنَّ بَنِي عَمٍّ لِتَمِيمٍ الدَّارِيِّ رَكِبُوا فِي الْبَحْرِ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ وَزَادَ فِيهِ قَالَتْ فَكَأَنَّمَا أَنْظُرُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَأَهْوَى بِمِخْصَرَتِهِ إِلَى الأَرْضِ وَقَالَ ‏"‏ هَذِهِ طَيْبَةُ ‏"‏ ‏.‏ يَعْنِي الْمَدِينَةَ ‏.‏\hadithno{7387}\hadithtrans{Al-Sha'bi reported:We visited Fatima b. Qais and she served us fresh dates which are called rutab and she also served us barley. I asked her about that woman in whose case three divorces had been pronounced as to how much time she should count as the waiting period. She said: My husband pronounced three divorces in my case and Allah's Messenger (ﷺ) permitted me to spend any waiting period in my family. (It was during this period) that announcement was made for the people to observe prayer in the bigger Mosque. I went there along with people and I was in the front row meant for women and it was adjacent to the last row of men and I heard Allah's Messenger (ﷺ) deliver sermon sitting on the pulpit. He said: The cousin of Tamim (Dari) sailed in the ocean. The rest of the hadith is the same but with this addition:" (I see) as if I am looking to Allah's Apostle (ﷺ) pointing his rod towards the land (and saying): It is Taiba, i. e. Medina}}
\hadithdefcmd{muslim}{7388}{وَحَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَأَحْمَدُ بْنُ عُثْمَانَ النَّوْفَلِيُّ، قَالاَ حَدَّثَنَا وَهْبُ، بْنُ جَرِيرٍ حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ غَيْلاَنَ بْنَ جَرِيرٍ، يُحَدِّثُ عَنِ الشَّعْبِيِّ، عَنْ فَاطِمَةَ بِنْتِ، قَيْسٍ قَالَتْ قَدِمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم تَمِيمٌ الدَّارِيُّ فَأَخْبَرَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَّهُ رَكِبَ الْبَحْرَ فَتَاهَتْ بِهِ سَفِينَتُهُ فَسَقَطَ إِلَى جَزِيرَةٍ فَخَرَجَ إِلَيْهَا يَلْتَمِسُ الْمَاءَ فَلَقِيَ إِنْسَانًا يَجُرُّ شَعَرَهُ ‏.‏ وَاقْتَصَّ الْحَدِيثَ وَقَالَ فِيهِ ثُمَّ قَالَ أَمَا إِنَّهُ لَوْ قَدْ أُذِنَ لِي فِي الْخُرُوجِ قَدْ وَطِئْتُ الْبِلاَدَ كُلَّهَا غَيْرَ طَيْبَةَ ‏.‏ فَأَخْرَجَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى النَّاسِ فَحَدَّثَهُمْ قَالَ ‏ "‏ هَذِهِ طَيْبَةُ وَذَاكَ الدَّجَّالُ ‏"‏ ‏.‏\hadithno{7388}\hadithtrans{Tamim Dari came to Allah's Messenger (ﷺ) and informed Allah's Messenger (ﷺ) that he sailed in an ocean and his ship lost direction and thus landed at an island. They moved about in that land in search of water. There they saw a person who had been pulling his hair. The rest of the hadith is the same. And he (Dajjal) said:If I were to be permitted to set out I would have covered all the lands except Taiba. Then Allah's Messenger (ﷺ) brought (Tamim Dari) before the public and he narrated to them and said: That is Taiba and that is the Dajjal}}
\hadithdefcmd{muslim}{7389}{حَدَّثَنِي أَبُو بَكْرِ بْنُ إِسْحَاقَ، حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الشَّعْبِيِّ، عَنْ فَاطِمَةَ بِنْتِ قَيْسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَعَدَ عَلَى الْمِنْبَرِ فَقَالَ ‏ "‏ أَيُّهَا النَّاسُ حَدَّثَنِي تَمِيمٌ الدَّارِيُّ أَنَّ أُنَاسًا مِنْ قَوْمِهِ كَانُوا فِي الْبَحْرِ فِي سَفِينَةٍ لَهُمْ فَانْكَسَرَتْ بِهِمْ فَرَكِبَ بَعْضُهُمْ عَلَى لَوْحٍ مِنْ أَلْوَاحِ السَّفِينَةِ فَخَرَجُوا إِلَى جَزِيرَةٍ فِي الْبَحْرِ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ\hadithno{7389}\hadithtrans{Fatima b. Qais reported that Allah's Messenger (ﷺ) sat on the pulpit and said:O people, Tamim Dari has reported to me that some persons of his tribe sailed in the ocean in a boat and it capsised and then some of them travelled on one of the planks of the boat and they went to an island in the ocean. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{7390}{حَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنِي أَبُو عَمْرٍو، - يَعْنِي الأَوْزَاعِيَّ - عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ مِنْ بَلَدٍ إِلاَّ سَيَطَؤُهُ الدَّجَّالُ إِلاَّ مَكَّةَ وَالْمَدِينَةَ وَلَيْسَ نَقْبٌ مِنْ أَنْقَابِهَا إِلاَّ عَلَيْهِ الْمَلاَئِكَةُ صَافِّينَ تَحْرُسُهَا فَيَنْزِلُ بِالسَّبَخَةِ فَتَرْجُفُ الْمَدِينَةُ ثَلاَثَ رَجَفَاتٍ يَخْرُجُ إِلَيْهِ مِنْهَا كُلُّ كَافِرٍ وَمُنَافِقٍ ‏"‏ ‏.‏\hadithno{7390}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said:There will be no land which would not be covered by the Dajjal but Mecca and Medina, and there would no passage out of the passages leading to them which would not be guarded by angels arranged in rows. Then he (the Dajjal) would appear in a barren place adjacent to Medina and it would rock three times that every unbeliever and hypocrite would get out of it towards him}}
\hadithdefcmd{muslim}{7391}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏.‏ فَذَكَرَ نَحْوَهُ غَيْرَ أَنَّهُ قَالَ فَيَأْتِي سَبَخَةَ الْجُرُفِ فَيَضْرِبُ رِوَاقَهُ وَقَالَ فَيَخْرُجُ إِلَيْهِ كُلُّ مُنَافِقٍ وَمُنَافِقَةٍ ‏.‏\hadithno{7391}\hadithtrans{This hadith has been transmitted on the authority of Anas that Allah's Messenger (ﷺ) said this but with this addition that (the Dajjal would come) and pitch his tent in the waste-land of Juruf and thus there would come out of (the city) every hypocrite, man and woman}}
\hadithdefcmd{muslim}{7392}{حَدَّثَنَا مَنْصُورُ بْنُ أَبِي مُزَاحِمٍ، حَدَّثَنَا يَحْيَى بْنُ حَمْزَةَ، عَنِ الأَوْزَاعِيِّ، عَنْ إِسْحَاقَ، بْنِ عَبْدِ اللَّهِ عَنْ عَمِّهِ، أَنَسِ بْنِ مَالِكٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَتْبَعُ الدَّجَّالَ مِنْ يَهُودِ أَصْبَهَانَ سَبْعُونَ أَلْفًا عَلَيْهِمُ الطَّيَالِسَةُ ‏"‏ ‏.‏\hadithno{7392}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said:The Dajjal would be followed by seventy thousand Jews of Isfahan wearing Persian shawls}}
\hadithdefcmd{muslim}{7393}{حَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ حَدَّثَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ أَخْبَرَتْنِي أُمُّ شَرِيكٍ، أَنَّهَا سَمِعَتِ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ لَيَفِرَّنَّ النَّاسُ مِنَ الدَّجَّالِ فِي الْجِبَالِ ‏"‏ ‏.‏ قَالَتْ أُمُّ شَرِيكٍ يَا رَسُولَ اللَّهِ فَأَيْنَ الْعَرَبُ يَوْمَئِذٍ قَالَ ‏"‏ هُمْ قَلِيلٌ ‏"‏ ‏.‏\hadithno{7393}\hadithtrans{Umm Sharik reported:I heard Allah's Messenger (ﷺ) as saying: The people would run away from the Dajjal seeking shelter in the mountains. She said: Where would be the Arabs then in that day? He said: They would be small in number}}
\hadithdefcmd{muslim}{7394}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ بَشَّارٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{7394}\hadithtrans{This hadith has been narrated on the authority of Ibn Juraij with the same chain of transmitters}}
\hadithdefcmd{muslim}{7395}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا أَحْمَدُ بْنُ إِسْحَاقَ الْحَضْرَمِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ الْمُخْتَارِ - حَدَّثَنَا أَيُّوبُ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ رَهْطٍ، مِنْهُمْ أَبُو الدَّهْمَاءِ وَأَبُو قَتَادَةَ قَالُوا كُنَّا نَمُرُّ عَلَى هِشَامِ بْنِ عَامِرٍ نَأْتِي عِمْرَانَ بْنَ حُصَيْنٍ فَقَالَ ذَاتَ يَوْمٍ إِنَّكُمْ لَتُجَاوِزُونِي إِلَى رِجَالٍ مَا كَانُوا بِأَحْضَرَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم مِنِّي وَلاَ أَعْلَمَ بِحَدِيثِهِ مِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا بَيْنَ خَلْقِ آدَمَ إِلَى قِيَامِ السَّاعَةِ خَلْقٌ أَكْبَرُ مِنَ الدَّجَّالِ ‏"‏ ‏.‏\hadithno{7395}\hadithtrans{Abu Qatada reported:We used to go to Imran b. Husain passing in front of Hisham b. 'Amir. He, one day, said: You pass by me (in order) to go to some persons, but (amongst the living persons) none remained in the company of Allah's Messenger (ﷺ) more than I and none knows more ahadith than I. I heard Allah's Messenger (ﷺ) as saying: There would be no creation (creating more trouble) than the Dajjal right from the creation of Adam to the Last Hour}}
\hadithdefcmd{muslim}{7396}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ الرَّقِّيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنْ أَيُّوبَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ ثَلاَثَةِ، رَهْطٍ مِنْ قَوْمِهِ فِيهِمْ أَبُو قَتَادَةَ قَالُوا كُنَّا نَمُرُّ عَلَى هِشَامِ بْنِ عَامِرٍ إِلَى عِمْرَانَ بْنِ حُصَيْنٍ ‏.‏ بِمِثْلِ حَدِيثِ عَبْدِ الْعَزِيزِ بْنِ مُخْتَارٍ غَيْرَ أَنَّهُ قَالَ ‏ "‏ أَمْرٌ أَكْبَرُ مِنَ الدَّجَّالِ ‏"‏ ‏.‏\hadithno{7396}\hadithtrans{This hadith has been transmitted on the authority of 'Imran b. Husain with a slight variation of wording}}
\hadithdefcmd{muslim}{7397}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بَادِرُوا بِالأَعْمَالِ سِتًّا طُلُوعَ الشَّمْسِ مِنْ مَغْرِبِهَا أَوِ الدُّخَانَ أَوِ الدَّجَّالَ أَوِ الدَّابَّةَ أَوْ خَاصَّةَ أَحَدِكُمْ أَوْ أَمْرَ الْعَامَّةِ ‏"‏ ‏.‏\hadithno{7397}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) having said:Hasten to do good deeds before six things happen: the rising of the sun from the west, the smoke, the Dajjal, the beast and (the death) of one of you or the general turmoil}}
\hadithdefcmd{muslim}{7398}{حَدَّثَنَا أُمَيَّةُ بْنُ بِسْطَامَ الْعَيْشِيُّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ زِيَادِ بْنِ رِيَاحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بَادِرُوا بِالأَعْمَالِ سِتًّا الدَّجَّالَ وَالدُّخَانَ وَدَابَّةَ الأَرْضِ وَطُلُوعَ الشَّمْسِ مِنْ مَغْرِبِهَا وَأَمْرَ الْعَامَّةِ وَخُوَيِّصَةَ أَحَدِكُمْ ‏"‏ ‏.‏\hadithno{7398}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Hasten in performing these good deeds (before these) six things (happen): (the appearance) of the Dajjal, the smoke, the beast of the earth, the rising of the sun from the west, the general turmoil (leading to large-scale massacre) and death of masses and individuals}}
\hadithdefcmd{muslim}{7399}{وَحَدَّثَنَاهُ زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{7399}\hadithtrans{This hadith has been narrated on the authority of Qatada through another chain of transmitters}}
\hadithdefcmd{muslim}{7400}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ مُعَلَّى بْنِ زِيَادٍ، عَنْ مُعَاوِيَةَ بْنِ، قُرَّةَ عَنْ مَعْقِلِ بْنِ يَسَارٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ح وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادٌ، عَنِ الْمُعَلَّى بْنِ زِيَادٍ، رَدَّهُ إِلَى مُعَاوِيَةَ بْنِ قُرَّةَ رَدَّهُ إِلَى مَعْقِلِ بْنِ يَسَارٍ رَدَّهُ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْعِبَادَةُ فِي الْهَرْجِ كَهِجْرَةٍ إِلَىَّ ‏"‏ ‏.‏\hadithno{7400}\hadithtrans{Ma'qil b. Yasar reported Allah's Apostle (ﷺ) as saying:Worshiping during the period of widespread turmoil is like emigration towards me}}
\hadithdefcmd{muslim}{7401}{وَحَدَّثَنِيهِ أَبُو كَامِلٍ، حَدَّثَنَا حَمَّادٌ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{7401}\hadithtrans{The previous hadith is narrated through Abu Kamil from Hammad with the same chain}}
\hadithdefcmd{muslim}{7402}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - حَدَّثَنَا شُعْبَةُ، عَنْ عَلِيِّ بْنِ الأَقْمَرِ، عَنْ أَبِي الأَحْوَصِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ إِلاَّ عَلَى شِرَارِ النَّاسِ ‏"‏ ‏.‏\hadithno{7402}\hadithtrans{Abdullah reported Allah's Apostle (ﷺ) as saying:The Last Hour would affect (most terribly) the wicked persons}}
\hadithdefcmd{muslim}{7403}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، وَعَبْدُ الْعَزِيزِ بْنُ أَبِي، حَازِمٍ عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا يَعْقُوبُ، عَنْ أَبِي حَازِمٍ، أَنَّهُ سَمِعَ سَهْلاً، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يُشِيرُ بِإِصْبَعِهِ الَّتِي تَلِي الإِبْهَامَ وَالْوُسْطَى وَهُوَ يَقُولُ ‏ "‏ بُعِثْتُ أَنَا وَالسَّاعَةُ هَكَذَا ‏"‏ ‏.‏\hadithno{7403}\hadithtrans{This hadith has been reported by Sahl b. Sa'd that he heard Allah's Messenger (ﷺ) as saying:I and the Last Hour are (close to each other) like this (and he, in order to explain it) pointed (by joining his) forefinger, (one) next to the thumb and the middle finger (together)}}
\hadithdefcmd{muslim}{7404}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بُعِثْتُ أَنَا وَالسَّاعَةُ كَهَاتَيْنِ ‏"‏ ‏.‏ قَالَ شُعْبَةُ وَسَمِعْتُ قَتَادَةَ يَقُولُ فِي قَصَصِهِ كَفَضْلِ إِحْدَاهُمَا عَلَى الأُخْرَى فَلاَ أَدْرِي أَذَكَرَهُ عَنْ أَنَسٍ أَوْ قَالَهُ قَتَادَةُ ‏.‏\hadithno{7404}\hadithtrans{Anas b. Malik reported that Allah's Messenger (way peace be upon him) said:I and the Last Hour have been sent like this. Shu'ba said: I heard Qatada as saying in his narration: The excellence of one over the other. And I do not know whether he narrated it from Anas or Qatada himself said so}}
\hadithdefcmd{muslim}{7405}{وَحَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، وَأَبَا التَّيَّاحِ، يُحَدِّثَانِ أَنَّهُمَا سَمِعَا أَنَسًا، يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بُعِثْتُ أَنَا وَالسَّاعَةُ هَكَذَا ‏"‏ ‏.‏ وَقَرَنَ شُعْبَةُ بَيْنَ إِصْبَعَيْهِ الْمُسَبِّحَةِ وَالْوُسْطَى يَحْكِيهِ ‏.‏\hadithno{7405}\hadithtrans{Shu'ba reported:I heard Qatada and Abu Tayyab narrating that both of them heard Anas as narrating that Allah's Messenger (ﷺ) said: I and the Last Hour have been sent like this, and Shu'ba drew his forefinger and middle finger near each other while narrating it}}
\hadithdefcmd{muslim}{7406}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا ‏.‏\hadithno{7406}\hadithtrans{This hadith has been narrated on the authority of Anas through another chain of transmitters}}
\hadithdefcmd{muslim}{7407}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنْ حَمْزَةَ، - يَعْنِي الضَّبِّيَّ - وَأَبِي التَّيَّاحِ عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِهِمْ ‏.‏\hadithno{7407}\hadithtrans{Anas reported Allah's Apostle (ﷺ) as saying like this, but he narrated it through another chain of transmitters}}
\hadithdefcmd{muslim}{7408}{وَحَدَّثَنَا أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ أَبِيهِ، عَنْ مَعْبَدٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بُعِثْتُ أَنَا وَالسَّاعَةُ كَهَاتَيْنِ ‏"‏ ‏.‏ قَالَ وَضَمَّ السَّبَّابَةَ وَالْوُسْطَى ‏.‏\hadithno{7408}\hadithtrans{Anas reported Allah's Messenger (ﷺ) as saying:I and the Last Hour have been sent like this and (he while doing it) joined the forefinger with the middle finger}}
\hadithdefcmd{muslim}{7409}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ الأَعْرَابُ إِذَا قَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم سَأَلُوهُ عَنِ السَّاعَةِ مَتَى السَّاعَةُ فَنَظَرَ إِلَى أَحْدَثِ إِنْسَانٍ مِنْهُمْ فَقَالَ ‏ "‏ إِنْ يَعِشْ هَذَا لَمْ يُدْرِكْهُ الْهَرَمُ قَامَتْ عَلَيْكُمْ سَاعَتُكُمْ ‏"‏ ‏.‏\hadithno{7409}\hadithtrans{A'isha reported that when the desert Arabs came to Allah's Messenger (ﷺ) they asked about the Last Hour as to when that would come. And he looked towards the youngest amongst them and said:If he lives he would not grow very old that he would find your Last Hour coming to you (he would see you dying)}}
\hadithdefcmd{muslim}{7410}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، عَنْ حَمَّادِ بْنِ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم مَتَى تَقُومُ السَّاعَةُ وَعِنْدَهُ غُلاَمٌ مِنَ الأَنْصَارِ يُقَالُ لَهُ مُحَمَّدٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ يَعِشْ هَذَا الْغُلاَمُ فَعَسَى أَنْ لاَ يُدْرِكَهُ الْهَرَمُ حَتَّى تَقُومَ السَّاعَةُ ‏"‏ ‏.‏\hadithno{7410}\hadithtrans{Anas reported that a person asked Allah's Messenger (ﷺ) as to when the Last Hour would come. He had in his presence a young boy of the Ansar who was called Muhammad. Allah's Messenger (ﷺ) said:If this young boy lives, he may not grow very old till (he would see) the Last Hour coming to you}}
\hadithdefcmd{muslim}{7411}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - حَدَّثَنَا مَعْبَدُ بْنُ هِلاَلٍ الْعَنَزِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَجُلاً، سَأَلَ النَّبِيَّ صلى الله عليه وسلم قَالَ مَتَى تَقُومُ السَّاعَةُ قَالَ فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم هُنَيْهَةً ثُمَّ نَظَرَ إِلَى غُلاَمٍ بَيْنَ يَدَيْهِ مِنْ أَزْدِ شَنُوءَةَ فَقَالَ ‏ "‏ إِنْ عُمِّرَ هَذَا لَمْ يُدْرِكْهُ الْهَرَمُ حَتَّى تَقُومَ السَّاعَةُ ‏"‏ ‏.‏ قَالَ قَالَ أَنَسٌ ذَاكَ الْغُلاَمُ مِنْ أَتْرَابِي يَوْمَئِذٍ ‏.‏\hadithno{7411}\hadithtrans{Anas b. Malik reported that a person asked Allah's Apostle (ﷺ):When would the Last Hour come? Thereupon Allah's Messenger (way peace be upon him) kept quiet for a while. Then looked at a young boy in his presence belonging to the tribe of Azd Shanu'a and he said: If this boy lives he would not grow very old till the Last Hour would come to you. Anas said that this young boy was of our age during those days}}
\hadithdefcmd{muslim}{7412}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، قَالَ مَرَّ غُلاَمٌ لِلْمُغِيرَةِ بْنِ شُعْبَةَ وَكَانَ مِنْ أَقْرَانِي فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنْ يُؤَخَّرْ هَذَا فَلَنْ يُدْرِكَهُ الْهَرَمُ حَتَّى تَقُومَ السَّاعَةُ ‏"‏ ‏.‏\hadithno{7412}\hadithtrans{Anas reported:A young boy of Mughira b. Shu'ba happened to pass by (the Holy Prophet) and he was of my age. Thereupon Allah's Apostle (ﷺ) said: If he lives long he would not grow very old till the Last Hour would come (to the old people of this generation)}}
\hadithdefcmd{muslim}{7413}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ تَقُومُ السَّاعَةُ وَالرَّجُلُ يَحْلُبُ اللِّقْحَةَ فَمَا يَصِلُ الإِنَاءُ إِلَى فِيهِ حَتَّى تَقُومَ وَالرَّجُلاَنِ يَتَبَايَعَانِ الثَّوْبَ فَمَا يَتَبَايَعَانِهِ حَتَّى تَقُومَ وَالرَّجُلُ يَلِطُ فِي حَوْضِهِ فَمَا يَصْدُرُ حَتَّى تَقُومَ ‏"‏ ‏.‏\hadithno{7413}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The Last Hour would come (so sudden) that a person would be milking the she- camel and the (milk) would not reach the brim of the vessel that the Last Hour would come, and the two persons would be engaged in buying and selling of the clothes and their bargain would not be struck before the Last Hour would come. And someone would be setting his tank in order and he would have hardly set it right when the Last Hour would come}}
\hadithdefcmd{muslim}{7414}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا بَيْنَ النَّفْخَتَيْنِ أَرْبَعُونَ ‏"‏ ‏.‏ قَالُوا يَا أَبَا هُرَيْرَةَ أَرْبَعُونَ يَوْمًا قَالَ أَبَيْتُ ‏.‏ قَالُوا أَرْبَعُونَ شَهْرًا قَالَ أَبَيْتُ ‏.‏ قَالُوا أَرْبَعُونَ سَنَةً قَالَ أَبَيْتُ ‏"‏ ثُمَّ يُنْزِلُ اللَّهُ مِنَ السَّمَاءِ مَاءً فَيَنْبُتُونَ كَمَا يَنْبُتُ الْبَقْلُ ‏"‏ ‏.‏ قَالَ ‏"‏ وَلَيْسَ مِنَ الإِنْسَانِ شَىْءٌ إِلاَّ يَبْلَى إِلاَّ عَظْمًا وَاحِدًا وَهُوَ عَجْبُ الذَّنَبِ وَمِنْهُ يُرَكَّبُ الْخَلْقُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{7414}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Between the two blowings of the trumpet (there would be an interval of forty). They said: Abu Huraira, do you mean forty days? He said: I cannot say anything. They said: Do you mean forty months? He said: I cannot say anything. They said: Do you mean forty years? He said: I cannot say anything. Then Allah would cause the water to, descend from the sky and they (people) will sprout like vegetable. The only thing in a man which would not decay would be one bone (the tailbone) from which the whole frame would be reconstituted on the Day of Resurrection}}
\hadithdefcmd{muslim}{7415}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ ابْنِ آدَمَ يَأْكُلُهُ التُّرَابُ إِلاَّ عَجْبَ الذَّنَبِ مِنْهُ خُلِقَ وَفِيهِ يُرَكَّبُ ‏"‏ ‏.‏\hadithno{7415}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The earth would consume all of the son of Adam except his tailbone. From it he was created, and from it he will be recreated (on the Day of Resurrection)}}
\hadithdefcmd{muslim}{7416}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ فِي الإِنْسَانِ عَظْمًا لاَ تَأْكُلُهُ الأَرْضُ أَبَدًا فِيهِ يُرَكَّبُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالُوا أَىُّ عَظْمٍ هُوَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ عَجْبُ الذَّنَبِ ‏"‏ ‏.‏\hadithno{7416}\hadithtrans{Abu Huraira reported so many ahadith from Allah's Apostle (ﷺ) and amongst these one was this that Allah's Messenger (ﷺ) said:There is a bone in the human being which the earth would never consume and it is from this that new bodies would be reconstituted (on the Day of Resurrection). They said: Allah's Messenger, which bone is that? Thereupon he said: It is the spinal bone}}
