% Auto-generated chapter 32 for muslim
% Hadiths in this chapter: 178

\hadithdefcmd{muslim}{4519}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، حَدَّثَنَا سُلَيْمُ بْنُ أَخْضَرَ، عَنِ ابْنِ عَوْنٍ، قَالَ كَتَبْتُ إِلَى نَافِعٍ أَسْأَلُهُ عَنِ الدُّعَاءِ، قَبْلَ الْقِتَالِ قَالَ فَكَتَبَ إِلَىَّ إِنَّمَا كَانَ ذَلِكَ فِي أَوَّلِ الإِسْلاَمِ قَدْ أَغَارَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى بَنِي الْمُصْطَلِقِ وَهُمْ غَارُّونَ وَأَنْعَامُهُمْ تُسْقَى عَلَى الْمَاءِ فَقَتَلَ مُقَاتِلَتَهُمْ وَسَبَى سَبْيَهُمْ وَأَصَابَ يَوْمَئِذٍ - قَالَ يَحْيَى أَحْسِبُهُ قَالَ - جُوَيْرِيَةَ - أَوْ قَالَ الْبَتَّةَ - ابْنَةَ الْحَارِثِ وَحَدَّثَنِي هَذَا الْحَدِيثَ عَبْدُ اللَّهِ بْنُ عُمَرَ وَكَانَ فِي ذَاكَ الْجَيْشِ\hadithno{4519}\hadithtrans{Ibn 'Aun reported:I wrote to Nafi' inquiring from him whether it was necessary to extend (to the disbelievers) an invitation to accept (Islam) before meeting them in fight. He wrote (in reply) to me that it was necessary in the early days of Islam. The Messenger of Allah (ﷺ) made a raid upon Banu Mustaliq while they were unaware and their cattle were having a drink at the water. He killed those who fought and imprisoned others. On that very day, he captured Juwairiya bint al-Harith. Nafi' said that this tradition was related to him by Abdullah b. Umar who (himself) was among the raiding troops}}
\hadithdefcmd{muslim}{4520}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ وَقَالَ جُوَيْرِيَةَ بِنْتَ الْحَارِثِ ‏.‏ وَلَمْ يَشُكَّ ‏.‏\hadithno{4520}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Aun and the name of Juwairiya bint al-Harith was mentioned beyond any doubt}}
\hadithdefcmd{muslim}{4523}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنِي عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي عَلْقَمَةُ بْنُ مَرْثَدٍ، أَنَّ سُلَيْمَانَ بْنَ بُرَيْدَةَ، حَدَّثَهُ عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا بَعَثَ أَمِيرًا أَوْ سَرِيَّةً دَعَاهُ فَأَوْصَاهُ ‏.‏ وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ سُفْيَانَ ‏.‏\hadithno{4523}\hadithtrans{Sulaiman b. Buraida repotted on the authority of his father that when Allah's Messenger (ﷺ) sent an Amir with a detachment he called him and advised him. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{4524}{حَدَّثَنَا إِبْرَاهِيمُ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْوَهَّابِ الْفَرَّاءُ، عَنِ الْحُسَيْنِ بْنِ الْوَلِيدِ، عَنْ شُعْبَةَ، بِهَذَا ‏.‏\hadithno{4524}\hadithtrans{This hadith has been transmitted on the authority of Shu'ba}}
\hadithdefcmd{muslim}{4525}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا بَعَثَ أَحَدًا مِنْ أَصْحَابِهِ فِي بَعْضِ أَمْرِهِ قَالَ ‏ "‏ بَشِّرُوا وَلاَ تُنَفِّرُوا وَيَسِّرُوا وَلاَ تُعَسِّرُوا ‏"‏ ‏.‏\hadithno{4525}\hadithtrans{It has been narrated on the authority of Abu Masa that when the Messenger of Allah (ﷺ) deputed any of his Companions on a mission, he would say:Give tidings (to the people) ; do not create (in their minds) aversion (towards religion) ; show them leniency and do not be hard upon them}}
\hadithdefcmd{muslim}{4526}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم بَعَثَهُ وَمُعَاذًا إِلَى الْيَمَنِ فَقَالَ ‏ "‏ يَسِّرَا وَلاَ تُعَسِّرَا وَبَشِّرَا وَلاَ تُنَفِّرَا وَتَطَاوَعَا وَلاَ تَخْتَلِفَا ‏"‏ ‏.‏\hadithno{4526}\hadithtrans{It has also been narrated by Sa'd b. Abu Burda through his father through his grandfather that the Prophet of Allah (ﷺ) sent him and Mu'adh (on a mission) to the Yemen, and said (by way of advising them):Show leniency (to the people) ; don't be hard upon them; give them glad tidings (of Divine favours in this world and the Hereafter) ; and do not create aversion. Work in collaboration and don't be divided}}
\hadithdefcmd{muslim}{4527}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي خَلَفٍ عَنْ زَكَرِيَّاءَ بْنِ عَدِيٍّ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، كِلاَهُمَا عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ نَحْوَ حَدِيثِ شُعْبَةَ وَلَيْسَ فِي حَدِيثِ زَيْدِ بْنِ أَبِي أُنَيْسَةَ ‏ "‏ وَتَطَاوَعَا وَلاَ تَخْتَلِفَا ‏"‏ ‏.‏\hadithno{4527}\hadithtrans{This hadith has been transmitted on the authority of Buraida but for the last two words}}
\hadithdefcmd{muslim}{4528}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَنَسٍ، ح. وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ، الْوَلِيدِ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، كِلاَهُمَا عَنْ شُعْبَةَ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَسِّرُوا وَلاَ تُعَسِّرُوا وَسَكِّنُوا وَلاَ تُنَفِّرُوا ‏"‏\hadithno{4528}\hadithtrans{The Messenger of Allah (may peace he upon him) has been reported by Anas b. Malik to have said:Show leniency; do not be hard; give solace and do not create aversion}}
\hadithdefcmd{muslim}{4529}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، وَأَبُو أُسَامَةَ ح وَحَدَّثَنِي زُهَيْرُ، بْنُ حَرْبٍ وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ - يَعْنِي أَبَا قُدَامَةَ السَّرَخْسِيَّ - قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا جَمَعَ اللَّهُ الأَوَّلِينَ وَالآخِرِينَ يَوْمَ الْقِيَامَةِ يُرْفَعُ لِكُلِّ غَادِرٍ لِوَاءٌ فَقِيلَ هَذِهِ غَدْرَةُ فُلاَنِ بْنِ فُلاَنٍ ‏"‏ ‏.‏\hadithno{4529}\hadithtrans{It has been narrated on the authority of Ibn 'Umar that the Messenger of Allah (ﷺ) said:When Allah will gather together, on the Day of Judgment, all the earlier and later generations of mankind, a flag will be raised (to mark off) every person guilty of breach of faith, and it will be announced that this is the perfidy of so and so, son of so and so (to attract the attention of people to his guilt)}}
\hadithdefcmd{muslim}{4530}{حَدَّثَنَا أَبُو الرَّبِيعِ الْعَتَكِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ، الرَّحْمَنِ الدَّارِمِيُّ حَدَّثَنَا عَفَّانُ، حَدَّثَنَا صَخْرُ بْنُ جُوَيْرِيَةَ، كِلاَهُمَا عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏.‏\hadithno{4530}\hadithtrans{This hadith has been narrated on the authority of Ibn Umar through some other Chains of transmitters}}
\hadithdefcmd{muslim}{4531}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ عَنْ إِسْمَاعِيلَ بْنِ جَعْفَرٍ، عَنْ عَبْدِ، اللَّهِ بْنِ دِينَارٍ أَنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عُمَرَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ الْغَادِرَ يَنْصِبُ اللَّهُ لَهُ لِوَاءً يَوْمَ الْقِيَامَةِ فَيُقَالُ أَلاَ هَذِهِ غَدْرَةُ فُلاَنٍ ‏"‏ ‏.‏\hadithno{4531}\hadithtrans{This hadith has been narrated by another chain of transmitters on the authority of the same narrator, with the wording:Allah will set up a flag for every person guilty of breach of faith on the Day of Judgment, and it will be announced: Look, this is the perfidy of so and so}}
\hadithdefcmd{muslim}{4532}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ حَمْزَةَ، وَسَالِمٍ، ابْنَىْ عَبْدِ اللَّهِ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لِكُلِّ غَادِرٍ لِوَاءٌ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4532}\hadithtrans{Ibn Umar reported that he heard the Messenger of Allah (ﷺ) saying:There will be a flag for every perfidious person on the Day of Judgment}}
\hadithdefcmd{muslim}{4533}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، ح وَحَدَّثَنِي بِشْرُ، بْنُ خَالِدٍ أَخْبَرَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - كِلاَهُمَا عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لِكُلِّ غَادِرٍ لِوَاءٌ يَوْمَ الْقِيَامَةِ يُقَالُ هَذِهِ غَدْرَةُ فُلاَنٍ ‏"‏ ‏.‏\hadithno{4533}\hadithtrans{Abdullah reported Allah's Prophet (ﷺ) as saying:There will be a flag for every perfidious person on the Day of Judgment, and it would be said: Here is the perfidy of so and so}}
\hadithdefcmd{muslim}{4534}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، ح وَحَدَّثَنِي عُبَيْدُ اللَّهِ، بْنُ سَعِيدٍ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، جَمِيعًا عَنْ شُعْبَةَ، فِي هَذَا الإِسْنَادِ ‏.‏ وَلَيْسَ فِي حَدِيثِ عَبْدِ الرَّحْمَنِ ‏ "‏ يُقَالُ هَذِهِ غَدْرَةُ فُلاَنٍ ‏"‏ ‏.‏\hadithno{4534}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with a slight variation of wording}}
\hadithdefcmd{muslim}{4535}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ يَزِيدَ بْنِ عَبْدِ الْعَزِيزِ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِكُلِّ غَادِرٍ لِوَاءٌ يَوْمَ الْقِيَامَةِ يُعْرَفُ بِهِ يُقَالُ هَذِهِ غَدْرَةُ فُلاَنٍ ‏"‏ ‏.‏\hadithno{4535}\hadithtrans{It has been narrated on the authority of Abdullah that the Messenger of Allah (ﷺ) said:There will be for every perfidious person on the Day of Judgment a flag by which he will be recognised. It will be announced: Here is the breach of faith of so and so}}
\hadithdefcmd{muslim}{4536}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ شُعْبَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِكُلِّ غَادِرٍ لِوَاءٌ يَوْمَ الْقِيَامَةِ يُعْرَفُ بِهِ ‏"‏ ‏.‏\hadithno{4536}\hadithtrans{Anas reported Allah's Messenger (ﷺ) having said this:There would be a flag for every perfidious person on the Day of Judgment by which he will be recognised}}
\hadithdefcmd{muslim}{4537}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا شُعْبَةُ، عَنْ خُلَيْدٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لِكُلِّ غَادِرٍ لِوَاءٌ عِنْدَ اسْتِهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4537}\hadithtrans{It is narrated on the authority of Abu Sa'id that the Messenger of Allah (ﷺ) said:On the Day of Judgment there will be a flag fixed behind the buttocks of every person guilty of the breach of faith}}
\hadithdefcmd{muslim}{4538}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا الْمُسْتَمِرُّ بْنُ الرَّيَّانِ، حَدَّثَنَا أَبُو نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِكُلِّ غَادِرٍ لِوَاءٌ يَوْمَ الْقِيَامَةِ يُرْفَعُ لَهُ بِقَدْرِ غَدْرِهِ أَلاَ وَلاَ غَادِرَ أَعْظَمُ غَدْرًا مِنْ أَمِيرِ عَامَّةٍ ‏"‏ ‏.‏\hadithno{4538}\hadithtrans{It is narrated on the authority of Abu Sa'id that the Messenger of Allah (ﷺ) said:On the Day of Judgment there will be a flag for every person guilty of the breach of faith. It will be raised in proportion to the extent of his guilt; and there is no guilt of treachery more serious than the one committed by the ruler of men}}
\hadithdefcmd{muslim}{4539}{وَحَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لِعَلِيٍّ وَزُهَيْرٍ - قَالَ عَلِيٌّ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعَ عَمْرٌو، جَابِرًا يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْحَرْبُ خَدْعَةٌ ‏"‏ ‏.‏\hadithno{4539}\hadithtrans{It is narrated on the authority of Jabir that the Messenger of Allah (ﷺ) said:War is a stratagem}}
\hadithdefcmd{muslim}{4540}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ سَهْمٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏الْحَرْبُ خُدْعَةٌ ‏"‏ ‏.‏\hadithno{4540}\hadithtrans{This hadith has also been narrated on the authority of Abu Huraira}}
\hadithdefcmd{muslim}{4541}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، عَنِ الْمُغِيرَةِ، - وَهُوَ ابْنُ عَبْدِ الرَّحْمَنِ الْحِزَامِيُّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي، هُرَيْرَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَمَنَّوْا لِقَاءَ الْعَدُوِّ فَإِذَا لَقِيتُمُوهُمْ فَاصْبِرُوا‏"‏ ‏.‏\hadithno{4541}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:Do not desire an encounter with the enemy; but when you encounter them, be firm}}
\hadithdefcmd{muslim}{4542}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي مُوسَى، بْنُ عُقْبَةَ عَنْ أَبِي النَّضْرِ، عَنْ كِتَابِ، رَجُلٍ مِنْ أَسْلَمَ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم يُقَالُ لَهُ عَبْدُ اللَّهِ بْنُ أَبِي أَوْفَى فَكَتَبَ إِلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ حِينَ سَارَ إِلَى الْحَرُورِيَّةِ يُخْبِرُهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ فِي بَعْضِ أَيَّامِهِ الَّتِي لَقِيَ فِيهَا الْعَدُوَّ يَنْتَظِرُ حَتَّى إِذَا مَالَتِ الشَّمْسُ قَامَ فِيهِمْ فَقَالَ ‏"‏ يَا أَيُّهَا النَّاسُ لاَ تَتَمَنَّوْا لِقَاءَ الْعَدُوِّ وَاسْأَلُوا اللَّهَ الْعَافِيَةَ فَإِذَا لَقِيتُمُوهُمْ فَاصْبِرُوا وَاعْلَمُوا أَنَّ الْجَنَّةَ تَحْتَ ظِلاَلِ السُّيُوفِ ‏"‏ ‏.‏ ثُمَّ قَامَ النَّبِيُّ صلى الله عليه وسلم وَقَالَ ‏"‏ اللَّهُمَّ مُنْزِلَ الْكِتَابِ وَمُجْرِيَ السَّحَابِ وَهَازِمَ الأَحْزَابِ اهْزِمْهُمْ وَانْصُرْنَا عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{4542}\hadithtrans{It is narrated by Abu Nadr that he learnt from a letter sent by a man from the Aslam tribe, who was a Companion of the Prophet (ﷺ) and whose name was 'Abdullah b. Abu Aufa, to 'Umar b. 'Ubaidullah when the latter marched upon Haruriyya (Khawarij) informing him that the Messenger of Allah (ﷺ) in one of those days when lie was confronting the enemy waited until the sun had declined. Then he stood up (to address the people) and said:O ye men, do not wish for an encounter with the enemy. Pray to Allah to grant you security; (but) when you (have to) encounter them exercise patience, and you should know that Paradise is under the shadows of the swords. Then the Messenger of Allah (ﷺ) stood up (again) and said: O Allah. Revealer of the Book, Disperser of the clouds, Defeater of the hordes, put our enemy to rout and help us against them}}
\hadithdefcmd{muslim}{4543}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي أَوْفَى، قَالَ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الأَحْزَابِ فَقَالَ ‏ "‏ اللَّهُمَّ مُنْزِلَ الْكِتَابِ سَرِيعَ الْحِسَابِ اهْزِمِ الأَحْزَابَ اللَّهُمَّ اهْزِمْهُمْ وَزَلْزِلْهُمْ ‏"‏ ‏.‏\hadithno{4543}\hadithtrans{It is narrated on the authority of Ibn Abu Aufa that the Messenger of Allah (ﷺ) cursed the tribes (who had marched upon Medina with a combined force in 5 H) and said:O Allah, Revealer of the Book, swift in (taking) account, put the tribes to rout. O Lord, defeat them and shake them}}
\hadithdefcmd{muslim}{4544}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، عَنْ إِسْمَاعِيلَ بْنِ أَبِي، خَالِدٍ قَالَ سَمِعْتُ ابْنَ أَبِي أَوْفَى، يَقُولُ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ خَالِدٍ غَيْرَ أَنَّهُ قَالَ ‏"‏ هَازِمَ الأَحْزَابِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ قَوْلَهُ ‏"‏ اللَّهُمَّ ‏"‏ ‏.‏\hadithno{4544}\hadithtrans{This hadith has been transmitted on the authority of Ibn Abu Aufa with a slight variation of words}}
\hadithdefcmd{muslim}{4545}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ أَبِي عُمَرَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، عَنْ إِسْمَاعِيلَ، بِهَذَا الإِسْنَادِ وَزَادَ ابْنُ أَبِي عُمَرَ فِي رِوَايَتِهِ ‏ "‏ مُجْرِيَ السَّحَابِ ‏"‏ ‏.‏\hadithno{4545}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Uyaina through another chain of transmitters (who added the words)" the Disperser of clouds" in his narration}}
\hadithdefcmd{muslim}{4546}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ يَوْمَ أُحُدٍ ‏ "‏ اللَّهُمَّ إِنَّكَ إِنْ تَشَأْ لاَ تُعْبَدْ فِي الأَرْضِ ‏"‏ ‏.‏\hadithno{4546}\hadithtrans{It is narrated on the authority of Anas that the Messenger of Allah (ﷺ) said on the day of the Battle of Uhud:O Allah, if Thou wilt (defeat Muslims), there will be none on the earth to worship Thee}}
\hadithdefcmd{muslim}{4547}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ، سَعِيدٍ حَدَّثَنَا لَيْثٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، أَنَّ امْرَأَةً، وُجِدَتْ، فِي بَعْضِ مَغَازِي رَسُولِ اللَّهِ صلى الله عليه وسلم مَقْتُولَةً فَأَنْكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَتْلَ النِّسَاءِ وَالصِّبْيَانِ‏.‏\hadithno{4547}\hadithtrans{It is narrated on the authority of 'Abdullah that a woman was found killed in one of the battles fought by the Messenger of Allah (ﷺ). He disapproved of the killing of women and children}}
\hadithdefcmd{muslim}{4548}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، وَأَبُو أُسَامَةَ قَالاَ حَدَّثَنَا عُبَيْدُ، اللَّهِ بْنُ عُمَرَ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ وُجِدَتِ امْرَأَةٌ مَقْتُولَةً فِي بَعْضِ تِلْكَ الْمَغَازِي فَنَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ قَتْلِ النِّسَاءِ وَالصِّبْيَانِ ‏.‏\hadithno{4548}\hadithtrans{It is narrated by Ibn 'Umar that a woman was found killed in one of these battles; so the Messenger of Allah (ﷺ) forbade the killing of women and children}}
\hadithdefcmd{muslim}{4549}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَسَعِيدُ بْنُ مَنْصُورٍ، وَعَمْرٌو النَّاقِدُ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، قَالَ يَحْيَى أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الصَّعْبِ، بْنِ جَثَّامَةَ قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنِ الذَّرَارِيِّ مِنَ الْمُشْرِكِينَ يُبَيَّتُونَ فَيُصِيبُونَ مِنْ نِسَائِهِمْ وَذَرَارِيِّهِمْ ‏.‏ فَقَالَ ‏ "‏ هُمْ مِنْهُمْ ‏"‏ ‏.‏\hadithno{4549}\hadithtrans{It is reported on the authority of Sa'b b. Jaththama that the Prophet of Allah (ﷺ), when asked about the women and children of the polytheists being killed during the night raid, said:They are from them}}
\hadithdefcmd{muslim}{4550}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ، اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ عَنِ ابْنِ عَبَّاسٍ، عَنِ الصَّعْبِ بْنِ جَثَّامَةَ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّا نُصِيبُ فِي الْبَيَاتِ مِنْ ذَرَارِيِّ الْمُشْرِكِينَ قَالَ ‏ "‏ هُمْ مِنْهُمْ ‏"‏ ‏.‏\hadithno{4550}\hadithtrans{It is narrated by Sa'b b. Jaththama that he said (to the Holy Prophet):Messenger of Allah, we kill the children of the polytheists during the night raids. He said: They are from them}}
\hadithdefcmd{muslim}{4551}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو، بْنُ دِينَارٍ أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ الصَّعْبِ بْنِ جَثَّامَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قِيلَ لَهُ لَوْ أَنَّ خَيْلاً أَغَارَتْ مِنَ اللَّيْلِ فَأَصَابَتْ مِنْ أَبْنَاءِ الْمُشْرِكِينَ قَالَ ‏ "‏ هُمْ مِنْ آبَائِهِمْ ‏"‏ ‏.‏\hadithno{4551}\hadithtrans{Sa'b b. Jaththama has narrated that the Prophet (ﷺ) asked:What about the children of polytheists killed by the cavalry during the night raid? He said: They are from them}}
\hadithdefcmd{muslim}{4552}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رُمْحٍ، قَالاَ أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ، سَعِيدٍ حَدَّثَنَا لَيْثٌ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَرَّقَ نَخْلَ بَنِي النَّضِيرِ وَقَطَعَ وَهِيَ الْبُوَيْرَةُ ‏.‏ زَادَ قُتَيْبَةُ وَابْنُ رُمْحٍ فِي حَدِيثِهِمَا فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ مَا قَطَعْتُمْ مِنْ لِينَةٍ أَوْ تَرَكْتُمُوهَا قَائِمَةً عَلَى أُصُولِهَا فَبِإِذْنِ اللَّهِ وَلِيُخْزِيَ الْفَاسِقِينَ‏\}‏\hadithno{4552}\hadithtrans{It is narrated on the authority of 'Abdullah that the Messenger of Allah (ﷺ) ordered the date-palms of Banu Nadir to be burnt and cut. These palms were at Buwaira. Qutaibah and Ibn Rumh in their versions of the tradition have added:So Allah, the Glorious and Exalted, revealed the verse:" Whatever trees you have cut down or left standing on their trunks, it was with the permission of Allah so that He may disgrace the evil-doers" (lix)}}
\hadithdefcmd{muslim}{4553}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَهَنَّادُ بْنُ السَّرِيِّ، قَالاَ حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ مُوسَى، بْنِ عُقْبَةَ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَطَعَ نَخْلَ بَنِي النَّضِيرِ وَحَرَّقَ وَلَهَا يَقُولُ حَسَّانُ وَهَانَ عَلَى سَرَاةِ بَنِي لُؤَىٍّ حَرِيقٌ بِالْبُوَيْرَةِ مُسْتَطِيرُ وَفِي ذَلِكَ نَزَلَتْ ‏\{‏ مَا قَطَعْتُمْ مِنْ لِينَةٍ أَوْ تَرَكْتُمُوهَا قَائِمَةً عَلَى أُصُولِهَا‏\}‏ الآيَةَ ‏.‏\hadithno{4553}\hadithtrans{It is narrated on the authority of Ibn Umar that the Messenger of Allah (ﷺ) caused the date-palms of Banu Nadir to be cut down and burnt. It is in this connection that Hassan (the poet) said:It was easy for the nobles of Quraish to burn Buwaira whose sparks were flying in all directions, in the same connection was revealed the Qur'anic verse:" Whatever trees you have cut down or left standing on their trunks}}
\hadithdefcmd{muslim}{4554}{وَحَدَّثَنَا سَهْلُ بْنُ عُثْمَانَ، أَخْبَرَنِي عُقْبَةُ بْنُ خَالِدٍ السَّكُونِيُّ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، قَالَ حَرَّقَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَخْلَ بَنِي النَّضِيرِ‏.‏\hadithno{4554}\hadithtrans{Abdullah b. Umar reported that Allah's Apostle (ﷺ) burnt the date-palms of Banu Nadir}}
\hadithdefcmd{muslim}{4555}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ مَعْمَرٍ، ح وَحَدَّثَنَا مُحَمَّدُ، بْنُ رَافِعٍ - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَزَا نَبِيٌّ مِنَ الأَنْبِيَاءِ فَقَالَ لِقَوْمِهِ لاَ يَتْبَعْنِي رَجُلٌ قَدْ مَلَكَ بُضْعَ امْرَأَةٍ وَهُوَ يُرِيدُ أَنْ يَبْنِيَ بِهَا وَلَمَّا يَبْنِ وَلاَ آخَرُ قَدْ بَنَى بُنْيَانًا وَلَمَّا يَرْفَعْ سُقُفَهَا وَلاَ آخَرُ قَدِ اشْتَرَى غَنَمًا أَوْ خَلِفَاتٍ وَهُوَ مُنْتَظِرٌ وِلاَدَهَا ‏.‏ قَالَ فَغَزَا فَأَدْنَى لِلْقَرْيَةِ حِينَ صَلاَةِ الْعَصْرِ أَوْ قَرِيبًا مِنْ ذَلِكَ فَقَالَ لِلشَّمْسِ أَنْتِ مَأْمُورَةٌ وَأَنَا مَأْمُورٌ اللَّهُمَّ احْبِسْهَا عَلَىَّ شَيْئًا ‏.‏ فَحُبِسَتْ عَلَيْهِ حَتَّى فَتَحَ اللَّهُ عَلَيْهِ - قَالَ - فَجَمَعُوا مَا غَنِمُوا فَأَقْبَلَتِ النَّارُ لِتَأْكُلَهُ فَأَبَتْ أَنْ تَطْعَمَهُ فَقَالَ فِيكُمْ غُلُولٌ فَلْيُبَايِعْنِي مِنْ كُلِّ قَبِيلَةٍ رَجُلٌ ‏.‏ فَبَايَعُوهُ فَلَصِقَتْ يَدُ رَجُلٍ بِيَدِهِ فَقَالَ فِيكُمُ الْغُلُولُ فَلْتُبَايِعْنِي قَبِيلَتُكَ ‏.‏ فَبَايَعَتْهُ - قَالَ - فَلَصِقَتْ بِيَدِ رَجُلَيْنِ أَوْ ثَلاَثَةٍ فَقَالَ فِيكُمُ الْغُلُولُ أَنْتُمْ غَلَلْتُمْ - قَالَ - فَأَخْرَجُوا لَهُ مِثْلَ رَأْسِ بَقَرَةٍ مِنْ ذَهَبٍ - قَالَ - فَوَضَعُوهُ فِي الْمَالِ وَهُوَ بِالصَّعِيدِ فَأَقْبَلَتِ النَّارُ فَأَكَلَتْهُ ‏.‏ فَلَمْ تَحِلَّ الْغَنَائِمُ لأَحَدٍ مِنْ قَبْلِنَا ذَلِكَ بِأَنَّ اللَّهَ تَبَارَكَ وَتَعَالَى رَأَى ضَعْفَنَا وَعَجْزَنَا فَطَيَّبَهَا لَنَا ‏"‏ ‏.‏\hadithno{4555}\hadithtrans{It has been narrated by Abu Huraira that the Messenger of Allah (ﷺ) said:One of the Prophets made a holy war. He said to his followers: One who has married a woman and wants to consummate to his marriage but has not yet done so; another who has built a house but has not yet erected its roof; and another who has bought goats and pregnantshe-camels and is waiting for their offspring-will not accommpany me. So he marched on and approached a village at or about the time of the Asr prayers. He said to the sun: Thou art subserviant (to Allah) and so am I. O Allah, stop it for me a little. It was stopped for him until Allah granted him victory. The people gathered the spoils of war (at one place). A fire approached the spoils to devour them, but it did not devour them. He (the Holy Prophet) said: Some of you have been guilty of misappropriation. So one man from each tribe should swear fealty to me. The did so (putting their hands into his). The hand of one man stuck to his hand and the Prophet (ﷺ) said: Your tribe is guilty of misappropriation. Let all the members of your tribe swear fealty to me one by one. They did so, when the hands of two or three persons got stuck with his hand. He said: You have misappropriated. So they took out gold equal in volume to the head of a cow. They-placed it among the spoils on the earth. Then the fire approached the spoils and devoured them. The spoils of war were not made lawful for any people before us, This is because Allah saw our weakness and humility and made them lawful for us}}
\hadithdefcmd{muslim}{4556}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكٍ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ أَخَذَ أَبِي مِنَ الْخُمْسِ سَيْفًا فَأَتَى بِهِ النَّبِيَّ صلى الله عليه وسلم فَقَالَ هَبْ لِي هَذَا ‏.‏ فَأَبَى فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ يَسْأَلُونَكَ عَنِ الأَنْفَالِ قُلِ الأَنْفَالُ لِلَّهِ وَالرَّسُولِ‏\}‏\hadithno{4556}\hadithtrans{A hadith has been narrated by Mus'ab b. Sa'd who heard it from his father as saying:My father took a sword from Khums and brought it to the Prophet (ﷺ) and said: Grant it to me. He refused. At this Allah revealed (the Qur'anic verse):" They ask thee concerning the spoils of war. Say: The spoils of war are for Allah and the Apostle" (viii)}}
\hadithdefcmd{muslim}{4557}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ أَبِيهِ، قَالَ نَزَلَتْ فِيَّ أَرْبَعُ آيَاتٍ أَصَبْتُ سَيْفًا فَأَتَى بِهِ النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ نَفِّلْنِيهِ ‏.‏ فَقَالَ ‏"‏ ضَعْهُ ‏"‏ ‏.‏ ثُمَّ قَامَ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ضَعْهُ مِنْ حَيْثُ أَخَذْتَهُ ‏"‏ ‏.‏ ثُمَّ قَامَ فَقَالَ نَفِّلْنِيهِ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ ضَعْهُ ‏"‏ ‏.‏ فَقَامَ فَقَالَ يَا رَسُولَ اللَّهِ نَفِّلْنِيهِ أَأُجْعَلُ كَمَنْ لاَ غَنَاءَ لَهُ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ ضَعْهُ مِنْ حَيْثُ أَخَذْتَهَ ‏"‏ ‏.‏ قَالَ فَنَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ يَسْأَلُونَكَ عَنِ الأَنْفَالِ قُلِ الأَنْفَالُ لِلَّهِ وَالرَّسُولِ‏\}‏\hadithno{4557}\hadithtrans{A hadith has been narrated by Mus'ab b. Sa'd who heard it from his father as saying:" Four verses of the Qur'an have been revealed about me. I found a sword (among the spoils of war). It was brought to the Prophet (ﷺ). He (my father) said: Messenger of Allah, bestow it upon me. The Apostle of Allah (ﷺ) said: Place it there. Then he (my father) stood up and the Messenger of Allah (ﷺ) said to him: Place it from where you got it. (At this) he (my father) said again: Messenger of Allah, bestow it upon me Shall I be treated like one who has no share in (the booty)? The Apostle of Allah (may peace be upon him said: Place it from where you got it. At this was revealed the verse:" They ask thee about the spoils of war.... Say: The spoils of war are for Allah and the Messenger)}}
\hadithdefcmd{muslim}{4558}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ بَعَثَ النَّبِيُّ صلى الله عليه وسلم سَرِيَّةً وَأَنَا فِيهِمْ قِبَلَ نَجْدٍ فَغَنِمُوا إِبِلاً كَثِيرَةً فَكَانَتْ سُهْمَانُهُمُ اثْنَى عَشَرَ بَعِيرًا أَوْ أَحَدَ عَشَرَ بَعِيرًا وَنُفِّلُوا بَعِيرًا بَعِيرًا ‏.‏\hadithno{4558}\hadithtrans{It has been narrated on the authority of Ibn Umar that the Prophet (ﷺ) sent an expedition to Najd and I was among the troops. They got a large number of camels as a booty. Eleven or twelve camels fell to the lot of every fighter and each of them also got one extra camel}}
\hadithdefcmd{muslim}{4559}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ سَرِيَّةً قِبَلَ نَجْدٍ وَفِيهِمُ ابْنُ عُمَرَ وَأَنَّ سُهْمَانَهُمْ بَلَغَتِ اثْنَىْ عَشَرَ بَعِيرًا وَنُفِّلُوا سِوَى ذَلِكَ بَعِيرًا فَلَمْ يُغَيِّرْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4559}\hadithtrans{Ibn 'Umar reported that Allah's Messenger (ﷺ) sent an expedition to Najd and Ibn Umar was also among the troops, and their share (of the spoils) came to twelve camels and they were given one camel over and above that. and Allah's Messenger (ﷺ) did not make any change in it}}
\hadithdefcmd{muslim}{4560}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، وَعَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَرِيَّةً إِلَى نَجْدٍ فَخَرَجْتُ فِيهَا فَأَصَبْنَا إِبِلاً وَغَنَمًا فَبَلَغَتْ سُهْمَانُنَا اثْنَىْ عَشَرَ بَعِيرًا وَنَفَّلَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بَعِيرًا بَعِيرًا ‏.‏\hadithno{4560}\hadithtrans{It has been narrated by Ibn 'Umar that the Messenger of Allah (ﷺ) sent an expedition to Najd, and I (also) went with the troops. We got camels and goats as spoils of war, and our share amounted to twelve camels per head, and the Messenger of Allah (ﷺ) gave an extra camel to each of us}}
\hadithdefcmd{muslim}{4561}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ الْقَطَّانُ - عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{4561}\hadithtrans{This hadith has been narrated on the authority of 'Ubaidullah with the same chain of transmitters}}
\hadithdefcmd{muslim}{4562}{وَحَدَّثَنَاهُ أَبُو الرَّبِيعِ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، قَالَ كَتَبْتُ إِلَى نَافِعٍ أَسْأَلُهُ عَنِ النَّفَلِ، فَكَتَبَ إِلَىَّ أَنَّ4661 - وَحَدَّثَنَا ابْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي مُوسَى، ح وَحَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي أُسَامَةُ بْنُ زَيْدٍ، كُلُّهُمْ عَنْ نَافِعٍ، بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِهِمْ ‏.‏\hadithno{4562}\hadithtrans{Ibn Aun said:I wrote to Nafi' asking him about Nafl (spoils of war) and be wrote to me that Ibn 'Umar was among that expedition. (The rest of the hadith is the same)}}
\hadithdefcmd{muslim}{4563}{وَحَدَّثَنَا سُرَيْجُ بْنُ يُونُسَ، وَعَمْرٌو النَّاقِدُ، - وَاللَّفْظُ لِسُرَيْجٍ - قَالاَ حَدَّثَنَا عَبْدُ، اللَّهِ بْنُ رَجَاءٍ عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، قَالَ نَفَّلَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم نَفَلاً سِوَى نَصِيبِنَا مِنَ الْخُمْسِ فَأَصَابَنِي شَارِفٌ وَالشَّارِفُ الْمُسِنُّ الْكَبِيرُ ‏\hadithno{4563}\hadithtrans{A hadith has been narrated by Salim who learnt it from his father and said:The Messenger of Allah (ﷺ) gave us an extra (camel) besides our share of Khums; (and in this extra share) I got a Sharif (and a Sharif is a big old camel)}}
\hadithdefcmd{muslim}{4564}{وَحَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، ح وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، كِلاَهُمَا عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ بَلَغَنِي عَنِ ابْنِ عُمَرَ، قَالَ نَفَّلَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَرِيَّةً بِنَحْوِ حَدِيثِ ابْنِ رَجَاءٍ ‏.‏\hadithno{4564}\hadithtrans{Ibn Shihab reported:It reached me through Ibn Umar that Allah's Messenger (ﷺ) gave a share of spoils to the troop. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{4565}{وَحَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبِ بْنِ اللَّيْثِ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ حَدَّثَنِي عُقَيْلُ، بْنُ خَالِدٍ عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمٍ، عَنْ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ كَانَ يُنَفِّلُ بَعْضَ مَنْ يَبْعَثُ مِنَ السَّرَايَا لأَنْفُسِهِمْ خَاصَّةً سِوَى قَسْمِ عَامَّةِ الْجَيْشِ وَالْخُمْسُ فِي ذَلِكَ وَاجِبٌ كُلِّهِ ‏.‏\hadithno{4565}\hadithtrans{It has been narrated on the authority of Abdullah b. 'Umar that the Messenger of Allah (ﷺ) used to give (from the spoils of war) to small troops seat on expeditions something more than the due share of each fighter in a large force. And Khums (one-fifth of the total spoils) was to be reserved (for Allah and His Apostle) in all cases}}
\hadithdefcmd{muslim}{4566}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا هُشَيْمٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عُمَرَ بْنِ، كَثِيرِ بْنِ أَفْلَحَ عَنْ أَبِي مُحَمَّدٍ الأَنْصَارِيِّ، وَكَانَ، جَلِيسًا لأَبِي قَتَادَةَ قَالَ قَالَ أَبُو قَتَادَةَ ‏.‏ وَاقْتَصَّ الْحَدِيثَ ‏.‏\hadithno{4566}\hadithtrans{Abu Muammad al-Ansari, who was the close companion of Abu Qatada. narrated the hadith (which follows)}}
\hadithdefcmd{muslim}{4567}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عُمَرَ بْنِ كَثِيرٍ، عَنْ أَبِي مُحَمَّدٍ، مَوْلَى أَبِي قَتَادَةَ أَنَّ أَبَا قَتَادَةَ، قَالَ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{4567}\hadithtrans{Abu Muhammad, the freed slave of Abu Qatada reported on the authority of Abu Qatda and narrated the hadith}}
\hadithdefcmd{muslim}{4568}{وَحَدَّثَنَا أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ سَمِعْتُ مَالِكَ بْنَ أَنَسٍ، يَقُولُ حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، عَنْ عُمَرَ بْنِ كَثِيرِ بْنِ أَفْلَحَ، عَنْ أَبِي مُحَمَّدٍ، مَوْلَى أَبِي قَتَادَةَ عَنْ أَبِي قَتَادَةَ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ حُنَيْنٍ فَلَمَّا الْتَقَيْنَا كَانَتْ لِلْمُسْلِمِينَ جَوْلَةٌ ‏.‏ قَالَ فَرَأَيْتُ رَجُلاً مِنَ الْمُشْرِكِينَ قَدْ عَلاَ رَجُلاً مِنَ الْمُسْلِمِينَ فَاسْتَدَرْتُ إِلَيْهِ حَتَّى أَتَيْتُهُ مِنْ وَرَائِهِ فَضَرَبْتُهُ عَلَى حَبْلِ عَاتِقِهِ وَأَقْبَلَ عَلَىَّ فَضَمَّنِي ضَمَّةً وَجَدْتُ مِنْهَا رِيحَ الْمَوْتِ ثُمَّ أَدْرَكَهُ الْمَوْتُ فَأَرْسَلَنِي فَلَحِقْتُ عُمَرَ بْنَ الْخَطَّابِ فَقَالَ مَا لِلنَّاسِ فَقُلْتُ أَمْرُ اللَّهِ ‏.‏ ثُمَّ إِنَّ النَّاسَ رَجَعُوا وَجَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ ‏"‏ مَنْ قَتَلَ قَتِيلاً لَهُ عَلَيْهِ بَيِّنَةٌ فَلَهُ سَلَبُهُ ‏"‏ ‏.‏ قَالَ فَقُمْتُ فَقُلْتُ مَنْ يَشْهَدُ لِي ثُمَّ جَلَسْتُ ثُمَّ قَالَ مِثْلَ ذَلِكَ فَقَالَ فَقُمْتُ فَقُلْتُ مَنْ يَشْهَدُ لِي ثُمَّ جَلَسْتُ ثُمَّ قَالَ ذَلِكَ الثَّالِثَةَ فَقُمْتُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا لَكَ يَا أَبَا قَتَادَةَ ‏"‏ ‏.‏ فَقَصَصْتُ عَلَيْهِ الْقِصَّةَ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ صَدَقَ يَا رَسُولَ اللَّهِ سَلَبُ ذَلِكَ الْقَتِيلِ عِنْدِي فَأَرْضِهِ مِنْ حَقِّهِ ‏.‏ وَقَالَ أَبُو بَكْرٍ الصِّدِّيقُ لاَهَا اللَّهِ إِذًا لاَ يَعْمِدُ إِلَى أَسَدٍ مِنْ أُسُدِ اللَّهِ يُقَاتِلُ عَنِ اللَّهِ وَعَنْ رَسُولِهِ فَيُعْطِيكَ سَلَبَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صَدَقَ فَأَعْطِهِ إِيَّاهُ ‏"‏ ‏.‏ فَأَعْطَانِي قَالَ فَبِعْتُ الدِّرْعَ فَابْتَعْتُ بِهِ مَخْرَفًا فِي بَنِي سَلِمَةَ فَإِنَّهُ لأَوَّلُ مَالٍ تَأَثَّلْتُهُ فِي الإِسْلاَمِ ‏.‏ وَفِي حَدِيثِ اللَّيْثِ فَقَالَ أَبُو بَكْرٍ كَلاَّ لاَ يُعْطِيهِ أُضَيْبِعَ مِنْ قُرَيْشٍ وَيَدَعُ أَسَدًا مِنْ أُسُدِ اللَّهِ ‏.‏ وَفِي حَدِيثِ اللَّيْثِ لأَوَّلُ مَالٍ تَأَثَّلْتُهُ ‏.‏\hadithno{4568}\hadithtrans{Abu Qatada reported:We accompanied the Messenger of Allah (my peace be upon him) on an expedition in the year of the Battle of Hunain. When we encountered the enemy, (some of the Muslims turned back (in fear). I saw that a man from the polytheists overpowered one of the Muslims. I turned round and attacked him from behind giving a blow between his neck and shoulder. He turned towards me and grappled with me in such a way that I began to see death staring me in the face. Then death overtook him and left me alone. I joined 'Umar b. al-Khattab who was saying: What has happened to the people (that they are retreating)? I said: It is the Decree of Allah. Then the people returned. (The battle ended in a victory for the Muslims) and the Messenger of Allah (ﷺ) sat down (to distribute the spoils of war). He said: One who has killed an enemy and can bring evidence to prove it will get his belongings. So I stood up and said: Who will give evidence for me? Then I sat down. Then he (the Holy Prophet) said like this. I stood up (again) and said: Who will bear witness for me? He (the Holy Prophet) made the same observation the third time, and I stood up (once again). Now the Messenger of Allah (ﷺ) said: What has happened to you, O Abu Qatada? Then I related the (whole) story, to him. At this, one of the people said: He has told the truth. Messenger of Allah 1 The belongings of the enemy killed by him are with me. Persuade him to forgo his right (in my favour). (Objecting to this proposal) Abu Bakr said: BY Allah, this will not happen. The Messenger of Allah (ﷺ) will not like to deprive one of the lions from among the lions of Allah who fight in the cause of Allah and His Messenger and give thee his share of the booty. So the Messenger of Allah (may peace he upon him) said: He (Abu Bakr) has told the truth, and so give the belongings to him (Abu Qatada). So he gave them to me. I sold the armour (which was a part of my share of the booty) and bought with the sale proceeds a garden in the street of Banu Salama. This was the first property I acquired after embracing Islam. In a version of the hadith narrated by Laith, the words uttered by Abu Bakr are:" No, never! He will not give it to a fox from the Quraish leaving aside a lion from the lions of Allah among...." And the hadith is closed with the words:" The first property I acquired}}
\hadithdefcmd{muslim}{4569}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا يُوسُفُ بْنُ الْمَاجِشُونِ، عَنْ صَالِحِ بْنِ إِبْرَاهِيمَ، بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ عَنْ أَبِيهِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، أَنَّهُ قَالَ بَيْنَا أَنَا وَاقِفٌ، فِي الصَّفِّ يَوْمَ بَدْرٍ نَظَرْتُ عَنْ يَمِينِي، وَشِمَالِي، فَإِذَا أَنَا بَيْنَ، غُلاَمَيْنِ مِنَ الأَنْصَارِ حَدِيثَةٍ أَسْنَانُهُمَا تَمَنَّيْتُ لَوْ كُنْتُ بَيْنَ أَضْلَعَ مِنْهُمَا فَغَمَزَنِي أَحَدُهُمَا ‏.‏ فَقَالَ يَا عَمِّ هَلْ تَعْرِفُ أَبَا جَهْلٍ قَالَ قُلْتُ نَعَمْ وَمَا حَاجَتُكَ إِلَيْهِ يَا ابْنَ أَخِي قَالَ أُخْبِرْتُ أَنَّهُ يَسُبُّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَالَّذِي نَفْسِي بِيَدِهِ لَئِنْ رَأَيْتُهُ لاَ يُفَارِقُ سَوَادِي سَوَادَهُ حَتَّى يَمُوتَ الأَعْجَلُ مِنَّا ‏.‏ قَالَ فَتَعَجَّبْتُ لِذَلِكَ فَغَمَزَنِي الآخَرُ فَقَالَ مِثْلَهَا - قَالَ - فَلَمْ أَنْشَبْ أَنْ نَظَرْتُ إِلَى أَبِي جَهْلٍ يَزُولُ فِي النَّاسِ فَقُلْتُ أَلاَ تَرَيَانِ هَذَا صَاحِبُكُمَا الَّذِي تَسْأَلاَنِ عَنْهُ قَالَ فَابْتَدَرَاهُ فَضَرَبَاهُ بِسَيْفَيْهِمَا حَتَّى قَتَلاَهُ ثُمَّ انْصَرَفَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَاهُ ‏.‏ فَقَالَ ‏"‏ أَيُّكُمَا قَتَلَهُ ‏"‏ ‏.‏ فَقَالَ كُلُّ وَاحِدٍ مِنْهُمَا أَنَا قَتَلْتُ ‏.‏ فَقَالَ ‏"‏ هَلْ مَسَحْتُمَا سَيْفَيْكُمَا ‏"‏ ‏.‏ قَالاَ لاَ ‏.‏ فَنَظَرَ فِي السَّيْفَيْنِ فَقَالَ ‏"‏ كِلاَكُمَا قَتَلَهُ ‏"‏ ‏.‏ وَقَضَى بِسَلَبِهِ لِمُعَاذِ بْنِ عَمْرِو بْنِ الْجَمُوحِ وَالرَّجُلاَنِ مُعَاذُ بْنُ عَمْرِو بْنِ الْجَمُوحِ وَمُعَاذُ ابْنُ عَفْرَاءَ ‏.‏\hadithno{4569}\hadithtrans{It has been narrated on the authority of 'Abd al-Rahman b. Auf who said:While I was standing in the battle array on the Day of Badr, I looked towards my right and my left, and found myself between two boys from the Ansar quite young in age. I wished I were between stronger persons. One of them made a sign to me and. said: Uncle, do you recognise Abu Jahl? 1 said: Yes. What do you want to do with him, O my nephew? He said: I have been told that he abuses the Messenger of Allah (ﷺ). By Allah, in Whose Hand is my life, if I see him (I will grapple with him) and will not leave him until one of us who is destined to die earlier is killed. The narrator said: I wondered at this. Then the other made a sign to me and said similar words. Soon after I saw Abu Jahl. He was moving about among men. I said to the two boys: Don't you see? He is the man you were inquiring about. (As soon as they heard this), they dashed towards him, struck him with their swords until he was killed. Then they returned to the Messenger of Allah (ﷺ) and informed him (to this effect). He asked: Which of you has killed him? Each one of them said: I have killed him. He said: Have you wiped your swords? They said: No. He examined their swords and said: Both of you have killed him. He then decided that the belongings of Abu Jahl he handed over to Mu'adh b. Amr b. al-Jamuh. And the two boys were Mu'adh b. Amr b. Jawth and Mu'adh b. Afra}}
\hadithdefcmd{muslim}{4570}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرٍ، عَنْ أَبِيهِ، عَنْ عَوْفِ بْنِ مَالِكٍ، قَالَ قَتَلَ رَجُلٌ مِنْ حِمْيَرَ رَجُلاً مِنَ الْعَدُوِّ فَأَرَادَ سَلَبَهُ فَمَنَعَهُ خَالِدُ بْنُ الْوَلِيدِ وَكَانَ وَالِيًا عَلَيْهِمْ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم عَوْفُ بْنُ مَالِكٍ فَأَخْبَرَهُ فَقَالَ لِخَالِدٍ ‏"‏ مَا مَنَعَكَ أَنْ تُعْطِيَهُ سَلَبَهُ ‏"‏ ‏.‏ قَالَ اسْتَكْثَرْتُهُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ ادْفَعْهُ إِلَيْهِ ‏"‏ ‏.‏ فَمَرَّ خَالِدٌ بِعَوْفٍ فَجَرَّ بِرِدَائِهِ ثُمَّ قَالَ هَلْ أَنْجَزْتُ لَكَ مَا ذَكَرْتُ لَكَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَمِعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَاسْتُغْضِبَ فَقَالَ ‏"‏ لاَ تُعْطِهِ يَا خَالِدُ لاَ تُعْطِهِ يَا خَالِدُ هَلْ أَنْتُمْ تَارِكُونَ لِي أُمَرَائِي إِنَّمَا مَثَلُكُمْ وَمَثَلُهُمْ كَمَثَلِ رَجُلٍ اسْتُرْعِيَ إِبِلاً أَوْ غَنَمًا فَرَعَاهَا ثُمَّ تَحَيَّنَ سَقْيَهَا فَأَوْرَدَهَا حَوْضًا فَشَرَعَتْ فِيهِ فَشَرِبَتْ صَفْوَهُ وَتَرَكَتْ كَدَرَهُ فَصَفْوُهُ لَكُمْ وَكَدَرُهُ عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{4570}\hadithtrans{Auf b. Malik has narrated that a man from the Himyar tribe killed an enemy and wanted to take the booty. Khalid b. Walid, who was the commander over them, forbade, him. 'Auf b Malik (the narrator) came to the Messenger of Allah (ﷺ) and informed him (to this effect). The latter asked Khalid:What prevented you from giving the booty to him? Khalid said: I thought it was too much. He (the Holy Prophet) said: Hand it over to him. Now when Khalid by Auf, the latter pulled him by his cloak and said (by way of chafing him): Hasn't the same thing happened what I reported to you from the Messenger of Allah (may peace he upon him)? When the Messenger of Allah (ﷺ) heard it. he was angry (and said): Khalid, don't give him, Khalid, don't give him. Are you going to desert the commanders appointed by roe? Your similitude and theirs is like a person who took camels and sheep for grazing. He grazed them and when it was time for them to have a drink, he brought them to a pool. So they drank from it, drinking away its clear water and leaving the turbid water below So the clear water (i. e. the best reward) is for you and the turbid water (i e. blame) is for them}}
\hadithdefcmd{muslim}{4571}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا صَفْوَانُ بْنُ عَمْرٍو، عَنْ عَبْدِ، الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ عَنْ أَبِيهِ، عَنْ عَوْفِ بْنِ مَالِكٍ الأَشْجَعِيِّ، قَالَ خَرَجْتُ مَعَ مَنْ خَرَجَ مَعَ زَيْدِ بْنِ حَارِثَةَ فِي غَزْوَةِ مُؤْتَةَ وَرَافَقَنِي مَدَدِيٌّ مِنَ الْيَمَنِ ‏.‏ وَسَاقَ الْحَدِيثَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِنَحْوِهِ غَيْرَ أَنَّهُ قَالَ فِي الْحَدِيثِ قَالَ عَوْفٌ فَقُلْتُ يَا خَالِدُ أَمَا عَلِمْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى بِالسَّلَبِ لِلْقَاتِلِ قَالَ بَلَى وَلَكِنِّي اسْتَكْثَرْتُهُ ‏.‏\hadithno{4571}\hadithtrans{It has been narrated on the authority of Auf b. Malik al-Ashja'i who said:I joined the expedition that marched under Zaid b. Haritha to Muta, and I received reinformcement from the Yemen. (After this introduction), the narrator narrated the tradition that had gone before except that in his version Auf was reported to have said (to Khalid): Khalid, didn't you know that the Messenger of Allah (way peace be upon him) had decided In favour of giving the booty (sized from an enemy) to one who killed him? He (Khalid) said: Yes. but I thought it was too much}}
\hadithdefcmd{muslim}{4572}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ الْحَنَفِيُّ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنِي إِيَاسُ بْنُ سَلَمَةَ، حَدَّثَنِي أَبِي سَلَمَةُ بْنُ الأَكْوَعِ، قَالَ غَزَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم هَوَازِنَ فَبَيْنَا نَحْنُ نَتَضَحَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِذْ جَاءَ رَجُلٌ عَلَى جَمَلٍ أَحْمَرَ فَأَنَاخَهُ ثُمَّ انْتَزَعَ طَلَقًا مِنْ حَقَبِهِ فَقَيَّدَ بِهِ الْجَمَلَ ثُمَّ تَقَدَّمَ يَتَغَدَّى مَعَ الْقَوْمِ وَجَعَلَ يَنْظُرُ وَفِينَا ضَعْفَةٌ وَرِقَّةٌ فِي الظَّهْرِ وَبَعْضُنَا مُشَاةٌ إِذْ خَرَجَ يَشْتَدُّ فَأَتَى جَمَلَهُ فَأَطْلَقَ قَيْدَهُ ثُمَّ أَنَاخَهُ وَقَعَدَ عَلَيْهِ فَأَثَارَهُ فَاشْتَدَّ بِهِ الْجَمَلُ فَاتَّبَعَهُ رَجُلٌ عَلَى نَاقَةٍ وَرْقَاءَ ‏.‏ قَالَ سَلَمَةُ وَخَرَجْتُ أَشْتَدُّ فَكُنْتُ عِنْدَ وَرِكِ النَّاقَةِ ‏.‏ ثُمَّ تَقَدَّمْتُ حَتَّى كُنْتُ عِنْدَ وَرِكِ الْجَمَلِ ثُمَّ تَقَدَّمْتُ حَتَّى أَخَذْتُ بِخِطَامِ الْجَمَلِ فَأَنَخْتُهُ فَلَمَّا وَضَعَ رُكْبَتَهُ فِي الأَرْضِ اخْتَرَطْتُ سَيْفِي فَضَرَبْتُ رَأْسَ الرَّجُلِ فَنَدَرَ ثُمَّ جِئْتُ بِالْجَمَلِ أَقُودُهُ عَلَيْهِ رَحْلُهُ وَسِلاَحُهُ فَاسْتَقْبَلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَالنَّاسُ مَعَهُ فَقَالَ ‏"‏ مَنْ قَتَلَ الرَّجُلَ ‏"‏ ‏.‏ قَالُوا ابْنُ الأَكْوَعِ ‏.‏ قَالَ ‏"‏ لَهُ سَلَبُهُ أَجْمَعُ ‏"‏ ‏.‏\hadithno{4572}\hadithtrans{It has been reported by Salama b. al-Akwa':We fought the Battle of Hawazin along with the Messenger of Allah (ﷺ). (One day) when we were having our breakfast with the Messenger of Allah (may peace he upon him), a man came riding a red camel. He made it kneel down, extracted a strip of leather from its girth and tethered the camel with it. Then he began to take food with the people and look (curiously around). We were in a poor condition as some of us were on foot (being without any riding animals). All of a sudden, he left us hurriedy, came to his camel, untethered it, made it kneel down, mounted it and urged the beast which ran off with him. A man on a brown rhe-camel chased him (taking him for a spy). Salama (the narrator) said: I followed on foot. I ran on until I was near the thigh of the she-camel. I advanced further until I was near the haunches of the camel. I advanced still further until I caught hold of the nosestring of the camel. I made it kneel down. As soon as it placed its knee on the ground, I drew my sword and struck at the head, of the rider who fell down. I brought the camel driving it along with the man's baggage and weapons. The Messenger of Allah (ﷺ) came forward to meet me and the people were with him. He asked: Who has killed the man? The people said: Ibn Akwa'. He said: Everything of the man is for him (Ibn Akwa)}}
\hadithdefcmd{muslim}{4573}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنِي إِيَاسُ بْنُ سَلَمَةَ، حَدَّثَنِي أَبِي قَالَ، غَزَوْنَا فَزَارَةَ وَعَلَيْنَا أَبُو بَكْرٍ أَمَّرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَيْنَا فَلَمَّا كَانَ بَيْنَنَا وَبَيْنَ الْمَاءِ سَاعَةٌ أَمَرَنَا أَبُو بَكْرٍ فَعَرَّسْنَا ثُمَّ شَنَّ الْغَارَةَ فَوَرَدَ الْمَاءَ فَقَتَلَ مَنْ قَتَلَ عَلَيْهِ وَسَبَى وَأَنْظُرُ إِلَى عُنُقٍ مِنَ النَّاسِ فِيهِمُ الذَّرَارِيُّ فَخَشِيتُ أَنْ يَسْبِقُونِي إِلَى الْجَبَلِ فَرَمَيْتُ بِسَهْمٍ بَيْنَهُمْ وَبَيْنَ الْجَبَلِ فَلَمَّا رَأَوُا السَّهْمَ وَقَفُوا فَجِئْتُ بِهِمْ أَسُوقُهُمْ وَفِيهِمُ امْرَأَةٌ مِنْ بَنِي فَزَارَةَ عَلَيْهَا قِشْعٌ مِنْ أَدَمٍ - قَالَ الْقِشْعُ النِّطَعُ - مَعَهَا ابْنَةٌ لَهَا مِنْ أَحْسَنِ الْعَرَبِ فَسُقْتُهُمْ حَتَّى أَتَيْتُ بِهِمْ أَبَا بَكْرٍ فَنَفَّلَنِي أَبُو بَكْرٍ ابْنَتَهَا فَقَدِمْنَا الْمَدِينَةَ وَمَا كَشَفْتُ لَهَا ثَوْبًا فَلَقِيَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي السُّوقِ فَقَالَ ‏"‏ يَا سَلَمَةُ هَبْ لِي الْمَرْأَةَ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ وَاللَّهِ لَقَدْ أَعْجَبَتْنِي وَمَا كَشَفْتُ لَهَا ثَوْبًا ثُمَّ لَقِيَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الْغَدِ فِي السُّوقِ فَقَالَ لِي ‏"‏ يَا سَلَمَةُ هَبْ لِي الْمَرْأَةَ لِلَّهِ أَبُوكَ ‏"‏ ‏.‏ فَقُلْتُ هِيَ لَكَ يَا رَسُولَ اللَّهِ فَوَاللَّهِ مَا كَشَفْتُ لَهَا ثَوْبًا فَبَعَثَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى أَهْلِ مَكَّةَ فَفَدَى بِهَا نَاسًا مِنَ الْمُسْلِمِينَ كَانُوا أُسِرُوا بِمَكَّةَ ‏.‏\hadithno{4573}\hadithtrans{It has been narrated on the authority of Salama (b. al-Akwa') who said:We fought against the Fazara, and Abu Bakr was the commander over us. He had been appointed by the Messenger of Allah (ﷺ). When we were only at an hour's distance from the water of the enemy, Abu Bakr ordered us to attack. We made a halt during the last part of the night to rest and then we attacked from all sides and reached their watering-place where a battle was fought. Some of the enemies were killed and some were taken prisoners. I saw a group of persons that consisted of women and children. I was afraid lest they should reach the mountain before me, so I shot an arrow between them and the mountain. When they saw the arrow, they stopped. So I brought them, driving them along. Among them was a woman from Banu Fazara. She was wearing a leather coat. With her was her daughter who was one of the prettiest girls in Arabia. I drove them along until I brought them to Abu Bakr who bestowed that girl upon me as a prize. So we arrived in Medina. I had not yet disrobed her when the Messenger of Allah (ﷺ) met me in the street and said: Give me that girl, O Salama. I said: Messenger of Allah, she has fascinated me. I had not yet disrobed her. When on the next day the Messenger of Allah (ﷺ) again met me in the street, he said: O Salama, give me that girl, may God bless your father. I said: She is for you, Messenger of Allah! By Allah. I have not yet disrobed her. The Messenger of Allah (ﷺ) sent her to the people of Mecca, and surrendered her as ransom for a number of Muslims who had been kept as prisoners at Mecca}}
\hadithdefcmd{muslim}{4574}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا قَرْيَةٍ أَتَيْتُمُوهَا وَأَقَمْتُمْ فِيهَا فَسَهْمُكُمْ فِيهَا وَأَيُّمَا قَرْيَةٍ عَصَتِ اللَّهَ وَرَسُولَهُ فَإِنَّ خُمُسَهَا لِلَّهِ وَلِرَسُولِهِ ثُمَّ هِيَ لَكُمْ ‏"‏ ‏.‏\hadithno{4574}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:If you come to a township (which has surrendered without a formal war) and stay therein, you have a share (that will be in the form of an award) in (the properties obtained from) it. If a township disobeys Allah and His Messenger (and actually fights against the Muslims) one-fifth of the booty seized therefrom is for Allah and His Apostle and the rest is for you}}
\hadithdefcmd{muslim}{4575}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ عَبَّادٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ - وَاللَّفْظُ لاِبْنِ أَبِي شَيْبَةَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنِ الزُّهْرِيِّ، عَنْ مَالِكِ بْنِ أَوْسٍ، عَنْ عُمَرَ، قَالَ كَانَتْ أَمْوَالُ بَنِي النَّضِيرِ مِمَّا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِمَّا لَمْ يُوجِفْ عَلَيْهِ الْمُسْلِمُونَ بِخَيْلٍ وَلاَ رِكَابٍ فَكَانَتْ لِلنَّبِيِّ صلى الله عليه وسلم خَاصَّةً فَكَانَ يُنْفِقُ عَلَى أَهْلِهِ نَفَقَةَ سَنَةٍ وَمَا بَقِيَ يَجْعَلُهُ فِي الْكُرَاعِ وَالسِّلاَحِ عُدَّةً فِي سَبِيلِ اللَّهِ ‏.‏\hadithno{4575}\hadithtrans{It has been narrated on the authority of Umar, who said:The properties abandoned by Banu Nadir were the ones which Allah bestowed upon His Apostle for which no expedition was undertaken either with cavalry or camelry. These properties were particularly meant for the Prophet (ﷺ). He would meet the annual expenditure of his family from the income thereof, and would spend what remained for purchasing horses and weapons as preparation for Jihad}}
\hadithdefcmd{muslim}{4576}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{4576}\hadithtrans{This hadith has been narrated on the authority of Zuhri}}
\hadithdefcmd{muslim}{4577}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ الضُّبَعِيُّ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، أَنَّ مَالِكَ بْنَ أَوْسٍ، حَدَّثَهُ قَالَ أَرْسَلَ إِلَىَّ عُمَرُ بْنُ الْخَطَّابِ فَجِئْتُهُ حِينَ تَعَالَى النَّهَارُ - قَالَ - فَوَجَدْتُهُ فِي بَيْتِهِ جَالِسًا عَلَى سَرِيرٍ مُفْضِيًا إِلَى رِمَالِهِ مُتَّكِئًا عَلَى وِسَادَةٍ مِنْ أَدَمٍ ‏.‏ فَقَالَ لِي يَا مَالُ إِنَّهُ قَدْ دَفَّ أَهْلُ أَبْيَاتٍ مِنْ قَوْمِكَ وَقَدْ أَمَرْتُ فِيهِمْ بِرَضْخٍ فَخُذْهُ فَاقْسِمْهُ بَيْنَهُمْ - قَالَ - قُلْتُ لَوْ أَمَرْتَ بِهَذَا غَيْرِي قَالَ خُذْهُ يَا مَالُ ‏.‏ قَالَ فَجَاءَ يَرْفَا فَقَالَ هَلْ لَكَ يَا أَمِيرَ الْمُؤْمِنِينَ فِي عُثْمَانَ وَعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَالزُّبَيْرِ وَسَعْدٍ فَقَالَ عُمَرُ نَعَمْ ‏.‏ فَأَذِنَ لَهُمْ فَدَخَلُوا ثُمَّ جَاءَ ‏.‏ فَقَالَ هَلْ لَكَ فِي عَبَّاسٍ وَعَلِيٍّ قَالَ نَعَمْ ‏.‏ فَأَذِنَ لَهُمَا فَقَالَ عَبَّاسٌ يَا أَمِيرَ الْمُؤْمِنِينَ اقْضِ بَيْنِي وَبَيْنَ هَذَا الْكَاذِبِ الآثِمِ الْغَادِرِ الْخَائِنِ ‏.‏ فَقَالَ الْقَوْمُ أَجَلْ يَا أَمِيرَ الْمُؤْمِنِينَ فَاقْضِ بَيْنَهُمْ وَأَرِحْهُمْ ‏.‏ فَقَالَ مَالِكُ بْنُ أَوْسٍ يُخَيَّلُ إِلَىَّ أَنَّهُمْ قَدْ كَانُوا قَدَّمُوهُمْ لِذَلِكَ - فَقَالَ عُمَرُ اتَّئِدَا أَنْشُدُكُمْ بِاللَّهِ الَّذِي بِإِذْنِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ أَتَعْلَمُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ نُورَثُ مَا تَرَكْنَا صَدَقَةٌ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ ثُمَّ أَقْبَلَ عَلَى الْعَبَّاسِ وَعَلِيٍّ فَقَالَ أَنْشُدُكُمَا بِاللَّهِ الَّذِي بِإِذْنِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ أَتَعْلَمَانِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ نُورَثُ مَا تَرَكْنَاهُ صَدَقَةٌ ‏"‏ ‏.‏ قَالاَ نَعَمْ ‏.‏ فَقَالَ عُمَرُ إِنَّ اللَّهَ جَلَّ وَعَزَّ كَانَ خَصَّ رَسُولَهُ صلى الله عليه وسلم بِخَاصَّةٍ لَمْ يُخَصِّصْ بِهَا أَحَدًا غَيْرَهُ قَالَ ‏\{‏ مَا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِنْ أَهْلِ الْقُرَى فَلِلَّهِ وَلِلرَّسُولِ‏\}‏ مَا أَدْرِي هَلْ قَرَأَ الآيَةَ الَّتِي قَبْلَهَا أَمْ لاَ ‏.‏ قَالَ فَقَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَكُمْ أَمْوَالَ بَنِي النَّضِيرِ فَوَاللَّهِ مَا اسْتَأْثَرَ عَلَيْكُمْ وَلاَ أَخَذَهَا دُونَكُمْ حَتَّى بَقِيَ هَذَا الْمَالُ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْخُذُ مِنْهُ نَفَقَةَ سَنَةٍ ثُمَّ يَجْعَلُ مَا بَقِيَ أُسْوَةَ الْمَالِ ‏.‏ ثُمَّ قَالَ أَنْشُدُكُمْ بِاللَّهِ الَّذِي بِإِذْنِهِ تَقُومُ السَّمَاءُ وَالأَرْضُ أَتَعْلَمُونَ ذَلِكَ قَالُوا نَعَمْ ‏.‏ ثُمَّ نَشَدَ عَبَّاسًا وَعَلِيًّا بِمِثْلِ مَا نَشَدَ بِهِ الْقَوْمَ أَتَعْلَمَانِ ذَلِكَ قَالاَ نَعَمْ ‏.‏ قَالَ فَلَمَّا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ أَبُو بَكْرٍ أَنَا وَلِيُّ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجِئْتُمَا تَطْلُبُ مِيرَاثَكَ مِنَ ابْنِ أَخِيكَ وَيَطْلُبُ هَذَا مِيرَاثَ امْرَأَتِهِ مِنْ أَبِيهَا فَقَالَ أَبُو بَكْرٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا نُورَثُ مَا تَرَكْنَا صَدَقَةٌ ‏"‏ ‏.‏ فَرَأَيْتُمَاهُ كَاذِبًا آثِمًا غَادِرًا خَائِنًا وَاللَّهُ يَعْلَمُ إِنَّهُ لَصَادِقٌ بَارٌّ رَاشِدٌ تَابِعٌ لِلْحَقِّ ثُمَّ تُوُفِّيَ أَبُو بَكْرٍ وَأَنَا وَلِيُّ رَسُولِ اللَّهِ صلى الله عليه وسلم وَوَلِيُّ أَبِي بَكْرٍ فَرَأَيْتُمَانِي كَاذِبًا آثِمًا غَادِرًا خَائِنًا وَاللَّهُ يَعْلَمُ إِنِّي لَصَادِقٌ بَارٌّ رَاشِدٌ تَابِعٌ لِلْحَقِّ فَوَلِيتُهَا ثُمَّ جِئْتَنِي أَنْتَ وَهَذَا وَأَنْتُمَا جَمِيعٌ وَأَمْرُكُمَا وَاحِدٌ فَقُلْتُمَا ادْفَعْهَا إِلَيْنَا فَقُلْتُ إِنْ شِئْتُمْ دَفَعْتُهَا إِلَيْكُمَا عَلَى أَنَّ عَلَيْكُمَا عَهْدَ اللَّهِ أَنْ تَعْمَلاَ فِيهَا بِالَّذِي كَانَ يَعْمَلُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَخَذْتُمَاهَا بِذَلِكَ قَالَ أَكَذَلِكَ قَالاَ نَعَمْ ‏.‏ قَالَ ثُمَّ جِئْتُمَانِي لأَقْضِيَ بَيْنَكُمَا وَلاَ وَاللَّهِ لاَ أَقْضِي بَيْنَكُمَا بِغَيْرِ ذَلِكَ حَتَّى تَقُومَ السَّاعَةُ فَإِنْ عَجَزْتُمَا عَنْهَا فَرُدَّاهَا إِلَىَّ ‏.‏\hadithno{4577}\hadithtrans{It is reported by Zuhri that this tradition was narrated to him by Malik b. Aus who said:Umar b. al-Khattab sent for me and I came to him when the day had advanced. I found him in his house sitting on his bare bed-stead, reclining on a leather pillow. He said (to me): Malik, some people of your tribe have hastened to me (with a request for help). I have ordered a little money for them. Take it and distribute it among them. I said: I wish you had ordered somebody else to do this job. He said: Malik, take it (and do what you have been told). At this moment (his man-servant) Yarfa' came in and said: Commander of the Faithful, what do you say about Uthman, Abd al-Rabman b. 'Auf, Zubair and Sa'd (who have come to seek an audience with you)? He said: Yes, and permitted them. so they entered. Then he (Yarfa') came again and said: What do you say about 'Ali and Abbas (who are present at the door)? He said: Yes, and permitted them to enter. Abbas said: Commander of the Faithful, decide (the dispute) between me and this sinful, treacherous, dishonest liar. The people (who were present) also said: Yes. Commander of the Faithful, do decide (the dispute) and have mercy on them. Malik b. Aus said: I could well imagine that they had sent them in advance for this purpose (by 'Ali and Abbas). 'Umar said: Wait and be patient. I adjure you by Allah by Whose order the heavens and the earth are sustained, don't you know that the Messenger of Allah (ﷺ) said:" We (prophets) do not have any heirs; what we leave behind is (to be given in) charity"? They said: Yes. Then he turned to Abbas and 'Ali and said: I adjure you both by Allah by Whose order the heavens and earth are sustained, don't you know that the Messenger of Allah (ﷺ) said:" We do not have any heirs; what we leave behind is (to be given in) charity"? They (too) said: Yes. (Then) Umar said: Allah, the Glorious and Exalted, had done to His Messenger (ﷺ) a special favour that He has not done to anyone else except him. He quoted the Qur'anic verse:" What Allah has bestowed upon His Apostle from (the properties) of the people of township is for Allah and His Messenger". The narrator said: I do not know whether he also recited the previous verse or not. Umar continued: The Messenger of Allah (ﷺ) distrbuted among you the properties abandoned by Banu Nadir. By Allah, he never preferred himself over you and never appropriated anything to your exclusion. (After a fair distribution in this way) this property was left over. The Messenger of Allah (ﷺ) would meet from its income his annual expenditure, and what remained would be deposited in the Bait-ul-Mal. (Continuing further) he said: I adjure you by Allah by Whose order the heavens and the earth are sustained. Do you know this? They said: Yes. Then he adjured Abbas and 'All as he had adjured the other persons and asked: Do you both know this? They said: Yes. He said: When the Messenger of Allah (ﷺ) passed away, Abu Bakr said:" I am the successor of the Messenger of Allah (ﷺ)." Both of you came to demand your shares from the property (left behind by the Messenger of Allah). (Referring to Hadrat 'Abbas), he said: You demanded your share from the property of your nephew, and he (referring to 'Ali) demanded a share on behalf of his wife from the property of her father. Abu Bakr (Allah be pleased with him) said: The Messenger of Allah (ﷺ) had said:" We do not have any heirs; what we leave behind is (to be given in) charity." So both of you thought him to be a liar, sinful, treacherous and dishonest. And Allah knows that he was true, virtuous, well-guided and a follower of truth. When Abu Bakr passed away and (I have become) the successor of the Messenger of Allah (ﷺ) and Abu Bakr (Allah be pleased with him), you thought me to be a liar, sinful, treacherous and dishonest. And Allah knows that I am true, virtuous, well-guided and a follower of truth. I became the guardian of this property. Then you as well as he came to me. Both of you have come and your purpose is identical. You said: Entrust the property to us. I said: If you wish that I should entrust it to you, it will be on the condition that both of you will undertake to abide by a pledge made with Allah that you will use it in the same way as the Messenger of Allah (ﷺ) used it. So both of you got it. He said: Wasn't it like this? They said: Yes. He said: Then you have (again) come to me with the request that I should adjudge between you. No, by Allah. I will not give any other judgment except this until the arrival of the Doomsday. If you are unable to hold the property on this condition, return it to me}}
\hadithdefcmd{muslim}{4578}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، - قَالَ ابْنُ رَافِعٍ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، - أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ مَالِكِ بْنِ أَوْسِ، بْنِ الْحَدَثَانِ قَالَ أَرْسَلَ إِلَىَّ عُمَرُ بْنُ الْخَطَّابِ فَقَالَ إِنَّهُ قَدْ حَضَرَ أَهْلُ أَبْيَاتٍ مِنْ قَوْمِكَ ‏.‏ بِنَحْوِ حَدِيثِ مَالِكٍ ‏.‏ غَيْرَ أَنَّ فِيهِ، فَكَانَ يُنْفِقُ عَلَى أَهْلِهِ مِنْهُ سَنَةً وَرُبَّمَا قَالَ مَعْمَرٌ يَحْبِسُ قُوتَ أَهْلِهِ مِنْهُ سَنَةً ثُمَّ يَجْعَلُ مَا بَقِيَ مِنْهُ مَجْعَلَ مَالِ اللَّهِ عَزَّ وَجَلَّ ‏.‏\hadithno{4578}\hadithtrans{The same hadith has been narrated by a different chain of transmitters with a slight variation in wording:'Umar b. al-Khattab sent for me and said: Some families from your tribe have come to me (then follows the foregoing hadith) by Malik with the difference that the Messenger of Allah (ﷺ) would spend on his family for a year. And sometimes Ma'mar said: He would retain sustenance for his family for a year, and what was left of that he spent in the cause of Allah, the Majestic and Exalted}}
\hadithdefcmd{muslim}{4579}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ إِنَّ أَزْوَاجَ النَّبِيِّ صلى الله عليه وسلم حِينَ تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَرَدْنَ أَنْ يَبْعَثْنَ عُثْمَانَ بْنَ عَفَّانَ إِلَى أَبِي بَكْرٍ فَيَسْأَلْنَهُ مِيرَاثَهُنَّ مِنَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ عَائِشَةُ لَهُنَّ أَلَيْسَ قَدْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ نُورَثُ مَا تَرَكْنَا فَهُوَ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{4579}\hadithtrans{It is narrated on the authority of 'A'isha who said:When the Messenger of Allah (ﷺ) passed away, his wives made up their minds to send 'Uthman b. 'Affan (as their spokesman) to Abu Bakr to demand from him their share from the legacy of the Prophet (ﷺ). (At this), A'isha said to them: Hasn't the Messenger of Allah (ﷺ) said:" We (Prophets) do not have any heirs; what we leave behind is (to be given in) charity"?}}
\hadithdefcmd{muslim}{4580}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، أَخْبَرَنَا حُجَيْنٌ، حَدَّثَنَا لَيْثٌ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّهَا أَخْبَرَتْهُ أَنَّ فَاطِمَةَ بِنْتَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَرْسَلَتْ إِلَى أَبِي بَكْرٍ الصِّدِّيقِ تَسْأَلُهُ مِيرَاثَهَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم مِمَّا أَفَاءَ اللَّهُ عَلَيْهِ بِالْمَدِينَةِ وَفَدَكٍ وَمَا بَقِيَ مِنْ خُمْسِ خَيْبَرَ فَقَالَ أَبُو بَكْرٍ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نُورَثُ مَا تَرَكْنَا صَدَقَةٌ إِنَّمَا يَأْكُلُ آلُ مُحَمَّدٍ - صلى الله عليه وسلم - فِي هَذَا الْمَالِ ‏"‏ ‏.‏ وَإِنِّي وَاللَّهِ لاَ أُغَيِّرُ شَيْئًا مِنْ صَدَقَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم عَنْ حَالِهَا الَّتِي كَانَتْ عَلَيْهَا فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلأَعْمَلَنَّ فِيهَا بِمَا عَمِلَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَبَى أَبُو بَكْرٍ أَنْ يَدْفَعَ إِلَى فَاطِمَةَ شَيْئًا فَوَجَدَتْ فَاطِمَةُ عَلَى أَبِي بَكْرٍ فِي ذَلِكَ - قَالَ - فَهَجَرَتْهُ فَلَمْ تُكَلِّمْهُ حَتَّى تُوُفِّيَتْ وَعَاشَتْ بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم سِتَّةَ أَشْهُرٍ فَلَمَّا تُوُفِّيَتْ دَفَنَهَا زَوْجُهَا عَلِيُّ بْنُ أَبِي طَالِبٍ لَيْلاً وَلَمْ يُؤْذِنْ بِهَا أَبَا بَكْرٍ وَصَلَّى عَلَيْهَا عَلِيٌّ وَكَانَ لِعَلِيٍّ مِنَ النَّاسِ وِجْهَةٌ حَيَاةَ فَاطِمَةَ فَلَمَّا تُوُفِّيَتِ اسْتَنْكَرَ عَلِيٌّ وُجُوهَ النَّاسِ فَالْتَمَسَ مُصَالَحَةَ أَبِي بَكْرٍ وَمُبَايَعَتَهُ وَلَمْ يَكُنْ بَايَعَ تِلْكَ الأَشْهُرَ فَأَرْسَلَ إِلَى أَبِي بَكْرٍ أَنِ ائْتِنَا وَلاَ يَأْتِنَا مَعَكَ أَحَدٌ - كَرَاهِيَةَ مَحْضَرِ عُمَرَ بْنِ الْخَطَّابِ - فَقَالَ عُمَرُ لأَبِي بَكْرٍ وَاللَّهِ لاَ تَدْخُلْ عَلَيْهِمْ وَحْدَكَ ‏.‏ فَقَالَ أَبُو بَكْرٍ وَمَا عَسَاهُمْ أَنْ يَفْعَلُوا بِي إِنِّي وَاللَّهِ لآتِيَنَّهُمْ ‏.‏ فَدَخَلَ عَلَيْهِمْ أَبُو بَكْرٍ ‏.‏ فَتَشَهَّدَ عَلِيُّ بْنُ أَبِي طَالِبٍ ثُمَّ قَالَ إِنَّا قَدْ عَرَفْنَا يَا أَبَا بَكْرٍ فَضِيلَتَكَ وَمَا أَعْطَاكَ اللَّهُ وَلَمْ نَنْفَسْ عَلَيْكَ خَيْرًا سَاقَهُ اللَّهُ إِلَيْكَ وَلَكِنَّكَ اسْتَبْدَدْتَ عَلَيْنَا بِالأَمْرِ وَكُنَّا نَحْنُ نَرَى لَنَا حَقًّا لِقَرَابَتِنَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَلَمْ يَزَلْ يُكَلِّمُ أَبَا بَكْرٍ حَتَّى فَاضَتْ عَيْنَا أَبِي بَكْرٍ فَلَمَّا تَكَلَّمَ أَبُو بَكْرٍ قَالَ وَالَّذِي نَفْسِي بِيَدِهِ لَقَرَابَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم أَحَبُّ إِلَىَّ أَنْ أَصِلَ مِنْ قَرَابَتِي وَأَمَّا الَّذِي شَجَرَ بَيْنِي وَبَيْنَكُمْ مِنْ هَذِهِ الأَمْوَالِ فَإِنِّي لَمْ آلُ فِيهِ عَنِ الْحَقِّ وَلَمْ أَتْرُكْ أَمْرًا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَصْنَعُهُ فِيهَا إِلاَّ صَنَعْتُهُ ‏.‏ فَقَالَ عَلِيٌّ لأَبِي بَكْرٍ مَوْعِدُكَ الْعَشِيَّةُ لِلْبَيْعَةِ ‏.‏ فَلَمَّا صَلَّى أَبُو بَكْرٍ صَلاَةَ الظُّهْرِ رَقِيَ عَلَى الْمِنْبَرِ فَتَشَهَّدَ وَذَكَرَ شَأْنَ عَلِيٍّ وَتَخَلُّفَهُ عَنِ الْبَيْعَةِ وَعُذْرَهُ بِالَّذِي اعْتَذَرَ إِلَيْهِ ثُمَّ اسْتَغْفَرَ وَتَشَهَّدَ عَلِيُّ بْنُ أَبِي طَالِبٍ فَعَظَّمَ حَقَّ أَبِي بَكْرٍ وَأَنَّهُ لَمْ يَحْمِلْهُ عَلَى الَّذِي صَنَعَ نَفَاسَةً عَلَى أَبِي بَكْرٍ وَلاَ إِنْكَارًا لِلَّذِي فَضَّلَهُ اللَّهُ بِهِ وَلَكِنَّا كُنَّا نَرَى لَنَا فِي الأَمْرِ نَصِيبًا فَاسْتُبِدَّ عَلَيْنَا بِهِ فَوَجَدْنَا فِي أَنْفُسِنَا فَسُرَّ بِذَلِكَ الْمُسْلِمُونَ وَقَالُوا أَصَبْتَ ‏.‏ فَكَانَ الْمُسْلِمُونَ إِلَى عَلِيٍّ قَرِيبًا حِينَ رَاجَعَ الأَمْرَ الْمَعْرُوفَ ‏.‏\hadithno{4580}\hadithtrans{It is narrated on the authority of Urwa b. Zubair who narrated from A'isha that she informed him that Fatima, daughter of the Messenger of Allah (ﷺ), sent someone to Abu Bakr to demand from him her share of the legacy left by the Messenger of Allah (ﷺ) from what Allah had bestowed upon him at Medina and Fadak and what was left from one-filth of the income (annually received) from Khaibar. Abu Bakr said:The Messenger of Allah (ﷺ) said:" We (prophets) do not have any heirs; what we leave behind is (to be given in) charity." The household of the Messenger of Allah (ﷺ) will live on the income from these properties, but, by Allah, I will not change the charity of the Messenger of Allah (ﷺ) from the condition in which it was in his own time. I will do the same with it as the Messenger of Allah (may peace be upun him) himself used to do. So Abu Bakr refused to hand over anything from it to Fatima who got angry with Abu Bakr for this reason. She forsook him and did not talk to him until the end of her life. She lived for six months after the death of the Messenger of Allah (ﷺ). When she died, her husband. 'Ali b. Abu Talib, buried her at night. He did not inform Abu Bakr about her death and offered the funeral prayer over her himself. During the lifetime of Fatima, 'All received (special) regard from the people. After she had died, he felt estrangement in the faces of the people towards him. So he sought to make peace with Abu Bakr and offer his allegiance to him. He had not yet owed allegiance to him as Caliph during these months. He sent a person to Abu Bakr requesting him to visit him unaccompanied by anyone (disapproving the presence of Umar). 'Umar said to Abu Bakr: BY Allah, you will not visit them alone. Abu Bakr said: What will they do to me? By Allah, I will visit them. And he did pay them a visit alone. 'All recited Tashahhud (as it is done in the beginning of a religious sermon) ; then said: We recognise your moral excellence and what Allah has bestowed upon you. We do not envy the favour (i. e. the Catiphate) which Allah nas conferred upon you; but you have done it (assumed the position of Caliph) alone (without consulting us), and we thought we had a right (to be consulted) on account of our kinship with the Messenger of Allah (ﷺ). He continued to talk to Abu Bakr (in this vein) until the latter's eyes welled up with tears. Then Abd Bakr spoke and said: By Allah, in Whose Hand is my life, the kinship of the Messenger of Allah (ﷺ) is dearer to me than the kinship of my own people. As regards the dispute that has arisen between you and me about these properties, I have not deviated from the right course and I have not given up doing about them what the Messenger of Allah (ﷺ) used to do. So 'Ali said to Abu Bakr: This aftetnoon is (fixed) for (swearing) allegiance (to you). So when Abu Bakr had finished his Zuhr prayer, he ascended the pulpit and recited Tashahhud, and described the status of 'Ali, his delay in swearing allegiance and the excuse which lie had offered to him (for this delay). (After this) he asked for God's forgiveness. Then 'Ali b. Abu Talib recited the Tashahhud. extolled the merits of Abu Bakr and (said that) his action was nott prompted by any jealousy of Abu Bakr on his part or his refusal to accept the high position which Allah had conferred upon him, (adding: ) But we were of the opinion that we should have a share in the government, but the matter had been decided without taking us into confidence, and this displeased us. (Hence the delay in offering allegiance. The Muslims were pleased with this (explanation) and they said: You have done the right thing. The Muslims were (again) favourably inclined to 'Ali since he adopted the proper course of action}}
\hadithdefcmd{muslim}{4581}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَ مُحَمَّدُ بْنُ رَافِعٍ وَعَبْدُ بْنُ حُمَيْدٍ قَالَ ابْنُ رَافِعٍ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّصلى الله عليه وسلم وَهُمَا حِينَئِذٍ يَطْلُبَانِ أَرْضَهُ مِنْ فَدَكٍ وَسَهْمَهُ مِنْ خَيْبَرَ ‏.‏ فَقَالَ لَهُمَا أَبُو بَكْرٍ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ وَسَاقَ الْحَدِيثَ بِمِثْلِ مَعْنَى حَدِيثِ عُقَيْلٍ عَنِ الزُّهْرِيِّ غَيْرَ أَنَّهُ قَالَ ثُمَّ قَامَ عَلِيٌّ فَعَظَّمَ مِنْ حَقِّ أَبِي بَكْرٍ وَذَكَرَ فَضِيلَتَهُ وَسَابِقَتَهُ ثُمَّ مَضَى إِلَى أَبِي بَكْرٍ فَبَايَعَهُ فَأَقْبَلَ النَّاسُ إِلَى عَلِيٍّ فَقَالُوا أَصَبْتَ وَأَحْسَنْتَ ‏.‏ فَكَانَ النَّاسُ قَرِيبًا إِلَى عَلِيٍّ حِينَ قَارَبَ الأَمْرَ الْمَعْرُوفَ ‏.‏\hadithno{4581}\hadithtrans{It has been narrated on the authority of 'A'isha that Fatima and 'Abbas approached Abu Bakr, soliciting transfer of the legacy of the Messenger of Allah (ﷺ) to them. At that time, they were demanding his (Holy Prophet's) lands at Fadak and his share from Khaibar. Abu Bakr said to them:I have heard from the Messenger of Allah (ﷺ). Then he quoted the hadith having nearly the same meaning as the one which has been narrated by Uqail on the authority of al-Zuhri (and which his gone before) except that in his version he said: Then 'Ali stood up, extolled the merits of Abu Bakr mentioned his superiority, and his earlier acceptance of Islam. Then he walked to Abu Bakr and swore allegiance to him. (At this) people turned towards 'Ali and said: you have done the right thing. And they became favourably inclined to 'Ali after he had adopted the proper course of action}}
\hadithdefcmd{muslim}{4582}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَالْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ قَالاَ حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ فَاطِمَةَ بِنْتَ رَسُولِ اللَّهِ صلى الله عليه وسلم سَأَلَتْ أَبَا بَكْرٍ بَعْدَ وَفَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنْ يَقْسِمَ لَهَا مِيرَاثَهَا مِمَّا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِمَّا أَفَاءَ اللَّهُ عَلَيْهِ ‏.‏ فَقَالَ لَهَا أَبُو بَكْرٍ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نُورَثُ مَا تَرَكْنَا صَدَقَةٌ ‏"‏ ‏.‏ قَالَ وَعَاشَتْ بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم سِتَّةَ أَشْهُرٍ وَكَانَتْ فَاطِمَةُ تَسْأَلُ أَبَا بَكْرٍ نَصِيبَهَا مِمَّا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ خَيْبَرَ وَفَدَكٍ وَصَدَقَتِهِ بِالْمَدِينَةِ فَأَبَى أَبُو بَكْرٍ عَلَيْهَا ذَلِكَ وَقَالَ لَسْتُ تَارِكًا شَيْئًا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْمَلُ بِهِ إِلاَّ عَمِلْتُ بِهِ إِنِّي أَخْشَى إِنْ تَرَكْتُ شَيْئًا مِنْ أَمْرِهِ أَنْ أَزِيغَ فَأَمَّا صَدَقَتُهُ بِالْمَدِينَةِ فَدَفَعَهَا عُمَرُ إِلَى عَلِيٍّ وَعَبَّاسٍ فَغَلَبَهُ عَلَيْهَا عَلِيٌّ وَأَمَّا خَيْبَرُ وَفَدَكُ فَأَمْسَكَهُمَا عُمَرُ وَقَالَ هُمَا صَدَقَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَتَا لِحُقُوقِهِ الَّتِي تَعْرُوهُ وَنَوَائِبِهِ وَأَمْرُهُمَا إِلَى مَنْ وَلِيَ الأَمْرَ قَالَ فَهُمَا عَلَى ذَلِكَ إِلَى الْيَوْمِ ‏.‏\hadithno{4582}\hadithtrans{It has been narrated by 'Urwa b Zubair on the authority of 'A'isha, wife of the Prophet (ﷺ), that Fatima, daughter of the Messenger of Allah (ﷺ), requested Abu Bakr, after the death of the Messenger of Allah (may peace he upon him), that he should set apart her share from what the Messenger of Allah (ﷺ) had left from the properties that God had bestowed upon him. Abu Bakr said to her:The Messenger of Allah (ﷺ) said:" We do not have any heirs; what we leave behind is Sadaqa (charity)." The narrator said: She (Fatima) lived six months after the death of the Messenger of Allah (ﷺ) and she used to demand from Abu Bakr her share from the legacy of the Messenger of Allah (ﷺ) from Khaibar, Fadak and his charitable endowments at Medina. Abu Bakr refused to give her this, and said: I am not going to give up doing anything which the Messenger of Allah (ﷺ) used to do. I am afraid that it I go against his instructions in any matter I shall deviate from the right course. So far as the charitable endowments at Medina were concerned, 'Umar handed them over to 'Ali and Abbas, but 'Ali got the better of him (and kept the property under his exclusive possession). And as far as Khaibar and Fadak were concerned 'Umar kept them with him, and said: These are the endowments of the Messenger of Allah (ﷺ) (to the Umma). Their income was spent on the discharge of the responsibilities that devolved upon him on the emergencies he had to meet. And their management was to be in the hands of one who managed the affairs (of the Islamic State). The narrator said: They have been managed as such up to this day}}
\hadithdefcmd{muslim}{4583}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَقْتَسِمُ وَرَثَتِي دِيِنَارًا مَا تَرَكْتُ بَعْدَ نَفَقَةِ نِسَائِي وَمَئُونَةِ عَامِلِي فَهُوَ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{4583}\hadithtrans{It has been narrated on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:My heirs cannot share even a dinar (from my legacy) ; what I leave behind after paving maintenance allowance to my wives and remuneration to my manager is (to go in) charity}}
\hadithdefcmd{muslim}{4584}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ ‏.‏\hadithno{4584}\hadithtrans{A similar hadith has been narrated on the authority of Abu Zinad through a different chain of transmitters}}
\hadithdefcmd{muslim}{4585}{وَحَدَّثَنِي ابْنُ أَبِي خَلَفٍ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ عَدِيٍّ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نُورَثُ مَا تَرَكْنَا صَدَقَةٌ ‏"‏ ‏.‏\hadithno{4585}\hadithtrans{It his been narrated on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:" We do not have any heirs; what we leave behind is a charitable endowment}}
\hadithdefcmd{muslim}{4586}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو كَامِلٍ فُضَيْلُ بْنُ حُسَيْنٍ كِلاَهُمَا عَنْ سُلَيْمٍ، قَالَ يَحْيَى أَخْبَرَنَا سُلَيْمُ بْنُ أَخْضَرَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، حَدَّثَنَا نَافِعٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَسَمَ فِي النَّفَلِ لِلْفَرَسِ سَهْمَيْنِ وَلِلرَّجُلِ سَهْمًا ‏.‏\hadithno{4586}\hadithtrans{It has been narrated on the authority of Ibn Umar that the Messenger of Allah (ﷺ) allowed two shares from the spoils to the horseman and one share to the footman}}
\hadithdefcmd{muslim}{4587}{حَدَّثَنَاهُ ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، بِهَذَا الإِسْنَادِ مِثْلَهُ وَلَمْ يَذْكُرْ فِي النَّفَلِ ‏.‏\hadithno{4587}\hadithtrans{The same tradition has been narrated on the authority of Ubaidullah by a different chain of transmitters who do not mention the words:" from the booty}}
\hadithdefcmd{muslim}{4588}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، حَدَّثَنِي سِمَاكٌ، الْحَنَفِيُّ قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ حَدَّثَنِي عُمَرُ بْنُ الْخَطَّابِ، قَالَ لَمَّا كَانَ يَوْمُ بَدْرٍ ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ - وَاللَّفْظُ لَهُ - حَدَّثَنَا عُمَرُ بْنُ يُونُسَ الْحَنَفِيُّ حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ حَدَّثَنِي أَبُو زُمَيْلٍ - هُوَ سِمَاكٌ الْحَنَفِيُّ - حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبَّاسٍ قَالَ حَدَّثَنِي عُمَرُ بْنُ الْخَطَّابِ قَالَ لَمَّا كَانَ يَوْمُ بَدْرٍ نَظَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْمُشْرِكِينَ وَهُمْ أَلْفٌ وَأَصْحَابُهُ ثَلاَثُمِائَةٍ وَتِسْعَةَ عَشَرَ رَجُلاً فَاسْتَقْبَلَ نَبِيُّ اللَّهِ صلى الله عليه وسلم الْقِبْلَةَ ثُمَّ مَدَّ يَدَيْهِ فَجَعَلَ يَهْتِفُ بِرَبِّهِ ‏"‏ اللَّهُمَّ أَنْجِزْ لِي مَا وَعَدْتَنِي اللَّهُمَّ آتِ مَا وَعَدْتَنِي اللَّهُمَّ إِنْ تَهْلِكْ هَذِهِ الْعِصَابَةُ مِنْ أَهْلِ الإِسْلاَمِ لاَ تُعْبَدْ فِي الأَرْضِ ‏"‏ ‏.‏ فَمَازَالَ يَهْتِفُ بِرَبِّهِ مَادًّا يَدَيْهِ مُسْتَقْبِلَ الْقِبْلَةِ حَتَّى سَقَطَ رِدَاؤُهُ عَنْ مَنْكِبَيْهِ فَأَتَاهُ أَبُو بَكْرٍ فَأَخَذَ رِدَاءَهُ فَأَلْقَاهُ عَلَى مَنْكِبَيْهِ ثُمَّ الْتَزَمَهُ مِنْ وَرَائِهِ ‏.‏ وَقَالَ يَا نَبِيَّ اللَّهِ كَذَاكَ مُنَاشَدَتُكَ رَبَّكَ فَإِنَّهُ سَيُنْجِزُ لَكَ مَا وَعَدَكَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ إِذْ تَسْتَغِيثُونَ رَبَّكُمْ فَاسْتَجَابَ لَكُمْ أَنِّي مُمِدُّكُمْ بِأَلْفٍ مِنَ الْمَلاَئِكَةِ مُرْدِفِينَ‏\}‏ فَأَمَدَّهُ اللَّهُ بِالْمَلاَئِكَةِ ‏.‏ قَالَ أَبُو زُمَيْلٍ فَحَدَّثَنِي ابْنُ عَبَّاسٍ قَالَ بَيْنَمَا رَجُلٌ مِنَ الْمُسْلِمِينَ يَوْمَئِذٍ يَشْتَدُّ فِي أَثَرِ رَجُلٍ مِنَ الْمُشْرِكِينَ أَمَامَهُ إِذْ سَمِعَ ضَرْبَةً بِالسَّوْطِ فَوْقَهُ وَصَوْتَ الْفَارِسِ يَقُولُ أَقْدِمْ حَيْزُومُ ‏.‏ فَنَظَرَ إِلَى الْمُشْرِكِ أَمَامَهُ فَخَرَّ مُسْتَلْقِيًا فَنَظَرَ إِلَيْهِ فَإِذَا هُوَ قَدْ خُطِمَ أَنْفُهُ وَشُقَّ وَجْهُهُ كَضَرْبَةِ السَّوْطِ فَاخْضَرَّ ذَلِكَ أَجْمَعُ ‏.‏ فَجَاءَ الأَنْصَارِيُّ فَحَدَّثَ بِذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ صَدَقْتَ ذَلِكَ مِنْ مَدَدِ السَّمَاءِ الثَّالِثَةِ ‏"‏ ‏.‏ فَقَتَلُوا يَوْمَئِذٍ سَبْعِينَ وَأَسَرُوا سَبْعِينَ ‏.‏ قَالَ أَبُو زُمَيْلٍ قَالَ ابْنُ عَبَّاسٍ فَلَمَّا أَسَرُوا الأُسَارَى قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَبِي بَكْرٍ وَعُمَرَ ‏"‏ مَا تَرَوْنَ فِي هَؤُلاَءِ الأُسَارَى ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ يَا نَبِيَّ اللَّهِ هُمْ بَنُو الْعَمِّ وَالْعَشِيرَةِ أَرَى أَنْ تَأْخُذَ مِنْهُمْ فِدْيَةً فَتَكُونُ لَنَا قُوَّةً عَلَى الْكُفَّارِ فَعَسَى اللَّهُ أَنْ يَهْدِيَهُمْ لِلإِسْلاَمِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا تَرَى يَا ابْنَ الْخَطَّابِ ‏"‏ ‏.‏ قُلْتُ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ مَا أَرَى الَّذِي رَأَى أَبُو بَكْرٍ وَلَكِنِّي أَرَى أَنْ تُمَكِّنَّا فَنَضْرِبَ أَعْنَاقَهُمْ فَتُمَكِّنَ عَلِيًّا مِنْ عَقِيلٍ فَيَضْرِبَ عُنُقَهُ وَتُمَكِّنِّي مِنْ فُلاَنٍ - نَسِيبًا لِعُمَرَ - فَأَضْرِبَ عُنُقَهُ فَإِنَّ هَؤُلاَءِ أَئِمَّةُ الْكُفْرِ وَصَنَادِيدُهَا فَهَوِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَا قَالَ أَبُو بَكْرٍ وَلَمْ يَهْوَ مَا قُلْتُ فَلَمَّا كَانَ مِنَ الْغَدِ جِئْتُ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو بَكْرٍ قَاعِدَيْنِ يَبْكِيَانِ قُلْتُ يَا رَسُولَ اللَّهِ أَخْبِرْنِي مِنْ أَىِّ شَىْءٍ تَبْكِي أَنْتَ وَصَاحِبُكَ فَإِنْ وَجَدْتُ بُكَاءً بَكَيْتُ وَإِنْ لَمْ أَجِدْ بُكَاءً تَبَاكَيْتُ لِبُكَائِكُمَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَبْكِي لِلَّذِي عَرَضَ عَلَىَّ أَصْحَابُكَ مِنْ أَخْذِهِمُ الْفِدَاءَ لَقَدْ عُرِضَ عَلَىَّ عَذَابُهُمْ أَدْنَى مِنْ هَذِهِ الشَّجَرَةِ ‏"‏ ‏.‏ شَجَرَةٍ قَرِيبَةٍ مِنْ نَبِيِّ اللَّهِ صلى الله عليه وسلم ‏.‏ وَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ مَا كَانَ لِنَبِيٍّ أَنْ يَكُونَ لَهُ أَسْرَى حَتَّى يُثْخِنَ فِي الأَرْضِ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ فَكُلُوا مِمَّا غَنِمْتُمْ حَلاَلاً طَيِّبًا‏\}‏ فَأَحَلَّ اللَّهُ الْغَنِيمَةَ لَهُمْ ‏.‏\hadithno{4588}\hadithtrans{It has been narrated on the authority of `Umar b. al-Khattab who said:When it was the day on which the Battle of Badr was fought, the Messenger of Allah (ﷺ) cast a glance at the infidels, and they were one thousand while his own Companions were three hundred and nineteen. The Prophet (ﷺ) turned (his face) towards the Qibla. Then he stretched his hands and began his supplication to his Lord: "O Allah, accomplish for me what Thou hast promised to me. O Allah, bring about what Thou hast promised to me. O Allah, if this small band of Muslims is destroyed. Thou will not be worshipped on this earth." He continued his supplication to his Lord, stretching his hands, facing the Qibla, until his mantle slipped down from his shoulders. So Abu Bakr came to him, picked up his mantle and put it on his shoulders. Then he embraced him from behind and said: Prophet of Allah, this prayer of yours to your Lord will suffice you, and He will fulfill for you what He has promised you. So Allah, the Glorious and Exalted, revealed (the Qur'anic verse): "When ye appealed to your Lord for help, He responded to your call (saying): I will help you with one thousand angels coming in succession." So Allah helped him with angels. Abu Zumail said that the hadith was narrated to him by Ibn `Abbas who said: While on that day a Muslim was chasing a disbeliever who was going ahead of him, he heard over him the swishing of the whip and the voice of the rider saying: Go ahead, Haizum! He glanced at the polytheist who had (now) fallen down on his back. When he looked at him (carefully he found that) there was a scar on his nose and his face was torn as if it had been lashed with a whip, and had turned green with its poison. An Ansari came to the Messenger of Allah (ﷺ) and related this (event) to him. He said: You have told the truth. This was the help from the third heaven. The Muslims that day (i.e. the day of the Battle of Badr) killed seventy persons and captured seventy. The Messenger of Allah (ﷺ) said to Abu Bakr and `Umar (Allah be pleased with them): What is your opinion about these captives? Abu Bakr said: They are our kith and kin. I think you should release them after getting from them a ransom. This will be a source of strength to us against the infidels. It is quite possible that Allah may guide them to Islam. Then the Messenger of Allah (ﷺ) said: What is your opinion, Ibn Khattab? He said: Messenger of Allah, I do not hold the same opinion as Abu Bakr. I am of the opinion that you should hand them over to us so that we may cut off their heads. Hand over `Aqil to `Ali that he may cut off his head, and hand over such and such relative to me that I may cut off his head. They are leaders of the disbelievers and veterans among them. The Messenger of Allah (ﷺ) approved the opinion of Abu Bakr and did not approve what I said. The next day when I came to the Messenger of Allah (ﷺ), I found that both he and Abu Bakr were sitting shedding tears. I said: Messenger of Allah, why are you and your Companion shedding tears? Tell me the reason. For I will weep, or I will at least pretend to weep in sympathy with you. The Messenger of Allah (ﷺ) said: I weep for what has happened to your companions for taking ransom (from the prisoners). I was shown the torture to which they were subjected. It was brought to me as close as this tree. (He pointed to a tree close to him.) Then God revealed the verse: "It is not befitting for a prophet that he should take prisoners until the force of the disbelievers has been crushed..." to the end of the verse: "so eat ye the spoils of war, (it is) lawful and pure. So Allah made booty lawful for them}}
\hadithdefcmd{muslim}{4589}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْلاً قِبَلَ نَجْدٍ فَجَاءَتْ بِرَجُلٍ مِنْ بَنِي حَنِيفَةَ يُقَالُ لَهُ ثُمَامَةُ بْنُ أُثَالٍ سَيِّدُ أَهْلِ الْيَمَامَةِ ‏.‏ فَرَبَطُوهُ بِسَارِيَةٍ مِنْ سَوَارِي الْمَسْجِدِ فَخَرَجَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَاذَا عِنْدَكَ يَا ثُمَامَةُ ‏"‏ ‏.‏ فَقَالَ عِنْدِي يَا مُحَمَّدُ خَيْرٌ إِنْ تَقْتُلْ تَقْتُلْ ذَا دَمٍ وَإِنْ تُنْعِمْ تُنْعِمْ عَلَى شَاكِرٍ وَإِنْ كُنْتَ تُرِيدُ الْمَالَ فَسَلْ تُعْطَ مِنْهُ مَا شِئْتَ ‏.‏ فَتَرَكَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى كَانَ بَعْدَ الْغَدِ فَقَالَ ‏"‏ مَا عِنْدَكَ يَا ثُمَامَةُ ‏"‏ ‏.‏ قَالَ مَا قُلْتُ لَكَ إِنْ تُنْعِمْ تُنْعِمْ عَلَى شَاكِرٍ وَإِنْ تَقْتُلْ تَقْتُلْ ذَا دَمٍ وَإِنْ كُنْتَ تُرِيدُ الْمَالَ فَسَلْ تُعْطَ مِنْهُ مَا شِئْتَ ‏.‏ فَتَرَكَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى كَانَ مِنَ الْغَدِ فَقَالَ ‏"‏ مَاذَا عِنْدَكَ يَا ثُمَامَةُ ‏"‏ ‏.‏ فَقَالَ عِنْدِي مَا قُلْتُ لَكَ إِنْ تُنْعِمْ تُنْعِمْ عَلَى شَاكِرٍ وَإِنْ تَقْتُلْ تَقْتُلْ ذَا دَمٍ وَإِنْ كُنْتَ تُرِيدُ الْمَالَ فَسَلْ تُعْطَ مِنْهُ مَا شِئْتَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَطْلِقُوا ثُمَامَةَ ‏"‏ ‏.‏ فَانْطَلَقَ إِلَى نَخْلٍ قَرِيبٍ مِنَ الْمَسْجِدِ فَاغْتَسَلَ ثُمَّ دَخَلَ الْمَسْجِدَ فَقَالَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ ‏.‏ يَا مُحَمَّدُ وَاللَّهِ مَا كَانَ عَلَى الأَرْضِ وَجْهٌ أَبْغَضَ إِلَىَّ مِنْ وَجْهِكَ فَقَدْ أَصْبَحَ وَجْهُكَ أَحَبَّ الْوُجُوهِ كُلِّهَا إِلَىَّ وَاللَّهِ مَا كَانَ مِنْ دِينٍ أَبْغَضَ إِلَىَّ مِنْ دِينِكَ فَأَصْبَحَ دِينُكَ أَحَبَّ الدِّينِ كُلِّهِ إِلَىَّ وَاللَّهِ مَا كَانَ مِنْ بَلَدٍ أَبْغَضَ إِلَىَّ مِنْ بَلَدِكَ فَأَصْبَحَ بَلَدُكَ أَحَبَّ الْبِلاَدِ كُلِّهَا إِلَىَّ وَإِنَّ خَيْلَكَ أَخَذَتْنِي وَأَنَا أُرِيدُ الْعُمْرَةَ فَمَاذَا تَرَى فَبَشَّرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَمَرَهُ أَنْ يَعْتَمِرَ فَلَمَّا قَدِمَ مَكَّةَ قَالَ لَهُ قَائِلٌ أَصَبَوْتَ فَقَالَ لاَ وَلَكِنِّي أَسْلَمْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَلاَ وَاللَّهِ لاَ يَأْتِيكُمْ مِنَ الْيَمَامَةِ حَبَّةُ حِنْطَةٍ حَتَّى يَأْذَنَ فِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4589}\hadithtrans{It has been narrated on the authority of Abu Huraira who said:The Messenger of Allah (ﷺ) sent some horsemen to Najd. They captured a man. He was from the tribe of Banu Hanifa and was called Thumama b. Uthal. He was the chief of the people of Yamama. People bound him with one of the pillars of the mosque. The Messenger of Allah (ﷺ) came out to (see) him. He said: O Thumama, what do you think? He replied: Muhammad, I have good opinion of you. If you kill me, you will kill a person who has spilt blood. If you do me a favour, you will do a favour to a grateful person. If you want wealth, ask and you will get what you will demand. The Messenger of Allah (may peace be pon him) lefthim (in this condition) for two days, (and came to him again) and said: What do you think, O Thumama? He replied: What I have already told you. If you do a favour, you will do a favour to a grateful person. If you kill me, you will kill a person who has spilt blood. If you want wealth, ask and you will get what you will demand. The Messenger of Allah (ﷺ) left him until the next day when he (came to him again) and said: What do you think, O Thumama? He replied: What I have already told you. If you do me a favour, you will do a favour to a grateful person. If you kill me, you will kill a person who has spilt blood. If you want wealth ask and you will get what you will demand. The Messenger of Allah (ﷺ) said: Set Thumama free. He went to a palm-grove near the mosque and took a bath. Then he entered the mosque and said: I bear testimony (to the truth) that there is no god but Allah and I testify that Muhammad is His bondman and His messenger. O Muhammad, by Allah, there was no face on the earth more hateful to me than your face, but (now) your face has become to me the dearest of all faces. By Allah, there was no religion more hateful to me than your religion, but (now) your religion has become the dearest of all religions to me. By Allah, there was no city more hateful to me than your city, but (now) your city has become the dearest of all cities to me. Your horsemen captured me when I intended going for Umra. Now what is your opinion (in the matter)? The Messenger of Allah (ﷺ) announced good tidings to him and told him to go on 'Umra. When he reached Mecca, somebody said to him: Have you changed your religion? He said: No! I have rather embraced Islam with the Messenger of Allah (ﷺ). By Allah, you will not get a single grain of wheat from Yamama until it is permitted by the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{4590}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنِي عَبْدُ الْحَمِيدِ بْنُ جَعْفَرٍ، حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ الْمَقْبُرِيُّ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْلاً لَهُ نَحْوَ أَرْضِ نَجْدٍ فَجَاءَتْ بِرَجُلٍ يُقَالُ لَهُ ثُمَامَةُ بْنُ أُثَالٍ الْحَنَفِيُّ سَيِّدُ أَهْلِ الْيَمَامَةِ ‏.‏ وَسَاقَ الْحَدِيثَ بِمِثْلِ حَدِيثِ اللَّيْثِ إِلاَّ أَنَّهُ قَالَ إِنْ تَقْتُلْنِي تَقْتُلْ ذَا دَمٍ ‏.‏\hadithno{4590}\hadithtrans{The same tradition has been narrated by a different chain of transmitters with a slight difference in the wording}}
\hadithdefcmd{muslim}{4591}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي، هُرَيْرَةَ أَنَّهُ قَالَ بَيْنَا نَحْنُ فِي الْمَسْجِدِ إِذْ خَرَجَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ انْطَلِقُوا إِلَى يَهُودَ ‏"‏ ‏.‏ فَخَرَجْنَا مَعَهُ حَتَّى جِئْنَاهُمْ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَنَادَاهُمْ فَقَالَ ‏"‏ يَا مَعْشَرَ يَهُودَ أَسْلِمُوا تَسْلَمُوا ‏"‏ ‏.‏ فَقَالُوا قَدْ بَلَّغْتَ يَا أَبَا الْقَاسِمِ ‏.‏ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ذَلِكَ أُرِيدُ أَسْلِمُوا تَسْلَمُوا ‏"‏ ‏.‏ فَقَالُوا قَدْ بَلَّغْتَ يَا أَبَا الْقَاسِمِ ‏.‏ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ذَلِكَ أُرِيدُ ‏"‏ ‏.‏ فَقَالَ لَهُمُ الثَّالِثَةَ فَقَالَ ‏"‏ اعْلَمُوا أَنَّمَا الأَرْضُ لِلَّهِ وَرَسُولِهِ وَأَنِّي أُرِيدُ أَنْ أُجْلِيَكُمْ مِنْ هَذِهِ الأَرْضِ فَمَنْ وَجَدَ مِنْكُمْ بِمَالِهِ شَيْئًا فَلْيَبِعْهُ وَإِلاَّ فَاعْلَمُوا أَنَّ الأَرْضَ لِلَّهِ وَرَسُولِهِ ‏"‏ ‏.‏\hadithno{4591}\hadithtrans{It has been narrated on the authority of Abu Huraira who said:We were (sitting) in the mosque when the Messenger of Allah (ﷺ) came to us and said: (Let us) go to the Jews. We went out with him until we came to them. The Messenger of Allah (ﷺ) stood up and called out to them (saying): O ye assembly of Jews, accept Islam (and) you will be safe. They said: Abu'l-Qasim, you have communicated (God's Message to us). The Messenger of Allah (ﷺ) said: I want this (i. e. you should admit that God's Message has been communicated to you), accept Islam and you would be safe. They said: Abu'l-Qisim, you have communicated (Allah's Message). The Messenger of Allah (ﷺ) said: I want this... - He said to them (the same words) the third time (and on getting the same reply) he added: You should know that the earth belongs to Allah and His Apostle, and I wish that I should expel you from this land Those of you who have any property with them should sell it, otherwise they should know that the earth belongs to Allah and His Apostle (and they may have to go away leaving everything behind)}}
\hadithdefcmd{muslim}{4592}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالَ ابْنُ رَافِعٍ حَدَّثَنَا وَقَالَ، إِسْحَاقُ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّالله عليه وسلم فَأَجْلَى رَسُولُ اللَّهِ صلى الله عليه وسلم بَنِي النَّضِيرِ وَأَقَرَّ قُرَيْظَةَ وَمَنَّ عَلَيْهِمْ حَتَّى حَارَبَتْ قُرَيْظَةُ بَعْدَ ذَلِكَ فَقَتَلَ رِجَالَهُمْ وَقَسَمَ نِسَاءَهُمْ وَأَوْلاَدَهُمْ وَأَمْوَالَهُمْ بَيْنَ الْمُسْلِمِينَ إِلاَّ أَنَّ بَعْضَهُمْ لَحِقُوا بِرَسُولِ اللَّهِ صلى الله عليه وسلم فَآمَنَهُمْ وَأَسْلَمُوا وَأَجْلَى رَسُولُ اللَّهِ صلى الله عليه وسلم يَهُودَ الْمَدِينَةِ كُلَّهُمْ بَنِي قَيْنُقَاعَ - وَهُمْ قَوْمُ عَبْدِ اللَّهِ بْنِ سَلاَمٍ - وَيَهُودَ بَنِي حَارِثَةَ وَكُلَّ يَهُودِيٍّ كَانَ بِالْمَدِينَةِ ‏.‏\hadithno{4592}\hadithtrans{It has been narrated on the authority of Ibn Umar that the Jews of Banu Nadir and Banu Quraiza fought against the Messenger of Allah (ﷺ) who expelled Banu Nadir, and allowed Quraiza to stay on, and granted favour to them until they too fought against him Then he killed their men, and distributed their women, children and properties among the Muslims, except that some of them had joined the Messenger of Allah (ﷺ) who granted them security. They embraced Islam. The Messenger of Allah (ﷺ) turned out all the Jews of Medina. Banu Qainuqa' (the tribe of 'Abdullah b. Salim) and the Jews of Banu Haritha and every other Jew who was in Medina}}
\hadithdefcmd{muslim}{4593}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي حَفْصُ بْنُ مَيْسَرَةَ، عَنْ مُوسَى، بِهَذَا الإِسْنَادِ هَذَا الْحَدِيثَ وَحَدِيثُ ابْنُ جُرَيْجٍ أَكْثَرُ وَأَتَمُّ ‏.‏\hadithno{4593}\hadithtrans{A similar hadith has been transmitted by a different chain of narrators, but the hadith narrated by Ibn Juraij is more detailed and complete}}
\hadithdefcmd{muslim}{4594}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، عَنِ ابْنِ جُرَيْجٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ أَخْبَرَنِي عُمَرُ بْنُ الْخَطَّابِ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لأُخْرِجَنَّ الْيَهُودَ وَالنَّصَارَى مِنْ جَزِيرَةِ الْعَرَبِ حَتَّى لاَ أَدَعَ إِلاَّ مُسْلِمًا ‏"‏ ‏.‏\hadithno{4594}\hadithtrans{It has been narrated by 'Umar b. al-Khattib that he heard the Messenger of Allah (ﷺ) say:I will expel the Jews and Christians from the Arabian Peninsula and will not leave any but Muslim}}
\hadithdefcmd{muslim}{4595}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، أَخْبَرَنَا سُفْيَانُ الثَّوْرِيُّ، ح وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، - وَهُوَ ابْنُ عُبَيْدِ اللَّهِ - كِلاَهُمَا عَنْ أَبِي الزُّبَيْرِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{4595}\hadithtrans{This hadith has been narrated on the authority of Zubair with the same chain of transmitters}}
\hadithdefcmd{muslim}{4596}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَأَلْفَاظُهُمْ مُتَقَارِبَةٌ - قَالَ أَبُو بَكْرٍ حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، وَقَالَ الآخَرَانِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، - عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ بْنَ سَهْلِ بْنِ حُنَيْفٍ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ، الْخُدْرِيَّ قَالَ نَزَلَ أَهْلُ قُرَيْظَةَ عَلَى حُكْمِ سَعْدِ بْنِ مُعَاذٍ فَأَرْسَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى سَعْدٍ فَأَتَاهُ عَلَى حِمَارٍ فَلَمَّا دَنَا قَرِيبًا مِنَ الْمَسْجِدِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلأَنْصَارِ ‏"‏ قُومُوا إِلَى سَيِّدِكُمْ - أَوْ خَيْرِكُمْ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ إِنَّ هَؤُلاَءِ نَزَلُوا عَلَى حُكْمِكَ ‏"‏ ‏.‏ قَالَ تَقْتُلُ مُقَاتِلَتَهُمْ وَتَسْبِي ذُرِّيَّتَهُمْ ‏.‏ قَالَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ قَضَيْتَ بِحُكْمِ اللَّهِ - وَرُبَّمَا قَالَ - قَضَيْتَ بِحُكْمِ الْمَلِكِ ‏"‏ ‏.‏ وَلَمْ يَذْكُرِ ابْنُ الْمُثَنَّى وَرُبَّمَا قَالَ ‏"‏ قَضَيْتَ بِحُكْمِ الْمَلِكِ ‏"‏ ‏.‏\hadithno{4596}\hadithtrans{It has been narrated on the authority of Abu Sa'id al-Khudri who said:The people of Quraiza surrendered accepting the decision of Sa'd b. Mu'adh about them. Accordingly, the Messenger of Allah (ﷺ) sent for Sa'd who came to him riding a donkey. When he approached the mosque, the Messenger of Allah (ﷺ) said to the Ansar: Stand up to receive your chieftain. Then he said (to Sa'd): These people have surrendered accepting your decision. He (Sa'd) said: You will kill their fighters and capture their women and children. (Hearing this), the Prophet (ﷺ) said: You have adjudged by the command of God. The narrator is reported to have said: Perhaps he said: You have adjudged by the decision of a king. Ibn Muthanna (in his version of the tradition) has not mentioned the alternative words}}
\hadithdefcmd{muslim}{4597}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ وَقَالَ فِي حَدِيثِهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَقَدْ حَكَمْتَ فِيهِمْ بِحُكْمِ اللَّهِ ‏"‏ ‏.‏ وَقَالَ مَرَّةً ‏"‏ لَقَدْ حَكَمْتَ بِحُكْمِ الْمَلِكِ ‏"‏ ‏.‏\hadithno{4597}\hadithtrans{Through the same chain of transmitters Shu'ba has narrated the same tradition in which he says that the Messenger of Allah (ﷺ) said (to Sa'd):You have adjudged according to the command of God. And once he said: you have adjudged by the decision of a king}}
\hadithdefcmd{muslim}{4598}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ، كِلاَهُمَا عَنِ ابْنِ نُمَيْرٍ، قَالَ ابْنُ الْعَلاَءِ حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ أُصِيبَ سَعْدٌ يَوْمَ الْخَنْدَقِ رَمَاهُ رَجُلٌ مِنْ قُرَيْشٍ يُقَالُ لَهُ ابْنُ الْعَرِقَةِ ‏.‏ رَمَاهُ فِي الأَكْحَلِ فَضَرَبَ عَلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْمَةً فِي الْمَسْجِدِ يَعُودُهُ مِنْ قَرِيبٍ فَلَمَّا رَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الْخَنْدَقِ وَضَعَ السِّلاَحَ فَاغْتَسَلَ فَأَتَاهُ جِبْرِيلُ وَهُوَ يَنْفُضُ رَأْسَهُ مِنَ الْغُبَارِ فَقَالَ وَضَعْتَ السِّلاَحَ وَاللَّهِ مَا وَضَعْنَاهُ اخْرُجْ إِلَيْهِمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَأَيْنَ ‏"‏ ‏.‏ فَأَشَارَ إِلَى بَنِي قُرَيْظَةَ فَقَاتَلَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَنَزَلُوا عَلَى حُكْمِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم الْحُكْمَ فِيهِمْ إِلَى سَعْدٍ قَالَ فَإِنِّي أَحْكُمُ فِيهِمْ أَنْ تُقْتَلَ الْمُقَاتِلَةُ وَأَنْ تُسْبَى الذُّرِّيَّةُ وَالنِّسَاءُ وَتُقْسَمَ أَمْوَالُهُمْ ‏.‏\hadithno{4598}\hadithtrans{It has been narrated on the authority of A'isha who said:Sa'd was wounded on the day of the Battle of the Ditch. A man from the Quraish called Ibn al-Ariqah shot at him an arrow which pierced the artery in the middle of his forearm. The Messenger of Allah (ﷺ) pitched a tent for him in the mosque and would inquire after him being in close proximity. When he returned from the Ditch and laid down his arms and took a bath, the angel Gabriel appeared to him and he was removing dust from his hair (as if he had just returned from the battle). The latter said: You have laid down arms. By God, we haven't (yet) laid them down. So march against them. The Messenger of Allah (ﷺ) asked: Where? He pointed to Banu Quraiza. So the Messenger of Allah (may peace he upon him) fought against them. They surrendered at the command of the Messenger of Allah (ﷺ), but he referred the decision about them to Sa'd who said: I decide about them that those of them who can fight be killed, their women and children taken prisoners and their properties distributed (among the Muslims)}}
\hadithdefcmd{muslim}{4599}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا هِشَامٌ، قَالَ قَالَ أَبِي فَأُخْبِرْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَقَدْ حَكَمْتَ فِيهِمْ بِحُكْمِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4599}\hadithtrans{It has been narrated on the authority of Hisham (who learnt it from his father) that the Messenger of Allah (ﷺ) said (to Sa'd):You have adjudged their case with the judgment of God. the Exalted and Glorified}}
\hadithdefcmd{muslim}{4600}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ نُمَيْرٍ، عَنْ هِشَامٍ، أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ، أَنَّ سَعْدًا، قَالَ وَتَحَجَّرَ كَلْمُهُ لِلْبُرْءِ فَقَالَ اللَّهُمَّ إِنَّكَ تَعْلَمُ أَنْ لَيْسَ أَحَدٌ أَحَبَّ إِلَىَّ أَنْ أُجَاهِدَ فِيكَ مِنْ قَوْمٍ كَذَّبُوا رَسُولَكَ صلى الله عليه وسلم وَأَخْرَجُوهُ اللَّهُمَّ فَإِنْ كَانَ بَقِيَ مِنْ حَرْبِ قُرَيْشٍ شَىْءٌ فَأَبْقِنِي أُجَاهِدْهُمْ فِيكَ اللَّهُمَّ فَإِنِّي أَظُنُّ أَنَّكَ قَدْ وَضَعْتَ الْحَرْبَ بَيْنَنَا وَبَيْنَهُمْ فَإِنْ كُنْتَ وَضَعْتَ الْحَرْبَ بَيْنَنَا وَبَيْنَهُمْ فَافْجُرْهَا وَاجْعَلْ مَوْتِي فِيهَا ‏.‏ فَانْفَجَرَتْ مِنْ لَبَّتِهِ فَلَمْ يَرُعْهُمْ - وَفِي الْمَسْجِدِ مَعَهُ خَيْمَةٌ مِنْ بَنِي غِفَارٍ - إِلاَّ وَالدَّمُ يَسِيلُ إِلَيْهِمْ فَقَالُوا يَا أَهْلَ الْخَيْمَةِ مَا هَذَا الَّذِي يَأْتِينَا مِنْ قِبَلِكُمْ فَإِذَا سَعْدٌ جُرْحُهُ يَغِذُّ دَمًا فَمَاتَ مِنْهَا ‏.‏\hadithno{4600}\hadithtrans{It has been narrated on the authority of 'A'isha that Sa'd's wound became dry and was going to heal when he prayed:O God, surely Thou knowest that nothing is dearer to me than that I should fight for Thy cause against the people who disbeliever Your Messenger (ﷺ) and turned him out (from his native place). If anything yet remains to be decided from the war against the Quraish, spare my life so that I may fight against them in Thy cause. O Lord, I think Thou hast ended the war between us and them. If Thou hast done so, open my wound (so that it may discharge) and cause my death thereby. So the wound begin to bleed from the front part of his neck. The people were not scared except when the blood flowed towards them, and in the mosque along with Sa'd's tent was the tent of Banu Ghifar. They said: O people of the tent, what is it that is coming to us from you? Lo! it was Sa'd's wound that was bleeding and he died thereof}}
\hadithdefcmd{muslim}{4601}{وَحَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ سُلَيْمَانَ الْكُوفِيُّ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ نَحْوَهُ غَيْرَ أَنَّهُ قَالَ فَانْفَجَرَ مِنْ لَيْلَتِهِ فَمَازَالَ يَسِيلُ حَتَّى مَاتَ وَزَادَ فِي الْحَدِيثِ قَالَ فَذَاكَ حِينَ يَقُولُ الشَّاعِرُ أَلاَ يَا سَعْدُ سَعْدَ بَنِي مُعَاذٍ فَمَا فَعَلَتْ قُرَيْظَةُ وَالنَّضِيرُ لَعَمْرُكَ إِنَّ سَعْدَ بَنِي مُعَاذٍ غَدَاةَ تَحَمَّلُوا لَهُوَ الصَّبُورُ تَرَكْتُمْ قِدْرَكُمْ لاَ شَىْءَ فِيهَا وَقِدْرُ الْقَوْمِ حَامِيَةٌ تَفُورُ وَقَدْ قَالَ الْكَرِيمُ أَبُو حُبَابٍ أَقِيمُوا قَيْنُقَاعُ وَلاَ تَسِيرُوا وَقَدْ كَانُوا بِبَلْدَتِهِمْ ثِقَالاً كَمَا ثَقُلَتْ بِمَيْطَانَ الصُّخُورُ\hadithno{4601}\hadithtrans{This tradition has been narrated by Hishim through the same chain of transmitters with a little difference in the wording. He said:(His wound) began to bleed that very night and it continued to bleed until he died. He has made the addition that it was then that (a non-believing) poet said: Hark, O Sa'd, Sa'd of Banu Mu'adh, What have the Quraiaa and Nadir done? By thy life! Sa'd b. Mu'adh>br> Was steadfast on the morn they departed. You have left your cooking-pot empty, While the cooking-pot of the people is hot and boiling. Abu Hubab the nobleman has said, O Qainuqa', do not depart. They were weighty in their country just aa rocks are weighty in Maitan}}
\hadithdefcmd{muslim}{4602}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ الضُّبَعِيُّ، حَدَّثَنَا جُوَيْرِيَةُ بْنُ أَسْمَاءَ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ، قَالَ نَادَى فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ انْصَرَفَ عَنِ الأَحْزَابِ ‏ "‏ أَنْ لاَ يُصَلِّيَنَّ أَحَدٌ الظُّهْرَ إِلاَّ فِي بَنِي قُرَيْظَةَ ‏"‏ ‏.‏ فَتَخَوَّفَ نَاسٌ فَوْتَ الْوَقْتِ فَصَلُّوا دُونَ بَنِي قُرَيْظَةَ ‏.‏ وَقَالَ آخَرُونَ لاَ نُصَلِّي إِلاَّ حَيْثُ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَإِنْ فَاتَنَا الْوَقْتُ قَالَ فَمَا عَنَّفَ وَاحِدًا مِنَ الْفَرِيقَيْنِ ‏.‏\hadithno{4602}\hadithtrans{It has been narrated on the authority of Abdullah who said:On the day he returned from the Battle of Ahzab, the Messenger of Allah (ﷺ) made for us an announcement that nobody would say his Zuhr prayer but in the quarters of Banu Quraiza (Some) people, being afraid that the time for prayer would expire, said their prayers before reaching the street of Banu Quraiza. The others said: We will not say our prayer except where the Messenger of Allah (ﷺ) has ordered us to say it even if the time expires. When he learned of the difference in the view of the two groups of the people, the Messenger of Allah (may peace be tipon him) did not blame anyone from the two groups}}
\hadithdefcmd{muslim}{4603}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ، شِهَابٍ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا قَدِمَ الْمُهَاجِرُونَ مِنْ مَكَّةَ الْمَدِينَةَ قَدِمُوا وَلَيْسَ بِأَيْدِيهِمْ شَىْءٌ وَكَانَ الأَنْصَارُ أَهْلَ الأَرْضِ وَالْعَقَارِ فَقَاسَمَهُمُ الأَنْصَارُ عَلَى أَنْ أَعْطَوْهُمْ أَنْصَافَ ثِمَارِ أَمْوَالِهِمْ كُلَّ عَامٍ وَيَكْفُونَهُمُ الْعَمَلَ وَالْمَئُونَةَ وَكَانَتْ أُمُّ أَنَسِ بْنِ مَالِكٍ وَهْىَ تُدْعَى أُمَّ سُلَيْمٍ - وَكَانَتْ أُمَّ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ كَانَ أَخًا لأَنَسٍ لأُمِّهِ - وَكَانَتْ أَعْطَتْ أُمُّ أَنَسٍ رَسُولَ اللَّهِ صلى الله عليه وسلم عِذَاقًا لَهَا فَأَعْطَاهَا رَسُولُ اللَّهِ صلى الله عليه وسلم أُمَّ أَيْمَنَ مَوْلاَتَهُ أُمَّ أُسَامَةَ بْنِ زَيْدٍ ‏.‏ قَالَ ابْنُ شِهَابٍ فَأَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا فَرَغَ مِنْ قِتَالِ أَهْلِ خَيْبَرَ وَانْصَرَفَ إِلَى الْمَدِينَةِ رَدَّ الْمُهَاجِرُونَ إِلَى الأَنْصَارِ مَنَائِحَهُمُ الَّتِي كَانُوا مَنَحُوهُمْ مِنْ ثِمَارِهِمْ - قَالَ - فَرَدَّ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى أُمِّي عِذَاقَهَا وَأَعْطَى رَسُولُ اللَّهِ صلى الله عليه وسلم أُمَّ أَيْمَنَ مَكَانَهُنَّ مِنْ حَائِطِهِ ‏.‏ قَالَ ابْنُ شِهَابٍ وَكَانَ مِنْ شَأْنِ أُمِّ أَيْمَنَ أُمِّ أُسَامَةَ بْنِ زَيْدٍ أَنَّهَا كَانَتْ وَصِيفَةً لِعَبْدِ اللَّهِ بْنِ عَبْدِ الْمُطَّلِبِ وَكَانَتْ مِنَ الْحَبَشَةِ فَلَمَّا وَلَدَتْ آمِنَةُ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدَ مَا تُوُفِّيَ أَبُوهُ فَكَانَتْ أُمُّ أَيْمَنَ تَحْضُنُهُ حَتَّى كَبِرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَعْتَقَهَا ثُمَّ أَنْكَحَهَا زَيْدَ بْنَ حَارِثَةَ ثُمَّ تُوُفِّيَتْ بَعْدَ مَا تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِخَمْسَةِ أَشْهُرٍ ‏.‏\hadithno{4603}\hadithtrans{It has been narrated on the authority of Anas b. Malik who said:When the Muhajirs migrated from Mecca to Medina; they came (in a state that) they had not anything (i. e. money) in theirhands, while the Ansar possessed lands and date palms. They divided their properties with the Muhajirs. The Ansar divided and gave them on the condition that they would give half the fruit from the orchards every year, and the Muhajirs would recompense them by working with them and putting in labour. The mother of Anas b. Malik was called Umm Sulaim and she was also the mother of 'Abdullah b. Talha who was a brother of Anas from his mother's side. The mother of Anas had given the Messenger of Allah (ﷺ) her date-palms. He bestowed them upon Umm Aiman, the slave-girl who had been freed by him and was the mother of Usama b. Zaid. When the Messenger of Allah (ﷺ) had finished the war with the people of Khaibar and returned to Medina, the Muhajirs returned to the Ansar all the gifts which they had given them out of the fruits. (Anas b. Malik said: ) The Messenger of. Allah (ﷺ) returned to my mother her date-palms and gave to Umm Aiman instead of them date-palms from his orchard. Ibn Shihab says that Umm Aiman was the mother of Usama b. Zaid who was the slave-girl of 'Abdullah b. 'Abd-ul-Muttalib and hailed from Abyssinia. When Amina gave birth to the Messenger of Allah (ﷺ) after the death of his father, Umm Aiman used to nurse him until he grew up. He (later on) freed her and married her to Zaid b. Haritha. She died five months after the death of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{4604}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَحَامِدُ بْنُ عُمَرَ الْبَكْرَاوِيُّ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، الْقَيْسِيُّ كُلُّهُمْ عَنِ الْمُعْتَمِرِ، - وَاللَّفْظُ لاِبْنِ أَبِي شَيْبَةَ - حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ التَّيْمِيُّ، عَنْ أَبِيهِ، عَنْ أَنَسٍ، أَنَّ رَجُلاً، - وَقَالَ حَامِدٌ وَابْنُ عَبْدِ الأَعْلَى أَنَّ الرَّجُلَ، - كَانَ يَجْعَلُ لِلنَّبِيِّ صلى الله عليه وسلم النَّخَلاَتِ مِنْ أَرْضِهِ ‏.‏ حَتَّى فُتِحَتْ عَلَيْهِ قُرَيْظَةُ وَالنَّضِيرُ فَجَعَلَ بَعْدَ ذَلِكَ يَرُدُّ عَلَيْهِ مَا كَانَ أَعْطَاهُ ‏.‏ قَالَ أَنَسٌ وَإِنَّ أَهْلِي أَمَرُونِي أَنْ آتِيَ النَّبِيَّ صلى الله عليه وسلم فَأَسْأَلَهُ مَا كَانَ أَهْلُهُ أَعْطَوْهُ أَوْ بَعْضَهُ وَكَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم قَدْ أَعْطَاهُ أُمَّ أَيْمَنَ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَأَعْطَانِيهِنَّ فَجَاءَتْ أُمُّ أَيْمَنَ فَجَعَلَتِ الثَّوْبَ فِي عُنُقِي وَقَالَتْ وَاللَّهِ لاَ نُعْطِيكَاهُنَّ وَقَدْ أَعْطَانِيهِنَّ ‏.‏ فَقَالَ نَبِيُّ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا أُمَّ أَيْمَنَ اتْرُكِيهِ وَلَكِ كَذَا وَكَذَا ‏"‏ ‏.‏ وَتَقُولُ كَلاَّ وَالَّذِي لاَ إِلَهَ إِلاَّ هُوَ ‏.‏ فَجَعَلَ يَقُولُ كَذَا حَتَّى أَعْطَاهَا عَشْرَةَ أَمْثَالِهِ أَوْ قَرِيبًا مِنْ عَشْرَةِ أَمْثَالِهِ ‏.‏\hadithno{4604}\hadithtrans{It has been narrated by Anas that (after his migration to Medina) a person placed at the Prophet's (ﷺ) disposal some date-palms growing on his land until the lands of Quraiza and Nadir were conquered. Then he began to return to him whatever he had received. (In this connection) my people told me to approach the Messenger of Allah (ﷺ) and ask from him what his people had given him or a portion thereof, but the Messenger of Allah (ﷺ) had bestowed those trees upon Umm Aiman. So I came to the Prophet (ﷺ) and he gave hem (back) to me. Umm Aiman (also) came (at this time). She put the cloth round my neck and said:No, by Allah, we will not give to, you what he has granted to me. The Prophet (ﷺ) said: Umm Aiman, let him have them and for you are such and such trees instead. But she said: By Allah, there is no god besides Him. No, never! The Prophet (ﷺ) continued saying: (You will get) such and such. until he had granted her ten times or nearly ten times more (than the original gift)}}
\hadithdefcmd{muslim}{4605}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ الْمُغِيرَةِ - حَدَّثَنَا حُمَيْدُ، بْنُ هِلاَلٍ عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، قَالَ أَصَبْتُ جِرَابًا مِنْ شَحْمٍ يَوْمَ خَيْبَرَ - قَالَ - فَالْتَزَمْتُهُ فَقُلْتُ لاَ أُعْطِي الْيَوْمَ أَحَدًا مِنْ هَذَا شَيْئًا - قَالَ - فَالْتَفَتُّ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم مُتَبَسِّمًا ‏.‏\hadithno{4605}\hadithtrans{It has been narrated on the authority of Abdullah b. Mughaffal who said I found a bag containing fat on the day of the Battle of Khaibar. I caught hold of it and said:I will not give anything today from it to anybody. Then I turned round and saw that the Messenger of Allah (ﷺ) was smiling (at my words)}}
\hadithdefcmd{muslim}{4606}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ الْعَبْدِيُّ، حَدَّثَنَا بَهْزُ بْنُ أَسَدٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي حُمَيْدُ، بْنُ هِلاَلٍ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مُغَفَّلٍ، يَقُولُ رُمِيَ إِلَيْنَا جِرَابٌ فِيهِ طَعَامٌ وَشَحْمٌ يَوْمَ خَيْبَرَفَوَثَبْتُ لآخُذَهُ قَالَ فَالْتَفَتُّ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَاسْتَحْيَيْتُ مِنْهُ ‏.‏\hadithno{4606}\hadithtrans{This tradition has been transmitted by a different chain of narrators with a different wording, the last in the chain being the same narrator, (i. e. 'Abdullah b. Mughaffal), who said:A bag containing food and fat was thrown to us. I lept forward to catch it. Then I turned round and saw (to my surprise) the Messenger of Allah (ﷺ) and I felt ashamed of my act in his presence}}
\hadithdefcmd{muslim}{4607}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَابْنُ أَبِي عُمَرَ، وَمُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ، حُمَيْدٍ - وَاللَّفْظُ لاِبْنِ رَافِعٍ - قَالَ ابْنُ رَافِعٍ وَابْنُ أَبِي عُمَرَ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ أَبَا سُفْيَانَ، أَخْبَرَهُ مِنْ، فِيهِ إِلَى فِيهِ قَالَ انْطَلَقْتُ فِي الْمُدَّةِ الَّتِي كَانَتْ بَيْنِي وَبَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَبَيْنَا أَنَا بِالشَّأْمِ إِذْ جِيءَ بِكِتَابٍ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى هِرَقْلَ يَعْنِي عَظِيمَ الرُّومِ - قَالَ - وَكَانَ دِحْيَةُ الْكَلْبِيُّ جَاءَ بِهِ فَدَفَعَهُ إِلَى عَظِيمِ بُصْرَى فَدَفَعَهُ عَظِيمُ بُصْرَى إِلَى هِرَقْلَ فَقَالَ هِرَقْلُ هَلْ هَا هُنَا أَحَدٌ مِنْ قَوْمِ هَذَا الرَّجُلِ الَّذِي يَزْعُمُ أَنَّهُ نَبِيٌّ قَالُوا نَعَمْ - قَالَ - فَدُعِيتُ فِي نَفَرٍ مِنْ قُرَيْشٍ فَدَخَلْنَا عَلَى هِرَقْلَ فَأَجْلَسَنَا بَيْنَ يَدَيْهِ فَقَالَ أَيُّكُمْ أَقْرَبُ نَسَبًا مِنْ هَذَا الرَّجُلِ الَّذِي يَزْعُمُ أَنَّهُ نَبِيٌّ فَقَالَ أَبُو سُفْيَانَ فَقُلْتُ أَنَا ‏.‏ فَأَجْلَسُونِي بَيْنَ يَدَيْهِ وَأَجْلَسُوا أَصْحَابِي خَلْفِي ثُمَّ دَعَا بِتَرْجُمَانِهِ فَقَالَ لَهُ قُلْ لَهُمْ إِنِّي سَائِلٌ هَذَا عَنِ الرَّجُلِ الَّذِي يَزْعُمُ أَنَّهُ نَبِيٌّ فَإِنْ كَذَبَنِي فَكَذِّبُوهُ ‏.‏ قَالَ فَقَالَ أَبُو سُفْيَانَ وَايْمُ اللَّهِ لَوْلاَ مَخَافَةَ أَنْ يُؤْثَرَ عَلَىَّ الْكَذِبُ لَكَذَبْتُ ‏.‏ ثُمَّ قَالَ لِتَرْجُمَانِهِ سَلْهُ كَيْفَ حَسَبُهُ فِيكُمْ قَالَ قُلْتُ هُوَ فِينَا ذُو حَسَبٍ قَالَ فَهَلْ كَانَ مِن�� آبَائِهِ مَلِكٌ قُلْتُ لاَ ‏.‏ قَالَ فَهَلْ كُنْتُمْ تَتَّهِمُونَهُ بِالْكَذِبِ قَبْلَ أَنْ يَقُولَ مَا قَالَ قُلْتُ لاَ ‏.‏ قَالَ وَمَنْ يَتَّبِعُهُ أَشْرَافُ النَّاسِ أَمْ ضُعَفَاؤُهُمْ قَالَ قُلْتُ بَلْ ضُعَفَاؤُهُمْ ‏.‏ قَالَ أَيَزِيدُونَ أَمْ يَنْقُصُونَ قَالَ قُلْتُ لاَ بَلْ يَزِيدُونَ ‏.‏ قَالَ هَلْ يَرْتَدُّ أَحَدٌ مِنْهُمْ عَنْ دِينِهِ بَعْدَ أَنْ يَدْخُلَ فِيهِ سَخْطَةً لَهُ قَالَ قُلْتُ لاَ ‏.‏ قَالَ فَهَلْ قَاتَلْتُمُوهُ قُلْتُ نَعَمْ ‏.‏ قَالَ فَكَيْفَ كَانَ قِتَالُكُمْ إِيَّاهُ قَالَ قُلْتُ تَكُونُ الْحَرْبُ بَيْنَنَا وَبَيْنَهُ سِجَالاً يُصِيبُ مِنَّا وَنُصِيبُ مِنْهُ ‏.‏ قَالَ فَهَلْ يَغْدِرُ قُلْتُ لاَ ‏.‏ وَنَحْنُ مِنْهُ فِي مُدَّةٍ لاَ نَدْرِي مَا هُوَ صَانِعٌ فِيهَا ‏.‏ قَالَ فَوَاللَّهِ مَا أَمْكَنَنِي مِنْ كَلِمَةٍ أُدْخِلُ فِيهَا شَيْئًا غَيْرَ هَذِهِ ‏.‏ قَالَ فَهَلْ قَالَ هَذَا الْقَوْلَ أَحَدٌ قَبْلَهُ قَالَ قُلْتُ لاَ ‏.‏ قَالَ لِتَرْجُمَانِهِ قُلْ لَهُ إِنِّي سَأَلْتُكَ عَنْ حَسَبِهِ فَزَعَمْتَ أَنَّهُ فِيكُمْ ذُو حَسَبٍ وَكَذَلِكَ الرُّسُلُ تُبْعَثُ فِي أَحْسَابِ قَوْمِهَا ‏.‏ وَسَأَلْتُكَ هَلْ كَانَ فِي آبَائِهِ مَلِكٌ فَزَعَمْتَ أَنْ لاَ ‏.‏ فَقُلْتُ لَوْ كَانَ مِنْ آبَائِهِ مَلِكٌ قُلْتُ رَجُلٌ يَطْلُبُ مُلْكَ آبَائِهِ ‏.‏ وَسَأَلْتُكَ عَنْ أَتْبَاعِهِ أَضُعَفَاؤُهُمْ أَمْ أَشْرَافُهُمْ فَقُلْتَ بَلْ ضُعَفَاؤُهُمْ وَهُمْ أَتْبَاعُ الرُّسُلِ ‏.‏ وَسَأَلْتُكَ هَلْ كُنْتُمْ تَتَّهِمُونَهُ بِالْكَذِبِ قَبْلَ أَنْ يَقُولَ مَا قَالَ فَزَعَمْتَ أَنْ لاَ ‏.‏ فَقَدْ عَرَفْتُ أَنَّهُ لَمْ يَكُنْ لِيَدَعَ الْكَذِبَ عَلَى النَّاسِ ثُمَّ يَذْهَبَ فَيَكْذِبَ عَلَى اللَّهِ ‏.‏ وَسَأَلْتُكَ هَلْ يَرْتَدُّ أَحَدٌ مِنْهُمْ عَنْ دِينِهِ بَعْدَ أَنْ يَدْخُلَهُ سَخْطَةً لَهُ فَزَعَمْتَ أَنْ لاَ ‏.‏ وَكَذَلِكَ الإِيمَانُ إِذَا خَالَطَ بَشَاشَةَ الْقُلُوبِ ‏.‏ وَسَأَلْتُكَ هَلْ يَزِيدُونَ أَوْ يَنْقُصُونَ فَزَعَمْتَ أَنَّهُمْ يَزِيدُونَ وَكَذَلِكَ الإِيمَانُ حَتَّى يَتِمَّ ‏.‏ وَسَأَلْتُكَ هَلْ قَاتَلْتُمُوهُ فَزَعَمْتَ أَنَّكُمْ قَدْ قَاتَلْتُمُوهُ فَتَكُونُ الْحَرْبُ بَيْنَكُمْ وَبَيْنَهُ سِجَالاً يَنَالُ مِنْكُمْ وَتَنَالُونَ مِنْهُ ‏.‏ وَكَذَلِكَ الرُّسُلُ تُبْتَلَى ثُمَّ تَكُونُ لَهُمُ الْعَاقِبَةُ وَسَأَلْتُكَ هَلْ يَغْدِرُ فَزَعَمْتَ أَنَّهُ لاَ يَغْدِرُ ‏.‏ وَكَذَلِكَ الرُّسُلُ لاَ تَغْدِرُ ‏.‏ وَسَأَلْتُكَ هَلْ قَالَ هَذَا الْقَوْلَ أَحَدٌ قَبْلَهُ فَزَعَمْتَ أَنْ لاَ ‏.‏ فَقُلْتُ لَوْ قَالَ هَذَا الْقَوْلَ أَحَدٌ قَبْلَهُ قُلْتُ رَجُلٌ ائْتَمَّ بِقَوْلٍ قِيلَ قَبْلَهُ ‏.‏ قَالَ ثُمَّ قَالَ بِمَ يَأْمُرُ كُمْ قُلْتُ يَأْمُرُنَا بِالصَّلاَةِ وَالزَّكَاةِ وَالصِّلَةِ وَالْعَفَافِ قَالَ إِنْ يَكُنْ مَا تَقُولُ فِيهِ حَقًّا فَإِنَّهُ نَبِيٌّ وَقَدْ كُنْتُ أَعْلَمُ أَنَّهُ خَارِجٌ وَلَمْ أَكُنْ أَظُنُّهُ مِنْكُمْ وَلَوْ أَنِّي أَعْلَمُ أَنِّي أَخْلُصُ إِلَيْهِ لأَحْبَبْتُ لِقَاءَهُ وَلَوْ كُنْتُ عِنْدَهُ لَغَسَلْتُ عَنْ قَدَمَيْهِ وَلَيَبْلُغَنَّ مُلْكُهُ مَا تَحْتَ قَدَمَىَّ ‏.‏ قَالَ ثُمَّ دَعَا بِكِتَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَرَأَهُ فَإِذَا فِيهِ ‏"‏ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ مِنْ مُحَمَّدٍ رَسُولِ اللَّهِ إِلَى هِرَقْلَ عَظِيمِ الرُّومِ سَلاَمٌ عَلَى مَنِ اتَّبَعَ الْهُدَى أَمَّا بَعْدُ فَإِنِّي أَدْعُوكَ بِدِعَايَةِ الإِسْلاَمِ أَسْلِمْ تَسْلَمْ وَأَسْلِمْ يُؤْتِكَ اللَّهُ أَجْرَكَ مَرَّتَيْنِ وَإِنْ تَوَلَّيْتَ فَإِنَّ عَلَيْكَ إِثْمَ الأَرِيسِيِّينَ وَ ‏\{‏ يَا أَهْلَ الْكِتَابِ تَعَالَوْا إِلَى كَلِمَةٍ سَوَاءٍ بَيْنَنَا وَبَيْنَكُمْ أَنْ لاَ نَعْبُدَ إِلاَّ اللَّهَ وَلاَ نُشْرِكَ بِهِ شَيْئًا وَلاَ يَتَّخِذَ بَعْضُنَا بَعْضًا أَرْبَابًا مِنْ دُونِ اللَّهِ فَإِنْ تَوَلَّوْا فَقُولُوا اشْهَدُوا بِأَنَّا مُسْلِمُونَ‏\}‏ فَلَمَّا فَرَغَ مِنْ قِرَاءَةِ الْكِتَابِ ارْتَفَعَتِ الأَصْوَاتُ عِنْدَهُ وَكَثُرَ اللَّغْطُ وَأَمَرَ بِنَا فَأُخْرِجْنَا ‏.‏ قَالَ فَقُلْتُ لأَصْحَابِي حِينَ خَرَجْنَا لَقَدْ أَمِرَ أَمْرُ ابْنِ أَبِي كَبْشَةَ إِنَّهُ لَيَخَافُهُ مَلِكُ بَنِي الأَصْفَرِ - قَالَ - فَمَا زِلْتُ مُوقِنًا بِأَمْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ سَيَظْهَرُ حَتَّى أَدْخَلَ اللَّهُ عَلَىَّ الإِسْلاَمَ ‏.‏\hadithno{4607}\hadithtrans{It has been narrated on the authority of Ibn Abbas who learnt the tradition personally from Abu Safyan. The latter said:I went out (on a mercantile venture) during the period (of truce) between me and the Messenger of Allah (ﷺ). While I was in Syria, the letter of the Messenger of Allah (ﷺ) was handed over to Hiraql (Ceasar), the Emperor of Rome (who was on a visit to Jerusalem at that time). The letter was brought by Dihya Kalbi who delivered it to the governor of Busra The governor passed it on to Hiraql, (On receiving the letter), he said: Is there anyone from the people of this man who thinks that he is a prophet. People said: Yes. So, I was called along with a few others from the Quraish. We were admitted to Hiraql and he seated usbefore him. He asked: Which of you has closer kinship with the man who thinks that he is a prophet? Abu Sufyan said: I. So they seated me in front of him and stated my companions behind me. Then, he called his interpreter and said to him: Tell them that I am going to ask this fellow (i. e. Abu Sufyan) about the man who thinks that he is a prophet. It he tells me a lie, then refute him. Abu Sufyan told (the narrator): By God, if there was not the fear that falsehood would be imputed to me I would have lied. (Then) Hiraqi said to his interpreter: Inquire from him about his ancestry, I said: He is of good ancestry among us. He asked: Has there been a king among his ancestors? I said: No. He asked: Did you accuse him of falsehood before he proclaimed his prophethood? I said: No. He asked: Who are his follower people of high status or low status? I said: (They are) of low status. He asked: Are they increasing in number or decreasing? I said. No. they are rather increasing. He asked: Does anyone give up his religion, being dissatisfied with it, after having embraced it? I said: No. He asked: Have you been at war with him? I said: Yes. He asked: How did you fare in that war? I said: The war between us and him has been wavering like a bucket, up at one turn and down at the other (i. e. the victory has been shared between us and him by turns). Sometimes he suffered loss at our hands and sometimes we suffered loss at his (hand). He asked: Has he (ever) violated his covenant? I said: No. but we have recently concluded a peace treaty with him for a petiod and we do not know what he is going to do about it. (Abu Sufyin said on oath that he could not interpolate in this dialogue anything from himself more than these words ) He asked: Did anyone make the proclamation (Of prophethood) before him? I said: No. He (now) said to his interpreter: Tell him, I asked him about his ancestry and he had replied that he had the best ancestry. This is the case with Prophets; they are the descendants of the noblest among their people (Addressing Abu Sufyan), he continued: I asked you if there had been a king among his ancestors. You said that there had been none. If there had been a king among his ancestors, I would have said that he was a man demanding his ancestral kingdom. I asked you about his followers whether they were people of high or low status, and you said that they were of rather low status. Such are the followers of the Prophets. I asked you whether you used to accuse him of falsehood before he proclaimed his prophethood, and you said that you did not. So I have understood that when he did not allow himself to tell a lie about the poeple, he would never go to the length of forging a falsehood about Allah. I asked you whether anyone renounced his religion being dissatisfied with it after he had embraced it, and you replied in the negative. Faith is like this when it enters the depth of the heart (it perpetuates them). I asked you whether his followers were increasing or decreasing. You said they were increasing. Faith is like this until it reaches its consummation. I asked you whether you had been at war with him, and you replied that you had been and that the victory between you and him had been shared by turns, sometimes he suffering loss at your hand and sometimes you suffering lost at his. This is how the Prophets are tried before the final victory its theirs. I asked you whether he (ever) violated his covenant, and you said that he did not. This is how the Prophets behave. They never violate (their covenants). I asked you whether anyone before him had proclaimed the same thing, and you replied in the negative. I said: If anyone had made the same proclamation before, I would have thought that he was a man following what had been proclaimed before. (Then) he asked: What does he enjoin upon you? I said: He exhorts us to offer Salat, to pay Zakat, to show due regard to kinship and to practise chastity. He said: It what you have told about him is true, he is certainly a Prophet. I knew that he was to appear but I did not think that he would be from among you. If I knew that I would be able to reach him. I would love to meet him; and it I had been with him. I would have washed his feet (out of reverence). His dominion would certainly extend to this place which is under my feet. Then he called for the letter of the Messenger of Allah (may pface be upon him) and read it. The letter ran as follows:" In the name of Allah, Most Gracious and Most Merciful. From Muhammad, the Messenger of Allah, to Hiraql, the Emperor of the Romans. Peace be upon him who follows the guidance. After this, I extend to you the invitation to accept Islam. Embrace Islam and you will be safe. Accept Islam, God will give you double the reward. And if you turn away, upon you will be the sin of your subjects." O People of the Book, come to the word that is common between us that we should worship none other than Allah, should not ascribe any partner to Him and some of us should not take their fellows as Lords other than Allah. If they turn away, you should say that we testify to our being Muslims [iii. 64]." When he hid finished the reading of the letter, noise and confused clamour was raise around him, and he ordered us to leave. Accordingly, we left. (Addressing my companions) while we were coming out (of the place). I said: Ibn Abu Kabsha (referring sarcastically to the Holy Prophet) has come to wield a great power. Lo! (even) the king of the Romans is afraid of him. I continued to believe that the authority of the Messenger of Allah (ﷺ) would triumph until God imbued me with (the spirit of) Islam}}
\hadithdefcmd{muslim}{4608}{وَحَدَّثَنَاهُ حَسَنٌ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ وَزَادَ فِي الْحَدِيثِ وَكَانَ قَيْصَرُ لَمَّا كَشَفَ اللَّهُ عَنْهُ جُنُودَ فَارِسَ مَشَى مِنْ حِمْصَ إِلَى إِيلِيَاءَ شُكْرًا لِمَا أَبْلاَهُ اللَّهُ ‏.‏ وَقَالَ فِي الْحَدِيثِ ‏"‏ مِنْ مُحَمَّدٍ عَبْدِ اللَّهِ وَرَسُولِهِ ‏"‏ ‏.‏ وَقَالَ ‏"‏ إِثْمَ الْيَرِيسِيِّينَ ‏"‏ ‏.‏ وَقَالَ ‏"‏ بِدَاعِيَةِ الإِسْلاَمِ ‏"‏ ‏.‏\hadithno{4608}\hadithtrans{This hadith has been narrated on the authority of Ibn Shihab with the same chain of transmitters but with the addition:" When Allah inflicted defeat on the armies of Persia, Caesar moved from Hims to Aelia (Bait al-Maqdis) for thanking Allah as He granted him victory." In this hadith these words occur:" From Muhammad, servant of Allah and His Messenger," and said:" The sin of your followers," and also said the words:" to the call of Islam}}
\hadithdefcmd{muslim}{4609}{حَدَّثَنِي يُوسُفُ بْنُ حَمَّادٍ الْمَعْنِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَتَبَ إِلَى كِسْرَى وَإِلَى قَيْصَرَ وَإِلَى النَّجَاشِيِّ وَإِلَى كُلِّ جَبَّارٍ يَدْعُوهُمْ إِلَى اللَّهِ تَعَالَى وَلَيْسَ بِالنَّجَاشِيِّ الَّذِي صَلَّى عَلَيْهِ النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{4609}\hadithtrans{It has been narrated on the authority of Anas that the Prophet of Allah (ﷺ) wrote to Chosroes (King of Persia), Caesar (Emperor of Rome), Negus (King of Abyssinia) and every (other) despot inviting them to Allah, the Exalted. And this Negus was not the one for whom the Messenger of Allah (ﷺ) had said the funeral prayers}}
\hadithdefcmd{muslim}{4610}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الرُّزِّيُّ، حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَطَاءٍ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ وَلَمْ يَقُلْ وَلَيْسَ بِالنَّجَاشِي الَّذِي صَلَّى عَلَيْهِ النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{4610}\hadithtrans{The tradition has been narrated on the authority of Anas b. Malik (the same narrator) through a different chain of transmitters, but this version does not mention:" And he was not the Negus for whom the Prophet (ﷺ) had said the funeral prayers}}
\hadithdefcmd{muslim}{4611}{وَحَدَّثَنِيهِ نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، أَخْبَرَنِي أَبِي، حَدَّثَنِي خَالِدُ بْنُ قَيْسٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، وَلَمْ يَذْكُرْ وَلَيْسَ بِالنَّجَاشِيِّ الَّذِي صَلَّى عَلَيْهِ النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{4611}\hadithtrans{It has been narrated on the authority of the same narrator through another chain of transmitters with the same difference in the wording}}
\hadithdefcmd{muslim}{4612}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي كَثِيرُ بْنُ عَبَّاسِ بْنِ عَبْدِ الْمُطَّلِبِ، قَالَ قَالَ عَبَّاسٌ شَهِدْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ حُنَيْنٍ فَلَزِمْتُ أَنَا وَأَبُو سُفْيَانَ بْنُ الْحَارِثِ بْنِ عَبْدِ الْمُطَّلِبِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَلَمْ نُفَارِقْهُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى بَغْلَةٍ لَهُ بَيْضَاءَ أَهْدَاهَا لَهُ فَرْوَةُ بْنُ نُفَاثَةَ الْجُذَامِيُّ فَلَمَّا الْتَقَى الْمُسْلِمُونَ وَالْكُفَّارُ وَلَّى الْمُسْلِمُونَ مُدْبِرِينَ فَطَفِقَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَرْكُضُ بَغْلَتَهُ قِبَلَ الْكُفَّارِ قَالَ عَبَّاسٌ وَ أَنَا آخِذٌ بِلِجَامِ بَغْلَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم أَكُفُّهَا إِرَادَةَ أَنْ لاَ تُسْرِعَ وَأَبُو سُفْيَانَ آخِذٌ بِرِكَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَىْ عَبَّاسُ نَادِ أَصْحَابَ السَّمُرَةِ ‏"‏ ‏.‏ فَقَالَ عَبَّاسٌ وَكَانَ رَجُلاً صَيِّتًا فَقُلْتُ بِأَعْلَى صَوْتِي أَيْنَ أَصْحَابُ السَّمُرَةِ قَالَ فَوَاللَّهِ لَكَأَنَّ عَطْفَتَهُمْ حِينَ سَمِعُوا صَوْتِي عَطْفَةُ الْبَقَرِ عَلَى أَوْلاَدِهَا ‏.‏ فَقَالُوا يَا لَبَّيْكَ يَا لَبَّيْكَ - قَالَ - فَاقْتَتَلُوا وَالْكُفَّارَ وَالدَّعْوَةُ فِي الأَنْصَارِ يَقُولُونَ يَا مَعْشَرَ الأَنْصَارِ يَا مَعْشَرَ الأَنْصَارِ قَالَ ثُمَّ قُصِرَتِ الدَّعْوَةُ عَلَى بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ فَقَالُوا يَا بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ يَا بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ ‏.‏ فَنَظَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى بَغْلَتِهِ كَالْمُتَطَاوِلِ عَلَيْهَا إِلَى قِتَالِهِمْ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا حِينَ حَمِيَ الْوَطِيسُ ‏"‏ ‏.‏ قَالَ ثُمَّ أَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَصَيَاتٍ فَرَمَى بِهِنَّ وُجُوهَ الْكُفَّارِ ثُمَّ قَالَ ‏"‏ انْهَزَمُوا وَرَبِّ مُحَمَّدٍ ‏"‏ ‏.‏ قَالَ فَذَهَبْتُ أَنْظُرُ فَإِذَا الْقِتَالُ عَلَى هَيْئَتِهِ فِيمَا أَرَى - قَالَ - فَوَاللَّهِ مَا هُوَ إِلاَّ أَنْ رَمَاهُمْ بِحَصَيَاتِهِ فَمَا زِلْتُ أَرَى حَدَّهُمْ كَلِيلاً وَأَمْرَهُمْ مُدْبِرًا ‏.‏\hadithno{4612}\hadithtrans{It has been narrated on the authority of 'Abbas who said:I was in the company of the Messenger of Allah (ﷺ) on the Day of Hunain. I and Abd Sufyan b. Harith b. 'Abd al-Muttalib stuck to the Messenaer of Allah (ﷺ) and we did not separate from him. And the Messenger of Allah (may place be upon him) was riding on his white mule which had been presented to him by Farwa b. Nufitha al-Judhami. When the Muslims had an encounter with the disbelievers, the Muslims fled, falling back, but the Messenger of Allah (ﷺ) began to spur his mule towards the disbelievers. I was holding the bridle of the mule of the Messenger of Allah (ﷺ) checking it from going very fast, and Abu Sufyan was holding the stirrup of the (mule of the) Messenger of Allah (ﷺ), who said: Abbas, call out to the people of al-Samura. Abbas (who was a man with a loud voice) called out at the top of the voice: Where are the people of Samura? (Abbas said: ) And by God, when they heard my voice, they came back (to us) as cows come back to their calves, and said: We are present, we are present! 'Abbas said: They began to fight the infidels. Then there was a call to The Ansar. Those (who called out to them) shouted: O ye party of the Ansar! O party of the Ansar! Banu al-Harith b. al-Khazraj were the last to be called. Those (who called out to them) shouted: O Banu Al-Harith b. al-Khazraj! O BanU Harith b. al-Khazraj! And the Messenger of Allah (ﷺ) who was riding on his mule looked at their fight with his neck stretched forward and he said: This is the time when the fight is raging hot. Then the Messenger of Allah (ﷺ) took (some) pebbles and threw them in the face of the infidels. Then he said: By the Lord of Muhammad, the infidels are defeated. 'Abbas said: I went round and saw that the battle was in the same condition in which I had seen it. By Allah, it remained in the same condition until he threw the pebbles. I continued to watch until I found that their force had been spent out and they began to retreat}}
\hadithdefcmd{muslim}{4613}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، جَمِيعًا عَنْ عَبْدِ، الرَّزَّاقِ أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ غَيْرَ أَنَّهُ قَالَ فَرْوَةُ بْنُ نُعَامَةَ الْجُذَامِيُّ ‏.‏ وَقَالَ ‏ "‏ انْهَزَمُوا وَرَبِّ الْكَعْبَةِ انْهَزَمُوا وَرَبِّ الْكَعْبَةِ ‏"‏ ‏.‏ وَزَادَ فِي الْحَدِيثِ حَتَّى هَزَمَهُمُ اللَّهُ قَالَ وَكَأَنِّي أَنْظُرُ إِلَى النَّبِيِّ صلى الله عليه وسلم يَرْكُضُ خَلْفَهُمْ عَلَى بَغْلَتِهِ ‏.‏\hadithno{4613}\hadithtrans{A version of the tradition has been transmitted through another chain of narrators. In this version the words uttered by the Prophet (ﷺ) (after he had thrown the pebbles in the face of the enemy) are reported as:" By the Lord of the Ka'ba, they have been defeated." And there is at the end the addition of the words:" Until Allah defeated them" (and I imagine) as if I saw the Prophet of Allah (ﷺ) chasing them on his mule}}
\hadithdefcmd{muslim}{4614}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي كَثِيرُ، بْنُ الْعَبَّاسِ عَنْ أَبِيهِ، قَالَ كُنْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم يَوْمَ حُنَيْنٍ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏ غَيْرَ أَنَّ حَدِيثَ يُونُسَ وَحَدِيثَ مَعْمَرٍ أَكْثَرُ مِنْهُ وَأَتَمُّ ‏.‏\hadithno{4614}\hadithtrans{Abbas reported:I was with Allah's Apostle (ﷺ) on the Day of Hunain. The rest of the hadith is the same but with this variation that the hadith transmitted by Yonus and Ma'mar is more detailed and complete}}
\hadithdefcmd{muslim}{4615}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي إِسْحَاقَ، قَالَ قَالَ رَجُلٌ لِلْبَرَاءِ يَا أَبَا عُمَارَةَ أَفَرَرْتُمْ يَوْمَ حُنَيْنٍ قَالَ لاَ وَاللَّهِ مَا وَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَكِنَّهُ خَرَجَ شُبَّانُ أَصْحَابِهِ وَأَخِفَّاؤُهُمْ حُسَّرًا لَيْسَ عَلَيْهِمْ سِلاَحٌ أَوْ كَثِيرُ سِلاَحٍ فَلَقُوا قَوْمًا رُمَاةً لاَ يَكَادُ يَسْقُطُ لَهُمْ سَهْمٌ جَمْعَ هَوَازِنَ وَبَنِي نَصْرٍ فَرَشَقُوهُمْ رَشْقًا مَا يَكَادُونَ يُخْطِئُونَ فَأَقْبَلُوا هُنَاكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَرَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى بَغْلَتِهِ الْبَيْضَاءِ وَأَبُو سُفْيَانَ بْنُ الْحَارِثِ بْنِ عَبْدِ الْمُطَّلِبِ يَقُودُ بِهِ فَنَزَلَ فَاسْتَنْصَرَ وَقَالَ ‏ "‏ أَنَا النَّبِيُّ لاَ كَذِبْ أَنَا ابْنُ عَبْدِ الْمُطَّلِبْ ‏"‏ ‏.‏ ثُمَّ صَفَّهُمْ ‏.‏\hadithno{4615}\hadithtrans{It has been narratedon the authority of Abu Ishaq who said:A man asked Bara' (b. 'Azib): Did you run away on the Day of Hunain. O, Abu Umira? He said: No, by Allah, The Messenger of Allah (ﷺ) did not turn his back; (what actually happened was that) some young men from among his companions, who were hasty and who were either without any arms or did not have abundant arms, advanced and met a party of archers (who were so good shots) that their arrows never missed the mark. This party (of archers) belonged to Banu Hawazin and Banu Nadir. They shot at the advancing young men and their arrows were not likely to miss their targets. So these young men turned to the Messenger of Allah (ﷺ) while he was riding on his white mule and Abu Sufyan b. al-Harith b. 'Abd al-Muttalib was leading him. (At this) he got down from his mule, invoked God's help, and called out: I am the Prophet. This is no untruth. I am the son of 'Abd al-Muttalib. Then he deployed his men into battle array}}
\hadithdefcmd{muslim}{4616}{حَدَّثَنَا أَحْمَدُ بْنُ جَنَابٍ الْمِصِّيصِيُّ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ زَكَرِيَّاءَ، عَنْ أَبِي، إِسْحَاقَ قَالَ جَاءَ رَجُلٌ إِلَى الْبَرَاءِ فَقَالَ أَكُنْتُمْ وَلَّيْتُمْ يَوْمَ حُنَيْنٍ يَا أَبَا عُمَارَةَ فَقَالَ أَشْهَدُ عَلَى نَبِيِّ اللَّهِ صلى الله عليه وسلم مَا وَلَّى وَلَكِنَّهُ انْطَلَقَ أَخِفَّاءُ مِنَ النَّاسِ وَحُسَّرٌ إِلَى هَذَا الْحَىِّ مِنْ هَوَازِنَ وَهُمْ قَوْمٌ رُمَاةٌ فَرَمَوْهُمْ بِرِشْقٍ مِنْ نَبْلٍ كَأَنَّهَا رِجْلٌ مِنْ جَرَادٍ فَانْكَشَفُوا فَأَقْبَلَ الْقَوْمُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَبُو سُفْيَانَ بْنُ الْحَارِثِ يَقُودُ بِهِ بَغْلَتَهُ فَنَزَلَ وَدَعَا وَاسْتَنْصَرَ وَهُوَ يَقُولُ ‏ "‏ أَنَا النَّبِيُّ لاَ كَذِبْ أَنَا ابْنُ عَبْدِ الْمُطَّلِبْ اللَّهُمَّ نَزِّلْ نَصْرَكَ ‏"‏ ‏.‏ قَالَ الْبَرَاءُ كُنَّا وَاللَّهِ إِذَا احْمَرَّ الْبَأْسُ نَتَّقِي بِهِ وَإِنَّ الشُّجَاعَ مِنَّا لَلَّذِي يُحَاذِي بِهِ ‏.‏ يَعْنِي النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{4616}\hadithtrans{It has been narrated (through a different chain of transmitters) by Abu Ishiq that a person said to Bara' (b. 'Azib):Abu Umara, did you flee on the Day of Hunain? He replied: The Messenger of Allah (ﷺ) did not retreat. (What actually happened was that some hasty young men who were either inadequately armed or were unarmed met a group of men from Banu Hawazin and Banu Nadir who happened to be (excellent) archers. The latter shot at them a volley of arrows that did not miss. The people turned to the Messenger of Allah (ﷺ). Abu Sufyan b. Harith was leading his mule. So he got down, prayed and invoked God's help. He said: I am the Prophet. This is no untruth. I am the son of Abd al-Muttalib. O God, descend Thy help. Bara' continued: When the battle grew fierce. we, by God. would seek protection by his side, and the bravest among us was he who confronted the onslaught and it was the Prophet (ﷺ)}}
\hadithdefcmd{muslim}{4617}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ، وَسَأَلَهُ، رَجُلٌ مِنْ قَيْسٍ أَفَرَرْتُمْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ حُنَيْنٍ فَقَالَ الْبَرَاءُ وَلَكِنْ رَسُولُ اللَّهِ صلى الله عليه وسلم لَمْ يَفِرَّ وَكَانَتْ هَوَازِنُ يَوْمَئِذٍ رُمَاةً وَإِنَّا لَمَّا حَمَلْنَا عَلَيْهِمُ انْكَشَفُوا فَأَكْبَبْنَا عَلَى الْغَنَائِمِ فَاسْتَقْبَلُونَا بِالسِّهَامِ وَلَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى بَغْلَتِهِ الْبَيْضَاءِ وَإِنَّ أَبَا سُفْيَانَ بْنَ الْحَارِثِ آخِذٌ بِلِجَامِهَا وَهُوَ يَقُولُ ‏ "‏ أَنَا النَّبِيُّ لاَ كَذِبْ أَنَا ابْنُ عَبْدِ الْمُطَّلِبْ ‏"‏ ‏.‏\hadithno{4617}\hadithtrans{It has been narrated through a still different chain of transmitters by the same narrator (i. e. Abu Ishaq) who said:I heard from Bara' who was asked by a man from the Qais tribe: Did you run away from the Messenger of Allah (ﷺ) on the Day of Hunain? Bara' said: But the Messenger of Allah (ﷺ) did not run away. On that day Banu Hawzzin took part in the battle as archers (on the side of the disbelievers). When we attacked them, they retreated and we fell upon the booty; (they rallied) and advanced towards us with arrows. (At that time) I saw the Messenger of Allah (ﷺ) riding on his white mule and Abu Sufyan b. al-Harith was holding its bridle. He (the Messenger of Allah was saying: I am the Prophet. This is no untruth. I am a descendant of 'Abd al-Muttalib)}}
\hadithdefcmd{muslim}{4618}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَأَبُو بَكْرِ بْنُ خَلاَّدٍ قَالُوا حَدَّثَنَا يَحْيَى، بْنُ سَعِيدٍ عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي أَبُو إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ قَالَ لَهُ رَجُلٌ يَا أَبَا عُمَارَةَ ‏.‏ فَذَكَرَ الْحَدِيثَ وَهُوَ أَقَلُّ مِنْ حَدِيثِهِمْ وَهَؤُلاَءِ أَتَمُّ حَدِيثًا ‏.‏\hadithno{4618}\hadithtrans{This hadith has been narrated on the authority of Bara' with another chain of transmitters, but this hadith is short as compared with other ahadith which are more detailed}}
\hadithdefcmd{muslim}{4619}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ الْحَنَفِيُّ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنِي إِيَاسُ بْنُ سَلَمَةَ، حَدَّثَنِي أَبِي قَالَ، غَزَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حُنَيْنًا فَلَمَّا وَاجَهْنَا الْعَدُوَّ تَقَدَّمْتُ فَأَعْلُو ثَنِيَّةً فَاسْتَقْبَلَنِي رَجُلٌ مِنَ الْعَدُوِّ فَأَرْمِيهِ بِسَهْمٍ فَتَوَارَى عَنِّي فَمَا دَرَيْتُ مَا صَنَعَ وَنَظَرْتُ إِلَى الْقَوْمِ فَإِذَا هُمْ قَدْ طَلَعُوا مِنْ ثَنِيَّةٍ أُخْرَى فَالْتَقَوْا هُمْ وَصَحَابَةُ النَّبِيِّ صلى الله عليه وسلم فَوَلَّى صَحَابَةُ النَّبِيِّ صلى الله عليه وسلم وَأَرْجِعُ مُنْهَزِمًا وَعَلَىَّ بُرْدَتَانِ مُتَّزِرًا بِإِحْدَاهُمَا مُرْتَدِيًا بِالأُخْرَى فَاسْتَطْلَقَ إِزَارِي فَجَمَعْتُهُمَا جَمِيعًا وَمَرَرْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مُنْهَزِمًا وَهُوَ عَلَى بَغْلَتِهِ الشَّهْبَاءِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَقَدْ رَأَى ابْنُ الأَكْوَعِ فَزَعًا ‏"‏ ‏.‏ فَلَمَّا غَشُوا رَسُولَ اللَّهِ صلى الله عليه وسلم نَزَلَ عَنِ الْبَغْلَةِ ثُمَّ قَبَضَ قَبْضَةً مِنْ تُرَابٍ مِنَ الأَرْضِ ثُمَّ اسْتَقْبَلَ بِهِ وُجُوهَهُمْ فَقَالَ ‏"‏ شَاهَتِ الْوُجُوهُ ‏"‏ ‏.‏ فَمَا خَلَقَ اللَّهُ مِنْهُمْ إِنْسَانًا إِلاَّ مَلأَ عَيْنَيْهِ تُرَابًا بِتِلْكَ الْقَبْضَةِ فَوَلَّوْا مُدْبِرِينَ فَهَزَمَهُمُ اللَّهُ عَزَّ وَجَلَّ وَقَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم غَنَائِمَهُمْ بَيْنَ الْمُسْلِمِينَ ‏.‏\hadithno{4619}\hadithtrans{This tradition has been narrated on the authority of Salama who said:We fought by the side of the Messenger of Allah (ﷺ) at Hunain. When we encountered the enemy, I advanced and ascended a hillock. A man from the enemy side turned towards me and I shot him with an arrow. He (ducked and) hid himself from me. I could not understand what he did, but (all of a sudden) I saw that a group of people appeared from the other hillock. They and the Companions of the Prophet (ﷺ) met in combat, but the Companions of the Prophet turned back and I too turned back defeated. I had two mantles, one of which I was wrapping round the waist (covering the lower part of my body) and the other I was putting around my shoulders. My waist-wrapper got loose and I held the two mantles together. (In this downcast condition) I passed by the Messenger of Allah (ﷺ) who was riding on his white mule. He said: The son of Akwa' finds himself to be utterly perplexed. Wher. the Companions gathered round him from all sides. the Messenger of Allah (ﷺ) got down from his mule. picked up a handful of dust from the ground, threw it into their (enemy) faces and said: May these faces be deformed 1 There was no one among the enemy whose eyes were not filled with the dust from this handful. So they turned back fleeing. and Allah the Exalted and Glorious defeated them, and the Messenger of Allah (ﷺ) distributed their booty among the Muslims}}
\hadithdefcmd{muslim}{4620}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، نُمَيْرٍ جَمِيعًا عَنْ سُفْيَانَ، قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ أَبِي الْعَبَّاسِ الشَّاعِرِ الأَعْمَى، عَنْ عَبْدِ اللَّهِ، بْنِ عَمْرٍو قَالَ حَاصَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَهْلَ الطَّائِفِ فَلَمْ يَنَلْ مِنْهُمْ شَيْئًا فَقَالَ ‏"‏ إِنَّا قَافِلُونَ إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏ قَالَ أَصْحَابُهُ نَرْجِعُ وَلَمْ نَفْتَتِحْهُ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اغْدُوا عَلَى الْقِتَالِ ‏"‏ ‏.‏ فَغَدَوْا عَلَيْهِ فَأَصَابَهُمْ جِرَاحٌ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّا قَافِلُونَ غَدًا ‏"‏ ‏.‏ قَالَ فَأَعْجَبَهُمْ ذَلِكَ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4620}\hadithtrans{It has been narrated on the authority of Ibn 'Amr who said:The Messenger of Allah (ﷺ) besieged the people of Ta'if, but did get victory over them. He said: God willing, we shall return. His Companions said: Shall we depart without having conquered it? The Messenger of Allah (ﷺ) said: (All right) make a raid in the morning. They did so. and were wounded (with the arrows showered upon them). So the Messenger of Allah (ﷺ) said: We shall depart tomorrow. (The narrator says): (Now) this (announcement) pleased them, and the Messenger of Allah (ﷺ) laughed at (their waywardness)}}
\hadithdefcmd{muslim}{4621}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم شَاوَرَ حِينَ بَلَغَهُ إِقْبَالُ أَبِي سُفْيَانَ قَالَ فَتَكَلَّمَ أَبُو بَكْرٍ فَأَعْرَضَ عَنْهُ ثُمَّ تَكَلَّمَ عُمَرُ فَأَعْرَضَ عَنْهُ فَقَامَ سَعْدُ بْنُ عُبَادَةَ فَقَالَ إِيَّانَا تُرِيدُ يَا رَسُولَ اللَّهِ وَالَّذِي نَفْسِي بِيَدِهِ لَوْ أَمَرْتَنَا أَنْ نُخِيضَهَا الْبَحْرَ لأَخَضْنَاهَا وَلَوْ أَمَرْتَنَا أَنْ نَضْرِبَ أَكْبَادَهَا إِلَى بَرْكِ الْغِمَادِ لَفَعَلْنَا - قَالَ - فَنَدَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّاسَ فَانْطَلَقُوا حَتَّى نَزَلُوا بَدْرًا وَوَرَدَتْ عَلَيْهِمْ رَوَايَا قُرَيْشٍ وَفِيهِمْ غُلاَمٌ أَسْوَدُ لِبَنِي الْحَجَّاجِ فَأَخَذُوهُ فَكَانَ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَسْأَلُونَهُ عَنْ أَبِي سُفْيَانَ وَأَصْحَابِهِ ‏.‏ فَيَقُولُ مَا لِي عِلْمٌ بِأَبِي سُفْيَانَ وَلَكِنْ هَذَا أَبُو جَهْلٍ وَعُتْبَةُ وَشَيْبَةُ وَأُمَيَّةُ بْنُ خَلَفٍ ‏.‏ فَإِذَا قَالَ ذَلِكَ ضَرَبُوهُ فَقَالَ نَعَمْ أَنَا أُخْبِرُكُمْ هَذَا أَبُو سُفْيَانَ ‏.‏ فَإِذَا تَرَكُوهُ فَسَأَلُوهُ فَقَالَ مَا لِي بِأَبِي سُفْيَانَ عِلْمٌ وَلَكِنْ هَذَا أَبُو جَهْلٍ وَعُتْبَةُ وَأُمَيَّةُ بْنُ خَلَفٍ فِي النَّاسِ ‏.‏ فَإِذَا قَالَ هَذَا أَيْضًا ضَرَبُوهُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ يُصَلِّي فَلَمَّا رَأَى ذَلِكَ انْصَرَفَ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَتَضْرِبُوهُ إِذَا صَدَقَكُمْ وَتَتْرُكُوهُ إِذَا كَذَبَكُمْ ‏"‏ ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا مَصْرَعُ فُلاَنٍ ‏"‏ ‏.‏ قَالَ وَيَضَعُ يَدَهُ عَلَى الأَرْضِ هَا هُنَا وَهَا هُنَا قَالَ فَمَا مَاطَ أَحَدُهُمْ عَنْ مَوْضِعِ يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4621}\hadithtrans{It has been narrated on the authority of Anas that when (the news of) the advance of Abu Sufyan (at the head of a force) reached him. the Messenger of Allah (ﷺ) held consultations with his Companions. The narrator said:Abu Bakr spoke (expressing his own views), but he (the Holy Prophet) did not pay heed to him. Then spoke 'Umar (expressing his views), but he (the Holy Prophet) did not pay heed to him (too). Then Sa'd b. 'Ubada stood up and said: Messenger of Allah, you want us (to speak). By God in Whose control is my life, if you order us to plunge our horses into the sea, we would do so. If you order us to goad our horses to the most distant place like Bark al-Ghimad, we would do so. The narrator said: Now the Messenger of Allah (ﷺ) called upon the people (for the encounter). So they set out and encamped at Badr. (Soon) the water-carriers of the Quraish arrived. Among them was a black slave belonging to Banu al-Hajjaj. The Companions of the Messenger of Allah (ﷺ) caught him and interrogated him about Abu Sufyan and his companions. He said: I know nothing about Abu Sufyan, but Abu Jahl, Utba, Shaiba and Umayya b. Khalaf are there. When he said this, they beat him. Then he said: All right, I will tell you about Abu Sufyan. They would stop beating him and then ask him (again) about Abu Sufyan. He would again say', I know nothing about Abu Sufyan, but Abu Jahl. 'Utba, Shaiba and Umayya b. Khalaf are there. When he said this, they beat him likewise. The Messenger of Allah (ﷺ) was standing in prayer. When he saw this he finished his prayer and said: By Allah in Whose control is my life, you beat him when he is telling you the truth, and you let him go when he tells you a lie. The narrator said: Then the Messenger of Allah (ﷺ) said: This is the place where so and so would be killed. He placed his hand on the earth (saying) here and here; (and) none of them fell away from the place which the Messenger of Allah (ﷺ) had indicated by placing his hand on the earth}}
\hadithdefcmd{muslim}{4622}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ وَفَدَتْ وُفُودٌ إِلَى مُعَاوِيَةَ وَذَلِكَ فِي رَمَضَانَ فَكَانَ يَصْنَعُ بَعْضُنَا لِبَعْضٍ الطَّعَامَ فَكَانَ أَبُو هُرَيْرَةَ مِمَّا يُكْثِرُ أَنْ يَدْعُوَنَا إِلَى رَحْلِهِ فَقُلْتُ أَلاَ أَصْنَعُ طَعَامًا فَأَدْعُوَهُمْ إِلَى رَحْلِي فَأَمَرْتُ بِطَعَامٍ يُصْنَعُ ثُمَّ لَقِيتُ أَبَا هُرَيْرَةَ مِنَ الْعَشِيِّ فَقُلْتُ الدَّعْوَةُ عِنْدِي اللَّيْلَةَ فَقَالَ سَبَقْتَنِي ‏.‏ قُلْتُ نَعَمْ ‏.‏ فَدَعَوْتُهُمْ فَقَالَ أَبُو هُرَيْرَةَ أَلاَ أُعْلِمُكُمْ بِحَدِيثٍ مِنْ حَدِيثِكُمْ يَا مَعْشَرَ الأَنْصَارِ ثُمَّ ذَكَرَ فَتْحَ مَكَّةَ فَقَالَ أَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى قَدِمَ مَكَّةَ فَبَعَثَ الزُّبَيْرَ عَلَى إِحْدَى الْمُجَنِّبَتَيْنِ وَبَعَثَ خَالِدًا عَلَى الْمُجَنِّبَةِ الأُخْرَى وَبَعَثَ أَبَا عُبَيْدَةَ عَلَى الْحُسَّرِ فَأَخَذُوا بَطْنَ الْوَادِي وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي كَتِيبَةٍ - قَالَ - فَنَظَرَ فَرَآنِي فَقَالَ ‏"‏ أَبُو هُرَيْرَةَ ‏"‏ ‏.‏ قُلْتُ لَبَّيْكَ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ ‏"‏ لاَ يَأْتِينِي إِلاَّ أَنْصَارِيٌّ ‏"‏ ‏.‏ زَادَ غَيْرُ شَيْبَانَ فَقَالَ ‏"‏ اهْتِفْ لِي بِالأَنْصَارِ ‏"‏ ‏.‏ قَالَ فَأَطَافُوا بِهِ وَوَبَّشَتْ قُرَيْشٌ أَوْبَاشًا لَهَا وَأَتْبَاعًا ‏.‏ فَقَالُوا نُقَدِّمُ هَؤُلاَءِ فَإِنْ كَانَ لَهُمْ شَىْءٌ كُنَّا مَعَهُمْ ‏.‏ وَإِنْ أُصِيبُوا أَعْطَيْنَا الَّذِي سُئِلْنَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَرَوْنَ إِلَى أَوْبَاشِ قُرَيْشٍ وَأَتْبَاعِهِمْ ‏"‏ ‏.‏ ثُمَّ قَالَ بِيَدَيْهِ إِحْدَاهُمَا عَلَى الأُخْرَى ثُمَّ قَالَ ‏"‏ حَتَّى تُوَافُونِي بِالصَّفَا ‏"‏ ‏.‏ قَالَ فَانْطَلَقْنَا فَمَا شَاءَ أَحَدٌ مِنَّا أَنْ يَقْتُلَ أَحَدًا إِلاَّ قَتَلَهُ وَمَا أَحَدٌ مِنْهُمْ يُوَجِّهُ إِلَيْنَا شَيْئًا - قَالَ - فَجَاءَ أَبُو سُفْيَانَ فَقَالَ يَا رَسُولَ اللَّهِ أُبِيحَتْ خَضْرَاءُ قُرَيْشٍ لاَ قُرَيْشَ بَعْدَ الْيَوْمِ ‏.‏ ثُمَّ قَالَ ‏"‏ مَنْ دَخَلَ دَارَ أَبِي سُفْيَانَ فَهُوَ آمِنٌ ‏"‏ ‏.‏ فَقَالَتِ الأَنْصَارُ بَعْضُهُمْ لِبَعْضٍ أَمَّا الرَّجُلُ فَأَدْرَكَتْهُ رَغْبَةٌ فِي قَرْيَتِهِ وَرَأْفَةٌ بِعَشِيرَتِهِ ‏.‏ قَالَ أَبُو هُرَيْرَةَ وَجَاءَ الْوَحْىُ وَكَانَ إِذَا جَاءَ الْوَحْىُ لاَ يَخْفَى عَلَيْنَا فَإِذَا جَاءَ فَلَيْسَ أَحَدٌ يَرْفَعُ طَرْفَهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى يَنْقَضِيَ الْوَحْىُ فَلَمَّا انْقَضَى الْوَحْىُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا مَعْشَرَ الأَنْصَارِ ‏"‏ ‏.‏ قَالُوا لَبَّيْكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ قُلْتُمْ أَمَّا الرَّجُلُ فَأَدْرَكَتْهُ رَغْبَةٌ فِي قَرْيَتِهِ ‏"‏ ‏.‏ قَالُوا قَدْ كَانَ ذَاكَ ‏.‏ قَالَ ‏"‏ كَلاَّ إِنِّي عَبْدُ اللَّهِ وَرَسُولُهُ هَاجَرْتُ إِلَى اللَّهِ وَإِلَيْكُمْ وَالْمَحْيَا مَحْيَاكُمْ وَالْمَمَاتُ مَمَاتُكُمْ ‏"‏ ‏.‏ فَأَقْبَلُوا إِلَيْهِ يَبْكُونَ وَيَقُولُونَ وَاللَّهِ مَا قُلْنَا الَّذِي قُلْنَا إِلاَّ الضِّنَّ بِاللَّهِ وَبِرَسُولِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ وَرَسُولَهُ يُصَدِّقَانِكُمْ وَيَعْذِرَانِكُمْ ‏"‏ ‏.‏ قَالَ فَأَقْبَلَ النَّاسُ إِلَى دَارِ أَبِي سُفْيَانَ وَأَغْلَقَ النَّاسُ أَبْوَابَهُمْ - قَالَ - وَأَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى أَقْبَلَ إِلَى الْحَجَرِ فَاسْتَلَمَهُ ثُمَّ طَافَ بِالْبَيْتِ - قَالَ - فَأَتَى عَلَى صَنَمٍ إِلَى جَنْبِ الْبَيْتِ كَانُوا يَعْبُدُونَهُ - قَالَ - وَفِي يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَوْسٌ وَهُوَ آخِذٌ بِسِيَةِ الْقَوْسِ فَلَمَّا أَتَى عَلَى الصَّنَمِ جَعَلَ يَطْعُنُهُ فِي عَيْنِهِ وَيَقُولُ ‏"‏ جَاءَ الْحَقُّ وَزَهَقَ الْبَاطِلُ ‏"‏ ‏.‏ فَلَمَّا فَرَغَ مِنْ طَوَافِهِ أَتَى الصَّفَا فَعَلاَ عَلَيْهِ حَتَّى نَظَرَ إِلَى الْبَيْتِ وَرَفَعَ يَدَيْهِ فَجَعَلَ يَحْمَدُ اللَّهَ وَيَدْعُو بِمَا شَاءَ أَنْ يَدْعُوَ ‏.‏\hadithno{4622}\hadithtrans{It has been narrated by 'Abdullah b. Rabah from Abu Huraira, who said:Many deputations came to Mu'awiya. This was in the month of Ramadan. We would prepare food for one another. Abu Huraira was one of those who frequently invited us to his house. I said: Should I not prepare food and invite them to my place? So I ordered meals to be prepared Then I met Abu Huraira in the evening and said: (You will have) your meals with me tonight. He said: You have forestalled me. I said: Yes, and invited them. (When they had finished with the meals) Abu Huraira said: Should I not tell yon a tradition from your traditions, O ye assembly of the Ansar? He then gave an account of the Conquest of Mecca and said: The Messenger of Allah (ﷺ) advanced until he reached Mecca. He deputed Zubair on his right flank and Khalid on the left, and he despatched Abu Ubaida with the force that had no armour. They advanced to the interior of the valley. The Messenger of Allah (ﷺ) was in the midst of a large contingent of fighters. He saw me and said: Abu Huraira. I said: I am here at your call, Messenger of Allah I He said: Let no one come to me except the Ansar, so call to me the Ansar (only). Abu Huraira continued: So they gathered round him. The Quraish also gathered their ruffians and their (lowly) followers, and said: We send these forward. If they get anything, we shall be with them (to share it), and if misfortune befalls them, we shall pay (as compensation) whatever we are asked for. The Messenger of Allah (ﷺ) said (to the Ansar): You see the ruffians and the (lowly) followers of the Quraish. And he indicated by (striking) one of his hands over the other that they should be killed and said: Meet me at as-Safa. Then we went on (and) if any one of us wanted that a certain person should be killed, he was killed, and none could offer any resistance. Abu Huraira continued: Then came Abu Sufyan and said: Messenger of Allah, the blood of the Quraish has become very cheap. There will be no Quraish from this day on. Then he (the Holy Prophet) said: Who enters the house of Abu Sufyan, he will be safe. Some of the Ansar whispered among themselves: (After all), love for his city and tenderness towards his relations have overpowered him. Abu Huraira said: (At this moment) revelation came to the Prophet (ﷺ) and when he was going to receive the Revelation, we understood it, and when he was (actually) receiving it, none of us would dare raise his eyes to the Messenger of Allah (ﷺ) until the revelation came to an end. When the revelation came to an end, the Messenger of Allah (ﷺ) said: O ye Assembly of the Ansar! They said: Here we are at your disposal, Messenger of Allah. He said: You were saying that love for his city and tenderness towards his people have overpowered this man. They said: So it was. He said: No, never. I am a bondman of God and His Messenger. I migrated towards God and towards you. I will live with you and will die with you. So, they (the Ansar) turned towards him in tears and they were saying: By Allah, we said what we said because of our tenacious attachment to Allah and His Messenger. The Messenger of Allah (ﷺ) said: Surely, Allah and His Messenger testify to your assertions and accept your apology. The narrator continued: People turned to the house of Abu Sufyan and people locked their doors. The Messenger of Allah (ﷺ) proceeded until he approached the (Black) Stone. He kissed it and circumambulated the Ka'ba. He reached near an idol by the side of the Ka'ba which was worshipped by the people. The Messenger of Allah (ﷺ) had a bow in his hand, and he was holding it from a corner. When he came near the idol, he began to pierce its eyes with the bow and (while doing so) was saying: Truth has been established and falsehood has perished. When he had finished the circumambulation, he came to Safa', ascended it to a height from where he could see the Ka'ba, raised his hands (in prayer) and began to praise Allah and prayed what he wanted to pray}}
\hadithdefcmd{muslim}{4623}{وَحَدَّثَنِيهِ عَبْدُ اللَّهِ بْنُ هَاشِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، بِهَذَا الإِسْنَادِ وَزَادَ فِي الْحَدِيثِ ثُمَّ قَالَ بِيَدَيْهِ إِحْدَاهُمَا عَلَى الأُخْرَى ‏"‏ احْصُدُوهُمْ حَصْدًا ‏"‏ ‏.‏ وَقَالَ فِي الْحَدِيثِ قَالُوا قُلْنَا ذَاكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ فَمَا اسْمِي إِذًا كَلاَّ إِنِّي عَبْدُ اللَّهِ وَرَسُولُهُ ‏"‏ ‏.‏\hadithno{4623}\hadithtrans{The tradition has been narrated by a different chain of transmitters with the following additions:(i) Then be (the Messenger of Allah) said with his hands one upon the other: Kill them (who stand in your way).... (ii) They (the Ansar) replied: We said so, Messenger of Allah! He said: What is my name? I am but Allah's bondman and His Messenger}}
\hadithdefcmd{muslim}{4624}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، حَدَّثَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنَا حَمَّادُ، بْنُ سَلَمَةَ أَخْبَرَنَا ثَابِتٌ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ، قَالَ وَفَدْنَا إِلَى مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ وَفِينَا أَبُو هُرَيْرَةَ فَكَانَ كُلُّ رَجُلٍ مِنَّا يَصْنَعُ طَعَامًا يَوْمًا لأَصْحَابِهِ فَكَانَتْ نَوْبَتِي فَقُلْتُ يَا أَبَا هُرَيْرَةَ الْيَوْمُ نَوْبَتِي ‏.‏ فَجَاءُوا إِلَى الْمَنْزِلِ وَلَمْ يُدْرِكْ طَعَامُنَا فَقُلْتُ يَا أَبَا هُرَيْرَةَ لَوْ حَدَّثْتَنَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى يُدْرِكَ طَعَامُنَا فَقَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ الْفَتْحِ فَجَعَلَ خَالِدَ بْنَ الْوَلِيدِ عَلَى الْمُجَنِّبَةِ الْيُمْنَى وَجَعَلَ الزُّبَيْرَ عَلَى الْمُجَنِّبَةِ الْيُسْرَى وَجَعَلَ أَبَا عُبَيْدَةَ عَلَى الْبَيَاذِقَةِ وَبَطْنِ الْوَادِي فَقَالَ ‏"‏ يَا أَبَا هُرَيْرَةَ ادْعُ لِي الأَنْصَارَ ‏"‏ ‏.‏ فَدَعَوْتُهُمْ فَجَاءُوا يُهَرْوِلُونَ فَقَالَ ‏"‏ يَا مَعْشَرَ الأَنْصَارِ هَلْ تَرَوْنَ أَوْبَاشَ قُرَيْشٍ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ انْظُرُوا إِذَا لَقِيتُمُوهُمْ غَدًا أَنْ تَحْصِدُوهُمْ حَصْدًا ‏"‏ ‏.‏ وَأَخْفَى بِيَدِهِ وَوَضَعَ يَمِينَهُ عَلَى شِمَالِهِ وَقَالَ ‏"‏ مَوْعِدُكُمُ الصَّفَا ‏"‏ ‏.‏ قَالَ فَمَا أَشْرَفَ يَوْمَئِذٍ لَهُمْ أَحَدٌ إِلاَّ أَنَامُوهُ - قَالَ - وَصَعِدَ رَسُولُ اللَّهِ صلى الله عليه وسلم الصَّفَا وَجَاءَتِ الأَنْصَارُ فَأَطَافُوا بِالصَّفَا فَجَاءَ أَبُو سُفْيَانَ فَقَالَ يَا رَسُولَ اللَّهِ أُبِيدَتْ خَضْرَاءُ قُرَيْشٍ لاَ قُرَيْشَ بَعْدَ الْيَوْمِ ‏.‏ قَالَ أَبُو سُفْيَانَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ دَخَلَ دَارَ أَبِي سُفْيَانَ فَهُوَ آمِنٌ وَمَنْ أَلْقَى السِّلاَحَ فَهُوَ آمِنٌ وَمَنْ أَغْلَقَ بَابَهُ فَهُوَ آمِنٌ ‏"‏ ‏.‏ فَقَالَتِ الأَنْصَارُ أَمَّا الرَّجُلُ فَقَدْ أَخَذَتْهُ رَأْفَةٌ بِعَشِيرَتِهِ وَرَغْبَةٌ فِي قَرْيَتِهِ ‏.‏ وَنَزَلَ الْوَحْىُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ قُلْتُمْ أَمَّا الرَّجُلُ فَقَدْ أَخَذَتْهُ رَأْفَةٌ بِعَشِيرَتِهِ وَرَغْبَةٌ فِي قَرْيَتِهِ ‏.‏ أَلاَ فَمَا اسْمِي إِذًا - ثَلاَثَ مَرَّاتٍ - أَنَا مُحَمَّدٌ عَبْدُ اللَّهِ وَرَسُولُهُ هَاجَرْتُ إِلَى اللَّهِ وَإِلَيْكُمْ فَالْمَحْيَا مَحْيَاكُمْ وَالْمَمَاتُ مَمَاتُكُمْ ‏"‏ ‏.‏ قَالُوا وَاللَّهِ مَا قُلْنَا إِلاَّ ضِنًّا بِاللَّهِ وَرَسُولِهِ ‏.‏ قَالَ ‏"‏ فَإِنَّ اللَّهَ وَرَسُولَهُ يُصَدِّقَانِكُمْ وَيَعْذِرَانِكُمْ ‏"‏ ‏.‏\hadithno{4624}\hadithtrans{It has been narrated on the authority of Abdullah b. Rabah who said:We came to Mu'awiya b. Abu Sufyan as a deputation and Abu Huraira was among us. Each of us would prepare food for his companions turn by turn for a day. (Accordingly) when it was my turn I said: Abu Huraira, it is my turn today. So they came to my place. The food was not yet ready, so I said to Abu Huraira: I wish you could narrate to us a tradition from the Messenger of Allah (ﷺ) until the food was ready. (Complying with my request) Abu Huraira said: We were with the Messenger of Allah (ﷺ) on the day of the Conquest of Mecca. He appointed Khalid b. Walid as commander of the right flank, Zubair as commander of the left flank, and Abu 'Ubaida as commander of the foot-soldiers (who were to advance) to the interior of the valley. He (then) said: Abu Huraira, call the Ansar to me. So I called out to them and they came hurriedly. He said: O ye Assembly of the Ansaar, do you see the ruffians of the Quraish? They said: Yes. He said: See, when you meet them tomorrow, wipe them out. He hinted at this with his hand, placing his right hand on his left and said: You will meet us at as-Safa'. (Abu Huraira continued): Whoever was seen by them that day was put to death. The Messenger of Allah (ﷺ) ascended the mount of as-Safa'. The Ansar also came there and surrounded the mount. Then came Abu Sufyan and said: Messenger ot Allah, the Quraish have perished. No member of the Quraish tribe will survive this day. The Messenger of Allah (ﷺ) said: Who enters the house of Abu Safyin will be safe, who lays down arms will be safe, who locks his door will be safe. (some of) the Ansar said: (After all) the man has been swayed by tenderness towards his family and love for his city. At this, Divine inspiration descended upon the Messenger of Allah (ﷺ). He said: You were saying that the man has been swayed by tenderness towards his family and love for his city. Do you know what my name is? I am Muhammad, the bondman of God and His Messenger. (He repeated this thrice.) I left my native place for the take of Allah and joined you. So I will live with you and die with you. Now the Ansar said: By God, we said (that) only out of our greed for Allah and His Messenger. He said: Allah and His Apostle testify to you and accept your apology}}
\hadithdefcmd{muslim}{4625}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَابْنُ أَبِي عُمَرَ، - وَاللَّفْظُ لاِبْنِ أَبِي شَيْبَةَ - قَالُوا حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ، قَالَ دَخَلَ النَّبِيُّ صلى الله عليه وسلم مَكَّةَ وَحَوْلَ الْكَعْبَةِ ثَلاَثُمِائَةٍ وَسِتُّونَ نُصُبًا فَجَعَلَ يَطْعُنُهَا بِعُودٍ كَانَ بِيَدِهِ وَيَقُولُ ‏"‏ ‏\{‏ جَاءَ الْحَقُّ وَزَهَقَ الْبَاطِلُ إِنَّ الْبَاطِلَ كَانَ زَهُوقًا‏\}‏ ‏\{‏ جَاءَ الْحَقُّ وَمَا يُبْدِئُ الْبَاطِلُ وَمَا يُعِيدُ‏\}‏ زَادَ ابْنُ أَبِي عُمَرَ يَوْمَ الْفَتْحِ ‏.‏\hadithno{4625}\hadithtrans{It has been narrated by Ibn Abdullah who said:The Prophet (ﷺ) entered Mecca. There were three hundred and sixty idols around the Ka'ba. He began to thrust them with the stick that was in his hand saying:" Truth has come and falsehood has vanished. Lo! falsehood was destined to vanish" (xvii. 8). Truth has arrived, and falsehood can neither create anything from the beginning nor can It restore to life}}
\hadithdefcmd{muslim}{4626}{وَحَدَّثَنَاهُ حَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، كِلاَهُمَا عَنْ عَبْدِ الرَّزَّاقِ، أَخْبَرَنَا الثَّوْرِيُّ، عَنِ ابْنِ أَبِي نَجِيحٍ، بِهَذَا الإِسْنَادِ إِلَى قَوْلِهِ زَهُوقًا ‏.‏ وَلَمْ يَذْكُرِ الآيَةَ الأُخْرَى وَقَالَ بَدَلَ نُصُبًا صَنَمًا ‏.‏\hadithno{4626}\hadithtrans{This tradition has been narrated by Ibn Abu Najah through a different chain of transmitters up to the word:Zahaqa, (This version) does not contain the second verse and substitutes Sanam for Nusub (both the words mean" idol" or" image" that is worshipped)}}
\hadithdefcmd{muslim}{4627}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، وَوَكِيعٌ، عَنْ زَكَرِيَّاءَ، عَنِ الشَّعْبِيِّ، قَالَ أَخْبَرَنِي عَبْدُ اللَّهِ بْنُ مُطِيعٍ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ يَوْمَ فَتْحِ مَكَّةَ ‏ "‏ لاَ يُقْتَلُ قُرَشِيٌّ صَبْرًا بَعْدَ هَذَا الْيَوْمِ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{4627}\hadithtrans{It has been narrated on the authority of Abdullah b. Muti' who heard from his father and said:I heard the Prophet (ﷺ) say on the day of the Conquest of Mecca: No Quraishite will be killed hound hand and foot from this day until the Day of judgment}}
\hadithdefcmd{muslim}{4628}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا زَكَرِيَّاءُ، بِهَذَا الإِسْنَادِ ‏.‏ وَزَادَ قَالَ وَلَمْ يَكُنْ أَسْلَمَ أَحَدٌ مِنْ عُصَاةِ قُرَيْشٍ غَيْرَ مُطِيعٍ كَانَ اسْمُهُ الْعَاصِي فَسَمَّاهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مُطِيعًا ‏.‏\hadithno{4628}\hadithtrans{The same tradition has been narrated on the authority of Zakriyya through the same chain of transmitters with the following addition:" No rebellious Quraishite with al-Asi as his name embraced Islam that day except Muti. His name-was al-Asi, but the Messenger of Allah (way peace be upon him) changed his name to Muti}}
\hadithdefcmd{muslim}{4629}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ، يَقُولُ كَتَبَ عَلِيُّ بْنُ أَبِي طَالِبٍ الصُّلْحَ بَيْنَ النَّبِيِّ صلى الله عليه وسلم وَبَيْنَ الْمُشْرِكِينَ يَوْمَ الْحُدَيْبِيَةِ فَكَتَبَ ‏"‏ هَذَا مَا كَاتَبَ عَلَيْهِ مُحَمَّدٌ رَسُولُ اللَّهِ‏"‏ ‏.‏ فَقَالُوا لاَ تَكْتُبْ رَسُولُ اللَّهِ فَلَوْ نَعْلَمُ أَنَّكَ رَسُولُ اللَّهِ لَمْ نُقَاتِلْكَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم لِعَلِيٍّ ‏"‏ امْحُهُ ‏"‏ ‏.‏ فَقَالَ مَا أَنَا بِالَّذِي أَمْحَاهُ ‏.‏ فَمَحَاهُ النَّبِيُّ صلى الله عليه وسلم بِيَدِهِ قَالَ وَكَانَ فِيمَا اشْتَرَطُوا أَنْ يَدْخُلُوا مَكَّةَ فَيُقِيمُوا بِهَا ثَلاَثًا وَلاَ يَدْخُلُهَا بِسِلاَحٍ إِلاَّ جُلُبَّانَ السِّلاَحِ ‏.‏ قُلْتُ لأَبِي إِسْحَاقَ وَمَا جُلُبَّانُ السِّلاَحِ قَالَ الْقِرَابُ وَمَا فِيهِ ‏.‏\hadithno{4629}\hadithtrans{It has been narrated on the authority of al-Bara' b. 'Azib who said:'Ali b. Abu Talib penned the treaty between the Prophet (ﷺ) and the polytheists on the Day of Hudaibiya. He wrote: This is what Muhammad, the Messenger of Allah, has settled. They (the polytheists) said: Do not write words" the Messenger of Allah". If we knew that you were the Messenger of Allah, we would not fight against you. The Prophet (ﷺ) said to 'Ali: Strike out these words. He (Ali) said: I am not going to strike them out. So the Prophet (ﷺ) struck them out with his own hand. The narrator said that the conditions upon which the two sides had agreed included that the Muslims would enter Mecca (next year) and would stay there for three days, and that they would not enter bearing arms except in their sheaths or bolsters}}
\hadithdefcmd{muslim}{4630}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ، يَقُولُ لَمَّا صَالَحَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَهْلَ الْحُدَيْبِيَةِ كَتَبَ عَلِيٌّ كِتَابًا بَيْنَهُمْ قَالَ فَكَتَبَ ‏"‏ مُحَمَّدٌ رَسُولُ اللَّهِ ‏"‏ ثُمَّ ذَكَرَ بِنَحْوِ حَدِيثِ مُعَاذٍ غَيْرَ أَنَّهُ لَمْ يَذْكُرْ فِي الْحَدِيثِ ‏"‏ هَذَا مَا كَاتَبَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{4630}\hadithtrans{It has been narrated on the authority of Abu Ishaq, who heard Bars' b. Azib say:When the Messenger of Allah (ﷺ) made peace with the people of Hudaibiya, 'Ali drew up the agreement between them, and so he wrote: Muhammad, the Messenger of Allah. (This is followed by the same wording as we have in the previous tradition except the omission of the words: This is what he has settled)}}
\hadithdefcmd{muslim}{4631}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَأَحْمَدُ بْنُ جَنَابٍ الْمِصِّيصِيُّ، جَمِيعًا عَنْ عِيسَى بْنِ يُونُسَ، - وَاللَّفْظُ لإِسْحَاقَ - أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، أَخْبَرَنَا زَكَرِيَّاءُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ لَمَّا أُحْصِرَ النَّبِيُّ صلى الله عليه وسلم عِنْدَ الْبَيْتِ صَالَحَهُ أَهْلُ مَكَّةَ عَلَى أَنْ يَدْخُلَهَا فَيُقِيمَ بِهَا ثَلاَثًا وَلاَ يَدْخُلَهَا إِلاَّ بِجُلُبَّانِ السِّلاَحِ السَّيْفِ وَقِرَابِهِ ‏.‏ وَلاَ يَخْرُجَ بِأَحَدٍ مَعَهُ مِنْ أَهْلِهَا وَلاَ يَمْنَعَ أَحَدًا يَمْكُثُ بِهَا مِمَّنْ كَانَ مَعَهُ ‏.‏ قَالَ لِعَلِيٍّ ‏"‏ اكْتُبِ الشَّرْطَ بَيْنَنَا بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ هَذَا مَا قَاضَى عَلَيْهِ مُحَمَّدٌ رَسُولُ اللَّهِ ‏"‏ ‏.‏ فَقَالَ لَهُ الْمُشْرِكُونَ لَوْ نَعْلَمُ أَنَّكَ رَسُولُ اللَّهِ تَابَعْنَاكَ وَلَكِنِ اكْتُبْ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ ‏.‏ فَأَمَرَ عَلِيًّا أَنْ يَمْحَاهَا فَقَالَ عَلِيٌّ لاَ وَاللَّهِ لاَ أَمْحَاهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرِنِي مَكَانَهَا ‏"‏ ‏.‏ فَأَرَاهُ مَكَانَهَا فَمَحَاهَا وَكَتَبَ ‏"‏ ابْنُ عَبْدِ اللَّهِ ‏"‏ ‏.‏ فَأَقَامَ بِهَا ثَلاَثَةَ أَيَّامٍ فَلَمَّا أَنْ كَانَ يَوْمُ الثَّالِثِ قَالُوا لِعَلِيٍّ هَذَا آخِرُ يَوْمٍ مِنْ شَرْطِ صَاحِبِكَ فَأْمُرْهُ فَلْيَخْرُجْ ‏.‏ فَأَخْبَرَهُ بِذَلِكَ فَقَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَخَرَجَ ‏.‏ وَقَالَ ابْنُ جَنَابٍ فِي رِوَايَتِهِ مَكَانَ تَابَعْنَاكَ بَايَعْنَاكَ ‏.‏\hadithno{4631}\hadithtrans{It has been narrated on the authority of Bara' who said:When the Prophet (ﷺ) was checked from going to the Ka'ba, the people of Mecca made peace with him'on the condition that he would (be allowed to) enter Mecca (next year) and stay there for three days, that he would not enter (the city) except with swords in their sheaths and arms encased in their covers, that he would not take eway with him anyone from its dwellers, nor would he prevent anyone from those with him to stay on in Mecca (if he so desired). He said to 'Ali: Write down the terms settled between us. (So 'Ali wrote): In the name of Allah, most Gracious and most Merciful. This is what Muhammad, the Messenger of Allah, has settled (with the Meccans), The polytheists said to him: If we knew that thou art the Messenger of of Allah, we would follow you. But write: Muhammad b. 'Abdullah. So he told 'Ali to strike out these words. 'Ali said: No, by Allah, I will not strike them out. The Messenger of Allah (may Peace be upon him) said: Show me their place (on the parchment). So he ('Ali) showed him their place and he (the Holy Prophet) struck them out; and 'Ali wrote: Ibn 'Abdullah. (According to the terms of the treaty, next year) the Prophet (ﷺ) stayed there for three days When it was the third day, they said to 'Ali: This is the last day according to the terms of your companion. So tell him to leave. 'Ali informed the Prophet (ﷺ) accordingly. He said: Yes, and left (the city). Ibn Janab in his version of the tradition used:" we would swear allegiance to you" instead of" we would follow you}}
\hadithdefcmd{muslim}{4632}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ قُرَيْشًا، صَالَحُوا النَّبِيَّ صلى الله عليه وسلم فِيهِمْ سُهَيْلُ بْنُ عَمْرٍو فَقَالَ النَّبِيُّ صلى الله عليه وسلم لِعَلِيٍّ ‏"‏ اكْتُبْ بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ ‏"‏ ‏.‏ قَالَ سُهَيْلٌ أَمَّا بِاسْمِ اللَّهِ فَمَا نَدْرِي مَا بِسْمِ اللَّهِ الرَّحْمَنِ الرَّحِيمِ وَلَكِنِ اكْتُبْ مَا نَعْرِفُ بِاسْمِكَ اللَّهُمَّ فَقَالَ ‏"‏ اكْتُبْ مِنْ مُحَمَّدٍ رَسُولِ اللَّهِ ‏"‏ ‏.‏ قَالُوا لَوْ عَلِمْنَا أَنَّكَ رَسُولُ اللَّهِ لاَتَّبَعْنَاكَ وَلَكِنِ اكْتُبِ اسْمَكَ وَاسْمَ أَبِيكَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اكْتُبْ مِنْ مُحَمَّدِ بْنِ عَبْدِ اللَّهِ ‏"‏ ‏.‏ فَاشْتَرَطُوا عَلَى النَّبِيِّ صلى الله عليه وسلم أَنَّ مَنْ جَاءَ مِنْكُمْ لَمْ نَرُدَّهُ عَلَيْكُمْ وَمَنْ جَاءَكُمْ مِنَّا رَدَدْتُمُوهُ عَلَيْنَا فَقَالُوا يَا رَسُولَ اللَّهِ أَنَكْتُبُ هَذَا قَالَ ‏"‏ نَعَمْ إِنَّهُ مَنْ ذَهَبَ مِنَّا إِلَيْهِمْ فَأَبْعَدَهُ اللَّهُ وَمَنْ جَاءَنَا مِنْهُمْ سَيَجْعَلُ اللَّهُ لَهُ فَرَجًا وَمَخْرَجًا ‏"‏ ‏.‏\hadithno{4632}\hadithtrans{It has been narrated on the authority of Anas that the Quraish made peace with the Prophet (ﷺ). Among them was Suhail b. Amr. The Prophet (ﷺ) said to 'Ali:Write" In the name of Allah, most Gracious and most Merciful." Suhail said: As for" Bismillah," we do not know what is meant by" Bismillah-ir-Rahman-ir-Rahim" (In the name of Allah most Gracious and most Merciful). But write what we understand, i. e. Bi ismika allahumma (in thy name. O Allah). Then, the Prophet (ﷺ) said: Write:" From Muhammad, the Messenger of Allah." They said: If we knew that thou welt the Messenger of Allah, we would follow you. Therefore, write your name and the name of your father. So the Prophet (ﷺ) said: Write" From Muhammad b. 'Abdullah." They laid the condition on the Prophet (ﷺ) that anyone who joined them from the Muslims, the Meccans would not return him, and anyone who joined you (the Muslims) from them, you would send him back to them. The Companions said: Messenger of Allah, should we write this? He said: Yes. One who goes away from us to join them-may Allah keep him away! and one who comes to join us from them (and is sent back) Allah will provide him relief and a way of escape}}
\hadithdefcmd{muslim}{4633}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، - وَتَقَارَبَا فِي اللَّفْظِ - حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ سِيَاهٍ، حَدَّثَنَا حَبِيبُ بْنُ أَبِي ثَابِتٍ، عَنْ أَبِي وَائِلٍ، قَالَ قَامَ سَهْلُ بْنُ حُنَيْفٍ يَوْمَ صِفِّينَ فَقَالَ أَيُّهَا النَّاسُ اتَّهِمُوا أَنْفُسَكُمْ لَقَدْ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ الْحُدَيْبِيَةِ وَلَوْ نَرَى قِتَالاً لَقَاتَلْنَا وَذَلِكَ فِي الصُّلْحِ الَّذِي كَانَ بَيْنَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَبَيْنَ الْمُشْرِكِينَ فَجَاءَ عُمَرُ بْنُ الْخَطَّابِ فَأَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَلَسْنَا عَلَى حَقٍّ وَهُمْ عَلَى بَاطِلٍ قَالَ ‏"‏ بَلَى ‏"‏ ‏.‏ قَالَ أَلَيْسَ قَتْلاَنَا فِي الْجَنَّةِ وَقَتْلاَهُمْ فِي النَّارِ قَالَ ‏"‏ بَلَى ‏"‏ ‏.‏ قَالَ فَفِيمَ نُعْطِي الدَّنِيَّةَ فِي دِينِنَا وَنَرْجِعُ وَلَمَّا يَحْكُمِ اللَّهُ بَيْنَنَا وَبَيْنَهُمْ فَقَالَ ‏"‏ يَا ابْنَ الْخَطَّابِ إِنِّي رَسُولُ اللَّهِ وَلَنْ يُضَيِّعَنِي اللَّهُ أَبَدًا ‏"‏ ‏.‏ قَالَ فَانْطَلَقَ عُمَرُ فَلَمْ يَصْبِرْ مُتَغَيِّظًا فَأَتَى أَبَا بَكْرٍ فَقَالَ يَا أَبَا بَكْرٍ أَلَسْنَا عَلَى حَقٍّ وَهُمْ عَلَى بَاطِلٍ قَالَ بَلَى ‏.‏ قَالَ أَلَيْسَ قَتْلاَنَا فِي الْجَنَّةِ وَقَتْلاَهُمْ فِي النَّارِ قَالَ بَلَى ‏.‏ قَالَ فَعَلاَمَ نُعْطِي الدَّنِيَّةَ فِي دِينِنَا وَنَرْجِعُ وَلَمَّا يَحْكُمِ اللَّهُ بَيْنَنَا وَبَيْنَهُمْ فَقَالَ يَا ابْنَ الْخَطَّابِ إِنَّهُ رَسُولُ اللَّهِ وَلَنْ يُضَيِّعَهُ اللَّهُ أَبَدًا ‏.‏ قَالَ فَنَزَلَ الْقُرْآنُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْفَتْحِ فَأَرْسَلَ إِلَى عُمَرَ فَأَقْرَأَهُ إِيَّاهُ فَقَالَ يَا رَسُولَ اللَّهِ أَوَفَتْحٌ هُوَ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ فَطَابَتْ نَفْسُهُ وَرَجَعَ ‏.‏\hadithno{4633}\hadithtrans{It has been narrated on the authority of Abu Wa'il who said:Sahal b. Hunaif stood up on the Day of Siffin and said: O ye people, blame yourselves (for want of discretion) ; we were with the Messenger of Allah (ﷺ) on the Day of Hudaibiya. If we had thought it fit to fight, we could fight. This was in the truce between the Messenger of Allah (ﷺ) and the polytheists. Umar b. Khattab came, approached the Messenger of Allah (ﷺ) and said: Messenger of Allah, aren't we fighting for truth and they for falsehood? He replied: By all means. He asked: Are not those killed from our side in Paradise and those killed. from their side in the Fire? He replied: Yes. He said: Then why should we put a blot upon our religion and return, while Allah has not decided the issue between them and ourselves? He said: Son of Khattab, I am the Messenger of Allah. Allah will never ruin me. (The narrator said): Umar went away, but he could not contain himself with rage. So he approached Abu Bakr and said: 'Abu Bakr, aren't we fighting for truth and they for falsehood? He replied: Yes. He asked: Aren't those killed from our side in Paradise and those killed from their side in the Fire? He replied: Why not? He (then) said: Why should we then disgrace our religion and return while God has not yet decided the issue between them and ourselves? Abu Bakr said: Son of Khattab, verily, he is the Messenger of Allah, and Allah will never ruin him. (The narrator continued): At this (a Sura of) the Qur'an (giving glad tidings of the victory) was revealed to the Messenger of Allah (ﷺ). He sent for Umar and made him read it. He asked: Is (this truce) a victory? He (the Messenger of Allah) replied: Yes. At this Umar was pleased, and returned}}
\hadithdefcmd{muslim}{4634}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، قَالَ سَمِعْتُ سَهْلَ بْنَ حُنَيْفٍ، يَقُولُ بِصِفِّينَ أَيُّهَا النَّاسُ اتَّهِمُوا رَأْيَكُمْ وَاللَّهِ لَقَدْ رَأَيْتُنِي يَوْمَ أَبِي جَنْدَلٍ وَلَوْ أَنِّي أَسْتَطِيعُ أَنْ أَرُدَّ أَمْرَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَرَدَدْتُهُ وَاللَّهِ مَا وَضَعْنَا سُيُوفَنَا عَلَى عَوَاتِقِنَا إِلَى أَمْرٍ قَطُّ إِلاَّ أَسْهَلْنَ بِنَا إِلَى أَمْرٍ نَعْرِفُهُ إِلاَّ أَمْرَكُمْ هَذَا ‏.‏ لَمْ يَذْكُرِ ابْنُ نُمَيْرٍ إِلَى أَمْرٍ قَطُّ ‏.‏\hadithno{4634}\hadithtrans{It has been narrated on the authority of Shaqiq who said:I heard Sahl b. Hunaif say at Siffin: O ye people, find fault with your (own) discretion. By Allah, on the Day of Abu Jandal (i. e. the day of Hudaibiya), I thought to myself that, if I could, I would reverse the order of the Messenger of Allah (ﷺ) (the terms of the truce being unpalatable). By Allah, we have never hung our swords on our shoulders in any situation whatsoever except when they made easy for us to realise the goal envisaged by us, but this battle of yours (seems to be an exception). Ibn Numair (in his version) did not mention the words:" In any situation whatsoever}}
\hadithdefcmd{muslim}{4635}{وَحَدَّثَنَاهُ عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ، جَمِيعًا عَنْ جَرِيرٍ، ح وَحَدَّثَنِي أَبُو سَعِيدٍ، الأَشَجُّ حَدَّثَنَا وَكِيعٌ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِهِمَا إِلَى أَمْرٍ يُفْظِعُنَا.‏\hadithno{4635}\hadithtrans{The same tradition has been narrated through a different chain of transmitters on the authority of A'mash. This version contains the words:Ila amrin yofzi'una instead of Ila amrin na'rifuhu}}
\hadithdefcmd{muslim}{4636}{وَحَدَّثَنِي إِبْرَاهِيمُ بْنُ سَعِيدٍ الْجَوْهَرِيُّ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ مَالِكِ بْنِ مِغْوَلٍ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي وَائِلٍ، قَالَ سَمِعْتُ سَهْلَ بْنَ حُنَيْفٍ، بِصِفِّينَ يَقُولُ اتَّهِمُوا رَأْيَكُمْ عَلَى دِينِكُمْ فَلَقَدْ رَأَيْتُنِي يَوْمَ أَبِي جَنْدَلٍ وَلَوْ أَسْتَطِيعُ أَنْ أَرُدَّ أَمْرَ رَسُولِ اللَّهِ صلى الله عليه وسلم - مَا فَتَحْنَا مِنْهُ فِي خُصْمٍ إِلاَّ انْفَجَرَ عَلَيْنَا مِنْهُ خُصْمٌ ‏.‏\hadithno{4636}\hadithtrans{It has been narrated through a different chain of transmitters on the authority of Abu Wa'il who said:I heard Sahl b. Hunaif say at Siffin: Blame (the hollowness) of your views about your religion. I thought to myself on the day of Abu Jandal that if I could turn down the order of the Messenger of Allah (ﷺ), I would. The situation was so difficult that if we mended it at one place, it was rent at another}}
\hadithdefcmd{muslim}{4637}{وَحَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي، عَرُوبَةَ عَنْ قَتَادَةَ، أَنَّ أَنَسَ بْنَ مَالِكٍ، حَدَّثَهُمْ قَالَ لَمَّا نَزَلَتْ ‏\{‏ إِنَّا فَتَحْنَا لَكَ فَتْحًا مُبِينًا * لِيَغْفِرَ لَكَ اللَّهُ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ فَوْزًا عَظِيمًا‏\}‏ مَرْجِعَهُ مِنَ الْحُدَيْبِيَةِ وَهُمْ يُخَالِطُهُمُ الْحُزْنُ وَالْكَآبَةُ وَقَدْ نَحَرَ الْهَدْىَ بِالْحُدَيْبِيَةِ فَقَالَ ‏"‏ لَقَدْ أُنْزِلَتْ عَلَىَّ آيَةٌ هِيَ أَحَبُّ إِلَىَّ مِنَ الدُّنْيَا جَمِيعًا ‏"‏ ‏.‏\hadithno{4637}\hadithtrans{It has been narrated on the authority of Anas b. Malik who said:When they (Companions of the Holy Prophet) were overwhelmed with grief and distress on his return from Hudaibiya where he had slaughtered his sacrificial beasts (not being allowed to proceed to Mecca), the Qur'anic verse: Inna fatahna... laka fathan mobinan to fauzan 'aziman, was revealed to him. (At this) he said: On me has descended a verse that is dearer to me than the whole world}}
\hadithdefcmd{muslim}{4638}{وَحَدَّثَنَا عَاصِمُ بْنُ النَّضْرِ التَّيْمِيُّ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي، حَدَّثَنَا قَتَادَةُ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا هَمَّامٌ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، جَمِيعًا عَنْ قَتَادَةَ، عَنْ أَنَسٍ، نَحْوَ حَدِيثِ ابْنِ أَبِي عَرُوبَةَ ‏.‏\hadithno{4638}\hadithtrans{This tradition has been narrated through a different chain of transmitters}}
\hadithdefcmd{muslim}{4639}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ جُمَيْعٍ، حَدَّثَنَا أَبُو الطُّفَيْلِ حَدَّثَنَا حُذَيْفَةُ بْنُ الْيَمَانِ، قَالَ مَا مَنَعَنِي أَنْ أَشْهَدَ، بَدْرًا إِلاَّ أَنِّي خَرَجْتُ أَنَا وَأَبِي - حُسَيْلٌ - قَالَ فَأَخَذَنَا كُفَّارُ قُرَيْشٍ قَالُوا إِنَّكُمْ تُرِيدُونَ مُحَمَّدًا فَقُلْنَا مَا نُرِيدُهُ مَا نُرِيدُ إِلاَّ الْمَدِينَةَ ‏.‏ فَأَخَذُوا مِنَّا عَهْدَ اللَّهِ وَمِيثَاقَهُ لَنَنْصَرِفَنَّ إِلَى الْمَدِينَةِ وَلاَ نُقَاتِلُ مَعَهُ فَأَتَيْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبَرْنَاهُ الْخَبَرَ فَقَالَ ‏ "‏ انْصَرِفَا نَفِي لَهُمْ بِعَهْدِهِمْ وَنَسْتَعِينُ اللَّهَ عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{4639}\hadithtrans{It has been reported on the authority of Hudbaifa b. al-Yaman who said:Nothing prevented me from being present at! he Battle of Badr except this incident. I came out with my father Husail (to participate in the Battle), but we were caught by the disbelievers of Quraish. They said: (Do) you intend to go to Muhammad? We said: We do not intend to go to him, but we wish to go (back) to Medina. So they took from us a covenant in the name of God that we would turn back to Medina and would not fight on the side of Muhammad (ﷺ). So, we came to the Messenger of Allah (ﷺ) and related the incident to him. He said: Both, of you proceed (to Medina) ; we will fulfil the covenant made with them and seek God's help against them}}
\hadithdefcmd{muslim}{4640}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنْ جَرِيرٍ، قَالَ زُهَيْرٌ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ التَّيْمِيِّ، عَنْ أَبِيهِ، قَالَ كُنَّا عِنْدَ حُذَيْفَةَ فَقَالَ رَجُلٌ لَوْ أَدْرَكْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَاتَلْتُ مَعَهُ وَأَبْلَيْتُ فَقَالَ حُذَيْفَةُ أَنْتَ كُنْتَ تَفْعَلُ ذَلِكَ لَقَدْ رَأَيْتُنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم لَيْلَةَ الأَحْزَابِ وَأَخَذَتْنَا رِيحٌ شَدِيدَةٌ وَقُرٌّ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلاَ رَجُلٌ يَأْتِينِي بِخَبَرِ الْقَوْمِ جَعَلَهُ اللَّهُ مَعِي يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ فَسَكَتْنَا فَلَمْ يُجِبْهُ مِنَّا أَحَدٌ ثُمَّ قَالَ ‏"‏ أَلاَ رَجُلٌ يَأْتِينَا بِخَبَرِ الْقَوْمِ جَعَلَهُ اللَّهُ مَعِي يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ فَسَكَتْنَا فَلَمْ يُجِبْهُ مِنَّا أَحَدٌ ثُمَّ قَالَ ‏"‏ أَلاَ رَجُلٌ يَأْتِينَا بِخَبَرِ الْقَوْمِ جَعَلَهُ اللَّهُ مَعِي يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ فَسَكَتْنَا فَلَمْ يُجِبْهُ مِنَّا أَحَدٌ فَقَالَ ‏"‏ قُمْ يَا حُذَيْفَةُ فَأْتِنَا بِخَبَرِ الْقَوْمِ ‏"‏ ‏.‏ فَلَمْ أَجِدْ بُدًّا إِذْ دَعَانِي بِاسْمِي أَنْ أَقُومَ قَالَ ‏"‏ اذْهَبْ فَأْتِنِي بِخَبَرِ الْقَوْمِ وَلاَ تَذْعَرْهُمْ عَلَىَّ ‏"‏ ‏.‏ فَلَمَّا وَلَّيْتُ مِنْ عِنْدِهِ جَعَلْتُ كَأَنَّمَا أَمْشِي فِي حَمَّامٍ حَتَّى أَتَيْتُهُمْ فَرَأَيْتُ أَبَا سُفْيَانَ يَصْلِي ظَهْرَهُ بِالنَّارِ فَوَضَعْتُ سَهْمًا فِي كَبِدِ الْقَوْسِ فَأَرَدْتُ أَنْ أَرْمِيَهُ فَذَكَرْتُ قَوْلَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ وَلاَ تَذْعَرْهُمْ عَلَىَّ ‏"‏ ‏.‏ وَلَوْ رَمَيْتُهُ لأَصَبْتُهُ فَرَجَعْتُ وَأَنَا أَمْشِي فِي مِثْلِ الْحَمَّامِ فَلَمَّا أَتَيْتُهُ فَأَخْبَرْتُهُ بِخَبَرِ الْقَوْمِ وَفَرَغْتُ قُرِرْتُ فَأَلْبَسَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ فَضْلِ عَبَاءَةٍ كَانَتْ عَلَيْهِ يُصَلِّي فِيهَا فَلَمْ أَزَلْ نَائِمًا حَتَّى أَصْبَحْتُ فَلَمَّا أَصْبَحْتُ قَالَ ‏"‏ قُمْ يَا نَوْمَانُ ‏"‏ ‏.‏\hadithno{4640}\hadithtrans{It has been narrated by Ibrahim al-Taimi on the authority of his father who said:We were sitting in the company of Hudhaifa. A man said: If I were in the time of the Messenger of Allah (ﷺ), I would have fought by his side and would have striven hard for his causes. Hudhaifa said: You might have done that, (but you should not make a flourish of your enthusiasm). I was with the Messenger of Allah (ﷺ) on the night of the Battle of Abzib and we were gripped by a violent wind and severe cold. The Messenger of Allah (may peace be him) said: Hark, the man who (goes reconnoitring and) brings me the news of the enemy shall be ranked with me on the Day of Judgment by Allah (the Glorious and Exalted). We all kept quiet and none of us responed to him. (Again) he said: Hark, a man who (goes reconnoitring and) brings me the news of the enemy shall be ranked with me on the Day of Judgment by Allah (the Glorious and Exalted). We kept quiet and none of us responded to him. He again said: Hark, a man who (goes reconnoitring and) brings me the news of the enemy shall be ranked with me on the Day of Judgtuent by Allah (the Glorious and Exalted) Then he said: Get up Hudhaifa, bring me the news of the enemy. When he called me by name I had no alternative but to get up. He said: Go and bring me information about the enemy, and do nothing that may provoke them against me. When I left him, I felt warm as if I were walking in a heated bath untill I reached them. I saw Abu Sufyan warming his back against fire I put an arrow in the middle of the bow. intending to shoot at him, when I recalled the words of the Messenger of Allah (ﷺ)" Do not provoke them against me." Had I shot at him, I would have hit him. But I returned and (felt warm as if) I were walking in a heated bath (hammam). Presenting myself before him, I gave him information about the enemy. When I had done so, I began to feel cold, so the Messenger of Allah (ﷺ) wrapped me in a blanket that he had in excess to his own requirement and with which he used to cover himself while saying his prayers. So I continued to sleep until it was morning. When it was morning he said: Get up, O heavy sleeper}}
\hadithdefcmd{muslim}{4641}{وَحَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ الأَزْدِيُّ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ عَلِيِّ بْنِ زَيْدٍ، وَثَابِتٍ، الْبُنَانِيِّ عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُفْرِدَ يَوْمَ أُحُدٍ فِي سَبْعَةٍ مِنَ الأَنْصَارِ وَرَجُلَيْنِ مِنْ قُرَيْشٍ فَلَمَّا رَهِقُوهُ قَالَ ‏"‏ مَنْ يَرُدُّهُمْ عَنَّا وَلَهُ الْجَنَّةُ أَوْ هُوَ رَفِيقِي فِي الْجَنَّةِ ‏"‏ ‏.‏ فَتَقَدَّمَ رَجُلٌ مِنَ الأَنْصَارِ فَقَاتَلَ حَتَّى قُتِلَ ثُمَّ رَهِقُوهُ أَيْضًا فَقَالَ ‏"‏ مَنْ يَرُدُّهُمْ عَنَّا وَلَهُ الْجَنَّةُ أَوْ هُوَ رَفِيقِي فِي الْجَنَّةِ ‏"‏ ‏.‏ فَتَقَدَّمَ رَجُلٌ مِنَ الأَنْصَارِ فَقَاتَلَ حَتَّى قُتِلَ فَلَمْ يَزَلْ كَذَلِكَ حَتَّى قُتِلَ السَّبْعَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِصَاحِبَيْهِ ‏"‏ مَا أَنْصَفْنَا أَصْحَابَنَا ‏"‏ ‏.‏\hadithno{4641}\hadithtrans{It has been reported on the authority of Anas b. Malik that (when the enemy got the upper hand) on the day of the Battle of Uhud, the Messenger of Allah (ﷺ) was left with only seven men from the ansar and two men from the Quraish. When the enemy advanced towards him and overwhelmed him, he said:Whoso turns them away from us will attain Paradise or will be my Companion in Paradise. A man from the Ansar came forward and fought (the enemy) until he was killed. The enemy advanced and overwhelmed him again and he repeated the words: Whoso turns them away, from us will attain Paradise or will be my Companion in Paradise. A man from the Arsar came forward and fought until he was killed. This state continued until the seven Ansar were killed (one after the other). Now, the Messenger of Allah (ﷺ) said to his two Companions: We have not done justice to our Companions}}
\hadithdefcmd{muslim}{4642}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، أَنَّهُ سَمِعَ سَهْلَ بْنَ سَعْدٍ، يُسْأَلُ عَنْ جُرْحِ، رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ أُحُدٍ فَقَالَ جُرِحَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم وَكُسِرَتْ رَبَاعِيَتُهُ وَهُشِمَتِ الْبَيْضَةُ عَلَى رَأْسِهِ فَكَانَتْ فَاطِمَةُ بِنْتُ رَسُولِ اللَّهِ صلى الله عليه وسلم تَغْسِلُ الدَّمَ وَكَانَ عَلِيُّ بْنُ أَبِي طَالِبٍ يَسْكُبُ عَلَيْهَا بِالْمِجَنِّ فَلَمَّا رَأَتْ فَاطِمَةُ أَنَّ الْمَاءَ لاَ يَزِيدُ الدَّمَ إِلاَّ كَثْرَةً أَخَذَتْ قِطْعَةَ حَصِيرٍ فَأَحْرَقَتْهُ حَتَّى صَارَ رَمَادًا ثُمَّ أَلْصَقَتْهُ بِالْجُرْحِ فَاسْتَمْسَكَ الدَّمُ ‏.‏\hadithno{4642}\hadithtrans{It has been narrated on the authority of Abd-ul-'Aziz b. Abu Hazim, who learnt from his father (Abu Hazim). The latter heard it from Sahl b. Sa'd who was asked about the injury which the Messenger of Allah (ﷺ) got on the day of the Battle of Uhud. He said:The face of the Messenger of Allah (ﷺ) was injured, his front teeth were damaged and his helmet was crushed. Fatima, the daughter of the Messenger of Allah (ﷺ), was washing the blood (from his head), and 'Ali b. Abu Talib was pouring water on it from a shield. When Fatima saw that the bleeding had increased on account of (pouring) water (on the wound), she took a piece of mat and burnt it until it was reduced to ashes. She put the ashes on the wound and the bleeding stopped}}
\hadithdefcmd{muslim}{4643}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنْ أَبِي حَازِمٍ، أَنَّهُ سَمِعَ سَهْلَ بْنَ سَعْدٍ، وَهُوَ يُسْأَلُ عَنْ جُرْحِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَمَ وَاللَّهِ إِنِّي لأَعْرِفُ مَنْ كَانَ يَغْسِلُ جُرْحَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَمَنْ كَانَ يَسْكُبُ الْمَاءَ ‏.‏ وَبِمَاذَا دُووِيَ جُرْحُهُ ‏.‏ ثُمَّ ذَكَرَ نَحْوَ حَدِيثِ عَبْدِ الْعَزِيزِ غَيْرَ أَنَّهُ زَادَ وَجُرِحَ وَجْهُهُ وَقَالَ مَكَانَ هُشِمَتْ كُسِرَتْ ‏.‏\hadithno{4643}\hadithtrans{It has been reported on the authority of Abu Hazim who heard from Sahl b. Sa'd. The latter was asked about the injury of the Messenger of Allah (ﷺ). He said:By God, I know the person who washed the wound of the Messenger of Allah (ﷺ), who poured water on it and with what the wound was treated. Then Sahl narrated the same tradition as has been narrated by 'Abd al-'Azlz except that he added the words:" And his face was injured" and replaced the word" Hushimat" by" Kusirat" (i. e. it was broken)}}
\hadithdefcmd{muslim}{4644}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ، أَبِي عُمَرَ جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، ح وَحَدَّثَنَا عَمْرُو بْنُ سَوَّادٍ الْعَامِرِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ، وَهْبٍ أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ سَهْلٍ التَّمِيمِيُّ، حَدَّثَنِي ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ مُطَرِّفٍ - كُلُّهُمْ عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ، بْنِ سَعْدٍ ‏.‏ بِهَذَا الْحَدِيثِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ فِي حَدِيثِ ابْنِ أَبِي هِلاَلٍ أُصِيبَ وَجْهُهُ ‏.‏ وَفِي حَدِيثِ ابْنِ مُطَرِّفٍ جُرِحَ وَجْهُهُ ‏.‏\hadithno{4644}\hadithtrans{The same tradition has been narrated on the authority of Sahl b. Sa'd through a different chain of transmitters with a slight difference in the wording}}
\hadithdefcmd{muslim}{4645}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كُسِرَتْ رَبَاعِيَتُهُ يَوْمَ أُحُدٍ وَشُجَّ فِي رَأْسِهِ فَجَعَلَ يَسْلُتُ الدَّمَ عَنْهُ وَيَقُولُ ‏"‏ كَيْفَ يُفْلِحُ قَوْمٌ شَجُّوا نَبِيَّهُمْ وَكَسَرُوا رَبَاعِيَتَهُ وَهُوَ يَدْعُوهُمْ إِلَى اللَّهِ ‏"‏ ‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ لَيْسَ لَكَ مِنَ الأَمْرِ شَىْءٌ‏\}‏\hadithno{4645}\hadithtrans{It has been narrated on the authority of Anas that the Messenger of Allah (ﷺ) had his front teeth damaged on the day of the Battle of Uhud, and got a wound on his head. He was wiping the blood (from his face) and was saying:How will these people attain salvation who have wounded their Prophet and broken his tooth while he called them towards God? At this time, God, the Exalted and Glorious, revealed the Verse:" Thou hast no authority" (iii)}}
\hadithdefcmd{muslim}{4646}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كَأَنِّي أَنْظُرُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يَحْكِي نَبِيًّا مِنَ الأَنْبِيَاءِ ضَرَبَهُ قَوْمُهُ وَهُوَ يَمْسَحُ الدَّمَ عَنْ وَجْهِهِ وَيَقُولُ ‏ "‏ رَبِّ اغْفِرْ لِقَوْمِي فَإِنَّهُمْ لاَ يَعْلَمُونَ ‏"‏ ‏.‏\hadithno{4646}\hadithtrans{It has been narrated on the authority of 'Abdullah who said:It appeared to me as if I saw the Messenger of Allah (ﷺ) (and heard him) relate the story of a Prophet who had been beaten by his people, was wiping the blood from his face and was saying. My Lord, forgive my people, for they do not know}}
\hadithdefcmd{muslim}{4647}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، وَمُحَمَّدُ بْنُ بِشْرٍ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ فَهُوَ يَنْضِحُ الدَّمَ عَنْ جَبِينِهِ ‏.‏\hadithno{4647}\hadithtrans{A version of the tradition with a slightly different wording has been narrated by another chain of transmitters}}
\hadithdefcmd{muslim}{4648}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اشْتَدَّ غَضَبُ اللَّهِ عَلَى قَوْمٍ فَعَلُوا هَذَا بِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ ‏.‏ وَهُوَ حِينَئِذٍ يُشِيرُ إِلَى رَبَاعِيَتِهِ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اشْتَدَّ غَضَبُ اللَّهِ عَلَى رَجُلٍ يَقْتُلُهُ رَسُولُ اللَّهِ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4648}\hadithtrans{It has been narrated by Hammam b. Munabbih who said:This is what has been related to us by Abu Huraira from the Messenger of Allah (ﷺ). (With this introduction) he narrated a number of traditions. One of these was that the Messenger of Allah (ﷺ) said: Great is the wrath of Allah upon a people who have done this to the Messenger of Allah (ﷺ), and he was at that time pointing to his front teeth. The Messenger of Allah (ﷺ) also said: Great is the wrath of Allah upon a person who has been killed by the Messenger of Allah (ﷺ) in the way of Allah, the Exalted and Glorious}}
\hadithdefcmd{muslim}{4649}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ بْنِ مُحَمَّدِ بْنِ أَبَانَ الْجُعْفِيُّ، حَدَّثَنَا عَبْدُ الرَّحِيمِ، - يَعْنِي ابْنَ سُلَيْمَانَ - عَنْ زَكَرِيَّاءَ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ الأَوْدِيِّ، عَنِ ابْنِ مَسْعُودٍ، قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي عِنْدَ الْبَيْتِ وَأَبُو جَهْلٍ وَأَصْحَابٌ لَهُ جُلُوسٌ وَقَدْ نُحِرَتْ جَزُورٌ بِالأَمْسِ فَقَالَ أَبُو جَهْلٍ أَيُّكُمْ يَقُومُ إِلَى سَلاَ جَزُورِ بَنِي فُلاَنٍ فَيَأْخُذُهُ فَيَضَعُهُ فِي كَتِفَىْ مُحَمَّدٍ إِذَا سَجَدَ فَانْبَعَثَ أَشْقَى الْقَوْمِ فَأَخَذَهُ فَلَمَّا سَجَدَ النَّبِيُّ صلى الله عليه وسلم وَضَعَهُ بَيْنَ كَتِفَيْهِ قَالَ فَاسْتَضْحَكُوا وَجَعَلَ بَعْضُهُمْ يَمِيلُ عَلَى بَعْضٍ وَأَنَا قَائِمٌ أَنْظُرُ ‏.‏ لَوْ كَانَتْ لِي مَنَعَةٌ طَرَحْتُهُ عَنْ ظَهْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَالنَّبِيُّ صلى الله عليه وسلم سَاجِدٌ مَا يَرْفَعُ رَأْسَهُ حَتَّى انْطَلَقَ إِنْسَانٌ فَأَخْبَرَ فَاطِمَةَ فَجَاءَتْ وَهِيَ جُوَيْرِيَةُ فَطَرَحَتْهُ عَنْهُ ‏.‏ ثُمَّ أَقْبَلَتْ عَلَيْهِمْ تَشْتِمُهُمْ فَلَمَّا قَضَى النَّبِيُّ صلى الله عليه وسلم صَلاَتَهُ رَفَعَ صَوْتَهُ ثُمَّ دَعَا عَلَيْهِمْ وَكَانَ إِذَا دَعَا دَعَا ثَلاَثًا ‏.‏ وَإِذَا سَأَلَ سَأَلَ ثَلاَثًا ثُمَّ قَالَ ‏"‏ اللَّهُمَّ عَلَيْكَ بِقُرَيْشٍ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ فَلَمَّا سَمِعُوا صَوْتَهُ ذَهَبَ عَنْهُمُ الضِّحْكُ وَخَافُوا دَعْوَتَهُ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ عَلَيْكَ بِأَبِي جَهْلِ بْنِ هِشَامٍ وَعُتْبَةَ بْنِ رَبِيعَةَ وَشَيْبَةَ بْنِ رَبِيعَةَ وَالْوَلِيدِ بْنِ عُقْبَةَ وَأُمَيَّةَ بْنِ خَلَفٍ وَعُقْبَةَ بْنِ أَبِي مُعَيْطٍ ‏"‏ ‏.‏ وَذَكَرَ السَّابِعَ وَلَمْ أَحْفَظْهُ فَوَالَّذِي بَعَثَ مُحَمَّدًا صلى الله عليه وسلم بِالْحَقِّ لَقَدْ رَأَيْتُ الَّذِينَ سَمَّى صَرْعَى يَوْمَ بَدْرٍ ثُمَّ سُحِبُوا إِلَى الْقَلِيبِ قَلِيبِ بَدْرٍ ‏.‏ قَالَ أَبُو إِسْحَاقَ الْوَلِيدُ بْنُ عُقْبَةَ غَلَطٌ فِي هَذَا الْحَدِيثِ ‏.‏\hadithno{4649}\hadithtrans{It has been narrated on the authority of Ibn Mas'ud who said:While the Messenger of Allah (ﷺ) was saying his prayer near the Ka'ba and Abu Jahl with his companions was sitting (near by), Abu Jahl said, referring to the she-camel that had been slaughtered the previous day: Who will rise to fetch the foetus of the she-camel of so and so, and place it between the shoulders of Muhammad when he goes down in prostration (a posture in prayer). The one most accursed among the people got up, brought the foetus and, when the Prophet (ﷺ) went down in prostration, placed it between his shoulders. Then they laughed at him and some of them leaned upon the others with laughter. And I stood looking. If I had the power, I would have thrown it away from the back of the Messenger of Allah (ﷺ). The Prophet (ﷺ) had bent down his head in prostration and did not raise it, until a man went (to his house) and informed (his daughter) Fatima, who was a young girl (at that time) (about this ugly incident). She came and removed (the filthy thing) from him. Then she turned towards them rebuking them (the mischief-mongers). When the Prophet (ﷺ) had finished his prayer, he invoked God's imprecations upon them in a loud voice. When he prayed, he prayed thrice, and when he asked for God's blessings, he asked thrice. Then he said thrice: O Allah, it is for Thee to deal with the Quraish. When they heard his voice, laughter vanished from them and they feared his malediction. Then he said: O God, it is for Thee to deal with Abu Jahl b. Hisham, 'Utba b. Rabi'a, Shaiba b. Rabi'a. Walid b. Uqba, Umayya b. Khalaf, Uqba b. Abu Mu'ait (and he mentioned the name of the seventh person. which I did not remember). By One Who sent Muhammad with truth, I saw (all) those he had named lying slain on the Day of Badr. Their dead bodies were dragged to be thrown into a pit near the battlefield. Abu Ishiq had said that the name of Walid b. 'Uqba has been wrongly mentioned in this tradition}}
\hadithdefcmd{muslim}{4650}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ أَبَا إِسْحَاقَ، يُحَدِّثُ عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ، قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم سَاجِدٌ وَحَوْلَهُ نَاسٌ مِنْ قُرَيْشٍ إِذْ جَاءَ عُقْبَةُ بْنُ أَبِي مُعَيْطٍ بِسَلاَ جَزُورٍ فَقَذَفَهُ عَلَى ظَهْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمْ يَرْفَعْ رَأْسَهُ فَجَاءَتْ فَاطِمَةُ فَأَخَذَتْهُ عَنْ ظَهْرِهِ وَدَعَتْ عَلَى مَنْ صَنَعَ ذَلِكَ فَقَالَ ‏ "‏ اللَّهُمَّ عَلَيْكَ الْمَلأَ مِنْ قُرَيْشٍ أَبَا جَهْلِ بْنَ هِشَامٍ وَعُتْبَةَ بْنَ رَبِيعَةَ وَعُقْبَةَ بْنَ أَبِي مُعَيْطٍ وَشَيْبَةَ بْنَ رَبِيعَةَ وَأُمَيَّةَ بْنَ خَلَفٍ أَوْ أُبَىَّ بْنَ خَلَفٍ ‏"‏ ‏.‏ شُعْبَةُ الشَّاكُّ قَالَ فَلَقَدْ رَأَيْتُهُمْ قُتِلُوا يَوْمَ بَدْرٍ فَأُلْقُوا فِي بِئْرٍ غَيْرَ أَنَّ أُمَيَّةَ أَوْ أُبَيًّا تَقَطَّعَتْ أَوْصَالُهُ فَلَمْ يُلْقَ فِي الْبِئْرِ ‏.‏\hadithno{4650}\hadithtrans{It has been narrated by Abdullah (b. Mas'ud) who said:When the Messenger of Allah (ﷺ) was lying postrate in prayer and around him were some people from the Quraish, 'Uqba b. Abu Mu'ait brought the foetus of a she-camel and threw it on the back of the Messenger of Allah (ﷺ). He did not raise his head until Fatima arrived, removed it from his back and cured him who had done that (ugly act). He said: O Allah, it is for Thee to deal with the chiefs of the Quraish. Abu Jahl b. Hisham, 'Utba b. Rabi'a. Uqba b. Abu Mu'ait, Shaiba b. Rabi'a, Umayya b. Khalaf or Ubayy b. Khalaf (Shu'ba, one of the narrator of this tradition is in doubt about the exact person). I saw that all were slain in the Battle of Badr and their dead bodies were thrown into a well, except that of Umayya or Ubayy which was cut into pieces and was thrown into the well}}
\hadithdefcmd{muslim}{4651}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَعْفَرُ بْنُ عَوْنٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي، إِسْحَاقَ بِهَذَا الإِسْنَادِ نَحْوَهُ وَزَادَ وَكَانَ يَسْتَحِبُّ ثَلاَثًا يَقُولُ ‏ "‏ اللَّهُمَّ عَلَيْكَ بِقُرَيْشٍ اللَّهُمَّ عَلَيْكَ بِقُرَيْشٍ اللَّهُمَّ عَلَيْكَ بِقُرَيْشٍ ‏"‏ ‏.‏ ثَلاَثًا وَذَكَرَ فِيهِمُ الْوَلِيدَ بْنَ عُتْبَةَ وَأُمَيَّةَ بْنَ خَلَفٍ وَلَمْ يَشُكَّ ‏.‏ قَالَ أَبُو إِسْحَاقَ وَنَسِيتُ السَّابِعَ ‏.‏\hadithno{4651}\hadithtrans{Abu Ishiq has narrated a similar tradition through a different chain of transmitters and has added:He (the Messenger of Allah) loved to repeat the supplication thrice. He was saying: O Allah, it is for Thee to deal with the Quraish (repeating these words thrice). And among the Quraish, he mentioned (the names of) al-Walid b. 'Utba and Umayya b. Khalaf. (The narrator says there is no doubt about the names of these persons but he has forgotten the name of the seventh man)}}
\hadithdefcmd{muslim}{4652}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ، قَالَ اسْتَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْبَيْتَ فَدَعَا عَلَى سِتَّةِ نَفَرٍ مِنْ قُرَيْشٍ ‏.‏ فِيهِمْ أَبُو جَهْلٍ وَأُمَيَّةُ بْنُ خَلَفٍ وَعُتْبَةُ بْنُ رَبِيعَةَ وَشَيْبَةُ بْنُ رَبِيعَةَ وَعُقْبَةُ بْنُ أَبِي مُعَيْطٍ فَأُقْسِمُ بِاللَّهِ لَقَدْ رَأَيْتُهُمْ صَرْعَى عَلَى بَدْرٍ ‏.‏ قَدْ غَيَّرَتْهُمُ الشَّمْسُ وَكَانَ يَوْمًا حَارًّا ‏.‏\hadithno{4652}\hadithtrans{It has been narrated on the authority of 'Abdullah that, the Messenger of Allah (ﷺ) turned his face towards the Ka'ba and invoked God's imprecations upon six men of the Quraish, amorig whom were Abu Jahl. Umayya b. Khalaf, Utba b. Rabi'a, Shaiba b. Rabi'a and 'Uqba b. Abu Mu'ait I swear by God that I saw them lying slain in the battlefield of Badr. It being a hot day, their complexion had changed (showing signs of decay)}}
\hadithdefcmd{muslim}{4653}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ سَرْحٍ وَحَرْمَلَةُ بْنُ يَحْيَى وَعَمْرُو بْنُ سَوَّادٍ الْعَامِرِيُّ - وَأَلْفَاظُهُمْ مُتَقَارِبَةٌ - قَالُوا حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم حَدَّثَتْهُ أَنَّهَا قَالَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ هَلْ أَتَى عَلَيْكَ يَوْمٌ كَانَ أَشَدَّ مِنْ يَوْمِ أُحُدٍ فَقَالَ ‏"‏ لَقَدْ لَقِيتُ مِنْ قَوْمِكِ وَكَانَ أَشَدَّ مَا لَقِيتُ مِنْهُمْ يَوْمَ الْعَقَبَةِ إِذْ عَرَضْتُ نَفْسِي عَلَى ابْنِ عَبْدِ يَالِيلَ بْنِ عَبْدِ كُلاَلٍ فَلَمْ يُجِبْنِي إِلَى مَا أَرَدْتُ فَانْطَلَقْتُ وَأَنَا مَهْمُومٌ عَلَى وَجْهِي فَلَمْ أَسْتَفِقْ إِلاَّ بِقَرْنِ الثَّعَالِبِ فَرَفَعْتُ رَأْسِي فَإِذَا أَنَا بِسَحَابَةٍ قَدْ أَظَلَّتْنِي فَنَظَرْتُ فَإِذَا فِيهَا جِبْرِيلُ فَنَادَانِي فَقَالَ إِنَّ اللَّهَ عَزَّ وَجَلَّ قَدْ سَمِعَ قَوْلَ قَوْمِكَ لَكَ وَمَا رَدُّوا عَلَيْكَ وَقَدْ بَعَثَ إِلَيْكَ مَلَكَ الْجِبَالِ لِتَأْمُرَهُ بِمَا شِئْتَ فِيهِمْ قَالَ فَنَادَانِي مَلَكُ الْجِبَالِ وَسَلَّمَ عَلَىَّ ‏.‏ ثُمَّ قَالَ يَا مُحَمَّدُ إِنَّ اللَّهَ قَدْ سَمِعَ قَوْلَ قَوْمِكَ لَكَ وَأَنَا مَلَكُ الْجِبَالِ وَقَدْ بَعَثَنِي رَبُّكَ إِلَيْكَ لِتَأْمُرَنِي بِأَمْرِكَ فَمَا شِئْتَ إِنْ شِئْتَ أَنْ أُطْبِقَ عَلَيْهِمُ الأَخْشَبَيْنِ ‏"‏ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَلْ أَرْجُو أَنْ يُخْرِجَ اللَّهُ مِنْ أَصْلاَبِهِمْ مَنْ يَعْبُدُ اللَّهَ وَحْدَهُ لاَ يُشْرِكُ بِهِ شَيْئًا ‏"‏ ‏\hadithno{4653}\hadithtrans{It has been narrated on the authority of `A'isha, the wife of the Prophet (ﷺ), who said to the Messenger of Allah (may peace he upon him):Messenger of Allah, has there come upon you a day more terrible than the day of Uhud. He said: I have experienced from thy people and the hardest treatment I met from them was what I received from them on the day of `Aqaba. I betook myself to Ibn `Abd Yalil b. `Abd Kulal with the purpose of inviting him to Islam, but he did not respond to me as I desired. So I departed with signs of (deep) distress on my face. I did not recover until I reached Qarn al-Tha`alib. Where I raised my head, lo! near me was a cloud which had cast its shadow on me. I looked and lo! there was in it the angel Jibril who called out to me and said: God, the Honoured and Glorious, has heard what thy people have said to thee, and how they have reacted to thy call. And He has sent to thee the angel in charge of the mountains so that thou mayest order him what thou wishest (him to do) with regard to them. The angel in charge of the mountains (then) called out to me, greeted me and said: Muhammad, God has listened to what thy people have said to thee. I am the angel in charge of the mountains, and thy Lord has sent me to thee so that thou mayest order me what thou wishest. If thou wishest that I should bring together the two mountains that stand opposite to each other at the extremities of Mecca to crush them in between, (I would do that). But the Messenger of Allah (may peace he upon him) said to him: I rather hope that God will produce from their descendants such persons as will worship Allah, the One, and will not ascribe partners to Him}}
\hadithdefcmd{muslim}{4654}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، كِلاَهُمَا عَنْ أَبِي عَوَانَةَ، قَالَ يَحْيَى أَخْبَرَنَا أَبُو عَوَانَةَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ جُنْدُبِ بْنِ سُفْيَانَ، قَالَ دَمِيَتْ إِصْبَعُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ تِلْكَ الْمَشَاهِدِ فَقَالَ ‏ "‏ هَلْ أَنْتِ إِلاَّ إِصْبَعٌ دَمِيتِ وَفِي سَبِيلِ اللَّهِ مَا لَقِيتِ ‏"‏ ‏.‏\hadithno{4654}\hadithtrans{It has been narrated on the authority of Jundub b. Sufyan who said:A finger of the Messenger of Allah (ﷺ) was wounded in one of the encounters He said: Thou art just a little finger which has bled, and what thou hast experienced is in the cause of Allah}}
\hadithdefcmd{muslim}{4655}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، بِهَذَا الإِسْنَادِ وَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي غَارٍ فَنُكِبَتْ إِصْبَعُهُ ‏.‏\hadithno{4655}\hadithtrans{It has been narrated on the authority of Aswad b. Qais who said:The Messenger of Allah (ﷺ) was in a cave (or raid) when his finger was hurt}}
\hadithdefcmd{muslim}{4656}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، أَنَّهُ سَمِعَ جُنْدُبًا، يَقُولُ أَبْطَأَ جِبْرِيلُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ الْمُشْرِكُونَ قَدْ وُدِّعَ مُحَمَّدٌ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَالضُّحَى * وَاللَّيْلِ إِذَا سَجَى * مَا وَدَّعَكَ رَبُّكَ وَمَا قَلَى‏\}‏\hadithno{4656}\hadithtrans{It has been narrated on the authority of Aswad b. Qais who heard Jundub saying that Gabriel delayed his visit to the Messenger of Allah (ﷺ) The polytheists began to say that Muhammad has been forsaken. At this Allah, the Glorious and Exalted, revealed:" Wa'dd hd wa'l-laili iza saja, ma wadda'ka Rabbuka wa' ma qala" [By the glorious morning light, and by the night when it is still: thy Lord has not forsaken thee, nor is He displeased]}}
\hadithdefcmd{muslim}{4657}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، - وَاللَّفْظُ لاِبْنِ رَافِعٍ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا زُهَيْرٌ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، قَالَ سَمِعْتُ جُنْدُبَ بْنَ سُفْيَانَ، يَقُولُ اشْتَكَى رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمْ يَقُمْ لَيْلَتَيْنِ أَوْ ثَلاَثًا فَجَاءَتْهُ امْرَأَةٌ فَقَالَتْ يَا مُحَمَّدُ إِنِّي لأَرْجُو أَنْ يَكُونَ شَيْطَانُكَ قَدْ تَرَكَكَ لَمْ أَرَهُ قَرِبَكَ مُنْذُ لَيْلَتَيْنِ أَوْ ثَلاَثٍ قَالَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَالضُّحَى * وَاللَّيْلِ إِذَا سَجَى * مَا وَدَّعَكَ رَبُّكَ وَمَا قَلَى‏\}‏\hadithno{4657}\hadithtrans{It has been narrated on the authority of Aswad b. Qais who said:I heard Jundub b. Sufyan say: The Messenger of Allah (ﷺ) fell ill and did not wake up for two or three nights (for prayers) A woman came to him and said: Muhammad, I hope that your satan has left you. I haven't seen him approach you for two or three nights. The narrator says: At this, Allah, the Glorious and Exalted, revealed:" By the Glorious}}
\hadithdefcmd{muslim}{4658}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالُوا حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ عَنْ شُعْبَةَ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا الْمُلاَئِيُّ، حَدَّثَنَا سُفْيَانُ، كِلاَهُمَا عَنِ الأَسْوَدِ بْنِ قَيْسٍ، بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِهِمَا ‏.‏\hadithno{4658}\hadithtrans{This hadith has been narrated on the authority of Aswad b. Qais with the same chain of transmitters}}
\hadithdefcmd{muslim}{4659}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَمُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، - وَاللَّفْظُ لاِبْنِ رَافِعٍ - قَالَ ابْنُ رَافِعٍ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، أَنَّ أُسَامَةَ بْنَ زَيْدٍ، أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم رَكِبَ حِمَارًا عَلَيْهِ إِكَافٌ تَحْتَهُ قَطِيفَةٌ فَدَكِيَّةٌ وَأَرْدَفَ وَرَاءَهُ أُسَامَةَ وَهُوَ يَعُودُ سَعْدَ بْنَ عُبَادَةَ فِي بَنِي الْحَارِثِ بْنِ الْخَزْرَجِ وَذَاكَ قَبْلَ وَقْعَةِ بَدْرٍ حَتَّى مَرَّ بِمَجْلِسٍ فِيهِ أَخْلاَطٌ مِنَ الْمُسْلِمِينَ وَالْمُشْرِكِينَ عَبَدَةِ الأَوْثَانِ وَالْيَهُودِ فِيهِمْ عَبْدُ اللَّهِ بْنُ أُبَىٍّ وَفِي الْمَجْلِسِ عَبْدُ اللَّهِ بْنُ رَوَاحَةَ فَلَمَّا غَشِيَتِ الْمَجْلِسَ عَجَاجَةُ الدَّابَّةِ خَمَّرَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ أَنْفَهُ بِرِدَائِهِ ثُمَّ قَالَ لاَ تُغَبِّرُوا عَلَيْنَا ‏.‏ فَسَلَّمَ عَلَيْهِمُ النَّبِيُّ صلى الله عليه وسلم ثُمَّ وَقَفَ فَنَزَلَ فَدَعَاهُمْ إِلَى اللَّهِ وَقَرَأَ عَلَيْهِمُ الْقُرْآنَ فَقَالَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ أَيُّهَا الْمَرْءُ لاَ أَحْسَنَ مِنْ هَذَا إِنْ كَانَ مَا تَقُولُ حَقًّا فَلاَ تُؤْذِنَا فِي مَجَالِسِنَا وَارْجِعْ إِلَى رَحْلِكَ فَمَنْ جَاءَكَ مِنَّا فَاقْصُصْ عَلَيْهِ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ رَوَاحَةَ اغْشَنَا فِي مَجَالِسِنَا فَإِنَّا نُحِبُّ ذَلِكَ ‏.‏ قَالَ فَاسْتَبَّ الْمُسْلِمُونَ وَالْمُشْرِكُونَ وَالْيَهُودُ حَتَّى هَمُّوا أَنْ يَتَوَاثَبُوا فَلَمْ يَزَلِ النَّبِيُّ صلى الله عليه وسلم يُخَفِّضُهُمْ ثُمَّ رَكِبَ دَابَّتَهُ حَتَّى دَخَلَ عَلَى سَعْدِ بْنِ عُبَادَةَ فَقَالَ ‏ "‏ أَىْ سَعْدُ أَلَمْ تَسْمَعْ إِلَى مَا قَالَ أَبُو حُبَابٍ - يُرِيدُ عَبْدَ اللَّهِ بْنَ أُبَىٍّ - قَالَ كَذَا وَكَذَا ‏"‏ ‏.‏ قَالَ اعْفُ عَنْهُ يَا رَسُولَ اللَّهِ وَاصْفَحْ فَوَاللَّهِ لَقَدْ أَعْطَاكَ اللَّهُ الَّذِي أَعْطَاكَ وَلَقَدِ اصْطَلَحَ أَهْلُ هَذِهِ الْبُحَيْرَةِ أَنْ يُتَوِّجُوهُ فَيُعَصِّبُوهُ بِالْعِصَابَةِ فَلَمَّا رَدَّ اللَّهُ ذَلِكَ بِالْحَقِّ الَّذِي أَعْطَاكَهُ شَرِقَ بِذَلِكَ فَذَلِكَ فَعَلَ بِهِ مَا رَأَيْتَ ‏.‏ فَعَفَا عَنْهُ النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{4659}\hadithtrans{It has been narrated on the authority of Usama b. Zaid that the Prophet (ﷺ) rode a donkey. It had on it a saddle under which was a mattress made at Fadak (a place near Medina). Behind him he seated Usama. He was going to the street of Banu Harith al-Khazraj to inquire after the health of Sa'd b. Ubada This happened before the Battle of Badr. (He proceeded) until he passed by a mixed company of people in which were Muslims, polytheists, idol worshippers and the Jews and among them were 'Abdullah b. Ubayy and 'Abdullah b. Rawaha. When the dust raised by the hoofs of the animal spread over the company, 'Abdullah b. Ubayy covered his nose with his mantle and said:Do not scatter the dust over us (Not minding this remark), the Prophet (ﷺ) greeted them, stopped, got down from his animal, invited them to Allah, and recited to them the Qur'an. 'Abdullah b. Ubayy said: O man, if what you say is the truth, the best thing for you would be not to bother us with it in our assemblies. Get back to your place. Whoso comes to you from us, tell him (all) this. Abdullah b. Rawaha said: Come to us in our gatherings, for we love (to hear) it. The narrator says: (At this), the Muslims, the polytheists and the Jews began to rebuke one another until they were determined to come to blows. The Prophet (ﷺ) continued to pacify them. (When they were pacified), he rode his animal and came to Sa'd b. 'Ubida. He said: Sa'd, haven't you heard what Abu Hubab (meaning 'Abdullah b. Ubayy) has said? He has said so and so. Sa'd said: Messenger of Allah, forgive and pardon. God has granted you a sublime position, (but so far as he is concerned) the people of this settlement had-decided to make him their king by making him wear a crown and a turban (in token thereof), but God has circumvented this by the truth He has granted you. This has made him jealous and his jealousy (must have) prompted the behaviour that you have witnessed. So, the Prophet (may peace upon him) forgave him}}
\hadithdefcmd{muslim}{4660}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا حُجَيْنٌ، - يَعْنِي ابْنَ الْمُثَنَّى - حَدَّثَنَا لَيْثٌ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، فِي هَذَا الإِسْنَادِ بِمِثْلِهِ وَزَادَ وَذَلِكَ قَبْلَ أَنْ يُسْلِمَ عَبْدُ اللَّهِ ‏.‏\hadithno{4660}\hadithtrans{A similar tradition has been narrated through a different chain of transmitters by Ibn Shihab with the addition of the words:" Before Abdullah (b. Ubayy) became a Muslim}}
\hadithdefcmd{muslim}{4661}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى الْقَيْسِيُّ، حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قِيلَ لِلنَّبِيِّ صلى الله عليه وسلم لَوْ أَتَيْتَ عَبْدَ اللَّهِ بْنَ أُبَىٍّ قَالَ فَانْطَلَقَ إِلَيْهِ وَرَكِبَ حِمَارًا وَانْطَلَقَ الْمُسْلِمُونَ وَهِيَ أَرْضٌ سَبِخَةٌ فَلَمَّا أَتَاهُ النَّبِيُّ صلى الله عليه وسلم قَالَ إِلَيْكَ عَنِّي فَوَاللَّهِ لَقَدْ آذَانِي نَتْنُ حِمَارِكَ ‏.‏ قَالَ فَقَالَ رَجُلٌ مِنَ الأَنْصَارِ وَاللَّهِ لَحِمَارُ رَسُولِ اللَّهِ صلى الله عليه وسلم أَطْيَبُ رِيحًا مِنْكَ - قَالَ - فَغَضِبَ لِعَبْدِ اللَّهِ رَجُلٌ مِنْ قَوْمِهِ - قَالَ - فَغَضِبَ لِكُلِّ وَاحِدٍ مِنْهُمَا أَصْحَابُهُ - قَالَ - فَكَانَ بَيْنَهُمْ ضَرْبٌ بِالْجَرِيدِ وَبِالأَيْدِي وَبِالنِّعَالِ - قَالَ - فَبَلَغَنَا أَنَّهَا نَزَلَتْ فِيهِمْ ‏\{‏ وَإِنْ طَائِفَتَانِ مِنَ الْمُؤْمِنِينَ اقْتَتَلُوا فَأَصْلِحُوا بَيْنَهُمَا‏\}‏ ‏.‏\hadithno{4661}\hadithtrans{It has been narrated on the authority of Anas b. Malik that it was said to the Prophet (ﷺ):Would that you approached Abdullah b. Ubayy (to persuade him to accept Islam). The Prophet (ﷺ) (accordingly) went to him, riding a donkey, and (a party of) Muslims also went (with him). On the way they had to walk over a piece of land affected with salinity. When the Prophet (ﷺ) approached him, he said: Do not come near me. By Allah, the obnoxious smell of your donkey has offended me. (As a rejoinder to this remark), a man from the Ansar said: By God, the smell of the donkey of the Messenger of Allah (ﷺ) is better than your smell. (At this), a man from the tribe of 'Abdullah got furious. Then people from both sides got furious and exchanged blows with sticks, hands and shoes. (The narrator says) that (after this scuffle) we learnt that (the Qur'anic verse):" It two parties of the Believers have a quarrel, make ye peace between them" (xlix. 9) was revealed about these fighting parties}}
\hadithdefcmd{muslim}{4662}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، أَخْبَرَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - حَدَّثَنَا سُلَيْمَانُ، التَّيْمِيُّ حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يَنْظُرُ لَنَا مَا صَنَعَ أَبُو جَهْلٍ ‏"‏ ‏.‏ فَانْطَلَقَ ابْنُ مَسْعُودٍ فَوَجَدَهُ قَدْ ضَرَبَهُ ابْنَا عَفْرَاءَ حَتَّى بَرَكَ - قَالَ - فَأَخَذَ بِلِحْيَتِهِ فَقَالَ آنْتَ أَبُو جَهْلٍ فَقَالَ وَهَلْ فَوْقَ رَجُلٍ قَتَلْتُمُوهُ - أَوْ قَالَ - قَتَلَهُ قَوْمُهُ قَالَ وَقَالَ أَبُو مِجْلَزٍ قَالَ أَبُو جَهْلٍ فَلَوْ غَيْرُ أَكَّارٍ قَتَلَنِي ‏.‏\hadithno{4662}\hadithtrans{It has been narrated on the authority of Anas b. Malik that the Messenger of Allah (ﷺ) said (after the encounter at Badr):Who will ascertain for us what has happened to Abu Jahl? Ibn Mas'ud went (to gather this information). He found that the two sons of 'Afra' had struck him and he lay cold at the point of death. He caught him by his beard and said: Art thou Abu Jahl? He said: is there anybody superior to the person you have killed, or (he said) his people have killed him. Ibn Mas'ud says that, according to Abu Mijlaz, Abu Jahl said: Alas! a person other than a farmer would have killed me}}
\hadithdefcmd{muslim}{4663}{حَدَّثَنَا حَامِدُ بْنُ عُمَرَ الْبَكْرَاوِيُّ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي يَقُولُ، حَدَّثَنَا أَنَسٌ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ يَعْلَمُ لِي مَا فَعَلَ أَبُو جَهْلٍ ‏"‏ ‏.‏ بِمِثْلِ حَدِيثِ ابْنِ عُلَيَّةَ وَقَوْلِ أَبِي مِجْلَزٍ كَمَا ذَكَرَهُ إِسْمَاعِيلُ ‏.‏\hadithno{4663}\hadithtrans{A similar tradition has been transmitted by a different chain of narrators, on the same authority with a slight difference In the wording}}
\hadithdefcmd{muslim}{4664}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَعَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْمِسْوَرِ، الزُّهْرِيُّ كِلاَهُمَا عَنِ ابْنِ عُيَيْنَةَ، - وَاللَّفْظُ لِلزُّهْرِيِّ - حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، سَمِعْتُ جَابِرًا، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ لِكَعْبِ بْنِ الأَشْرَفِ فَإِنَّهُ قَدْ آذَى اللَّهَ وَرَسُولَهُ ‏"‏ ‏.‏ فَقَالَ مُحَمَّدُ بْنُ مَسْلَمَةَ يَا رَسُولَ اللَّهِ أَتُحِبُّ أَنْ أَقْتُلَهُ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ ائْذَنْ لِي فَلأَقُلْ قَالَ ‏"‏ قُلْ ‏"‏ ‏.‏ فَأَتَاهُ فَقَالَ لَهُ وَذَكَرَ مَا بَيْنَهُمَا وَقَالَ إِنَّ هَذَا الرَّجُلَ قَدْ أَرَادَ صَدَقَةً وَقَدْ عَنَّانَا ‏.‏ فَلَمَّا سَمِعَهُ قَالَ وَأَيْضًا وَاللَّهِ لَتَمَلُّنَّهُ ‏.‏ قَالَ إِنَّا قَدِ اتَّبَعْنَاهُ الآنَ وَنَكْرَهُ أَنْ نَدَعَهُ حَتَّى نَنْظُرَ إِلَى أَىِّ شَىْءٍ يَصِيرُ أَمْرُهُ - قَالَ - وَقَدْ أَرَدْتُ أَنْ تُسْلِفَنِي سَلَفًا قَالَ فَمَا تَرْهَنُنِي قَالَ مَا تُرِيدُ ‏.‏ قَالَ تَرْهَنُنِي نِسَاءَكُمْ قَالَ أَنْتَ أَجْمَلُ الْعَرَبِ أَنَرْهَنُكَ نِسَاءَنَا قَالَ لَهُ تَرْهَنُونِي أَوْلاَدَكُمْ ‏.‏ قَالَ يُسَبُّ ابْنُ أَحَدِنَا فَيُقَالُ رُهِنَ فِي وَسْقَيْنِ مِنْ تَمْرٍ ‏.‏ وَلَكِنْ نَرْهَنُكَ اللأْمَةَ - يَعْنِي السِّلاَحَ - قَالَ فَنَعَمْ ‏.‏ وَوَاعَدَهُ أَنْ يَأْتِيَهُ بِالْحَارِثِ وَأَبِي عَبْسِ بْنِ جَبْرٍ وَعَبَّادِ بْنِ بِشْرٍ قَالَ فَجَاءُوا فَدَعَوْهُ لَيْلاً فَنَزَلَ إِلَيْهِمْ قَالَ سُفْيَانُ قَالَ غَيْرُ عَمْرٍو قَالَتْ لَهُ امْرَأَتُهُ إِنِّي لأَسْمَعُ صَوْتًا كَأَنَّهُ صَوْتُ دَمٍ قَالَ إِنَّمَا هَذَا مُحَمَّدُ بْنُ مَسْلَمَةَ وَرَضِيعُهُ وَأَبُو نَائِلَةَ إِنَّ الْكَرِيمَ لَوْ دُعِيَ إِلَى طَعْنَةٍ لَيْلاً لأَجَابَ ‏.‏ قَالَ مُحَمَّدٌ إِنِّي إِذَا جَاءَ فَسَوْفَ أَمُدُّ يَدِي إِلَى رَأْسِهِ فَإِذَا اسْتَمْكَنْتُ مِنْهُ فَدُونَكُمْ قَالَ فَلَمَّا نَزَلَ نَزَلَ وَهُوَ مُتَوَشِّحٌ فَقَالُوا نَجِدُ مِنْكَ رِيحَ الطِّيبِ قَالَ نَعَمْ تَحْتِي فُلاَنَةُ هِيَ أَعْطَرُ نِسَاءِ الْعَرَبِ ‏.‏ قَالَ فَتَأْذَنُ لِي أَنْ أَشُمَّ مِنْهُ قَالَ نَعَمْ فَشُمَّ ‏.‏ فَتَنَاوَلَ فَشَمَّ ثُمَّ قَالَ أَتَأْذَنُ لِي أَنْ أَعُودَ قَالَ فَاسْتَمْكَنَ مِنْ رَأْسِهِ ثُمَّ قَالَ دُونَكُمْ ‏.‏ قَالَ فَقَتَلُوهُ ‏.‏\hadithno{4664}\hadithtrans{It has been narrated on the authority of Jabir that the Messenger of Allah (ﷺ) said:Who will kill Ka'b b. Ashraf? He has maligned Allah, the Exalted, and His Messenger. Muhammad b. Maslama said: Messenger of Allah, do you wish that I should kill him? He said: Yes. He said: Permit me to talk (to him in the way I deem fit). He said: Talk (as you like). So, Muhammad b. Maslama came to Ka'b and talked to him, referred to the old friendship between them and said: This man (i. e. the Holy Prophet) has made up his mind to collect charity (from us) and this has put us to a great hardship. When be heard this, Ka'b said: By God, you will be put to more trouble by him. Muhammad b. Maslama said: No doubt, now we have become his followers and we do not like to forsake him until we see what turn his affairs will take. I want that you should give me a loan. He said: What will you mortgage? He said: What do you want? He said: Pledge me your women. He said: You are the most handsome of the Arabs; should we pledge our women to you? He said: Pledge me your children. He said: The son of one of us may abuse us saying that he was pledged for two wasqs of dates, but we can pledge you (cur) weapons. He said: All right. Then Muhammad b. Maslama promised that he would come to him with Harith, Abu 'Abs b. Jabr and Abbad b. Bishr. So they came and called upon him at night. He came down to them. Sufyan says that all the narrators except 'Amr have stated that his wife said: I hear a voice which sounds like the voice of murder. He said: It is only Muhammad b. Maslama and his foster-brother, Abu Na'ila. When a gentleman is called at night even it to be pierced with a spear, he should respond to the call. Muhammad said to his companions: As he comes down, I will extend my hands towards his head and when I hold him fast, you should do your job. So when he came down and he was holding his cloak under his arm, they said to him: We sense from you a very fine smell. He said: Yes, I have with me a mistress who is the most scented of the women of Arabia. He said: Allow me to smell (the scent on your head). He said: Yes, you may smell. So he caught it and smelt. Then he said: Allow me to do so (once again). He then held his head fast and said to his companions: Do your job. And they killed him}}
\hadithdefcmd{muslim}{4665}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - عَنْ عَبْدِ الْعَزِيزِ، بْنِ صُهَيْبٍ عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غَزَا خَيْبَرَ قَالَ فَصَلَّيْنَا عِنْدَهَا صَلاَةَ الْغَدَاةِ بِغَلَسٍ فَرَكِبَ نَبِيُّ اللَّهِ صلى الله عليه وسلم وَرَكِبَ أَبُو طَلْحَةَ وَأَنَا رَدِيفُ أَبِي طَلْحَةَ فَأَجْرَى نَبِيُّ اللَّهِ صلى الله عليه وسلم فِي زُقَاقِ خَيْبَرَ وَإِنَّ رُكْبَتِي لَتَمَسُّ فَخِذَ نَبِيِّ اللَّهِ صلى الله عليه وسلم وَانْحَسَرَ الإِزَارُ عَنْ فَخِذِ نَبِيِّ اللَّهِ صلى الله عليه وسلم وَإِنِّي لأَرَى بَيَاضَ فَخِذِ نَبِيِّ اللَّهِ صلى الله عليه وسلم فَلَمَّا دَخَلَ الْقَرْيَةَ قَالَ ‏ "‏ اللَّهُ أَكْبَرُ خَرِبَتْ خَيْبَرُ إِنَّا إِذَا نَزَلْنَا بِسَاحَةِ قَوْمٍ فَسَاءَ صَبَاحُ الْمُنْذَرِينَ ‏"‏ ‏.‏ قَالَهَا ثَلاَثَ مِرَارٍ قَالَ وَقَدْ خَرَجَ الْقَوْمُ إِلَى أَعْمَالِهِمْ فَقَالُوا مُحَمَّدٌ - قَالَ عَبْدُ الْعَزِيزِ وَقَالَ بَعْضُ أَصْحَابِنَا - وَالْخَمِيسَ قَالَ وَأَصَبْنَاهَا عَنْوَةً ‏.‏\hadithno{4665}\hadithtrans{It has been narrated on the authority of Anas that the Messenger of Allah (ﷺ) raided Khaibar. One morning we offered prayers in the darkness of early dawn (near Khaibar). Then the Messenger of Allah (ﷺ) mounted (his horse). Abu Talha mounted his and I mounted behind Abu Talha on the same horse. The Prophet of Allah (ﷺ) rode through the streets of Khaibar and (I rode so close to him) that my knee touched the thigh of the Prophet of Allah (ﷺ). The wrapper got aside from his thigh, and I could see its whiteness. When he entered the town, he said:God is Great. Khaibar shall face destruction. When we descend in the city-square of a people, it is a bad day for them who have been warned (and have not taken heed). He said these words thrice. The people of the town had just come out from (their houses) to go about their jobs. They said (in surprise): Muhammad has come. We captured Khaibar by force}}
\hadithdefcmd{muslim}{4666}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، قَالَ كُنْتُ رِدْفَ أَبِي طَلْحَةَ يَوْمَ خَيْبَرَ وَقَدَمِي تَمَسُّ قَدَمَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَأَتَيْنَاهُمْ حِينَ بَزَغَتِ الشَّمْسُ وَقَدْ أَخْرَجُوا مَوَاشِيَهُمْ وَخَرَجُوا بِفُئُوسِهِمْ وَمَكَاتِلِهِمْ وَمُرُورِهِمْ فَقَالُوا مُحَمَّدٌ وَالْخَمِيسَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَرِبَتْ خَيْبَرُ إِنَّا إِذَا نَزَلْنَا بِسَاحَةِ قَوْمٍ فَسَاءَ صَبَاحُ الْمُنْذَرِينَ ‏"‏ ‏.‏ قَالَ فَهَزَمَهُمُ اللَّهُ عَزَّ وَجَلَّ ‏.‏\hadithno{4666}\hadithtrans{It has been narrated (through another chain of transmitters) on the authority of the same narrator (i. e. Anas) who said:I was riding behind Abu Talha on the day of the Battle of Khaibar (and we were riding so close to the Prophet that) my foot would touch his We encountered the people at sunrise when they had come out with their axes, spades and strings driving their cattle along. They shouted (in surprise): Muhammad has come along with his force! The Messenger of Allah (ﷺ) said: Khaibar shall face destruction. Behold! when we descend in the city-square of a people, it is a bad day for those who have been warned (but have not taken heed). Allah, the Glorious and Majestic, inflicted defeat upon them}}
\hadithdefcmd{muslim}{4667}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَإِسْحَاقُ بْنُ مَنْصُورٍ، قَالاَ أَخْبَرَنَا النَّضْرُ بْنُ شُمَيْلٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا أَتَى رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْبَرَ قَالَ ‏ "‏ إِنَّا إِذَا نَزَلْنَا بِسَاحَةِ قَوْمٍ فَسَاءَ صَبَاحُ الْمُنْذَرِينَ ‏"‏ ‏.‏\hadithno{4667}\hadithtrans{This hadith has been transmitted on the authority of Anas b. Malik with a slight variation of words}}
\hadithdefcmd{muslim}{4668}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ عَبَّادٍ، - وَاللَّفْظُ لاِبْنِ عَبَّادٍ - قَالاَ حَدَّثَنَا حَاتِمٌ، - وَهُوَ ابْنُ إِسْمَاعِيلَ - عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، مَوْلَى سَلَمَةَ بْنِ الأَكْوَعِ عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلَى خَيْبَرَ فَتَسَيَّرْنَا لَيْلاً فَقَالَ رَجُلٌ مِنَ الْقَوْمِ لِعَامِرِ بْنِ الأَكْوَعِ أَلاَ تُسْمِعُنَا مِنْ هُنَيْهَاتِكَ وَكَانَ عَامِرٌ رَجُلاً شَاعِرًا فَنَزَلَ يَحْدُو بِالْقَوْمِ يَقُولُ اللَّهُمَّ لَوْلاَ أَنْتَ مَا اهْتَدَيْنَا وَلاَ تَصَدَّقْنَا وَلاَ صَلَّيْنَا فَاغْفِرْ فِدَاءً لَكَ مَا اقْتَفَيْنَا وَثَبِّتِ الأَقْدَامَ إِنْ لاَقَيْنَا وَأَلْقِيَنْ سَكِينَةً عَلَيْنَا إِنَّا إِذَا صِيحَ بِنَا أَتَيْنَا وَبِالصِّيَاحِ عَوَّلُوا عَلَيْنَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ هَذَا السَّائِقُ ‏"‏ ‏.‏ قَالُوا عَامِرٌ ‏.‏ قَالَ ‏"‏ يَرْحَمُهُ اللَّهُ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ وَجَبَتْ يَا رَسُولَ اللَّهِ لَوْلاَ أَمْتَعْتَنَا بِهِ ‏.‏ قَالَ فَأَتَيْنَا خَيْبَرَ فَحَصَرْنَاهُمْ حَتَّى أَصَابَتْنَا مَخْمَصَةٌ شَدِيدَةٌ ثُمَّ قَالَ ‏"‏ إِنَّ اللَّهَ فَتَحَهَا عَلَيْكُمْ ‏"‏ ‏.‏ قَالَ فَلَمَّا أَمْسَى النَّاسُ مَسَاءَ الْيَوْمِ الَّذِي فُتِحَتْ عَلَيْهِمْ أَوْقَدُوا نِيرَانًا كَثِيرَةً فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا هَذِهِ النِّيرَانُ عَلَى أَىِّ شَىْءٍ تُوقِدُونَ ‏"‏ ‏.‏ فَقَالُوا عَلَى لَحْمٍ ‏.‏ قَالَ ‏"‏ أَىُّ لَحْمٍ ‏"‏ ‏.‏ قَالُوا لَحْمُ حُمُرِ الإِنْسِيَّةِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَهْرِيقُوهَا وَاكْسِرُوهَا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ أَوْ يُهَرِيقُوهَا وَيَغْسِلُوهَا فَقَالَ ‏"‏ أَوْ ذَاكَ ‏"‏ ‏.‏ قَالَ فَلَمَّا تَصَافَّ الْقَوْمُ كَانَ سَيْفُ عَامِرٍ فِيهِ قِصَرٌ فَتَنَاوَلَ بِهِ سَاقَ يَهُودِيٍّ لِيَضْرِبَهُ وَيَرْجِعُ ذُبَابُ سَيْفِهِ فَأَصَابَ رُكْبَةَ عَامِرٍ فَمَاتَ مِنْهُ قَالَ فَلَمَّا قَفَلُوا قَالَ سَلَمَةُ وَهُوَ آخِذٌ بِيَدِي قَالَ فَلَمَّا رَآنِي رَسُولُ اللَّهِ صلى الله عليه وسلم سَاكِتًا قَالَ ‏"‏ مَا لَكَ ‏"‏ ‏.‏ قُلْتُ لَهُ فِدَاكَ أَبِي وَأُمِّي زَعَمُوا أَنَّ عَامِرًا حَبِطَ عَمَلُهُ قَالَ ‏"‏ مَنْ قَالَهُ ‏"‏ ‏.‏ قُلْتُ فُلاَنٌ وَفُلاَنٌ وَأُسَيْدُ بْنُ حُضَيْرٍ الأَنْصَارِيُّ فَقَالَ ‏"‏ كَذَبَ مَنْ قَالَهُ إِنَّ لَهُ لأَجْرَيْنِ ‏"‏ ‏.‏ وَجَمَعَ بَيْنَ إِصْبَعَيْهِ ‏"‏ إِنَّهُ لَجَاهِدٌ مُجَاهِدٌ قَلَّ عَرَبِيٌّ مَشَى بِهَا مِثْلَهُ ‏"‏ ‏.‏ وَخَالَفَ قُتَيْبَةُ مُحَمَّدًا فِي الْحَدِيثِ فِي حَرْفَيْنِ وَفِي رِوَايَةِ ابْنِ عَبَّادٍ وَأَلْقِ سَكِينَةً عَلَيْنَا ‏.‏\hadithno{4668}\hadithtrans{It has been narrated on the authority of Salama b. al-Akwa' who said:We marched upon Khaibar with the Messenger of Allah (ﷺ). We journeyed during the night. One of the people said to (my brother) 'Amir b. al-Akwa': Won't you recite to us some of your verses? Amir was a poet. So he began to chant his verses to urge the camels, reciting: O God, if Thou hadst not guided us We would have neither been guided rightly nor practised charity, Nor offered prayers. We wish to lay down our lives for Thee; so forgive Thou our lapses, And keep us steadfast when we encounter (our enemies). Bestow upon us peace and tranquillity. Behold, when with a cry they called upon us to help. The Messenger of Allah (ﷺ) said: Who is this driver (of the camels)? They said: It is 'Amir. He said: God will show mercy to him. A man said: Martyrdom is reserved for him. Messenger of Allah, would that you had allowed us to benefit ourselves from his life. (The narrator says): We reached Khaibar and besieged them, and (we continued the siege) until extreme hunger afflicted us. Then the Messenger of Allah (ﷺ) said: Behold, God has conquered it for you. When it was evening of the day on which the city was conquered. the Muslims lit many fires. The Messenger of Allah (ﷺ) said: What are these fires? And what are they cooking? They said: They are cooking meat. He asked. Which meat? They said: That of domestic asses. He said: Let them throw it away and break the pots (in which it is being cooked). A man said: Or should they throw it away and wash the pots? He said: They may do that. When the people drew themselves up in battle array 'Amir caught hold of his sword that was rather short He drove a Jew before him to strike him with it. (As he struck him), his sword recoiled and struck his own knee, and 'Amir died of the wound. When the people returned (after the conquest of Kliaibar) and he (Salama) had caught hold of my hand, and said: The Messenger of Allah (ﷺ) saw that I was silent (and dejected) ; he said: What's the matter with thee? I said to him: My father and my mother be thy ransom, people presume that 'Amir's sacrifice has been in vain. He asked: Who has said that? I said: So and so and Usaid b. Hudair al-Ansari. He said: Who has said that has lied. For him (for 'Amir) there is a double reward. (He indicated this by putting two of his fingers together.) He was a devotee of God and a warrior fighting for His cause. There will be hardly any Arab who can fight as bravely as he did. Qutaiba has differed in a few words}}
\hadithdefcmd{muslim}{4669}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَبْدُ الرَّحْمَنِ، - وَنَسَبَهُ غَيْرُ ابْنِ وَهْبٍ فَقَالَ ابْنُ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ - أَنَّ سَلَمَةَ، بْنَ الأَكْوَعِ قَالَ لَمَّا كَانَ يَوْمُ خَيْبَرَ قَاتَلَ أَخِي قِتَالاً شَدِيدًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَارْتَدَّ عَلَيْهِ سَيْفُهُ فَقَتَلَهُ فَقَالَ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي ذَلِكَ وَشَكُّوا فِيهِ رَجُلٌ مَاتَ فِي سِلاَحِهِ ‏.‏ وَشَكُّوا فِي بَعْضِ أَمْرِهِ ‏.‏ قَالَ سَلَمَةُ فَقَفَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ خَيْبَرَ فَقُلْتُ يَا رَسُولَ اللَّهِ ائْذَنْ لِي أَنْ أَرْجُزَ لَكَ ‏.‏ فَأَذِنَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ عُمَرُ بْنُ الْخَطَّابِ أَعْلَمُ مَا تَقُولُ قَالَ فَقُلْتُ وَاللَّهِ لَوْلاَ اللَّهُ مَا اهْتَدَيْنَا وَلاَ تَصَدَّقْنَا وَلاَ صَلَّيْنَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ صَدَقْتَ ‏"‏ ‏.‏ وَأَنْزِلَنَّ سَكِينَةً عَلَيْنَا وَثَبِّتِ الأَقْدَامَ إِنْ لاَقَيْنَا وَالْمُشْرِكُونَ قَدْ بَغَوْا عَلَيْنَا قَالَ فَلَمَّا قَضَيْتُ رَجَزِي قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ قَالَ هَذَا ‏"‏ ‏.‏ قُلْتُ قَالَهُ أَخِي فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَرْحَمُهُ اللَّهُ ‏"‏ ‏.‏ قَالَ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّ نَاسًا لَيَهَابُونَ الصَّلاَةَ عَلَيْهِ يَقُولُونَ رَجُلٌ مَاتَ بِسِلاَحِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَاتَ جَاهِدًا مُجَاهِدًا ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ ثُمَّ سَأَلْتُ ابْنًا لِسَلَمَةَ بْنِ الأَكْوَعِ فَحَدَّثَنِي عَنْ أَبِيهِ مِثْلَ ذَلِكَ غَيْرَ أَنَّهُ قَالَ - حِينَ قُلْتُ إِنَّ نَاسًا يَهَابُونَ الصَّلاَةَ عَلَيْهِ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَذَبُوا مَاتَ جَاهِدًا مُجَاهِدًا فَلَهُ أَجْرُهُ مَرَّتَيْنِ ‏"‏ ‏.‏ وَأَشَارَ بِإِصْبَعَيْهِ ‏.‏\hadithno{4669}\hadithtrans{It has been reported on the authority of Salama b. Akwa' who said:On the day of the Battle of Khaibar my brother fought a fierce fight by the side of the Messenger of Allah (ﷺ). His sword rebounded and killed him. The Companions of the Messenger of Allah (may peace be upon hill) talked about his death and doubted (whether it was martyrdom). (They said): (He is) a man killed by his own weapon, and expressed doubt about his affair. Salama said: When the Messenger of Allah (ﷺ) returned from Khaibar, I said: Messenger of Allah, permit me that I may recite to you some rajaz verses. The Messenger of Allah (ﷺ) permitted him. 'Umar b. Khattab said: I know what you will recite. I recited: By God, if God had guided us not, We would hive neither been guided aright nor practised charity, Nor offered prayers. The Messenger of Allah (ﷺ) said: What you have said is true, 'I (continued): And descend on us peace and tranquillity And keep us steadfast if we encounter (with our enemies) And the polytheists have rebelled against us. When I finished my rajaz, the Messenger of Allah (ﷺ) said: Who composed these verses? I said: They were composed by my brother. The Messenger of Allah (ﷺ) said: May God show mercy to him! I said: By God, some people are reluctant to invoke God's mercy on him (because) they say he is a man who died by his own sword. (Hearing this) the Messenger of Allah (ﷺ) said: He died as God's devotee and warrior. Ibn Shihab has said: I asked one of the sons of Salama (b. Akwa') about (the death of 'Amir). He related to me a similar tradition except that he said: When I said some people were reluctant invoke God's blessings on him, the Messenger of Allah (may peace be, upon him said: They lied. ('Amir) died as God's devotee and warrior (in the cause of Allah). For him there is a double reward, and he pointed out this by putting his two fingers together}}
\hadithdefcmd{muslim}{4670}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ الأَحْزَابِ يَنْقُلُ مَعَنَا التُّرَابَ وَلَقَدْ وَارَى التُّرَابُ بَيَاضَ بَطْنِهِ وَهُوَ يَقُولُ ‏"‏ وَاللَّهِ لَوْلاَ أَنْتَ مَا اهْتَدَيْنَا وَلاَ تَصَدَّقْنَا وَلاَ صَلَّيْنَا فَأَنْزِلَنْ سَكِينَةً عَلَيْنَا إِنَّ الأُلَى قَدْ أَبَوْا عَلَيْنَا ‏"‏ ‏.‏ قَالَ وَرُبَّمَا قَالَ ‏"‏ إِنَّ الْمَلاَ قَدْ أَبَوْا عَلَيْنَا إِذَا أَرَادُوا فِتْنَةً أَبَيْنَا ‏"‏ ‏.‏ وَيَرْفَعُ بِهَا صَوْتَهُ ‏.‏\hadithno{4670}\hadithtrans{It has been reported on the authority of Barra' who said:The Messenger of Allah (ﷺ) was carrying the earth with us on the Day of Ahzab and the whiteness of his belly had been covered with earth. (While engaged in this toil) he was reciting: By God, if Thou hadst not guided us We would have neither been guided aright nor practised charity, Nor offered prayers. Descend on us peace and tranquillity. Behold I these people (the Meccans) refused to follow us. According to another version, he recited: The chieftains (of the tribes) refused to follow us When they contemplated mischief, we rejected it. And with this (verse) he would raise his voice}}
\hadithdefcmd{muslim}{4671}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ، ‏.‏ فَذَكَرَ مِثْلَهُ إِلاَّ أَنَّهُ قَالَ ‏ "‏ إِنَّ الأُلَى قَدْ بَغَوْا عَلَيْنَا ‏"‏ ‏.‏\hadithno{4671}\hadithtrans{It has been narrated on the authority of Abu Ishaq who said:I heard from Bara' a similar tradition except that he said:" These people (the Meccans) rebelled against us}}
\hadithdefcmd{muslim}{4672}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ جَاءَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ نَحْفِرُ الْخَنْدَقَ وَنَنْقُلُ التُّرَابَ عَلَى أَكْتَافِنَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ لاَ عَيْشَ إِلاَّ عَيْشُ الآخِرَةِ فَاغْفِرْ لِلْمُهَاجِرِينَ وَالأَنْصَارِ ‏"‏ ‏.‏\hadithno{4672}\hadithtrans{It has been reported on the authority of Sahl b. Sa'd who said:The Messenger of Allah (ﷺ) came to us while we were digging the ditch and were carrying the earth on our shoulders. (Seeing our condition), he said: O God, there is no life but the life of the Hereafter. So forgive Thou the Muhajirs and the Ansar}}
\hadithdefcmd{muslim}{4673}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - حَدَّثَنَا مُحَمَّدُ بْنُ، جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ اللَّهُمَّ لاَ عَيْشَ إِلاَّ عَيْشُ الآخِرَهْ فَاغْفِرْ لِلأَنْصَارِ وَالْمُهَاجِرَهْ ‏"‏ ‏.‏\hadithno{4673}\hadithtrans{It has been narrated on the authority of Anas b. Malik that the Messenger of Allah (ﷺ) said:O God, there is no life, but the life of the Hereafter, So forgive Thou the Ansar and the Muhajirs}}
\hadithdefcmd{muslim}{4674}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏"‏ اللَّهُمَّ إِنَّ الْعَيْشَ عَيْشُ الآخِرَةِ ‏"‏ ‏.‏ قَالَ شُعْبَةُ أَوْ قَالَ ‏"‏ اللَّهُمَّ لاَ عَيْشَ إِلاَّ‎عَيْشُ الآخِرَهْ فَأَكْرِمِ الأَنْصَارَ وَالْمُهَاجِرَهْ ‏"‏ ‏.‏\hadithno{4674}\hadithtrans{According to another version of the tradition, reported on the authority of Anas b. Malik, the Messenger of Allah (may peace he upon him) is reported to have said:O God, there is no life but the life of the Hereafter, So grant honour to the Ansar and the Muhajirs}}
\hadithdefcmd{muslim}{4675}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَشَيْبَانُ بْنُ فَرُّوخَ، قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ، شَيْبَانُ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَبِي التَّيَّاحِ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ كَانُوا يَرْتَجِزُونَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم مَعَهُمْ وَهُمْ يَقُولُونَ اللَّهُمَّ لاَ خَيْرَ إِلاَّ خَيْرُ الآخِرَهْ فَانْصُرِ الأَنْصَارَ وَالْمُهَاجِرَهْ وَفِي حَدِيثِ شَيْبَانَ بَدَلَ فَانْصُرْ فَاغْفِرْ ‏.‏\hadithno{4675}\hadithtrans{According to still another version of the tradition narrated by the same authority, and handed down through a different chain of transmitters, it has been reported that they (the Companions of the Holy Prophet) were reciting rajaz verses and the Messenger of Allah (ﷺ) was (reciting) with them. And they were chanting:O God, there is no good but the good of the Hereafter. So help Thou the Ansar and the Muhajirs. Shaiban substituted" So forgive Thou" for" So help Thou}}
\hadithdefcmd{muslim}{4676}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ أَصْحَابَ، مُحَمَّدٍ صلى الله عليه وسلم كَانُوا يَقُولُونَ يَوْمَ الْخَنْدَقِ نَحْنُ الَّذِينَ بَايَعُوا مُحَمَّدًا عَلَى الإِسْلاَمِ مَا بَقِينَا أَبَدًا أَوْ قَالَ عَلَى الْجِهَادِ ‏.‏ شَكَّ حَمَّادٌ وَالنَّبِيُّ صلى الله عليه وسلم يَقُولُ ‏ "‏ اللَّهُمَّ إِنَّ الْخَيْرَ خَيْرُ الآخِرَهْ فَاغْفِرْ لِلأَنْصَارِ وَالْمُهَاجِرَهْ ‏"‏ ‏.‏\hadithno{4676}\hadithtrans{It has been narrated (through a still difterent chain of transmitters) by Anas that the Companions of Muhammad (ﷺ) were chanting on the day of the Battle of the Ditch:We are those who have sworn allegiance to Muhammad (And made a covenant with him) to follow Islam as long as we live. Hammad is not sure whether Anas said:" Ala'l-Islam" or," Ala'l-Jihad". And the Prophet (ﷺ) was chanting: O God, the real good is the good of the Hereafter, So forgive Thou the Ansar and the Muhajirs}}
\hadithdefcmd{muslim}{4677}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ - عَنْ يَزِيدَ بْنِ أَبِي، عُبَيْدٍ قَالَ سَمِعْتُ سَلَمَةَ بْنَ الأَكْوَعِ، يَقُولُ خَرَجْتُ قَبْلَ أَنْ يُؤَذَّنَ، بِالأُولَى وَكَانَتْ لِقَاحُ رَسُولِ اللَّهِ صلى الله عليه وسلم تَرْعَى بِذِي قَرَدٍ - قَالَ - فَلَقِيَنِي غُلاَمٌ لِعَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ فَقَالَ أُخِذَتْ لِقَاحُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ مَنْ أَخَذَهَا قَالَ غَطَفَانُ قَالَ فَصَرَخْتُ ثَلاَثَ صَرَخَاتٍ يَا صَبَاحَاهْ ‏.‏ قَالَ فَأَسْمَعْتُ مَا بَيْنَ لاَبَتَىِ الْمَدِينَةِ ثُمَّ انْدَفَعْتُ عَلَى وَجْهِي حَتَّى أَدْرَكْتُهُمْ بِذِي قَرَدٍ وَقَدْ أَخَذُوا يَسْقُونَ مِنَ الْمَاءِ فَجَعَلْتُ أَرْمِيهِمْ بِنَبْلِي وَكُنْتُ رَامِيًا وَأَقُولُ أَنَا ابْنُ الأَكْوَعِ وَالْيَوْمَ يَوْمُ الرُّضَّعِ فَأَرْتَجِزُ حَتَّى اسْتَنْقَذْتُ اللِّقَاحَ مِنْهُمْ وَاسْتَلَبْتُ مِنْهُمْ ثَلاَثِينَ بُرْدَةً - قَالَ - وَجَاءَ النَّبِيُّ صلى الله عليه وسلم وَالنَّاسُ فَقُلْتُ يَا نَبِيَّ اللَّهِ إِنِّي قَدْ حَمَيْتُ الْقَوْمَ الْمَاءَ وَهُمْ عِطَاشٌ فَابْعَثْ إِلَيْهِمُ السَّاعَةَ فَقَالَ ‏ "‏ يَا ابْنَ الأَكْوَعِ مَلَكْتَ فَأَسْجِحْ ‏"‏ ‏.‏ - قَالَ - ثُمَّ رَجَعْنَا وَيُرْدِفُنِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى نَاقَتِهِ حَتَّى دَخَلْنَا الْمَدِينَةَ ‏.‏\hadithno{4677}\hadithtrans{It has been narrated on the authority of Yazid b. Abu 'Ubaid who said that he heard Salama b. al-Akwa' say:I went out before the Adhan for the morning prayer had been delivered. The milch she-camels of the Messenger of Allah (ﷺ) were grazing at Dhu Qarad. 'Abd al-Rahman b. Auf's slave met me and said: The milch she-camels of the Messenger of Allah (ﷺ) had been taken away. I said: Who has taken them away? He said: (the people belonging to the tribe of) Ghatafan. I cried thrice: Help! I made the whole city between the two lavas hear my cry. Then I ran straight in their pursuit until I overtook them at Dhu Qarad where they were just going to water their animals. I, being an archer, began to shoot them with my arrows and was saying: I am the son of al-Akwa'. And today is the day when the cowards will meet their doom. I continued to chant until I rescued the milch she-camels from them, and snatched from them thirty mantles. Now, the Messenger of Allah (ﷺ) and some other people came along. I said: Prophet of Allah, I have prevented them from water while they were thirsty. So you should send a force (to punish them). He (the Holy Prophet) said: Ibn al-Akwa', you have taken (what, you have taken). Now let them go. Then we returned and the Messenger of Allah (ﷺ) made me mount behind him on his she-camel until we entered Medina}}
\hadithdefcmd{muslim}{4678}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ، إِبْرَاهِيمَ أَخْبَرَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، كِلاَهُمَا عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ، عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ - وَهَذَا حَدِيثُهُ - أَخْبَرَنَا أَبُو عَلِيٍّ الْحَنَفِيُّ، عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْمَجِيدِ حَدَّثَنَا عِكْرِمَةُ، - وَهُوَ ابْنُ عَمَّارٍ - حَدَّثَنِي إِيَاسُ بْنُ سَلَمَةَ، حَدَّثَنِي أَبِي قَالَ، قَدِمْنَا الْحُدَيْبِيَةَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَنَحْنُ أَرْبَعَ عَشْرَةَ مِائَةً وَعَلَيْهَا خَمْسُونَ شَاةً لاَ تُرْوِيهَا - قَالَ - فَقَعَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى جَبَا الرَّكِيَّةِ فَإِمَّا دَعَا وَإِمَّا بَسَقَ فِيهَا - قَالَ - فَجَاشَتْ فَسَقَيْنَا وَاسْتَقَيْنَا ‏.‏ قَالَ ثُمَّ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَعَانَا لِلْبَيْعَةِ فِي أَصْلِ الشَّجَرَةِ ‏.‏ قَالَ فَبَايَعْتُهُ أَوَّلَ النَّاسِ ثُمَّ بَايَعَ وَبَايَعَ حَتَّى إِذَا كَانَ فِي وَسَطٍ مِنَ النَّاسِ قَالَ ‏"‏ بَايِعْ يَا سَلَمَةُ ‏"‏ ‏.‏ قَالَ قُلْتُ قَدْ بَايَعْتُكَ يَا رَسُولَ اللَّهِ فِي أَوَّلِ النَّاسِ قَالَ ‏"‏ وَأَيْضًا ‏"‏ ‏.‏ قَالَ وَرَآنِي رَسُولُ اللَّهِ صلى الله عليه وسلم عَزِلاً - يَعْنِي لَيْسَ مَعَهُ سِلاَحٌ - قَالَ فَأَعْطَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم حَجَفَةً أَوْ دَرَقَةً ثُمَّ بَايَعَ حَتَّى إِذَا كَانَ فِي آخِرِ النَّاسِ قَالَ ‏"‏ أَلاَ تُبَايِعُنِي يَا سَلَمَةُ ‏"‏ ‏.‏ قَالَ قُلْتُ قَدْ بَايَعْتُكَ يَا رَسُولَ اللَّهِ فِي أَوَّلِ النَّاسِ وَفِي أَوْسَطِ النَّاسِ قَالَ ‏"‏ وَأَيْضًا ‏"‏ ‏.‏ قَالَ فَبَايَعْتُهُ الثَّالِثَةَ ثُمَّ قَالَ لِي ‏"‏ يَا سَلَمَةُ أَيْنَ حَجَفَتُكَ أَوْ دَرَقَتُكَ الَّتِي أَعْطَيْتُكَ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ لَقِيَنِي عَمِّي عَامِرٌ عَزِلاً فَأَعْطَيْتُهُ إِيَّاهَا - قَالَ - فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ إِنَّكَ كَالَّذِي قَالَ الأَوَّلُ اللَّهُمَّ أَبْغِنِي حَبِيبًا هُوَ أَحَبُّ إِلَىَّ مِنْ نَفْسِي ‏"‏ ‏.‏ ثُمَّ إِنَّ الْمُشْرِكِينَ رَاسَلُونَا الصُّلْحَ حَتَّى مَشَى بَعْضُنَا فِي بَعْضٍ وَاصْطَلَحْنَا ‏.‏ قَالَ وَكُنْتُ تَبِيعًا لِطَلْحَةَ بْنِ عُبَيْدِ اللَّهِ أَسْقِي فَرَسَهُ وَأَحُسُّهُ وَأَخْدُمُهُ وَآكُلُ مِنْ طَعَامِهِ وَتَرَكْتُ أَهْلِي وَمَالِي مُهَاجِرًا إِلَى اللَّهِ وَرَسُولِهِ صلى الله عليه وسلم قَالَ فَلَمَّا اصْطَلَحْنَا نَحْنُ وَأَهْلُ مَكَّةَ وَاخْتَلَطَ بَعْضُنَا بِبَعْضٍ أَتَيْتُ شَجَرَةً فَكَسَحْتُ شَوْكَهَا فَاضْطَجَعْتُ فِي أَصْلِهَا - قَالَ - فَأَتَانِي أَرْبَعَةٌ مِنَ الْمُشْرِكِينَ مِنْ أَهْلِ مَكَّةَ فَجَعَلُوا يَقَعُونَ فِي رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَبْغَضْتُهُمْ فَتَحَوَّلْتُ إِلَى شَجَرَةٍ أُخْرَى وَعَلَّقُوا سِلاَحَهُمْ وَاضْطَجَعُوا فَبَيْنَمَا هُمْ كَذَلِكَ إِذْ نَادَى مُنَادٍ مِنْ أَسْفَلِ الْوَادِي يَا لَلْمُهَاجِرِينَ قُتِلَ ابْنُ زُنَيْمٍ ‏.‏ قَالَ فَاخْتَرَطْتُ سَيْفِي ثُمَّ شَدَدْتُ عَلَى أُولَئِكَ الأَرْبَعَةِ وَهُمْ رُقُودٌ فَأَخَذْتُ سِلاَحَهُمْ ‏.‏ فَجَعَلْتُهُ ضِغْثًا فِي يَدِي قَالَ ثُمَّ قُلْتُ وَالَّذِي كَرَّمَ وَجْهَ مُحَمَّدٍ لاَ يَرْفَعُ أَحَدٌ مِنْكُمْ رَأْسَهُ إِلاَّ ضَرَبْتُ الَّذِي فِيهِ عَيْنَاهُ ‏.‏ قَالَ ثُمَّ جِئْتُ بِهِمْ أَسُوقُهُمْ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ - وَجَاءَ عَمِّي عَامِرٌ بِرَجُلٍ مِنَ الْعَبَلاَتِ يُقَالُ لَهُ مِكْرَزٌ ‏.‏ يَقُودُهُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى فَرَسٍ مُجَفَّفٍ فِي سَبْعِينَ مِنَ الْمُشْرِكِينَ فَنَظَرَ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ دَعُوهُمْ يَكُنْ لَهُمْ بَدْءُ الْفُجُورِ وَثِنَاهُ ‏"‏ فَعَفَا عَنْهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنْزَلَ اللَّهُ ‏\{‏ وَهُوَ الَّذِي كَفَّ أَيْدِيَهُمْ عَنْكُمْ وَأَيْدِيَكُمْ عَنْهُمْ بِبَطْنِ مَكَّةَ مِنْ بَعْدِ أَنْ أَظْفَرَكُمْ عَلَيْهِمْ‏\}‏ الآيَةَ كُلَّهَا ‏.‏ قَالَ ثُمَّ خَرَجْنَا رَاجِعِينَ إِلَى الْمَدِينَةِ فَنَزَلْنَا مَنْزِلاً بَيْنَنَا وَبَيْنَ بَنِي لَحْيَانَ جَبَلٌ وَهُمُ الْمُشْرِكُونَ فَاسْتَغْفَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِمَنْ رَقِيَ هَذَا الْجَبَلَ اللَّيْلَةَ كَأَنَّهُ طَلِيعَةٌ لِلنَّبِيِّ صلى الله عليه وسلم وَأَصْحَابِهِ - قَالَ سَلَمَةُ - فَرَقِيتُ تِلْكَ اللَّيْلَةَ مَرَّتَيْنِ أَوْ ثَلاَثًا ثُمَّ قَدِمْنَا الْمَدِينَةَ فَبَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِظَهْرِهِ مَعَ رَبَاحٍ غُلاَمِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَنَا مَعَهُ وَخَرَجْتُ مَعَهُ بِفَرَسِ طَلْحَةَ أُنَدِّيهِ مَعَ الظَّهْرِ فَلَمَّا أَصْبَحْنَا إِذَا عَبْدُ الرَّحْمَنِ الْفَزَارِيُّ قَدْ أَغَارَ عَلَى ظَهْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْتَاقَهُ أَجْمَعَ وَقَتَلَ رَاعِيَهُ قَالَ فَقُلْتُ يَا رَبَاحُ خُذْ هَذَا الْفَرَسَ فَأَبْلِغْهُ طَلْحَةَ بْنَ عُبَيْدِ اللَّهِ وَأَخْبِرْ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنَّ الْمُشْرِكِينَ قَدْ أَغَارُوا عَلَى سَرْحِهِ - قَالَ - ثُمَّ قُمْتُ عَلَى أَكَمَةٍ فَاسْتَقْبَلْتُ الْمَدِينَةَ فَنَادَيْتُ ثَلاَثًا يَا صَبَاحَاهْ ‏.‏ ثُمَّ خَرَجْتُ فِي آثَارِ الْقَوْمِ أَرْمِيهِمْ بِالنَّبْلِ وَأَرْتَجِزُ أَقُولُ أَنَا ابْنُ الأَكْوَعِ وَالْيَوْمَ يَوْمُ الرُّضَّعِ فَأَلْحَقُ رَجُلاً مِنْهُمْ فَأَصُكُّ سَهْمًا فِي رَحْلِهِ حَتَّى خَلَصَ نَصْلُ السَّهْمِ إِلَى كَتِفِهِ - قَالَ - قُلْتُ خُذْهَا وَأَنَا ابْنُ الأَكْوَعِ وَالْيَوْمُ يَوْمُ الرُّضَّعِ قَالَ فَوَاللَّهِ مَا زِلْتُ أَرْمِيهِمْ وَأَعْقِرُ بِهِمْ فَإِذَا رَجَعَ إِلَىَّ فَارِسٌ أَتَيْتُ شَجَرَةً فَجَلَسْتُ فِي أَصْلِهَا ثُمَّ رَمَيْتُهُ فَعَقَرْتُ بِهِ حَتَّى إِذَا تَضَايَقَ الْجَبَلُ فَدَخَلُوا فِي تَضَايُقِهِ عَلَوْتُ الْجَبَلَ فَجَعَلْتُ أُرَدِّيهِمْ بِالْحِجَارَةِ - قَالَ - فَمَا زِلْتُ كَذَلِكَ أَتْبَعُهُمْ حَتَّى مَا خَلَقَ اللَّهُ مِنْ بَعِيرٍ مِنْ ظَهْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ خَلَّفْتُهُ وَرَاءَ ظَهْرِي وَخَلَّوْا بَيْنِي وَبَيْنَهُ ثُمَّ اتَّبَعْتُهُمْ أَرْمِيهِمْ حَتَّى أَلْقَوْا أَكْثَرَ مِنْ ثَلاَثِينَ بُرْدَةً وَثَلاَثِينَ رُمْحًا يَسْتَخِفُّونَ وَلاَ يَطْرَحُونَ شَيْئًا إِلاَّ جَعَلْتُ عَلَيْهِ آرَامًا مِنَ الْحِجَارَةِ يَعْرِفُهَا رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَصْحَابُهُ حَتَّى أَتَوْا مُتَضَايِقًا مِنْ ثَنِيَّةٍ فَإِذَا هُمْ قَدْ أَتَاهُمْ فُلاَنُ بْنُ بَدْرٍ الْفَزَارِيُّ فَجَلَسُوا يَتَضَحَّوْنَ - يَعْنِي يَتَغَدَّوْنَ - وَجَلَسْتُ عَلَى رَأْسِ قَرْنٍ قَالَ الْفَزَارِيُّ مَا هَذَا الَّذِي أَرَى قَالُوا لَقِينَا مِنْ هَذَا الْبَرْحَ وَاللَّهِ مَا فَارَقَنَا مُنْذُ غَلَسٍ يَرْمِينَا حَتَّى انْتَزَعَ كُلَّ شَىْءٍ فِي أَيْدِينَا ‏.‏ قَالَ فَلْيَقُمْ إِلَيْهِ نَفَرٌ مِنْكُمْ أَرْبَعَةٌ ‏.‏ قَالَ فَصَعِدَ إِلَىَّ مِنْهُمْ أَرْبَعَةٌ فِي الْجَبَلِ - قَالَ - فَلَمَّا أَمْكَنُونِي مِنَ الْكَلاَمِ - قَالَ - قُلْتُ هَلْ تَعْرِفُونِي قَالُوا لاَ وَمَنْ أَنْتَ قَالَ قُلْتُ أَنَا سَلَمَةُ بْنُ الأَكْوَعِ وَالَّذِي كَرَّمَ وَجْهَ مُحَمَّدٍ صلى الله عليه وسلم لاَ أَطْلُبُ رَجُلاً مِنْكُمْ إِلاَّ أَدْرَكْتُهُ وَلاَ يَطْلُبُنِي رَجُلٌ مِنْكُمْ ‏.‏ فَيُدْرِكَنِي قَالَ أَحَدُهُمْ أَنَا أَظُنُّ ‏.‏ قَالَ فَرَجَعُوا فَمَا بَرِحْتُ مَكَانِي حَتَّى رَأَيْتُ فَوَارِسَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَتَخَلَّلُونَ الشَّجَرَ - قَالَ - فَإِذَا أَوَّلُهُمُ الأَخْرَمُ الأَسَدِيُّ عَلَى إِثْرِهِ أَبُو قَتَادَةَ الأَنْصَارِيُّ وَعَلَى إِثْرِهِ الْمِقْدَادُ بْنُ الأَسْوَدِ الْكِنْدِيُّ - قَالَ - فَأَخَذْتُ بِعِنَانِ الأَخْرَمِ - قَالَ - فَوَلَّوْا مُدْبِرِينَ قُلْتُ يَا أَخْرَمُ احْذَرْهُمْ لاَ يَقْتَطِعُوكَ حَتَّى يَلْحَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَصْحَابُهُ ‏.‏ قَالَ يَا سَلَمَةُ إِنْ كُنْتَ تُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ وَتَعْلَمُ أَنَّ الْجَنَّةَ حَقٌّ وَالنَّارَ حَقٌّ فَلاَ تَحُلْ بَيْنِي وَبَيْنَ الشَّهَادَةِ ‏.‏ قَالَ فَخَلَّيْتُهُ فَالْتَقَى هُوَ وَعَبْدُ الرَّحْمَنِ - قَالَ - فَعَقَرَ بِعَبْدِ الرَّحْمَنِ فَرَسَهُ وَطَعَنَهُ عَبْدُ الرَّحْمَنِ فَقَتَلَهُ وَتَحَوَّلَ عَلَى فَرَسِهِ وَلَحِقَ أَبُو قَتَادَةَ فَارِسُ رَسُولِ اللَّهِ صلى الله عليه وسلم بِعَبْدِ الرَّحْمَنِ فَطَعَنَهُ فَقَتَلَهُ فَوَالَّذِي كَرَّمَ وَجْهَ مُحَمَّدٍ صلى الله عليه وسلم لَتَبِعْتُهُمْ أَعْدُو عَلَى رِجْلَىَّ حَتَّى مَا أَرَى وَرَائِي مِنْ أَصْحَابِ مُحَمَّدٍ صلى الله عليه وسلم وَلاَ غُبَارِهِمْ شَيْئًا حَتَّى يَعْدِلُوا قَبْلَ غُرُوبِ الشَّمْسِ إِلَى شِعْبٍ فِيهِ مَاءٌ يُقَالُ لَهُ ذُو قَرَدٍ لِيَشْرَبُوا مِنْهُ وَهُمْ عِطَاشٌ - قَالَ - فَنَظَرُوا إِلَىَّ أَعْدُو وَرَاءَهُمْ فَحَلَّيْتُهُمْ عَنْهُ - يَعْنِي أَجْلَيْتُهُمْ عَنْهُ - فَمَا ذَاقُوا مِنْهُ قَطْرَةً - قَالَ - وَيَخْرُجُونَ فَيَشْتَدُّونَ فِي ثَنِيَّةٍ - قَالَ - فَأَعْدُو فَأَلْحَقُ رَجُلاً مِنْهُمْ فَأَصُكُّهُ بِسَهْمٍ فِي نُغْضِ كَتِفِهِ ‏.‏ قَالَ قُلْتُ خُذْهَا وَأَنَا ابْنُ الأَكْوَعِ وَالْيَوْمَ يَوْمُ الرُّضَّعِ قَالَ يَا ثَكِلَتْهُ أُمُّهُ أَكْوَعُهُ بُكْرَةَ قَالَ قُلْتُ نَعَمْ يَا عَدُوَّ نَفْسِهِ أَكْوَعُكَ بُكْرَةَ - قَالَ - وَأَرْدَوْا فَرَسَيْنِ عَلَى ثَنِيَّةٍ قَالَ فَجِئْتُ بِهِمَا أَسُوقُهُمَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ - وَلَحِقَنِي عَامِرٌ بِسَطِيحَةٍ فِيهَا مَذْقَةٌ مِنْ لَبَنٍ وَسَطِيحَةٍ فِيهَا مَاءٌ فَتَوَضَّأْتُ وَشَرِبْتُ ثُمَّ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى الْمَاءِ الَّذِي حَلَّيْتُهُمْ عَنْهُ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَدْ أَخَذَ تِلْكَ الإِبِلَ وَكُلَّ شَىْءٍ اسْتَنْقَذْتُهُ مِنَ الْمُشْرِكِينَ وَكُلَّ رُمْحٍ وَبُرْدَةٍ وَإِذَا بِلاَلٌ نَحَرَ نَاقَةً مِنَ الإِبِلِ الَّذِي اسْتَنْقَذْتُ مِنَ الْقَوْمِ وَإِذَا هُوَ يَشْوِي لِرَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ كَبِدِهَا وَسَنَامِهَا - قَالَ - قُلْتُ يَا رَسُولَ اللَّهِ خَلِّنِي فَأَنْتَخِبُ مِنَ الْقَوْمِ مِائَةَ رَجُلٍ فَأَتَّبِعُ الْقَوْمَ فَلاَ يَبْقَى مِنْهُمْ مُخْبِرٌ إِلاَّ قَتَلْتُهُ - قَالَ - فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى بَدَتْ نَوَاجِذُهُ فِي ضَوْءِ النَّارِ فَقَالَ ‏"‏ يَا سَلَمَةُ أَتُرَاكَ كُنْتَ فَاعِلاً ‏"‏ ‏.‏ قُلْتُ نَعَمْ وَالَّذِي أَكْرَمَكَ ‏.‏ فَقَالَ ‏"‏ إِنَّهُمُ الآنَ لَيُقْرَوْنَ فِي أَرْضِ غَطَفَانَ ‏"‏ ‏.‏ قَالَ فَجَاءَ رَجُلٌ مِنْ غَطَفَانَ فَقَالَ نَحَرَ لَهُمْ فُلاَنٌ جَزُورًا فَلَمَّا كَشَفُوا جِلْدَهَا رَأَوْا غُبَارًا فَقَالُوا أَتَاكُمُ الْقَوْمُ فَخَرَجُوا هَارِبِينَ ‏.‏ فَلَمَّا أَصْبَحْنَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَانَ خَيْرَ فُرْسَانِنَا الْيَوْمَ أَبُو قَتَادَةَ وَخَيْرَ رَجَّالَتِنَا سَلَمَةُ ‏"‏ ‏.‏ قَالَ ثُمَّ أَعْطَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم سَهْمَيْنِ سَهْمُ الْفَارِسِ وَسَهْمُ الرَّاجِلِ فَجَمَعَهُمَا لِي جَمِيعًا ثُمَّ أَرْدَفَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَرَاءَهُ عَلَى الْعَضْبَاءِ رَاجِعِينَ إِلَى الْمَدِينَةِ - قَالَ - فَبَيْنَمَا نَحْنُ نَسِيرُ قَالَ وَكَانَ رَجُلٌ مِنَ الأَنْصَارِ لاَ يُسْبَقُ شَدًّا - قَالَ - فَجَعَلَ يَقُولُ أَلاَ مُسَابِقٌ إِلَى الْمَدِينَةِ هَلْ مِنْ مُسَابِقٍ فَجَعَلَ يُعِيدُ ذَلِكَ - قَالَ - فَلَمَّا سَمِعْتُ كَلاَمَهُ قُلْتُ أَمَا تُكْرِمُ كَرِيمًا وَلاَ تَهَابُ شَرِيفًا قَالَ لاَ إِلاَّ أَنْ يَكُونَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ قُلْتُ يَا رَسُولَ اللَّهِ بِأَبِي وَأُمِّي ذَرْنِي فَلأُسَابِقَ الرَّجُلَ قَالَ ‏"‏ إِنْ شِئْتَ ‏"‏ ‏.‏ قَالَ قُلْتُ اذْهَبْ إِلَيْكَ وَثَنَيْتُ رِجْلَىَّ فَطَفَرْتُ فَعَدَوْتُ - قَالَ - فَرَبَطْتُ عَلَيْهِ شَرَفًا أَوْ شَرَفَيْنِ أَسْتَبْقِي نَفَسِي ثُمَّ عَدَوْتُ فِي إِثْرِهِ فَرَبَطْتُ عَلَيْهِ شَرَفًا أَوْ شَرَفَيْنِ ثُمَّ إِنِّي رَفَعْتُ حَتَّى أَلْحَقَهُ - قَالَ - فَأَصُكُّهُ بَيْنَ كَتِفَيْهِ - قَالَ - قُلْتُ قَدْ سُبِقْتَ وَاللَّهِ قَالَ أَنَا أَظُنُّ ‏.‏ قَالَ فَسَبَقْتُهُ إِلَى الْمَدِينَةِ قَالَ فَوَاللَّهِ مَا لَبِثْنَا إِلاَّ ثَلاَثَ لَيَالٍ حَتَّى خَرَجْنَا إِلَى خَيْبَرَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَجَعَلَ عَمِّي عَامِرٌ يَرْتَجِزُ بِالْقَوْمِ تَاللَّهِ لَوْلاَ اللَّهُ مَا اهْتَدَيْنَا وَلاَ تَصَدَّقْنَا وَلاَ صَلَّيْنَا وَنَحْنُ عَنْ فَضْلِكَ مَا اسْتَغْنَيْنَا فَثَبِّتِ الأَقْدَامَ إِنْ لاَقَيْنَا وَأَنْزِلَنْ سَكِينَةً عَلَيْنَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ قَالَ أَنَا عَامِرٌ ‏.‏ قَالَ ‏"‏ غَفَرَ لَكَ رَبُّكَ ‏"‏ ‏.‏ قَالَ وَمَا اسْتَغْفَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم لإِنْسَانٍ يَخُصُّهُ إِلاَّ اسْتُشْهِدَ ‏.‏ قَالَ فَنَادَى عُمَرُ بْنُ الْخَطَّابِ وَهُوَ عَلَى جَمَلٍ لَهُ يَا نَبِيَّ اللَّهِ لَوْلاَ مَا مَتَّعْتَنَا بِعَامِرٍ ‏.‏ قَالَ فَلَمَّا قَدِمْنَا خَيْبَرَ قَالَ خَرَجَ مَلِكُهُمْ مَرْحَبٌ يَخْطِرُ بِسَيْفِهِ وَيَقُولُ قَدْ عَلِمَتْ خَيْبَرُ أَنِّي مَرْحَبُ شَاكِي السِّلاَحِ بَطَلٌ مُجَرَّبُ إِذَا الْحُرُوبُ أَقْبَلَتْ تَلَهَّبُ قَالَ وَبَرَزَ لَهُ عَمِّي عَامِرٌ فَقَالَ قَدْ عَلِمَتْ خَيْبَرُ أَنِّي عَامِرٌ شَاكِي السِّلاَحِ بَطَلٌ مُغَامِرٌ قَالَ فَاخْتَلَفَا ضَرْبَتَيْنِ فَوَقَعَ سَيْفُ مَرْحَبٍ فِي تُرْسِ عَامِرٍ وَذَهَبَ عَامِرٌ يَسْفُلُ لَهُ فَرَجَعَ سَيْفُهُ عَلَى نَفْسِهِ فَقَطَعَ أَكْحَلَهُ فَكَانَتْ فِيهَا نَفْسُهُ ‏.‏ قَالَ سَلَمَةُ فَخَرَجْتُ فَإِذَا نَفَرٌ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم يَقُولُونَ بَطَلَ عَمَلُ عَامِرٍ قَتَلَ نَفْسَهُ قَالَ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم وَأَنَا أَبْكِي فَقُلْتُ يَا رَسُولَ اللَّهِ بَطَلَ عَمَلُ عَامِرٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ قَالَ ذَلِكَ ‏"‏ ‏.‏ قَالَ قُلْتُ نَاسٌ مِنْ أَصْحَابِكَ ‏.‏ قَالَ ‏"‏ كَذَبَ مَنْ قَالَ ذَلِكَ بَلْ لَهُ أَجْرُهُ مَرَّتَيْنِ ‏"‏ ‏.‏ ثُمَّ أَرْسَلَنِي إِلَى عَلِيٍّ وَهُوَ أَرْمَدُ فَقَالَ ‏"‏ لأُعْطِيَنَّ الرَّايَةَ رَجُلاً يُحِبُّ اللَّهَ وَرَسُولَهُ أَوْ يُحِبُّهُ اللَّهُ وَرَسُولُهُ ‏"‏ ‏.‏ قَالَ فَأَتَيْتُ عَلِيًّا فَجِئْتُ بِهِ أَقُودُهُ وَهُوَ أَرْمَدُ حَتَّى أَتَيْتُ بِهِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَبَسَقَ فِي عَيْنَيْهِ فَبَرَأَ وَأَعْطَاهُ الرَّايَةَ وَخَرَجَ مَرْحَبٌ فَقَالَ قَدْ عَلِمَتْ خَيْبَرُ أَنِّي مَرْحَبُ شَاكِي السِّلاَحِ بَطَلٌ مُجَرَّبُ إِذَا الْحُرُوبُ أَقْبَلَتْ تَلَهَّبُ فَقَالَ عَلِيٌّ أَنَا الَّذِي سَمَّتْنِي أُمِّي حَيْدَرَهْ كَلَيْثِ غَابَاتٍ كَرِيهِ الْمَنْظَرَهْ أُوفِيهِمُ بِالصَّاعِ كَيْلَ السَّنْدَرَهْ قَالَ فَضَرَبَ رَأْسَ مَرْحَبٍ فَقَتَلَهُ ثُمَّ كَانَ الْفَتْحُ عَلَى يَدَيْهِ ‏.‏\hadithno{4678}\hadithtrans{It has been narrated on the authority of Ibn Salama. He heard the tradition from his father who said:We arrived at Hudaibiya with the Messenger of Allah (ﷺ) and we were fourteen hundred in number. There were fifty goats for them which could not be watered (by the small quantity of water in the local well). So, the Messenger of Allah (ﷺ) sat on the brink of the well. Either he prayed or spat into the well The water welled up. We drank and watered (the beasts as well). Then the Messenger of Allah (ﷺ) called us to take the vow of allegiance, as he was sitting at the base of a tree. I was the first man to take the vow. Then other people took the vow. When half the number of people had done so, he said to me: You take the vow, Salama. I said: I was one of those who took the vow in the first instance. He said: (You may do) again. Then the Messenger. of Allah (ﷺ) saw that I was without weapons. He gave me a big or a small shield. Then he continued to administer vows to the people until it was the last batch of them. He said (to me): Won't you swear allegiance, Salama? I said: Messenger of Allah, I took the oath with the first batch of the people and then again when you were in the middle of the people. He said: (Doesn't matter), you may (do so) again. So I took the oath of allegiance thrice. Then he said to me: Salama, where is the shield which I gave to thee? I said: Messenger of Allah, my uncle 'Amir met me and he was without any weapons. So I gave the shield to him. The Messenger of Allah (ﷺ) laughed and said: You are like a person of the days gone by who said: O God. I seek a friend who is dearer to me than myself. (When all Companions had sworn allegiance to the Holy Prophet), the polytheists sent messages of peace, until people could move from our camp to that of the Meccans and vice versa. Finally, the peace treaty was concluded. I was a dependant of Talha b. Ubaidullah. I watered his horse, rubbed its back. I served Talha (doing odd jobs for him) and partook from his food. I had left my family and my property as an emigrant in the cause of Allah and His Messenger (may peace be uron him). When we and the people of Mecca had concluded a peace treaty and the people of one side began to mix with those of the other, I came to a tree, swept away its thorns and lay down (for rest) at its base; (while I lay there), four of the polytheists from the Meccans came to me and began to talk ill of the Messenger of Allah (ﷺ). I got enraged with them and moved to another tree. They hung their weapons (to the branches of the tree) and lay down (for rest). (While they lay there), somebody from the lower part of the valley cried out: Run up, O Muhajirs! Ibn Zunaim has been murdered. I drew my sword and attacked these four while they were asleep. I seized their arms and collected them up in my hand, and said: By the Being Who has conferred honour upon Muhammad, none of you shall raise his head, else I will smite his face. (Then) I came driving them along to the Prophet (ﷺ). (At the same time). my uncle Amir came (to him) with a man from" Abalat called Mikraz. Amir was dragging him on a horse with a thick covering on its back along with seventy polytheists. The Messenger of Allah (ﷺ) cast a glance at them and said: Let them go (so that) they may prove guilty of breach of trust more than once (before we take action against them). So the Messenger of Allah (ﷺ) forgave them. On this occasion. God revealed the Qur'anic verse:" It is He Who restrained their hands from you and your hands from them in the valley of Mecca after He had granted you a victory over them" (xlviii. 24). Then we moved returning to Medina, and halted at a place where there was a mountain between us and Banu Lihyan who were polytheists. The Messenaer of Allah (ﷺ) asked God's forgiveness for one who ascended the mountain at night to act as a scout for the Messenger of Allah (ﷺ) and his Compinions. I ascended (that mountain) twice or thrice that night. (At last) we reached Medina. The Messenger of Allah (ﷺ) sent his camels with his slave, Rabah, and I was with him. I (also) went to the pasture with the horse of Talha along with the camels. When the day dawned, Abd al-Rahman al-Fazari made a raid and drove away all the camels of the Messenger of Allah (ﷺ), and killed the man who looked after them. I said: Rabah, ride this horse, take it to Talha b. 'Ubaidullah and Inform the Messenger of Allah (ﷺ) that the polytheists have made away with his camels. Then I stood upon a hillock and turning my face to Medina, shouted thrice: Come to our help I Then I set out in pursuit of the raiders, shooting at them with arrows and chanting a (self-eulogatory) verse in the Iambic metre: I am the son of al-Akwa' And today is the day of defeat for the mean. I would overtake a man from them, shoot at him an arrow which, piercing through the saddle, would reach his shoulder. and I would say: Take it, chanting at the same time the verse And I am the son of al-Akwa' And tody is the day of defeat for the mean. By God, I continued shooting at them and hamstringing their animals. Whenever a horseman turned upon me, I would come to a tree and (hid myself) sitting at its base. Then I would shoot at him and hamstring his horse. (At last) they entered a narrow mountain gorge. I ascended that mountain and held them at bay throwing stones at them. I continued to chase them in this way until I got all the camels of the Messenger of Allah (ﷺ) released and no camel was left with them. They left me; then I followed them shooting at them (continually) until they dropped more than thirty mantles and thirty lances. lightening their burden. On everything they dropped, I put a mark with the help of (a piece of) stone so that the Messenger of Allah (ﷺ) and his Companions might recognise them (that it was booty left by the enemy). (They went on) until They came to a narrow valley when so and so, son of Badr al-Fazari joined them. They (now) sat down to take their breakfast and I sat on the top of a tapering rock. Al-Fazari said: Who is that fellow I am seeing? They said: This fellow has harassed us. By God, he has not left us since dusk and has been (continually) shooting at us until he has snatched everything from our hands. He said: Four of you should make a dash at him (and kill him). (Accordingly), four of them ascended the mountain coming towards me. When it became possible for me to talk to them, I said: Do you recognise me? They said: No. Who are thou? I said: I am Salama, son of al-Akwa'. By the Being Who has honoured the countenance of Muhammad (ﷺ) I can kill any of you I like but none of you will be able to kill me. One of them said: I think (he is right). So they returned. I did not move from my place until I saw the horsemen of the Messenger of Allah (ﷺ), who came riding through the trees. Lo! the foremost among them was Akhram al-Asadi. Behind him was Abu Qatada al-Ansari and behind him was al-Miqdad b. al-Aswad al-Kindi. I caught hold of the rein of Akhram's horse (Seeing this). they (the raiders) fled. I said (to Akhram): Akhram, guard yourself against them until Allah's Messenger (ﷺ) and his Companions join you. He said: ) Salama, if you believe In Allah and the Day of Judgment and (if) you kaow that Paradise is a reality and Hell is a reality, you should not stand between me and martyrdom. so I let him go. Akhram and Abd al-Rahman (Fazari) met in combat. Akhram hamstrung Abd al-Rahman's horse and the latter struck him with his lance and killed him. Abd al-Rabman turned about riding Akhram's horse. Abu Qatada, a horse-man of the Messenger of Allah (ﷺ), met 'Abd al-Rahman (in combat), smote him with his lance and killed him. By the Being Who honoured the countenance of Muhammad (may peace oe upon him), I followed them running on my feet (so fast) that I couldn't see behind me the Companions of Muhammad (ﷺ), nor any dust raised by their horses. (I followed them) until before sunset they reached a valley which had a spring of water, which was called Dhu Qarad, so that they could have a drink, for they were thirsty. They saw me running towards them. I turned them out of the valley before they could drink a drop of its water. They left the valley and ran down a slope. I ran (behind them), overtook a man from them, shot him with an arrow through the shoulder blade and said: Take this. I am the son of al-Akwa'; and today is the day of annihilation for the people who are mean. The fellow (who was wounded) said: May his mother weep over him! Are you the Akwa' who has been chasing us since morning? I said: Yes, O enemy of thyself, the same Akwa'. They left two horses dead tired on the hillock and I came dragging them along to the Messenger of Allah (ﷺ). I met 'Amir who had with him a container having milk diluted with water and a container having water. I performed ablution with the water and drank the milk. Then I came to the Messenger of Allah (ﷺ) while he was at (the spring of) water from which I had driven them away. The Messenger of Allah (ﷺ) had captured those camels and everything else I had captured and all the lances and mantles I had snatched from the polytheists and Bilal had slaughtered a she-camel from the camels I had seized from the people, and was roasting its liver and hump for the Messenger of Allah (ﷺ). I said: Messenger of Allah, let me select from our people one hundred men and I will follow the marauders and I will finish them all so that nobody is left to convey the news (of their destruction to their people). (At these words of mine), the Messenger of Allah (ﷺ) laughed so much that his molar teeth could be seen in the light of the fire, and he said: Salama, do you think you can do this? I said: Yes, by the Being Who has honoured you. He said: Now they have reached the land of Ghatafan where they are being feted. (At this time) a man from the Ghatafan came along and said: So and so slaughtered a camel for them. When they were exposing its skin, they saw dust (being raised far off). They said: They (Akwa' and his companions) have come. So. they went away fleeing. When it was morning, the Messenger of Allah (ﷺ) said: Our best horseman today is Abu Qatada and our best footman today is Salama. Then he gave me two shares of the booty-the share meant for the horseman and the share meant for the footman, and combined both of them for me. Intending to return to Medina, he made me mount behind him on his she-camel named al-Adba'. While we were travelling, a man from the Ansar who could not be beaten in a race said: Is there anyone who could compete (with me) in race to Medina? Is there any competitor? He continued repeating this. When I heard his talk, I said: Don't you show consideration to a dignified person and don't you have awe for a noble man? He said: No, unless he be the Messenger of Allah (ﷺ). I said: Messenger of Allah, may my father and mother be thy ransom, let me get down so that I may beat this man (in the race). He said: It you wish, (you may). I said (to the man): I am coming to thee, I then turned my feet. sprang up and tan and gasped (for a while) when one or two elevated places were left and again followed his heel and again gasped (for a while) when one or two elevated places were left and again dashed until I joined him and gave a blow between his shoulders. I said: You have been overtaken, by God. He said: I think so. Thus, I reached Medina ahead of him. By God, we had stayed there only three nights when we set out to Khaibar with the Messenger of Allah (ﷺ). (On the way) my uncle, Amir, began to recite the following rajaz verses for the people: By God, if Thou hadst not guided us aright, We would have neither practised charity nor offered prayers. (O God! ) We cannot do without Thy favours; Keep us steadfast when we encounter the enemy, And descend tranquillity upon us. The Messenger of Allah (ﷺ) said: Who is this? 'Amir said: it is 'Amir. He said: May thy God forgive thee! The narrator said: Whenever the Messenger of Allah (ﷺ) asked forgiveness for a particular person, he was sure to embrace martyrdom. Umar b. Khattab who was riding on his camel called out: Prophet of Allah, I wish you had allowed us to benefit from Amir. Salama continued: When we reached Khaibar, its king named Marhab advanced brandishing his sword and chanting: Khaibar knows that I am Marhab (who behaves like) A fully armed, and well-tried warrior. When the war comes spreading its flames. My uncle, Amir, came out to combat with him, saying: Khaibar certainly knows that I am 'Amir, A fully armed veteran who plunges into battles. They exchanged blows. Marbab's sword struck the shield of 'Amir who bent forward to attack his opponent from below, but his sword recoiled upon him and cut the main artery: in his forearm which caused his death. Salama said: I came out and heard some people among the Companions of the Prophet (ﷺ) saying: Amir's deed has been wasted; he has killed himself. So I came to the Prophet (ﷺ) weeping and I said: Messenger of Allah. Amir's deed has been wasted. The Messenger (ﷺ) said: Who passed this remark? I said: Some of your Companions. He said: He who has passed that remark has told a lie, for 'Amir there is a double reward. Then he sent me to 'Ali who had sore eyes, and said: I will give the banner to a man who loves Allah and His Messenger or whom Allah and His Messenger love. So I went to 'Ali, brought him beading him along and he had sore eyes, and I took him to the Messenger of Allah (ﷺ), who applied his saliva to his eyes and he got well. The Messenger of Allah (ﷺ) gave him the banner (and 'Ali went to meet Marhab in a single combat). The latter advanced chanting: Khaibar knows certainly that I am Marhab, A fully armed and well-tried valorous warrior (hero) When war comes spreading its flames. 'Ali chanted in reply: I am the one whose mother named him Haidar, (And am) like a lion of the forest with a terror-striking countenance. I give my opponents the measure of sandara in exchange for sa' (i. e. return thir attack with one that is much more fierce). The narrator said: 'Ali struck at the head of Mirhab and killed him, so the victory (capture of Khaibar) was due to him. This long tradition has also been handed down Through a different chain of transmitters}}
\hadithdefcmd{muslim}{4679}{حَدَّثَنِي عَمْرُو بْنُ مُحَمَّدٍ النَّاقِدُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ ثَمَانِينَ، رَجُلاً مِنْ أَهْلِ مَكَّةَ هَبَطُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ جَبَلِ التَّنْعِيمِ مُتَسَلِّحِينَ يُرِيدُونَ غِرَّةَ النَّبِيِّ صلى الله عليه وسلم وَأَصْحَابِهِ فَأَخَذَهُمْ سَلَمًا فَاسْتَحْيَاهُمْ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَهُوَ الَّذِي كَفَّ أَيْدِيَهُمْ عَنْكُمْ وَأَيْدِيَكُمْ عَنْهُمْ بِبَطْنِ مَكَّةَ مِنْ بَعْدِ أَنْ أَظْفَرَكُمْ عَلَيْهِمْ‏\}‏\hadithno{4679}\hadithtrans{It has been narrated on the authority of Anas b. Malik that eighty Persons from the inhabitants of Mecca swooped down upon the Messenger of Allah (ﷺ) from the mountain of Tan'im. They were armed and wanted to attack the Prophet (ﷺ) and his Companions unawares. He (the Holy Prophet) captured them but spared their lives. So, God, the Exalted and Glorious, revealed the verses:" It is He Who restrained your hands from them and their hands from you in the valley of Mecca after He had given you a victory over them}}
\hadithdefcmd{muslim}{4682}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْزُو بِأُمِّ سُلَيْمٍ وَنِسْوَةٍ مِنَ الأَنْصَارِ مَعَهُ إِذَا غَزَا فَيَسْقِينَ الْمَاءَ وَيُدَاوِينَ الْجَرْحَى ‏.‏\hadithno{4682}\hadithtrans{It has been narrated on the authority of Anas b. Malik who said that the Messenger of Allah (ﷺ) allowed Umm Sulaim and some other women of the Ansar to accompany him when he went to war; they would give water (to the soldiers) and would treat the wounded}}
\hadithdefcmd{muslim}{4683}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَمْرٍو، - وَهُوَ أَبُو مَعْمَرٍ الْمِنْقَرِيُّ - حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - وَهُوَ ابْنُ صُهَيْبٍ - عَنْ أَنَسِ، بْنِ مَالِكٍ قَالَ لَمَّا كَانَ يَوْمُ أُحُدٍ انْهَزَمَ نَاسٌ مِنَ النَّاسِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَأَبُو طَلْحَةَ بَيْنَ يَدَىِ النَّبِيِّ صلى الله عليه وسلم مُجَوِّبٌ عَلَيْهِ بِحَجَفَةٍ - قَالَ - وَكَانَ أَبُو طَلْحَةَ رَجُلاً رَامِيًا شَدِيدَ النَّزْعِ وَكَسَرَ يَوْمَئِذٍ قَوْسَيْنِ أَوْ ثَلاَثًا - قَالَ - فَكَانَ الرَّجُلُ يَمُرُّ مَعَهُ الْجَعْبَةُ مِنَ النَّبْلِ فَيَقُولُ انْثُرْهَا لأَبِي طَلْحَةَ ‏.‏ قَالَ وَيُشْرِفُ نَبِيُّ اللَّهِ صلى الله عليه وسلم يَنْظُرُ إِلَى الْقَوْمِ فَيَقُولُ أَبُو طَلْحَةَ يَا نَبِيَّ اللَّهِ بِأَبِي أَنْتَ وَأُمِّي لاَ تُشْرِفْ لاَ يُصِبْكَ سَهْمٌ مِنْ سِهَامِ الْقَوْمِ نَحْرِي دُونَ نَحْرِكَ قَالَ وَلَقَدْ رَأَيْتُ عَائِشَةَ بِنْتَ أَبِي بَكْرٍ وَأُمَّ سُلَيْمٍ وَإِنَّهُمَا لَمُشَمِّرَتَانِ أَرَى خَدَمَ سُوقِهِمَا تَنْقُلاَنِ الْقِرَبَ عَلَى مُتُونِهِمَا ثُمَّ تُفْرِغَانِهِ فِي أَفْوَاهِهِمْ ثُمَّ تَرْجِعَانِ فَتَمْلآنِهَا ثُمَّ تَجِيئَانِ تُفْرِغَانِهِ فِي أَفْوَاهِ الْقَوْمِ وَلَقَدْ وَقَعَ السَّيْفُ مِنْ يَدَىْ أَبِي طَلْحَةَ إِمَّا مَرَّتَيْنِ وَإِمَّا ثَلاَثًا مِنَ النُّعَاسِ ‏.‏\hadithno{4683}\hadithtrans{It has been narrated on the authority of Anas b. Malik who said:On the Day of Uhud some of the people, being defeated, left the Prophet (ﷺ), but Abu Talha stood before him covering him with a shield. Abu Talha was a powerful archer who broke two or three bows that day. When a man would pass by carrying a quiver containing arrows, he would say: Spare them for Abu Talha. Whenever the Prophet (ﷺ) raised his head to look at the people, Abu Talha would say: Prophet of Allah, may my father and my mother be thy ransom, do not raise your head lest you be struck by an arrow shot by the enemy. My neck is before your neck. The narrator said: I saw `A'isha bint Abu Bakr and Umm Sulaim. Both of them had tucked up their garments, so I could see the anklets on their feet. They were carrying water-skins on their backs and would pour water into the mouths of the people. They would then go back (to the well), would fill them again and would return to pour water into the mouths of the soldiers. (On this day), Abu Talha's sword dropped down from his hands twice or thrice because of drowsiness}}
\hadithdefcmd{muslim}{4684}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ بْنِ هُرْمُزَ، أَنَّ نَجْدَةَ، كَتَبَ إِلَى ابْنِ عَبَّاسٍ يَسْأَلُهُ عَنْ خَمْسِ، خِلاَلٍ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ لَوْلاَ أَنْ أَكْتُمَ، عِلْمًا مَا كَتَبْتُ إِلَيْهِ ‏.‏ كَتَبَ إِلَيْهِ نَجْدَةُ أَمَّا بَعْدُ فَأَخْبِرْنِي هَلْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْزُو بِالنِّسَاءِ وَهَلْ كَانَ يَضْرِبُ لَهُنَّ بِسَهْمٍ وَهَلْ كَانَ يَقْتُلُ الصِّبْيَانَ وَمَتَى يَنْقَضِي يُتْمُ الْيَتِيمِ وَعَنِ الْخُمْسِ لِمَنْ هُوَ فَكَتَبَ إِلَيْهِ ابْنُ عَبَّاسٍ كَتَبْتَ تَسْأَلُنِي هَلْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَغْزُو بِالنِّسَاءِ وَقَدْ كَانَ يَغْزُو بِهِنَّ فَيُدَاوِينَ الْجَرْحَى وَيُحْذَيْنَ مِنَ الْغَنِيمَةِ وَأَمَّا بِسَهْمٍ فَلَمْ يَضْرِبْ لَهُنَّ وَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَكُنْ يَقْتُلُ الصِّبْيَانَ فَلاَ تَقْتُلِ الصِّبْيَانَ وَكَتَبْتَ تَسْأَلُنِي مَتَى يَنْقَضِي يُتْمُ الْيَتِيمِ فَلَعَمْرِي إِنَّ الرَّجُلَ لَتَنْبُتُ لِحْيَتُهُ وَإِنَّهُ لَضَعِيفُ الأَخْذِ لِنَفْسِهِ ضَعِيفُ الْعَطَاءِ مِنْهَا فَإِذَا أَخَذَ لِنَفْسِهِ مِنْ صَالِحِ مَا يَأْخُذُ النَّاسُ فَقَدْ ذَهَبَ عَنْهُ الْيُتْمُ وَكَتَبْتَ تَسْأَلُنِي عَنِ الْخُمْسِ لِمَنْ هُوَ وَإِنَّا كُنَّا نَقُولُ هُوَ لَنَا ‏.‏ فَأَبَى عَلَيْنَا قَوْمُنَا ذَاكَ ‏.‏\hadithno{4684}\hadithtrans{It has been narrated on the authority of Yazid b. Hurmuz that Najda wrote to Ibn Abbas inquiring of him five things. Ibn Abbas said:If I had not the fear of committing (sin) for concealing the knowledge I would not have written to him. Najda wrote to him saying (after praising the Almighty and invoking blessings on the Prophet): Tell me whether the Messenger of Allah (ﷺ) took women to participate with him in Jihad; (if he did), whether he allotted them a regular share from the booty; whether he killed the children of (the enemy in the war), how long an orphan would be entitled to consideration as such, and for whom the Khums (fifth part of the booty) was booty. Ibn Abbas wrote to him: You have written asking me whether the Messenger of Allah (ﷺ) took women with him to participate in Jihad. He did take them to the battle and sometimes he fought along with them. They would treat the wounded and were given a reward from the booty, but he did not assign any regular share for them. And the Messenger of Allah (ﷺ) did not kill the children of the enemy, so you should not kill the children. Also you have written to me asking me when the orphanhood of an orphan comes to an end. By my life, if a man has become bearded but is still incapable of getting his due from others or fulfilling his obligation towards them, (he is yet an orphan to be treated as such), but when he can look after his interests like grown-up people, he is no longer an orphan. And you have written to me inquiring about Khums as to whom it is meant for. (In this connection) we (the kinsmen of the Messenger of Allah) used to say: It is for us, but those people (i.e. Banu Umayya) have denied it to us}}
\hadithdefcmd{muslim}{4685}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، كِلاَهُمَا عَنْ حَاتِمِ بْنِ إِسْمَاعِيلَ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ بْنِ هُرْمُزَ، أَنَّ نَجْدَةَ، كَتَبَ إِلَى ابْنِ عَبَّاسٍ يَسْأَلُهُ عَنْ خِلاَلٍ، ‏.‏ بِمِثْلِ حَدِيثِ سُلَيْمَانَ بْنِ بِلاَلٍ غَيْرَ أَنَّ فِي، حَدِيثِ حَاتِمٍ وَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَكُنْ يَقْتُلُ الصِّبْيَانَ فَلاَ تَقْتُلِ الصِّبْيَانَ إِلاَّ أَنْ تَكُونَ تَعْلَمُ مَا عَلِمَ الْخَضِرُ مِنَ الصَّبِيِّ الَّذِي قَتَلَ ‏.‏ وَزَادَ إِسْحَاقُ فِي حَدِيثِهِ عَنْ حَاتِمٍ وَتُمَيِّزَ الْمُؤْمِنَ فَتَقْتُلَ الْكَافِرَ وَتَدَعَ الْمُؤْمِنَ ‏.‏\hadithno{4685}\hadithtrans{This tradition has been narrated by the game authority (Yazid b. Hurmus) through a different chain of transmitters with the following difference in the elucidation of one of the points raised by Najda in his letter to Ibn Abas:The Messenger of Allah (ﷺ) used not to kill the children, so thou shouldst not kill them unless you could know what Khadir had known about the child he killed, or you could distinguish between a child who would grow up to he a believer (and a child who would grow up to be a non-believer), so that you killed the (prospective) non-believer and left the (prospective) believer aside}}
\hadithdefcmd{muslim}{4686}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ يَزِيدَ بْنِ هُرْمُزَ، قَالَ كَتَبَ نَجْدَةُ بْنُ عَامِرٍ الْحَرُورِيُّ إِلَى ابْنِ عَبَّاسٍ يَسْأَلُهُ عَنِ الْعَبْدِ، وَالْمَرْأَةِ يَحْضُرَانِ الْمَغْنَمَ هَلْ يُقْسَمُ لَهُمَا وَعَنْ قَتْلِ الْوِلْدَانِ وَعَنِ الْيَتِيمِ مَتَى يَنْقَطِعُ عَنْهُ الْيُتْمُ وَعَنْ ذَوِي الْقُرْبَى مَنْ هُمْ فَقَالَ لِيَزِيدَ اكْتُبْ إِلَيْهِ فَلَوْلاَ أَنْ يَقَعَ فِي أُحْمُوقَةٍ مَا كَتَبْتُ إِلَيْهِ اكْتُبْ إِنَّكَ كَتَبْتَ تَسْأَلُنِي عَنِ الْمَرْأَةِ وَالْعَبْدِ يَحْضُرَانِ الْمَغْنَمَ هَلْ يُقْسَمُ لَهُمَا شَىْءٌ وَإِنَّهُ لَيْسَ لَهُمَا شَىْءٌ إِلاَّ أَنْ يُحْذَيَا وَكَتَبْتَ تَسْأَلُنِي عَنْ قَتْلِ الْوِلْدَانِ وَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَقْتُلْهُمْ وَأَنْتَ فَلاَ تَقْتُلْهُمْ إِلاَّ أَنْ تَعْلَمَ مِنْهُمْ مَا عَلِمَ صَاحِبُ مُوسَى مِنَ الْغُلاَمِ الَّذِي قَتَلَهُ وَكَتَبْتَ تَسْأَلُنِي عَنِ الْيَتِيمِ مَتَى يَنْقَطِعُ عَنْهُ اسْمُ الْيُتْمِ وَإِنَّهُ لاَ يَنْقَطِعُ عَنْهُ اسْمُ الْيُتْمِ حَتَّى يَبْلُغَ وَيُؤْنَسَ مِنْهُ رُشْدٌ وَكَتَبْتَ تَسْأَلُنِي عَنْ ذَوِي الْقُرْبَى مَنْ هُمْ وَإِنَّا زَعَمْنَا أَنَّا هُمْ فَأَبَى ذَلِكَ عَلَيْنَا قَوْمُنَا ‏.‏\hadithno{4686}\hadithtrans{It has been narrated on the authority of Yazid b. Hurmuz who said:Najda b. 'Amir al-Haruri wrote to Ibn Abbas asking him about the slave and the woman as to whether they would get a share from the booty (it they participated in Jihad) ; about the killing of (enemy) children (in war) ; about the orphan as to when his orphanhood comes to an end; about kinsmen (of the Holy Prophet) as to who they are. He said to Yazid: Write to him. (If he were not likely to fall into folly, I would not have written to him.) Write: You have written asking about the woman and the slave whether they would get a share of the booty if they participated in Jihad. (You should know that) there is nothing of the sort for them except that they will be given a prize. And you have written asking me about the killing of the enemy children in war. (You should understand that) the Messenger of Allah (may peare be upon him) did not kill them. and thou shouldst not kill them unless thou knew what the companion of Moses (i. e. Khadir) knew about the boy he had killed. And you have written asking me about the orphan as to when the period of his orphanhood comes to an end, so that the sobriquet of" orphan" is dropped from him. (In this regard, you should know that) the sobriquet" orphan" will not be dropped from him until he attains maturity of body and mind. And you have written asking me about the close relatives (of the Holy Prophet) as to who they are. We think that it is we, but our people have denied us this (position and its concomitant privileges)}}
\hadithdefcmd{muslim}{4687}{وَحَدَّثَنَاهُ عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ الْعَبْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أُمَيَّةَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ يَزِيدَ بْنِ هُرْمُزَ، قَالَ كَتَبَ نَجْدَةُ إِلَى ابْنِ عَبَّاسٍ ‏.‏ وَسَاقَ الْحَدِيثَ بِمِثْلِهِ ‏.‏ قَالَ أَبُو إِسْحَاقَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ، حَدَّثَنَا سُفْيَانُ، بِهَذَا الْحَدِيثِ بِطُولِهِ\hadithno{4687}\hadithtrans{This hadith has been narrated on the authority of Yazid b. Hurmuz through another chain of transmitters}}
\hadithdefcmd{muslim}{4688}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا وَهْبُ بْنُ جَرِيرِ بْنِ حَازِمٍ، حَدَّثَنِي أَبِي قَالَ، سَمِعْتُ قَيْسًا، يُحَدِّثُ عَنْ يَزِيدَ بْنِ هُرْمُزَ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنَا بَهْزٌ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، حَدَّثَنِي قَيْسُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ هُرْمُزَ، قَالَ كَتَبَ نَجْدَةُ بْنُ عَامِرٍ إِلَى ابْنِ عَبَّاسٍ قَالَ فَشَهِدْتُ ابْنَ عَبَّاسٍ حِينَ قَرَأَ كِتَابَهُ وَحِينَ كَتَبَ جَوَابَهُ وَقَالَ ابْنُ عَبَّاسٍ وَاللَّهِ لَوْلاَ أَنْ أَرُدَّهُ عَنْ نَتْنٍ يَقَعُ فِيهِ مَا كَتَبْتُ إِلَيْهِ وَلاَ نُعْمَةَ عَيْنٍ قَالَ فَكَتَبَ إِلَيْهِ إِنَّكَ سَأَلْتَ عَنْ سَهْمِ ذِي الْقُرْبَى الَّذِي ذَكَرَ اللَّهُ مَنْ هُمْ وَإِنَّا كُنَّا نَرَى أَنَّ قَرَابَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم هُمْ نَحْنُ فَأَبَى ذَلِكَ عَلَيْنَا قَوْمُنَا وَسَأَلْتَ عَنِ الْيَتِيمِ مَتَى يَنْقَضِي يُتْمُهُ وَإِنَّهُ إِذَا بَلَغَ النِّكَاحَ وَأُونِسَ مِنْهُ رُشْدٌ وَدُفِعَ إِلَيْهِ مَالُهُ فَقَدِ انْقَضَى يُتْمُهُ وَسَأَلْتَ هَلْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْتُلُ مِنْ صِبْيَانِ الْمُشْرِكِينَ أَحَدًا فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَكُنْ يَقْتُلُ مِنْهُمْ أَحَدًا وَأَنْتَ فَلاَ تَقْتُلْ مِنْهُمْ أَحَدًا إِلاَّ أَنْ تَكُونَ تَعْلَمُ مِنْهُمْ مَا عَلِمَ الْخَضِرُ مِنَ الْغُلاَمِ حِينَ قَتَلَهُ وَسَأَلْتَ عَنِ الْمَرْأَةِ وَالْعَبْدِ هَلْ كَانَ لَهُمَا سَهْمٌ مَعْلُومٌ إِذَا حَضَرُوا الْبَأْسَ فَإِنَّهُمْ لَمْ يَكُنْ لَهُمْ سَهْمٌ مَعْلُومٌ إِلاَّ أَنْ يُحْذَيَا مِنْ غَنَائِمِ الْقَوْمِ\hadithno{4688}\hadithtrans{It has been narrated on the anthority of Yazid b. Hurmuz who said:Najda wrote to Ibn Abbas. I was sitting in the company of Ibn 'Abbas when he read his letter and wrote its reply. Ibn Abbas said: Were it not for preventing him from falling into wickedness. I would not have replied to his letter, may he never be joyful. He wrote in reply to him referring to the share of the close relatives (of the Holy Prophet) (from the booty) whom God has mentioned. (I have to tell you that) we thought we were the close relatives of the Messenger of Allah (ﷺ), but our people have refused to recognise us as such. You have asked about the orphan as to when his orphanhood comes to an end. (I have to say that) when he reaches the age of marriage, attains maturity of mind, and his property is returned to him, then he is no longer an orphan. You have inquired whether the Messenger of Allah (may peace be upo him) used to kill anyone from the children of the polytheists in the war. (You should know that) the Messenger of Allah (ﷺ) used not to kill any one of their children, and you (too) should not kill any one of them, except when you knew about them what Khadir had known about the boy whom he killed. And you have inquired whether there is a fixed share of the booty for women and slaves when they participate in a battle. (I have to tell you that) there is no fixed share for them except that they will be given some reward from the spoils of war}}
\hadithdefcmd{muslim}{4689}{وَحَدَّثَنِي أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا زَائِدَةُ، حَدَّثَنَا سُلَيْمَانُ الأَعْمَشُ، عَنِ الْمُخْتَارِ بْنِ صَيْفِيٍّ، عَنْ يَزِيدَ بْنِ هُرْمُزَ، قَالَ كَتَبَ نَجْدَةُ إِلَى ابْنِ عَبَّاسٍ ‏.‏ فَذَكَرَ بَعْضَ الْحَدِيثِ وَلَمْ يُتِمَّ الْقِصَّةَ كَإِتْمَامِ مَنْ ذَكَرْنَا حَدِيثَهُمْ ‏.‏\hadithno{4689}\hadithtrans{This hadith has been transmitted on the authority of Yazid b. Hurmuz. but not complete (as we find in the above mentioned ahadith)}}
\hadithdefcmd{muslim}{4690}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ هِشَامٍ، عَنْ حَفْصَةَ، بِنْتِ سِيرِينَ عَنْ أُمِّ عَطِيَّةَ الأَنْصَارِيَّةِ، قَالَتْ غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم سَبْعَ غَزَوَاتٍ أَخْلُفُهُمْ فِي رِحَالِهِمْ فَأَصْنَعُ لَهُمُ الطَّعَامَ وَأُدَاوِي الْجَرْحَى وَأَقُومُ عَلَى الْمَرْضَى\hadithno{4690}\hadithtrans{It has been narrated on the authority of Umm 'Atiyya, the Ansarite, who said:I took part with the Messenger of Allah (ﷺ) in seven battles. I would stay behind in the camp of men, cook their food, treat the wounded and nurse the sick}}
\hadithdefcmd{muslim}{4691}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{4691}\hadithtrans{A similar tradition has been narrated on the authority of Hisham b. Hassan through a different chain of transmitters}}
\hadithdefcmd{muslim}{4692}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ، بْنُ جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، أَنَّ عَبْدَ اللَّهِ بْنَ يَزِيدَ، خَرَجَ يَسْتَسْقِي بِالنَّاسِ فَصَلَّى رَكْعَتَيْنِ ثُمَّ اسْتَسْقَى قَالَ فَلَقِيتُ يَوْمَئِذٍ زَيْدَ بْنَ أَرْقَمَ - وَقَالَ - لَيْسَ بَيْنِي وَبَيْنَهُ غَيْرُ رَجُلٍ أَوْ بَيْنِي وَبَيْنَهُ رَجُلٌ - قَالَ - فَقُلْتُ لَهُ كَمْ غَزَا رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ تِسْعَ عَشْرَةَ فَقُلْتُ كَمْ غَزَوْتَ أَنْتَ مَعَهُ قَالَ سَبْعَ عَشْرَةَ غَزْوَةً - قَالَ - فَقُلْتُ فَمَا أَوَّلُ غَزْوَةٍ غَزَاهَا قَالَ ذَاتُ الْعُسَيْرِ أَوِ الْعُشَيْرِ ‏.‏\hadithno{4692}\hadithtrans{It has been narrated on the authority of Abu Ishaq that 'Abdullah b. Yazid went (out of the city) with people for offering" Istisqa" ' prayer (for rainfall). He offered two rak'ahs. Then he prayed for rain. That day I met Zaid b. Arqam. There was only one man between me and him (at that time). I asked him:How many military expeditions did the Messenger of Allah (ﷺ) undertake? He said: Nineteen expeditions. I asked him: On how many expeditions did you accompany him? He said: On seventeen expeditions. I asked: Which was the first expedition he led? He answered: Dhat-ul-, Usair or 'Ushair}}
\hadithdefcmd{muslim}{4693}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، عَنْ زَيْدِ بْنِ أَرْقَمَ، سَمِعَهُ مِنْهُ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غَزَا تِسْعَ عَشْرَةَ غَزْوَةً وَحَجَّ بَعْدَ مَا هَاجَرَ حَجَّةً لَمْ يَحُجَّ غَيْرَهَا حَجَّةَ الْوَدَاعِ ‏.‏\hadithno{4693}\hadithtrans{It has been narrated on the authority of Zaid b. Arqam that the Messenger of Allah (ﷺ) fought nineteen battles and after the Migration performed only one Pilgrimage called Hajjat-ul-Wada}}
\hadithdefcmd{muslim}{4694}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا زَكَرِيَّاءُ، أَخْبَرَنَا أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم تِسْعَ عَشْرَةَ غَزْوَةً - قَالَ جَابِرٌ - لَمْ أَشْهَدْ بَدْرًا وَلاَ أُحُدًا مَنَعَنِي أَبِي فَلَمَّا قُتِلَ عَبْدُ اللَّهِ يَوْمَ أُحُدٍ لَمْ أَتَخَلَّفْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةٍ قَطُّ ‏.‏\hadithno{4694}\hadithtrans{It has been reported on the authority of Abu Zubair who heard Jabir b. `Abdullah say:I fought in the company of the Messenger of Allah (ﷺ) nineteen battles. Jabir said: I did not participate in the Battle of Badr and the Battle of Uhud. My father prevented me (from participating in these battles as my age was tender). After `Abdullah (my father) was killed on the Day of Uhud, I never lagged behind the Messenger of Allah (ﷺ) and joined every battle (he fought)}}
\hadithdefcmd{muslim}{4695}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، ح وَحَدَّثَنَا سَعِيدُ بْنُ مُحَمَّدٍ، الْجَرْمِيُّ حَدَّثَنَا أَبُو تُمَيْلَةَ، قَالاَ جَمِيعًا حَدَّثَنَا حُسَيْنُ بْنُ وَاقِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، ‏.‏ قَالَ غَزَا رَسُولُ اللَّهِ صلى الله عليه وسلم تِسْعَ عَشْرَةَ غَزْوَةً قَاتَلَ فِي ثَمَانٍ مِنْهُنَّ ‏.‏ وَلَمْ يَقُلْ أَبُو بَكْرٍ مِنْهُنَّ ‏.‏ وَقَالَ فِي حَدِيثِهِ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ ‏.‏\hadithno{4695}\hadithtrans{It has been narrated on the authority of Buraida (who heard the tradition from his father) that the Messenger of Allah (ﷺ) conducted nineteen military campaigns and he (actually) fought in eight of them}}
\hadithdefcmd{muslim}{4696}{وَحَدَّثَنِي أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ كَهْمَسٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّهُ قَالَ غَزَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم سِتَّ عَشْرَةَ غَزْوَةً ‏.‏\hadithno{4696}\hadithtrans{It has been narrated by Buraida who heard it from his father that he joined the Messenger of Allah (ﷺ) in sixteen military campaigns}}
\hadithdefcmd{muslim}{4697}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ - عَنْ يَزِيدَ، - وَهُوَ ابْنُ أَبِي عُبَيْدٍ قَالَ سَمِعْتُ سَلَمَةَ، يَقُولُ غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم سَبْعَ غَزَوَاتٍ وَخَرَجْتُ فِيمَا يَبْعَثُ مِنَ الْبُعُوثِ تِسْعَ غَزَوَاتٍ مَرَّةً عَلَيْنَا أَبُو بَكْرٍ وَمَرَّةً عَلَيْنَا أُسَامَةُ بْنُ زَيْدٍ ‏.‏\hadithno{4697}\hadithtrans{It has been narrated on the authority of Salama who said:I joined seven military expeditions led by the Messenger of Allah himself (ﷺ), and nine expeditions which he sent out once under Abu Bakr and once under Usama b. Zaid}}
\hadithdefcmd{muslim}{4698}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمٌ، بِهَذَا الإِسْنَادِ ‏.‏ غَيْرَ أَنَّهُ قَالَ فِي كِلْتَيْهِمَا سَبْعَ غَزَوَاتٍ ‏.‏\hadithno{4698}\hadithtrans{The (foregoing) tradition has also been narrated on the authority of Hatim through the same chain of transmitters with the difference that according to this version both these types of expeditions were seven in number}}
\hadithdefcmd{muslim}{4699}{حَدَّثَنَا أَبُو عَامِرٍ عَبْدُ اللَّهِ بْنُ بَرَّادٍ الأَشْعَرِيُّ، وَمُحَمَّدُ بْنُ الْعَلاَءِ الْهَمْدَانِيُّ، - وَاللَّفْظُ لأَبِي عَامِرٍ - قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزَاةٍ وَنَحْنُ سِتَّةُ نَفَرٍ بَيْنَنَا بَعِيرٌ نَعْتَقِبُهُ - قَالَ - فَنَقِبَتْ أَقْدَامُنَا فَنَقِبَتْ قَدَمَاىَ وَسَقَطَتْ أَظْفَارِي فَكُنَّا نَلُفُّ عَلَى أَرْجُلِنَا الْخِرَقَ فَسُمِّيَتْ غَزْوَةَ ذَاتِ الرِّقَاعِ لِمَا كُنَّا نُعَصِّبُ عَلَى أَرْجُلِنَا مِنَ الْخِرَقِ ‏.‏ قَالَ أَبُو بُرْدَةَ فَحَدَّثَ أَبُو مُوسَى بِهَذَا الْحَدِيثِ ثُمَّ كَرِهَ ذَلِكَ ‏.‏ قَالَ كَأَنَّهُ كَرِهَ أَنْ يَكُونَ شَيْئًا مِنْ عَمَلِهِ أَفْشَاهُ ‏.‏ قَالَ أَبُو أُسَامَةَ وَزَادَنِي غَيْرُ بُرَيْدٍ وَاللَّهُ يَجْزِي بِهِ ‏.‏\hadithno{4699}\hadithtrans{It has been narrated on the authority of Abu Musa (Ash'ari) who said:We set out on an expedition with the Messenger of Allah (ﷺ). We were six in number and had (with us) only one camel which we rode turn by turn Our feet were injured. My feet were so badly injured that my nails dropped off. We covered our feet with rags. so this expedition was called Dhat-ur-Riqa' (i. e. the expedition of rags) because we bandaged our feet with rags (on that day). Abu Burda said: Abu Musa narrated this tradition, and then disliked repeating it as he did not want to give any publicity to what he did in a noble cause Abu Usama said: Narrators other than Abu Buraida have added to the version of the words:" God will reward it}}
\hadithdefcmd{muslim}{4700}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مَالِكٍ، ح وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ - وَاللَّفْظُ لَهُ - حَدَّثَنِي عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنِ الْفُضَيْلِ بْنِ أَبِي، عَبْدِ اللَّهِ عَنْ عَبْدِ اللَّهِ بْنِ نِيَارٍ الأَسْلَمِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم قِبَلَ بَدْرٍ فَلَمَّا كَانَ بِحَرَّةِ الْوَبَرَةِ أَدْرَكَهُ رَجُلٌ قَدْ كَانَ يُذْكَرُ مِنْهُ جُرْأَةٌ وَنَجْدَةٌ فَفَرِحَ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم حِينَ رَأَوْهُ فَلَمَّا أَدْرَكَهُ قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم جِئْتُ لأَتَّبِعَكَ وَأُصِيبَ مَعَكَ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تُؤْمِنُ بِاللَّهِ وَرَسُولِهِ ‏"‏ ‏.‏ قَالَ لاَ قَالَ ‏"‏ فَارْجِعْ فَلَنْ أَسْتَعِينَ بِمُشْرِكٍ ‏"‏ ‏.‏ قَالَتْ ثُمَّ مَضَى حَتَّى إِذَا كُنَّا بِالشَّجَرَةِ أَدْرَكَهُ الرَّجُلُ فَقَالَ لَهُ كَمَا قَالَ أَوَّلَ مَرَّةٍ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم كَمَا قَالَ أَوَّلَ مَرَّةٍ قَالَ ‏"‏ فَارْجِعْ فَلَنْ أَسْتَعِينَ بِمُشْرِكٍ ‏"‏ ‏.‏ قَالَ ثُمَّ رَجَعَ فَأَدْرَكَهُ بِالْبَيْدَاءِ فَقَالَ لَهُ كَمَا قَالَ أَوَّلَ مَرَّةٍ ‏"‏ تُؤْمِنُ بِاللَّهِ وَرَسُولِهِ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَانْطَلِقْ ‏"‏ ‏.‏\hadithno{4700}\hadithtrans{It has been narrated on the authority of A'isha, wife of the Prophet (ﷺ), who said:The Messenger of Allah (ﷺ) set out for Badr. When he reached Harrat-ul-Wabara (a place four miles from Medina) a man met him who was known for his valour and courage. The Companions of the Messenger of Allah (ﷺ) were pleased to see him. He said: I have come so that I may follow you and get a share from the booty. The Messenger of Allah (ﷺ) said to him: Do you believe in Allah and His Apostle? He said: No. The Messenger of Allah (ﷺ) said: Go back, I will not seek help from a Mushrik (polytheist). He went on until we reached Shajara, where the man met him again. He asked him the same question again and the man gave him the same answer. He said: Go back. Im will not seek help from a Mushrik. The man returned and overtook him at Baida'? He asked him as he had asked previously: Do you believe in Allah and His Apostle? The man said: Yes. The Messenger of Allah (ﷺ) said to him: Then come along with us}}
