% Auto-generated chapter 12 for muslim
% Hadiths in this chapter: 229

\hadithdefcmd{muslim}{2263}{وَحَدَّثَنِي عَمْرُو بْنُ مُحَمَّدِ بْنِ بُكَيْرٍ النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، قَالَ سَأَلْتُ عَمْرَو بْنَ يَحْيَى بْنِ عُمَارَةَ فَأَخْبَرَنِي عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ صَدَقَةٌ وَلاَ فِيمَا دُونَ خَمْسِ ذَوْدٍ صَدَقَةٌ وَلاَ فِيمَا دُونَ خَمْسِ أَوَاقٍ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2263}\hadithtrans{Abu Sa'id al-Khudri reported Allah's Messenger (way peace be upon him) as saying:No sadaqa (zakat) is payable on less than five wasqs of (dates or grains), on less than five camel-heads and on less than five uqiyas (of silver)}}
\hadithdefcmd{muslim}{2264}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَخْبَرَنَا اللَّيْثُ، ح وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، كِلاَهُمَا عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرِو بْنِ يَحْيَى، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ‏.‏\hadithno{2264}\hadithtrans{A hadith like this has been narrated by 'Amr b. Yahya with the same chain of transmitters}}
\hadithdefcmd{muslim}{2265}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَمْرُو، بْنُ يَحْيَى بْنِ عُمَارَةَ عَنْ أَبِيهِ، يَحْيَى بْنِ عُمَارَةَ قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏ وَأَشَارَ النَّبِيُّ صلى الله عليه وسلم بِكَفِّهِ بِخَمْسِ أَصَابِعِهِ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ ابْنِ عُيَيْنَةَ ‏.‏\hadithno{2265}\hadithtrans{Umara reported:I heard Abd Sa'id al-Khudri as saying that he had heard Allah's Messenger (ﷺ) make (this) observation with a gesture of his five fingers, and then he narrated the hadith as transmitted by 'Uyaina (hadith)}}
\hadithdefcmd{muslim}{2266}{وَحَدَّثَنِي أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ حَدَّثَنَا بِشْرٌ، - يَعْنِي ابْنَ مُفَضَّلٍ - حَدَّثَنَا عُمَارَةُ بْنُ غَزِيَّةَ، عَنْ يَحْيَى بْنِ عُمَارَةَ، قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسِ ذَوْدٍ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسِ أَوَاقٍ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2266}\hadithtrans{Abu Sa'id al-Khudri reported Allah's Messenger (ﷺ) as saying:No Sadaqa (zakat) is due on less than five wasqs of (dates or grains), on less than five camel-heads, and on less than five uqiyas (of silver)}}
\hadithdefcmd{muslim}{2267}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالُوا حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ يَحْيَى بْنِ عُمَارَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسَاقٍ مِنْ تَمْرٍ وَلاَ حَبٍّ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2267}\hadithtrans{Abu Sa'id al-Khudri reported Allah's Messenger (ﷺ) as saying:No Sadaqa is payable on less than five wasqs of dates or grains}}
\hadithdefcmd{muslim}{2268}{وَحَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ يَحْيَى بْنِ عُمَارَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ فِي حَبٍّ وَلاَ تَمْرٍ صَدَقَةٌ حَتَّى يَبْلُغَ خَمْسَةَ أَوْسُقٍ وَلاَ فِيمَا دُونَ خَمْسِ ذَوْدٍ صَدَقَةٌ وَلاَ فِيمَا دُونَ خَمْسِ أَوَاقٍ صَدَقَةٌ‏"‏ ‏.‏\hadithno{2268}\hadithtrans{Abu Sa'id al-Khudri reported Allah's Messenger (ﷺ) as saying:No Sadaqa is payable on the grains and dates till it (comes to the Weight) of five wasqs, or less than five heads of camels, or less than five uqiyas (of silver)}}
\hadithdefcmd{muslim}{2269}{وَحَدَّثَنِي عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ إِسْمَاعِيلَ، بْنِ أُمَيَّةَ بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَ حَدِيثِ ابْنِ مَهْدِيٍّ ‏.‏\hadithno{2269}\hadithtrans{A hadith like this has been narrated by Isma'il b. Umayya with the same chain of transmitters}}
\hadithdefcmd{muslim}{2270}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا الثَّوْرِيُّ، وَمَعْمَرٌ، عَنْ إِسْمَاعِيلَ، بْنِ أُمَيَّةَ بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَ حَدِيثِ ابْنِ مَهْدِيٍّ وَيَحْيَى بْنِ آدَمَ غَيْرَ أَنَّهُ قَالَ - بَدَلَ التَّمْرِ - ثَمَرٍ ‏.‏\hadithno{2270}\hadithtrans{A hadith like this has been narrated by Isma'il b. Umayya with the same chain of transmitters, but instead of the word dates, fruit has been used}}
\hadithdefcmd{muslim}{2271}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، وَهَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عِيَاضُ بْنُ عَبْدِ اللَّهِ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لَيْسَ فِيمَا دُونَ خَمْسِ أَوَاقٍ مِنَ الْوَرِقِ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسِ ذَوْدٍ مِنَ الإِبِلِ صَدَقَةٌ وَلَيْسَ فِيمَا دُونَ خَمْسَةِ أَوْسُقٍ مِنَ التَّمْرِ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2271}\hadithtrans{Jabir b. 'Abdullah reported Allah's Messenger (ﷺ) as saying:No Sadaqa is payable on less than five fiqiyas of silver, and on less than five heads of camels, and less than five wasqs of dates}}
\hadithdefcmd{muslim}{2272}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَحْمَدُ بْنُ عَمْرِو بْنِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ سَرْحٍ وَهَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ وَعَمْرُو بْنُ سَوَّادٍ وَالْوَلِيدُ بْنُ شُجَاعٍ كُلُّهُمْ عَنِ ابْنِ وَهْبٍ، قَالَ أَبُو الطَّاهِرِ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، أَنَّ أَبَا الزُّبَيْرِ، حَدَّثَهُ أَنَّهُ، سَمِعَ جَابِرَ بْنَ، عَبْدِ اللَّهِ يَذْكُرُ أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ فِيمَا سَقَتِ الأَنْهَارُ وَالْغَيْمُ الْعُشُورُ وَفِيمَا سُقِيَ بِالسَّانِيَةِ نِصْفُ الْعُشْرِ ‏"‏ ‏.‏\hadithno{2272}\hadithtrans{Jabir b. Abdullah reported Allah's Messenger (ﷺ) as saying:A tenth is payable on what is watered by rivers, or rains, and a twentieth on what is watered by camels}}
\hadithdefcmd{muslim}{2273}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ عَلَى الْمُسْلِمِ فِي عَبْدِهِ وَلاَ فَرَسِهِ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2273}\hadithtrans{Abu Huraira reported Allah's Messsenger (ﷺ) as saying:No Sadaqa is due from a Muslim on his slave or horse}}
\hadithdefcmd{muslim}{2274}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا أَيُّوبُ، بْنُ مُوسَى عَنْ مَكْحُولٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ أَبِي هُرَيْرَةَ، - قَالَ عَمْرٌو - عَنِ النَّبِيِّ صلى الله عليه وسلم وَقَالَ زُهَيْرٌ يَبْلُغُ بِهِ ‏ "‏ لَيْسَ عَلَى الْمُسْلِمِ فِي عَبْدِهِ وَلاَ فَرَسِهِ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2274}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:No Sadaqa is due from a Muslim on his slave or horse}}
\hadithdefcmd{muslim}{2275}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، ح وَحَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ، بْنُ زَيْدٍ ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، كُلُّهُمْ عَنْ خُثَيْمِ بْنِ، عِرَاكِ بْنِ مَالِكٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{2275}\hadithtrans{A hadith like this has been narrated by Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{2276}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَهَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، وَأَحْمَدُ بْنُ عِيسَى، قَالُوا حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَخْرَمَةُ، عَنْ أَبِيهِ، عَنْ عِرَاكِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ فِي الْعَبْدِ صَدَقَةٌ إِلاَّ صَدَقَةُ الْفِطْرِ ‏"‏ ‏.‏\hadithno{2276}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There is no Sadaqa on a slave except Sadaqat-ul-Fitr}}
\hadithdefcmd{muslim}{2277}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَلِيُّ بْنُ حَفْصٍ، حَدَّثَنَا وَرْقَاءُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ بَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم عُمَرَ عَلَى الصَّدَقَةِ فَقِيلَ مَنَعَ ابْنُ جَمِيلٍ وَخَالِدُ بْنُ الْوَلِيدِ وَالْعَبَّاسُ عَمُّ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا يَنْقِمُ ابْنُ جَمِيلٍ إِلاَّ أَنَّهُ كَانَ فَقِيرًا فَأَغْنَاهُ اللَّهُ وَأَمَّا خَالِدٌ فَإِنَّكُمْ تَظْلِمُونَ خَالِدًا قَدِ احْتَبَسَ أَدْرَاعَهُ وَأَعْتَادَهُ فِي سَبِيلِ اللَّهِ وَأَمَّا الْعَبَّاسُ فَهِيَ عَلَىَّ وَمِثْلُهَا مَعَهَا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ يَا عُمَرُ أَمَا شَعَرْتَ أَنَّ عَمَّ الرَّجُلِ صِنْوُ أَبِيهِ ‏"‏ ‏.‏\hadithno{2277}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) sent Umar for (collecting) Sadaqa (zakat), and it was said that Ibn Jamil, Khalid b. Walid and 'Abbas the uncle of the Messenger of Allah (ﷺ), refused (to pay it). Upon this the Messenger of Allah (ﷺ) said:Ibn Jamil is taking revenge but for this that he was destitute and Allah made him rich. As regards Khalid, you are unjust to Khalid, for be reserved his armours and weapons for the sake of Allah, and as for 'Abbas, I shall be responsible for it and an equal amount along with it. And he again said: 'Umar, bear this in mind, the uncle of a person is like his father}}
\hadithdefcmd{muslim}{2278}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَرَضَ زَكَاةَ الْفِطْرِ مِنْ رَمَضَانَ عَلَى النَّاسِ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ عَلَى كُلِّ حُرٍّ أَوْ عَبْدٍ ذَكَرٍ أَوْ أُنْثَى مِنَ الْمُسْلِمِينَ ‏.‏\hadithno{2278}\hadithtrans{Ibn Umar said that Allah's Messenger (way peace be upon him) prescribed the payment of Zakat-ul-Fitr (on breaking the fast) of Ramadan for people, for every freeman, or slave, male and female among the Muslims-one sa' of dried dates, or one sa' of barley}}
\hadithdefcmd{muslim}{2279}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو أُسَامَةَ عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ فَرَضَ رَسُولُ اللَّهِ صلى الله عليه وسلم زَكَاةَ الْفِطْرِ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ عَلَى كُلِّ\hadithno{2279}\hadithtrans{Ibn 'Umar said that the Messenger of Allah (ﷺ) prescribed Zakat-ul-Fitr one sa' of dates or one sa' of barley for every slave or freeman, young or old}}
\hadithdefcmd{muslim}{2280}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ، عُمَرَ قَالَ فَرَضَ النَّبِيُّ صلى الله عليه وسلم صَدَقَةَ رَمَضَانَ عَلَى الْحُرِّ وَالْعَبْدِ وَالذَّكَرِ وَالأُنْثَى صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ ‏.‏ قَالَ فَعَدَلَ النَّاسُ بِهِ نِصْفَ صَاعٍ مِنْ بُرٍّ ‏.‏\hadithno{2280}\hadithtrans{Ibn 'Umar said that the Messenger of Allah (ﷺ) prescribed the Sadaqa of Ramadan (Sadaqat-al-Fitr) one sa' of dates or one sa' of barley for every free man or a slave, male or female, and then the people equalised (one sa' of dates or barley) with half a sa' of wheat}}
\hadithdefcmd{muslim}{2281}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِزَكَاةِ الْفِطْرِ صَاعٍ مِنْ تَمْرٍ أَوْ صَاعٍ مِنْ شَعِيرٍ ‏.‏ قَالَ ابْنُ عُمَرَ فَجَعَلَ النَّاسُ عِدْلَهُ مُدَّيْنِ مِنْ حِنْطَةٍ ‏.‏\hadithno{2281}\hadithtrans{Abdullah b. Umar reported that the Messenger of Allah (ﷺ) ordered the (payment of) Zakat-ul-Fitr one sa' of dates, or one sa' of barley. Ibn 'Umar ('Abdullah b. 'Umar) further said:The people equalised it (then) with two mudds of fine wheat}}
\hadithdefcmd{muslim}{2282}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم فَرَضَ زَكَاةَ الْفِطْرِ مِنْ رَمَضَانَ عَلَى كُلِّ نَفْسٍ مِنَ الْمُسْلِمِينَ حُرٍّ أَوْ عَبْدٍ أَوْ رَجُلٍ أَوِ امْرَأَةٍ صَغِيرٍ أَوْ كَبِيرٍ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ شَعِيرٍ ‏.‏\hadithno{2282}\hadithtrans{Ibn Umar reported that the Messenger of Allah (ﷺ) prescribed Zakat-ul-Fitr of Ramadan one sa' of dates or one sa' of barley for every individual among the Muslims (whether) free man or slave, male or female, young or old}}
\hadithdefcmd{muslim}{2283}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عِيَاضِ بْنِ، عَبْدِ اللَّهِ بْنِ سَعْدِ بْنِ أَبِي سَرْحٍ أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ كُنَّا نُخْرِجُ زَكَاةَ الْفِطْرِ صَاعًا مِنْ طَعَامٍ أَوْ صَاعًا مِنْ شَعِيرٍ أَوْ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ أَقِطٍ أَوْ صَاعًا مِنْ زَبِيبٍ ‏.‏\hadithno{2283}\hadithtrans{Sad b. Abu Sarh heard Abu Sa'id al-Khudri as saying:We used to take out as the Zakat of Fitr one sa' of grain, or one sa' of barley or one sa' of dates, or one sa' of cheese or one sa' of raisins}}
\hadithdefcmd{muslim}{2284}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا دَاوُدُ، - يَعْنِي ابْنَ قَيْسٍ - عَنْ عِيَاضِ، بْنِ عَبْدِ اللَّهِ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كُنَّا نُخْرِجُ إِذْ كَانَ فِينَا رَسُولُ اللَّهِ صلى الله عليه وسلم زَكَاةَ الْفِطْرِ عَنْ كُلِّ صَغِيرٍ وَكَبِيرٍ حُرٍّ أَوْ مَمْلُوكٍ صَاعًا مِنْ طَعَامٍ أَوْ صَاعًا مِنْ أَقِطٍ أَوْ صَاعًا مِنْ شَعِيرٍ أَوْ صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ زَبِيبٍ فَلَمْ نَزَلْ نُخْرِجُهُ حَتَّى قَدِمَ عَلَيْنَا مُعَاوِيَةُ بْنُ أَبِي سُفْيَانَ حَاجًّا أَوْ مُعْتَمِرًا فَكَلَّمَ النَّاسَ عَلَى الْمِنْبَرِ فَكَانَ فِيمَا كَلَّمَ بِهِ النَّاسَ أَنْ قَالَ إِنِّي أُرَى أَنَّ مُدَّيْنِ مِنْ سَمْرَاءِ الشَّامِ تَعْدِلُ صَاعًا مِنْ تَمْرٍ فَأَخَذَ النَّاسُ بِذَلِكَ ‏.‏ قَالَ أَبُو سَعِيدٍ فَأَمَّا أَنَا فَلاَ أَزَالُ أُخْرِجُهُ كَمَا كُنْتُ أُخْرِجُهُ أَبَدًا مَا عِشْتُ ‏.‏\hadithno{2284}\hadithtrans{Abd Sa'id al-Khudri reported:We, on behalf of every young or old, free man or slave (amongst us), used to take out during the lifetime of the Messenger of Allah (ﷺ) as the Zakat of Fitr one sa' of grain, or one sa' of cheese or one sa' of raisins. And we continued taking out these till Mu'awiya b. Abu Sufyan came to us for pilgrimage or 'Umra, and addressed the people on the pulpit and said to them: I see that two mudds of zakat out of the wheat (red) of Syria is equal to one sa' of dates. So the people accepted it. But Abu Sa'id said: I would continue to take out as I used to take out (before, i e. one sa') as long as I live}}
\hadithdefcmd{muslim}{2285}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، قَالَ أَخْبَرَنِي عِياضُ بْنُ عَبْدِ اللَّهِ بْنِ سَعْدِ بْنِ أَبِي سَرْحٍ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ كُنَّا نُخْرِجُ زَكَاةَ الْفِطْرِ وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِينَا عَنْ كُلِّ صَغِيرٍ وَكَبِيرٍ حُرٍّ وَمَمْلُوكٍ مِنْ ثَلاَثَةِ أَصْنَافٍ صَاعًا مِنْ تَمْرٍ صَاعًا مِنْ أَقِطٍ صَاعًا مِنْ شَعِيرٍ فَلَمْ نَزَلْ نُخْرِجُهُ كَذَلِكَ حَتَّى كَانَ مُعَاوِيَةُ فَرَأَى أَنَّ مُدَّيْنِ مِنْ بُرٍّ تَعْدِلُ صَاعًا مِنْ تَمْرٍ ‏.‏ قَالَ أَبُو سَعِيدٍ فَأَمَّا أَنَا فَلاَ أَزَالُ أُخْرِجُهُ كَذَلِكَ ‏.‏\hadithno{2285}\hadithtrans{Sa'd b. Abu Sarh heard Abu Sa'id al-Khudri as saying:We, on behalf of young or old, free or slave, used to take out the Zakat of Fitr while the Messenger of Allah (may peace he upon him) was among us, in three kinds, one sa' of dates, one sa' of cheese, or one sa' of barley, and we continued to take that out till the time of Mu'awiya, for he saw that two mudds of wheat were equal to one sa' of dates. Abu Sa'id sald: I would continue to take that out as before (i e. one sa' of wheat)}}
\hadithdefcmd{muslim}{2286}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنِ الْحَارِثِ بْنِ، عَبْدِ الرَّحْمَنِ بْنِ أَبِي ذُبَابٍ عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي سَرْحٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كُنَّا نُخْرِجُ زَكَاةَ الْفِطْرِ مِنْ ثَلاَثَةِ أَصْنَافٍ الأَقِطِ وَالتَّمْرِ وَالشَّعِيرِ ‏.‏\hadithno{2286}\hadithtrans{Abu Sa'id al Khudri reported:We used to take out the Zakat of Fitr in three kinds, cheese, dates and barley}}
\hadithdefcmd{muslim}{2287}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا حَاتِمُ بْنُ إِسْمَاعِيلَ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عِيَاضِ، بْنِ عَبْدِ اللَّهِ بْنِ أَبِي سَرْحٍ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ مُعَاوِيَةَ، لَمَّا جَعَلَ نِصْفَ الصَّاعِ مِنَ الْحِنْطَةِ عِدْلَ صَاعٍ مِنْ تَمْرٍ أَنْكَرَ ذَلِكَ أَبُو سَعِيدٍ وَقَالَ لاَ أُخْرِجُ فِيهَا إِلاَّ الَّذِي كُنْتُ أُخْرِجُ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم صَاعًا مِنْ تَمْرٍ أَوْ صَاعًا مِنْ زَبِيبٍ أَوْ صَاعًا مِنْ شَعِيرٍ أَوْ صَاعًا مِنْ أَقِطٍ ‏.‏\hadithno{2287}\hadithtrans{Abu Sa'id al-Khudri reported that when Mu'awiya prescribed half a sa' of wheat equal to one sa' of dates, he (Abu Sa'id al-Khudri) objected to it, and said:I would take out (Sadaqat-ul-Fitr) but that which I used to bring forth during the lifetime of the Messenger of Allah (ﷺ) one sa' of dates, or one sa' of raisins, or one sa' of barley, or one sa' of cheese}}
\hadithdefcmd{muslim}{2288}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِزَكَاةِ الْفِطْرِ أَنْ تُؤَدَّى قَبْلَ خُرُوجِ النَّاسِ إِلَى الصَّلاَةِ ‏.‏\hadithno{2288}\hadithtrans{Ibn 'Umar reported that the Messenger of Allah (ﷺ) ordered that the Sadaqat-ul-Fitr should be paid before the people go out for prayer}}
\hadithdefcmd{muslim}{2289}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، عَنْ نَافِعٍ، عَنْ عَبْدِ، اللَّهِ بْنِ عُمَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ بِإِخْرَاجِ زَكَاةِ الْفِطْرِ أَنْ تُؤَدَّى قَبْلَ خُرُوجِ النَّاسِ إِلَى الصَّلاَةِ ‏.‏\hadithno{2289}\hadithtrans{Abdullah b 'Umar reported that the Messenger of Allah (ﷺ) ordered the payment of Sadaqat-ul-Fitr before people go out for prayer}}
\hadithdefcmd{muslim}{2290}{وَحَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصٌ، - يَعْنِي ابْنَ مَيْسَرَةَ الصَّنْعَانِيَّ - عَنْ زَيْدِ بْنِ أَسْلَمَ، أَنَّ أَبَا صَالِحٍ، ذَكْوَانَ أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ صَاحِبِ ذَهَبٍ وَلاَ فِضَّةٍ لاَ يُؤَدِّي مِنْهَا حَقَّهَا إِلاَّ إِذَا كَانَ يَوْمُ الْقِيَامَةِ صُفِّحَتْ لَهُ صَفَائِحَ مِنْ نَارٍ فَأُحْمِيَ عَلَيْهَا فِي نَارِ جَهَنَّمَ فَيُكْوَى بِهَا جَنْبُهُ وَجَبِينُهُ وَظَهْرُهُ كُلَّمَا بَرَدَتْ أُعِيدَتْ لَهُ فِي يَوْمٍ كَانَ مِقْدَارُهُ خَمْسِينَ أَلْفَ سَنَةٍ حَتَّى يُقْضَى بَيْنَ الْعِبَادِ فَيُرَى سَبِيلُهُ إِمَّا إِلَى الْجَنَّةِ وَإِمَّا إِلَى النَّارِ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ فَالإِبِلُ قَالَ ‏"‏ وَلاَ صَاحِبُ إِبِلٍ لاَ يُؤَدِّي مِنْهَا حَقَّهَا وَمِنْ حَقِّهَا حَلَبُهَا يَوْمَ وِرْدِهَا إِلاَّ إِذَا كَانَ يَوْمُ الْقِيَامَةِ بُطِحَ لَهَا بِقَاعٍ قَرْقَرٍ أَوْفَرَ مَا كَانَتْ لاَ يَفْقِدُ مِنَهَا فَصِيلاً وَاحِدًا تَطَؤُهُ بِأَخْفَافِهَا وَتَعَضُّهُ بِأَفْوَاهِهَا كُلَّمَا مَرَّ عَلَيْهِ أُولاَهَا رُدَّ عَلَيْهِ أُخْرَاهَا فِي يَوْمٍ كَانَ مِقْدَارُهُ خَمْسِينَ أَلْفَ سَنَةٍ حَتَّى يُقْضَى بَيْنَ الْعِبَادِ فَيُرَى سَبِيلُهُ إِمَّا إِلَى الْجَنَّةِ وَإِمَّا إِلَى النَّارِ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ فَالْبَقَرُ وَالْغَنَمُ قَالَ ‏"‏ وَلاَ صَاحِبُ بَقَرٍ وَلاَ غَنَمٍ لاَ يُؤَدِّي مِنْهَا حَقَّهَا إِلاَّ إِذَا كَانَ يَوْمُ الْقِيَامَةِ بُطِحَ لَهَا بِقَاعٍ قَرْقَرٍ لاَ يَفْقِدُ مِنْهَا شَيْئًا لَيْسَ فِيهَا عَقْصَاءُ وَلاَ جَلْحَاءُ وَلاَ عَضْبَاءُ تَنْطِحُهُ بِقُرُونِهَا وَتَطَؤُهُ بِأَظْلاَفِهَا كُلَّمَا مَرَّ عَلَيْهِ أُولاَهَا رُدَّ عَلَيْهِ أُخْرَاهَا فِي يَوْمٍ كَانَ مِقْدَارُهُ خَمْسِينَ أَلْفَ سَنَةٍ حَتَّى يُقْضَى بَيْنَ الْعِبَادِ فَيُرَى سَبِيلُهُ إِمَّا إِلَى الْجَنَّةِ وَإِمَّا إِلَى النَّارِ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ فَالْخَيْلُ قَالَ ‏"‏ الْخَيْلُ ثَلاَثَةٌ هِيَ لِرَجُلٍ وِزْرٌ وَهِيَ لِرَجُلٍ سِتْرٌ وَهِيَ لِرَجُلٍ أَجْرٌ فَأَمَّا الَّتِي هِيَ لَهُ وِزْرٌ فَرَجُلٌ رَبَطَهَا رِيَاءً وَفَخْرًا وَنِوَاءً عَلَى أَهْلِ الإِسْلاَمِ فَهِيَ لَهُ وِزْرٌ وَأَمَّا الَّتِي هِيَ لَهُ سِتْرٌ فَرَجُلٌ رَبَطَهَا فِي سَبِيلِ اللَّهِ ثُمَّ لَمْ يَنْسَ حَقَّ اللَّهِ فِي ظُهُورِهَا وَلاَ رِقَابِهَا فَهِيَ لَهُ سِتْرٌ وَأَمَّا الَّتِي هِيَ لَهُ أَجْرٌ فَرَجُلٌ رَبَطَهَا فِي سَبِيلِ اللَّهِ لأَهْلِ الإِسْلاَمِ فِي مَرْجٍ وَرَوْضَةٍ فَمَا أَكَلَتْ مِنْ ذَلِكَ الْمَرْجِ أَوِ الرَّوْضَةِ مِنْ شَىْءٍ إِلاَّ كُتِبَ لَهُ عَدَدَ مَا أَكَلَتْ حَسَنَاتٌ وَكُتِبَ لَهُ عَدَدَ أَرْوَاثِهَا وَأَبْوَالِهَا حَسَنَاتٌ وَلاَ تَقْطَعُ طِوَلَهَا فَاسْتَنَّتْ شَرَفًا أَوْ شَرَفَيْنِ إِلاَّ كَتَبَ اللَّهُ لَهُ عَدَدَ آثَارِهَا وَأَرْوَاثِهَا حَسَنَاتٍ وَلاَ مَرَّ بِهَا صَاحِبُهَا عَلَى نَهْرٍ فَشَرِبَتْ مِنْهُ وَلاَ يُرِيدُ أَنْ يَسْقِيَهَا إِلاَّ كَتَبَ اللَّهُ لَهُ عَدَدَ مَا شَرِبَتْ حَسَنَاتٍ ‏"‏ ‏.‏ قِيلَ يَا رَسُولَ اللَّهِ فَالْحُمُرُ قَالَ ‏"‏ مَا أُنْزِلَ عَلَىَّ فِي الْحُمُرِ شَىْءٌ إِلاَّ هَذِهِ الآيَةُ الْفَاذَّةُ الْجَامِعَةُ ‏\{‏ فَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ خَيْرًا يَرَهُ * وَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ شَرًّا يَرَهُ‏\}‏ ‏"‏ ‏.‏\hadithno{2290}\hadithtrans{Abu Huraira reported Allah's Messenger (way peace be upon him) as saying:If any owner of gold or silver does not pay what is due on him, when the Day of Resurrection would come, plates of fire would be beaten out for him; these would then be heated in the fire of Hell and his sides, his forehead and his back would be cauterized with them. Whenever these cool down, (the process is) repeated during a day the extent of which would be fifty thousand years, until judgment is pronounced among servants, and he sees whether his path is to take him to Paradise or to Hell. It was said: Messenger of Allah, what about the camel? He (the Holy Prophet) said: If any owner of the camel does not pay what is due on him, and of his due in that (camel) is (also) to milk it on the day when it comes down to water. When the Day of Resurrection comes a soft sandy plain would be set for him, as extensive as possible, (he will find) that not a single young one is missing, and they will trample him with their hoofs and bite him with their mouths. As often as the first of them passes him, the last of them would be made to return during a day the extent of which would be fifty thousand years, until judgment is pronounced among servants and he sees whether his path is to take him to Paradise or to Hell. It was (again) said: Messenger of Allah, what about cows (cattle) and sheep? He said: It any owner of the cattle and sheep does not pay what is due on them, when the Day of Resurrection comes a soft sandy plain would be spread for them, he will find none of them missing, with twisted horns, without horns or with a broken horn, and they will gore him with their horns and trample him with their hoofs. As often as the first of them passes him the last of them would be made to return to him during a day the extent of which would be fifty thousand years, until judgment would be pronounced among the servants. And he would be shown his path-path leading him to Paradise or to Hell. It was said: Messenger of Allah, what about the horse? Upon this he said: The horses are of three types. To one than (these are) a burden, and to another man (these are) a covering, and still to another man (these are) a source of reward. The one for whom these are a burden is the person who rears them in order to show off, for vainglory and for opposing the Muslims; so they are a burden for him. The one for whom these are a covering is the person who rears them for the sake of Allah but does not forget the right of Allah concerning their backs and their necks, and so they are a covering for him. As for those which bring reward (these refer to) the person who rears them for the sake of Allah to be used for Muslims and he puts them in meadow and field. And whatever thing do these eat from that meadow and field would be recorded on his behalf as good deeds, as would also the amount of their dung and urine. And these would not break their halter and prance a course or two without having got recorded the amount of their hoof marks and their dung as a good deed on his behalf (on behalf of their owner). And their master does not bring them past a river from which they drink, though he did not intend to quench their thirst, but Allah would record for him the amount of what they drink on his behalf as deeds. It was said: Messenger of Allah, what about the asses?, Upon this he said: Nothing has been revealed to me in regard to the asses (in particular) except this one verse of a comprehensive nature:" He who does an atom's weight of good will see it, and he who does an atom's weight of evil will see it" (xcix)}}
\hadithdefcmd{muslim}{2291}{وَحَدَّثَنِي يُونُسُ بْنُ عَبْدِ الأَعْلَى الصَّدَفِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي هِشَامُ، بْنُ سَعْدٍ عَنْ زَيْدِ بْنِ أَسْلَمَ، فِي هَذَا الإِسْنَادِ بِمَعْنَى حَدِيثِ حَفْصِ بْنِ مَيْسَرَةَ إِلَى آخِرِهِ غَيْرَ أَنَّهُ قَالَ ‏"‏ مَا مِنْ صَاحِبِ إِبِلٍ لاَ يُؤَدِّي حَقَّهَا ‏"‏ ‏.‏ وَلَمْ يَقُلْ ‏"‏ مِنْهَا حَقَّهَا ‏"‏ ‏.‏ وَذَكَرَ فِيهِ ‏"‏ لاَ يَفْقِدُ مِنْهَا فَصِيلاً وَاحِدًا ‏"‏ ‏.‏ وَقَالَ ‏"‏ يُكْوَى بِهَا جَنْبَاهُ وَجَبْهَتُهُ وَظَهْرُهُ ‏"‏ ‏.‏\hadithno{2291}\hadithtrans{This hadith has been narrated by Zaid b. Aslam with the same chain of transmitters except that he said:" None among the owners of camels who does not pay their due," but did not say" their due (Zakat) out of them." and he make a mention:" He did not miss a single young one out of them." and he said:" Their sides. their foreheads and their backs would be cauterised}}
\hadithdefcmd{muslim}{2292}{وَحَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ الأُمَوِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا سُهَيْلُ، بْنُ أَبِي صَالِحٍ عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ صَاحِبِ كَنْزٍ لاَ يُؤَدِّي زَكَاتَهُ إِلاَّ أُحْمِيَ عَلَيْهِ فِي نَارِ جَهَنَّمَ فَيُجْعَلُ صَفَائِحَ فَيُكْوَى بِهَا جَنْبَاهُ وَجَبِينُهُ حَتَّى يَحْكُمَ اللَّهُ بَيْنَ عِبَادِهِ فِي يَوْمٍ كَانَ مِقْدَارُهُ خَمْسِينَ أَلْفَ سَنَةٍ ثُمَّ يُرَى سَبِيلَهُ إِمَّا إِلَى الْجَنَّةِ وَإِمَّا إِلَى النَّارِ وَمَا مِنْ صَاحِبِ إِبِلٍ لاَ يُؤَدِّي زَكَاتَهَا إِلاَّ بُطِحَ لَهَا بِقَاعٍ قَرْقَرٍ كَأَوْفَرِ مَا كَانَتْ تَسْتَنُّ عَلَيْهِ كُلَّمَا مَضَى عَلَيْهِ أُخْرَاهَا رُدَّتْ عَلَيْهِ أُولاَهَا حَتَّى يَحْكُمَ اللَّهُ بَيْنَ عِبَادِهِ فِي يَوْمٍ كَانَ مِقْدَارُهُ خَمْسِينَ أَلْفَ سَنَةٍ ثُمَّ يُرَى سَبِيلَهُ إِمَّا إِلَى الْجَنَّةِ وَإِمَّا إِلَى النَّارِ وَمَا مِنْ صَاحِبِ غَنَمٍ لاَ يُؤَدِّي زَكَاتَهَا إِلاَّ بُطِحَ لَهَا بِقَاعٍ قَرْقَرٍ كَأَوْفَرِ مَا كَانَتْ فَتَطَؤُهُ بِأَظْلاَفِهَا وَتَنْطِحُهُ بِقُرُونِهَا لَيْسَ فِيهَا عَقْصَاءُ وَلاَ جَلْحَاءُ كُلَّمَا مَضَى عَلَيْهِ أُخْرَاهَا رُدَّتْ عَلَيْهِ أُولاَهَا حَتَّى يَحْكُمَ اللَّهُ بَيْنَ عِبَادِهِ فِي يَوْمٍ كَانَ مِقْدَارُهُ خَمْسِينَ أَلْفَ سَنَةٍ مِمَّا تَعُدُّونَ ثُمَّ يُرَى سَبِيلَهُ إِمَّا إِلَى الْجَنَّةِ وَإِمَّا إِلَى النَّارِ ‏"‏ ‏.‏ قَالَ سُهَيْلٌ فَلاَ أَدْرِي أَذَكَرَ الْبَقَرَ أَمْ لاَ ‏.‏ قَالُوا فَالْخَيْلُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الْخَيْلُ فِي نَوَاصِيهَا - أَوْ قَالَ - الْخَيْلُ مَعْقُودٌ فِي نَوَاصِيهَا - قَالَ سُهَيْلٌ أَنَا أَشُكُّ - الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ الْخَيْلُ ثَلاَثَةٌ فَهْىَ لِرَجُلٍ أَجْرٌ وَلِرَجُلٍ سِتْرٌ وَلِرَجُلٍ وِزْرٌ فَأَمَّا الَّتِي هِيَ لَهُ أَجْرٌ فَالرَّجُلُ يَتَّخِذُهَا فِي سَبِيلِ اللَّهِ وَيُعِدُّهَا لَهُ فَلاَ تُغَيِّبُ شَيْئًا فِي بُطُونِهَا إِلاَّ كَتَبَ اللَّهُ لَهُ أَجْرًا وَلَوْ رَعَاهَا فِي مَرْجٍ مَا أَكَلَتْ مِنْ شَىْءٍ إِلاَّ كَتَبَ اللَّهُ لَهُ بِهَا أَجْرًا وَلَوْ سَقَاهَا مِنْ نَهْرٍ كَانَ لَهُ بِكُلِّ قَطْرَةٍ تُغَيِّبُهَا فِي بُطُونِهَا أَجْرٌ - حَتَّى ذَكَرَ الأَجْرَ فِي أَبْوَالِهَا وَأَرْوَاثِهَا - وَلَوِ اسْتَنَّتْ شَرَفًا أَوْ شَرَفَيْنِ كُتِبَ لَهُ بِكُلِّ خَطْوَةٍ تَخْطُوهَا أَجْرٌ وَأَمَّا الَّذِي هِيَ لَهُ سِتْرٌ فَالرَّجُلُ يَتَّخِذُهَا تَكَرُّمًا وَتَجَمُّلاً وَلاَ يَنْسَى حَقَّ ظُهُورِهَا وَبُطُونِهَا فِي عُسْرِهَا وَيُسْرِهَا وَأَمَّا الَّذِي عَلَيْهِ وِزْرٌ فَالَّذِي يَتَّخِذُهَا أَشَرًا وَبَطَرًا وَبَذَخًا وَرِيَاءَ النَّاسِ فَذَاكَ الَّذِي هِيَ عَلَيْهِ وِزْرٌ ‏"‏ ‏.‏ قَالُوا فَالْحُمُرُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ مَا أَنْزَلَ اللَّهُ عَلَىَّ فِيهَا شَيْئًا إِلاَّ هَذِهِ الآيَةَ الْجَامِعَةَ الْفَاذَّةَ ‏\{‏ فَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ خَيْرًا يَرَهُ * وَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ شَرًّا يَرَهُ‏\}‏ ‏"‏ ‏.‏\hadithno{2292}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:No owner of the treasure who does not pay Zakat (would be spared) but (his hoards) would be heated in the Fire of Hell and these would be made into plates and with these his sides, his forehead would be cauterised till Allah would pronounce judgment among His servants during a day, the extent of which would be fifty thousand years. He would then see his path, leading either to Paradise or to Hell. And no owner of the camels who does not pay Zakat (would be spared) but a soft sandy plain would be set for him and they (the camels) would be made to pass over him till the last of them would be made to return till Allah would pronounce judgment among His servants during a day the extent of which would be fifty thousand years. He would then see his path leading him to Paradise or leading him to Hell. And no owner of the (cattle and) goats who does not pay Zakat (would be spared) but a soft sandy plain would be set for him, he would find none of them missing, with twisted horns, without horns, or with broken horns, and they will gore him with their horns and trample him with their hoofs and they would be made to pass over him till the last of them would be made to return till Allah would pronounce judgment among His servants, during a day the extent of which would be fifty thousand years, and he would see the paths leading to Paradise or to Hell. Suhail said: I do not know whether he made mention of the cows. They said: Messenger of Allah (ﷺ), what about the horses? He said: The horses have goodness in their foreheads (or he said) or goodness is ingrained in the foreheads of the horses (Suhail said: I am in doubt as to what was actually said) up till the Day of judgement. The horses are of three kinds. They are a source of reward to a person, they are a covering to a person, and they are a burden to a person. As for those which bring reward is that a person would get reward who rears them for the sake of Allah and trains them for Him, and nothing disappears in their stomachs but Allah would record for him a good deed. And if they were to graze in the meadow, they would eat nothing but Allah would record for him a reward. And if they were to drink water from the canal, with every drop that, would disappear in their stomachs there would be reward (for the owner). He went on describing till a reward was mentioned for their urine and dung. And if they pranced a course or two, there would be recorded a reward for every pace that they covered. As for one for whom they are a covering, he is the man who rears them for honour and dignity but does not forget the right of their backs and their stomachs, in plenty and adversity, As regards one for whom they are a burden, he is that who rears them for vainglory and showing off to the people; for him they are, the burden. They said: Messenger of Allah, what about asses? He said: Allah has not revealed to me anything in regards to it except this one comprehensive verse:" He who does an atom's weight of good will see it, and he who does an atom's weight of evil will see it" (xcix)}}
\hadithdefcmd{muslim}{2293}{وَحَدَّثَنَاهُ قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي الدَّرَاوَرْدِيَّ - عَنْ سُهَيْلٍ، بِهَذَا الإِسْنَادِ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا رَوْحُ بْنُ الْقَاسِمِ، حَدَّثَنَا سُهَيْلُ بْنُ أَبِي صَالِحٍ، بِهَذَا الإِسْنَادِ وَقَالَ بَدَلَ عَقْصَاءُ عَضْبَاءُ وَقَالَ ‏ "‏ فَيُكْوَى بِهَا جَنْبُهُ وَظَهْرُهُ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ جَبِينُهُ ‏.‏\hadithno{2293}\hadithtrans{This hadith has been narrated by Suhail b. Abu Salih with the same chain of transmitters, and he said he substituted the word aqsa' with 'adba' and said:" his side and his back," but he made no mention of his forehead}}
\hadithdefcmd{muslim}{2294}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ بُكَيْرًا، حَدَّثَهُ عَنْ ذَكْوَانَ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا لَمْ يُؤَدِّ الْمَرْءُ حَقَّ اللَّهِ أَوِ الصَّدَقَةَ فِي إِبِلِهِ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ بِنَحْوِ حَدِيثِ سُهَيْلٍ عَنْ أَبِيهِ ‏.‏\hadithno{2294}\hadithtrans{This hadith has been narrated by Abu Huraira through another chain of transmitters:The Messenger of Allah (ﷺ) said:" When a person does not pay what is due to Allah or Sadaqa of his camels...." The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2296}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ، عَبْدِ اللَّهِ الأَنْصَارِيَّ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ مَا مِنْ صَاحِبِ إِبِلٍ لاَ يَفْعَلُ فِيهَا حَقَّهَا إِلاَّ جَاءَتْ يَوْمَ الْقِيَامَةِ أَكْثَرَ مَا كَانَتْ قَطُّ وَقَعَدَ لَهَا بِقَاعٍ قَرْقَرٍ تَسْتَنُّ عَلَيْهِ بِقَوَائِمِهَا وَأَخْفَافِهَا وَلاَ صَاحِبِ بَقَرٍ لاَ يَفْعَلُ فِيهَا حَقَّهَا إِلاَّ جَاءَتْ يَوْمَ الْقِيَامَةِ أَكْثَرَ مَا كَانَتْ وَقَعَدَ لَهَا بِقَاعٍ قَرْقَرٍ تَنْطِحُهُ بِقُرُونِهَا وَتَطَؤُهُ بِقَوَائِمِهَا وَلاَ صَاحِبِ غَنَمٍ لاَ يَفْعَلُ فِيهَا حَقَّهَا إِلاَّ جَاءَتْ يَوْمَ الْقِيَامَةِ أَكْثَرَ مَا كَانَتْ وَقَعَدَ لَهَا بِقَاعٍ قَرْقَرٍ تَنْطِحُهُ بِقُرُونِهَا وَتَطَؤُهُ بِأَظْلاَفِهَا لَيْسَ فِيهَا جَمَّاءُ وَلاَ مُنْكَسِرٌ قَرْنُهَا وَلاَ صَاحِبِ كَنْزٍ لاَ يَفْعَلُ فِيهِ حَقَّهُ إِلاَّ جَاءَ كَنْزُهُ يَوْمَ الْقِيَامَةِ شُجَاعًا أَقْرَعَ يَتْبَعُهُ فَاتِحًا فَاهُ فَإِذَا أَتَاهُ فَرَّ مِنْهُ فَيُنَادِيهِ خُذْ كَنْزَكَ الَّذِي خَبَأْتَهُ فَأَنَا عَنْهُ غَنِيٌّ فَإِذَا رَأَى أَنْ لاَ بُدَّ مِنْهُ سَلَكَ يَدَهُ فِي فِيهِ فَيَقْضَمُهَا قَضْمَ الْفَحْلِ ‏"‏ ‏.‏ قَالَ أَبُو الزُّبَيْرِ سَمِعْتُ عُبَيْدَ بْنَ عُمَيْرٍ يَقُولُ هَذَا الْقَوْلَ ثُمَّ سَأَلْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ عَنْ ذَلِكَ فَقَالَ مِثْلَ قَوْلِ عُبَيْدِ بْنِ عُمَيْرٍ ‏.‏ وَقَالَ أَبُو الزُّبَيْرِ سَمِعْتُ عُبَيْدَ بْنَ عُمَيْرٍ يَقُولُ قَالَ رَجُلٌ يَا رَسُولَ اللَّهِ مَا حَقُّ الإِبِلِ قَالَ ‏"‏ حَلَبُهَا عَلَى الْمَاءِ وَإِعَارَةُ دَلْوِهَا وَإِعَارَةُ فَحْلِهَا وَمَنِيحَتُهَا وَحَمْلٌ عَلَيْهَا فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏\hadithno{2296}\hadithtrans{Jabir b. 'Abdullah al-Ansari reported Allah's Messenger (ﷺ) as saying:The owner of a camel who does not pay what is due on it (would be punished in this way) that on the Day of Resurrection many more (along with his camel) would come and the owner would be made to sit on a soft sandy ground and they would trample him with their feet and hooves. And no owner of the cattle who does not pay what is due on them (would be spared the punishment) but on the Day of Resurrection, many more would come and he (the owner) would be made to sit on the soft sandy ground and would be gored by their horns and trampled under their feet. And no owner of the goats and sheep who does not pay what is due on them (would be spared of punishment) but many more would come on the Day of Resurrection and he (the owner) would be made to sit on a soft sandy ground and they would gore him with their horns and trample him under their hooves. And there would be more (among this flock of sheep and goat) without horns or with broken horns. And no owner of the treasure who does not pay its due but his treasure would come on the Day of Resurrection like a bald snake and would pursue him with its mouth open, and when it would come near he would run away from it, and he would be called thus:" Take your treasure which you concealed, for I do not need it." When he would find no way out he would put his hand in its mouth and it would gnaw it like a he-camel. Abu Zubair said: We heard Ubaid b. Umair saying this. We then asked Jabir b. 'Abdullah about this. And he also said like Ubaid b. Umair, Abu Zubair said: I heard 'Ubaid b. 'Umair saying: A man said: Messenger of Allah, what is due on camels? He said: Milking them near water, and lending of bucket (used for drawing water from it), or lending its male for mating with a she-camel and providing it as a ride for the sake of Allah}}
\hadithdefcmd{muslim}{2297}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَا مِنْ صَاحِبِ إِبِلٍ وَلاَ بَقَرٍ وَلاَ غَنَمٍ لاَ يُؤَدِّي حَقَّهَا إِلاَّ أُقْعِدَ لَهَا يَوْمَ الْقِيَامَةِ بِقَاعٍ قَرْقَرٍ تَطَؤُهُ ذَاتُ الظِّلْفِ بِظِلْفِهَا وَتَنْطِحُهُ ذَاتُ الْقَرْنِ بِقَرْنِهَا لَيْسَ فِيهَا يَوْمَئِذٍ جَمَّاءُ وَلاَ مَكْسُورَةُ الْقَرْنِ ‏"‏ ‏.‏ قُلْنَا يَا رَسُولَ اللَّهِ وَمَا حَقُّهَا قَالَ ‏"‏ إِطْرَاقُ فَحْلِهَا وَإِعَارَةُ دَلْوِهَا وَمَنِيحَتُهَا وَحَلَبُهَا عَلَى الْمَاءِ وَحَمْلٌ عَلَيْهَا فِي سَبِيلِ اللَّهِ وَلاَ مِنْ صَاحِبِ مَالٍ لاَ يُؤَدِّي زَكَاتَهُ إِلاَّ تَحَوَّلَ يَوْمَ الْقِيَامَةِ شُجَاعًا أَقْرَعَ يَتْبَعُ صَاحِبَهُ حَيْثُمَا ذَهَبَ وَهُوَ يَفِرُّ مِنْهُ وَيُقَالُ هَذَا مَالُكَ الَّذِي كُنْتَ تَبْخَلُ بِهِ فَإِذَا رَأَى أَنَّهُ لاَ بُدَّ مِنْهُ أَدْخَلَ يَدَهُ فِي فِيهِ فَجَعَلَ يَقْضَمُهَا كَمَا يَقْضَمُ الْفَحْلُ ‏"‏ ‏.‏\hadithno{2297}\hadithtrans{Jabir b. Abdullah reported the Messenger of Allah (ﷺ) as saying:No owner of camels or cattle or flock of sheep or goats who does not pay his due (would be spared punishment) but would be made to sit on the Day of Resurrection on a soft sandy ground and the hoofed animals would trample him with their hoofs and gore him with their horns. And none of them on that day would be without horns, or with broken horns. We said: Messenger of Allah, but what is due on them? He said: Lending of the male (for use) and lending of the bucket (used for drawing water for them) and for mating and milking them near water and providing them as a ride for the sake of Allah. And no owner of the property who does not pay Zakat (would be spared punishment) but it (his property) would turn into a bald snake and would follow its owner wherever he would go, and he would run away from it, and it would be said to him: That is your property about which you were stingy. And when he would find no other way out he would thrust his hand in its mouth and it would gnaw it like a male camel}}
\hadithdefcmd{muslim}{2298}{حَدَّثَنَا أَبُو كَامِلٍ، فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ هِلاَلٍ الْعَبْسِيُّ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ جَاءَ نَاسٌ مِنَ الأَعْرَابِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا إِنَّ نَاسًا مِنَ الْمُصَدِّقِينَ يَأْتُونَنَا فَيَظْلِمُونَنَا ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ارْضُوا مُصَدِّقِيكُمْ ‏"‏ ‏.‏ قَالَ جَرِيرٌ مَا صَدَرَ عَنِّي مُصَدِّقٌ مُنْذُ سَمِعْتُ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ وَهُوَ عَنِّي رَاضٍ ‏.‏\hadithno{2298}\hadithtrans{Jabir b. 'Abdullah reported:There came people from among the Bedouins to the Messenger of Allah (ﷺ) and said: Collectors of Sadaqa come to us and treat us unjustly. Upon this the Messenger of Allah (ﷺ) said: Please your collectors. Jarir said: Ever since I heard it from the Messenger of Allah (ﷺ) no collector had departed but was pleased with me}}
\hadithdefcmd{muslim}{2299}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، ح وَحَدَّثَنَا مُحَمَّدُ، بْنُ بَشَّارٍ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، ح وَحَدَّثَنَا إِسْحَاقُ، أَخْبَرَنَا أَبُو أُسَامَةَ، كُلُّهُمْ عَنْ مُحَمَّدِ، بْنِ أَبِي إِسْمَاعِيلَ بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{2299}\hadithtrans{This hadith has been narrated by Muhammad b. Isma'il with the same chain of transmitters}}
\hadithdefcmd{muslim}{2300}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنِ الْمَعْرُورِ بْنِ سُوَيْدٍ، عَنْ أَبِي ذَرٍّ، قَالَ انْتَهَيْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ جَالِسٌ فِي ظِلِّ الْكَعْبَةِ ‏.‏ فَلَمَّا رَآنِي قَالَ ‏"‏ هُمُ الأَخْسَرُونَ وَرَبِّ الْكَعْبَةِ ‏"‏ ‏.‏ قَالَ فَجِئْتُ حَتَّى جَلَسْتُ فَلَمْ أَتَقَارَّ أَنْ قُمْتُ فَقُلْتُ يَا رَسُولَ اللَّهِ فِدَاكَ أَبِي وَأُمِّي مَنْ هُمْ قَالَ ‏"‏ هُمُ الأَكْثَرُونَ أَمْوَالاً إِلاَّ مَنْ قَالَ هَكَذَا وَهَكَذَا وَهَكَذَا - مِنْ بَيْنِ يَدَيْهِ وَمِنْ خَلْفِهِ وَعَنْ يَمِينِهِ وَعَنْ شِمَالِهِ - وَقَلِيلٌ مَا هُمْ مَا مِنْ صَاحِبِ إِبِلٍ وَلاَ بَقَرٍ وَلاَ غَنَمٍ لاَ يُؤَدِّي زَكَاتَهَا إِلاَّ جَاءَتْ يَوْمَ الْقِيَامَةِ أَعْظَمَ مَا كَانَتْ وَأَسْمَنَهُ تَنْطِحُهُ بِقُرُونِهَا وَتَطَؤُهُ بِأَظْلاَفِهَا كُلَّمَا نَفِدَتْ أُخْرَاهَا عَادَتْ عَلَيْهِ أُولاَهَا حَتَّى يُقْضَى بَيْنَ النَّاسِ ‏"‏ ‏.‏\hadithno{2300}\hadithtrans{Abu Dharr reported:I went to the Messenger of Allah (ﷺ) and he was sitting under the shade of the Ka'ba. As he saw me he said: By the Lord of the Ka'ba, they are the losers. I came there till I sat and I could not stay (longer) and (then) stood up. I said: Messenger of Allah, let my father, be ransom for you, who are they (the losers)? He said: They are those having a huge amount of wealth except so and so and (those who spend their wealth generously on them whom they find in front of them, behind them and on their right side and on their left side) and they are a few. And no owner of camels, or cattle or goat and sheep, who does not pay Zakat (would be spared punishment) but these (camels, cattle, goats and sheep) would come on the Day of Resurrection wearing more flesh and would gore him with their horns and trample them with their hooves. And when the last one would pass away, the first one would return (to trample him) till judgment would be pronounced among people}}
\hadithdefcmd{muslim}{2301}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنِ الْمَعْرُورِ، عَنْ أَبِي ذَرٍّ، قَالَ انْتَهَيْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ جَالِسٌ فِي ظِلِّ الْكَعْبَةِ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ وَكِيعٍ غَيْرَ أَنَّهُ قَالَ ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ مَا عَلَى الأَرْضِ رَجُلٌ يَمُوتُ فَيَدَعُ إِبِلاً أَوْ بَقَرًا أَوْ غَنَمًا لَمْ يُؤَدِّ زَكَاتَهَا ‏"‏ ‏.‏\hadithno{2301}\hadithtrans{Abu Dbarr reported:I went to the Messenger of Allah (ﷺ) and he was sitting under the shade of the Ka'ba, and the rest of the hadith it the same but for this that he (the Holy Prophet) said:" By Allah, in Whose hand is my life, no person on earth who dies and leaves behind camels, or cattle or goat and sheep, and does not pay Zakat (would be spared the punishment)}}
\hadithdefcmd{muslim}{2302}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَلاَّمٍ الْجُمَحِيُّ، حَدَّثَنَا الرَّبِيعُ، - يَعْنِي ابْنَ مُسْلِمٍ - عَنْ مُحَمَّدِ بْنِ زِيَادٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا يَسُرُّنِي أَنَّ لِي أُحُدًا ذَهَبًا تَأْتِي عَلَىَّ ثَالِثَةٌ وَعِنْدِي مِنْهُ دِينَارٌ إِلاَّ دِينَارٌ أُرْصِدُهُ لِدَيْنٍ عَلَىَّ ‏"‏ ‏.‏\hadithno{2302}\hadithtrans{Abu Huraira reported that the Prophet (ﷺ) said:Nothing is more delighting to me than this that Uhud should be of gold for me, and no dinar is left with me out of it before three nights pass except a dinar which I would set aside for the repayment of debt upon me}}
\hadithdefcmd{muslim}{2303}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ زِيَادٍ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{2303}\hadithtrans{Abu Huraira reported the same from the Prophet (ﷺ)}}
\hadithdefcmd{muslim}{2304}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَابْنُ نُمَيْرٍ وَأَبُو كُرَيْبٍ كُلُّهُمْ عَنْ أَبِي مُعَاوِيَةَ، - قَالَ يَحْيَى أَخْبَرَنَا أَبُو مُعَاوِيَةَ، - عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ أَبِي، ذَرٍّ قَالَ كُنْتُ أَمْشِي مَعَ النَّبِيِّ صلى الله عليه وسلم فِي حَرَّةِ الْمَدِينَةِ عِشَاءً وَنَحْنُ نَنْظُرُ إِلَى أُحُدٍ فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَبَا ذَرٍّ ‏"‏ ‏.‏ قَالَ قُلْتُ لَبَّيْكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ مَا أُحِبُّ أَنَّ أُحُدًا ذَاكَ عِنْدِي ذَهَبٌ أَمْسَى ثَالِثَةً عِنْدِي مِنْهُ دِينَارٌ إِلاَّ دِينَارًا أُرْصِدُهُ لِدَيْنٍ إِلاَّ أَنْ أَقُولَ بِهِ فِي عِبَادِ اللَّهِ هَكَذَا - حَثَا بَيْنَ يَدَيْهِ - وَهَكَذَا - عَنْ يَمِينِهِ - وَهَكَذَا - عَنْ شِمَالِهِ ‏"‏ ‏.‏ قَالَ ثُمَّ مَشَيْنَا فَقَالَ ‏"‏ يَا أَبَا ذَرٍّ ‏"‏ ‏.‏ قَالَ قُلْتُ لَبَّيْكَ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِنَّ الأَكْثَرِينَ هُمُ الأَقَلُّونَ يَوْمَ الْقِيَامَةِ إِلاَّ مَنْ قَالَ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ مِثْلَ مَا صَنَعَ فِي الْمَرَّةِ الأُولَى قَالَ ثُمَّ مَشَيْنَا قَالَ ‏"‏ يَا أَبَا ذَرٍّ كَمَا أَنْتَ حَتَّى آتِيَكَ ‏"‏ ‏.‏ قَالَ فَانْطَلَقَ حَتَّى تَوَارَى عَنِّي - قَالَ - سَمِعْتُ لَغَطًا وَسَمِعْتُ صَوْتًا - قَالَ - فَقُلْتُ لَعَلَّ رَسُولَ اللَّهِ صلى الله عليه وسلم عُرِضَ لَهُ - قَالَ - فَهَمَمْتُ أَنْ أَتَّبِعَهُ قَالَ ثُمَّ ذَكَرْتُ قَوْلَهُ ‏"‏ لاَ تَبْرَحْ حَتَّى آتِيَكَ ‏"‏ ‏.‏ قَالَ فَانْتَظَرْتُهُ فَلَمَّا جَاءَ ذَكَرْتُ لَهُ الَّذِي سَمِعْتُ - قَالَ - فَقَالَ ‏"‏ ذَاكَ جِبْرِيلُ أَتَانِي فَقَالَ مَنْ مَاتَ مِنْ أُمَّتِكَ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏ قَالَ قُلْتُ وَإِنْ زَنَى وَإِنْ سَرَقَ قَالَ ‏"‏ وَإِنْ زَنَى وَإِنْ سَرَقَ ‏"‏ ‏.‏\hadithno{2304}\hadithtrans{Abu Dharr reported:I walked with the Messenger of Allah (ﷺ) on the stony ground of Medina in the afternoon and we were looking at Uhud. The Messenger of Allah (way peace by upon him) said: Abu Dharr! I said: Messenger of Allah, I am here at thy beck and call. He said: What I desire is that Uhud be gold with me and three nights should pass and there is left with me any dinar but one coin which I would keep to pay debt. (I love) to spend it among the servants of Allah like this and he pointed in front of him, and on his right side and on his left side. We then proceeded on and he said: Abu Dharr. I said: At thy beck and call, Messenger of Allah. He (the Holy Prophet) said: The rich would be poor on the Day of Resurrection, but he who spent like this and like this and like this, and he pointed as at the first time. We again went on when he said. Abu Dharr, stay where you are till I come back to you. He (the Holy Prophet) then moved on till he disappeared from my sight He (Abu Dharr) said: I heard a sound and I heard a noise. I said (to myself): The Messenger of Allah (ﷺ) might have met (mishap or an enemy). I wished to follow him but I remembered his command for not departing till he would come back. So I waited for him, and when he came I made a mention of what I heard. He said: it was Gabriel, who came to me and said:" He who dies among your Ummah without associating Anything with Allah would enter Paradise. I said: Even if he committed fornication or theft? He said: Even if he committed fornication or theft}}
\hadithdefcmd{muslim}{2305}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عَبْدِ الْعَزِيزِ، - وَهُوَ ابْنُ رُفَيْعٍ - عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ أَبِي ذَرٍّ، قَالَ خَرَجْتُ لَيْلَةً مِنَ اللَّيَالِي فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْشِي وَحْدَهُ لَيْسَ مَعَهُ إِنْسَانٌ قَالَ فَظَنَنْتُ أَنَّهُ يَكْرَهُ أَنْ يَمْشِيَ مَعَهُ أَحَدٌ - قَالَ - فَجَعَلْتُ أَمْشِي فِي ظِلِّ الْقَمَرِ فَالْتَفَتَ فَرَآنِي فَقَالَ ‏"‏ مَنْ هَذَا ‏"‏ ‏.‏ فَقُلْتُ أَبُو ذَرٍّ جَعَلَنِي اللَّهُ فِدَاءَكَ ‏.‏ قَالَ ‏"‏ يَا أَبَا ذَرٍّ تَعَالَهْ ‏"‏ ‏.‏ قَالَ فَمَشَيْتُ مَعَهُ سَاعَةً فَقَالَ ‏"‏ إِنَّ الْمُكْثِرِينَ هُمُ الْمُقِلُّونَ يَوْمَ الْقِيَامَةِ إِلاَّ مَنْ أَعْطَاهُ اللَّهُ خَيْرًا فَنَفَحَ فِيهِ يَمِينَهُ وَشِمَالَهُ وَبَيْنَ يَدَيْهِ وَوَرَاءَهُ وَعَمِلَ فِيهِ خَيْرًا ‏"‏ ‏.‏ قَالَ فَمَشَيْتُ مَعَهُ سَاعَةً فَقَالَ ‏"‏ اجْلِسْ هَا هُنَا ‏"‏ ‏.‏ قَالَ فَأَجْلَسَنِي فِي قَاعٍ حَوْلَهُ حِجَارَةٌ فَقَالَ لِيَ ‏"‏ اجْلِسْ هَا هُنَا حَتَّى أَرْجِعَ إِلَيْكَ ‏"‏ ‏.‏ قَالَ فَانْطَلَقَ فِي الْحَرَّةِ حَتَّى لاَ أَرَاهُ فَلَبِثَ عَنِّي فَأَطَالَ اللَّبْثَ ثُمَّ إِنِّي سَمِعْتُهُ وَهُوَ مُقْبِلٌ وَهُوَ يَقُولُ ‏"‏ وَإِنْ سَرَقَ وَإِنْ زَنَى ‏"‏ ‏.‏ قَالَ فَلَمَّا جَاءَ لَمْ أَصْبِرْ فَقُلْتُ يَا نَبِيَّ اللَّهِ جَعَلَنِي اللَّهُ فِدَاءَكَ مَنْ تُكَلِّمُ فِي جَانِبِ الْحَرَّةِ مَا سَمِعْتُ أَحَدًا يَرْجِعُ إِلَيْكَ شَيْئًا ‏.‏ قَالَ ‏"‏ ذَاكَ جِبْرِيلُ عَرَضَ لِي فِي جَانِبِ الْحَرَّةِ فَقَالَ بَشِّرْ أُمَّتَكَ أَنَّهُ مَنْ مَاتَ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا دَخَلَ الْجَنَّةَ ‏.‏ فَقُلْتُ يَا جِبْرِيلُ وَإِنْ سَرَقَ وَإِنْ زَنَى قَالَ نَعَمْ ‏.‏ قَالَ قُلْتُ وَإِنْ سَرَقَ وَإِنْ زَنَى قَالَ نَعَمْ ‏.‏ قَالَ قُلْتُ وَإِنْ سَرَقَ وَإِنْ زَنَى قَالَ نَعَمْ وَإِنْ شَرِبَ الْخَمْرَ ‏"‏ ‏.‏\hadithno{2305}\hadithtrans{Abu Dharr reported:I went out one night (and found) the Messenger of Allah (ﷺ) walking all alone. There was no man with him. I thought that he did not like anyone walking along with him. So I began to walk in the light of the moon. He, however turned his attention to me and saw me and said: Who is this? I said: It is Abu Dharr. Let Allah make me as ransom for you. He said: Abu Dharr, come on. He (Abu Dharr) said: So I walked along with him for some time and he said: The wealthy persons would have little (reward) on the Day of Resurrection, except upon whom Allah conferred goodness (wealth). He dispensed it to his right, left, in front of him and at his back (just as the wind diffuses fragrance) and did good with it (riches). I went along with him for some time when He said: Sit here. And he made me sit at a safe place and there were stones around it, and he said to me: Sit here till I come to you. He went away on the stony ground till I could not see him. He stayed away from me, and he prolonged his stay. Then I heard him as he came back and he was saying: Even if he committed theft and even if he committed fornication. When he came I could not help asking him: Apostle of Allah, let Allah make me ransom for you, whom were you speaking on the stony ground? I heard nobody responding to you. He (the Holy Prophet) said: It was Gabriel who met me by the side of the stony ground and said: Give glad tidings to your Ummah that he who died without associating ought with Allah would go into Paradise. I said: Gabriel, even if he committed theft and fornication? He said: Yes. I said: Even it he committed theft and fornication? He said: Yes, I again said: Even if he committed theft and fornication? He said: Yes, even if he drank wine}}
\hadithdefcmd{muslim}{2306}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي، الْعَلاَءِ عَنِ الأَحْنَفِ بْنِ قَيْسٍ، قَالَ قَدِمْتُ الْمَدِينَةَ فَبَيْنَا أَنَا فِي، حَلْقَةٍ فِيهَا مَلأٌ مِنْ قُرَيْشٍ إِذْ جَاءَ رَجُلٌ أَخْشَنُ الثِّيَابِ أَخْشَنُ الْجَسَدِ أَخْشَنُ الْوَجْهِ فَقَامَ عَلَيْهِمْ فَقَالَ بَشِّرِ الْكَانِزِينَ بِرَضْفٍ يُحْمَى عَلَيْهِ فِي نَارِ جَهَنَّمَ فَيُوضَعُ عَلَى حَلَمَةِ ثَدْىِ أَحَدِهِمْ حَتَّى يَخْرُجَ مِنْ نُغْضِ كَتِفَيْهِ وَيُوضَعُ عَلَى نُغْضِ كَتِفَيْهِ حَتَّى يَخْرُجَ مِنْ حَلَمَةِ ثَدْيَيْهِ يَتَزَلْزَلُ قَالَ فَوَضَعَ الْقَوْمُ رُءُوسَهُمْ فَمَا رَأَيْتُ أَحَدًا مِنْهُمْ رَجَعَ إِلَيْهِ شَيْئًا - قَالَ - فَأَدْبَرَ وَاتَّبَعْتُهُ حَتَّى جَلَسَ إِلَى سَارِيَةٍ فَقُلْتُ مَا رَأَيْتُ هَؤُلاَءِ إِلاَّ كَرِهُوا مَا قُلْتَ لَهُمْ ‏.‏ قَالَ إِنَّ هَؤُلاَءِ لاَ يَعْقِلُونَ شَيْئًا إِنَّ خَلِيلِي أَبَا الْقَاسِمِ صلى الله عليه وسلم دَعَانِي فَأَجَبْتُهُ فَقَالَ ‏"‏ أَتَرَى أُحُدًا ‏"‏ ‏.‏ فَنَظَرْتُ مَا عَلَىَّ مِنَ الشَّمْسِ وَأَنَا أَظُنُّ أَنَّهُ يَبْعَثُنِي فِي حَاجَةٍ لَهُ فَقُلْتُ أَرَاهُ ‏.‏ فَقَالَ ‏"‏ مَا يَسُرُّنِي أَنَّ لِي مِثْلَهُ ذَهَبًا أُنْفِقُهُ كُلَّهُ إِلاَّ ثَلاَثَةَ دَنَانِيرَ ‏"‏ ‏.‏ ثُمَّ هَؤُلاَءِ يَجْمَعُونَ الدُّنْيَا لاَ يَعْقِلُونَ شَيْئًا ‏.‏ قَالَ قُلْتُ مَا لَكَ وَلإِخْوَتِكَ مِنْ قُرَيْشٍ لاَ تَعْتَرِيهِمْ وَتُصِيبُ مِنْهُمْ ‏.‏ قَالَ لاَ وَرَبِّكَ لاَ أَسْأَلُهُمْ عَنْ دُنْيَا وَلاَ أَسْتَفْتِيهِمْ عَنْ دِينٍ حَتَّى أَلْحَقَ بِاللَّهِ وَرَسُولِهِ ‏.‏\hadithno{2306}\hadithtrans{Ahnaf b. Qais reported:I came to Medina and when I was in the company of the grandees of Quraish a man with a crude body and an uncouth face wearing coarse clothes came there. He stood up before them and said: Give glad tidings to those whom who amass riches of the stones which would be heated in the Fire of Hell, and would be placed at the tick of the chest till it would project from the shoulder bone and would he put on the shoulder bone till it would project from the tick of his chest, and it (this stone) would continue passing and repassing (from one side to the other). He (the narrator) said: Then people hung their heads and I saw none among them giving any answer. He then returned and I followed him till he sat near a pillar. I said: I find that these (people) disliked what you said to them and they do not understand anything. My friend Abu'l-Qasim (Muhammad) (may peace he upon him) called me and I responded to him, and he said: Do you see Uhud? I saw the sun (shining) on me and I thought that he would send me on an errand for him. So I said: I see it. Upon this he said: Nothing would delight me more than this that I should have gold like it (equal to the bulk of Uhud), and I should spend it all except three dinars. (How sad it is) that they hoard worldly riches, and they know nothing. I said: What about you and your brothers Quraish? You do not go to thein for any need and do not accept anything from them. He said: By Allah, I neither beg anything from them (from worldly goods), nor do I ask them anything about religion till I meet my Allah and His Messenger}}
\hadithdefcmd{muslim}{2307}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا أَبُو الأَشْهَبِ، حَدَّثَنَا خُلَيْدٌ الْعَصَرِيُّ، عَنِ الأَحْنَفِ، بْنِ قَيْسٍ قَالَ كُنْتُ فِي نَفَرٍ مِنْ قُرَيْشٍ فَمَرَّ أَبُو ذَرٍّ وَهُوَ يَقُولُ بَشِّرِ الْكَانِزِينَ بِكَىٍّ فِي ظُهُورِهِمْ يَخْرُجُ مِنْ جُنُوبِهِمْ وَبِكَىٍّ مِنْ قِبَلِ أَقْفَائِهِمْ يَخْرُجُ مِنْ جِبَاهِهِمْ ‏.‏ - قَالَ - ثُمَّ تَنَحَّى فَقَعَدَ ‏.‏ - قَالَ - قُلْتُ مَنْ هَذَا قَالُوا هَذَا أَبُو ذَرٍّ ‏.‏ قَالَ فَقُمْتُ إِلَيْهِ فَقُلْتُ مَا شَىْءٌ سَمِعْتُكَ تَقُولُ قُبَيْلُ قَالَ مَا قُلْتُ إِلاَّ شَيْئًا قَدْ سَمِعْتُهُ مِنْ نَبِيِّهِمْ صلى الله عليه وسلم ‏.‏ قَالَ قُلْتُ مَا تَقُولُ فِي هَذَا الْعَطَاءِ قَالَ خُذْهُ فَإِنَّ فِيهِ الْيَوْمَ مَعُونَةً فَإِذَا كَانَ ثَمَنًا لِدِينِكَ فَدَعْهُ‏.‏\hadithno{2307}\hadithtrans{Ahnaf b. Qais reported:While I was in the company of the (elites) of Quraiah, Abu Dharr came there and he was saying: Give glad tidings to the hoarders of riches that their backs would be branded (so deeply) that (the hot Iron) would come out of their sides, and when the backs of their necks would be branded, it would come out of their foreheads. He (Abu Dharr) then went away and sat down. I asked who he was. They said: He is Abu Dharr. I went to him and said to him: What is this that I heard from you which you were saying before? He said: I said nothing but only that which I heard from their Prophet (ﷺ). I again said: What do you say about this gift? He said: Take it, for today it is a help. But when it becomes a price for your religion, then abandon it}}
\hadithdefcmd{muslim}{2308}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ قَالَ اللَّهُ تَبَارَكَ وَتَعَالَى يَا ابْنَ آدَمَ أَنْفِقْ أُنْفِقْ عَلَيْكَ ‏"‏ ‏.‏ وَقَالَ ‏"‏ يَمِينُ اللَّهِ مَلأَى - وَقَالَ ابْنُ نُمَيْرٍ مَلآنُ - سَحَّاءُ لاَ يَغِيضُهَا شَىْءٌ اللَّيْلَ وَالنَّهَارَ ‏"‏ ‏.‏\hadithno{2308}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying that Allah, the Most Blessed and High, said:O son of Adam, spend. I will spend on you. The right hand of Allah is full and overflowing and in nothing would diminish it, by overspending day and night}}
\hadithdefcmd{muslim}{2309}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ بْنُ هَمَّامٍ، حَدَّثَنَا مَعْمَرُ بْنُ رَاشِدٍ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، أَخِي وَهْبِ بْنِ مُنَبِّهٍ قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا ‏.‏ وَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ اللَّهَ قَالَ لِي أَنْفِقْ أُنْفِقْ عَلَيْكَ ‏"‏ ‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَمِينُ اللَّهِ مَلأَى لاَ يَغِيضُهَا سَحَّاءُ اللَّيْلَ وَالنَّهَارَ أَرَأَيْتُمْ مَا أَنْفَقَ مُذْ خَلَقَ السَّمَاءَ وَالأَرْضَ فَإِنَّهُ لَمْ يَغِضْ مَا فِي يَمِينِهِ ‏"‏ ‏.‏ قَالَ ‏"‏ وَعَرْشُهُ عَلَى الْمَاءِ وَبِيَدِهِ الأُخْرَى الْقَبْضُ يَرْفَعُ وَيَخْفِضُ ‏"‏ ‏.‏\hadithno{2309}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying that Allah said to him:" Spend, I will bestow upon you." And the Messenger of Allah (ﷺ) said: The right hand of Allah is full and spending (the riches) liberally during day and night will not diminish (the resources of Allah). Don't you see what (an enormous amount of resources) He has spent since He created the heaven and the earth, and what is in His right hand has not decreased? His Throne is upon the water. And in His other hand is death, and He elevates and degrades (whom He likes)}}
\hadithdefcmd{muslim}{2310}{حَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، كِلاَهُمَا عَنْ حَمَّادِ بْنِ زَيْدٍ، - قَالَ أَبُو الرَّبِيعِ حَدَّثَنَا حَمَّادٌ، - حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَفْضَلُ دِينَارٍ يُنْفِقُهُ الرَّجُلُ دِينَارٌ يُنْفِقُهُ عَلَى عِيَالِهِ وَدِينَارٌ يُنْفِقُهُ الرَّجُلُ عَلَى دَابَّتِهِ فِي سَبِيلِ اللَّهِ وَدِينَارٌ يُنْفِقُهُ عَلَى أَصْحَابِهِ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو قِلاَبَةَ وَبَدَأَ بِالْعِيَالِ ثُمَّ قَالَ أَبُو قِلاَبَةَ وَأَىُّ رَجُلٍ أَعْظَمُ أَجْرًا مِنْ رَجُلٍ يُنْفِقُ عَلَى عِيَالٍ صِغَارٍ يُعِفُّهُمْ أَوْ يَنْفَعُهُمُ اللَّهُ بِهِ وَيُغْنِيهِمْ ‏.‏\hadithno{2310}\hadithtrans{Thauban reported Allah's Messenger (ﷺ) as saying:The most excellent dinar is one that a person spends on his family, and the dinar which he spends on his animal in Allah's path, and the dinar he spends on his companions in Allah's path. Abu Qilaba (one of the narrators) said: He (the narrator) started with family, and then Abu Qilaba said: Who is the person with greater reward than a person who spends on young members of his family (and thus) preserves (saves them from want) (and by virtue of which) Allah brings profit for them and makes them rich}}
\hadithdefcmd{muslim}{2311}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لأَبِي كُرَيْبٍ - قَالُوا حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مُزَاحِمِ بْنِ زُفَرَ، عَنْ مُجَاهِدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ دِينَارٌ أَنْفَقْتَهُ فِي سَبِيلِ اللَّهِ وَدِينَارٌ أَنْفَقْتَهُ فِي رَقَبَةٍ وَدِينَارٌ تَصَدَّقْتَ بِهِ عَلَى مِسْكِينٍ وَدِينَارٌ أَنْفَقْتَهُ عَلَى أَهْلِكَ أَعْظَمُهَا أَجْرًا الَّذِي أَنْفَقْتَهُ عَلَى أَهْلِكَ ‏"‏ ‏.‏\hadithno{2311}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Of the dinar you spend as a contribution in Allah's path, or to set free a slave, or as a sadaqa given to a needy, or to support your family, the one yielding the greatest reward is that which you spent on your family}}
\hadithdefcmd{muslim}{2312}{حَدَّثَنَا سَعِيدُ بْنُ مُحَمَّدٍ الْجَرْمِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبْجَرَ الْكِنَانِيُّ، عَنْ أَبِيهِ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، عَنْ خَيْثَمَةَ، قَالَ كُنَّا جُلُوسًا مَعَ عَبْدِ اللَّهِ بْنِ عَمْرٍو إِذْ جَاءَهُ قَهْرَمَانٌ لَهُ فَدَخَلَ فَقَالَ أَعْطَيْتَ الرَّقِيقَ قُوتَهُمْ قَالَ لاَ ‏.‏ قَالَ فَانْطَلِقْ فَأَعْطِهِمْ ‏.‏ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كَفَى بِالْمَرْءِ إِثْمًا أَنْ يَحْبِسَ عَمَّنْ يَمْلِكُ قُوتَهُ ‏"‏ ‏.‏\hadithno{2312}\hadithtrans{Khaithama reported:While we were sitting in the company of 'Abdullah b. 'Umar there came in his steward. He (Ibn 'Umar) said: Have you supplied the provision to the slaves? He said: No. Upon this he said: Go and give (the provision) to them, for the Messenger of Allah (ﷺ) has said: This sin is enough for a man that he withholds the subsistence from one whose master he is}}
\hadithdefcmd{muslim}{2313}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ أَعْتَقَ رَجُلٌ مِنْ بَنِي عُذْرَةَ عَبْدًا لَهُ عَنْ دُبُرٍ، فَبَلَغَ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ ‏"‏ أَلَكَ مَالٌ غَيْرُهُ ‏"‏ ‏.‏ فَقَالَ لاَ ‏.‏ فَقَالَ ‏"‏ مَنْ يَشْتَرِيهِ مِنِّي ‏"‏ ‏.‏ فَاشْتَرَاهُ نُعَيْمُ بْنُ عَبْدِ اللَّهِ الْعَدَوِيُّ بِثَمَانِمِائَةِ دِرْهَمٍ فَجَاءَ بِهَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَدَفَعَهَا إِلَيْهِ ثُمَّ قَالَ ‏"‏ ابْدَأْ بِنَفْسِكَ فَتَصَدَّقْ عَلَيْهَا فَإِنْ فَضَلَ شَىْءٌ فَلأَهْلِكَ فَإِنْ فَضَلَ عَنْ أَهْلِكَ شَىْءٌ فَلِذِي قَرَابَتِكَ فَإِنْ فَضَلَ عَنْ ذِي قَرَابَتِكَ شَىْءٌ فَهَكَذَا وَهَكَذَا ‏"‏ ‏.‏ يَقُولُ فَبَيْنَ يَدَيْكَ وَعَنْ يَمِينِكَ وَعَنْ شِمَالِكَ ‏.‏\hadithno{2313}\hadithtrans{Jabir reported:A person from the Banu 'Udhra set a slave free after his death. This news reached the Messenger of Allah (may peace be upon hhn). Upon this he said: Have you any property besides it? He said: No. Upon this he said: Who would buy (this slave) from me? Nulaim b. Abdullah bought it for eight hundred dirhams and (this amount was) brought to the Messenger of Allah (ﷺ) who returned it to him (the owner), and then said: Start with your own self and spend it on yourself, and if anything is left, it should be spent on your family, and if anything is left (after meeting the needs of the family) it should be spent on relatives, and if anything is left from the family, it should be spent like this, like this. And he was saying: In front of you, on your right and on your left}}
\hadithdefcmd{muslim}{2314}{وَحَدَّثَنِي يَعْقُوبُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ عُلَيَّةَ - عَنْ أَيُّوبَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَجُلاً، مِنَ الأَنْصَارِ - يُقَالُ لَهُ أَبُو مَذْكُورٍ - أَعْتَقَ غُلاَمًا لَهُ عَنْ دُبُرٍ يُقَالُ لَهُ يَعْقُوبُ وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ اللَّيْثِ ‏.‏\hadithno{2314}\hadithtrans{Jabir reported that a person among the Ansar who was called Abu Madhkur granted posthumous freedom to his slave who was called Ya'qub. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2315}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي، طَلْحَةَ أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ أَبُو طَلْحَةَ أَكْثَرَ أَنْصَارِيٍّ بِالْمَدِينَةِ مَالاً وَكَانَ أَحَبَّ أَمْوَالِهِ إِلَيْهِ بَيْرَحَى وَكَانَتْ مُسْتَقْبِلَةَ الْمَسْجِدِ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْخُلُهَا وَيَشْرَبُ مِنْ مَاءٍ فِيهَا طَيِّبٍ ‏.‏ قَالَ أَنَسٌ فَلَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ قَامَ أَبُو طَلْحَةَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ اللَّهَ يَقُولُ فِي كِتَابِهِ ‏\{‏ لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ وَإِنَّ أَحَبَّ أَمْوَالِي إِلَىَّ بَيْرَحَى وَإِنَّهَا صَدَقَةٌ لِلَّهِ أَرْجُو بِرَّهَا وَذُخْرَهَا عِنْدَ اللَّهِ فَضَعْهَا يَا رَسُولَ اللَّهِ حَيْثُ شِئْتَ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ بَخْ ذَلِكَ مَالٌ رَابِحٌ ذَلِكَ مَالٌ رَابِحٌ قَدْ سَمِعْتُ مَا قُلْتَ فِيهَا وَإِنِّي أَرَى أَنْ تَجْعَلَهَا فِي الأَقْرَبِينَ ‏"‏ ‏.‏ فَقَسَمَهَا أَبُو طَلْحَةَ فِي أَقَارِبِهِ وَبَنِي عَمِّهِ ‏.‏\hadithno{2315}\hadithtrans{Anas b. Malik is reported as saying:Abu Talha was the one among the Ansar of Medina who possessed the largest property and among his property he valued most was his garden known as Bairaha' which was opposite the mosque, and the Messenger of Allah (ﷺ) often visited it and he drank of its sweet water. When this verse was revealed: "You will never attain righteousness till you give freely of what you love" (iii. 91), Abu Talha got up and, going to Allah's Messenger (ﷺ), said: Allah says in His Book: "You will never attain righteousness till you give freely of what you love," and the dearest of my property is Bairaha' so I give it as Sadaqa to God from Whom I hope for reward for it and the treasure with Allah; so spend it, Messenger of Allah, on whatever purpose you deem it proper. The Messenger of Allah (ﷺ) said: Well done! that is a profitable deal, that is a profitable deal. I have heard what you have said, but I think you should spend it on your nearest relatives. So Abu Talha distributed it among the nearest relatives and his cousins on his father's side}}
\hadithdefcmd{muslim}{2316}{حَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسٍ، قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ لَنْ تَنَالُوا الْبِرَّ حَتَّى تُنْفِقُوا مِمَّا تُحِبُّونَ‏\}‏ قَالَ أَبُو طَلْحَةَ أُرَى رَبَّنَا يَسْأَلُنَا مِنْ أَمْوَالِنَا فَأُشْهِدُكَ يَا رَسُولَ اللَّهِ أَنِّي قَدْ جَعَلْتُ أَرْضِي بَرِيحَا لِلَّهِ ‏.‏ قَالَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اجْعَلْهَا فِي قَرَابَتِكَ ‏"‏ ‏.‏ قَالَ فَجَعَلَهَا فِي حَسَّانَ بْنِ ثَابِتٍ وَأُبَىِّ بْنِ كَعْبٍ ‏.‏\hadithno{2316}\hadithtrans{Anas reported that when this verse was tevealed:" You will not attain righteousness till you give freely of what you love," Abu Talha said: I see that our Lord has demanded from us out of our property; so I make you a witness, Messenger of Allah. that I give my land known as Bairaha' for the sake of Allah. Upon this the Messenger of Allah (ﷺ) said: Give that to your relatives. So he gave it to Hassan b. Thabit and Ubayy b. Ka'b}}
\hadithdefcmd{muslim}{2317}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنْ بُكَيْرٍ، عَنْ كُرَيْبٍ، عَنْ مَيْمُونَةَ بِنْتِ الْحَارِثِ، أَنَّهَا أَعْتَقَتْ وَلِيدَةً فِي زَمَانِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَتْ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لَوْ أَعْطَيْتِهَا أَخْوَالَكِ كَانَ أَعْظَمَ لأَجْرِكِ ‏"‏ ‏.‏\hadithno{2317}\hadithtrans{Maimuna bint Harith reported that she set free a slave-girl during the lifetime of the Messenger of Allah (ﷺ) and she made a mention of that to the Messenger of Allah (ﷺ) and he said:Had you gives her to your maternal uncles, you would have a greater reward}}
\hadithdefcmd{muslim}{2318}{حَدَّثَنَا حَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ زَيْنَبَ، امْرَأَةِ عَبْدِ اللَّهِ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَصَدَّقْنَ يَا مَعْشَرَ النِّسَاءِ وَلَوْ مِنْ حُلِيِّكُنَّ ‏"‏ ‏.‏ قَالَتْ فَرَجَعْتُ إِلَى عَبْدِ اللَّهِ فَقُلْتُ إِنَّكَ رَجُلٌ خَفِيفُ ذَاتِ الْيَدِ وَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَدْ أَمَرَنَا بِالصَّدَقَةِ فَأْتِهِ فَاسْأَلْهُ فَإِنْ كَانَ ذَلِكَ يَجْزِي عَنِّي وَإِلاَّ صَرَفْتُهَا إِلَى غَيْرِكُمْ ‏.‏ قَالَتْ فَقَالَ لِي عَبْدُ اللَّهِ بَلِ ائْتِيهِ أَنْتِ ‏.‏ قَالَتْ فَانْطَلَقْتُ فَإِذَا امْرَأَةٌ مِنَ الأَنْصَارِ بِبَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم حَاجَتِي حَاجَتُهَا - قَالَتْ - وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَدْ أُلْقِيَتْ عَلَيْهِ الْمَهَابَةُ - قَالَتْ - فَخَرَجَ عَلَيْنَا بِلاَلٌ فَقُلْنَا لَهُ ائْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبِرْهُ أَنَّ امْرَأَتَيْنِ بِالْبَابِ تَسْأَلاَنِكَ أَتَجْزِي الصَّدَقَةُ عَنْهُمَا عَلَى أَزْوَاجِهِمَا وَعَلَى أَيْتَامٍ فِي حُجُورِهِمَا وَلاَ تُخْبِرْهُ مَنْ نَحْنُ - قَالَتْ - فَدَخَلَ بِلاَلٌ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَأَلَهُ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ هُمَا ‏"‏ ‏.‏ فَقَالَ امْرَأَةٌ مِنَ الأَنْصَارِ وَزَيْنَبُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَىُّ الزَّيَانِبِ ‏"‏ ‏.‏ قَالَ امْرَأَةُ عَبْدِ اللَّهِ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَهُمَا أَجْرَانِ أَجْرُ الْقَرَابَةِ وَأَجْرُ الصَّدَقَةِ ‏"‏ ‏.‏\hadithno{2318}\hadithtrans{Zainab, the wife of 'Abdullah (b. Mas'ud ), reported that the Messenger of Allah (ﷺ) said:0 women, give sadaqa even though it be some of your jewellery. She returned to 'Abdullah and said: You are a person with empty hands, whereas the Messenger of Allah (ﷺ) has commanded us to give sadaqa, so better go to him and ask and if this will suffice for me; otherwise I shall give it to someone else. 'Abdullah said to me (his wife): You better go yourself. So I went and there was another woman of the Ansar at the door of the Messenger of Allah (ﷺ) having the same porpose as I had. Now Allah's Messenger (ﷺ) was invested with awe (so we did not like to knock). Then Bilal came out and we said to him: Go to the Messenger of Allah (ﷺ) and inform him that there are two women at the door asking him whether it will serve them to give sadaqa to their spouses and to orphans who are under their charge, but do not inform him who we are. Bilal went to the Messenger of Allah (ﷺ) and asked him (what these women had instructed him to ask). The Messenger of Allah (ﷺ) asked him who these women were. He (Bilal) said: They are women from Ansar and Zainab. Upon this the Messenger of Allah (ﷺ) said: Which of the Zainabs? He said: The wife of 'Abdullah. The Messenger of Allah (ﷺ) said: There are two rewards for them, the reward of kinship and the reward of Sadaqa}}
\hadithdefcmd{muslim}{2319}{حَدَّثَنِي أَحْمَدُ بْنُ يُوسُفَ الأَزْدِيُّ، حَدَّثَنَا عُمَرُ بْنُ حَفْصِ بْنِ غِيَاثٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنِي شَقِيقٌ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ زَيْنَبَ، امْرَأَةِ عَبْدِ اللَّهِ ‏.‏ قَالَ فَذَكَرْتُ لإِبْرَاهِيمَ فَحَدَّثَنِي عَنْ أَبِي عَبَيْدَةَ عَنْ عَمْرِو بْنِ الْحَارِثِ عَنْ زَيْنَبَ امْرَأَةِ عَبْدِ اللَّهِ ‏.‏ بِمِثْلِهِ سَوَاءً قَالَ قَالَتْ كُنْتُ فِي الْمَسْجِدِ فَرَآنِي النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ تَصَدَّقْنَ وَلَوْ مِنْ حُلِيِّكُنَّ ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ بِنَحْوِ حَدِيثِ أَبِي الأَحْوَصِ ‏.‏\hadithno{2319}\hadithtrans{A hadith like this has been narrated on the authority of Zainab the wife of 'Abdullah, and she said:I was in the mosque and the Prophet of Allah (ﷺ) saw me and said: Give Sadaqa even though it is out of your jewellery. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2320}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ زَيْنَبَ بِنْتِ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ هَلْ لِي أَجْرٌ فِي بَنِي أَبِي سَلَمَةَ أُنْفِقُ عَلَيْهِمْ وَلَسْتُ بِتَارِكَتِهِمْ هَكَذَا وَهَكَذَا إِنَّمَا هُمْ بَنِيَّ ‏.‏ فَقَالَ ‏ "‏ نَعَمْ لَكِ فِيهِمْ أَجْرُ مَا أَنْفَقْتِ عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{2320}\hadithtrans{Umm Salama said:I asked the Messenger of Allah (ﷺ) whether there is a reward for me if I spend on Abu Salama's sons, and I am not going to abandon them in this state (of helplessness) for they are my sons. He (the Holy Prophet) said: Yes. For you is the reward for what you spend on them}}
\hadithdefcmd{muslim}{2321}{وَحَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، ح وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، جَمِيعًا عَنْ هِشَامِ بْنِ عُرْوَةَ، فِي هَذَا الإِسْنَادِ بِمِثْلِهِ ‏.‏\hadithno{2321}\hadithtrans{This hadith has been narrated by Ibn 'Urwa with the same chain of transmitters}}
\hadithdefcmd{muslim}{2322}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَدِيٍّ، - وَهُوَ ابْنُ ثَابِتٍ - عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ أَبِي مَسْعُودٍ الْبَدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْمُسْلِمَ إِذَا أَنْفَقَ عَلَى أَهْلِهِ نَفَقَةً وَهُوَ يَحْتَسِبُهَا كَانَتْ لَهُ صَدَقَةً ‏"‏ ‏.‏\hadithno{2322}\hadithtrans{Abu Mas'ud reported Allah's Messenger (way peace be upon him) as saying:When a Muslim spends on his family seeking reward for it from Allah, it counts for him as sadaqa}}
\hadithdefcmd{muslim}{2323}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ بَشَّارٍ، وَأَبُو بَكْرِ بْنُ نَافِعٍ كِلاَهُمَا عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، ح وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، جَمِيعًا عَنْ شُعْبَةَ، فِي هَذَا الإِسْنَادِ ‏.‏\hadithno{2323}\hadithtrans{This hadith has been narrated by Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{2324}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ، قَالَتْ قُلْتُ يَا رَسُولَ اللَّهِ إِنَّ أُمِّي قَدِمَتْ عَلَىَّ وَهْىَ رَاغِبَةٌ - أَوْ رَاهِبَةٌ - أَفَأَصِلُهَا قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏\hadithno{2324}\hadithtrans{Asma' daughter of Abu Bakr reported:I said: Messenger of Allah, my mother, who is inclined or scared has come to me. Should I (even An her position of being opposed to Islam) treat her well? He said: Yes}}
\hadithdefcmd{muslim}{2325}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ قَدِمَتْ عَلَىَّ أُمِّي وَهِيَ مُشْرِكَةٌ فِي عَهْدِ قُرَيْشٍ إِذْ عَاهَدَهُمْ فَاسْتَفْتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ قَدِمَتْ عَلَىَّ أُمِّي وَهْىَ رَاغِبَةٌ أَفَأَصِلُ أُمِّي قَالَ ‏ "‏ نَعَمْ صِلِي أُمَّكِ ‏"‏ ‏.‏\hadithno{2325}\hadithtrans{Asma' bint Abu Bakr reported:My mother who was a polytheist came to me when he (the Holy Prophet) entered into treaty with, the Quraish (of Mecca). I inquired from the Messenger of Allah (ﷺ) saying: Messenger of Allah, there has come to me my mother and she is inclined; should I (in this state of her mind) show her kindness? He said: Yes, treat her kindly}}
\hadithdefcmd{muslim}{2326}{وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّ أُمِّيَ افْتُلِتَتْ نَفْسَهَا وَلَمْ تُوصِ وَأَظُنُّهَا لَوْ تَكَلَّمَتْ تَصَدَّقَتْ أَفَلَهَا أَجْرٌ إِنْ تَصَدَّقْتُ عَنْهَا قَالَ ‏ "‏ نَعَمْ ‏"‏.‏\hadithno{2326}\hadithtrans{A'isha said that a person came to the Messenger of Allah (ﷺ) and said:My mother died suddenly without having made any will. I think she would have definitely given Sadaqa if she had been able to speak. Would she have a reward if I gave Sadaqa on her behalf? He (the Holy Prophet) said: Yes}}
\hadithdefcmd{muslim}{2327}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، ح حَدَّثَنَا الْحَكَمُ بْنُ مُوسَى، حَدَّثَنَا شُعَيْبُ بْنُ إِسْحَاقَ، كُلُّهُمْ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِ أَبِي أُسَامَةَ وَلَمْ تُوصِ ‏.‏ كَمَا قَالَ ابْنُ بِشْرٍ وَلَمْ يَقُلْ ذَلِكَ الْبَاقُونَ ‏.‏\hadithno{2327}\hadithtrans{This hadith has been narrated on the authority of Hisham with the same chain of transmitters. And in the hadith transmitted by Abu Usama the words are:" She did not make any will," as it has been reported by Ibn Bishr, but it was not reported by the rest of the narrators}}
\hadithdefcmd{muslim}{2328}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبَّادُ بْنُ الْعَوَّامِ، كِلاَهُمَا عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ، فِي حَدِيثِ قُتَيْبَةَ قَالَ قَالَ نَبِيُّكُمْ صلى الله عليه وسلم وَقَالَ ابْنُ أَبِي شَيْبَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُّ مَعْرُوفٍ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2328}\hadithtrans{Hudhaifa and Abu Shaiba reported Allah's Messenger (ﷺ) as saying:Every act of goodness is sadaqa}}
\hadithdefcmd{muslim}{2329}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ الضُّبَعِيُّ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، حَدَّثَنَا وَاصِلٌ، مَوْلَى أَبِي عُيَيْنَةَ عَنْ يَحْيَى بْنِ عُقَيْلٍ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنْ أَبِي الأَسْوَدِ الدِّيلِيِّ، عَنْ أَبِي، ذَرٍّ أَنَّ نَاسًا، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالُوا لِلنَّبِيِّ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ ذَهَبَ أَهْلُ الدُّثُورِ بِالأُجُورِ يُصَلُّونَ كَمَا نُصَلِّي وَيَصُومُونَ كَمَا نَصُومُ وَيَتَصَدَّقُونَ بِفُضُولِ أَمْوَالِهِمْ ‏.‏ قَالَ ‏"‏ أَوَلَيْسَ قَدْ جَعَلَ اللَّهُ لَكُمْ مَا تَصَّدَّقُونَ إِنَّ بِكُلِّ تَسْبِيحَةٍ صَدَقَةً وَكُلِّ تَكْبِيرَةٍ صَدَقَةٌ وَكُلِّ تَحْمِيدَةٍ صَدَقَةٌ وَكُلِّ تَهْلِيلَةٍ صَدَقَةٌ وَأَمْرٌ بِالْمَعْرُوفِ صَدَقَةٌ وَنَهْىٌ عَنْ مُنْكَرٍ صَدَقَةٌ وَفِي بُضْعِ أَحَدِكُمْ صَدَقَةٌ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ أَيَأْتِي أَحَدُنَا شَهْوَتَهُ وَيَكُونُ لَهُ فِيهَا أَجْرٌ قَالَ ‏"‏ أَرَأَيْتُمْ لَوْ وَضَعَهَا فِي حَرَامٍ أَكَانَ عَلَيْهِ فِيهَا وِزْرٌ فَكَذَلِكَ إِذَا وَضَعَهَا فِي الْحَلاَلِ كَانَ لَهُ أَجْرٌ ‏"‏ ‏.‏\hadithno{2329}\hadithtrans{Abu Dharr reported:some of the people from among the Companions of the Messenger of Allah (ﷺ) said to him: Messenger of Allah, the rich have taken away (all the) reward. They observe prayer as we do; they keep the fasts as we keep, and they give Sadaqa out of their surplus riches. Upon this he (the Holy Prophet) said: Has Allah not prescribed for you (a course) by following which you can (also) do sadaqa? In every declaration of the glorification of Allah (i. e. saying Subhan Allah) there is a Sadaqa, and every Takbir (i. e. saying Allah-O-Akbar) is a sadaqa, and every praise of His (saying al-Hamdu Lillah) is a Sadaqa and every declaration that He is One (La illha ill-Allah) is a sadaqa, and enjoining of good is a sadaqa, and forbidding of that which is evil is a Sadaqa, and in man's sexual Intercourse (with his wife, ) there is a Sadaqa. They (the Companions) said: Messenger of Allah, is there reward for him who satisfies his sexual passion among us? He said: Tell me, if he were to devote it to something forbidden, would it not be a sin on his part? Similarly, if he were to devote it to something lawful, he should have a reward}}
\hadithdefcmd{muslim}{2330}{حَدَّثَنَا حَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا أَبُو تَوْبَةَ الرَّبِيعُ بْنُ نَافِعٍ، حَدَّثَنَا مُعَاوِيَةُ، - يَعْنِي ابْنَ سَلاَّمٍ - عَنْ زَيْدٍ، أَنَّهُ سَمِعَ أَبَا سَلاَّمٍ، يَقُولُ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ فَرُّوخَ، أَنَّهُ سَمِعَ عَائِشَةَ، تَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّهُ خُلِقَ كُلُّ إِنْسَانٍ مِنْ بَنِي آدَمَ عَلَى سِتِّينَ وَثَلاَثِمَائَةِ مَفْصِلٍ فَمَنْ كَبَّرَ اللَّهَ وَحَمِدَ اللَّهَ وَهَلَّلَ اللَّهَ وَسَبَّحَ اللَّهَ وَاسْتَغْفَرَ اللَّهَ وَعَزَلَ حَجَرًا عَنْ طَرِيقِ النَّاسِ أَوْ شَوْكَةً أَوْ عَظْمًا عَنْ طَرِيقِ النَّاسِ وَأَمَرَ بِمَعْرُوفٍ أَوْ نَهَى عَنْ مُنْكَرٍ عَدَدَ تِلْكَ السِّتِّينَ وَالثَّلاَثِمِائَةِ السُّلاَمَى فَإِنَّهُ يَمْشِي يَوْمَئِذٍ وَقَدْ زَحْزَحَ نَفْسَهُ عَنِ النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو تَوْبَةَ وَرُبَّمَا قَالَ ‏"‏ يُمْسِي ‏"‏ ‏.‏\hadithno{2330}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) as saying:Every one of the children of Adam has been created with three hundred and sixty joints; so he who declares the Glory of Allah, praises Allah, declares Allah to be One, Glorifies Allah, and seeks forgiveness from Allah, and removes stone, or thorn, or bone from people's path, and enjoins what is good and forbids from evil, to the number of those three hundred and sixty joints, will walk that day having saved himself from the Fire. Abu Taubah said: "Perhaps he said: 'Will reach the evening}}
\hadithdefcmd{muslim}{2331}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا يَحْيَى بْنُ حَسَّانَ، حَدَّثَنِي مُعَاوِيَةُ، أَخْبَرَنِي أَخِي، زَيْدٌ بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّهُ قَالَ ‏"‏ أَوْ أَمَرَ بِمَعْرُوفٍ ‏"‏ ‏.‏ وَقَالَ ‏"‏ فَإِنَّهُ يُمْسِي يَوْمَئِذٍ ‏"‏ ‏.‏\hadithno{2331}\hadithtrans{This hadith has been narrated on the authority of Zaid with the same chain of transmitters except with (a slight) change of words (i.e. he [the Holy Prophet]) said:Or he enjoined what is good, ... and said: He enters the evening [i.e. he walks till evening]}}
\hadithdefcmd{muslim}{2332}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ نَافِعٍ الْعَبْدِيُّ، حَدَّثَنَا يَحْيَى بْنُ كَثِيرٍ، حَدَّثَنَا عَلِيٌّ، - يَعْنِي ابْنَ الْمُبَارَكِ - حَدَّثَنَا يَحْيَى، عَنْ زَيْدِ بْنِ سَلاَّمٍ، عَنْ جَدِّهِ أَبِي سَلاَّمٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ، بْنُ فَرُّوخَ أَنَّهُ سَمِعَ عَائِشَةَ، تَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خُلِقَ كُلُّ إِنْسَانٍ ‏"‏ ‏.‏ بِنَحْوِ حَدِيثِ مُعَاوِيَةَ عَنْ زَيْدٍ ‏.‏ وَقَالَ ‏"‏ فَإِنَّهُ يَمْشِي يَوْمَئِذٍ ‏"‏ ‏.‏\hadithno{2332}\hadithtrans{This hadith has been narrated by 'A'isha through anothr chain of transmitters in which she reported Allah's Messenger (ﷺ) as saying:" Every man is created" ; the rest of the hadith is the same and he said:" He walks on that day}}
\hadithdefcmd{muslim}{2333}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ شُعْبَةَ، عَنْ سَعِيدِ بْنِ أَبِي، بُرْدَةَ عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ عَلَى كُلِّ مُسْلِمٍ صَدَقَةٌ ‏"‏ ‏.‏ قِيلَ أَرَأَيْتَ إِنْ لَمْ يَجِدْ قَالَ ‏"‏ يَعْتَمِلُ بِيَدَيْهِ فَيَنْفَعُ نَفْسَهُ وَيَتَصَدَّقُ ‏"‏ ‏.‏ قَالَ قِيلَ أَرَأَيْتَ إِنْ لَمْ يَسْتَطِعْ قَالَ ‏"‏ يُعِينُ ذَا الْحَاجَةِ الْمَلْهُوفَ ‏"‏ ‏.‏ قَالَ قِيلَ لَهُ أَرَأَيْتَ إِنْ لَمْ يَسْتَطِعْ قَالَ ‏"‏ يَأْمُرُ بِالْمَعْرُوفِ أَوِ الْخَيْرِ ‏"‏ ‏.‏ قَالَ أَرَأَيْتَ إِنْ لَمْ يَفْعَلْ قَالَ ‏"‏ يُمْسِكُ عَنِ الشَّرِّ فَإِنَّهَا صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2333}\hadithtrans{Sa'id b. Abu Burda reported on the authority of his grandfather that the Messenger of Allah (ﷺ) said:Giving of Sadaqa is essential for every Muslim. It was said (to him): What do you say of him who does not find (the means) to do so? He said: Let him work with both his hands, thus doing benefit to himself and give Sadaqa. It was said to him: What about him who does not have (the means) to do so? He said: Then let him assist the needy, the aggrieved. It was said: What do you say of one who cannot even do this? He said: Then he should enjoin what is reputable or what is good. He said: What about him if he cannot do that? He (the Holy Prophet) said: He should then abstain from evil, for verify that is Sadaqa on his behalf}}
\hadithdefcmd{muslim}{2334}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ.‏\hadithno{2334}\hadithtrans{This hadith has been narrated by Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{2335}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ بْنُ هَمَّامٍ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ، مُنَبِّهٍ قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ مُحَمَّدٍ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُّ سُلاَمَى مِنَ النَّاسِ عَلَيْهِ صَدَقَةٌ كُلَّ يَوْمٍ تَطْلُعُ فِيهِ الشَّمْسُ - قَالَ - تَعْدِلُ بَيْنَ الاِثْنَيْنِ صَدَقَةٌ وَتُعِينُ الرَّجُلَ فِي دَابَّتِهِ فَتَحْمِلُهُ عَلَيْهَا أَوْ تَرْفَعُ لَهُ عَلَيْهَا مَتَاعَهُ صَدَقَةٌ - قَالَ - وَالْكَلِمَةُ الطَّيِّبَةُ صَدَقَةٌ وَكُلُّ خَطْوَةٍ تَمْشِيهَا إِلَى الصَّلاَةِ صَدَقَةٌ وَتُمِيطُ الأَذَى عَنِ الطَّرِيقِ صَدَقَةٌ ‏"‏ ‏.‏\hadithno{2335}\hadithtrans{Hammam b. Munabbih reported that-this is out of (those ahadith) which Abu Huraira narrated to us from Muhammad, the Messenger of Allah (ﷺ). And he while making a mention of ahadith reported from Allah's Messenger (ﷺ) said this:Sadaqa is due on every joint of a person, every day the sun rises. Administering of justice between two men is also a Sadaqa. And assisting a man to ride upon his beast, or helping him load his luggage upon it, is a Sadaqa; and a good word is a Sadaqa; and every step that you take towards prayer is a Sadaqa, and removing of harmful things from the pathway is a Sadaqa}}
\hadithdefcmd{muslim}{2336}{وَحَدَّثَنِي الْقَاسِمُ بْنُ زَكَرِيَّا، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنِي سُلَيْمَانُ، - وَهُوَ ابْنُ بِلاَلٍ - حَدَّثَنِي مُعَاوِيَةُ بْنُ أَبِي مُزَرِّدٍ، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ يَوْمٍ يُصْبِحُ الْعِبَادُ فِيهِ إِلاَّ مَلَكَانِ يَنْزِلاَنِ فَيَقُولُ أَحَدُهُمَا اللَّهُمَّ أَعْطِ مُنْفِقًا خَلَفًا ‏.‏ وَيَقُولُ الآخَرُ اللَّهُمَّ أَعْطِ مُمْسِكًا تَلَفًا ‏"‏ ‏.‏\hadithno{2336}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There is never a day wherein servants (of God) get up at morn, but are not visited by two angels. One of them says: 0 Allah, give him more who spends (for the sake of Allah), and the other says: 0 Allah, bring destruction to one who withholds}}
\hadithdefcmd{muslim}{2337}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، - وَاللَّفْظُ لَهُ - حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مَعْبَدِ بْنِ خَالِدٍ، قَالَ سَمِعْتُ حَارِثَةَ بْنَ وَهْبٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تَصَدَّقُوا فَيُوشِكُ الرَّجُلُ يَمْشِي بِصَدَقَتِهِ فَيَقُولُ الَّذِي أُعْطِيَهَا لَوْ جِئْتَنَا بِهَا بِالأَمْسِ قَبِلْتُهَا فَأَمَّا الآنَ فَلاَ حَاجَةَ لِي بِهَا ‏.‏ فَلاَ يَجِدُ مَنْ يَقْبَلُهَا ‏"‏ ‏.‏\hadithno{2337}\hadithtrans{Haritha b. Wahb reported Allah's Messenger (ﷺ) as saying:Give Sadaqa for a time is about to come when a person would walk with alms and the one whom it is to be given would say: Had you brought it yesterday, I would have accepted it. For the present I do not need it. (And the giver of Sadaqa) I would not find anyone to accept it}}
\hadithdefcmd{muslim}{2338}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَرَّادٍ الأَشْعَرِيُّ، وَأَبُو كُرَيْبٍ مُحَمَّدُ بْنُ الْعَلاَءِ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لَيَأْتِيَنَّ عَلَى النَّاسِ زَمَانٌ يَطُوفُ الرَّجُلُ فِيهِ بِالصَّدَقَةِ مِنَ الذَّهَبِ ثُمَّ لاَ يَجِدُ أَحَدًا يَأْخُذُهَا مِنْهُ وَيُرَى الرَّجُلُ الْوَاحِدُ يَتْبَعُهُ أَرْبَعُونَ امْرَأَةً يَلُذْنَ بِهِ مِنْ قِلَّةِ الرِّجَالِ وَكَثْرَةِ النِّسَاءِ ‏"‏ ‏.‏ وَفِي رِوَايَةِ ابْنِ بَرَّادٍ ‏"‏ وَتَرَى الرَّجُلَ ‏"‏ ‏.‏\hadithno{2338}\hadithtrans{Abu Musa reported Allah's Messenger (ﷺ) as saying:There would come a time for the people when a person would roam about with Sadaqa of gold, but he would find no one to accept it from him. And a man would be seen followed by forty women seeking refuge with him on account of the scarcity of males and abundance of females}}
\hadithdefcmd{muslim}{2340}{وَحَدَّثَنَا أَبُو الطَّاهِرِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ أَبِي يُونُسَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَكْثُرَ فِيكُمُ الْمَالُ فَيَفِيضَ حَتَّى يُهِمَّ رَبَّ الْمَالِ مَنْ يَقْبَلُهُ مِنْهُ صَدَقَةً وَيُدْعَى إِلَيْهِ الرَّجُلُ فَيَقُولُ لاَ أَرَبَ لِي فِيهِ ‏"‏ ‏.‏\hadithno{2340}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The Last Hour will not come till wealth is abundant and overflowing, so much so that the owner of the property will think as to who will accept Sadaqa from him, and a person would be called to accept Sadaqa and he would say: I do not need it}}
\hadithdefcmd{muslim}{2341}{وَحَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، وَأَبُو كُرَيْبٍ وَمُحَمَّدُ بْنُ يَزِيدَ الرِّفَاعِيُّ - وَاللَّفْظُ لِوَاصِلٍ - قَالُوا حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَقِيءُ الأَرْضُ أَفْلاَذَ كَبِدِهَا أَمْثَالَ الأُسْطُوَانِ مِنَ الذَّهَبِ وَالْفِضَّةِ فَيَجِيءُ الْقَاتِلُ فَيَقُولُ فِي هَذَا قَتَلْتُ ‏.‏ وَيَجِيءُ الْقَاطِعُ فَيَقُولُ فِي هَذَا قَطَعْتُ رَحِمِي ‏.‏ وَيَجِيءُ السَّارِقُ فَيَقُولُ فِي هَذَا قُطِعَتْ يَدِي ثُمَّ يَدَعُونَهُ فَلاَ يَأْخُذُونَ مِنْهُ شَيْئًا ‏"‏ ‏.‏\hadithno{2341}\hadithtrans{Abu Huraira reported Allah's Messenaer (ﷺ) as saying:The earth will vomit long pieces of its liver like columns of gold and silver, and the murderer will come and say: It was for this that I committed murder. The breaker of family ties will come and say: It was for this that I broke the family ties; and the thief will come and say: It is for this that my hands were cut off. They will then leave it and will not take anything out of it}}
\hadithdefcmd{muslim}{2342}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ سَعِيدِ بْنِ يَسَارٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا تَصَدَّقَ أَحَدٌ بِصَدَقَةٍ مِنْ طَيِّبٍ - وَلاَ يَقْبَلُ اللَّهُ إِلاَّ الطَّيِّبَ - إِلاَّ أَخَذَهَا الرَّحْمَنُ بِيَمِينِهِ وَإِنْ كَانَتْ تَمْرَةً فَتَرْبُو فِي كَفِّ الرَّحْمَنِ حَتَّى تَكُونَ أَعْظَمَ مِنَ الْجَبَلِ كَمَا يُرَبِّي أَحَدُكُمْ فَلُوَّهُ أَوْ فَصِيلَهُ ‏"‏ ‏.‏\hadithno{2342}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:If anyone gives as Sadaqa the equivalent of a date from that (earning) earned honestly, for Allah accepts that which is lawful, the Lord would accept it with His Right Hand, and even if it is a date, it would foster in the Hand of the lord, as one of you fosters his colt, till it becomes bigger than a mountain}}
\hadithdefcmd{muslim}{2343}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْقَارِيَّ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَتَصَدَّقُ أَحَدٌ بِتَمْرَةٍ مِنْ كَسْبٍ طَيِّبٍ إِلاَّ أَخَذَهَا اللَّهُ بِيَمِينِهِ فَيُرَبِّيهَا كَمَا يُرَبِّي أَحَدُكُمْ فَلُوَّهُ أَوْ قَلُوصَهُ حَتَّى تَكُونَ مِثْلَ الْجَبَلِ أَوْ أَعْظَمَ ‏"‏ ‏.‏\hadithno{2343}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:No one gives Sadaqa of a date out of his honest earning, but Allah accepts it with His Right Hand, and then fosters it as one of you fosters the colt or a young she-camel, till it becomes like a mountain or even greater}}
\hadithdefcmd{muslim}{2344}{وَحَدَّثَنِي أُمَيَّةُ بْنُ بِسْطَامَ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - حَدَّثَنَا رَوْحُ بْنُ الْقَاسِمِ، ح وَحَدَّثَنِيهِ أَحْمَدُ بْنُ عُثْمَانَ الأَوْدِيُّ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنِي سُلَيْمَانُ، - يَعْنِي ابْنَ بِلاَلٍ - كِلاَهُمَا عَنْ سُهَيْلٍ، بِهَذَا الإِسْنَادِ ‏.‏ فِي حَدِيثِ رَوْحٍ ‏"‏ مِنَ الْكَسْبِ الطَّيِّبِ فَيَضَعُهَا فِي حَقِّهَا ‏"‏ ‏.‏ وَفِي حَدِيثِ سُلَيْمَانَ ‏"‏ فَيَضَعُهَا فِي مَوْضِعِهَا ‏"‏ ‏.‏\hadithno{2344}\hadithtrans{This hadith has been narrated through another chain of transmitters with a change of words. In the hadith transmitted Rauh (the words are):" Out of the honest earning and its spending at what is its (due) right" ; and in the hadith transmitted by Sulaiman (the words are):" And its spending at its proper place}}
\hadithdefcmd{muslim}{2345}{وَحَدَّثَنِيهِ أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي هِشَامُ بْنُ سَعْدٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ حَدِيثِ يَعْقُوبَ عَنْ سُهَيْلٍ ‏.‏\hadithno{2345}\hadithtrans{Narrated Abu Huraira:This hadith has been transmitted through another chain the same as the narration of Ya'qub from Suhail}}
\hadithdefcmd{muslim}{2346}{وَحَدَّثَنِي أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا فُضَيْلُ بْنُ مَرْزُوقٍ، حَدَّثَنِي عَدِيُّ بْنُ ثَابِتٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيُّهَا النَّاسُ إِنَّ اللَّهَ طَيِّبٌ لاَ يَقْبَلُ إِلاَّ طَيِّبًا وَإِنَّ اللَّهَ أَمَرَ الْمُؤْمِنِينَ بِمَا أَمَرَ بِهِ الْمُرْسَلِينَ فَقَالَ ‏\{‏ يَا أَيُّهَا الرُّسُلُ كُلُوا مِنَ الطَّيِّبَاتِ وَاعْمَلُوا صَالِحًا إِنِّي بِمَا تَعْمَلُونَ عَلِيمٌ‏\}‏ وَقَالَ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا كُلُوا مِنْ طَيِّبَاتِ مَا رَزَقْنَاكُمْ‏\}‏ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ الرَّجُلَ يُطِيلُ السَّفَرَ أَشْعَثَ أَغْبَرَ يَمُدُّ يَدَيْهِ إِلَى السَّمَاءِ يَا رَبِّ يَا رَبِّ وَمَطْعَمُهُ حَرَامٌ وَمَشْرَبُهُ حَرَامٌ وَمَلْبَسُهُ حَرَامٌ وَغُذِيَ بِالْحَرَامِ فَأَنَّى يُسْتَجَابُ لِذَلِكَ ‏"‏ ‏.‏\hadithno{2346}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:O people, Allah is Good and He therefore, accepts only that which is good. And Allah commanded the believers as He commanded the Messengers by saying: "O Messengers, eat of the good things, and do good deeds; verily I am aware of what you do" (xxiii. 51). And He said: "O those who believe, eat of the good things that We gave you" (ii. 172). He then made a mention of a person who travels widely, his hair disheveled and covered with dust. He lifts his hand towards the sky (and thus makes the supplication): "O Lord, O Lord," whereas his diet is unlawful, his drink is unlawful, and his clothes are unlawful and his nourishment is unlawful. How can then his supplication be accepted?}}
\hadithdefcmd{muslim}{2347}{حَدَّثَنَا عَوْنُ بْنُ سَلاَّمٍ الْكُوفِيُّ، حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ الْجُعْفِيُّ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْقِلٍ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ اسْتَطَاعَ مِنْكُمْ أَنْ يَسْتَتِرَ مِنَ النَّارِ وَلَوْ بِشِقِّ تَمْرَةٍ فَلْيَفْعَلْ ‏"‏ ‏.‏\hadithno{2347}\hadithtrans{Adi b. Hatim reported that he heard Allah's Messenger (way peace be upon him) as saying:He who among you can protect himself against Fire, he should do so, even if it should be with half a date}}
\hadithdefcmd{muslim}{2348}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ خَشْرَمٍ، قَالَ ابْنُ حُجْرٍ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، عَنْ خَيْثَمَةَ، عَنْ عَدِيِّ، بْنِ حَاتِمٍ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْكُمْ مِنْ أَحَدٍ إِلاَّ سَيُكَلِّمُهُ اللَّهُ لَيْسَ بَيْنَهُ وَبَيْنَهُ تُرْجُمَانٌ فَيَنْظُرُ أَيْمَنَ مِنْهُ فَلاَ يَرَى إِلاَّ مَا قَدَّمَ وَيَنْظُرُ أَشْأَمَ مِنْهُ فَلاَ يَرَى إِلاَّ مَا قَدَّمَ وَيَنْظُرُ بَيْنَ يَدَيْهِ فَلاَ يَرَى إِلاَّ النَّارَ تِلْقَاءَ وَجْهِهِ فَاتَّقُوا النَّارَ وَلَوْ بِشِقِّ تَمْرَةٍ ‏"‏ ‏.‏ زَادَ ابْنُ حُجْرٍ قَالَ الأَعْمَشُ وَحَدَّثَنِي عَمْرُو بْنُ مُرَّةَ عَنْ خَيْثَمَةَ مِثْلَهُ وَزَادَ فِيهِ ‏"‏ وَلَوْ بِكَلِمَةٍ طَيِّبَةٍ ‏"‏ ‏.‏ وَقَالَ إِسْحَاقُ قَالَ الأَعْمَشُ عَنْ عَمْرِو بْنِ مُرَّةَ عَنْ خَيْثَمَةَ ‏.‏\hadithno{2348}\hadithtrans{Adi b. Hatim reported Allah's Messenger (ﷺ) as saying:Allah will speak with everyone amongst you without any interpreter between them. He (the man) would see towards his right and would not find anything but (the deeds) which he had done before, and he would see towards the left and would not find anything but (the deeds) which he had done before. He would see in front of him and would find nothing but Fire just before his face. So protect (yourselves) against Fire even if it is with the help of half a date. A hadith like this has been transmitted by Khaithama and addition has been made in this of (these words) ;" Even if it is with a good word}}
\hadithdefcmd{muslim}{2349}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ خَيْثَمَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ ذَكَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّارَ فَأَعْرَضَ وَأَشَاحَ ثُمَّ قَالَ ‏"‏ اتَّقُوا النَّارَ ‏"‏ ‏.‏ ثُمَّ أَعْرَضَ وَأَشَاحَ حَتَّى ظَنَنَّا أَنَّهُ كَأَنَّمَا يَنْظُرُ إِلَيْهَا ثُمَّ قَالَ ‏"‏ اتَّقُوا النَّارَ وَلَوْ بِشِقِّ تَمْرَةٍ فَمَنْ لَمْ يَجِدْ فَبِكَلِمَةٍ طَيِّبَةٍ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ أَبُو كُرَيْبٍ كَأَنَّمَا وَقَالَ حَدَّثَنَا أَبُو مُعَاوِيَةَ حَدَّثَنَا الأَعْمَشُ ‏.‏\hadithno{2349}\hadithtrans{Adi b. Hatim reported that the Messenger of Allah (ﷺ) made a mention of Fire. He turned his face aside and diverted his attention and then said:Guard (yourselves) against Fire. He turned his face and diverted his attention till we thought as if he were (actually seeing it and then said: Protect yourselves against Fire even if it is with half a date, and he who does not find it, (he should do so) with pleasant words. Abu Kuraib did not mention the word: (as if)}}
\hadithdefcmd{muslim}{2350}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ خَيْثَمَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ ذَكَرَ النَّارَ فَتَعَوَّذَ مِنْهَا وَأَشَاحَ بِوَجْهِهِ ثَلاَثَ مِرَارٍ ثُمَّ قَالَ ‏ "‏ اتَّقُوا النَّارَ وَلَوْ بِشِقِّ تَمْرَةٍ فَإِنْ لَمْ تَجِدُوا فَبِكَلِمَةٍ طَيِّبَةٍ ‏"‏ ‏.‏\hadithno{2350}\hadithtrans{Adi b. Hatim reported that the Messenger of Allah (ﷺ) made a mention of the Fire and sought refuge (with Allah against it). He turned aside his face three times and then said:Protect yourselves against Fire even if with half a date. But if you fail to find it (then protect yourselves against Fire) with the help of a pleasant word}}
\hadithdefcmd{muslim}{2351}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَوْنِ، بْنِ أَبِي جُحَيْفَةَ عَنِ الْمُنْذِرِ بْنِ جَرِيرٍ، عَنْ أَبِيهِ، قَالَ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي صَدْرِ النَّهَارِ قَالَ فَجَاءَهُ قَوْمٌ حُفَاةٌ عُرَاةٌ مُجْتَابِي النِّمَارِ أَوِ الْعَبَاءِ مُتَقَلِّدِي السُّيُوفِ عَامَّتُهُمْ مِنْ مُضَرَ بَلْ كُلُّهُمْ مِنْ مُضَرَ فَتَمَعَّرَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم لِمَا رَأَى بِهِمْ مِنَ الْفَاقَةِ فَدَخَلَ ثُمَّ خَرَجَ فَأَمَرَ بِلاَلاً فَأَذَّنَ وَأَقَامَ فَصَلَّى ثُمَّ خَطَبَ فَقَالَ ‏"‏ ‏\{‏ يَا أَيُّهَا النَّاسُ اتَّقُوا رَبَّكُمُ الَّذِي خَلَقَكُمْ مِنْ نَفْسٍ وَاحِدَةٍ‏\}‏ إِلَى آخِرِ الآيَةِ ‏\{‏ إِنَّ اللَّهَ كَانَ عَلَيْكُمْ رَقِيبًا‏\}‏ وَالآيَةَ الَّتِي فِي الْحَشْرِ ‏\{‏ اتَّقُوا اللَّهَ وَلْتَنْظُرْ نَفْسٌ مَا قَدَّمَتْ لِغَدٍ وَاتَّقُوا اللَّهَ‏\}‏ تَصَدَّقَ رَجُلٌ مِنْ دِينَارِهِ مِنْ دِرْهَمِهِ مِنْ ثَوْبِهِ مِنْ صَاعِ بُرِّهِ مِنْ صَاعِ تَمْرِهِ - حَتَّى قَالَ - وَلَوْ بِشِقِّ تَمْرَةٍ ‏"‏ ‏.‏ قَالَ فَجَاءَ رَجُلٌ مِنَ الأَنْصَارِ بِصُرَّةٍ كَادَتْ كَفُّهُ تَعْجِزُ عَنْهَا بَلْ قَدْ عَجَزَتْ - قَالَ - ثُمَّ تَتَابَعَ النَّاسُ حَتَّى رَأَيْتُ كَوْمَيْنِ مِنْ طَعَامٍ وَثِيَابٍ حَتَّى رَأَيْتُ وَجْهَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَتَهَلَّلُ كَأَنَّهُ مُذْهَبَةٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ سَنَّ فِي الإِسْلاَمِ سُنَّةً حَسَنَةً فَلَهُ أَجْرُهَا وَأَجْرُ مَنْ عَمِلَ بِهَا بَعْدَهُ مِنْ غَيْرِ أَنْ يَنْقُصَ مِنْ أُجُورِهِمْ شَىْءٌ وَمَنْ سَنَّ فِي الإِسْلاَمِ سُنَّةً سَيِّئَةً كَانَ عَلَيْهِ وِزْرُهَا وَوِزْرُ مَنْ عَمِلَ بِهَا مِنْ بَعْدِهِ مِنْ غَيْرِ أَنْ يَنْقُصَ مِنْ أَوْزَارِهِمْ شَىْءٌ ‏"‏ ‏.‏\hadithno{2351}\hadithtrans{Mundhir b. Jarir reported on the authority of his father:While we were in the company of the Messenger of Allah (ﷺ) in the early hours of the morning, some people came there (who) were barefooted, naked, wearing striped woollen clothes, or cloaks, with their swords hung (around their necks). Most of them, nay, all of them, belonged to the tribe of Mudar. The colour of the face of the Messenger of Allah (ﷺ) underwent a change when he saw them in poverty. He then entered (his house) and came out and commanded Bilal (to pronounce Adhan). He pronounced Adhan and Iqima, and he (the Holy Prophet) observed prayer (along with his Companion) and then addressed (them reciting verses of the Holy Qur'an): '" 0 people, fear your Lord, Who created you from a single being" to the end of the verse," Allah is ever a Watcher over you" (iv. 1). (He then recited) a verse of Sura Hashr:" Fear Allah. and let every soul consider that which it sends forth for the morrow and fear Allah" (lix. 18). (Then the audience began to vie with one another in giving charity.) Some donated a dinar, others a dirham, still others clothes, some donated a sa' of wheat, some a sa' of dates; till he (the Holy Prophet) said: (Bring) even if it is half a date. Then a person from among the Ansar came there with a money bag which his hands could scarcely lift; in fact, they could not (lift). Then the people followed continuously, till I saw two heaps of eatables and clothes, and I saw the face of the Messenger (ﷺ) glistening, like gold (on account of joy). The Messenger of Allah (ﷺ) said: He who sets a good precedent in Islam, there is a reward for him for this (act of goodness) and reward of that also who acted according to it subsequently, without any deduction from their rewards; and he who sets in Islam an evil precedent, there is upon him the burden of that, and the burden of him also who acted upon it subsequently, without any deduction from their burden}}
\hadithdefcmd{muslim}{2352}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، الْعَنْبَرِيُّ حَدَّثَنَا أَبِي قَالاَ، جَمِيعًا حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي عَوْنُ بْنُ أَبِي جُحَيْفَةَ، قَالَ سَمِعْتُ الْمُنْذِرَ بْنَ جَرِيرٍ، عَنْ أَبِيهِ، قَالَ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَدْرَ النَّهَارِ ‏.‏ بِمِثْلِ حَدِيثِ ابْنِ جَعْفَرٍ وَفِي حَدِيثِ ابْنِ مُعَاذٍ مِنَ الزِّيَادَةِ قَالَ ثُمَّ صَلَّى الظُّهْرَ ثُمَّ خَطَبَ ‏.‏\hadithno{2352}\hadithtrans{This hadith has been narrated on the authority of Mandhir through another chain of transmitters. And the hadith transmitted by Ibn Mu'adh contains an addition:" He then observed the noon prayer and then gave the sermon}}
\hadithdefcmd{muslim}{2353}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، وَأَبُو كَامِلٍ وَمُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ الأُمَوِيُّ قَالُوا حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنِ الْمُنْذِرِ بْنِ جَرِيرٍ، عَنْ أَبِيهِ، قَالَ كُنْتُ جَالِسًا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَأَتَاهُ قَوْمٌ مُجْتَابِي النِّمَارِ وَسَاقُوا الْحَدِيثَ بِقِصَّتِهِ وَفِيهِ فَصَلَّى الظُّهْرَ ثُمَّ صَعِدَ مِنْبَرًا صَغِيرًا فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ فَإِنَّ اللَّهَ أَنْزَلَ فِي كِتَابِهِ ‏\{‏ يَا أَيُّهَا النَّاسُ اتَّقُوا رَبَّكُمُ‏\}‏ الآيَةَ ‏"‏ ‏.‏\hadithno{2353}\hadithtrans{Mundhir b. Jarir narrated on the authority of his father:When we were sitting in the company of the Messenger of Allah (ﷺ). There came people dressed in striped woollen clothes, and the rest of the hadith in the same, and there (it is also mentioned):" He observed the Zuhr prayer and then climbed up a small pulpit, praised Allah, lauded Him, and then said: Verily Allah in His Book has revealed: 'O people, fear your Lord, ' etc." (iv)}}
\hadithdefcmd{muslim}{2354}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ مُوسَى بْنِ عَبْدِ اللَّهِ بْنِ، يَزِيدَ وَأَبِي الضُّحَى عَنْ عَبْدِ الرَّحْمَنِ بْنِ هِلاَلٍ الْعَبْسِيِّ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ جَاءَ نَاسٌ مِنَ الأَعْرَابِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَيْهِمُ الصُّوفُ فَرَأَى سُوءَ حَالِهِمْ ‏.‏ قَدْ أَصَابَتْهُمْ حَاجَةٌ ‏.‏ فَذَكَرَ بِمَعْنَى حَدِيثِهِمْ ‏.‏\hadithno{2354}\hadithtrans{Jarir b. 'Abdullah reported:People came to to the Messenger of Allah (ﷺ) and they ware dressed in woollen clothes. He (the Holy Prophet) saw their dismal state, as they were suffering from want and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{2355}{حَدَّثَنِي يَحْيَى بْنُ مَعِينٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنِيهِ بِشْرُ بْنُ خَالِدٍ، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا مُحَمَّدٌ، - يَعْنِي ابْنَ جَعْفَرٍ - عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، عَنْ أَبِي وَائِلٍ، عَنْ أَبِي مَسْعُودٍ، قَالَ أُمِرْنَا بِالصَّدَقَةِ ‏.‏ قَالَ كُنَّا نُحَامِلُ - قَالَ - فَتَصَدَّقَ أَبُو عَقِيلٍ بِنِصْفِ صَاعٍ - قَالَ - وَجَاءَ إِنْسَانٌ بِشَىْءٍ أَكْثَرَ مِنْهُ فَقَالَ الْمُنَافِقُونَ إِنَّ اللَّهَ لَغَنِيٌّ عَنْ صَدَقَةِ هَذَا وَمَا فَعَلَ هَذَا الآخَرُ إِلاَّ رِيَاءً فَنَزَلَتْ ‏\{‏ الَّذِينَ يَلْمِزُونَ الْمُطَّوِّعِينَ مِنَ الْمُؤْمِنِينَ فِي الصَّدَقَاتِ وَالَّذِينَ لاَ يَجِدُونَ إِلاَّ جُهْدَهُمْ‏\}‏ وَلَمْ يَلْفِظْ بِشْرٌ بِالْمُطَّوِّعِينَ ‏.‏\hadithno{2355}\hadithtrans{Abu Mas'ud reported:We were commanded to give charity (despite the fact.) that we were coolies. Abu 'Aqil donated half a sa'. And there came another man with more than this. The hypocrites said: Verily Allah does not stand in need of the charity of this, and the second one has done nothing but only made a show (of his charity). Then this verse was revealed." Those who scoff at the voluntary givers of charity among the believers as well as those who cannot find anything (to give) but with their hard labour" (ix. 80). And Bishr did not utter the word Muttawwi'in}}
\hadithdefcmd{muslim}{2356}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنِي سَعِيدُ بْنُ الرَّبِيعِ، ح وَحَدَّثَنِيهِ إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو دَاوُدَ، كِلاَهُمَا عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِ سَعِيدِ بْنِ الرَّبِيعِ قَالَ كُنَّا نُحَامِلُ عَلَى ظُهُورِنَا ‏.‏\hadithno{2356}\hadithtrans{This hadith has been narrated by Shu'ba with the same chain of transmitters and in the hadith transmitted by Sa'id b. al Rabi (the words are):" We used to carry loads on our backs}}
\hadithdefcmd{muslim}{2357}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ ‏ "‏ أَلاَ رَجُلٌ يَمْنَحُ أَهْلَ بَيْتٍ نَاقَةً تَغْدُو بِعُسٍّ وَتَرُوحُ بِعُسٍّ إِنَّ أَجْرَهَا لَعَظِيمٌ ‏"‏ ‏.‏\hadithno{2357}\hadithtrans{It is narrated on the authority of Abu Huraira (that the Messenger of Allah) said:Of course the person who gives to the family a she-camel as a gift, which gives milk morning and evening equal to a large bowl, its reward (the reward of the gift) is great}}
\hadithdefcmd{muslim}{2358}{حَدَّثَنِي مُحَمَّدُ بْنُ أَحْمَدَ بْنِ أَبِي خَلَفٍ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ عَدِيٍّ، أَخْبَرَنَا عُبَيْدُ اللَّهِ، بْنُ عَمْرٍو عَنْ زَيْدٍ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ نَهَى فَذَكَرَ خِصَالاً وَقَالَ ‏ "‏ مَنْ مَنَحَ مَنِيحَةً غَدَتْ بِصَدَقَةٍ وَرَاحَتْ بِصَدَقَةٍ صَبُوحِهَا وَغَبُوقِهَا ‏"‏ ‏.‏\hadithno{2358}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) forbade (to do certain things) and then he made a mention of certain habits and said:He who gives a she-camel as a gift, for him is the reward (of the gift) both morning and evening - a reward for drinking milk in the morning and a reward for drinking milk in the evening}}
\hadithdefcmd{muslim}{2359}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ عَمْرٌو وَحَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ قَالَ وَقَالَ ابْنُ جُرَيْجٍ عَنِ الْحَسَنِ بْنِ مُسْلِمٍ عَنْ طَاوُسٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الْمُنْفِقِ وَالْمُتَصَدِّقِ كَمَثَلِ رَجُلٍ عَلَيْهِ جُبَّتَانِ أَوْ جُنَّتَانِ مِنْ لَدُنْ ثُدِيِّهِمَا إِلَى تَرَاقِيهِمَا فَإِذَا أَرَادَ الْمُنْفِقُ - وَقَالَ الآخَرُ فَإِذَا أَرَادَ الْمُتَصَدِّقُ - أَنْ يَتَصَدَّقَ سَبَغَتْ عَلَيْهِ أَوْ مَرَّتْ وَإِذَا أَرَادَ الْبَخِيلُ أَنْ يُنْفِقَ قَلَصَتْ عَلَيْهِ وَأَخَذَتْ كُلُّ حَلْقَةٍ مَوْضِعَهَا حَتَّى تُجِنَّ بَنَانَهُ وَتَعْفُوَ أَثَرَهُ ‏"‏ ‏.‏ قَالَ فَقَالَ أَبُو هُرَيْرَةَ فَقَالَ يُوَسِّعُهَا فَلاَ تَتَّسِعُ ‏.‏\hadithno{2359}\hadithtrans{Abu Haraira reported that the likeness of one who spends or one who gives charity is that of a person who has two cloaks or two coats-of-mail over him right from the breast to the collar bones. And when the spender (and the other narrator said, when the giver of charity) makes up his mind to give charity, it (coat-mail) becomes expanded for him. But when a miserly person intends to spend, it contracts and every ring grips the place where it is. For the giver of charity, this coat-of. mail expands to cover his whole body and obliterates even his footprints. Abu Huraira said:(The miserly man) tries to expand it (the coat-of-mail) but it does not expand}}
\hadithdefcmd{muslim}{2360}{حَدَّثَنِي سُلَيْمَانُ بْنُ عُبَيْدِ اللَّهِ أَبُو أَيُّوبَ الْغَيْلاَنِيُّ، حَدَّثَنَا أَبُو عَامِرٍ، - يَعْنِي الْعَقَدِيَّ - حَدَّثَنَا إِبْرَاهِيمُ بْنُ نَافِعٍ، عَنِ الْحَسَنِ بْنِ مُسْلِمٍ، عَنْ طَاوُسٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ ضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلَ الْبَخِيلِ وَالْمُتَصَدِّقِ كَمَثَلِ رَجُلَيْنِ عَلَيْهِمَا جُنَّتَانِ مِنْ حَدِيدٍ قَدِ اضْطُرَّتْ أَيْدِيهِمَا إِلَى ثُدَيِّهِمَا وَتَرَاقِيهِمَا فَجَعَلَ الْمُتَصَدِّقُ كُلَّمَا تَصَدَّقَ بِصَدَقَةٍ انْبَسَطَتْ عَنْهُ حَتَّى تُغَشِّيَ أَنَامِلَهُ وَتَعْفُوَ أَثَرَهُ وَجَعَلَ الْبَخِيلُ كُلَّمَا هَمَّ بِصَدَقَةٍ قَلَصَتْ وَأَخَذَتْ كُلُّ حَلْقَةٍ مَكَانَهَا ‏"‏ ‏.‏ قَالَ فَأَنَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ بِإِصْبَعِهِ فِي جَيْبِهِ فَلَوْ رَأَيْتَهُ يُوَسِّعُهَا وَلاَ تَوَسَّعُ ‏.‏\hadithno{2360}\hadithtrans{Abu Haraira reported that the Messenger of Allah (ﷺ) gave similitudes of a miserly man and the giver of charity as two persons who have two coats-of-mail over them with their hands pressed closely to their breasts and their collar bones. Whenever the giver of charity gives charity it (the coat-of mail) expands so much as to cover his finger tips and obliterate his foot prints. And whenever the miserly person intends to give charity (the coat-of-mail) contracts and every ring grips the place where it is. He (Abu Huraira) said:I saw the Messenger of Allah (ﷺ) saying with fingers in the opening of his shirt:" If you had seen him trying to expand it, it will not expand}}
\hadithdefcmd{muslim}{2361}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَحْمَدُ بْنُ إِسْحَاقَ الْحَضْرَمِيُّ، عَنْ وُهَيْبٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَثَلُ الْبَخِيلِ وَالْمُتَصَدِّقِ مَثَلُ رَجُلَيْنِ عَلَيْهِمَا جُنَّتَانِ مِنْ حَدِيدٍ إِذَا هَمَّ الْمُتَصَدِّقُ بِصَدَقَةٍ اتَّسَعَتْ عَلَيْهِ حَتَّى تُعَفِّيَ أَثَرَهُ وَإِذَا هَمَّ الْبَخِيلُ بِصَدَقَةٍ تَقَلَّصَتْ عَلَيْهِ وَانْضَمَّتْ يَدَاهُ إِلَى تَرَاقِيهِ وَانْقَبَضَتْ كُلُّ حَلْقَةٍ إِلَى صَاحِبَتِهَا ‏"‏ ‏.‏ قَالَ فَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ فَيَجْهَدُ أَنْ يُوَسِّعَهَا فَلاَ يَسْتَطِيعُ ‏"‏ ‏.‏\hadithno{2361}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:. The similitude of a miserly man and the giver of charity is that of two persons with coats of mail over them; when the giver of charity intends to give charity, it expands over him (to much so) that the footprints are also obliterated. And when the miserly man intends to give charity, it contracts over him, and his hands are tied up to his collar bone, and every ring is fixed up to another. He (the narrator) said: I heard the Messenger of Allah (ﷺ) as saying: He would try to expand it. but he would not be able to do so}}
\hadithdefcmd{muslim}{2362}{حَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنِي حَفْصُ بْنُ مَيْسَرَةَ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ أَبِي، الزِّنَادِ عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ رَجُلٌ لأَتَصَدَّقَنَّ اللَّيْلَةَ بِصَدَقَةٍ فَخَرَجَ بِصَدَقَتِهِ فَوَضَعَهَا فِي يَدِ زَانِيَةٍ فَأَصْبَحُوا يَتَحَدَّثُونَ تُصُدِّقَ اللَّيْلَةَ عَلَى زَانِيَةٍ ‏.‏ قَالَ اللَّهُمَّ لَكَ الْحَمْدُ عَلَى زَانِيَةٍ لأَتَصَدَّقَنَّ بِصَدَقَةٍ ‏.‏ فَخَرَجَ بِصَدَقَتِهِ فَوَضَعَهَا فِي يَدِ غَنِيٍّ فَأَصْبَحُوا يَتَحَدَّثُونَ تُصُدِّقَ عَلَى غَنِيٍّ ‏.‏ قَالَ اللَّهُمَّ لَكَ الْحَمْدُ عَلَى غَنِيٍّ لأَتَصَدَّقَنَّ بِصَدَقَةٍ ‏.‏ فَخَرَجَ بِصَدَقَتِهِ فَوَضَعَهَا فِي يَدِ سَارِقٍ فَأَصْبَحُوا يَتَحَدَّثُونَ تُصُدِّقَ عَلَى سَارِقٍ ‏.‏ فَقَالَ اللَّهُمَّ لَكَ الْحَمْدُ عَلَى زَانِيَةٍ وَعَلَى غَنِيٍّ وَعَلَى سَارِقٍ ‏.‏ فَأُتِيَ فَقِيلَ لَهُ أَمَّا صَدَقَتُكَ فَقَدْ قُبِلَتْ أَمَّا الزَّانِيَةُ فَلَعَلَّهَا تَسْتَعِفُّ بِهَا عَنْ زِنَاهَا وَلَعَلَّ الْغَنِيَّ يَعْتَبِرُ فَيُنْفِقُ مِمَّا أَعْطَاهُ اللَّهُ وَلَعَلَّ السَّارِقَ يَسْتَعِفُّ بِهَا عَنْ سَرِقَتِهِ ‏"‏ ‏.‏\hadithno{2362}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:A man expressed his intention to give charity, so he came out with charity and placed it in the hand of an adulteress. In the morning, the people were talking and saying: charity was given to an adulteress last night. He (the giver of Sadaqa) said: 0 Allah, to Thee be the praise-to an adulteress. He then again expressed his intention to give charity; so he went out with the charity and placed it in the hand of a rich person. In the morning the people were talking and saying: Charity was given to a rich person. He (the giver of charity) said: 0 Allah, to Thee be the praise-to a well-to-do person. He then expressed his intention to give charity, so he went out with charity and placed it in the hand of a thief. In the morning, the people were talking and saying: Charity was given to a thief. So (one of the persons) said: 0 Allah, to Thee be the praise (what a misfortune it is that charity has been given to) the adulteress, to a rich person. to a thief! There came (the angel to him) and he was told: Your charity has been accepted. As for the adulteress (the charity might become the means) whereby she might restrain herself from fornication. The rich man might perhaps learn a lesson and spend from what Allah has given him, and the thief might thereby refrain from committing theft}}
\hadithdefcmd{muslim}{2363}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو عَامِرٍ الأَشْعَرِيُّ وَابْنُ نُمَيْرٍ وَأَبُو كُرَيْبٍ كُلُّهُمْ عَنْ أَبِي أُسَامَةَ، - قَالَ أَبُو عَامِرٍ حَدَّثَنَا أَبُو أُسَامَةَ، - حَدَّثَنَا بُرَيْدٌ، عَنْ جَدِّهِ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى�� عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْخَازِنَ الْمُسْلِمَ الأَمِينَ الَّذِي يُنْفِذُ - وَرُبَّمَا قَالَ يُعْطِي - مَا أُمِرَ بِهِ فَيُعْطِيهِ كَامِلاً مُوَفَّرًا طَيِّبَةً بِهِ نَفْسُهُ فَيَدْفَعُهُ إِلَى الَّذِي أُمِرَ لَهُ بِهِ - أَحَدُ الْمُتَصَدِّقَيْنِ ‏"‏ ‏.‏\hadithno{2363}\hadithtrans{Abu Musa reported Allah's Apostle (ﷺ) as saying:The honest Muslim trustee who spends (sometimes he said" who gives" ) what he is commanded to do and he gives that in full with his heart overflowing with cheerfulness and he gives it to one to whom he is ordered, he is one of the givers of charity}}
\hadithdefcmd{muslim}{2364}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنْ جَرِيرٍ، - قَالَ يَحْيَى - أَخْبَرَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَنْفَقَتِ الْمَرْأَةُ مِنْ طَعَامِ بَيْتِهَا غَيْرَ مُفْسِدَةٍ كَانَ لَهَا أَجْرُهَا بِمَا أَنْفَقَتْ وَلِزَوْجِهَا أَجْرُهُ بِمَا كَسَبَ وَلِلْخَازِنِ مِثْلُ ذَلِكَ لاَ يَنْقُصُ بَعْضُهُمْ أَجْرَ بَعْضٍ شَيْئًا ‏"‏ ‏.‏\hadithno{2364}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) as saying:When a woman gives in charity some of the food in her house, without causing any damage, there is reward for her for whatever she has given, and a reward for her husband for what he earned. The same applies to the trustee. In no respect does the one diminish the reward of the other}}
\hadithdefcmd{muslim}{2365}{وَحَدَّثَنَاهُ ابْنُ أَبِي عُمَرَ، حَدَّثَنَا فُضَيْلُ بْنُ عِيَاضٍ، عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ مِنْ طَعَامِ زَوْجِهَا ‏"‏ ‏.‏\hadithno{2365}\hadithtrans{This hadith has been narrated by Mansur with the same chain of transmitters (with this alteration of words):" from the food of her husband}}
\hadithdefcmd{muslim}{2366}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَنْفَقَتِ الْمَرْأَةُ مِنْ بَيْتِ زَوْجِهَا غَيْرَ مُفْسِدَةٍ كَانَ لَهَا أَجْرُهَا وَلَهُ مِثْلُهُ بِمَا اكْتَسَبَ وَلَهَا بِمَا أَنْفَقَتْ وَلِلْخَازِنِ مِثْلُ ذَلِكَ مِنْ غَيْرِ أَنْ يَنْتَقِصَ مِنْ أُجُورِهِمْ شَيْئًا ‏"‏ ‏.‏\hadithno{2366}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) as saying:When a woman spends (something as Sadaqa) out of the household of her husband without causing any damage, there is a reward for her and for him too like it for whatever he earned, and for her (for the wife) because of her spending (for the sake of Allah), and for the trustee also (there is a reward like it), without any reduction from their rewards}}
\hadithdefcmd{muslim}{2367}{وَحَدَّثَنَاهُ ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ نَحْوَهُ\hadithno{2367}\hadithtrans{This hadith has been narrated by A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{2368}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ وَزُهَيْرُ بْنُ حَرْبٍ جَمِيعًا عَنْ حَفْصِ، بْنِ غِيَاثٍ - قَالَ ابْنُ نُمَيْرٍ حَدَّثَنَا حَفْصٌ، - عَنْ مُحَمَّدِ بْنِ زَيْدٍ، عَنْ عُمَيْرٍ، مَوْلَى آبِي اللَّحْمِ قَالَ كُنْتُ مَمْلُوكًا فَسَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَأَتَصَدَّقُ مِنْ مَالِ مَوَالِيَّ بِشَىْءٍ قَالَ ‏ "‏ نَعَمْ وَالأَجْرُ بَيْنَكُمَا نِصْفَانِ ‏"‏ ‏.‏\hadithno{2368}\hadithtrans{Umair, the freed slave of Abi'l-Lahm reported:I was the slave (of Abi'l-Lahm). I asked the Messenger of Allah (ﷺ) if I could give some charity out of my master's wealth. He said: Yes, and the reward is half and half between you two}}
\hadithdefcmd{muslim}{2369}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَاتِمٌ، - يَعْنِي ابْنَ إِسْمَاعِيلَ - عَنْ يَزِيدَ، - يَعْنِي ابْنَ أَبِي عُبَيْدٍ - قَالَ سَمِعْتُ عُمَيْرًا، مَوْلَى آبِي اللَّحْمِ قَالَ أَمَرَنِي مَوْلاَىَ أَنْ أُقَدِّدَ، لَحْمًا فَجَاءَنِي مِسْكِينٌ فَأَطْعَمْتُهُ مِنْهُ فَعَلِمَ بِذَلِكَ مَوْلاَىَ فَضَرَبَنِي فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرْتُ ذَلِكَ لَهُ فَدَعَاهُ ‏.‏ فَقَالَ ‏"‏ لِمَ ضَرَبْتَهُ ‏"‏ ‏.‏ فَقَالَ يُعْطِي طَعَامِي بِغَيْرِ أَنْ آمُرَهُ ‏.‏ فَقَالَ ‏"‏ الأَجْرُ بَيْنَكُمَا ‏"‏ ‏.‏\hadithno{2369}\hadithtrans{Umair, the freed slave of Abi'l-Lahm, said:My master commanded me to cut some meat in strips; (as I was doing it) a poor man came to me and I gave him some of it to eat. My master came to know of that, and he beat me. I came to the Messenger of Allah (ﷺ) and narrated it to him. He (the Holy Prophet) summoned him and said: Why did you beat him? He (Abi'l-Lahm) said: He gives away my food without being commanded to do so. Upon this he (the Holy Prophet) said: The reward would be shared by you two}}
\hadithdefcmd{muslim}{2370}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ مُحَمَّدٍ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَصُمِ الْمَرْأَةُ وَبَعْلُهَا شَاهِدٌ إِلاَّ بِإِذْنِهِ وَلاَ تَأْذَنْ فِي بَيْتِهِ وَهُوَ شَاهِدٌ إِلاَّ بِإِذْنِهِ وَمَا أَنْفَقَتْ مِنْ كَسْبِهِ مِنْ غَيْرِ أَمْرِهِ فَإِنَّ نِصْفَ أَجْرِهِ لَهُ ‏"‏ ‏.‏\hadithno{2370}\hadithtrans{Hammam b. Munabbih said:These are some of the a hadith of Muhammad. the Messenger of Allah (ﷺ), transmitted to us on the authority of Abu Huraira. So he narrated one hadith out of them (as this): The Messenger of Allah (ﷺ) said: No woman should observe fast when her spouse is present (in the house) but with his permission. And she should not admit any (mahram) in his house, while he (her husband) is present, but with his permission. And whatever she spends from his earnings without his sanction, for him is half the reward}}
\hadithdefcmd{muslim}{2371}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، - وَاللَّفْظُ لأَبِي الطَّاهِرِ - قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَنْفَقَ زَوْجَيْنِ فِي سَبِيلِ اللَّهِ نُودِيَ فِي الْجَنَّةِ يَا عَبْدَ اللَّهِ هَذَا خَيْرٌ ‏.‏ فَمَنْ كَانَ مِنْ أَهْلِ الصَّلاَةِ دُعِيَ مِنْ بَابِ الصَّلاَةِ وَمَنْ كَانَ مِنْ أَهْلِ الْجِهَادِ دُعِيَ مِنْ بَابِ الْجِهَادِ ، وَمَنْ كَانَ مِنْ أَهْلِ الصَّدَقَةِ دُعِيَ مِنْ بَابِ الصَّدَقَةِ ، وَمَنْ كَانَ مِنْ أَهْلِ الصِّيَامِ دُعِيَ مِنْ بَابِ الرَّيَّانِ " ، قَالَ أَبُو بَكْرٍ الصِّدِّيقُ : يَا رَسُولَ اللَّهِ مَا عَلَى أَحَدٍ يُدْعَى مِنْ تِلْكَ الْأَبْوَابِ مِنْ ضَرُورَةٍ ، فَهَلْ يُدْعَى أَحَدٌ مِنْ تِلْكَ الْأَبْوَابِ كُلِّهَا ؟ ، قَالَ رَسُولُ اللَّهِ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ : " نَعَمْ وَأَرْجُو أَنْ تَكُونَ مِنْهُمْ " ، حَدَّثَنِي عَمْرٌو النَّاقِدُ ، وَالْحَسَنُ الْحُلْوَانِيُّ ، وَعَبْدُ بْنُ حُمَيْدٍ ، قَالُوا : حَدَّثَنَا يَعْقُوبُ وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ ، حَدَّثَنَا أَبِي ، عَنْ صَالِحٍ . وحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ ، أَخْبَرَنَا مَعْمَرٌ كِلَاهُمَا ، عَنْ الزُّهْرِيِّ بِإِسْنَادِ يُونُسَ وَمَعْنَى حَدِيثِهِ\hadithno{2371}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:If anyone contributes a pair of anything for the sake of Allah, he would be invited to enter Paradise (with these words): O servant of Allah, it is good (for you). Those who engage in prayer will he invited to enter by the gate of prayer; those who take part in Jihad will be invited to enter by the gate of Jihad; those who give charity will be invited to enter by the gate of charity; and those who observe fast will be invited to enter by the gate ar-Rayyan. Abu Bakr Siddiq said: Messenger of Allah, is it necessary that a person be invited through one of these gates? Will anyone be invited to enter by all those gates? The Messenger of Allah (ﷺ) said: Yes, and I hope you will be one of them}}
\hadithdefcmd{muslim}{2372}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَالْحَسَنُ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالُوا حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَبْدُ، الرَّزَّاقِ أَخْبَرَنَا مَعْمَرٌ، كِلاَهُمَا عَنِ الزُّهْرِيِّ، بِإِسْنَادِ يُونُسَ وَمَعْنَى حَدِيثِهِ ‏.‏\hadithno{2372}\hadithtrans{This hadith has been narrated by Zuhri through another chain of transmitters}}
\hadithdefcmd{muslim}{2373}{وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، حَدَّثَنَا شَيْبَانُ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا شَبَابَةُ، حَدَّثَنِي شَيْبَانُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَنْفَقَ زَوْجَيْنِ فِي سَبِيلِ اللَّهِ دَعَاهُ خَزَنَةُ الْجَنَّةِ كُلُّ خَزَنَةِ بَابٍ أَىْ فُلُ هَلُمَّ ‏"‏ ‏.‏ فَقَالَ أَبُو بَكْرٍ يَا رَسُولَ اللَّهِ ذَلِكَ الَّذِي لاَ تَوَى عَلَيْهِ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي لأَرْجُو أَنْ تَكُونَ مِنْهُمْ ‏"‏ ‏.‏\hadithno{2373}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who spent pairs for the sake of Allah, the guardians of Paradise would call him, (in fact) every guardian of the door (of Paradise would welcome him saying): O, so and so, come on. Upon this Abu Bakr said: Messenger of Allah, (it means) there would be no distress on this person. The Messenger of Allah (ﷺ) said. I hope you would be among them}}
\hadithdefcmd{muslim}{2374}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا مَرْوَانُ، - يَعْنِي الْفَزَارِيَّ - عَنْ يَزِيدَ، - وَهُوَ ابْنُ كَيْسَانَ - عَنْ أَبِي حَازِمٍ الأَشْجَعِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ أَصْبَحَ مِنْكُمُ الْيَوْمَ صَائِمًا ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ رضى الله عنه أَنَا ‏.‏ قَالَ ‏"‏ فَمَنْ تَبِعَ مِنْكُمُ الْيَوْمَ جَنَازَةً ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ رضى الله عنه أَنَا ‏.‏ قَالَ ‏"‏ فَمَنْ أَطْعَمَ مِنْكُمُ الْيَوْمَ مِسْكِينًا ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ رضى الله عنه أَنَا ‏.‏ قَالَ ‏"‏ فَمَنْ عَادَ مِنْكُمُ الْيَوْمَ مَرِيضًا ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ رضى الله عنه أَنَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا اجْتَمَعْنَ فِي امْرِئٍ إِلاَّ دَخَلَ الْجَنَّةَ ‏"‏ ‏.‏\hadithno{2374}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) said:Who fasted among you today? Abu Bakr (Allah be pleased with him) replied: I did. He (the Prophet again) said: Who among you followed a bier today? Abu Bakr (Allah be pleased with him) replied: I did. He (the Prophet again) said: Who among you fed a poor man today? Abu Bakr (Allah he pleased with him) replied: I did. He (again) said: Who among you visited an invalid today? Abu Bakr (Allah be pleased with him) said: I did. Upon this the Messenger of Allah (ﷺ) said: Anyone in whom (these good deeds) are combined will certainly enter paradise}}
\hadithdefcmd{muslim}{2375}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصٌ، - يَعْنِي ابْنَ غِيَاثٍ - عَنْ هِشَامٍ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، - رضى الله عنها - قَالَتْ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنْفِقِي - أَوِ انْضَحِي أَوِ انْفَحِي - وَلاَ تُحْصِي فَيُحْصِيَ اللَّهُ عَلَيْكِ ‏"‏ ‏.‏\hadithno{2375}\hadithtrans{Asma', daughter of Abu Bakr (Allah be pleased with him), reported:The Messenger of Allah (ﷺ) said to me: Spend, and do not calculate, or otherwise Allah would also calculate in your case}}
\hadithdefcmd{muslim}{2376}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنْ أَبِي، مُعَاوِيَةَ - قَالَ زُهَيْرٌ حَدَّثَنَا مُحَمَّدُ بْنُ خَازِمٍ، - حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ عَبَّادِ بْنِ حَمْزَةَ، وَعَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ انْفَحِي - أَوِ انْضَحِي أَوْ أَنْفِقِي - وَلاَ تُحْصِي فَيُحْصِيَ اللَّهُ عَلَيْكِ وَلاَ تُوعِي فَيُوعِيَ اللَّهُ عَلَيْكِ ‏"‏ ‏.‏\hadithno{2376}\hadithtrans{Asma' reported Allah's Messenger (way peace be upon him) as saying (to her):Spend and do not calculate, (for) Allah would calculate in your case; and do not hoard, otherwise Allah would be withholding from you}}
\hadithdefcmd{muslim}{2377}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا هِشَامٌ، عَنْ عَبَّادِ بْنِ حَمْزَةَ، عَنْ أَسْمَاءَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لَهَا نَحْوَ حَدِيثِهِمْ ‏.‏\hadithno{2377}\hadithtrans{This hadith has been narrated on the authority of Asma' through another chain of transmitters}}
\hadithdefcmd{muslim}{2378}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي ابْنُ أَبِي مُلَيْكَةَ، أَنَّ عَبَّادَ بْنَ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، أَخْبَرَهُ عَنْ أَسْمَاءَ، بِنْتِ أَبِي بَكْرٍ أَنَّهَا جَاءَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ يَا نَبِيَّ اللَّهِ لَيْسَ لِي شَىْءٌ إِلاَّ مَا أَدْخَلَ عَلَىَّ الزُّبَيْرُ فَهَلْ عَلَىَّ جُنَاحٌ أَنْ أَرْضَخَ مِمَّا يُدْخِلُ عَلَىَّ فَقَالَ ‏ "‏ ارْضَخِي مَا اسْتَطَعْتِ وَلاَ تُوعِي فَيُوعِيَ اللَّهُ عَلَيْكِ ‏"‏ ‏.‏\hadithno{2378}\hadithtrans{Asma', daughter of Abu Bakr, reported that abe came to the Messenger of Allah (may peace he upon him) and said:Apostle of Allah, I have nothing with me, but only, that which is given to me by Zubair (for household expenses). Is there any sin for me if I spend out of that which is given to me (by Zabair)? Upon this he (the Holy Prophet) said: Spend according to your means; and do not hoard, for Allah will withhold from you}}
\hadithdefcmd{muslim}{2379}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، جَمِيعًا عَنْ يَحْيَى الْقَطَّانِ، - قَالَ زُهَيْرٌ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، - عَنْ عُبَيْدِ اللَّهِ، أَخْبَرَنِي خُبَيْبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ سَبْعَةٌ يُظِلُّهُمُ اللَّهُ فِي ظِلِّهِ يَوْمَ لاَ ظِلَّ إِلاَّ ظِلُّهُ الإِمَامُ الْعَادِلُ وَشَابٌّ نَشَأَ بِعِبَادَةِ اللَّهِ وَرَجُلٌ قَلْبُهُ مُعَلَّقٌ فِي الْمَسَاجِدِ وَرَجُلاَنِ تَحَابَّا فِي اللَّهِ اجْتَمَعَا عَلَيْهِ وَتَفَرَّقَا عَلَيْهِ وَرَجُلٌ دَعَتْهُ امْرَأَةٌ ذَاتُ مَنْصِبٍ وَجَمَالٍ فَقَالَ إِنِّي أَخَافُ اللَّهَ ‏.‏ وَرَجُلٌ تَصَدَّقَ بِصَدَقَةٍ فَأَخْفَاهَا حَتَّى لاَ تَعْلَمَ يَمِينُهُ مَا تُنْفِقُ شِمَالُهُ وَرَجُلٌ ذَكَرَ اللَّهَ خَالِيًا فَفَاضَتْ عَيْنَاهُ ‏"‏ ‏.‏\hadithno{2379}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) had said:Seven are (the persons) whom Allah would give protection with His Shade on the Day when there would be no shade but that of Him (i. e. on the Day of Judgment, and they are): a just ruler, a youth who grew up with the worship of Allah; a person whose heart is attached to the mosques; two persons who love and meet each other and depart from each other for the sake of Allah; a man whom a beautiful woman of high rank seduces (for illicit relation), but he (rejects this offer by saying):" I fear Allah" ; a person who gives charity and conceals it (to such an extent) that the right hand does not know what the left has given: and a person who remembered Allah in privacy and his eyes shed tears}}
\hadithdefcmd{muslim}{2380}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، - أَوْ عَنْ أَبِي هُرَيْرَةَ، - أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ عُبَيْدِ اللَّهِ ‏.‏ وَقَالَ ‏ "‏ وَرَجُلٌ مُعَلَّقٌ بِالْمَسْجِدِ إِذَا خَرَجَ مِنْهُ حَتَّى يَعُودَ إِلَيْهِ ‏"‏ ‏.‏\hadithno{2380}\hadithtrans{This hadith has been narrated, on the authority, of Abu Huraira (with this change of words)." A person whose heart is attached to the mosque when he goes out of it till he returns to it}}
\hadithdefcmd{muslim}{2382}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ أَىُّ الصَّدَقَةِ أَعْظَمُ فَقَالَ ‏ "‏ أَنْ تَصَدَّقَ وَأَنْتَ صَحِيحٌ شَحِيحٌ تَخْشَى الْفَقْرَ وَتَأْمُلُ الْغِنَى وَلاَ تُمْهِلْ حَتَّى إِذَا بَلَغَتِ الْحُلْقُومَ قُلْتَ لِفُلاَنٍ كَذَا وَلِفُلاَنٍ كَذَا أَلاَ وَقَدْ كَانَ لِفُلاَنٍ ‏"‏ ‏.‏\hadithno{2382}\hadithtrans{Abu Huraira reported that there came a person to the Messenger of Allah (ﷺ) and said:Messenger of Allah, which charity is the best? Upon this he said: That you should give charity (in a state when you are) healthy and close-fisted, one haunted by the fear of poverty, hoping to become rich (charity in such a state of health and mind is the best). And you must not defer (charity to such a length) that you are about to die and would he saying: This is for so and so, and this is for so and so. Lo, it has already come into (the possession of so and so)}}
\hadithdefcmd{muslim}{2383}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَىُّ الصَّدَقَةِ أَعْظَمُ أَجْرًا فَقَالَ ‏ "‏ أَمَا وَأَبِيكَ لَتُنَبَّأَنَّهُ أَنْ تَصَدَّقَ وَأَنْتَ صَحِيحٌ شَحِيحٌ تَخْشَى الْفَقْرَ وَتَأْمُلُ الْبَقَاءَ وَلاَ تُمْهِلْ حَتَّى إِذَا بَلَغَتِ الْحُلْقُومَ قُلْتَ لِفُلاَنٍ كَذَا وَلِفُلاَنٍ كَذَا وَقَدْ كَانَ لِفُلاَنٍ ‏"‏ ‏.‏\hadithno{2383}\hadithtrans{Abu Huraira reported that a person came to the Messenger of Allah (ﷺ) and said:Messenger of Allah, which charity is the greatest in reward? (The Prophet said): By your father, beware, you should give charity (in a state when you are) healthy and close-fisted, haunted by the fear of poverty, and still hoping to live (as rich). And you must not defer charity (to the time) when you are about to die, and would then say:" This is for so and so, and this for so and so." It has already become the possession of so and so}}
\hadithdefcmd{muslim}{2384}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا عُمَارَةُ بْنُ الْقَعْقَاعِ، بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِ جَرِيرٍ غَيْرَ أَنَّهُ قَالَ أَىُّ الصَّدَقَةِ أَفْضَلُ ‏.‏\hadithno{2384}\hadithtrans{This hadith has been narrated with the same chain of transmitters except with this change (of words):" Which charity is most excellent?}}
\hadithdefcmd{muslim}{2385}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنْ نَافِعٍ، عَنْ عَبْدِ، اللَّهِ بْنِ عُمَرَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ وَهُوَ عَلَى الْمِنْبَرِ وَهُوَ يَذْكُرُ الصَّدَقَةَ وَالتَّعَفُّفَ عَنِ الْمَسْأَلَةِ ‏ "‏ الْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى وَالْيَدُ الْعُلْيَا الْمُنْفِقَةُ وَالسُّفْلَى السَّائِلَةُ ‏"‏ ‏.‏\hadithno{2385}\hadithtrans{Abdullah b. Umar reported that as Allah's Messenger (ﷺ) was sitting on the pulpit and talking about Sadaqa and abstention from begging, he said:The upper hand is better than the lower one, the upper being the one which bestows and the lower one which begs}}
\hadithdefcmd{muslim}{2386}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمُحَمَّدُ بْنُ حَاتِمٍ، وَأَحْمَدُ بْنُ عَبْدَةَ، جَمِيعًا عَنْ يَحْيَى الْقَطَّانِ، - قَالَ ابْنُ بَشَّارٍ حَدَّثَنَا يَحْيَى، - حَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، قَالَ سَمِعْتُ مُوسَى بْنَ طَلْحَةَ، يُحَدِّثُ أَنَّ حَكِيمَ بْنَ حِزَامٍ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَفْضَلُ الصَّدَقَةِ - أَوْ خَيْرُ الصَّدَقَةِ - عَنْ ظَهْرِ غِنًى وَالْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى وَابْدَأْ بِمَنْ تَعُولُ ‏"‏‏.‏\hadithno{2386}\hadithtrans{Hakim b. Hizam reported Allah's Messenger (ﷺ) having said this:The most excellent Sadaqa or the best of Sadaqa is that after giving which the (giver) remains rich and the upper hand is better than the lower hand, and begin from the members of your household}}
\hadithdefcmd{muslim}{2387}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، وَسَعِيدٍ، عَنْ حَكِيمِ بْنِ حِزَامٍ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم فَأَعْطَانِي ثُمَّ سَأَلْتُهُ فَأَعْطَانِي ثُمَّ سَأَلْتُهُ فَأَعْطَانِي ثُمَّ قَالَ ‏ "‏ إِنَّ هَذَا الْمَالَ خَضِرَةٌ حُلْوَةٌ فَمَنْ أَخَذَهُ بِطِيبِ نَفْسٍ بُورِكَ لَهُ فِيهِ وَمَنْ أَخَذَهُ بِإِشْرَافِ نَفْسٍ لَمْ يُبَارَكْ لَهُ فِيهِ وَكَانَ كَالَّذِي يَأْكُلُ وَلاَ يَشْبَعُ وَالْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى ‏"‏ ‏.‏\hadithno{2387}\hadithtrans{Hakim b. Hizam reported:I begged the Messenger of Allah (ﷺ), and he gave me. I again begged, he again gave me. I again begged, he again gave me, and then said: This property is green and sweet; he who receives it with a cheerful heart is blessed in it, and he who receives it with an avaricious mind would not be blessed in it, he being like one who eats without being satished, and the upper hand is better thad the lower hand}}
\hadithdefcmd{muslim}{2388}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَزُهَيْرُ بْنُ حَرْبٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالُوا حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنَا شَدَّادٌ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَا ابْنَ آدَمَ إِنَّكَ أَنْ تَبْذُلَ الْفَضْلَ خَيْرٌ لَكَ وَأَنْ تُمْسِكَهُ شَرٌّ لَكَ وَلاَ تُلاَمُ عَلَى كَفَافٍ وَابْدَأْ بِمَنْ تَعُولُ وَالْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى ‏"‏\hadithno{2388}\hadithtrans{Abu Umama reported Allah's Messenger (ﷺ) as saying:O son of Adam, it is better for you if you spend your surplus (wealth), but if you withhold it, it is evil for you. There is (however) no reproach for you (if you withhold means necessary) for a living. And begin (charity) with your dependents; and the upper hand is better than the lower hand}}
\hadithdefcmd{muslim}{2389}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، أَخْبَرَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، حَدَّثَنِي رَبِيعَةُ بْنُ يَزِيدَ الدِّمَشْقِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرٍ الْيَحْصَبِيِّ، قَالَ سَمِعْتُ مُعَاوِيَةَ، يَقُولُ إِيَّاكُمْ وَأَحَادِيثَ إِلاَّ حَدِيثًا كَانَ فِي عَهْدِ عُمَرَ فَإِنَّ عُمَرَ كَانَ يُخِيفُ النَّاسَ فِي اللَّهِ عَزَّ وَجَلَّ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يَقُولُ ‏"‏ مَنْ يُرِدِ اللَّهُ بِهِ خَيْرًا يُفَقِّهْهُ فِي الدِّينِ ‏"‏ ‏.‏ وَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّمَا أَنَا خَازِنٌ فَمَنْ أَعْطَيْتُهُ عَنْ طِيبِ نَفْسٍ فَيُبَارَكُ لَهُ فِيهِ وَمَنْ أَعْطَيْتُهُ عَنْ مَسْأَلَةٍ وَشَرَهٍ كَانَ كَالَّذِي يَأْكُلُ وَلاَ يَشْبَعُ ‏"‏ ‏.‏\hadithno{2389}\hadithtrans{Mu'awiya said:Be cautious about ahadith except those which were current during the reign of Umar, for he exhorted people to fear Allah, the Exalted and mMajestic. I heard the Messenger of Allah (ﷺ) as saying: He upon whom Allah intends to bestow goodness, He confers upon him an insight in religion; and I heard the Messenger of Allah (ﷺ) as saying: I am the treasurer. To one whom I give out of (my own) sweet will, he would be blessed in that, but he whom I give (yielding to) his constant begging and for his covetousness is like one who would eat, but would not be satisfied}}
\hadithdefcmd{muslim}{2390}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ وَهْبِ بْنِ مُنَبِّهٍ، عَنْ أَخِيهِ، هَمَّامٍ عَنْ مُعَاوِيَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُلْحِفُوا فِي الْمَسْأَلَةِ فَوَاللَّهِ لاَ يَسْأَلُنِي أَحَدٌ مِنْكُمْ شَيْئًا فَتُخْرِجَ لَهُ مَسْأَلَتُهُ مِنِّي شَيْئًا وَأَنَا لَهُ كَارِهٌ فَيُبَارَكَ لَهُ فِيمَا أَعْطَيْتُهُ ‏"‏ ‏.‏\hadithno{2390}\hadithtrans{Mu'awiya reported Allah's Messenger (ﷺ) as saying:Do not press in a matter, for I swear by Allah, none of you who asks me for anything and manages to get his request while I disdain it, will he be blessed in that which I give him}}
\hadithdefcmd{muslim}{2391}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرِو بْنِ دِينَارٍ، حَدَّثَنِي وَهْبُ بْنُ، مُنَبِّهٍ - وَدَخَلْتُ عَلَيْهِ فِي دَارِهِ بِصَنْعَاءَ فَأَطْعَمَنِي مِنْ جَوْزَةٍ فِي دَارِهِ - عَنْ أَخِيهِ قَالَ سَمِعْتُ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏.‏ فَذَكَرَ مِثْلَهُ ‏.‏\hadithno{2391}\hadithtrans{Amr b. Dinar reported from Wahb b. Munabbih:I went to his house in San'a' and he offered me nuts grown in his house to eat. And his brother said: I heard Mu'awiya b. Abu Sufyan saying that he had heard the Messenger of Allah (ﷺ) as saying, and then he made a mention (of a hadith) like one mentioned above}}
\hadithdefcmd{muslim}{2392}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، قَالَ سَمِعْتُ مُعَاوِيَةَ بْنَ أَبِي سُفْيَانَ، وَهُوَ يَخْطُبُ يَقُولُ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ يُرِدِ اللَّهُ بِهِ خَيْرًا يُفَقِّهْهُ فِي الدِّينِ وَإِنَّمَا أَنَا قَاسِمٌ وَيُعْطِي اللَّهُ ‏"‏ ‏.‏\hadithno{2392}\hadithtrans{Abd al-Rahman b. Auf reported:I heard Mu'awiya b. Abu Sufyan saying in an address that he had heard the Messenger of Allah (ﷺ) as saying: He to whom Allah intends to do good, He gives him insight into religion. And I am only the distributor while Allah is the Bestower}}
\hadithdefcmd{muslim}{2393}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَيْسَ الْمِسْكِينُ بِهَذَا الطَّوَّافِ الَّذِي يَطُوفُ عَلَى النَّاسِ فَتَرُدُّهُ اللُّقْمَةُ وَاللُّقْمَتَانِ وَالتَّمْرَةُ وَالتَّمْرَتَانِ ‏"‏ ‏.‏ قَالُوا فَمَا الْمِسْكِينُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ الَّذِي لاَ يَجِدُ غِنًى يُغْنِيهِ وَلاَ يُفْطَنُ لَهُ فَيُتَصَدَّقَ عَلَيْهِ وَلاَ يَسْأَلُ النَّاسَ شَيْئًا ‏"‏ ‏.‏\hadithno{2393}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:The poor man (miskin) is not the one who goes round to the people and is dismissed with one or two morsels. and one or two dates. They (the Prophet's Companions) said: Messenger of Allah, then who is miskin? He said: He who does not get enough to satisfy him, and he is not considered so (as to elicit the attention of the benevolent people), so that charity way be given to him. and he does not beg anything from people}}
\hadithdefcmd{muslim}{2394}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - أَخْبَرَنِي شَرِيكٌ، عَنْ عَطَاءِ بْنِ يَسَارٍ، مَوْلَى مَيْمُونَةَ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ الْمِسْكِينُ بِالَّذِي تَرُدُّهُ التَّمْرَةُ وَالتَّمْرَتَانِ وَلاَ اللُّقْمَةُ وَاللُّقْمَتَانِ إِنَّمَا الْمِسْكِينُ الْمُتَعَفِّفُ اقْرَءُوا إِنْ شِئْتُمْ ‏\{‏ لاَ يَسْأَلُونَ النَّاسَ إِلْحَافًا‏\}‏ ‏"‏ ‏.‏\hadithno{2394}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Miskin is not he who is dismissed with one or two dates, and with one morsel or two morsels. (In fact) miskin is he who abstains (from begging). Read if you so desire (the verse):" They beg not of men importunately)" (ii)}}
\hadithdefcmd{muslim}{2395}{وَحَدَّثَنِيهِ أَبُو بَكْرِ بْنُ إِسْحَاقَ، حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنِي شَرِيكٌ، أَخْبَرَنِي عَطَاءُ بْنُ يَسَارٍ، وَعَبْدُ الرَّحْمَنِ بْنُ أَبِي عَمْرَةَ، أَنَّهُمَا سَمِعَا أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِ حَدِيثِ إِسْمَاعِيلَ ‏.‏\hadithno{2395}\hadithtrans{This hadith has been narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{2396}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، عَنْ مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُسْلِمٍ، أَخِي الزُّهْرِيِّ عَنْ حَمْزَةَ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَزَالُ الْمَسْأَلَةُ بِأَحَدِكُمْ حَتَّى يَلْقَى اللَّهَ وَلَيْسَ فِي وَجْهِهِ مُزْعَةُ لَحْمٍ ‏"‏ ‏.‏\hadithno{2396}\hadithtrans{Hamza. son of 'Abdullah, reported on the authority of his father that the Messenger of Allah (ﷺ) said:When a man is always begging from people. he would meet Allah (in a state) that there would be no flesh on his face}}
\hadithdefcmd{muslim}{2397}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنِي إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَخِي الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ وَلَمْ يَذْكُرْ ‏ "‏ مُزْعَةُ ‏"‏ ‏.‏\hadithno{2397}\hadithtrans{This hadith has been narrated on the authority of the brother of Zuhri with the same chain of transmitters, but no mention has been made of the word" muz'a" (piece)}}
\hadithdefcmd{muslim}{2398}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي اللَّيْثُ، عَنْ عُبَيْدِ اللَّهِ بْنِ، أَبِي جَعْفَرٍ عَنْ حَمْزَةَ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ سَمِعَ أَبَاهُ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا يَزَالُ الرَّجُلُ يَسْأَلُ النَّاسَ حَتَّى يَأْتِيَ يَوْمَ الْقِيَامَةِ وَلَيْسَ فِي وَجْهِهِ مُزْعَةُ لَحْمٍ ‏"‏ ‏.‏\hadithno{2398}\hadithtrans{Hamza b. 'Abdullah b. Umar heard his father say that the Messenger of Allah (ﷺ) had said:The person would continue begging from people till he would come on the Day of Resurrection and there would be no flesh on his face}}
\hadithdefcmd{muslim}{2399}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَوَاصِلُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ عُمَارَةَ بْنِ، الْقَعْقَاعِ عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ سَأَلَ النَّاسَ أَمْوَالَهُمْ تَكَثُّرًا فَإِنَّمَا يَسْأَلُ جَمْرًا فَلْيَسْتَقِلَّ أَوْ لِيَسْتَكْثِرْ ‏"‏ ‏.‏\hadithno{2399}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who begs the riches of others to increase his own is asking only for live coals, so let him ask a little or much}}
\hadithdefcmd{muslim}{2400}{حَدَّثَنِي هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ بَيَانٍ أَبِي بِشْرٍ، عَنْ قَيْسِ بْنِ، أَبِي حَازِمٍ عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لأَنْ يَغْدُوَ أَحَدُكُمْ فَيَحْطِبَ عَلَى ظَهْرِهِ فَيَتَصَدَّقَ بِهِ وَيَسْتَغْنِيَ بِهِ مِنَ النَّاسِ خَيْرٌ لَهُ مِنْ أَنْ يَسْأَلَ رَجُلاً أَعْطَاهُ أَوْ مَنَعَهُ ذَلِكَ فَإِنَّ الْيَدَ الْعُلْيَا أَفْضَلُ مِنَ الْيَدِ السُّفْلَى وَابْدَأْ بِمَنْ تَعُولُ ‏"‏ ‏.‏\hadithno{2400}\hadithtrans{Abu Huraira is reported to have heard the Messenger of Allah (ﷺ) as saying:It is better for one among you to bring a load of firewood on his back and give charity out of it (and satisfy his own need) and be independent of people, than that he should beg from people, whether they give him anything or refuse him. Verily the upper hand is better than the lower hand, and begin (charity) with your dependents}}
\hadithdefcmd{muslim}{2401}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ إِسْمَاعِيلَ، حَدَّثَنِي قَيْسُ بْنُ، أَبِي حَازِمٍ قَالَ أَتَيْنَا أَبَا هُرَيْرَةَ فَقَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ وَاللَّهِ لأَنْ يَغْدُوَ أَحَدُكُمْ فَيَحْطِبَ عَلَى ظَهْرِهِ فَيَبِيعَهُ ‏"‏ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ بَيَانٍ ‏.‏\hadithno{2401}\hadithtrans{Qais b. Abu Hizam reported:We came to Abu Huraira and he told Allah's Messenger (ﷺ) having said this: By Allah, (it is better) that one among you should go and bring a load of firewood on his back and he should sell it, and the rest of the hadith was narrated (like the previous one)}}
\hadithdefcmd{muslim}{2402}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَيُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو، بْنُ الْحَارِثِ عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لأَنْ يَحْتَزِمَ أَحَدُكُمْ حُزْمَةً مِنْ حَطَبٍ فَيَحْمِلَهَا عَلَى ظَهْرِهِ فَيَبِيعَهَا خَيْرٌ لَهُ مِنْ أَنْ يَسْأَلَ رَجُلاً يُعْطِيهِ أَوْ يَمْنَعُهُ ‏"‏ ‏.‏\hadithno{2402}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:It is better for any one of you to tie a bundle of firewood and carry it on his back and sell it than to beg a person, he may give or may refuse}}
\hadithdefcmd{muslim}{2403}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، وَسَلَمَةُ بْنُ شَبِيبٍ، - قَالَ سَلَمَةُ حَدَّثَنَا وَقَالَ الدَّارِمِيُّ، أَخْبَرَنَا مَرْوَانُ، وَهُوَ ابْنُ مُحَمَّدٍ الدِّمَشْقِيُّ - حَدَّثَنَا سَعِيدٌ، - وَهُوَ ابْنُ عَبْدِ الْعَزِيزِ - عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي مُسْلِمٍ الْخَوْلاَنِيِّ، قَالَ حَدَّثَنِي الْحَبِيبُ الأَمِينُ، أَمَّا هُوَ فَحَبِيبٌ إِلَىَّ وَأَمَّا هُوَ عِنْدِي فَأَمِينٌ عَوْفُ بْنُ مَالِكٍ الأَشْجَعِيُّ قَالَ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم تِسْعَةً أَوْ ثَمَانِيَةً أَوْ سَبْعَةً فَقَالَ ‏"‏ أَلاَ تُبَايِعُونَ رَسُولَ اللَّهِ ‏"‏ وَكُنَّا حَدِيثَ عَهْدٍ بِبَيْعَةٍ فَقُلْنَا قَدْ بَايَعْنَاكَ يَا رَسُولَ اللَّهِ ‏.‏ ثُمَّ قَالَ ‏"‏ أَلاَ تُبَايِعُونَ رَسُولَ اللَّهِ ‏"‏ ‏.‏ فَقُلْنَا قَدْ بَايَعْنَاكَ يَا رَسُولَ اللَّهِ ‏.‏ ثُمَّ قَالَ ‏"‏ أَلاَ تُبَايِعُونَ رَسُولَ اللَّهِ ‏"‏ ‏.‏ قَالَ فَبَسَطْنَا أَيْدِيَنَا وَقُلْنَا قَدْ بَايَعْنَاكَ يَا رَسُولَ اللَّهِ فَعَلاَمَ نُبَايِعُكَ قَالَ ‏"‏ عَلَى أَنْ تَعْبُدُوا اللَّهَ وَلاَ تُشْرِكُوا بِهِ شَيْئًا وَالصَّلَوَاتِ الْخَمْسِ وَتُطِيعُوا - وَأَسَرَّ كَلِمَةً خَفِيَّةً - وَلاَ تَسْأَلُوا النَّاسَ شَيْئًا ‏"‏ ‏.‏ فَلَقَدْ رَأَيْتُ بَعْضَ أُولَئِكَ النَّفَرِ يَسْقُطُ سَوْطُ أَحَدِهِمْ فَمَا يَسْأَلُ أَحَدًا يُنَاوِلُهُ إِيَّاهُ ‏.‏\hadithno{2403}\hadithtrans{Malik al-Ashja'i reported:We, nine, eight or seven men, were in the company of the Messenger of Allah (ﷺ) and he said: Why don't you pledge allegiance to the Messenger of Allah? -while we had recently pledged allegiance. So we said: Messenger of Allah, we have already pledged allegiance to you. He again said: Why don't you pledge allegiance to the Messenger of Allah? And we said: Messenger of Allah, we have already pledged allegiance to you. He again said: Why don't you pledge allegiance to the Messenger of Allah? We stretched our hands and said: Messenger of Allah. we have already pledged allegiance to you. Now tell (on what things) should we pledge allegiance to you. He said I (You must pledge allegiance) that you would worship Allah only and would not associate with Him anything, (and observe) five prayers, and obey- (and he said onething in an undertone) -that you would not beg people of anything. (And as a consequence of that) I saw that some of these people did not ask anyone to pick up the whip for them if it fell down}}
\hadithdefcmd{muslim}{2404}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، كِلاَهُمَا عَنْ حَمَّادِ بْنِ زَيْدٍ، قَالَ يَحْيَى أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ هَارُونَ بْنِ رِيَابٍ، حَدَّثَنِي كِنَانَةُ بْنُ نُعَيْمٍ الْعَدَوِيُّ، عَنْ قَبِيصَةَ بْنِ، مُخَارِقٍ الْهِلاَلِيِّ قَالَ تَحَمَّلْتُ حَمَالَةً فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَسْأَلُهُ فِيهَا فَقَالَ ‏"‏ أَقِمْ حَتَّى تَأْتِيَنَا الصَّدَقَةُ فَنَأْمُرَ لَكَ بِهَا ‏"‏ ‏.‏ قَالَ ثُمَّ قَالَ ‏"‏ يَا قَبِيصَةُ إِنَّ الْمَسْأَلَةَ لاَ تَحِلُّ إِلاَّ لأَحَدِ ثَلاَثَةٍ رَجُلٍ تَحَمَّلَ حَمَالَةً فَحَلَّتْ لَهُ الْمَسْأَلَةُ حَتَّى يُصِيبَهَا ثُمَّ يُمْسِكُ وَرَجُلٍ أَصَابَتْهُ جَائِحَةٌ اجْتَاحَتْ مَالَهُ فَحَلَّتْ لَهُ الْمَسْأَلَةُ حَتَّى يُصِيبَ قِوَامًا مِنْ عَيْشٍ - أَوْ قَالَ سِدَادًا مِنْ عَيْشٍ - وَرَجُلٍ أَصَابَتْهُ فَاقَةٌ حَتَّى يَقُومَ ثَلاَثَةٌ مِنْ ذَوِي الْحِجَا مِنْ قَوْمِهِ لَقَدْ أَصَابَتْ فُلاَنًا فَاقَةٌ فَحَلَّتْ لَهُ الْمَسْأَلَةُ حَتَّى يُصِيبَ قِوَامًا مِنْ عَيْشٍ - أَوْ قَالَ سِدَادًا مِنْ عَيْشٍ - فَمَا سِوَاهُنَّ مِنَ الْمَسْأَلَةِ يَا قَبِيصَةُ سُحْتًا يَأْكُلُهَا صَاحِبُهَا سُحْتًا ‏"‏ ‏.‏\hadithno{2404}\hadithtrans{Qabisa b. Mukhariq al-Hilali said:I was under debt and I came to the Messenger of Allah (ﷺ) and begged from him regarding it. He said: Wait till we receive Sadaqa, so that we order that to be given to you. He again said: Qabisa, begging is not permissible but for one of the three (classes) of persons: one who has incurred debt, for him begging is permissible till he pays that off, after which he must stop it; a man whose property has been destroyed by a calamity which has smitten him, for him begging is permissible till he gets what will support life, or will provide him reasonable subsistence; and a person who has been smitten by poverty. the genuineness of which is confirmed by three intelligent members of this peoples for him begging is permissible till he gets what will support him, or will provide him subsistence. Qabisa, besides these three (every other reason) for begging is forbidden, and one who engages in such consumes that what is forbidden}}
\hadithdefcmd{muslim}{2405}{وَحَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، ح وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، - رضى الله عنه - يَقُولُ قَدْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعْطِينِي الْعَطَاءَ فَأَقُولُ أَعْطِهِ أَفْقَرَ إِلَيْهِ مِنِّي ‏.‏ حَتَّى أَعْطَانِي مَرَّةً مَالاً فَقُلْتُ أَعْطِهِ أَفْقَرَ إِلَيْهِ مِنِّي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خُذْهُ وَمَا جَاءَكَ مِنْ هَذَا الْمَالِ وَأَنْتَ غَيْرُ مُشْرِفٍ وَلاَ سَائِلٍ فَخُذْهُ وَمَا لاَ فَلاَ تُتْبِعْهُ نَفْسَكَ ‏"‏ ‏.‏\hadithno{2405}\hadithtrans{Salim b. Abdullah b. 'Umar reported on the authority of his father ('Abdullah b. 'Umar) that he had heard 'Umar b. Khattab (Allah be pleased with him) saying:The Messenger of Allah (ﷺ) gave me a gift, but I said: Give it to one who needs it more than I. He gave me wealth for the second time but I said: Give it to one who needs it more than I. Upon this the Messenger of Allah (ﷺ) said: Take out of this wealth which comes to you without your being avaricious and without begging, but in other circumstance's do not let your heart hanker after it}}
\hadithdefcmd{muslim}{2406}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُعْطِي عُمَرَ بْنَ الْخَطَّابِ - رضى الله عنه - الْعَطَاءَ فَيَقُولُ لَهُ عُمَرُ أَعْطِهِ يَا رَسُولَ اللَّهِ أَفْقَرَ إِلَيْهِ مِنِّي ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خُذْهُ فَتَمَوَّلْهُ أَوْ تَصَدَّقْ بِهِ وَمَا جَاءَكَ مِنْ هَذَا الْمَالِ وَأَنْتَ غَيْرُ مُشْرِفٍ وَلاَ سَائِلٍ فَخُذْهُ وَمَا لاَ فَلاَ تُتْبِعْهُ نَفْسَكَ ‏"‏ ‏.‏ قَالَ سَالِمٌ فَمِنْ أَجْلِ ذَلِكَ كَانَ ابْنُ عُمَرَ لاَ يَسْأَلُ أَحَدًا شَيْئًا وَلاَ يَرُدُّ شَيْئًا أُعْطِيَهُ ‏.‏\hadithno{2406}\hadithtrans{Salim b. 'Abdullah reported on the authority of his father that the Messenger of Allah (ﷺ) gave to 'Umar b. Khattab some gift. Umar said to him:Messenger of Allah, give it to one who needs it more than I. Upon this the Messenger of Allah (ﷺ) said: Take it; either keep it with you or give it as a charity, and whatever comes to you in the form of this type of wealth, without your being avaricious or begging for it, accept it, but in other circumstances do not let your heart hanker after it. And it was on account of this that Ibn 'Umar never begged anything from anyone, nor refused anything given to him}}
\hadithdefcmd{muslim}{2407}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ عَمْرٌو وَحَدَّثَنِي ابْنُ شِهَابٍ، بِمِثْلِ ذَلِكَ عَنِ السَّائِبِ بْنِ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ السَّعْدِيِّ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، - رضى الله عنه - عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2407}\hadithtrans{This hadith has been narrated by Abdullah b. al-Sa'di from 'Umar b. al-Khattab who heard it from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{2408}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ بُكَيْرٍ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنِ ابْنِ السَّاعِدِيِّ، الْمَالِكِيِّ أَنَّهُ قَالَ اسْتَعْمَلَنِي عُمَرُ بْنُ الْخَطَّابِ - رضى الله عنه - عَلَى الصَّدَقَةِ فَلَمَّا فَرَغْتُ مِنْهَا وَأَدَّيْتُهَا إِلَيْهِ أَمَرَ لِي بِعُمَالَةٍ فَقُلْتُ إِنَّمَا عَمِلْتُ لِلَّهِ وَأَجْرِي عَلَى اللَّهِ ‏.‏ فَقَالَ خُذْ مَا أُعْطِيتَ فَإِنِّي عَمِلْتُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَعَمَّلَنِي فَقُلْتُ مِثْلَ قَوْلِكَ فَقَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أُعْطِيتَ شَيْئًا مِنْ غَيْرِ أَنْ تَسْأَلَ فَكُلْ وَتَصَدَّقْ ‏"‏ ‏.‏\hadithno{2408}\hadithtrans{Ibn al-Sa'di Maliki reported:'Umar b. Khattab (Allah be pleased with him) appointed me as a collector of Sadaqa. When I had finished that (the task assigned to me) and I handed over that to him (to 'Umar), he commanded me to (accept) some remuneration (for the work). I said: I performed this duty for Allah and my reward is with Allah. He said: Take whatever has been given to you, for I also performed this duty during the time of the Messenger of Allah (ﷺ). He assigned me the task of a collector and I said as you say, and the Messenger of Allah (ﷺ) said to me: When you are given anything without your begging for it, (then accept it), eat it and give it in charity}}
\hadithdefcmd{muslim}{2409}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنِ ابْنِ السَّعْدِيِّ، أَنَّهُ قَالَ اسْتَعْمَلَنِي عُمَرُ بْنُ الْخَطَّابِ - رضى الله عنه - عَلَى الصَّدَقَةِ ‏.‏ بِمِثْلِ حَدِيثِ اللَّيْثِ ‏.‏\hadithno{2409}\hadithtrans{Ibn al-Sa'di reported:'Umar b. Khattab (Allah be pleased with him) appointed me as a collector of Sadaqat. The rest of the hadith in the same}}
\hadithdefcmd{muslim}{2410}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ قَلْبُ الشَّيْخِ شَابٌّ عَلَى حُبِّ اثْنَتَيْنِ حُبِّ الْعَيْشِ وَالْمَالِ ‏"‏ ‏.‏\hadithno{2410}\hadithtrans{Abu Huraira reported from the Messenger of Allah (ﷺ) as having said this:The heart of an old person feels young for the love of two things: love for long life and wealth}}
\hadithdefcmd{muslim}{2411}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَلْبُ الشَّيْخِ شَابٌّ عَلَى حُبِّ اثْنَتَيْنِ طُولُ الْحَيَاةِ وَحُبُّ الْمَالِ ‏"‏ ‏.‏\hadithno{2411}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) had said this:The heart of an old person is young for two things: for long life and love for wealth}}
\hadithdefcmd{muslim}{2412}{وَحَدَّثَنِي يَحْيَى بْنُ يَحْيَى، وَسَعِيدُ بْنُ مَنْصُورٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، كُلُّهُمْ عَنْ أَبِي عَوَانَةَ، - قَالَ يَحْيَى أَخْبَرَنَا أَبُو عَوَانَةَ، - عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَهْرَمُ ابْنُ آدَمَ وَتَشِبُّ مِنْهُ اثْنَتَانِ الْحِرْصُ عَلَى الْمَالِ وَالْحِرْصُ عَلَى الْعُمُرِ ‏"‏ ‏.‏\hadithno{2412}\hadithtrans{Anas reported Allah's Messenger (ﷺ) as saying:The son of Adam grows old, but two (desires) in him remain young: desire for wealth and desire for life}}
\hadithdefcmd{muslim}{2413}{وَحَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ بِمِثْلِهِ ‏.‏\hadithno{2413}\hadithtrans{A hadith like this has been narrated by Anas through another chain of transmitters}}
\hadithdefcmd{muslim}{2414}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِهِ ‏.‏\hadithno{2414}\hadithtrans{This hadith has been narrated on the authority of Anas through another chain of transmitters}}
\hadithdefcmd{muslim}{2415}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَسَعِيدُ بْنُ مَنْصُورٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كَانَ لاِبْنِ آدَمَ وَادِيَانِ مِنْ مَالٍ لاَبْتَغَى وَادِيًا ثَالِثًا وَلاَ يَمْلأُ جَوْفَ ابْنِ آدَمَ إِلاَّ التُّرَابُ وَيَتُوبُ اللَّهُ عَلَى مَنْ تَابَ ‏"‏ ‏.‏\hadithno{2415}\hadithtrans{Anas reported Allah's Messenger (ﷺ) as saying:If the son of Adam were to possess two valleys of riches. he would long for the third one. And the stomach of the son of Adam is not filled but with dust. And Allah returns to him who repents}}
\hadithdefcmd{muslim}{2416}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ - فَلاَ أَدْرِي أَشَىْءٌ أُنْزِلَ أَمْ شَىْءٌ كَانَ يَقُولُهُ - بِمِثْلِ حَدِيثِ أَبِي عَوَانَةَ ‏.‏\hadithno{2416}\hadithtrans{Anas b. Malik reported:I heard the Messenger of Allah (ﷺ) as saying this, but I do not know whether this thing was revealed to him or not, but he said to}}
\hadithdefcmd{muslim}{2417}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنِي ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لَوْ كَانَ لاِبْنِ آدَمَ وَادٍ مِنْ ذَهَبٍ أَحَبَّ أَنَّ لَهُ وَادِيًا آخَرَ وَلَنْ يَمْلأَ فَاهُ إِلاَّ التُّرَابُ وَاللَّهُ يَتُوبُ عَلَى مَنْ تَابَ ‏"‏ ‏.‏\hadithno{2417}\hadithtrans{Anas b. Malik reported Allah's Messenger (ﷺ) as saying:If there were two valleys of gold for the son of Adam, he would long for another one. and his mouth will not be filled but with dust, and Allah returns to him who repents}}
\hadithdefcmd{muslim}{2418}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ سَمِعْتُ عَطَاءً، يَقُولُ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَوْ أَنَّ لاِبْنِ آدَمَ مِلْءَ وَادٍ مَالاً لأَحَبَّ أَنْ يَكُونَ إِلَيْهِ مِثْلُهُ وَلاَ يَمْلأُ نَفْسَ ابْنِ آدَمَ إِلاَّ التُّرَابُ وَاللَّهُ يَتُوبُ عَلَى مَنْ تَابَ ‏"‏ ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَلاَ أَدْرِي أَمِنَ الْقُرْآنِ هُوَ أَمْ لاَ ‏.‏ وَفِي رِوَايَةِ زُهَيْرٍ قَالَ فَلاَ أَدْرِي أَمِنَ الْقُرْآنِ ‏.‏ لَمْ يَذْكُرِ ابْنَ عَبَّاسٍ ‏.‏\hadithno{2418}\hadithtrans{Ibn Abbas reported Allah's Messenger (ﷺ) as saying:If there were for the son of Adam a valley full of riches, he would long to possess another one like it. and Ibn Adam does not feel satiated but with dust. And Allah returns to him who returns (to Him). Ibn Abbas said: I do not know whether it is from the Qur'an or not; and in the narration transmitted by Zuhair it was said: I do not know whether it is from the Qur'an, and he made no mention of Ibn Abbas}}
\hadithdefcmd{muslim}{2419}{حَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ دَاوُدَ، عَنْ أَبِي حَرْبِ بْنِ أَبِي، الأَسْوَدِ عَنْ أَبِيهِ، قَالَ بَعَثَ أَبُو مُوسَى الأَشْعَرِيُّ إِلَى قُرَّاءِ أَهْلِ الْبَصْرَةِ فَدَخَلَ عَلَيْهِ ثَلاَثُمِائَةِ رَجُلٍ قَدْ قَرَءُوا الْقُرْآنَ فَقَالَ أَنْتُمْ خِيَارُ أَهْلِ الْبَصْرَةِ وَقُرَّاؤُهُمْ فَاتْلُوهُ وَلاَ يَطُولَنَّ عَلَيْكُمُ الأَمَدُ فَتَقْسُوَ قُلُوبُكُمْ كَمَا قَسَتْ قُلُوبُ مَنْ كَانَ قَبْلَكُمْ وَإِنَّا كُنَّا نَقْرَأُ سُورَةً كُنَّا نُشَبِّهُهَا فِي الطُّولِ وَالشِّدَّةِ بِبَرَاءَةَ فَأُنْسِيتُهَا غَيْرَ أَنِّي قَدْ حَفِظْتُ مِنْهَا لَوْ كَانَ لاِبْنِ آدَمَ وَادِيَانِ مِنْ مَالٍ لاَبْتَغَى وَادِيًا ثَالِثًا وَلاَ يَمْلأُ جَوْفَ ابْنِ آدَمَ إِلاَّ التُّرَابُ ‏.‏ وَكُنَّا نَقْرَأُ سُورَةً كُنَّا نُشَبِّهُهَا بِإِحْدَى الْمُسَبِّحَاتِ فَأُنْسِيتُهَا غَيْرَ أَنِّي حَفِظْتُ مِنْهَا ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا لِمَ تَقُولُونَ مَا لاَ تَفْعَلُونَ‏\}‏ فَتُكْتَبُ شَهَادَةً فِي أَعْنَاقِكُمْ فَتُسْأَلُونَ عَنْهَا يَوْمَ الْقِيَامَةِ ‏.‏\hadithno{2419}\hadithtrans{Abu Harb b. Abu al-Aswad reported on the authority of his father that Abu Musa al-Ash'ari sent for the reciters of Basra. They came to him and they were three hundred in number. They recited the Qur'an and he said:You are the best among the inhabitants of Basra, for you are the reciters among them. So continue to recite it. (But bear in mind) that your reciting for a long time may not harden your hearts as were hardened the hearts of those before you. We used to recite a surah which resembled in length and severity to (Surah) Bara'at. I have, however, forgotten it with the exception of this which I remember out of it:" If there were two valleys full of riches, for the son of Adam, he would long for a third valley, and nothing would fill the stomach of the son of Adam but dust." And we used so recite a surah which resembled one of the surahs of Musabbihat, and I have forgotten it, but remember (this much) out of it:" Oh people who believe, why do you say that which you do not practise" (lxi 2.) and" that is recorded in your necks as a witness (against you) and you would be asked about it on the Day of Resurrection" (xvii)}}
\hadithdefcmd{muslim}{2420}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ الْغِنَى عَنْ كَثْرَةِ الْعَرَضِ وَلَكِنَّ الْغِنَى غِنَى النَّفْسِ ‏"‏ ‏.‏\hadithno{2420}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) had said:Richness does not lie in the abundance of (worldly) goods but richness is the richness of the soul (heart, self)}}
\hadithdefcmd{muslim}{2421}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا اللَّيْثُ بْنُ سَعْدٍ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، - وَتَقَارَبَا فِي اللَّفْظِ - قَالَ حَدَّثَنَا لَيْثٌ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ عِيَاضِ بْنِ، عَبْدِ اللَّهِ بْنِ سَعْدٍ أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَخَطَبَ النَّاسَ فَقَالَ ‏"‏ لاَ وَاللَّهِ مَا أَخْشَى عَلَيْكُمْ أَيُّهَا النَّاسُ إِلاَّ مَا يُخْرِجُ اللَّهُ لَكُمْ مِنْ زَهْرَةِ الدُّنْيَا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ أَيَأْتِي الْخَيْرُ بِالشَّرِّ فَصَمَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَاعَةً ثُمَّ قَالَ ‏"‏ كَيْفَ قُلْتَ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَيَأْتِي الْخَيْرُ بِالشَّرِّ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الْخَيْرَ لاَ يَأْتِي إِلاَّ بِخَيْرٍ أَوَ خَيْرٌ هُوَ إِنَّ كُلَّ مَا يُنْبِتُ الرَّبِيعُ يَقْتُلُ حَبَطًا أَوْ يُلِمُّ إِلاَّ آكِلَةَ الْخَضِرِ أَكَلَتْ حَتَّى إِذَا امْتَلأَتْ خَاصِرَتَاهَا اسْتَقْبَلَتِ الشَّمْسَ ثَلَطَتْ أَوْ بَالَتْ ثُمَّ اجْتَرَّتْ فَعَادَتْ فَأَكَلَتْ فَمَنْ يَأْخُذْ مَالاً بِحَقِّهِ يُبَارَكْ لَهُ فِيهِ وَمَنْ يَأْخُذْ مَالاً بِغَيْرِ حَقِّهِ فَمَثَلُهُ كَمَثَلِ الَّذِي يَأْكُلُ وَلاَ يَشْبَعُ ‏"‏ ‏.‏\hadithno{2421}\hadithtrans{Abu Sa'id al-Khudri reported that the Messenger of Allah (ﷺ) stood up and addressed the people thus:O people, by Allah, I do not entertain fear about you in regard to anything else than that which Allah would bring forth for you in the form of adornment of the world. A person said: Messenger of Allah, does good produce evil? The Messenger of Allah (ﷺ) remained silent for a while and he then said: What did you say? He replied: Messenger of Allah, I said: Does good produce evil? The Messenger of Allah (ﷺ) said to him: The good does not produce but good. but among the plants the spring rain produces There some which kill with a tremour or nearly kill all but the animal which feeds on vegetation. It eats and when its flanks are distended, it faces the can. then when it has donged or urinated and chewed it returns and eats. He who accepts wealth rightly, Allah confers blessing on it for him. and he who takes wealth without any right, he is like one who eats and is not satisfied}}
\hadithdefcmd{muslim}{2422}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ أَخْوَفُ مَا أَخَافُ عَلَيْكُمْ مَا يُخْرِجُ اللَّهُ لَكُمْ مِنْ زَهْرَةِ الدُّنْيَا ‏"‏ ‏.‏ قَالُوا وَمَا زَهْرَةُ الدُّنْيَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ بَرَكَاتُ الأَرْضِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَهَلْ يَأْتِي الْخَيْرُ بِالشَّرِّ قَالَ ‏"‏ لاَ يَأْتِي الْخَيْرُ إِلاَّ بِالْخَيْرِ لاَ يَأْتِي الْخَيْرُ إِلاَّ بِالْخَيْرِ لاَ يَأْتِي الْخَيْرُ إِلاَّ بِالْخَيْرِ إِنَّ كُلَّ مَا أَنْبَتَ الرَّبِيعُ يَقْتُلُ أَوْ يُلِمُّ إِلاَّ آكِلَةَ الْخَضِرِ فَإِنَّهَا تَأْكُلُ حَتَّى إِذَا امْتَدَّتْ خَاصِرَتَاهَا اسْتَقْبَلَتِ الشَّمْسَ ثُمَّ اجْتَرَّتْ وَبَالَتْ وَثَلَطَتْ ثُمَّ عَادَتْ فَأَكَلَتْ إِنَّ هَذَا الْمَالَ خَضِرَةٌ حُلْوَةٌ فَمَنْ أَخَذَهُ بِحَقِّهِ وَوَضَعَهُ فِي حَقِّهِ فَنِعْمَ الْمَعُونَةُ هُوَ وَمَنْ أَخَذَهُ بِغَيْرِ حَقِّهِ كَانَ كَالَّذِي يَأْكُلُ وَلاَ يَشْبَعُ ‏"‏ ‏.‏\hadithno{2422}\hadithtrans{Abu Sa'id al-Khudri reported that the Messenger of Allah (ﷺ) had said:The most dreadful thing I fear in your case is what Allah brings forth for you in the form of the adornment of the world. They (the Prophet's Companions) said: Messenger of Allah, what is the adornment of the world? He said: Blessings (the natural resources) of the earth. They (again) said: Messenger of Allah, does good produce evil? He said: No, only good comes out of good. No, only good comes out of good. No. only good comes out of good. All that which the spring rain helps to grow kills or is about to kill but (the animal) which feeds on vegetation. It eats and when its flanks are distended, it faces the sun, it chews the cud, it has dunged and urinated. it returns and eats. This wealth is green and sweet, and he who accepts it and applies it rightly, finds it a good help, but he who takes it wrongfully is like one who eats without being satisfied}}
\hadithdefcmd{muslim}{2423}{حَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ هِشَامٍ، صَاحِبِ الدَّسْتَوَائِيِّ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ هِلاَلِ بْنِ أَبِي مَيْمُونَةَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ جَلَسَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ وَجَلَسْنَا حَوْلَهُ فَقَالَ ‏"‏ إِنَّ مِمَّا أَخَافُ عَلَيْكُمْ بَعْدِي مَا يُفْتَحُ عَلَيْكُمْ مِنْ زَهْرَةِ الدُّنْيَا وَزِينَتِهَا ‏"‏ ‏.‏ فَقَالَ رَجُلٌ أَوَيَأْتِي الْخَيْرُ بِالشَّرِّ يَا رَسُولَ اللَّهِ قَالَ فَسَكَتَ عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقِيلَ لَهُ مَا شَأْنُكَ تُكَلِّمُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَلاَ يُكَلِّمُكَ قَالَ وَرُئِينَا أَنَّهُ يُنْزَلُ عَلَيْهِ فَأَفَاقَ يَمْسَحُ عَنْهُ الرُّحَضَاءَ وَقَالَ ‏"‏ إِنَّ هَذَا السَّائِلَ - وَكَأَنَّهُ حَمِدَهُ فَقَالَ - إِنَّهُ لاَ يَأْتِي الْخَيْرُ بِالشَّرِّ وَإِنَّ مِمَّا يُنْبِتُ الرَّبِيعُ يَقْتُلُ أَوْ يُلِمُّ إِلاَّ آكِلَةَ الْخَضِرِ فَإِنَّهَا أَكَلَتْ حَتَّى إِذَا امْتَلأَتْ خَاصِرَتَاهَا اسْتَقْبَلَتْ عَيْنَ الشَّمْسِ فَثَلَطَتْ وَبَالَتْ ثُمَّ رَتَعَتْ وَإِنَّ هَذَا الْمَالَ خَضِرٌ حُلْوٌ وَنِعْمَ صَاحِبُ الْمُسْلِمِ هُوَ لِمَنْ أَعْطَى مِنْهُ الْمِسْكِينَ وَالْيَتِيمَ وَابْنَ السَّبِيلِ أَوْ كَمَا قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَإِنَّهُ مَنْ يَأْخُذُهُ بِغَيْرِ حَقِّهِ كَانَ كَالَّذِي يَأْكُلُ وَلاَ يَشْبَعُ وَيَكُونُ عَلَيْهِ شَهِيدًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2423}\hadithtrans{Abu Said al-Khudri reported:The Messenger of Allah (ﷺ) was sitting on the pulpit and we were sitting around him, and he said: What I am afraid of in regard to you after my death is that there would be opened for you the adornments of the world and its beauties. A person said: Messenger of Allah, does good produce evil? The Messenger of Allah (ﷺ) remained silent. And it was said to him (the man who had asked the question from the Holy Prophet): What Is the matter with you, that you speak with the Messenger of Allah (ﷺ) but he does not speak with you? We thought as if revelation was descending upon him. He regained himself and wiped the sweat from him and said: He was the inquirer (and his style of expression showed as if he praised him and then added): Verily good does not produce evil. Whatever the spring rainfall causes to grow kills or is about to kill, but that (animal) which feeds on vegetation. It eats till its flanks are filled; it faces the sun and dungs and urinates. and then returns to eat. And this Wealth is a sweet vegetation, and it is a good companion for a Muslim who gives out of it to the needy, to the orphan. to the wayfarer, or something like that as the Messenger of Allah (ﷺ) said: He who takes it without his right is like one who eats but does not feel satisfied, and it would stand witness against him on the Day of judgment}}
\hadithdefcmd{muslim}{2424}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، فِيمَا قُرِئَ عَلَيْهِ عَنِ ابْنِ شِهَابٍ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ نَاسًا، مِنَ الأَنْصَارِ سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَعْطَاهُمْ ثُمَّ سَأَلُوهُ فَأَعْطَاهُمْ حَتَّى إِذَا نَفِدَ مَا عِنْدَهُ قَالَ ‏ "‏ مَا يَكُنْ عِنْدِي مِنْ خَيْرٍ فَلَنْ أَدَّخِرَهُ عَنْكُمْ وَمَنْ يَسْتَعْفِفْ يُعِفَّهُ اللَّهُ وَمَنْ يَسْتَغْنِ يُغْنِهِ اللَّهُ وَمَنْ يَصْبِرْ يُصَبِّرْهُ اللَّهُ وَمَا أُعْطِيَ أَحَدٌ مِنْ عَطَاءٍ خَيْرٌ وَأَوْسَعُ مِنَ الصَّبْرِ ‏"‏ ‏.‏\hadithno{2424}\hadithtrans{Abu Sa'id al-Khudri reported that some people from among the Ansar begged from the Messenger of Allah (ﷺ) and he gave them. They again begged him and he again gave them, till when what was in his possession was exhausted he said:Whatever good (riches, goods) I have, I will not withhold it from you. He who refrains from begging Allah safeguards him against want. and he who seeks sufficiency, Allah would keep him in a state of sufficiency, and he who shows endurance. Allah would grant him power to endure, and none is blessed with an endowment better and greater than endurance}}
\hadithdefcmd{muslim}{2425}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ ‏.‏\hadithno{2425}\hadithtrans{This hadith has been narrated by Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{2426}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو عَبْدِ الرَّحْمَنِ الْمُقْرِئُ، عَنْ سَعِيدِ بْنِ أَبِي، أَيُّوبَ حَدَّثَنِي شُرَحْبِيلُ، - وَهُوَ ابْنُ شَرِيكٍ - عَنْ أَبِي عَبْدِ الرَّحْمَنِ الْحُبُلِيِّ، عَنْ عَبْدِ اللَّهِ، بْنِ عَمْرِو بْنِ الْعَاصِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَدْ أَفْلَحَ مَنْ أَسْلَمَ وَرُزِقَ كَفَافًا وَقَنَّعَهُ اللَّهُ بِمَا آتَاهُ ‏"‏ ‏.‏\hadithno{2426}\hadithtrans{Amr b. al-'As reported Allah's Messenger (ﷺ) as saying:He Is successful who has accepted Islam, who has been provided with sufficient for his want and been made contented by Allah with what He has given him}}
\hadithdefcmd{muslim}{2427}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالُوا حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِيهِ، كِلاَهُمَا عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ اجْعَلْ رِزْقَ آلِ مُحَمَّدٍ قُوتًا ‏"‏ ‏.‏\hadithno{2427}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:O Allah, make the provision of Muhammad's family sufficient just to sustain life}}
\hadithdefcmd{muslim}{2428}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ سَلْمَانَ، بْنِ رَبِيعَةَ قَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ رضى الله عنه قَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَسْمًا فَقُلْتُ وَاللَّهِ يَا رَسُولَ اللَّهِ لَغَيْرُ هَؤُلاَءِ كَانَ أَحَقَّ بِهِ مِنْهُمْ ‏.‏ قَالَ ‏ "‏ إِنَّهُمْ خَيَّرُونِي أَنْ يَسْأَلُونِي بِالْفُحْشِ أَوْ يُبَخِّلُونِي فَلَسْتُ بِبَاخِلٍ ‏"‏ ‏.‏\hadithno{2428}\hadithtrans{Umar b. Khattab (Allah be pleased with him) reported that the Messenger of Allah (ﷺ) distributed something. Upon this I said:Messenger of Allah, I swear by God, the others besides them were more deserving than these (to whom you gave charity). He said: They had in fact left no other alternative for me. but (that they should) either beg importunately from me or they would regard me as a miser, but I am not a miser}}
\hadithdefcmd{muslim}{2429}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا إِسْحَاقُ بْنُ سُلَيْمَانَ الرَّازِيُّ، قَالَ سَمِعْتُ مَالِكًا، ح وَحَدَّثَنِي يُونُسُ بْنُ عَبْدِ الأَعْلَى، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي مَالِكُ، بْنُ أَنَسٍ عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنْتُ أَمْشِي مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ رِدَاءٌ نَجْرَانِيٌّ غَلِيظُ الْحَاشِيَةِ فَأَدْرَكَهُ أَعْرَابِيٌّ فَجَبَذَهُ بِرِدَائِهِ جَبْذَةً شَدِيدَةً نَظَرْتُ إِلَى صَفْحَةِ عُنُقِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَقَدْ أَثَّرَتْ بِهَا حَاشِيَةُ الرِّدَاءِ مِنْ شِدَّةِ جَبْذَتِهِ ثُمَّ قَالَ يَا مُحَمَّدُ مُرْ لِي مِنْ مَالِ اللَّهِ الَّذِي عِنْدَكَ ‏.‏ فَالْتَفَتَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَضَحِكَ ثُمَّ أَمَرَ لَهُ بِعَطَاءٍ ‏.‏\hadithno{2429}\hadithtrans{Anas b. Malik reported:I was walking with the Messenger of Allah (ﷺ) and he had put on a mantle of Najran with a thick border. A bedouin met him and pulled the mantle so violently that I saw this violent pulling leaving marks of the border of the mantle on the skin of the neck of the Messenger of Allah (ﷺ). And he (the bedouin) said: Muhammad, issue command that I should be given out of the wealth of Allah which is at your disposal. The Messenger of Allah (ﷺ) turned his attention to him and smiled, and then ordered for him a gift (provision)}}
\hadithdefcmd{muslim}{2430}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا هَمَّامٌ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، ح وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنَا الأَوْزَاعِيُّ، كُلُّهُمْ عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ، بْنِ مَالِكٍ عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏.‏ وَفِي حَدِيثِ عِكْرِمَةَ بْنِ عَمَّارٍ مِنَ الزِّيَادَةِ قَالَ ثُمَّ جَبَذَهُ إِلَيْهِ جَبْذَةً رَجَعَ نَبِيُّ اللَّهِ صلى الله عليه وسلم فِي نَحْرِ الأَعْرَابِيِّ ‏.‏ وَفِي حَدِيثِ هَمَّامٍ فَجَاذَبَهُ حَتَّى انْشَقَّ الْبُرْدُ وَحَتَّى بَقِيَتْ حَاشِيَتُهُ فِي عُنُقِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2430}\hadithtrans{This hadith has been narrated on the authority of Anas b. Malik through another chain of transmitters. And In the hadith transmitted by Ikrima b. 'Ammir there is an addition:" He (the bedouin) pulled his (mantle) so violently that the Messenger of Allah (ﷺ) was drifted very close to the bedouin." And in the hadith transmitted by Hammam, (the words are):" He pulled it so violently that the mantle was torn and the border was left around the neck of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{2431}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، أَنَّهُ قَالَ قَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَقْبِيَةً وَلَمْ يُعْطِ مَخْرَمَةَ شَيْئًا فَقَالَ مَخْرَمَةُ يَا بُنَىَّ انْطَلِقْ بِنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَانْطَلَقْتُ مَعَهُ قَالَ ادْخُلْ فَادْعُهُ لِي ‏.‏ قَالَ فَدَعَوْتُهُ لَهُ فَخَرَجَ إِلَيْهِ وَعَلَيْهِ قَبَاءٌ مِنْهَا فَقَالَ ‏"‏ خَبَأْتُ هَذَا لَكَ ‏"‏ ‏.‏ قَالَ فَنَظَرَ إِلَيْهِ فَقَالَ ‏"‏ رَضِيَ مَخْرَمَةُ ‏"‏ ‏.‏\hadithno{2431}\hadithtrans{Miswar b. Makhrama reported that the Messenger of Allah (ﷺ) distributed some cloaks but did not bestow one upon Makhrama. Upon this Makhrama said:O my son, come along with me to the Messenger of Allah (ﷺ). So I went with him. He said: Enter the house and call him (to come out) for me. So I called him and he (the Holy Prophet) came out, and there was a cloak (from those already distributed) on him. He (the Holy Prophet) said: I had kept it for you. He (Makhrama), looked at it and was pleased}}
\hadithdefcmd{muslim}{2432}{حَدَّثَنَا أَبُو الْخَطَّابِ، زِيَادُ بْنُ يَحْيَى الْحَسَّانِيُّ حَدَّثَنَا حَاتِمُ بْنُ وَرْدَانَ أَبُو صَالِحٍ، حَدَّثَنَا أَيُّوبُ السَّخْتِيَانِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، عَنِ الْمِسْوَرِ بْنِ مَخْرَمَةَ، قَالَ قَدِمَتْ عَلَى النَّبِيِّ صلى الله عليه وسلم أَقْبِيَةٌ فَقَالَ لِي أَبِي مَخْرَمَةُ انْطَلِقْ بِنَا إِلَيْهِ عَسَى أَنْ يُعْطِيَنَا مِنْهَا شَيْئًا ‏.‏ قَالَ فَقَامَ أَبِي عَلَى الْبَابِ فَتَكَلَّمَ فَعَرَفَ النَّبِيُّ صلى الله عليه وسلم صَوْتَهُ فَخَرَجَ وَمَعَهُ قَبَاءٌ وَهُوَ يُرِيهِ مَحَاسِنَهُ وَهُوَ يَقُولُ ‏ "‏ خَبَأْتُ هَذَا لَكَ خَبَأْتُ هَذَا لَكَ ‏"‏ ‏.‏\hadithno{2432}\hadithtrans{Miswar b. Makhrama reported:Some cloaks were presented to the Messenger of Allah (ﷺ). My father Makhrama said to me: Come along with me to him; perhaps we may be able to get anything out of that (stock of cloaks). My father stood at the door and began to talk. The Apostle of Allah (ﷺ) recognised him by his voice and came out and there was a cloak with him, and he was showing its beauties and saying: I kept it for you, I kept it for you}}
\hadithdefcmd{muslim}{2433}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عَامِرُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، سَعْدٍ أَنَّهُ أَعْطَى رَسُولُ اللَّهِ صلى الله عليه وسلم رَهْطًا وَأَنَا جَالِسٌ فِيهِمْ قَالَ فَتَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْهُمْ رَجُلاً لَمْ يُعْطِهِ وَهُوَ أَعْجَبُهُمْ إِلَىَّ فَقُمْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَسَارَرْتُهُ فَقُلْتُ يَا رَسُولَ اللَّهِ مَا لَكَ عَنْ فُلاَنٍ وَاللَّهِ إِنِّي لأَرَاهُ مُؤْمِنًا ‏.‏ قَالَ ‏"‏ أَوْ مُسْلِمًا ‏"‏ ‏.‏ فَسَكَتُّ قَلِيلاً ثُمَّ غَلَبَنِي مَا أَعْلَمُ مِنْهُ فَقُلْتُ يَا رَسُولَ اللَّهِ مَا لَكَ عَنْ فُلاَنٍ فَوَاللَّهِ إِنِّي لأَرَاهُ مُؤْمِنًا ‏.‏ قَالَ ‏"‏ أَوْ مُسْلِمًا ‏"‏ ‏.‏ فَسَكَتُّ قَلِيلاً ثُمَّ غَلَبَنِي مَا أَعْلَمُ مِنْهُ فَقُلْتُ يَا رَسُولَ اللَّهِ مَا لَكَ عَنْ فُلاَنٍ فَوَاللَّهِ إِنِّي لأَرَاهُ مُؤْمِنًا ‏.‏ قَالَ ‏"‏ أَوْ مُسْلِمًا ‏"‏ ‏.‏ قَالَ ‏"‏ إِنِّي لأُعْطِي الرَّجُلَ ‏.‏ وَغَيْرُهُ أَحَبُّ إِلَىَّ مِنْهُ خَشْيَةَ أَنْ يُكَبَّ فِي النَّارِ عَلَى وَجْهِهِ ‏"‏ ‏.‏ وَفِي حَدِيثِ الْحُلْوَانِيِّ تَكْرَارُ الْقَوْلِ مَرَّتَيْنِ ‏.‏\hadithno{2433}\hadithtrans{Sa'd reported that the Messenger of Allah (ﷺ) bestowed (some gifts) upon a group of people and I was sitting amongst them. The Messenger of Allah (ﷺ), however, left a person and he did not give him anything. and he seemed to me the most excellent among them (and thus deserved the gifts more than anyone else). So I stood up before the Messenger of Allah (ﷺ) and said to him in undertone:Messenger of Allah, what about so and so? By Allah, I find him a believer. He (the Messenger of Allah) said: He may be a Muslim. I kept quiet for a short while, and then what I knew of him urged me (to plead his case again) and I said: Messenger of Allah, what about so and so? By Allah, I find him a believer. Upon this he (the Holy Prophet) said: He may be a Muslim. I again remained quiet for a short while, and what I knew of him again urged me (to plead his case so I) said: Messenger of Allah, what about so and so? By Allah, I find him a believer. Upon this he (the Holy Prophet) said: He may be a Muslim. I often bestow (something) upon a person, whereas someone else is dearer to me than he, because of the fear that he may fall headlong into the fire. And in the hadith transmitted by Hulwani this statement was repeated twice}}
\hadithdefcmd{muslim}{2434}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ، بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ حَدَّثَنَا ابْنُ أَخِي ابْنِ شِهَابٍ، ح وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ، بْنُ حُمَيْدٍ قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كُلُّهُمْ عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ عَلَى مَعْنَى حَدِيثِ صَالِحٍ عَنِ الزُّهْرِيِّ ‏.‏\hadithno{2434}\hadithtrans{This hadith has been narrated on the authority of Zuhri with the same chain of transmitters}}
\hadithdefcmd{muslim}{2435}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنْ إِسْمَاعِيلَ بْنِ مُحَمَّدِ بْنِ سَعْدٍ، قَالَ سَمِعْتُ مُحَمَّدَ بْنَ سَعْدٍ، يُحَدِّثُ بِهَذَا الْحَدِيثِ - يَعْنِي حَدِيثَ الزُّهْرِيِّ الَّذِي ذَكَرْنَا - فَقَالَ فِي حَدِيثِهِ فَضَرَبَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ بَيْنَ عُنُقِي وَكَتِفِي ثُمَّ قَالَ ‏ "‏ أَقِتَالاً أَىْ سَعْدُ إِنِّي لأُعْطِي الرَّجُلَ ‏"‏ ‏.‏\hadithno{2435}\hadithtrans{This hadith has been narrated on the authority of Muhammad b. Sa'd through another chain of transmitters (and the words are):" The Messenger of Allah (ﷺ) struck between my neck and shoulder with his hand and said: Do you wrangle, O Sa'd, because I bestow (some gifts) upon a person?}}
\hadithdefcmd{muslim}{2436}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ أُنَاسًا، مِنَ الأَنْصَارِ قَالُوا يَوْمَ حُنَيْنٍ حِينَ أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مِنْ أَمْوَالِ هَوَازِنَ مَا أَفَاءَ فَطَفِقَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعْطِي رِجَالاً مِنْ قُرَيْشٍ الْمِائَةَ مِنَ الإِبِلِ فَقَالُوا يَغْفِرُ اللَّهُ لِرَسُولِ اللَّهِ يُعْطِي قُرَيْشًا وَيَتْرُكُنَا وَسُيُوفُنَا تَقْطُرُ مِنْ دِمَائِهِمْ ‏.‏ قَالَ أَنَسُ بْنُ مَالِكٍ فَحُدِّثَ ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ قَوْلِهِمْ فَأَرْسَلَ إِلَى الأَنْصَارِ فَجَمَعَهُمْ فِي قُبَّةٍ مِنْ أَدَمٍ فَلَمَّا اجْتَمَعُوا جَاءَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا حَدِيثٌ بَلَغَنِي عَنْكُمْ ‏"‏ ‏.‏ فَقَالَ لَهُ فُقَهَاءُ الأَنْصَارِ أَمَّا ذَوُو رَأْيِنَا يَا رَسُولَ اللَّهِ فَلَمْ يَقُولُوا شَيْئًا وَأَمَّا أُنَاسٌ مِنَّا حَدِيثَةٌ أَسْنَانُهُمْ قَالُوا يَغْفِرُ اللَّهُ لِرَسُولِهِ يُعْطِي قُرَيْشًا وَيَتْرُكُنَا وَسُيُوفُنَا تَقْطُرُ مِنْ دِمَائِهِمْ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِنِّي أُعْطِي رِجَالاً حَدِيثِي عَهْدٍ بِكُفْرٍ أَتَأَلَّفُهُمْ أَفَلاَ تَرْضَوْنَ أَنْ يَذْهَبَ النَّاسُ بِالأَمْوَالِ وَتَرْجِعُونَ إِلَى رِحَالِكُمْ بِرَسُولِ اللَّهِ فَوَاللَّهِ لَمَا تَنْقَلِبُونَ بِهِ خَيْرٌ مِمَّا يَنْقَلِبُونَ بِهِ ‏"‏ ‏.‏ فَقَالُوا بَلَى يَا رَسُولَ اللَّهِ قَدْ رَضِينَا ‏.‏ قَالَ ‏"‏ فَإِنَّكُمْ سَتَجِدُونَ أَثَرَةً شَدِيدَةً فَاصْبِرُوا حَتَّى تَلْقَوُا اللَّهَ وَرَسُولَهُ فَإِنِّي عَلَى الْحَوْضِ ‏"‏ ‏.‏ قَالُوا سَنَصْبِرُ ‏.‏\hadithno{2436}\hadithtrans{Anas b. Malik reported that when on the Day of Hunain Allah conferred upon His Apostle (ﷺ) the riches of Hawazin (without armed encounter), the Messenger of Allah (ﷺ) set about distributing to some persons of Quraish one hundred camels Upon this they (the young people from the Ansar) said:May Allah grant pardon to the Messenger of Allah (ﷺ) that he bestowed (these camels) upon the people of Quraish, and he ignored us, whereas our swords are still dripping blood. Anas b. Malik said: Their statement was conveyed to the Messenger of Allah (ﷺ) and he sent (someone) to the Ansar and gathered them under a tent of leather. When they had assembled, the Messenger of Allah (ﷺ) came to them and said: What is this news that has reached me from you? The wise people of the Ansar said: Messenger of Allah, so far as the sagacious amongst us are concerned they have said nothing, but we have amongst us persons of immature age; they said: May Allah grant pardon to the Messenger of Allah (ﷺ) that he gave to the Quraish and ignored us (despite the fact) that our swords are besmeared with their blood. Upon this the Messenger of Allah (ﷺ) said: I give (at times material gifts) to persons who were quite recently in the state of unbelief, so that I may incline them to truth Don't you feel delighted that people should go with riches, and you should go back to your places with the Messenger of Allah? By Allah, that with which you would return is better than that with which they would return. They said: Yes, Messenger of Allah, we are pleased. The Prophet said too: You would find marked preference (in conferring of the material gifts) in future, so you should show patience till you meet Allah and His Messenger and I would he at the Haud Kauthar. They said: We would show patience}}
\hadithdefcmd{muslim}{2437}{حَدَّثَنَا حَسَنٌ الْحُلْوَانِيُّ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ - حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّهُ قَالَ لَمَّا أَفَاءَ اللَّهُ عَلَى رَسُولِهِ مَا أَفَاءَ مِنْ أَمْوَالِ هَوَازِنَ ‏.‏ وَاقْتَصَّ الْحَدِيثَ بِمِثْلِهِ غَيْرَ أَنَّهُ قَالَ قَالَ أَنَسٌ فَلَمْ نَصْبِرْ ‏.‏ وَقَالَ فَأَمَّا أُنَاسٌ حَدِيثَةٌ أَسْنَانُهُمْ ‏.‏\hadithno{2437}\hadithtrans{Anas b. Malik reported that when Allah conferred upon His Messenger (ﷺ) the riches of Hawazin (without armed encounter) ; the rest of the hadith is the same except some variation (of words):" Anas said: We could not tolerate it and he also said: The people were immature in age}}
\hadithdefcmd{muslim}{2438}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا ابْنُ أَخِي ابْنِ شِهَابٍ، عَنْ عَمِّهِ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، ‏.‏ وَسَاقَ الْحَدِيثَ بِمِثْلِهِ ‏.‏ إِلاَّ أَنَّهُ قَالَ قَالَ أَنَسٌ قَالُوا نَصْبِرُ ‏.‏ كَرِوَايَةِ يُونُسَ عَنِ الزُّهْرِيِّ ‏.‏\hadithno{2438}\hadithtrans{This hadith has been narrated on the authority of Anas b. Malik through another chain of transmitters}}
\hadithdefcmd{muslim}{2439}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ جَمَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم الأَنْصَارَ فَقَالَ ‏"‏ أَفِيكُمْ أَحَدٌ مِنْ غَيْرِكُمْ ‏"‏ ‏.‏ فَقَالُوا لاَ إِلاَّ ابْنُ أُخْتٍ لَنَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ ابْنَ أُخْتِ الْقَوْمِ مِنْهُمْ ‏"‏ ‏.‏ فَقَالَ ‏"‏ إِنَّ قُرَيْشًا حَدِيثُ عَهْدٍ بِجَاهِلِيَّةٍ وَمُصِيبَةٍ وَإِنِّي أَرَدْتُ أَنْ أَجْبُرَهُمْ وَأَتَأَلَّفَهُمْ أَمَا تَرْضَوْنَ أَنْ يَرْجِعَ النَّاسُ بِالدُّنْيَا وَتَرْجِعُونَ بِرَسُولِ اللَّهِ إِلَى بُيُوتِكُمْ لَوْ سَلَكَ النَّاسُ وَادِيًا وَسَلَكَ الأَنْصَارُ شِعْبًا لَسَلَكْتُ شِعْبَ الأَنْصَارِ ‏"‏ ‏.‏\hadithno{2439}\hadithtrans{Anas b. Malik reported that the Messenger of Allah (ﷺ) gathered the Ansar and said:Is there someone alien among you? They said: No, but only the son of our sister. Upon this the Messenger of Allah (ﷺ) said: The son of the sister of the people is included among the tribe, and (farther) said: The Quraish have recently abandoned Jahillyya and have just been delivered from distress; I, therefore, intend to help them and conciliate them. Don't you feel happy that the people should return with worldly riches and you return with the Messenger of Allah to your houses? (So far as my love for you is concerned I should say) if the people were to tread a valley and the Ansar tread a narraw path (in a mountain) I would tread the narrow path of the Ansar}}
\hadithdefcmd{muslim}{2440}{حَدَّثَنَا مُحَمَّدُ بْنُ الْوَلِيدِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، قَالَ لَمَّا فُتِحَتْ مَكَّةُ قَسَمَ الْغَنَائِمَ فِي قُرَيْشٍ فَقَالَتِ الأَنْصَارُ إِنَّ هَذَا لَهُوَ الْعَجَبُ إِنَّ سُيُوفَنَا تَقْطُرُ مِنْ دِمَائِهِمْ وَإِنَّ غَنَائِمَنَا تُرَدُّ عَلَيْهِمْ ‏.‏ فَبَلَغَ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَجَمَعَهُمْ فَقَالَ ‏"‏ مَا الَّذِي بَلَغَنِي عَنْكُمْ ‏"‏ ‏.‏ قَالُوا هُوَ الَّذِي بَلَغَكَ ‏.‏ وَكَانُوا لاَ يَكْذِبُونَ ‏.‏ قَالَ ‏"‏ أَمَا تَرْضَوْنَ أَنْ يَرْجِعَ النَّاسُ بِالدُّنْيَا إِلَى بُيُوتِهِمْ وَتَرْجِعُونَ بِرَسُولِ اللَّهِ إِلَى بُيُوتِكُمْ لَوْ سَلَكَ النَّاسُ وَادِيًا أَوْ شِعْبًا وَسَلَكَتِ الأَنْصَارُ وَادِيًا أَوْ شِعْبًا لَسَلَكْتُ وَادِيَ الأَنْصَارِ أَوْ شِعْبَ الأَنْصَارِ ‏"‏ ‏.‏\hadithno{2440}\hadithtrans{Anas b. Malik reported:When Mecca was conquered, he (the Holy Prophet) distributed the spoils among the Quraish. Upon this the Ansar said: It is strange that our swords are dripping with their blood, whereas our spoils have been given to them (to the Quraish). This (remark) reached the Messenger of Allah (ﷺ), and so he gathered them and said: What is this that has been conveyed to me about you? They said: (Yes) it is that very thing that, has reached you and they were not (the people) to speak a lie. Upon this he said: Don't you like that the people should return to their houses along with worldly riches, whereas you should return to your houses with the Messenger of Allah? If the people were to tread a valley or a narrow path, and the Ansar were also to tread a valley or a narrow path, I would tread the valley (along with the) Ansar or the narrow path (along with the) Ansar}}
\hadithdefcmd{muslim}{2441}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَإِبْرَاهِيمُ بْنُ مُحَمَّدِ بْنِ عَرْعَرَةَ، - يَزِيدُ أَحَدُهُمَا عَلَى الآخَرِ الْحَرْفَ بَعْدَ الْحَرْفِ - قَالاَ حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ حَدَّثَنَا ابْنُ عَوْنٍ عَنْ هِشَامِ بْنِ زَيْدِ بْنِ أَنَسٍ عَنْ أَنَسِ بْنِ مَالِكٍ قَالَ لَمَّا كَانَ يَوْمُ حُنَيْنٍ أَقْبَلَتْ هَوَازِنُ وَغَطَفَانُ وَغَيْرُهُمْ بِذَرَارِيِّهِمْ وَنَعَمِهِمْ وَمَعَ النَّبِيِّ صلى الله عليه وسلم يَوْمَئِذٍ عَشَرَةُ آلاَفٍ وَمَعَهُ الطُّلَقَاءُ فَأَدْبَرُوا عَنْهُ حَتَّى بَقِيَ وَحْدَهُ - قَالَ - فَنَادَى يَوْمَئِذٍ نِدَاءَيْنِ لَمْ يَخْلِطْ بَيْنَهُمَا شَيْئًا - قَالَ - فَالْتَفَتَ عَنْ يَمِينِهِ فَقَالَ ‏"‏ يَا مَعْشَرَ الأَنْصَارِ ‏"‏ ‏.‏ فَقَالُوا لَبَّيْكَ يَا رَسُولَ اللَّهِ أَبْشِرْ نَحْنُ مَعَكَ - قَالَ - ثُمَّ الْتَفَتَ عَنْ يَسَارِهِ فَقَالَ ‏"‏ يَا مَعْشَرَ الأَنْصَارِ ‏"‏ ‏.‏ قَالُوا لَبَّيْكَ يَا رَسُولَ اللَّهِ أَبْشِرْ نَحْنُ مَعَكَ - قَالَ - وَهُوَ عَلَى بَغْلَةٍ بَيْضَاءَ فَنَزَلَ فَقَالَ أَنَا عَبْدُ اللَّهِ وَرَسُولُهُ ‏.‏ فَانْهَزَمَ الْمُشْرِكُونَ وَأَصَابَ رَسُولُ اللَّهِ صلى الله عليه وسلم غَنَائِمَ كَثِيرَةً فَقَسَمَ فِي الْمُهَاجِرِينَ وَالطُّلَقَاءِ وَلَمْ يُعْطِ الأَنْصَارَ شَيْئًا فَقَالَتِ الأَنْصَارُ إِذَا كَانَتِ الشِّدَّةُ فَنَحْنُ نُدْعَى وَتُعْطَى الْغَنَائِمُ غَيْرَنَا ‏.‏ فَبَلَغَهُ ذَلِكَ فَجَمَعَهُمْ فِي قُبَّةٍ فَقَالَ ‏"‏ يَا مَعْشَرَ الأَنْصَارِ مَا حَدِيثٌ بَلَغَنِي عَنْكُمْ ‏"‏ ‏.‏ فَسَكَتُوا فَقَالَ ‏"‏ يَا مَعْشَرَ الأَنْصَارِ أَمَا تَرْضَوْنَ أَنْ يَذْهَبَ النَّاسُ بِالدُّنْيَا وَتَذْهَبُونَ بِمُحَمَّدٍ تَحُوزُونَهُ إِلَى بُيُوتِكُمْ ‏"‏ ‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ رَضِينَا ‏.‏ قَالَ فَقَالَ ‏"‏ لَوْ سَلَكَ النَّاسُ وَادِيًا وَسَلَكَتِ الأَنْصَارُ شِعْبًا لأَخَذْتُ شِعْبَ الأَنْصَارِ ‏"‏ ‏.‏ قَالَ هِشَامٌ فَقُلْتُ يَا أَبَا حَمْزَةَ أَنْتَ شَاهِدٌ ذَاكَ قَالَ وَأَيْنَ أَغِيبُ عَنْهُ\hadithno{2441}\hadithtrans{Anas b. Malik reported that when it was the Day of Hunain there came the tribes of Hawazin, Ghatafan and others along with their children and animals, and there were with the Messenger of Allah (ﷺ) that day ten thousand (soldiers), and newly freed men (of Mecca after its conquest). All these men (once) turned their backs, till he (the Holy Prophet) was left alone. He (the Messenger of Allah) on that day called twice and he did not interpose anything between these two (announcements). He turned towards his right and said:O people of Ansar! They said: At thy beck and call (are we), Messenger of Allah. Be glad we are with thee. He then turned towards his left and said: O people of Ansar. They said: At thy beck and call (are we). Be glad we are with thee. He (the Holy Prophet) was riding a white mule. He dismounted and said: I am the servant of Allah and His Apostle. The polytheists suffered defeat and the Messenger of Allah (may peace he upon him) acquired a large quantity of spoils, and he distributed them among the refugees and the people recently delivered (of Mecca) but did not give anything to the Ansar. The Ansar said: In the hour of distress it is we who are called (for help). but the spoils are given to other people besides us. This (remark) reached him (the Holy Prophet). and he gathered them In a tent. and said: What is this news that has reached me on your behalf? They kept silence. Upon this he said: O people of Ansar, don't you like that people should go away with worldly (riches), and you go away with Muhammad taking him to your houses? They said: Yes, happy we are. Messenger of Allah. He (the Holy Prophet) said: If the people were to tread a valley, and the Ansar were to tread a narrow path, I would take the narrow path of the Ansar. Hisham said: I asked Abu Hamza if he was present there. He said: How could I be absent from him?}}
\hadithdefcmd{muslim}{2442}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، وَحَامِدُ بْنُ عُمَرَ، وَمُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، قَالَ ابْنُ مُعَاذٍ حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، عَنْ أَبِيهِ، قَالَ حَدَّثَنِي السُّمَيْطُ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ افْتَتَحْنَا مَكَّةَ ثُمَّ إِنَّا غَزَوْنَا حُنَيْنًا فَجَاءَ الْمُشْرِكُونَ بِأَحْسَنِ صُفُوفٍ رَأَيْتُ - قَالَ - فَصُفَّتِ الْخَيْلُ ثُمَّ صُفَّتِ الْمُقَاتِلَةُ ثُمَّ صُفَّتِ النِّسَاءُ مِنْ وَرَاءِ ذَلِكَ ثُمَّ صُفَّتِ الْغَنَمُ ثُمَّ صُفَّتِ النَّعَمُ - قَالَ - وَنَحْنُ بَشَرٌ كَثِيرٌ قَدْ بَلَغْنَا سِتَّةَ آلاَفٍ وَعَلَى مُجَنِّبَةِ خَيْلِنَا خَالِدُ بْنُ الْوَلِيدِ - قَالَ - فَجَعَلَتْ خَيْلُنَا تَلْوِي خَلْفَ ظُهُورِنَا فَلَمْ نَلْبَثْ أَنِ انْكَشَفَتْ خَيْلُنَا وَفَرَّتِ الأَعْرَابُ وَمَنْ نَعْلَمُ مِنَ النَّاسِ - قَالَ - فَنَادَى رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا لَلْمُهَاجِرِينَ يَا لَلْمُهَاجِرِينَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ يَا لَلأَنْصَارِ يَا لَلأَنْصَارِ ‏"‏ ‏.‏ قَالَ قَالَ أَنَسٌ هَذَا حَدِيثُ عِمِّيَّةٍ ‏.‏ قَالَ قُلْنَا لَبَّيْكَ يَا رَسُولَ اللَّهِ - قَالَ - فَتَقَدَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم - قَالَ - فَايْمُ اللَّهِ مَا أَتَيْنَاهُمْ حَتَّى هَزَمَهُمُ اللَّهُ - قَالَ - فَقَبَضْنَا ذَلِكَ الْمَالَ ثُمَّ انْطَلَقْنَا إِلَى الطَّائِفِ فَحَاصَرْنَاهُمْ أَرْبَعِينَ لَيْلَةً ثُمَّ رَجَعْنَا إِلَى مَكَّةَ فَنَزَلْنَا - قَالَ - فَجَعَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُعْطِي الرَّجُلَ الْمِائَةَ مِنَ الإِبِلِ ‏.‏ ثُمَّ ذَكَرَ بَاقِيَ الْحَدِيثِ كَنَحْوِ حَدِيثِ قَتَادَةَ وَأَبِي التَّيَّاحِ وَهِشَامِ بْنِ زَيْدٍ ‏.‏\hadithno{2442}\hadithtrans{Anas b. Malik reported:We conquered Mecca and then we went on an expedition to Hunain. The polytheists came, forming themselves into the best rows that I have seen. They first formed the rows of cavalry, then those of infantry, and then those of women behind them. Then there were formed the rows of sheep and goats and then of other animals. We were also people large in number, and our (number) had reached six thousand. And on one side Khalid b. Walid was in charge of the cavalry. And our horses at once turned back from our rear. And we could hardly hold our own when our horses were exposed, and the bedouins and the people whom we knew took to their heels. (Seeing this) the Messenger of Allah (ﷺ) called thus: O emigrants, O emigrants. He then. said: O Ansar, O Ansar. (Anas said: This hadith is transmitted by a group of eminent persons.) We said: At thy beck and call are we, Messenger of Allah. The Messenger of Allah (ﷺ) then advanced and he (Anas) said: By Allah, we had not yet reached them when Allah defeated them. and we took possession of the wealth and we then marched towards Ta'if, and we besieged them for forty nights. and then came back to Mecca and encamped (at a place), and the Messenger of Allah (ﷺ) began to bestow a hundred camels upon each individual. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{2443}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عُمَرَ الْمَكِّيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عُمَرَ بْنِ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ أَبِيهِ، عَنْ عَبَايَةَ بْنِ رِفَاعَةَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، قَالَ أَعْطَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَبَا سُفْيَانَ بْنَ حَرْبٍ وَصَفْوَانَ بْنَ أُمَيَّةَ وَعُيَيْنَةَ بْنَ حِصْنٍ وَالأَقْرَعَ بْنَ حَابِسٍ كُلَّ إِنْسَانٍ مِنْهُمْ مِائَةً مِنَ الإِبِلِ وَأَعْطَى عَبَّاسَ بْنَ مِرْدَاسٍ دُونَ ذَلِكَ ‏.‏ فَقَالَ عَبَّاسُ بْنُ مِرْدَاسٍ أَتَجْعَلُ نَهْبِي وَنَهْبَ الْعُبَيْدِ بَيْنَ عُيَيْنَةَ وَالأَقْرَعِ فَمَا كَانَ بَدْرٌ وَلاَ حَابِسٌ يَفُوقَانِ مِرْدَاسَ فِي الْمَجْمَعِ وَمَا كُنْتُ دُونَ امْرِئٍ مِنْهُمَا وَمَنْ تَخْفِضِ الْيَوْمَ لاَ يُرْفَعِ قَالَ فَأَتَمَّ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِائَةً ‏.‏\hadithno{2443}\hadithtrans{Rafi' b. Khadij reported that the Messenger of Allah; (ﷺ) gave to Abu Sufyan b. Harb and Safwan. b. Umayya and 'Uyaina b. Hisn and Aqra' b. Habis, i.e. to every one of these persons, one hundred camels, and gave to 'Abbas b. Mirdas less than this number. Upon this 'Abbas b. Mirdis said:You allot the share of my booty and that of my horse between 'Uyaina and Aqra'. Both Uyaina and Aqra' are in no way more eminent than Mirdas (my father) in the assembly. I am in no way inferior to any one of these persons. And he who is let down today would not be elevated. He (the narrator) said: The Messenger of Allah (ﷺ) then completed one hundred camels for him}}
\hadithdefcmd{muslim}{2444}{وَحَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، عَنْ عُمَرَ بْنِ سَعِيدِ بْنِ مَسْرُوقٍ، بِهَذَا الإِسْنَادِ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَسَمَ غَنَائِمَ حُنَيْنٍ فَأَعْطَى أَبَا سُفْيَانَ بْنَ حَرْبٍ مِائَةً مِنَ الإِبِلِ ‏.‏ وَسَاقَ الْحَدِيثَ بِنَحْوِهِ وَزَادَ وَأَعْطَى عَلْقَمَةَ بْنَ عُلاَثَةَ مِائَةً ‏.‏\hadithno{2444}\hadithtrans{This hadith has been narrated by Sa'id b. Masruq with the same chain of transmitters (with the words):" The Apostle of Allah (ﷺ) distributed the spoils of Hunain, and he (the Holy Prophet) gave one hundred camels to Abu Sufyan b. Harb. The rest of the hadith is the same, but with this addition:" He bestowed upon" Alqama b. 'Ulatha one hundred (camels)}}
\hadithdefcmd{muslim}{2445}{وَحَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ الشَّعِيرِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنِي عُمَرُ بْنُ سَعِيدٍ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ فِي الْحَدِيثِ عَلْقَمَةَ بْنَ عُلاَثَةَ وَلاَ صَفْوَانَ بْنَ أُمَيَّةَ وَلَمْ يَذْكُرِ الشِّعْرَ فِي حَدِيثِهِ‏.‏\hadithno{2445}\hadithtrans{This hadith has been narrated by Sa'id with the same chain of transmitters, but no mention has been made of Alqama b. 'Ulatha, nor of safwin b. Umayya, and he did not mention the verse in his hadith}}
\hadithdefcmd{muslim}{2446}{حَدَّثَنَا سُرَيْجُ بْنُ يُونُسَ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَمْرِو بْنِ يَحْيَى بْنِ عُمَارَةَ، عَنْ عَبَّادِ بْنِ تَمِيمٍ، عَنْ عَبْدِ اللَّهِ بْنِ زَيْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا فَتَحَ حُنَيْنًا قَسَمَ الْغَنَائِمَ فَأَعْطَى الْمُؤَلَّفَةَ قُلُوبُهُمْ فَبَلَغَهُ أَنَّ الأَنْصَارَ يُحِبُّونَ أَنْ يُصِيبُوا مَا أَصَابَ النَّاسُ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَخَطَبَهُمْ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ يَا مَعْشَرَ الأَنْصَارِ أَلَمْ أَجِدْكُمْ ضُلاَّلاً فَهَدَاكُمُ اللَّهُ بِي وَعَالَةً فَأَغْنَاكُمُ اللَّهُ بِي وَمُتَفَرِّقِينَ فَجَمَعَكُمُ اللَّهُ بِي ‏"‏ ‏.‏ وَيَقُولُونَ اللَّهُ وَرَسُولُهُ أَمَنُّ ‏.‏ فَقَالَ ‏"‏ أَلاَ تُجِيبُونِي ‏"‏ ‏.‏ فَقَالُوا اللَّهُ وَرَسُولُهُ أَمَنُّ ‏.‏ فَقَالَ ‏"‏ أَمَا إِنَّكُمْ لَوْ شِئْتُمْ أَنْ تَقُولُوا كَذَا وَكَذَا وَكَانَ مِنَ الأَمْرِ كَذَا وَكَذَا ‏"‏ ‏.‏ لأَشْيَاءَ عَدَّدَهَا ‏.‏ زَعَمَ عَمْرٌو أَنْ لاَ يَحْفَظُهَا فَقَالَ ‏"‏ أَلاَ تَرْضَوْنَ أَنْ يَذْهَبَ النَّاسُ بِالشَّاءِ وَالإِبِلِ وَتَذْهَبُونَ بِرَسُولِ اللَّهِ إِلَى رِحَالِكُمُ الأَنْصَارُ شِعَارٌ وَالنَّاسُ دِثَارٌ وَلَوْلاَ الْهِجْرَةُ لَكُنْتُ امْرَأً مِنَ الأَنْصَارِ وَلَوْ سَلَكَ النَّاسُ وَادِيًا وَشِعْبًا لَسَلَكْتُ وَادِيَ الأَنْصَارِ وَشِعْبَهُمْ إِنَّكُمْ سَتَلْقَوْنَ بَعْدِي أَثَرَةً فَاصْبِرُوا حَتَّى تَلْقَوْنِي عَلَى الْحَوْضِ ‏"‏ ‏.‏\hadithno{2446}\hadithtrans{Abdullah b. Zaid reported that when the Messenger of Allah (ﷺ) conquered Hunain he distributed the booty, and he bestowed upon those whose hearts it was intended to win. It was conveyed to him (the Holy Prophet) that the Ansar cherished a desire that they should be given (that very portion) which the people (of Quraish) had got. Upon this the Messenger of Allah (ﷺ) stood up and, after having praised Allah and lauded Him, addressed them thus:O people of Ansar, did I not find you erring and Allah guided you aright through me, and (in the state of) being destitute and Allah made you free from want through me, and in a state of disunity and Allah united you through me, and they (the Ansar) said: Allah and His Messenger are most benevolent. He (again) said: Why do you not answer me? They said: Allah and His Messenger are the most benevolent. He said, If you wish you should say so and so, and the event (should take) such and such course (and in this connection he made a mention) of so many things. 'Amr is under the impression that he has not been able to remember them. He (the Holy Prophet) further said: Don't you feel happy (over this state of affairs) that the people should go away with goats and camels, and you go to your places along with the Messenger of Allah? The Ansar are inner garments (more close to me) and (other) people are outer garments. Had there not been migration, I would have been a man from among the Ansar. If the people were to tread a valley or a narrow path, I would tread the valley (chosen) by the Ansar or narrow path (trodden) by them. And you would soon find after me preferences (over you in getting material benefits). So you should show patience till you meet me at the Haud (Kauthar)}}
\hadithdefcmd{muslim}{2447}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ لَمَّا كَانَ يَوْمُ حُنَيْنٍ آثَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم نَاسًا فِي الْقِسْمَةِ فَأَعْطَى الأَقْرَعَ بْنَ حَابِسٍ مِائَةً مِنَ الإِبِلِ وَأَعْطَى عُيَيْنَةَ مِثْلَ ذَلِكَ وَأَعْطَى أُنَاسًا مِنْ أَشْرَافِ الْعَرَبِ وَآثَرَهُمْ يَوْمَئِذٍ فِي الْقِسْمَةِ فَقَالَ رَجُلٌ وَاللَّهِ إِنَّ هَذِهِ لَقِسْمَةٌ مَا عُدِلَ فِيهَا وَمَا أُرِيدَ فِيهَا وَجْهُ اللَّهِ ‏.‏ قَالَ فَقُلْتُ وَاللَّهِ لأُخْبِرَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم - قَالَ - فَأَتَيْتُهُ فَأَخْبَرْتُهُ بِمَا قَالَ - قَالَ - فَتَغَيَّرَ وَجْهُهُ حَتَّى كَانَ كَالصِّرْفِ ثُمَّ قَالَ ‏"‏ فَمَنْ يَعْدِلُ إِنْ لَمْ يَعْدِلِ اللَّهُ وَرَسُولُهُ ‏"‏ ‏.‏ قَالَ ثُمَّ قَالَ ‏"‏ يَرْحَمُ اللَّهُ مُوسَى قَدْ أُوذِيَ بِأَكْثَرَ مِنْ هَذَا فَصَبَرَ ‏"‏ ‏.‏ قَالَ قُلْتُ لاَ جَرَمَ لاَ أَرْفَعُ إِلَيْهِ بَعْدَهَا حَدِيثًا ‏.‏\hadithno{2447}\hadithtrans{Abdullah reported:On the day of Hunain, the Messenger of Allah (ﷺ) showed preference (to some) people in the distribution of the spoils. He bestowed on Aqra' b. Habis one hundred camels, and bestowed an equal (number) upon 'Uyaina, and bestowed on people among the elites of Arabia, and preferred them (to others) on that day, in the distribution (of spoils). Upon this a person said: By Allah, neither justice has been done in this distribution (of spoils), nor has the pleasure of Allah been sought in it. I (the narrator ) said: By Allah, I will certainly inform the Messenger of Allah (ﷺ) about it. I came to him and informed him about what he had said. The colour of his (the Prophet's) face changed red like blood and he then said: "Who would do justice, if Allah and His Messenger do not do justice?" He further said: "May Allah have mercy upon Moses; he was tormented more than this, but he showed patience." I said: Never would I convey him (the Holy Prophet) after this (unpleasant) narration}}
\hadithdefcmd{muslim}{2448}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَسَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَسْمًا فَقَالَ رَجُلٌ إِنَّهَا لَقِسْمَةٌ مَا أُرِيدَ بِهَا وَجْهُ اللَّهِ - قَالَ - فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَسَارَرْتُهُ فَغَضِبَ مِنْ ذَلِكَ غَضَبًا شَدِيدًا وَاحْمَرَّ وَجْهُهُ حَتَّى تَمَنَّيْتُ أَنِّي لَمْ أَذْكُرْهُ لَهُ - قَالَ - ثُمَّ قَالَ ‏ "‏ قَدْ أُوذِيَ مُوسَى بِأَكْثَرَ مِنْ هَذَا فَصَبَرَ ‏"‏ ‏.‏\hadithno{2448}\hadithtrans{Abdullah reported:The Messenger of Allah (ﷺ) distributed spoils (of war). Upon this a person said: This is a distribution In which the pleasure of Allah has not been sought. I came to the Messenger of Allah (ﷺ) and informed him in an undertone. He (the Holy Prophet) was deeply angry at this and his face became red till I wished that I had not made a mention of it to him. He (the Holy Prophet) then said: Moses was tormented more than this, but he showed patience}}
\hadithdefcmd{muslim}{2449}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحِ بْنِ الْمُهَاجِرِ، أَخْبَرَنَا اللَّيْثُ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي، الزُّبَيْرِ عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ أَتَى رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم بِالْجِعْرَانَةِ مُنْصَرَفَهُ مِنْ حُنَيْنٍ وَفِي ثَوْبِ بِلاَلٍ فِضَّةٌ وَرَسُولُ اللَّهِ صلى الله عليه وسلم يَقْبِضُ مِنْهَا يُعْطِي النَّاسَ فَقَالَ يَا مُحَمَّدُ اعْدِلْ ‏.‏ قَالَ ‏"‏ وَيْلَكَ وَمَنْ يَعْدِلُ إِذَا لَمْ أَكُنْ أَعْدِلُ لَقَدْ خِبْتَ وَخَسِرْتَ إِنْ لَمْ أَكُنْ أَعْدِلُ ‏"‏ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ رضى الله عنه دَعْنِي يَا رَسُولَ اللَّهِ فَأَقْتُلَ هَذَا الْمُنَافِقَ ‏.‏ فَقَالَ ‏"‏ مَعَاذَ اللَّهِ أَنْ يَتَحَدَّثَ النَّاسُ أَنِّي أَقْتُلُ أَصْحَابِي إِنَّ هَذَا وَأَصْحَابَهُ يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ حَنَاجِرَهُمْ يَمْرُقُونَ مِنْهُ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ ‏"‏ ‏.‏\hadithno{2449}\hadithtrans{Jabir b. Abdullah reported that a person came to the Messenger of Allah (ﷺ) at Jirana on his way back from Hunain, and there was in the clothes of Bilal some silver. The Messenger of Allah (ﷺ) took a handful out of that and bestowed it upon the people. He (the person who had met the Prophet at Ji'rana) said to him:Muhammad, do justice. He (the Holy Prophet) said: Woe be upon thee, who would do justice if I do not do justice, and you would be very unfortunate and a loser if I do not do justice. Upon this Umar b. Khattab (Allah be pleased with him) said: Permit me to kill this hypocrite. Upon this he (the Holy Prophet) said: May there be protection of Allah! People would say that I kill my companions. This man and his companions would recite the Qur'an but it would not go beyond their throat, and they swerve from it just as the arrow goes through the prey}}
\hadithdefcmd{muslim}{2450}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، يَقُولُ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، ح. وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنِي قُرَّةُ بْنُ خَالِدٍ، حَدَّثَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْسِمُ مَغَانِمَ ‏.‏ وَسَاقَ الْحَدِيثَ ‏.‏\hadithno{2450}\hadithtrans{This hadith has been narrated on the authority of Jabir b. 'Abdullah through another chain of transmitters}}
\hadithdefcmd{muslim}{2451}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ أَبِي نُعْمٍ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ بَعَثَ عَلِيٌّ - رضى الله عنه - وَهُوَ بِالْيَمَنِ بِذَهَبَةٍ فِي تُرْبَتِهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَسَمَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَرْبَعَةِ نَفَرٍ الأَقْرَعُ بْنُ حَابِسٍ الْحَنْظَلِيُّ وَعُيَيْنَةُ بْنُ بَدْرٍ الْفَزَارِيُّ وَعَلْقَمَةُ بْنُ عُلاَثَةَ الْعَامِرِيُّ ثُمَّ أَحَدُ بَنِي كِلاَبٍ وَزَيْدُ الْخَيْرِ الطَّائِيُّ ثُمَّ أَحَدُ بَنِي نَبْهَانَ - قَالَ - فَغَضِبَتْ قُرَيْشٌ فَقَالُوا أَتُعْطِي صَنَادِيدَ نَجْدٍ وَتَدَعُنَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي إِنَّمَا فَعَلْتُ ذَلِكَ لأَتَأَلَّفَهُمْ ‏"‏ فَجَاءَ رَجُلٌ كَثُّ اللِّحْيَةِ مُشْرِفُ الْوَجْنَتَيْنِ غَائِرُ الْعَيْنَيْنِ نَاتِئُ الْجَبِينِ مَحْلُوقُ الرَّأْسِ فَقَالَ اتَّقِ اللَّهَ يَا مُحَمَّدُ ‏.‏ - قَالَ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَمَنْ يُطِعِ اللَّهَ إِنْ عَصَيْتُهُ أَيَأْمَنُنِي عَلَى أَهْلِ الأَرْضِ وَلاَ تَأْمَنُونِي ‏"‏ قَالَ ثُمَّ أَدْبَرَ الرَّجُلُ فَاسْتَأْذَنَ رَجُلٌ مِنَ الْقَوْمِ فِي قَتْلِهِ - يُرَوْنَ أَنَّهُ خَالِدُ بْنُ الْوَلِيدِ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ مِنْ ضِئْضِئِ هَذَا قَوْمًا يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ حَنَاجِرَهُمْ يَقْتُلُونَ أَهْلَ الإِسْلاَمِ وَيَدَعُونَ أَهْلَ الأَوْثَانِ يَمْرُقُونَ مِنَ الإِسْلاَمِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ لَئِنْ أَدْرَكْتُهُمْ لأَقْتُلَنَّهُمْ قَتْلَ عَادٍ ‏"‏ ‏.‏\hadithno{2451}\hadithtrans{Abu Said Khudri reported that 'Ali (Allah be pleased with him) sent some gold alloyed with dust to the Messenger of Allah (ﷺ), and the Messenger of Allah (ﷺ) distributed that among four men, al-Aqra b. Habis Hanzali and Uyaina b. Badr al-Fazari and 'Alqama b. 'Ulatha al-'Amiri, then to one person of the tribe of Kilab and to Zaid al-Khair al-Ta'l, and then to one person of the tribe of Nabhan. Upon this the people of Quraish felt angry and said:He (the Holy Prophet) gave to the chiefs of Najd and ignored us. Upon this the Messenger of Allah (ﷺ) said: I have done it with a view to conciliating between them. Then there came a person with thick beard, prominent cheeks, deep sunken eyes and protruding forehead and shaven head. He said: Muhammad, fear Allah. Upon this the Messenger of Allah (ﷺ) said: "If I disobey Allah, who would then obey Him? Have I not been (sent as the) most trustworthy among the people of the world? But you do not repose trust in me." That person then went back. A person among the people then sought permission (from the Holy Prophet) for his murder. According to some, it was Khalid b. Walid who sought the permission. Upon this the Messenger of Allah (ﷺ), said: From this very person's posterity there would arise people who would recite the Qur'an, but it would not go beyond their throat; they would kill the followers of Islam and would spare the idol-worshippers. They would glance through the teachings of Islam so hurriedly just as the arrow passes through the pray. If I were to ever find them I would kill them like 'Ad}}
\hadithdefcmd{muslim}{2452}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، حَدَّثَنَا عَبْدُ، الرَّحْمَنِ بْنُ أَبِي نُعْمٍ قَالَ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ بَعَثَ عَلِيُّ بْنُ أَبِي طَالِبٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْيَمَنِ بِذَهَبَةٍ فِي أَدِيمٍ مَقْرُوظٍ لَمْ تُحَصَّلْ مِنْ تُرَابِهَا - قَالَ - فَقَسَمَهَا بَيْنَ أَرْبَعَةِ نَفَرٍ بَيْنَ عُيَيْنَةَ بْنِ حِصْنٍ وَالأَقْرَعِ بْنِ حَابِسٍ وَزَيْدِ الْخَيْلِ وَالرَّابِعُ إِمَّا عَلْقَمَةُ بْنُ عُلاَثَةَ وَإِمَّا عَامِرُ بْنُ الطُّفَيْلِ فَقَالَ رَجُلٌ مِنْ أَصْحَابِهِ كُنَّا نَحْنُ أَحَقَّ بِهَذَا مِنْ هَؤُلاَءِ - قَالَ - فَبَلَغَ ذَلِكَ النَّبِيَّ صلى الله عليه وسلم ‏.‏ فَقَالَ ‏"‏ أَلاَ تَأْمَنُونِي وَأَنَا أَمِينُ مَنْ فِي السَّمَاءِ يَأْتِينِي خَبَرُ السَّمَاءِ صَبَاحًا وَمَسَاءً ‏"‏ ‏.‏ قَالَ فَقَامَ رَجُلٌ غَائِرُ الْعَيْنَيْنِ مُشْرِفُ الْوَجْنَتَيْنِ نَاشِزُ الْجَبْهَةِ كَثُّ اللِّحْيَةِ مَحْلُوقُ الرَّأْسِ مُشَمَّرُ الإِزَارِ فَقَالَ يَا رَسُولَ اللَّهِ اتَّقِ اللَّهَ ‏.‏ فَقَالَ ‏"‏ وَيْلَكَ أَوَلَسْتُ أَحَقَّ أَهْلِ الأَرْضِ أَنْ يَتَّقِيَ اللَّهَ ‏"‏ ‏.‏ قَالَ ثُمَّ وَلَّى الرَّجُلُ فَقَالَ خَالِدُ بْنُ الْوَلِيدِ يَا رَسُولَ اللَّهِ أَلاَ أَضْرِبُ عُنُقَهُ فَقَالَ ‏"‏ لاَ لَعَلَّهُ أَنْ يَكُونَ يُصَلِّي ‏"‏ ‏.‏ قَالَ خَالِدٌ وَكَمْ مِنْ مُصَلٍّ يَقُولُ بِلِسَانِهِ مَا لَيْسَ فِي قَلْبِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنِّي لَمْ أُومَرْ أَنْ أَنْقُبَ عَنْ قُلُوبِ النَّاسِ وَلاَ أَشُقَّ بُطُونَهُمْ ‏"‏ ‏.‏ قَالَ ثُمَّ نَظَرَ إِلَيْهِ وَهُوَ مُقَفٍّ فَقَالَ ‏"‏ إِنَّهُ يَخْرُجُ مِنْ ضِئْضِئِ هَذَا قَوْمٌ يَتْلُونَ كِتَابَ اللَّهِ رَطْبًا لاَ يُجَاوِزُ حَنَاجِرَهُمْ يَمْرُقُونَ مِنَ الدِّينِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ - قَالَ أَظُنُّهُ قَالَ - لَئِنْ أَدْرَكْتُهُمْ لأَقْتُلَنَّهُمْ قَتْلَ ثَمُودَ ‏"‏ ‏.‏\hadithno{2452}\hadithtrans{Abu Said al-Khudri reported:'Ali b. Abu Talib sent to the Messenger of Allah (ﷺ) from Yemen some gold alloyed with clay in a leather bag dyed in the leaves of Mimosa flava. He distributed it among four men. 'Uyaina b. Hisna, Aqra' b. Habis and Zaid al-Khail, and the fourth one was either Alqama b. 'Ulatha or 'Amir b. Tufail. A person from among his (Prophet's) Companions said: We had a better claim to this (wealth) than these (persons). This (remark) reached the Messenger of Allah (ﷺ) upon which he said: Will you not trust me, whereas I am a trustee of Him Who is in the heaven? The news come to me from the heaven morning and evening. Then there stood up a person with deep sunken eyes, prominent cheek bones, and elevated forehead, thick beard, shaven head, tucked up loincloth, and he said: Messenger of Allah, fear Allah. He (the Holy Prophet) said: Woe to thee. Do I not deserve most to fear Allah amongst the people of the earth? That man then returned. Khalid b. Walid then said: Messenger of Allah, should I not strike his neck? Upon this he (the Holy Prophet) said: Perhaps he may be observing the prayer. Khalid said: How many observers of prayer are there who profess with their tongue what is not in their heart? Upon this the Messenger of Allah (ﷺ) said: I have not been commanded to pierce through the hearts of people, nor to split their bellies (insides). He again looked at him and he was going back. Upon this he (the Holy Prophet) said: There would arise a people from the progeny of this (man) who would recite the Qur'an glibly, but it would not go beyond their throats; they would (hurriedly) pass through (the teachings of their) religion just as the arrow passes through the prey. I conceive that he (the Holy Prophet) also said this: If I find them I would certainly kill them as were killed the (people of) Thamud}}
\hadithdefcmd{muslim}{2453}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، بِهَذَا الإِسْنَادِ قَالَ وَعَلْقَمَةُ بْنُ عُلاَثَةَ وَلَمْ يَذْكُرْ عَامِرَ بْنَ الطُّفَيْلِ وَقَالَ نَاتِئُ الْجَبْهَةِ وَلَمْ يَقُلْ نَاشِزُ ‏.‏ وَزَادَ فَقَامَ إِلَيْهِ عُمَرُ بْنُ الْخَطَّابِ - رضى الله عنه - فَقَالَ يَا رَسُولَ اللَّهِ أَلاَ أَضْرِبُ عُنُقَهُ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قَالَ ثُمَّ أَدْبَرَ فَقَامَ إِلَيْهِ خَالِدٌ سَيْفُ اللَّهِ فَقَالَ يَا رَسُولَ اللَّهِ أَلاَ أَضْرِبُ عُنُقَهُ قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ فَقَالَ ‏"‏ إِنَّهُ سَيَخْرُجُ مِنْ ضِئْضِئِ هَذَا قَوْمٌ يَتْلُونَ كِتَابَ اللَّهِ لَيِّنًا رَطْبًا - وَقَالَ قَالَ عُمَارَةُ حَسِبْتُهُ قَالَ ‏"‏ لَئِنْ أَدْرَكْتُهُمْ لأَقْتُلَنَّهُمْ قَتْلَ ثَمُودَ ‏"‏ ‏.‏\hadithno{2453}\hadithtrans{This hadith has been narrated through another chain of transmitters and (the narrator) made a mention of elevated forehead, but he made no mention of tucked-up loin cloth and made this addition:" There stood up 'Umar b. Khattab (Allah be pleased with him), and said: Should I not strike his neck? Upon this he said: No. Then he turned away, and Khalid the Sword of Allah stood up against him, and said: Prophet of Allah. shall I not strike off his neck? He said, No, and then said: A people would rise from his progeny who would recite the Book of Allah glibly and fluently. 'Umar said: I think he (the Holy Prophet) also said this: If I find them I would certainly kill them like Thamud}}
\hadithdefcmd{muslim}{2454}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، بِهَذَا الإِسْنَادِ وَقَالَ بَيْنَ أَرْبَعَةِ نَفَرٍ زَيْدُ الْخَيْرِ وَالأَقْرَعُ بْنُ حَابِسٍ وَعُيَيْنَةُ بْنُ حِصْنٍ وَعَلْقَمَةُ بْنُ عُلاَثَةَ أَوْ عَامِرُ بْنُ الطُّفَيْلِ ‏.‏ وَقَالَ نَاشِزُ الْجَبْهَةِ ‏.‏ كَرِوَايَةِ عَبْدِ الْوَاحِدِ ‏.‏ وَقَالَ إِنَّهُ سَيَخْرُجُ مِنْ ضِئْضِئِ هَذَا قَوْمٌ وَلَمْ يَذْكُرْ ‏ "‏ لَئِنْ أَدْرَكْتُهُمْ لأَقْتُلَنَّهُمْ قَتْلَ ثَمُودَ ‏"‏ ‏.‏\hadithno{2454}\hadithtrans{This hadith has been narrated through another chain of transmitters, but no mention has been made of:" If I find them, I would kill them as the Thamud were killed}}
\hadithdefcmd{muslim}{2455}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، يَقُولُ أَخْبَرَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، وَعَطَاءِ بْنِ يَسَارٍ، أَنَّهُمَا أَتَيَا أَبَا سَعِيدٍ الْخُدْرِيَّ فَسَأَلاَهُ عَنِ الْحَرُورِيَّةِ، هَلْ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَذْكُرُهَا قَالَ لاَ أَدْرِي مَنِ الْحَرُورِيَّةُ وَلَكِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَخْرُجُ فِي هَذِهِ الأُمَّةِ - وَلَمْ يَقُلْ مِنْهَا - قَوْمٌ تَحْقِرُونَ صَلاَتَكُمْ مَعَ صَلاَتِهِمْ فَيَقْرَءُونَ الْقُرْآنَ ‏.‏ لاَ يُجَاوِزُ حُلُوقَهُمْ - أَوْ حَنَاجِرَهُمْ - يَمْرُقُونَ مِنَ الدِّينِ مُرُوقَ السَّهْمِ مِنَ الرَّمِيَّةِ فَيَنْظُرُ الرَّامِي إِلَى سَهْمِهِ إِلَى نَصْلِهِ إِلَى رِصَافِهِ فَيَتَمَارَى فِي الْفُوقَةِ هَلْ عَلِقَ بِهَا مِنَ الدَّمِ شَىْءٌ ‏"‏ ‏.‏\hadithno{2455}\hadithtrans{Abu Salama and 'Ata' b. Yasar came to Abu Sa'id al-Khudri and asked him about Haruriya, saying:Did you hear the Messenger of Allah (ﷺ) making a mention of them? He (Abu Sai'd al-Khudri) said: I don't know who the Haruriya are, but I heard the Messenger of Allah (ﷺ) as saying: There would arise in this nation (and he did not say" out of them" ) a people and you would hold insignificant your prayers as compared with their prayers. And they would recite the Qur'an which would not go beyond their throats and would swerve through the religion (as blank) just as a (swift) arrow passes through the prey. The archer looks at his arrow, at its iron head and glances at its end (which he held) in the tip of his fingers to see whether it had any stain of blood}}
\hadithdefcmd{muslim}{2456}{حَدَّثَنِي أَبُو الطَّاهِرِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، ح . وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، وَأَحْمَدُ بْنُ عَبْدِ الرَّحْمَنِ الْفِهْرِيُّ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، وَالضَّحَّاكُ الْهَمْدَانِيُّ، أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ، قَالَ بَيْنَا نَحْنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يَقْسِمُ قَسْمًا أَتَاهُ ذُو الْخُوَيْصِرَةِ وَهُوَ رَجُلٌ مِنْ بَنِي تَمِيمٍ فَقَالَ يَا رَسُولَ اللَّهِ اعْدِلْ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَيْلَكَ وَمَنْ يَعْدِلُ إِنْ لَمْ أَعْدِلْ قَدْ خِبْتَ وَخَسِرْتَ إِنْ لَمْ أَعْدِلْ ‏"‏ ‏.‏ فَقَالَ عُمَرُ بْنُ الْخَطَّابِ رضى الله عنه يَا رَسُولَ اللَّهِ ائْذَنْ لِي فِيهِ أَضْرِبْ عُنُقَهُ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ دَعْهُ فَإِنَّ لَهُ أَصْحَابًا يَحْقِرُ أَحَدُكُمْ صَلاَتَهُ مَعَ صَلاَتِهِمْ وَصِيَامَهُ مَعَ صِيَامِهِمْ يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ تَرَاقِيَهُمْ يَمْرُقُونَ مِنَ الإِسْلاَمِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ يُنْظَرُ إِلَى نَصْلِهِ فَلاَ يُوجَدُ فِيهِ شَىْءٌ ثُمَّ يُنْظَرُ إِلَى رِصَافِهِ فَلاَ يُوجَدُ فِيهِ شَىْءٌ ثُمَّ يُنْظَرُ إِلَى نَضِيِّهِ فَلاَ يُوجَدُ فِيهِ شَىْءٌ - وَهُوَ الْقِدْحُ - ثُمَّ يُنْظَرُ إِلَى قُذَذِهِ فَلاَ يُوجَدُ فِيهِ شَىْءٌ سَبَقَ الْفَرْثَ وَالدَّمَ ‏.‏ آيَتُهُمْ رَجُلٌ أَسْوَدُ إِحْدَى عَضُدَيْهِ مِثْلُ ثَدْىِ الْمَرْأَةِ أَوْ مِثْلُ الْبَضْعَةِ تَدَرْدَرُ يَخْرُجُونَ عَلَى حِينِ فُرْقَةٍ مِنَ النَّاسِ ‏"‏ ‏.‏ قَالَ أَبُو سَعِيدٍ فَأَشْهَدُ أَنِّي سَمِعْتُ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَشْهَدُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ - رضى الله عنه - قَاتَلَهُمْ وَأَنَا مَعَهُ فَأَمَرَ بِذَلِكَ الرَّجُلِ فَالْتُمِسَ فَوُجِدَ فَأُتِيَ بِهِ حَتَّى نَظَرْتُ إِلَيْهِ عَلَى نَعْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم الَّذِي نَعَتَ ‏.‏\hadithno{2456}\hadithtrans{Abu Sai'd al-Khudri reported:When we were in the company of the Messenger of Allah (ﷺ) and he was distributing the spoils of war, there came to him Dhul-Khuwasira, one of Banu Tamim. He said: Messenger of Allah, do justice. Upon this the Messenger of Allah (ﷺ) said: Woe be upon thee! Who would do justice, if I do not do justice? You would be unsuccessful and incurring a loss, if I do not do justice. Upon this Umar b. Khattab (Allah be pleased with him) said: Messenger of Allah, permit me to strike off his neck. The Messenger of Allah (ﷺ) said: Leave him, for he has friends (who would outwardly look to be so religious and pious) that everyone among you would consider his prayer insignificant as compared with their prayer, and his fast as compared with their fasts. They would recite the Qur'an but it would not go beyond their collar-bones. They would pass through (the teachings of Islam so hurriedly) just as the arrow passes through the prey. He would look at its Iron head, but would not find anything ticking) there. He would then see at the lowest end, but would not find anything sticking there. He would then see at its grip but would not find anything sticking to it. He would then see at its feathers and he would find nothing sticking to them (as the arrow would pass so quickly that nothing would stick to it) neither excrement nor blood. They would be recognised by the presence of a black man among them whose upper arms would be like a woman's breast, or like a piece of meat as it quivers, and they would come forth at the time when there is dissension among the people. Abu Sai'd said: I testify to the fact that I heard it from the Messenger of Allah (ﷺ), and I testify to the fact that 'Ali b. Abu Talib fought against them and I was with him. He gave orders about that man who was sought for, and when he was brought in, and when I looked at him, he was exactly as the Messenger of Allah (ﷺ) had described him}}
\hadithdefcmd{muslim}{2457}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سُلَيْمَانَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم ذَكَرَ قَوْمًا يَكُونُونَ فِي أُمَّتِهِ يَخْرُجُونَ فِي فُرْقَةٍ مِنَ النَّاسِ سِيمَاهُمُ التَّحَالُقُ قَالَ ‏"‏ هُمْ شَرُّ الْخَلْقِ - أَوْ مِنْ أَشَرِّ الْخَلْقِ - يَقْتُلُهُمْ أَدْنَى الطَّائِفَتَيْنِ إِلَى الْحَقِّ ‏"‏ ‏.‏ قَالَ فَضَرَبَ النَّبِيُّ صلى الله عليه وسلم لَهُمْ مَثَلاً أَوْ قَالَ قَوْلاً ‏"‏ الرَّجُلُ يَرْمِي الرَّمِيَّةَ - أَوْ قَالَ الْغَرَضَ - فَيَنْظُرُ فِي النَّصْلِ فَلاَ يَرَى بَصِيرَةً وَيَنْظُرُ فِي النَّضِيِّ فَلاَ يَرَى بَصِيرَةً وَيَنْظُرُ فِي الْفُوقِ فَلاَ يَرَى بَصِيرَةً ‏"‏ ‏.‏ قَالَ قَالَ أَبُو سَعِيدٍ وَأَنْتُمْ قَتَلْتُمُوهُمْ يَا أَهْلَ الْعِرَاقِ ‏.‏\hadithno{2457}\hadithtrans{Abu Sa'id al-Khudri said that the Messenger of Allah (ﷺ) made a mention of a sect that would be among his Ummah which would emerge out of the dissension of the people. Their distinctive mark would be shaven heads. They would be the worst creatures or the worst of the creatures. The group who would be nearer to the truth out of the two would kill them. The Apostle of Allah (ﷺ) gave an example (to give their description) or he said:A man throws an arrow at the prey (or he said at the target), and sees at its iron head, but finds no sign (of blood there), or he sees at the lowest end, but would not see or find any sign (of blood there). He would then see into the grip but would not find (anything) sticking to it. Abu Sai'd then said: People of Iraq. it is you who have killed them}}
\hadithdefcmd{muslim}{2458}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا الْقَاسِمُ، - وَهُوَ ابْنُ الْفَضْلِ الْحُدَّانِيُّ - حَدَّثَنَا أَبُو نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَمْرُقُ مَارِقَةٌ عِنْدَ فُرْقَةٍ مِنَ الْمُسْلِمِينَ يَقْتُلُهَا أَوْلَى الطَّائِفَتَيْنِ بِالْحَقِّ ‏"‏ ‏.‏\hadithno{2458}\hadithtrans{Abu Sa'id al-Khudri reported that the Messenger of Allah (ﷺ) said:A group would secede itself (from the Ummah) when there would be dissension among the Muslims. Out of the two groups who would be nearer the truth would kill them}}
\hadithdefcmd{muslim}{2459}{حَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ قُتَيْبَةُ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَكُونُ فِي أُمَّتِي فِرْقَتَانِ فَتَخْرُجُ مِنْ بَيْنِهِمَا مَارِقَةٌ يَلِي قَتْلَهُمْ أَوْلاَهُمْ بِالْحَقِّ ‏"‏ ‏.‏\hadithno{2459}\hadithtrans{Abu Sa'id al-Khudri reported Allah's Messenger (ﷺ) as saying:There would be two groups in my Ummah, and there would emerge another group (seceding itself from both of them), and the party nearer to the truth among the two would kill them (the group of the Khawarij)}}
\hadithdefcmd{muslim}{2460}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا دَاوُدُ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي، سَعِيدٍ الْخُدْرِيِّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَمْرُقُ مَارِقَةٌ فِي فُرْقَةٍ مِنَ النَّاسِ فَيَلِي قَتْلَهُمْ أَوْلَى الطَّائِفَتَيْنِ بِالْحَقِّ ‏"‏ ‏.‏\hadithno{2460}\hadithtrans{It was narrated from Abu Sa'eed Al-Khudri that the Messenger of Allah (ﷺ) said:"A group will secede at a time of division among the people, and they will be killed by the group that is closer to the truth}}
\hadithdefcmd{muslim}{2461}{حَدَّثَنِي عُبَيْدُ اللَّهِ الْقَوَارِيرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، حَدَّثَنَا سُفْيَانُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنِ الضَّحَّاكِ الْمِشْرَقِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي حَدِيثٍ ذَكَرَ فِيهِ قَوْمًا يَخْرُجُونَ عَلَى فُرْقَةٍ مُخْتَلِفَةٍ يَقْتُلُهُمْ أَقْرَبُ الطَّائِفَتَيْنِ مِنَ الْحَقِّ ‏.‏\hadithno{2461}\hadithtrans{Abu Sa'id al-Khudri reported from the Messenger of Allah (ﷺ) that a group (Khawarij) would emerge from the different parties (the party of Hadrat 'Ali and the party of Amir Mu'awiya), the group nearer the truth between the two would kill them}}
\hadithdefcmd{muslim}{2462}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَعَبْدُ اللَّهِ بْنُ سَعِيدٍ الأَشَجُّ، جَمِيعًا عَنْ وَكِيعٍ، - قَالَ الأَشَجُّ حَدَّثَنَا وَكِيعٌ، - حَدَّثَنَا الأَعْمَشُ، عَنْ خَيْثَمَةَ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، قَالَ قَالَ عَلِيٌّ إِذَا حَدَّثْتُكُمْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلأَنْ أَخِرَّ مِنَ السَّمَاءِ أَحَبُّ إِلَىَّ مِنْ أَنْ أَقُولَ عَلَيْهِ مَا لَمْ يَقُلْ وَإِذَا حَدَّثْتُكُمْ فِيمَا بَيْنِي وَبَيْنَكُمْ فَإِنَّ الْحَرْبَ خَدْعَةٌ ‏.‏ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ سَيَخْرُجُ فِي آخِرِ الزَّمَانِ قَوْمٌ أَحْدَاثُ الأَسْنَانِ سُفَهَاءُ الأَحْلاَمِ يَقُولُونَ مِنْ خَيْرِ قَوْلِ الْبَرِيَّةِ يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ حَنَاجِرَهُمْ يَمْرُقُونَ مِنَ الدِّينِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ فَإِذَا لَقِيتُمُوهُمْ فَاقْتُلُوهُمْ فَإِنَّ فِي قَتْلِهِمْ أَجْرًا لِمَنْ قَتَلَهُمْ عِنْدَ اللَّهِ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2462}\hadithtrans{Ali said:Whenever I narrate to you anything from the Messenger of Allah (ﷺ) believe it to be absolutely true as falling from the sky is dearer to me than that of attributing anything to him (the Holy Prophet) which he never said. When I talk to you of anything which is between me and you (there might creep some error in it) for battle is an outwitting. I heard the Messenger of Allah (ﷺ) as saying: There would arise at the end of the age a people who would be young in age and immature in thought, but they would talk (in such a manner) as if their words are the best among the creatures. They would recite the Qur'an, but it would not go beyond their throats, and they would pass through the religion as an arrow goes through the prey. So when you meet them, kill them, for in their killing you would get a reward with Allah on the Day of Judgement}}
\hadithdefcmd{muslim}{2463}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ أَبِي، بَكْرٍ الْمُقَدَّمِيُّ وَأَبُو بَكْرِ بْنُ نَافِعٍ قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏\hadithno{2463}\hadithtrans{A hadith like this has been narrated through another chain of transmitters}}
\hadithdefcmd{muslim}{2464}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَزُهَيْرُ بْنُ حَرْبٍ قَالُوا حَدَّثَنَا أَبُو مُعَاوِيَةَ، كِلاَهُمَا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ وَلَيْسَ فِي حَدِيثِهِمَا ‏ "‏ يَمْرُقُونَ مِنَ الدِّينِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ ‏"‏ ‏.‏\hadithno{2464}\hadithtrans{This hadith has been narrated on the authority of A'mash with the same chain of transmitters, but (these words) are not there:" They pass through the religion clean as the arrow passes through the prey}}
\hadithdefcmd{muslim}{2465}{وَحَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا ابْنُ عُلَيَّةَ، وَحَمَّادُ بْنُ زَيْدٍ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لَهُمَا - قَالاَ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ عَبِيدَةَ، عَنْ عَلِيٍّ، قَالَ ذَكَرَ الْخَوَارِجَ فَقَالَ فِيهِمْ رَجُلٌ مُخْدَجُ الْيَدِ - أَوْ مُودَنُ الْيَدِ أَوْ مَثْدُونُ الْيَدِ - لَوْلاَ أَنْ تَبْطَرُوا لَحَدَّثْتُكُمْ بِمَا وَعَدَ اللَّهُ الَّذِينَ يَقْتُلُونَهُمْ عَلَى لِسَانِ مُحَمَّدٍ صلى الله عليه وسلم - قَالَ - قُلْتُ آنْتَ سَمِعْتَهُ مِنْ مُحَمَّدٍ صلى الله عليه وسلم قَالَ إِي وَرَبِّ الْكَعْبَةِ إِي وَرَبِّ الْكَعْبَةِ إِي وَرَبِّ الْكَعْبَةِ ‏.‏\hadithno{2465}\hadithtrans{Abida narrated from 'Ali that he made a mention of the Khawarij (and in this connection) said that there would be a person among them with a defective hand (or with a short hand) or a fleshy hand. If you were to exercise restraint, I would tell you what Allah has promised to those who would kill them on the order of Muhammad (ﷺ). I (the narrator) said to him:Did you hear it from Muhammad (ﷺ)? He (Hadrat 'Ali) said: Yes, by the Lord of the Ka'bah; Yes, by the Lord of the Ka'bah; yes, by the Lord of the Ka'bah}}
\hadithdefcmd{muslim}{2466}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدٍ، عَنْ عَبِيدَةَ، قَالَ لاَ أُحَدِّثُكُمْ إِلاَّ مَا سَمِعْتُ مِنْهُ، ‏.‏ فَذَكَرَ عَنْ عَلِيٍّ، نَحْوَ حَدِيثِ أَيُّوبَ مَرْفُوعًا ‏.‏\hadithno{2466}\hadithtrans{Abida said:I will not narrate to you except what I heard from him (Hadrat 'Ali), and then he narrated from him}}
\hadithdefcmd{muslim}{2467}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ بْنُ هَمَّامٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، حَدَّثَنَا سَلَمَةُ بْنُ كُهَيْلٍ، حَدَّثَنِي زَيْدُ بْنُ وَهْبٍ الْجُهَنِيُّ، أَنَّهُ كَانَ فِي الْجَيْشِ الَّذِينَ كَانُوا مَعَ عَلِيٍّ - رضى الله عنه - الَّذِينَ سَارُوا إِلَى الْخَوَارِجِ فَقَالَ عَلِيٌّ رضى الله عنه أَيُّهَا النَّاسُ إِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَخْرُجُ قَوْمٌ مِنْ أُمَّتِي يَقْرَءُونَ الْقُرْآنَ لَيْسَ قِرَاءَتُكُمْ إِلَى قِرَاءَتِهِمْ بِشَىْءٍ وَلاَ صَلاَتُكُمْ إِلَى صَلاَتِهِمْ بِشَىْءٍ وَلاَ صِيَامُكُمْ إِلَى صِيَامِهِمْ بِشَىْءٍ يَقْرَءُونَ الْقُرْآنَ يَحْسِبُونَ أَنَّهُ لَهُمْ وَهُوَ عَلَيْهِمْ لاَ تُجَاوِزُ صَلاَتُهُمْ تَرَاقِيَهُمْ يَمْرُقُونَ مِنَ الإِسْلاَمِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ ‏"‏ ‏.‏ لَوْ يَعْلَمُ الْجَيْشُ الَّذِينَ يُصِيبُونَهُمْ مَا قُضِيَ لَهُمْ عَلَى لِسَانِ نَبِيِّهِمْ صلى الله عليه وسلم لاَتَّكَلُوا عَنِ الْعَمَلِ وَآيَةُ ذَلِكَ أَنَّ فِيهِمْ رَجُلاً لَهُ عَضُدٌ وَلَيْسَ لَهُ ذِرَاعٌ عَلَى رَأْسِ عَضُدِهِ مِثْلُ حَلَمَةِ الثَّدْىِ عَلَيْهِ شَعَرَاتٌ بِيضٌ فَتَذْهَبُونَ إِلَى مُعَاوِيَةَ وَأَهْلِ الشَّامِ وَتَتْرُكُونَ هَؤُلاَءِ يَخْلُفُونَكُمْ فِي ذَرَارِيِّكُمْ وَأَمْوَالِكُمْ وَاللَّهِ إِنِّي لأَرْجُو أَنْ يَكُونُوا هَؤُلاَءِ الْقَوْمَ فَإِنَّهُمْ قَدْ سَفَكُوا الدَّمَ الْحَرَامَ وَأَغَارُوا فِي سَرْحِ النَّاسِ فَسِيرُوا عَلَى اسْمِ اللَّهِ ‏.‏ قَالَ سَلَمَةُ بْنُ كُهَيْلٍ فَنَزَّلَنِي زَيْدُ بْنُ وَهْبٍ مَنْزِلاً حَتَّى قَالَ مَرَرْنَا عَلَى قَنْطَرَةٍ فَلَمَّا الْتَقَيْنَا وَعَلَى الْخَوَارِجِ يَوْمَئِذٍ عَبْدُ اللَّهِ بْنُ وَهْبٍ الرَّاسِبِيُّ فَقَالَ لَهُمْ أَلْقُوا الرِّمَاحَ وَسُلُّوا سُيُوفَكُمْ مِنْ جُفُونِهَا فَإِنِّي أَخَافُ أَنْ يُنَاشِدُوكُمْ كَمَا نَاشَدُوكُمْ يَوْمَ حَرُورَاءَ ‏.‏ فَرَجَعُوا فَوَحَّشُوا بِرِمَاحِهِمْ وَسَلُّوا السُّيُوفَ وَشَجَرَهُمُ النَّاسُ بِرِمَاحِهِمْ - قَالَ - وَقُتِلَ بَعْضُهُمْ عَلَى بَعْضٍ وَمَا أُصِيبَ مِنَ النَّاسِ يَوْمَئِذٍ إِلاَّ رَجُلاَنِ فَقَالَ عَلِيٌّ رضى الله عنه الْتَمِسُوا فِيهِمُ الْمُخْدَجَ ‏.‏ فَالْتَمَسُوهُ فَلَمْ يَجِدُوهُ فَقَامَ عَلِيٌّ - رضى الله عنه - بِنَفْسِهِ حَتَّى أَتَى نَاسًا قَدْ قُتِلَ بَعْضُهُمْ عَلَى بَعْضٍ قَالَ أَخِّرُوهُمْ ‏.‏ فَوَجَدُوهُ مِمَّا يَلِي الأَرْضَ فَكَبَّرَ ثُمَّ قَالَ صَدَقَ اللَّهُ وَبَلَّغَ رَسُولُهُ - قَالَ - فَقَامَ إِلَيْهِ عَبِيدَةُ السَّلْمَانِيُّ فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ اللَّهَ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ لَسَمِعْتَ هَذَا الْحَدِيثَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِي وَاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ ‏.‏ حَتَّى اسْتَحْلَفَهُ ثَلاَثًا وَهُوَ يَحْلِفُ لَهُ ‏.‏\hadithno{2467}\hadithtrans{Zaid b. Wahb Juhani reported and he was among the squadron which was under the command of Ali (Allah be pleased with him) and which set out (to curb the activities) of the Khawarij. 'Ali (Allah be pleased with him) said:O people, I heard the Messenger of Allah (ﷺ) say: There would arise from my Ummah a people who would recite the Qur'an, and your recital would seem insignificant as compared with their recital, your prayer as compared with their prayer, and your fast, as compared with their fast. They would recite the Qur'an thinking that it supports them, whereas it is an evidence against them. Their prayer does not get beyond their collar bone; they would swerve through Islam just as the arrow passes through the prey. If the squadron which is to encounter them were to know (what great boon) has been assured to them by their Messenger (ﷺ) they would completely rely upon this deed (alone and cease to do other good deeds), and their (that of the Khawarij) distinctive mark is that there would be (among them) a person whose wrist would be without the arm, and the end of his wrist would be fleshy like the nipple of the breast on which there would be white hair. You would be marching towards Muawiya and the people of Syria and you would leave them behind among your children and your property (to do harm). By Allah, I believe that these are the people (against whom you have been commanded to fight and get reward) for they have shed forbidden blood, and raided the animals of the people. So go forth in the name of Allah (to fight against them). Salama b. Kuhail mentioned that Zaid b. Wahb made me alight at every stage, till we crossed a bridge. 'Abdullah b. Wahb al-Rasibi was at the head of the Khawarij when we encountered them. He ('Abdullah) said to his army: Throw the spears and draw out your swords from their sheaths, for I fear that they would attack you as they attacked you on the day of Harura. They went back and threw their spears and drew out their swords, and people fought against them with spears and they were killed one after another. Only two persons were killed among the people (among the army led by 'Ali) on that day. 'Ali (Allah be pleased with him) said: Find out from among them (the dead bodies of the Khawarij) (the maimed). They searched but did not find him. 'Ali (Allah be pleased with him) then himself stood up and (walked) till he came to the people who had been killed one after another. He ('Ali) said: Search them to the last, and then ('Ali's companions) found him (the dead body of the maimed) near the earth. He ('Ali) then pronounced Allahu Akbar (Allah is the Greatest) and then said, Allah told the Truth and His Messenger (ﷺ) conveyed it. Then there stood before him 'Abida Salmani who said: Commander of the Believers, by Allah, besides Whom there is no god but He, (tell me) whether you heard this hadith from the Messenger of Allah (ﷺ). He said: Yes, by Allah, besides Whom there is no god but He. He asked him to take an oath thrice and he took the oath}}
\hadithdefcmd{muslim}{2468}{حَدَّثَنِي أَبُو الطَّاهِرِ، وَيُونُسُ بْنُ عَبْدِ الأَعْلَى، قَالاَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ الأَشَجِّ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّ الْحَرُورِيَّةَ لَمَّا خَرَجَتْ وَهُوَ مَعَ عَلِيِّ بْنِ أَبِي طَالِبٍ - رضى الله عنه - قَالُوا لاَ حُكْمَ إِلاَّ لِلَّهِ ‏.‏ قَالَ عَلِيٌّ كَلِمَةُ حَقٍّ أُرِيدَ بِهَا بَاطِلٌ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَصَفَ نَاسًا إِنِّي لأَعْرِفُ صِفَتَهُمْ فِي هَؤُلاَءِ ‏ "‏ يَقُولُونَ الْحَقَّ بِأَلْسِنَتِهِمْ لاَ يَجُوزُ هَذَا مِنْهُمْ - وَأَشَارَ إِلَى حَلْقِهِ - مِنْ أَبْغَضِ خَلْقِ اللَّهِ إِلَيْهِ مِنْهُمْ أَسْوَدُ إِحْدَى يَدَيْهِ طُبْىُ شَاةٍ أَوْ حَلَمَةُ ثَدْىٍ ‏"‏ ‏.‏ فَلَمَّا قَتَلَهُمْ عَلِيُّ بْنُ أَبِي طَالِبٍ - رضى الله عنه - قَالَ انْظُرُوا ‏.‏ فَنَظَرُوا فَلَمْ يَجِدُوا شَيْئًا فَقَالَ ارْجِعُوا فَوَاللَّهِ مَا كَذَبْتُ وَلاَ كُذِبْتُ ‏.‏ مَرَّتَيْنِ أَوْ ثَلاَثًا ثُمَّ وَجَدُوهُ فِي خَرِبَةٍ فَأَتَوْا بِهِ حَتَّى وَضَعُوهُ بَيْنَ يَدَيْهِ ‏.‏ قَالَ عُبَيْدُ اللَّهِ وَأَنَا حَاضِرُ ذَلِكَ مِنْ أَمْرِهِمْ ‏.‏ وَقَوْلِ عَلِيٍّ فِيهِمْ زَادَ يُونُسُ فِي رِوَايَتِهِ قَالَ بُكَيْرٌ وَحَدَّثَنِي رَجُلٌ عَنِ ابْنِ حُنَيْنٍ أَنَّهُ قَالَ رَأَيْتُ ذَلِكَ الأَسْوَدَ ‏.‏\hadithno{2468}\hadithtrans{Ubaidullah b. Abu Rafi', the freed slave of the Messenger of Allah (ﷺ), said:When Haruria (the Khawarij) set out and as he was with 'Ali b. Abu Talib (Allah be pleased with him) they said, "There is no command but that of Allah." Upon this 'Ali said: The statement is true but it is intentionally applied (to support) a wrong (cause). The Messenger of Allah (ﷺ) described their characteristics and I found these characteristics in them. They state the truth with their tongue, but it does not go beyond this part of their bodies (and the narrator pointed towards his throat). The most hateful among the creation of Allah is one black man among them (Khawarij). One of his hand is like the teat of a goat or the nipple of the breast. When 'Ali b. Abu Talib (Allah be pleased with him) killed them, he said: Search (for his dead body). They searched for him, but they did not find it (his dead body). Upon this he said: Go (and search for him). By Allah, neither I have spoken a lie nor has the lie been spoken to me. 'Ali said this twice and thrice. They then found him (the dead body) in a rain. They brought (his dead) body till they placed it before him (Hadrat 'Ali). 'Ubaidullah said: And, I was present at (that place) when this happened and when 'Ali said about them. A person narrated to me from Ibn Hanain that he said: I saw that black man}}
\hadithdefcmd{muslim}{2469}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا سُلَيْمَانُ بْنُ الْمُغِيرَةِ، حَدَّثَنَا حُمَيْدُ بْنُ هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ بَعْدِي مِنْ أُمَّتِي - أَوْ سَيَكُونُ بَعْدِي مِنْ أُمَّتِي - قَوْمٌ يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ حَلاَقِيمَهُمْ يَخْرُجُونَ مِنَ الدِّينِ كَمَا يَخْرُجُ السَّهْمُ مِنَ الرَّمِيَّةِ ثُمَّ لاَ يَعُودُونَ فِيهِ هُمْ شَرُّ الْخَلْقِ وَالْخَلِيقَةِ ‏"‏ ‏.‏ فَقَالَ ابْنُ الصَّامِتِ فَلَقِيتُ رَافِعَ بْنَ عَمْرٍو الْغِفَارِيَّ أَخَا الْحَكَمِ الْغِفَارِيِّ قُلْتُ مَا حَدِيثٌ سَمِعْتُهُ مِنْ أَبِي ذَرٍّ كَذَا وَكَذَا فَذَكَرْتُ لَهُ هَذَا الْحَدِيثَ فَقَالَ وَأَنَا سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2469}\hadithtrans{Abu Dharr reported Allah's Messenger (ﷺ) as saying:Verily there would arise from my Ummah after me or soon after me a group (of people) who would recite the Qur'an, but it would not go beyond their throats, and they would pass clean through their religion just as the arrow passes through the prey, and they would never come back to it. They would be the worst among the creation and the creatures. Ibn Samit (one of the narrators) said: I met Rafi' b. 'Amr Ghifari, the brother of Al-Hakam Ghifari and I said: What is this hadith that I heard from Abu Dharr, i. e. so and so? and then I narrated that hadith to him and said: I heard it from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{2470}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنِ الشَّيْبَانِيِّ، عَنْ يُسَيْرِ بْنِ، عَمْرٍو قَالَ سَأَلْتُ سَهْلَ بْنَ حُنَيْفٍ هَلْ سَمِعْتَ النَّبِيَّ صلى الله عليه وسلم يَذْكُرُ الْخَوَارِجَ فَقَالَ سَمِعْتُهُ - وَأَشَارَ بِيَدِهِ نَحْوَ الْمَشْرِقِ ‏ "‏ قَوْمٌ يَقْرَءُونَ الْقُرْآنَ بِأَلْسِنَتِهِمْ لاَ يَعْدُو تَرَاقِيَهُمْ يَمْرُقُونَ مِنَ الدِّينِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ ‏"‏ ‏.‏\hadithno{2470}\hadithtrans{Yusair b. 'Amr reported that he inquired of Sahl b. Hunaif:Did you hear the Messenger of Allah (ﷺ) making a mention of the Khawarij? He said: I heard him say (and he pointed with his hand towards the east) that these would be a people who would recite the Qur'an with their tongues and it would not go beyond their collar bones. They would pass clean through their religion just as the arrow passes through the prey}}
\hadithdefcmd{muslim}{2471}{وَحَدَّثَنَاهُ أَبُو كَامِلٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا سُلَيْمَانُ الشَّيْبَانِيُّ، بِهَذَا الإِسْنَادِ وَقَالَ يَخْرُجُ مِنْهُ أَقْوَامٌ ‏.‏\hadithno{2471}\hadithtrans{This hadith had been transmitted by Sulaiman Shaibani with the same chain of narrators (and the words are)," There would arise out of (this group) many a group}}
\hadithdefcmd{muslim}{2472}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ، جَمِيعًا عَنْ يَزِيدَ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، - عَنِ الْعَوَّامِ بْنِ حَوْشَبٍ، حَدَّثَنَا أَبُو إِسْحَاقَ الشَّيْبَانِيُّ، عَنْ أُسَيْرِ بْنِ عَمْرٍو، عَنْ سَهْلِ بْنِ حُنَيْفٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَتِيهُ قَوْمٌ قِبَلَ الْمَشْرِقِ مُحَلَّقَةٌ رُءُوسُهُمْ ‏"‏ ‏.‏\hadithno{2472}\hadithtrans{Sahl b. Hunaif reported Allah's Apostle (ﷺ) as saying:There would arise from the east a people with shaven heads}}
\hadithdefcmd{muslim}{2473}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدٍ، - وَهُوَ ابْنُ زِيَادٍ - سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ أَخَذَ الْحَسَنُ بْنُ عَلِيٍّ تَمْرَةً مِنْ تَمْرِ الصَّدَقَةِ فَجَعَلَهَا فِي فِيهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كِخْ كِخْ ارْمِ بِهَا أَمَا عَلِمْتَ أَنَّا لاَ نَأْكُلُ الصَّدَقَةَ ‏"‏ ‏.‏\hadithno{2473}\hadithtrans{Abu Huraira reported that Hasan b. 'Ali took one of The dates of the sadaqa and put it in his mouth, whereupon the Prophet (ﷺ) said:Leave it, leave it, throw it; don't you know that we do not eat the sadaqa?}}
\hadithdefcmd{muslim}{2474}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَزُهَيْرُ بْنُ حَرْبٍ جَمِيعًا عَنْ وَكِيعٍ، عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ أَنَّا لاَ، تَحِلُّ لَنَا الصَّدَقَةُ ‏"‏ ‏.‏\hadithno{2474}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the same chain of transmitters (and the words of the Holy Prophet) are:" Sadaqa is not permissible for us}}
\hadithdefcmd{muslim}{2475}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ، أَبِي عَدِيٍّ كِلاَهُمَا عَنْ شُعْبَةَ، فِي هَذَا الإِسْنَادِ كَمَا قَالَ ابْنُ مُعَاذٍ ‏ "‏ أَنَّا لاَ، نَأْكُلُ الصَّدَقَةَ ‏"‏ ‏.‏\hadithno{2475}\hadithtrans{This very hadith has been narrated on the authority of Sbu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{2476}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، أَنَّ أَبَا يُونُسَ، مَوْلَى أَبِي هُرَيْرَةَ حَدَّثَهُ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنِّي لأَنْقَلِبُ إِلَى أَهْلِي فَأَجِدُ التَّمْرَةَ سَاقِطَةً عَلَى فِرَاشِي ثُمَّ أَرْفَعُهَا لآكُلَهَا ثُمَّ أَخْشَى أَنْ تَكُونَ صَدَقَةً فَأُلْقِيهَا ‏"‏ ‏.‏\hadithno{2476}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:I go back to my family and I find a date lying on my bed. I then take it up to eat it, but then I throw it away fearing that it may be a Sadaqa}}
\hadithdefcmd{muslim}{2477}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ بْنُ هَمَّامٍ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ، مُنَبِّهٍ قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ مُحَمَّدٍ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَاللَّهِ إِنِّي لأَنْقَلِبُ إِلَى أَهْلِي فَأَجِدُ التَّمْرَةَ سَاقِطَةً عَلَى فِرَاشِي - أَوْ فِي بَيْتِي - فَأَرْفَعُهَا لآكُلَهَا ثُمَّ أَخْشَى أَنْ تَكُونَ صَدَقَةً - أَوْ مِنَ الصَّدَقَةِ - فَأُلْقِيهَا ‏"‏ ‏.‏\hadithno{2477}\hadithtrans{Out of so many ahadith which Hammam b. Munabbih narrated on the authority of Abu Huraira from the Messenger of Allah (ﷺ) one is this that the Messenger of Allah (ﷺ) said:I go back to my family and I find a date lying on my bed or in my house, and I take it up to eat it, but then I throw it away fearing that it may be a Sadaqa or from Sadaqa}}
\hadithdefcmd{muslim}{2478}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَجَدَ تَمْرَةً فَقَالَ ‏ "‏ لَوْلاَ أَنْ تَكُونَ مِنَ الصَّدَقَةِ لأَكَلْتُهَا ‏"‏ ‏.‏\hadithno{2478}\hadithtrans{Anas b. Malik reported that the Messenger of Allah (ﷺ) found a date in the street and said:If it were not of sadaqa I would have eaten it}}
\hadithdefcmd{muslim}{2479}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ زَائِدَةَ، عَنْ مَنْصُورٍ، عَنْ طَلْحَةَ بْنِ مُصَرِّفٍ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِتَمْرَةٍ بِالطَّرِيقِ فَقَالَ ‏ "‏ لَوْلاَ أَنْ تَكُونَ مِنَ الصَّدَقَةِ لأَكَلْتُهَا ‏"‏ ‏.‏\hadithno{2479}\hadithtrans{Anas b. Malik reported that the Messenger of Allah (ﷺ) found a date lying on the path and said:If it were not out of Sadaqa, I would have eaten it}}
\hadithdefcmd{muslim}{2480}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم وَجَدَ تَمْرَةً فَقَالَ ‏ "‏ لَوْلاَ أَنْ تَكُونَ صَدَقَةً لأَكَلْتُهَا ‏"‏ ‏.‏\hadithno{2480}\hadithtrans{Anas b. Malik reported that the Messenger of Allah (ﷺ) found a date and said:Were it not (that I fear) it may be part of sadaqa, I would have eaten it}}
\hadithdefcmd{muslim}{2481}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ الضُّبَعِيُّ، حَدَّثَنَا جُوَيْرِيَةُ، عَنْ مَالِكٍ، عَنِ الزُّهْرِيِّ، أَنَّ عَبْدَ اللَّهِ بْنَ عَبْدِ اللَّهِ بْنِ نَوْفَلِ بْنِ الْحَارِثِ بْنِ عَبْدِ الْمُطَّلِبِ، حَدَّثَهُ أَنَّ عَبْدَ الْمُطَّلِبِ بْنَ رَبِيعَةَ بْنِ الْحَارِثِ حَدَّثَهُ قَالَ اجْتَمَعَ رَبِيعَةُ بْنُ الْحَارِثِ وَالْعَبَّاسُ بْنُ عَبْدِ الْمُطَّلِبِ فَقَالاَ وَاللَّهِ لَوْ بَعَثْنَا هَذَيْنِ الْغُلاَمَيْنِ - قَالاَ لِي وَلِلْفَضْلِ بْنِ عَبَّاسٍ - إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَكَلَّمَاهُ فَأَمَّرَهُمَا عَلَى هَذِهِ الصَّدَقَاتِ فَأَدَّيَا مَا يُؤَدِّي النَّاسُ وَأَصَابَا مِمَّا يُصِيبُ النَّاسُ - قَالَ - فَبَيْنَمَا هُمَا فِي ذَلِكَ جَاءَ عَلِيُّ بْنُ أَبِي طَالِبٍ فَوَقَفَ عَلَيْهِمَا فَذَكَرَا لَهُ ذَلِكَ فَقَالَ عَلِيُّ بْنُ أَبِي طَالِبٍ لاَ تَفْعَلاَ فَوَاللَّهِ مَا هُوَ بِفَاعِلٍ ‏.‏ فَانْتَحَاهُ رَبِيعَةُ بْنُ الْحَارِثِ فَقَالَ وَاللَّهِ مَا تَصْنَعُ هَذَا إِلاَّ نَفَاسَةً مِنْكَ عَلَيْنَا فَوَاللَّهِ لَقَدْ نِلْتَ صِهْرَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَا نَفِسْنَاهُ عَلَيْكَ ‏.‏ قَالَ عَلِيٌّ أَرْسِلُوهُمَا ‏.‏ فَانْطَلَقَا وَاضْطَجَعَ عَلِيٌّ - قَالَ - فَلَمَّا صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الظُّهْرَ سَبَقْنَاهُ إِلَى الْحُجْرَةِ فَقُمْنَا عِنْدَهَا حَتَّى جَاءَ فَأَخَذَ بِآذَانِنَا ‏.‏ ثُمَّ قَالَ ‏"‏ أَخْرِجَا مَا تُصَرِّرَانِ ‏"‏ ثُمَّ دَخَلَ وَدَخَلْنَا عَلَيْهِ وَهُوَ يَوْمَئِذٍ عِنْدَ زَيْنَبَ بِنْتِ جَحْشٍ - قَالَ - فَتَوَاكَلْنَا الْكَلاَمَ ثُمَّ تَكَلَّمَ أَحَدُنَا فَقَالَ يَا رَسُولَ اللَّهِ أَنْتَ أَبَرُّ النَّاسِ وَأَوْصَلُ النَّاسِ وَقَدْ بَلَغْنَا النِّكَاحَ فَجِئْنَا لِتُؤَمِّرَنَا عَلَى بَعْضِ هَذِهِ الصَّدَقَاتِ فَنُؤَدِّيَ إِلَيْكَ كَمَا يُؤَدِّي النَّاسُ وَنُصِيبَ كَمَا يُصِيبُونَ - قَالَ - فَسَكَتَ طَوِيلاً حَتَّى أَرَدْنَا أَنْ نُكَلِّمَهُ - قَالَ - وَجَعَلَتْ زَيْنَبُ تُلْمِعُ عَلَيْنَا مِنْ وَرَاءِ الْحِجَابِ أَنْ لاَ تُكَلِّمَاهُ - قَالَ - ثُمَّ قَالَ ‏"‏ إِنَّ الصَّدَقَةَ لاَ تَنْبَغِي لآلِ مُحَمَّدٍ ‏.‏ إِنَّمَا هِيَ أَوْسَاخُ النَّاسِ ادْعُوَا لِي مَحْمِيَةَ - وَكَانَ عَلَى الْخُمُسِ - وَنَوْفَلَ بْنَ الْحَارِثِ بْنِ عَبْدِ الْمُطَّلِبِ ‏"‏ ‏.‏ قَالَ فَجَاءَاهُ فَقَالَ لِمَحْمِيَةَ ‏"‏ أَنْكِحْ هَذَا الْغُلاَمَ ابْنَتَكَ ‏"‏ ‏.‏ لِلْفَضْلِ بْنِ عَبَّاسٍ فَأَنْكَحَهُ وَقَالَ لِنَوْفَلِ بْنِ الْحَارِثِ ‏"‏ أَنْكِحْ هَذَا الْغُلاَمَ ابْنَتَكَ ‏"‏ ‏.‏ لِي فَأَنْكَحَنِي وَقَالَ لِمَحْمِيَةَ ‏"‏ أَصْدِقْ عَنْهُمَا مِنَ الْخُمُسِ كَذَا وَكَذَا ‏"‏ ‏.‏ قَالَ الزُّهْرِيُّ وَلَمْ يُسَمِّهِ لِي ‏.‏\hadithno{2481}\hadithtrans{Abd al-Muttalib b. Rabi'a b. al-Harith reported that Rabi'a b. al-Harith and Abbas b. Abd al-Muttalib gathered together and said:By Allah, if we had sent these two young boys (i. e. I and Fadl b. 'Abbas) to the Messenger of Allah (ﷺ) and they had spoken to him, he would have appointed them (as the collectors) of these sadaqat; and they would (collect them) and pay (to the Holy Prophet) as other people (collectors) paid and would get a share as other people got it. As they were talking about it there came 'Ali b. Abu Talib and stood before them, and they made a mention of it to him. 'Ali b. Abu Talib said: Don't do that; by Allah he (the Holy Prophet) would not do that (would not accept your request). Rabi'a b. Harith turned to him and said: By Allah, you are not doing so but out of jealousy that you nurse against us By Allah, you became the son-in-law of the Messenger of Allah (ﷺ) but we felt no jealousy against you (for this great privilege of yours). 'Ali then said: Send them (if you like). They set out and 'Ali lay on the bed. When the Messenger of Allah (ﷺ) offered the noon prayer. we went ahead of him to his apartment and stood near it till he came out. He took hold of our ears (out of love and affection) and then said: Give out what you have kept in your hearts. He then entered (the apartment) and we also went in and he (the Holy Prophet) was on that day (in the house of) Zainab b. jahsh. We urged each (of us) to speak. Then one of us thus spoke: Messenger of Allah, you are the best of humanity and the best to cement the ties of blood-relations. We have reached the-marriageable age. We have come (to you) so that you may appoint us (as collectors) of these sadaqat. and we would pay you just as thin people (other collectors) pay you, and get our share as others get it. He (the Holy Prophet) kept silence for a long time till we wished that we should speak with him (again), and Zainab pointied to us from behind the curtain not to talk (any more). He (the Holy Prophet) said; It does not become the family of Muhammad (to accept) sadaqat for they are the impurities of people. You call to me Mahmiya (and he was in charge of khums, i. e, of the one-fifth part that goes to the treasury out of the spoils of war), and Naufal b. Harith b. 'Abd al-Muttalib. They both came to him, and he (the Holy Prophet) said to Mahmiya: Marry your daughter to this young man (i. e. Fadl b. 'Abbas), and he married her to him And he said to Naufal b. Harith: Marry your daughter to this young man (i e. 'Abd al-Muttalib b. Rabi'a, the narrator of this hadith) and he married her to me, and he said to Mahmiya: Pay so much mahr on behalf of both of them from this khums Zuhri, however. said: He did not determine (the amount of mahr)}}
\hadithdefcmd{muslim}{2482}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ، شِهَابٍ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ نَوْفَلٍ الْهَاشِمِيِّ، أَنَّ عَبْدَ الْمُطَّلِبِ بْنَ رَبِيعَةَ بْنِ الْحَارِثِ، بْنِ عَبْدِ الْمُطَّلِبِ أَخْبَرَهُ أَنَّ أَبَاهُ رَبِيعَةَ بْنَ الْحَارِثِ بْنِ عَبْدِ الْمُطَّلِبِ وَالْعَبَّاسَ بْنَ عَبْدِ الْمُطَّلِبِ قَالاَ لِعَبْدِ الْمُطَّلِبِ بْنِ رَبِيعَةَ وَلِلْفَضْلِ بْنِ عَبَّاسٍ ائْتِيَا رَسُولَ اللَّهِ صلى الله عليه وسلم وَسَاقَ الْحَدِيثَ بِنَحْوِ حَدِيثِ مَالِكٍ وَقَالَ فِيهِ فَأَلْقَى عَلِيٌّ رِدَاءَهُ ثُمَّ اضْطَجَعَ عَلَيْهِ وَقَالَ أَنَا أَبُو حَسَنٍ الْقَرْمُ وَاللَّهِ لاَ أَرِيمُ مَكَانِي حَتَّى يَرْجِعَ إِلَيْكُمَا ابْنَاكُمَا بِحَوْرِ مَا بَعَثْتُمَا بِهِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ وَقَالَ فِي الْحَدِيثِ ثُمَّ قَالَ لَنَا ‏"‏ إِنَّ هَذِهِ الصَّدَقَاتِ إِنَّمَا هِيَ أَوْسَاخُ النَّاسِ وَإِنَّهَا لاَ تَحِلُّ لِمُحَمَّدٍ وَلاَ لآلِ مُحَمَّدٍ ‏"‏ ‏.‏ وَقَالَ أَيْضًا ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ادْعُوَا لِي مَحْمِيَةَ بْنَ جَزْءٍ ‏"‏ ‏.‏ وَهُوَ رَجُلٌ مِنْ بَنِي أَسَدٍ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم اسْتَعْمَلَهُ عَلَى الأَخْمَاسِ ‏.‏\hadithno{2482}\hadithtrans{Rabi'a b. Harith b. 'Abd al-Muttalib and Abbas b. 'Abd al-Muttalib said to Abd al-Muttalib b. Rabi'a and Fadl b. Ibn Abbas:Go to the Messenger of Allah (ﷺ), and the rest of the hadith is the same (but with this addition):" 'Ali spread his cloak and then lay down on it and said: I am the father of Hasan, and I am the chief. By Allah, I would not move from my place till your sons come back to you with the reply to that for which you sent them to the Messenger of Allah (ﷺ). And he then also said: Verily these sadaqat are the impurities of people, and they are not permissible for Muhammad (may peaace be upon him), and for the family of Muhammad. And he also said: The Messenger of Allah (ﷺ) also said to me: Call Mahmiya b. Jaz', and he was person from Banu Asad. and the Messenger of Allah (ﷺ) had appointed him as a collector of khums}}
\hadithdefcmd{muslim}{2483}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُبَيْدَ بْنَ السَّبَّاقِ، قَالَ إِنَّ جُوَيْرِيَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَلَيْهَا فَقَالَ ‏"‏ هَلْ مِنْ طَعَامٍ ‏"‏ ‏.‏ قَالَتْ لاَ وَاللَّهِ يَا رَسُولَ اللَّهِ مَا عِنْدَنَا طَعَامٌ إِلاَّ عَظْمٌ مِنْ شَاةٍ أُعْطِيَتْهُ مَوْلاَتِي مِنَ الصَّدَقَةِ ‏.‏ فَقَالَ ‏"‏ قَرِّبِيهِ فَقَدْ بَلَغَتْ مَحِلَّهَا ‏"‏ ‏.‏\hadithno{2483}\hadithtrans{Juwayriya, the wife of the Messenger of Allah (ﷺ)" said that Messenger of Allah (ﷺ) came to her and said:Is there anything to eat? She said: Messenger of Allah, I swear by God, there is no food with us except a bone of goat which my freed maid-servant was given as sadaqa. Upon this he said: Bring that to me, for it (the sadaqa) has reached its destination}}
\hadithdefcmd{muslim}{2484}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنِ ابْنِ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{2484}\hadithtrans{This hadith has been narrated by Zuhri with the same chain of trainsmitters}}
\hadithdefcmd{muslim}{2485}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ، الْمُثَنَّى وَابْنُ بَشَّارٍ قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، كِلاَهُمَا عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، ح وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، سَمِعَ أَنَسَ بْنَ مَالِكٍ، قَالَ أَهْدَتْ بَرِيرَةُ إِلَى النَّبِيِّ صلى الله عليه وسلم لَحْمًا تُصُدِّقَ بِهِ عَلَيْهَا فَقَالَ ‏ "‏ هُوَ لَهَا صَدَقَةٌ وَلَنَا هَدِيَّةٌ ‏"‏ ‏.‏\hadithno{2485}\hadithtrans{Anas b. Malik reported that Barira presented to the Messenger of Allah (ﷺ) a piece of meat which had been given to her as sadaqa. Upon this he (the Holy Prophet) said:That is a Sadaqa for her and a gift for us}}
\hadithdefcmd{muslim}{2486}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، وَأُتِيَ النَّبِيُّ، صلى الله عليه وسلم بِلَحْمِ بَقَرٍ فَقِيلَ هَذَا مَا تُصُدِّقَ بِهِ عَلَى بَرِيرَةَ ‏.‏ فَقَالَ ‏ "‏ هُوَ لَهَا صَدَقَةٌ وَلَنَا هَدِيَّةٌ ‏"‏ ‏.‏\hadithno{2486}\hadithtrans{A'isha reported that (once) the Messenger of Allah (may peace be upon him, ) was presented with beef. It was said (by someone) that it had been given to Barira as Sadaqa. Upon this he (the Prophet) said:It is a Sadaqa for her and a gift for us}}
\hadithdefcmd{muslim}{2487}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَتْ فِي بَرِيرَةَ ثَلاَثُ قَضِيَّاتٍ كَانَ النَّاسُ يَتَصَدَّقُونَ عَلَيْهَا وَتُهْدِي لَنَا فَذَكَرْتُ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ هُوَ عَلَيْهَا صَدَقَةٌ وَلَكُمْ هَدِيَّةٌ فَكُلُوهُ ‏"‏ ‏.‏\hadithno{2487}\hadithtrans{A'isha (Allah be pleased with her) said:Three are the decions (of the Shari'ah that we have come to know) through Barira. The people gave her sadaqa and she offered us as gift. We made a mention of it to the Messenger of Allah (ﷺ), whereupon he said: It is a sadaqa for her and a gift for you; so eat it}}
\hadithdefcmd{muslim}{2488}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، عَنْ سِمَاكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، ح . وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ عَبْدَ، الرَّحْمَنِ بْنَ الْقَاسِمِ قَالَ سَمِعْتُ الْقَاسِمَ، يُحَدِّثُ عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ ذَلِكَ ‏.‏\hadithno{2488}\hadithtrans{This hadith has been narrated on the authority of A'isha through another chain of transmitters}}
\hadithdefcmd{muslim}{2489}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي مَالِكُ بْنُ أَنَسٍ، عَنْ رَبِيعَةَ، عَنِ الْقَاسِمِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ ذَلِكَ غَيْرَ أَنَّهُ قَالَ ‏ "‏ وَهُوَ لَنَا مِنْهَا هَدِيَّةٌ ‏"‏ ‏.‏\hadithno{2489}\hadithtrans{This hadith has been transmitted on the authority of 'A'isha in a similar manner except a slight variation that he said:" That is a gift for us out of it}}
\hadithdefcmd{muslim}{2490}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ خَالِدٍ، عَنْ حَفْصَةَ، عَنْ أُمِّ عَطِيَّةَ، قَالَتْ بَعَثَ إِلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم بِشَاةٍ مِنَ الصَّدَقَةِ فَبَعَثْتُ إِلَى عَائِشَةَ مِنْهَا بِشَىْءٍ فَلَمَّا جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى عَائِشَةَ قَالَ ‏"‏ هَلْ عِنْدَكُمْ شَىْءٌ ‏"‏ ‏.‏ قَالَتْ لاَ ‏.‏ إِلاَّ أَنَّ نُسَيْبَةَ بَعَثَتْ إِلَيْنَا مِنَ الشَّاةِ الَّتِي بَعَثْتُمْ بِهَا إِلَيْهَا قَالَ ‏"‏ إِنَّهَا قَدْ بَلَغَتْ مَحِلَّهَا ‏"‏ ‏.‏\hadithno{2490}\hadithtrans{Umm 'Atiyya, said:The Messenger of Allah (ﷺ) sent me some mutton of sadaqa. I sent a piece out of that to 'A'isha. When the Messenger of Allah (ﷺ) came to 'A'isha, he said: Have you anything with you (to eat)? She said: Nothing, except only that mutton sent to us by Nusaiba (the kunya of Umm 'Atiyya) which you had sent to her. Whereupon he said: It has reached its proper place}}
\hadithdefcmd{muslim}{2491}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سَلاَّمٍ الْجُمَحِيُّ، حَدَّثَنَا الرَّبِيعُ، - يَعْنِي ابْنَ مُسْلِمٍ - عَنْ مُحَمَّدٍ، - وَهُوَ ابْنُ زِيَادٍ - عَنْ أَبِي هُرَيْرَةَ، ‏.‏ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أُتِيَ بِطَعَامٍ سَأَلَ عَنْهُ فَإِنْ قِيلَ هَدِيَّةٌ أَكَلَ مِنْهَا وَإِنْ قِيلَ صَدَقَةٌ لَمْ يَأْكُلْ مِنْهَا ‏.‏\hadithno{2491}\hadithtrans{Abu Huraira reported:Whenever the Messenger of Allah (ﷺ) was presented with food, he asked about it, If he was told that it was a gift, he ate out of that, and if he was told that it was a sadaqa he did not eat out of that}}
\hadithdefcmd{muslim}{2492}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ قَالَ يَحْيَى أَخْبَرَنَا وَكِيعٌ، عَنْ شُعْبَةَ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى، ح . وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، عَنْ شُعْبَةَ، عَنْ عَمْرٍو، - وَهُوَ ابْنُ مُرَّةَ - حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي أَوْفَى، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَتَاهُ قَوْمٌ بِصَدَقَتِهِمْ قَالَ ‏"‏ اللَّهُمَّ صَلِّ عَلَيْهِمْ ‏"‏ ‏.‏ فَأَتَاهُ أَبِي أَبُو أَوْفَى بِصَدَقَتِهِ فَقَالَ ‏"‏ اللَّهُمَّ صَلِّ عَلَى آلِ أَبِي أَوْفَى ‏"‏ ‏.‏\hadithno{2492}\hadithtrans{Abdullah b. Abu Aufa said that it was the common practice of the Messenger of Allah (ﷺ) that when the people brought to him sadaqa he blessed them:O Allah, bless them. So when Abu Aufa brought to him Sadaqa he (the Holy Prophet) said: O Allah, bless, the posterity of Abu Aufa}}
\hadithdefcmd{muslim}{2493}{وَحَدَّثَنَاهُ ابْنُ نُمَيْرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ شُعْبَةَ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّهُ قَالَ ‏ "‏ صَلِّ عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{2493}\hadithtrans{This hadith has been narrated by Shu'ba with the same chain of transmitters (but with a slight variation of words, that he said):(O Allah), bless them}}
\hadithdefcmd{muslim}{2494}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، وَأَبُو خَالِدٍ الأَحْمَرُ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، وَابْنُ، أَبِي عَدِيٍّ وَعَبْدُ الأَعْلَى كُلُّهُمْ عَنْ دَاوُدَ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا دَاوُدُ، عَنِ الشَّعْبِيِّ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَتَاكُمُ الْمُصَدِّقُ فَلْيَصْدُرْ عَنْكُمْ وَهُوَ عَنْكُمْ رَاضٍ ‏"‏ ‏.‏\hadithno{2494}\hadithtrans{Jarir b. 'Abdullah said:'When the collector of sadaqat (Zakat) comes to you, (you should see) that he goes away pleased with you}}
