% Auto-generated chapter 61 for bukhari
% Hadiths in this chapter: 151

\hadithdefcmd{bukhari}{3489}{حَدَّثَنَا خَالِدُ بْنُ يَزِيدَ الْكَاهِلِيُّ، حَدَّثَنَا أَبُو بَكْرٍ، عَنْ أَبِي حَصِينٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسِ، رضى الله عنهما‏.‏ ‏\{‏وَجَعَلْنَاكُمْ شُعُوبًا وَقَبَائِلَ‏\}‏ قَالَ الشُّعُوبُ الْقَبَائِلُ الْعِظَامُ، وَالْقَبَائِلُ الْبُطُونُ‏.‏\hadithno{3489}\hadithtrans{Narrated Ibn `Abbas:Regarding the Verse: 'And (We) made you into Shu'ub and Qabail-- (49.13) that Shu'ub means the big Qabail (i.e. nations) while the Qabail (i.e. tribes) means the branch tribes}}
\hadithdefcmd{bukhari}{3490}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قِيلَ يَا رَسُولَ اللَّهِ مَنْ أَكْرَمُ النَّاسِ قَالَ ‏"‏ أَتْقَاهُمْ ‏"‏‏.‏ قَالُوا لَيْسَ عَنْ هَذَا نَسْأَلُكَ‏.‏ قَالَ ‏"‏ فَيُوسُفُ نَبِيُّ اللَّهِ ‏"‏‏.‏\hadithno{3490}\hadithtrans{Narrated Abu Huraira:Once Allah's Messenger (ﷺ) was asked, "Who is the most honorable amongst the people?" He said, "The most righteous (i.e. Allah-fearing) amongst you." They said, "We do not ask you about this." He said, "Then Joseph, the prophet of Allah}}
\hadithdefcmd{bukhari}{3491}{حَدَّثَنَا قَيْسُ بْنُ حَفْصٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا كُلَيْبُ بْنُ وَائِلٍ، قَالَ حَدَّثَتْنِي رَبِيبَةُ النَّبِيِّ، صلى الله عليه وسلم زَيْنَبُ ابْنَةُ أَبِي سَلَمَةَ قَالَ قُلْتُ لَهَا أَرَأَيْتِ النَّبِيَّ صلى الله عليه وسلم أَكَانَ مِنْ مُضَرَ قَالَتْ فَمِمَّنْ كَانَ إِلاَّ مِنْ مُضَرَ مِنْ بَنِي النَّضْرِ بْنِ كِنَانَةَ‏.‏\hadithno{3491}\hadithtrans{Narrated Kulaib bin Wail:I asked Zainab bint Abi Salama (i.e. daughter of the wife of the Prophet, "Tell me about the Prophet (ﷺ) . Did he belong to the tribe of Mudar?" She replied, "Yes, he belonged to the tribe of Mudar and was from the offspring of An-Nadr bin Kinana}}
\hadithdefcmd{bukhari}{3492}{حَدَّثَنَا مُوسَى، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا كُلَيْبٌ، حَدَّثَتْنِي رَبِيبَةُ النَّبِيِّ، صلى الله عليه وسلم وَأَظُنُّهَا زَيْنَبَ قَالَتْ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالْمُقَيَّرِ وَالْمُزَفَّتِ‏.‏ وَقُلْتُ لَهَا أَخْبِرِينِي النَّبِيُّ صلى الله عليه وسلم مِمَّنْ كَانَ مِنْ مُضَرَ كَانَ قَالَتْ فَمِمَّنْ كَانَ إِلاَّ مِنْ مُضَرَ، كَانَ مِنْ وَلَدِ النَّضْرِ بْنِ كِنَانَةَ‏.‏\hadithno{3492}\hadithtrans{Narrated Kulaib:I was told by the Rabiba (i.e. daughter of the wife of the Prophet) who, I think, was Zainab, that the Prophet (forbade the utensils (of wine called) Ad-Dubba, Al-Hantam, Al-Muqaiyar and Al-Muzaffat. I said to her, 'Tell me as to which tribe the Prophet (ﷺ) belonged; was he from the tribe of Mudar?'' She replied, "He belonged to the tribe of Mudar and was from the offspring of An-Nadr bin Kinana}}
\hadithdefcmd{bukhari}{3494}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ تَجِدُونَ النَّاسَ مَعَادِنَ، خِيَارُهُمْ فِي الْجَاهِلِيَّةِ خِيَارُهُمْ فِي الإِسْلاَمِ إِذَا فَقِهُوا، وَتَجِدُونَ خَيْرَ النَّاسِ فِي هَذَا الشَّأْنِ أَشَدَّهُمْ لَهُ كَرَاهِيَةً ‏"‏‏.‏ ‏"‏ وَتَجِدُونَ شَرَّ النَّاسِ ذَا الْوَجْهَيْنِ، الَّذِي يَأْتِي هَؤُلاَءِ بِوَجْهٍ، وَيَأْتِي هَؤُلاَءِ بِوَجْهٍ ‏"‏‏.‏\hadithno{3494}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "You see that the people are of different natures. Those who were the best in the pre-Islamic period, are also the best in Islam if they comprehend religious knowledge. You see that the best amongst the people in this respect (i.e. ambition of ruling) are those who hate it most. And you see that the worst among people is the double faced (person) who appears to these with one face and to the others with another face (i.e a hypocrite)}}
\hadithdefcmd{bukhari}{3496}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ النَّاسُ تَبَعٌ لِقُرَيْشٍ فِي هَذَا الشَّأْنِ، مُسْلِمُهُمْ تَبَعٌ لِمُسْلِمِهِمْ، وَكَافِرُهُمْ تَبَعٌ لِكَافِرِهِمْ ‏"‏‏.‏ "وَالنَّاسُ مَعَادِنُ، خِيَارُهُمْ فِي الْجَاهِلِيَّةِ خِيَارُهُمْ فِي الإِسْلاَمِ إِذَا فَقِهُوا، تَجِدُونَ مِنْ خَيْرِ النَّاسِ أَشَدَّ النَّاسِ كَرَاهِيَةً لِهَذَا الشَّأْنِ حَتَّى يَقَعَ فِيهِ\hadithno{3496}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The tribe of Quraish has precedence over the people in this connection (i.e the right of ruling). The Muslims follow the Muslims amongst them, and the infidels follow the infidels amongst them. People are of different natures: The best amongst them in the pre-Islamic period are the best in Islam provided they comprehend the religious knowledge. You will find that the best amongst the people in this respect (i.e. of ruling) is he who hates it (i.e. the idea of ruling) most, till he is given the pledge of allegiance}}
\hadithdefcmd{bukhari}{3497}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، حَدَّثَنِي عَبْدُ الْمَلِكِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما – ‏\{‏إِلاَّ الْمَوَدَّةَ فِي الْقُرْبَى‏\}‏ قَالَ فَقَالَ سَعِيدُ بْنُ جُبَيْرٍ قُرْبَى مُحَمَّدٍ صلى الله عليه وسلم‏.‏ فَقَالَ إِنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَكُنْ بَطْنٌ مِنْ قُرَيْشٍ إِلاَّ وَلَهُ فِيهِ قَرَابَةٌ، فَنَزَلَتْ عَلَيْهِ إِلاَّ أَنْ تَصِلُوا قَرَابَةً بَيْنِي وَبَيْنَكُمْ‏.‏\hadithno{3497}\hadithtrans{Narrated Tawus:Ibn `Abbas recited the Qur'anic Verse:--'Except to be kind to me for my kin-ship to you--" (42.23) Sa`id bin Jubair said, "(The Verse implies) the kinship of Muhammad." Ibn `Abbas said, "There was not a single house (i.e. sub-tribe) of Quraish but had a kinship to the Prophet (ﷺ) and so the above Verse was revealed in this connection, and its interpretation is: 'O Quraish! You should keep good relation between me (i.e. Muhammad) and you}}
\hadithdefcmd{bukhari}{3498}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، عَنْ أَبِي مَسْعُودٍ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مِنْ هَا هُنَا جَاءَتِ الْفِتَنُ نَحْوَ الْمَشْرِقِ، وَالْجَفَاءُ وَغِلَظُ الْقُلُوبِ فِي الْفَدَّادِينَ أَهْلِ الْوَبَرِ عِنْدَ أُصُولِ أَذْنَابِ الإِبِلِ، وَالْبَقَرِ فِي رَبِيعَةَ وَمُضَرَ ‏"‏‏.‏\hadithno{3498}\hadithtrans{Narrated Abi Mas`ud:The Prophet (ﷺ) said, "From this side from the east, afflictions will appear. Rudeness and lack of mercy are characteristics of the rural bedouins who are busy with their camels and cows (and pay no attention to religion). Such are the tribes of Rabi`a and Mudar}}
\hadithdefcmd{bukhari}{3499}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْفَخْرُ وَالْخُيَلاَءُ فِي الْفَدَّادِينَ أَهْلِ الْوَبَرِ، وَالسَّكِينَةُ فِي أَهْلِ الْغَنَمِ، وَالإِيمَانُ يَمَانٍ، وَالْحِكْمَةُ يَمَانِيَةٌ ‏"‏‏.‏ سُمِّيَتِ الْيَمَنَ لأَنَّهَا عَنْ يَمِينِ الْكَعْبَةِ، وَالشَّأْمَ عَنْ يَسَارِ الْكَعْبَةِ، وَالْمَشْأَمَةُ الْمَيْسَرَةُ، وَالْيَدُ الْيُسْرَى الشُّؤْمَى، وَالْجَانِبُ الأَيْسَرُ الأَشْأَمُ‏.‏\hadithno{3499}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "Pride and arrogance are characteristics of the rural bedouins while calmness is found among the owners of sheep. Belief is Yemenite, and wisdom is also Yemenite i.e. the Yemenites are well-known for their true belief and wisdom)." Abu `Abdullah (Al-Bukhari) said, "Yemen was called so because it is situated to the right of the Ka`ba, and Sham was called so because it is situated to the left of the Ka`ba}}
\hadithdefcmd{bukhari}{3500}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ كَانَ مُحَمَّدُ بْنُ جُبَيْرِ بْنِ مُطْعِمٍ يُحَدِّثُ أَنَّهُ بَلَغَ مُعَاوِيَةَ وَهْوَ عِنْدَهُ فِي وَفْدٍ مِنْ قُرَيْشٍ أَنَّ عَبْدَ اللَّهِ بْنَ عَمْرِو بْنِ الْعَاصِ يُحَدِّثُ أَنَّهُ سَيَكُونُ مَلِكٌ مِنْ قَحْطَانَ، فَغَضِبَ مُعَاوِيَةُ، فَقَامَ فَأَثْنَى عَلَى اللَّهِ بِمَا هُوَ أَهْلُهُ، ثُمَّ قَالَ أَمَّا بَعْدُ فَإِنَّهُ بَلَغَنِي أَنَّ رِجَالاً مِنْكُمْ يَتَحَدَّثُونَ أَحَادِيثَ لَيْسَتْ فِي كِتَابِ اللَّهِ، وَلاَ تُؤْثَرُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم، فَأُولَئِكَ جُهَّالُكُمْ، فَإِيَّاكُمْ وَالأَمَانِيَّ الَّتِي تُضِلُّ أَهْلَهَا، فَإِنِّي سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ هَذَا الأَمْرَ فِي قُرَيْشٍ، لاَ يُعَادِيهِمْ أَحَدٌ إِلاَّ كَبَّهُ اللَّهُ عَلَى وَجْهِهِ، مَا أَقَامُوا الدِّينَ ‏"‏‏.‏\hadithno{3500}\hadithtrans{Narrated Muhammad bin Jubair bin Mut`im:That while he was with a delegation from Quraish to Muawiya, the latter heard the news that `Abdullah bin `Amr bin Al-`As said that there would be a king from the tribe of Qahtan. On that Muawiya became angry, got up and then praised Allah as He deserved, and said, "Now then, I have heard that some men amongst you narrate things which are neither in the Holy Book, nor have been told by Allah's Messenger (ﷺ). Those men are the ignorant amongst you. Beware of such hopes as make the people go astray, for I heard Allah's Messenger (ﷺ) saying, 'Authority of ruling will remain with Quraish, and whoever bears hostility to them, Allah will destroy him as long as they abide by the laws of the religion}}
\hadithdefcmd{bukhari}{3501}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا عَاصِمُ بْنُ مُحَمَّدٍ، قَالَ سَمِعْتُ أَبِي، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لا يَزَالُ هَذَا الأَمْرُ فِي قُرَيْشٍ، مَا بَقِيَ مِنْهُمُ اثْنَانِ ‏"‏‏.‏\hadithno{3501}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "Authority of ruling will remain with Quraish, even if only two of them remained}}
\hadithdefcmd{bukhari}{3502}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ جُبَيْرِ بْنِ مُطْعِمٍ، قَالَ مَشَيْتُ أَنَا وَعُثْمَانُ بْنُ عَفَّانَ،، فَقَالَ يَا رَسُولَ اللَّهِ أَعْطَيْتَ بَنِي الْمُطَّلِبِ وَتَرَكْتَنَا، وَإِنَّمَا نَحْنُ وَهُمْ مِنْكَ بِمَنْزِلَةٍ وَاحِدَةٍ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنَّمَا بَنُو هَاشِمٍ وَبَنُو الْمُطَّلِبِ شَىْءٌ وَاحِدٌ ‏"‏‏.‏\hadithno{3502}\hadithtrans{Narrated Jubair bin Mut`im:`Uthman bin `Affan went (to the Prophet) and said, "O Allah's Messenger (ﷺ)! You gave property to Bani Al-Muttalib and did not give us, although we and they are of the same degree of relationship to you." The Prophet (ﷺ) said, "Only Bani Hashim and Bani Al Muttalib are one thing (as regards family status)}}
\hadithdefcmd{bukhari}{3503}{وَقَالَ اللَّيْثُ حَدَّثَنِي أَبُو الأَسْوَدِ، مُحَمَّدٌ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، قَالَ ذَهَبَ عَبْدُ اللَّهِ بْنُ الزُّبَيْرِ مَعَ أُنَاسٍ مِنْ بَنِي زُهْرَةَ إِلَى عَائِشَةَ، وَكَانَتْ أَرَقَّ شَىْءٍ لِقَرَابَتِهِمْ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{3503}\hadithtrans{Narrated `Urwa bin Az-Zubair: `Abdullah bin Az-Zubair went with some women of the tribe of Bani Zuhra to `Aisha who used to treat them nicely because of their relation to Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{3504}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ سَعْدٍ، ح قَالَ يَعْقُوبُ بْنُ إِبْرَاهِيمَ حَدَّثَنَا أَبِي، عَنْ أَبِيهِ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ هُرْمُزَ الأَعْرَجُ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قُرَيْشٌ وَالأَنْصَارُ وَجُهَيْنَةُ وَمُزَيْنَةُ وَأَسْلَمُ وَأَشْجَعُ وَغِفَارُ مَوَالِيَّ لَيْسَ لَهُمْ مَوْلًى، دُونَ اللَّهِ وَرَسُولِهِ ‏"‏‏.‏\hadithno{3504}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The tribe of Quraish, the Ansar, the (people of the tribe of) Julhaina, Muzaina, Aslam, Ashja', and Ghifar are my disciples and have no protectors except Allah and His Apostle}}
\hadithdefcmd{bukhari}{3505}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، قَالَ حَدَّثَنِي أَبُو الأَسْوَدِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، قَالَ كَانَ عَبْدُ اللَّهِ بْنُ الزُّبَيْرِ أَحَبَّ الْبَشَرِ إِلَى عَائِشَةَ بَعْدَ النَّبِيِّ صلى الله عليه وسلم وَأَبِي بَكْرٍ، وَكَانَ أَبَرَّ النَّاسِ بِهَا، وَكَانَتْ لاَ تُمْسِكُ شَيْئًا مِمَّا جَاءَهَا مِنْ رِزْقِ اللَّهِ ‏\{‏إِلاَّ‏\}‏ تَصَدَّقَتْ‏.‏ فَقَالَ ابْنُ الزُّبَيْرِ يَنْبَغِي أَنْ يُؤْخَذَ عَلَى يَدَيْهَا‏.‏ فَقَالَتْ أَيُؤْخَذُ عَلَى يَدَىَّ عَلَىَّ نَذْرٌ إِنْ كَلَّمْتُهُ‏.‏ فَاسْتَشْفَعَ إِلَيْهَا بِرِجَالٍ مِنْ قُرَيْشٍ، وَبِأَخْوَالِ رَسُولِ اللَّهِ صلى الله عليه وسلم خَاصَّةً فَامْتَنَعَتْ، فَقَالَ لَهُ الزُّهْرِيُّونَ أَخْوَالُ النَّبِيِّ صلى الله عليه وسلم مِنْهُمْ عَبْدُ الرَّحْمَنِ بْنُ الأَسْوَدِ بْنِ عَبْدِ يَغُوثَ وَالْمِسْوَرُ بْنُ مَخْرَمَةَ إِذَا اسْتَأْذَنَّا فَاقْتَحِمِ الْحِجَابَ‏.‏ فَفَعَلَ، فَأَرْسَلَ إِلَيْهَا بِعَشْرِ رِقَابٍ، فَأَعْتَقَتْهُمْ، ثُمَّ لَمْ تَزَلْ تُعْتِقُهُمْ حَتَّى بَلَغَتْ أَرْبَعِينَ‏.‏ فَقَالَتْ وَدِدْتُ أَنِّي جَعَلْتُ حِينَ حَلَفْتُ عَمَلاً أَعْمَلُهُ فَأَفْرُغَ مِنْهُ‏.‏\hadithno{3505}\hadithtrans{Narrated `Urwa bin Az-Zubair:`Abdullah bin Az-Zubair was the most beloved person to `Aisha excluding the Prophet (ﷺ) and Abu Bakr, and he in his turn, was the most devoted to her, `Aisha used not to withhold the money given to her by Allah, but she used to spend it in charity. (`Abdullah) bin Az-Zubair said, " `Aisha should be stopped from doing so." (When `Aisha heard this), she said protestingly, "Shall I be stopped from doing so? I vow that I will never talk to `Abdullah bin Az-Zubair." On that, Ibn Az-Zubair asked some people from Quraish and particularly the two uncles of Allah's Messenger (ﷺ) to intercede with her, but she refused (to talk to him). Az-Zuhriyun, the uncles of the Prophet, including `Abdur-Rahman bin Al-Aswad bin `Abd Yaghuth and Al-Miswar bin Makhrama said to him, "When we ask for the permission to visit her, enter her house along with us (without taking her leave)." He did accordingly (and she accepted their intercession). He sent her ten slaves whom she manumitted as an expiation for (not keeping) her vow. `Aisha manumitted more slaves for the same purpose till she manumitted forty slaves. She said, "I wish I had specified what I would have done in case of not fulfilling my vow when I made the vow, so that I might have done it easily}}
\hadithdefcmd{bukhari}{3506}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسٍ، أَنَّ عُثْمَانَ، دَعَا زَيْدَ بْنَ ثَابِتٍ وَعَبْدَ اللَّهِ بْنَ الزُّبَيْرِ وَسَعِيدَ بْنَ الْعَاصِ وَعَبْدَ الرَّحْمَنِ بْنَ الْحَارِثِ بْنِ هِشَامٍ فَنَسَخُوهَا فِي الْمَصَاحِفِ، وَقَالَ عُثْمَانُ لِلرَّهْطِ الْقُرَشِيِّينَ الثَّلاَثَةِ إِذَا اخْتَلَفْتُمْ أَنْتُمْ وَزَيْدُ بْنُ ثَابِتٍ فِي شَىْءٍ مِنَ الْقُرْآنِ، فَاكْتُبُوهُ بِلِسَانِ قُرَيْشٍ، فَإِنَّمَا نَزَلَ بِلِسَانِهِمْ‏.‏ فَفَعَلُوا ذَلِكَ‏.‏\hadithno{3506}\hadithtrans{Narrated Anas:`Uthman called Zaid bin Thabit, `Abdullah bin Az-Zubair, Sa`id bin Al-`As and `AbdurRahman bin Al-Harith bin Hisham, and then they wrote the manuscripts of the Holy Qur'an in the form of book in several copies. `Uthman said to the three Quraishi persons, "If you differ with Zaid bin Thabit on any point of the Qur'an, then write it in the language of Quraish, as the Qur'an was revealed in their language." So they acted accordingly. (Zaid bin Thabit was an Ansari and not from Quraish)}}
\hadithdefcmd{bukhari}{3507}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ يَزِيدَ بْنِ أَبِي عُبَيْدٍ، حَدَّثَنَا سَلَمَةُ ـ رضى الله عنه ـ قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى قَوْمٍ مِنْ أَسْلَمَ، يَتَنَاضَلُونَ بِالسُّوقِ، فَقَالَ ‏"‏ ارْمُوا بَنِي إِسْمَاعِيلَ، فَإِنَّ أَبَاكُمْ كَانَ رَامِيًا، وَأَنَا مَعَ بَنِي فُلاَنٍ ‏"‏‏.‏ لأَحَدِ الْفَرِيقَيْنِ، فَأَمْسَكُوا بِأَيْدِيهِمْ فَقَالَ ‏"‏ مَا لَهُمْ ‏"‏‏.‏ قَالُوا وَكَيْفَ نَرْمِي وَأَنْتَ مَعَ بَنِي فُلاَنٍ‏.‏ قَالَ ‏"‏ ارْمُوا وَأَنَا مَعَكُمْ كُلِّكُمْ ‏"‏‏.‏\hadithno{3507}\hadithtrans{Narrated Salama:Allah's Messenger (ﷺ) passed by some people from the tribe of Aslam practicing archery. He said, "O children of Ishmael! Throw (arrows), for your father was an archer. I am on the side of Bani so-and-so," meaning one of the two teams. The other team stopped throwing, whereupon the Prophet (ﷺ) said, "What has happened to them?" They replied, "How shall we throw while you are with Bani so-and-so?" He said, "Throw for I am with all of you}}
\hadithdefcmd{bukhari}{3508}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنِ الْحُسَيْنِ، عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، قَالَ حَدَّثَنِي يَحْيَى بْنُ يَعْمَرَ، أَنَّ أَبَا الأَسْوَدِ الدِّيلِيَّ، حَدَّثَهُ عَنْ أَبِي ذَرٍّ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَيْسَ مِنْ رَجُلٍ ادَّعَى لِغَيْرِ أَبِيهِ وَهْوَ يَعْلَمُهُ إِلاَّ كَفَرَ، وَمَنِ ادَّعَى قَوْمًا لَيْسَ لَهُ فِيهِمْ فَلْيَتَبَوَّأْ مَقْعَدَهُ مِنَ النَّارِ ‏"‏‏.‏\hadithno{3508}\hadithtrans{Narrated Abu Dhar:The Prophet (ﷺ) said, "If somebody claims to be the son of any other than his real father knowingly, he but disbelieves in Allah, and if somebody claims to belong to some folk to whom he does not belong, let such a person take his place in the (Hell) Fire}}
\hadithdefcmd{bukhari}{3509}{حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، حَدَّثَنَا حَرِيزٌ، قَالَ حَدَّثَنِي عَبْدُ الْوَاحِدِ بْنُ عَبْدِ اللَّهِ النَّصْرِيُّ، قَالَ سَمِعْتُ وَاثِلَةَ بْنَ الأَسْقَعِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ مِنْ أَعْظَمِ الْفِرَى أَنْ يَدَّعِيَ الرَّجُلُ إِلَى غَيْرِ أَبِيهِ، أَوْ يُرِيَ عَيْنَهُ مَا لَمْ تَرَ، أَوْ يَقُولُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مَا لَمْ يَقُلْ ‏"‏‏.‏\hadithno{3509}\hadithtrans{Narrated Wathila bin Al-Asqa:Allah's Messenger (ﷺ) said, "Verily, one of the worst lies is to claim falsely to be the son of someone other than one's real father, or to claim to have had a dream one has not had, or to attribute to me what I have not said}}
\hadithdefcmd{bukhari}{3510}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ، عَنْ أَبِي جَمْرَةَ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ قَدِمَ وَفْدُ عَبْدِ الْقَيْسِ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّا مِنْ هَذَا الْحَىِّ مِنْ رَبِيعَةَ قَدْ حَالَتْ بَيْنَنَا وَبَيْنَكَ كُفَّارُ مُضَرَ، فَلَسْنَا نَخْلُصُ إِلَيْكَ إِلاَّ فِي كُلِّ شَهْرٍ حَرَامٍ، فَلَوْ أَمَرْتَنَا بِأَمْرٍ، نَأْخُذُهُ عَنْكَ، وَنُبَلِّغُهُ مَنْ وَرَاءَنَا‏.‏ قَالَ ‏ "‏ آمُرُكُمْ بِأَرْبَعٍ، وَأَنْهَاكُمْ عَنْ أَرْبَعٍ، الإِيمَانِ بِاللَّهِ شَهَادَةِ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَإِقَامِ الصَّلاَةِ وَإِيتَاءِ الزَّكَاةِ، وَأَنْ تُؤَدُّوا إِلَى اللَّهِ خُمْسَ مَا غَنِمْتُمْ، وَأَنْهَاكُمْ عَنِ الدُّبَّاءِ، وَالْحَنْتَمِ، وَالنَّقِيرِ، وَالْمُزَفَّتِ ‏"‏‏.‏\hadithno{3510}\hadithtrans{Narrated Ibn `Abbas:The delegates of `Abd-ul-Qais came to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! We are from the tribe of Rabi`a and the infidels of Mudar tribe stand between us and you, so that we cannot come to you except in the Sacred Months. Therefore we would like you to give us some instructions which we may follow and convey to our people staying behind us." The Prophet (ﷺ) said, "I order you to observe four things and forbid you (to do) four things: (I order you) to believe in Allah testifying that None has the right to be worshipped except Allah; to offer the prayer perfectly; to pay the Zakat; and to give one-fifth of the war booty to Allah. And I forbid you to use Ad-Dubba, Al-Hantam, An-Naqir and Al- Muzaffat." (These are names of utensils in which alcoholic drinks were served)}}
\hadithdefcmd{bukhari}{3511}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ وَهْوَ عَلَى الْمِنْبَرِ ‏ "‏ أَلاَ إِنَّ الْفِتْنَةَ هَا هُنَا ـ يُشِيرُ إِلَى الْمَشْرِقِ ـ مِنْ حَيْثُ يَطْلُعُ قَرْنُ الشَّيْطَانِ ‏"‏‏.‏\hadithno{3511}\hadithtrans{Narrated `Abdullah bin `Umar:I heard Allah's Messenger (ﷺ) on the pulpit saying, "Verily, afflictions (will start) from here," pointing towards the east, "whence the side of the head of Satan comes out}}
\hadithdefcmd{bukhari}{3512}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ سَعْدٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ هُرْمُزَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ قُرَيْشٌ وَالأَنْصَارُ وَجُهَيْنَةُ وَمُزَيْنَةُ وَأَسْلَمُ وَغِفَارُ وَأَشْجَعُ مَوَالِيَّ، لَيْسَ لَهُمْ مَوْلًى دُونَ اللَّهِ وَرَسُولِهِ ‏"‏‏.‏\hadithno{3512}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The tribes of Quraish, Al-Ansar, Juhaina, Muzaina, Aslam, Ghifar and Ashja' are my helpers, and they have no protector (i.e. Master) except Allah and His Apostle}}
\hadithdefcmd{bukhari}{3513}{حَدَّثَنِي مُحَمَّدُ بْنُ غُرَيْرٍ الزُّهْرِيُّ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، عَنْ أَبِيهِ، عَنْ صَالِحٍ، حَدَّثَنَا نَافِعٌ، أَنَّ عَبْدَ اللَّهِ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ عَلَى الْمِنْبَرِ ‏ "‏ غِفَارُ غَفَرَ اللَّهُ لَهَا، وَأَسْلَمُ سَالَمَهَا اللَّهُ، وَعُصَيَّةُ عَصَتِ اللَّهَ وَرَسُولَهُ ‏"‏‏.‏\hadithno{3513}\hadithtrans{Narrated `Abdullah bin `Umar:While Allah's Messenger (ﷺ) was on the pulpit, he said, "May Allah forgive the tribe of Ghifar! And may Allah save the tribe of Aslam! The tribe of `Usaiya have disobeyed Allah and His Apostle}}
\hadithdefcmd{bukhari}{3514}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَسْلَمُ سَالَمَهَا اللَّهُ، وَغِفَارُ غَفَرَ اللَّهُ لَهَا ‏"‏‏.‏\hadithno{3514}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "May Allah save the tribe of Aslam, and may Allah forgive the tribe of Ghifar}}
\hadithdefcmd{bukhari}{3515}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ،‏.‏ حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَرَأَيْتُمْ إِنْ كَانَ جُهَيْنَةُ وَمُزَيْنَةُ وَأَسْلَمُ وَغِفَارُ خَيْرًا مِنْ بَنِي تَمِيمٍ وَبَنِي أَسَدٍ، وَمِنْ بَنِي عَبْدِ اللَّهِ بْنِ غَطَفَانَ وَمِنْ بَنِي عَامِرِ بْنِ صَعْصَعَةَ ‏"‏‏.‏ فَقَالَ رَجُلٌ خَابُوا وَخَسِرُوا‏.‏ فَقَالَ ‏"‏ هُمْ خَيْرٌ مِنْ بَنِي تَمِيمٍ وَمِنْ بَنِي أَسَدٍ، وَمِنْ بَنِي عَبْدِ اللَّهِ بْنِ غَطَفَانَ، وَمِنْ بَنِي عَامِرِ بْنِ صَعْصَعَةَ ‏"‏‏.‏\hadithno{3515}\hadithtrans{Narrated Abu Bakra:The Prophet (ﷺ) said, "Do you think that the tribes of Juhaina, Muzaina, Aslam and Ghifar are better than the tribes of Bani Tamim, Bani Asad, Bani `Abdullah bin Ghatafan and Bani Amir bin Sasaa?" A man said, "They were unsuccessful and losers." The Prophet (ﷺ) added, "(Yes), they are better than the tribes of Bani Tamim, Bani Asad, Bani `Abdullah bin Ghatafan and Bani Amir bin Sasaa}}
\hadithdefcmd{bukhari}{3516}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ أَبِي يَعْقُوبَ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، أَنَّ الأَقْرَعَ بْنَ حَابِسٍ، قَالَ لِلنَّبِيِّ صلى الله عليه وسلم إِنَّمَا بَايَعَكَ سُرَّاقُ الْحَجِيجِ مِنْ أَسْلَمَ وَغِفَارَ وَمُزَيْنَةَ ـ وَأَحْسِبُهُ وَجُهَيْنَةَ ابْنُ أَبِي يَعْقُوبَ شَكَّ ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَرَأَيْتَ إِنْ كَانَ أَسْلَمُ وَغِفَارُ وَمُزَيْنَةُ ـ وَأَحْسِبُهُ ـ وَجُهَيْنَةُ خَيْرًا مِنْ بَنِي تَمِيمٍ وَبَنِي عَامِرٍ وَأَسَدٍ وَغَطَفَانَ، خَابُوا وَخَسِرُوا ‏"‏‏.‏ قَالَ نَعَمْ‏.‏ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ، إِنَّهُمْ لَخَيْرٌ مِنْهُمْ ‏"‏‏.‏\hadithno{3516}\hadithtrans{Narrated Abu Bakra:Al-Aqra' bin Habis said to the Prophet (ﷺ) "Nobody gave you the pledge of allegiance but the robbers of the pilgrims (i.e. those who used to rob the pilgrims) from the tribes of Aslam, Ghifar, Muzaina." (Ibn Abi Ya'qub is in doubt whether Al-Aqra' added. 'And Juhaina.') The Prophet (ﷺ) said, "Don't you think that the tribes of Aslam, Ghifar, Muzaina (and also perhaps) Juhaina are better than the tribes of Bani Tamim, Bani Amir, Asad, and Ghatafan?" Somebody said, "They were unsuccessful and losers!" The Prophet said, "Yes, by Him in Whose Hands my life is, they (i.e. the former) are better than they (i.e. the latter)}}
\hadithdefcmd{bukhari}{3517}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ ثَوْرِ بْنِ زَيْدٍ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَخْرُجَ رَجُلٌ مِنْ قَحْطَانَ يَسُوقُ النَّاسَ بِعَصَاهُ ‏"‏‏.‏\hadithno{3517}\hadithtrans{Narrated Abu Hurairah (ra):The Prophet (ﷺ) said, "The hour will not be established unless a man from the tribe of Qahtan appears, driving the people with his stick (ruling them with violence and oppression)}}
\hadithdefcmd{bukhari}{3518}{حَدَّثَنَا مُحَمَّدٌ، أَخْبَرَنَا مَخْلَدُ بْنُ يَزِيدَ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي عَمْرُو بْنُ دِينَارٍ، أَنَّهُ سَمِعَ جَابِرًا ـ رضى الله عنه ـ يَقُولُ غَزَوْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم وَقَدْ ثَابَ مَعَهُ نَاسٌ مِنَ الْمُهَاجِرِينَ حَتَّى كَثُرُوا، وَكَانَ مِنَ الْمُهَاجِرِينَ رَجُلٌ لَعَّابٌ فَكَسَعَ أَنْصَارِيًّا، فَغَضِبَ الأَنْصَارِيُّ غَضَبًا شَدِيدًا، حَتَّى تَدَاعَوْا، وَقَالَ الأَنْصَارِيُّ يَا لَلأَنْصَارِ‏.‏ وَقَالَ الْمُهَاجِرِيُّ يَا لَلْمُهَاجِرِينَ‏.‏ فَخَرَجَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ مَا بَالُ دَعْوَى أَهْلِ الْجَاهِلِيَّةِ ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ مَا شَأْنُهُمْ ‏"‏‏.‏ فَأُخْبِرَ بِكَسْعَةِ الْمُهَاجِرِيِّ الأَنْصَارِيَّ قَالَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ دَعُوهَا فَإِنَّهَا خَبِيثَةٌ ‏"‏‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ أُبَىٍّ ابْنُ سَلُولَ أَقَدْ تَدَاعَوْا عَلَيْنَا، لَئِنْ رَجَعْنَا إِلَى الْمَدِينَةِ لَيُخْرِجَنَّ الأَعَزُّ مِنْهَا الأَذَلَّ‏.‏ فَقَالَ عُمَرُ أَلاَ نَقْتُلُ يَا رَسُولَ اللَّهِ هَذَا الْخَبِيثَ لِعَبْدِ اللَّهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ يَتَحَدَّثُ النَّاسُ أَنَّهُ كَانَ يَقْتُلُ أَصْحَابَهُ ‏"‏‏.‏\hadithno{3518}\hadithtrans{Narrated Jabir:We were in the company of the Prophet (ﷺ) in a Ghazwa. A large number of emigrants joined him and among the emigrants there was a person who used to play jokes (or play with spears); so he (jokingly) stroked an Ansari man on the hip. The Ansari got so angry that both of them called their people. The Ansari said, "Help, O Ansar!" And the emigrant said "Help, O emigrants!" The Prophet (ﷺ) came out and said, "What is wrong with the people (as they are calling) this call of the period of Ignorance? "Then he said, "What is the matter with them?" So he was told about the stroke of the emigrant to the Ansari. The Prophet (ﷺ) said, "Stop this (i.e. appeal for help) for it is an evil call. "Abdullah bin Ubai bin Salul (a hypocrite) said, "The emigrants have called and (gathered against us); so when we return to Medina, surely, the more honorable people will expel therefrom the meaner," Upon that `Umar said, "O Allah's Prophet! Shall we not kill this evil person (i.e. `Abdullah bin Ubai bin Salul) ?" The Prophet) said, "(No), lest the people should say that Muhammad used to kill his companions}}
\hadithdefcmd{bukhari}{3519}{حَدَّثَنِي ثَابِتُ بْنُ مُحَمَّدٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَعَنْ سُفْيَانَ، عَنْ زُبَيْدٍ، عَنْ إِبْرَاهِيمَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ لَيْسَ مِنَّا مَنْ ضَرَبَ الْخُدُودَ، وَشَقَّ الْجُيُوبَ، وَدَعَا بِدَعْوَى الْجَاهِلِيَّةِ ‏"‏‏.‏\hadithno{3519}\hadithtrans{Narrated `Abdullah (bin Mas`ud):The Prophet (ﷺ) said, "Who-ever slaps his face or tears the bosom of his dress, or calls the calls of the Period of Ignorance, is not from us}}
\hadithdefcmd{bukhari}{3520}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، أَخْبَرَنَا إِسْرَائِيلُ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عَمْرُو بْنُ لُحَىِّ بْنِ قَمَعَةَ بْنِ خِنْدِفَ أَبُو خُزَاعَةَ ‏"‏‏.‏\hadithno{3520}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "`Amr bin Luhai bin Qam'a bin Khindif was the father of Khuza`a}}
\hadithdefcmd{bukhari}{3521}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ سَمِعْتُ سَعِيدَ بْنَ الْمُسَيَّبِ، قَالَ الْبَحِيرَةُ الَّتِي يُمْنَعُ دَرُّهَا لِلطَّوَاغِيتِ وَلاَ يَحْلُبُهَا أَحَدٌ مِنَ النَّاسِ، وَالسَّائِبَةُ الَّتِي كَانُوا يُسَيِّبُونَهَا لآلِهَتِهِمْ فَلاَ يُحْمَلُ عَلَيْهَا شَىْءٌ‏.‏ قَالَ وَقَالَ أَبُو هُرَيْرَةَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ رَأَيْتُ عَمْرَو بْنَ عَامِرِ بْنِ لُحَىٍّ الْخُزَاعِيَّ يَجُرُّ قُصْبَهُ فِي النَّارِ، وَكَانَ أَوَّلَ مَنْ سَيَّبَ السَّوَائِبَ ‏"‏‏.‏\hadithno{3521}\hadithtrans{Narrated Sa`id bin Al-Musaiyab:Al-Bahira was an animal whose milk was spared for the idols and other deities, and so nobody was allowed to milk it. As-Saiba was an animal which they (i.e. infidels) used to set free in the names of their gods so that it would not be used for carrying anything. Abu Huraira said, "The Prophet (ﷺ) said, 'I saw `Amr bin 'Amir bin Luhai Al-Khuza`i dragging his intestines in the (Hell) Fire, for he was the first man who started the custom of releasing animals (for the sake of false gods)}}
\hadithdefcmd{bukhari}{3522}{حَدَّثَنَا زَيْدٌ ـ هُوَ ابْنُ أَخْزَمَ ـ قَالَ أَبُو قُتَيْبَةَ سَلْمُ بْنُ قُتَيْبَةَ حَدَّثَنِي مُثَنَّى بْنُ سَعِيدٍ الْقَصِيرُ، قَالَ حَدَّثَنِي أَبُو جَمْرَةَ، قَالَ لَنَا ابْنُ عَبَّاسِ أَلاَ أُخْبِرُكُمْ بِإِسْلاَمِ أَبِي ذَرٍّ، قَالَ قُلْنَا بَلَى‏.‏ قَالَ قَالَ أَبُو ذَرٍّ كُنْتُ رَجُلاً مِنْ غِفَارٍ، فَبَلَغَنَا أَنَّ رَجُلاً قَدْ خَرَجَ بِمَكَّةَ، يَزْعُمُ أَنَّهُ نَبِيٌّ، فَقُلْتُ لأَخِي انْطَلِقْ إِلَى هَذَا الرَّجُلِ كَلِّمْهُ وَأْتِنِي بِخَبَرِهِ‏.‏ فَانْطَلَقَ فَلَقِيَهُ، ثُمَّ رَجَعَ فَقُلْتُ مَا عِنْدَكَ فَقَالَ وَاللَّهِ لَقَدْ رَأَيْتُ رَجُلاً يَأْمُرُ بِالْخَيْرِ وَيَنْهَى عَنِ الشَّرِّ‏.‏ فَقُلْتُ لَهُ لَمْ تَشْفِنِي مِنَ الْخَبَرِ‏.‏ فَأَخَذْتُ جِرَابًا وَعَصًا، ثُمَّ أَقْبَلْتُ إِلَى مَكَّةَ فَجَعَلْتُ لاَ أَعْرِفُهُ، وَأَكْرَهُ أَنْ أَسْأَلَ عَنْهُ، وَأَشْرَبُ مِنْ مَاءِ زَمْزَمَ وَأَكُونُ فِي الْمَسْجِدِ‏.‏ قَالَ فَمَرَّ بِي عَلِيٌّ فَقَالَ كَأَنَّ الرَّجُلَ غَرِيبٌ‏.‏ قَالَ قُلْتُ نَعَمْ‏.‏ قَالَ فَانْطَلِقْ إِلَى الْمَنْزِلِ‏.‏ قَالَ فَانْطَلَقْتُ مَعَهُ لاَ يَسْأَلُنِي عَنْ شَىْءٍ، وَلاَ أُخْبِرُهُ، فَلَمَّا أَصْبَحْتُ غَدَوْتُ إِلَى الْمَسْجِدِ لأَسْأَلَ عَنْهُ، وَلَيْسَ أَحَدٌ يُخْبِرُنِي عَنْهُ بِشَىْءٍ‏.‏ قَالَ فَمَرَّ بِي عَلِيٌّ فَقَالَ أَمَا نَالَ لِلرَّجُلِ يَعْرِفُ مَنْزِلَهُ بَعْدُ قَالَ قُلْتُ لاَ‏.‏ قَالَ انْطَلِقْ مَعِي‏.‏ قَالَ فَقَالَ مَا أَمْرُكَ وَمَا أَقْدَمَكَ هَذِهِ الْبَلْدَةَ قَالَ قُلْتُ لَهُ إِنْ كَتَمْتَ عَلَىَّ أَخْبَرْتُكَ‏.‏ قَالَ فَإِنِّي أَفْعَلُ‏.‏ قَالَ قُلْتُ لَهُ بَلَغَنَا أَنَّهُ قَدْ خَرَجَ هَا هُنَا رَجُلٌ يَزْعُمُ أَنَّهُ نَبِيٌّ، فَأَرْسَلْتُ أَخِي لِيُكَلِّمَهُ فَرَجَعَ وَلَمْ يَشْفِنِي مِنَ الْخَبَرِ، فَأَرَدْتُ أَنْ أَلْقَاهُ‏.‏ فَقَالَ لَهُ أَمَا إِنَّكَ قَدْ رَشَدْتَ، هَذَا وَجْهِي إِلَيْهِ، فَاتَّبِعْنِي، ادْخُلْ حَيْثُ أَدْخُلُ، فَإِنِّي إِنْ رَأَيْتُ أَحَدًا أَخَافُهُ عَلَيْكَ، قُمْتُ إِلَى الْحَائِطِ، كَأَنِّي أُصْلِحُ نَعْلِي، وَامْضِ أَنْتَ، فَمَضَى وَمَضَيْتُ مَعَهُ، حَتَّى دَخَلَ وَدَخَلْتُ مَعَهُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقُلْتُ لَهُ اعْرِضْ عَلَىَّ الإِسْلاَمَ‏.‏ فَعَرَضَهُ فَأَسْلَمْتُ مَكَانِي، فَقَالَ لِي ‏ "‏ يَا أَبَا ذَرٍّ اكْتُمْ هَذَا الأَمْرَ، وَارْجِعْ إِلَى بَلَدِكَ، فَإِذَا بَلَغَكَ ظُهُورُنَا فَأَقْبِلْ ‏"‏‏.‏ فَقُلْتُ وَالَّذِي بَعَثَكَ بِالْحَقِّ لأَصْرُخَنَّ بِهَا بَيْنَ أَظْهُرِهِمْ‏.‏ فَجَاءَ إِلَى الْمَسْجِدِ، وَقُرَيْشٌ فِيهِ فَقَالَ يَا مَعْشَرَ قُرَيْشٍ، إِنِّي أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ‏.‏ فَقَالُوا قُومُوا إِلَى هَذَا الصَّابِئِ‏.‏ فَقَامُوا فَضُرِبْتُ لأَمُوتَ فَأَدْرَكَنِي الْعَبَّاسُ، فَأَكَبَّ عَلَىَّ ثُمَّ أَقْبَلَ عَلَيْهِمْ، فَقَالَ وَيْلَكُمْ تَقْتُلُونَ رَجُلاً مِنْ غِفَارَ، وَمَتْجَرُكُمْ وَمَمَرُّكُمْ عَلَى غِفَارَ‏.‏ فَأَقْلَعُوا عَنِّي، فَلَمَّا أَنْ أَصْبَحْتُ الْغَدَ رَجَعْتُ فَقُلْتُ مِثْلَ مَا قُلْتُ بِالأَمْسِ، فَقَالُوا قُومُوا إِلَى هَذَا الصَّابِئِ‏.‏ فَصُنِعَ ‏\{‏بِي‏\}‏ مِثْلَ مَا صُنِعَ بِالأَمْسِ وَأَدْرَكَنِي الْعَبَّاسُ فَأَكَبَّ عَلَىَّ، وَقَالَ مِثْلَ مَقَالَتِهِ بِالأَمْسِ‏.‏ قَالَ فَكَانَ هَذَا أَوَّلَ إِسْلاَمِ أَبِي ذَرٍّ رَحِمَهُ اللَّهُ‏.‏\hadithno{3522}\hadithtrans{Narrated Abu Jamra:Ibn `Abbas said to us, "Shall I tell you the story of Abu Dhar's conversion to Islam?" We said, "Yes." He said, "Abu Dhar said: I was a man from the tribe of Ghifar. We heard that a man had appeared in Mecca, claiming to be a Prophet. I said to my brother, 'Go to that man and talk to him and bring me his news.' He set out, met him and returned. I asked him, 'What is the news with you?' He said, 'By Allah, I saw a man enjoining what is good and forbidding what is evil.' I said to him, 'You have not satisfied me with this little information.' So, I took a waterskin and a stick and proceeded towards Mecca. Neither did I know him (i.e. the Prophet (ﷺ) ), nor did I like to ask anyone about him. I Kept on drinking Zam zam water and staying in the Mosque. Then `Ali passed by me and said, 'It seems you are a stranger?' I said, 'Yes.' He proceeded to his house and I accompanied him. Neither did he ask me anything, nor did I tell him anything. Next morning I went to the Mosque to ask about the Prophet but no-one told me anything about him. `Ali passed by me again and asked, 'Hasn't the man recognized his dwelling place yet' I said, 'No.' He said, 'Come along with me.' He asked me, 'What is your business? What has brought you to this town?' I said to him, 'If you keep my secret, I will tell you.' He said, 'I will do.' I said to him, 'We have heard that a person has appeared here, claiming to be a Prophet. I sent my brother to speak to him and when he returned, he did not bring a satisfactory report; so I thought of meeting him personally.' `Ali said (to Abu Dhar), 'You have reached your goal; I am going to him just now, so follow me, and wherever I enter, enter after me. If I should see someone who may cause you trouble, I will stand near a wall pretending to mend my shoes (as a warning), and you should go away then.' `Ali proceeded and I accompanied him till he entered a place, and I entered with him to the Prophet (ﷺ) to whom I said, 'Present (the principles of) Islam to me.' When he did, I embraced Islam 'immediately. He said to me, 'O Abu Dhar! Keep your conversion as a secret and return to your town; and when you hear of our victory, return to us. ' I said, 'By Him Who has sent you with the Truth, I will announce my conversion to Islam publicly amongst them (i.e. the infidels),' Abu Dhar went to the Mosque, where some people from Quraish were present, and said, 'O folk of Quraish ! I testify that None has the right to be worshipped except Allah, and I (also) testify that Muhammad is Allah's Slave and His Apostle.' (Hearing that) the Quraishi men said, 'Get at this Sabi (i.e. Muslim) !' They got up and beat me nearly to death. Al `Abbas saw me and threw himself over me to protect me. He then faced them and said, 'Woe to you! You want to kill a man from the tribe of Ghifar, although your trade and your communications are through the territory of Ghifar?' They therefore left me. The next morning I returned (to the Mosque) and said the same as I had said on the previous day. They again said, 'Get at this Sabi!' I was treated in the same way as on the previous day, and again Al-Abbas found me and threw himself over me to protect me and told them the same as he had said the day before.' So, that was the conversion of Abu Dhar (may Allah be Merciful to him) to Islam}}
\hadithdefcmd{bukhari}{3523}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ أَسْلَمُ وَغِفَارُ وَشَىْءٌ مِنْ مُزَيْنَةَ وَجُهَيْنَةَ ـ أَوْ قَالَ شَىْءٌ مِنْ جُهَيْنَةَ أَوْ مُزَيْنَةَ ـ خَيْرٌ عِنْدَ اللَّهِ ـ أَوْ قَالَ ـ يَوْمَ الْقِيَامَةِ مِنْ أَسَدٍ وَتَمِيمٍ وَهَوَازِنَ وَغَطَفَانَ‏.‏\hadithno{3523}\hadithtrans{Narrated Abu Hurairah (ra):The Prophet (ﷺ) said, (The people of) Aslam, Ghifar and some people of Muzaina and Juhaina or said (some people of Juhaina or Muzaina) are better with Allah or said (on the Day of resurrection) than the tribe of Asad, Tamim, Hawazin and Ghatafan}}
\hadithdefcmd{bukhari}{3524}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ إِذَا سَرَّكَ أَنْ تَعْلَمَ جَهْلَ الْعَرَبِ فَاقْرَأْ مَا فَوْقَ الثَّلاَثِينَ وَمِائَةٍ فِي سُورَةِ الأَنْعَامِ ‏\{‏قَدْ خَسِرَ الَّذِينَ قَتَلُوا أَوْلاَدَهُمْ سَفَهًا بِغَيْرِ عِلْمٍ‏\}‏ إِلَى قَوْلِهِ ‏\{‏قَدْ ضَلُّوا وَمَا كَانُوا مُهْتَدِينَ‏\}‏‏.‏\hadithno{3524}\hadithtrans{Narrated Ibn `Abbas:If you wish to know about the ignorance of the Arabs, refer to Surat-al-Anam after Verse No. 130:-- Indeed lost are those who have killed their children From folly without knowledge and have forbidden that which Allah has provided for them, inventing a lie against Allah. They have indeed gone astray and were not guided}}
\hadithdefcmd{bukhari}{3525}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا عَمْرُو بْنُ مُرَّةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ لَمَّا نَزَلَتْ ‏\{‏وَأَنْذِرْ عَشِيرَتَكَ الأَقْرَبِينَ‏\}‏ جَعَلَ النَّبِيُّ صلى الله عليه وسلم يُنَادِي ‏"‏ يَا بَنِي فِهْرٍ، يَا بَنِي عَدِيٍّ لِبُطُونِ قُرَيْشٍ ‏"‏‏.‏\hadithno{3525}\hadithtrans{Narrated Ibn `Abbas:When the Verse:-- 'And warn your tribe of near kindred.' (26.214) was revealed, the Prophet (ﷺ) started calling (the 'Arab tribes), "O Bani Fihr, O Bani `Adi" mentioning first the various branch tribes of Quraish}}
\hadithdefcmd{bukhari}{3526}{وَقَالَ لَنَا قَبِيصَةُ أَخْبَرَنَا سُفْيَانُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا نَزَلَتْ ‏\{‏وَأَنْذِرْ عَشِيرَتَكَ الأَقْرَبِينَ‏\}‏ جَعَلَ النَّبِيُّ صلى الله عليه وسلم يَدْعُوهُمْ قَبَائِلَ قَبَائِلَ‏.‏\hadithno{3526}\hadithtrans{Narrated Ibn `Abbas: When the Verse:-- 'And warn your tribe of near kindred' (26.214). was revealed, the Prophet (ﷺ) started calling every tribe by its name}}
\hadithdefcmd{bukhari}{3527}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، أَخْبَرَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ يَا بَنِي عَبْدِ مَنَافٍ، اشْتَرُوا أَنْفُسَكُمْ مِنَ اللَّهِ، يَا بَنِي عَبْدِ الْمُطَّلِبِ اشْتَرُوا أَنْفُسَكُمْ مِنَ اللَّهِ، يَا أُمَّ الزُّبَيْرِ بْنِ الْعَوَّامِ عَمَّةَ رَسُولِ اللَّهِ، يَا فَاطِمَةُ بِنْتَ مُحَمَّدٍ، اشْتَرِيَا أَنْفُسَكُمَا مِنَ اللَّهِ، لاَ أَمْلِكُ لَكُمَا مِنَ اللَّهِ شَيْئًا، سَلاَنِي مِنْ مَالِي مَا شِئْتُمَا ‏"‏‏.‏\hadithno{3527}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "O Bani `Abd Manaf! Buy yourselves from Allah; O Bani `Abdul-Muttalib! Buy yourselves from Allah; O mother of Az-Zubair bin Al-Awwam, the aunt of Allah's Messenger (ﷺ), and O Fatima bint Muhammad! Buy yourselves from Allah, for I cannot defend you before Allah. You (both) can ask me from my property as much as you like}}
\hadithdefcmd{bukhari}{3528}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ دَعَا النَّبِيُّ صلى الله عليه وسلم الأَنْصَارَ فَقَالَ ‏"‏ هَلْ فِيكُمْ أَحَدٌ مِنْ غَيْرِكُمْ ‏"‏‏.‏ قَالُوا لاَ، إِلاَّ ابْنُ أُخْتٍ لَنَا‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ابْنُ أُخْتِ الْقَوْمِ مِنْهُمْ ‏"‏‏.‏\hadithno{3528}\hadithtrans{Narrated Anas:The Prophet (ﷺ) sent for the Ansar (and when they came), he asked, 'Is there any stranger amongst you?" They said, "No except the son of our sister." Allah's Messenger (ﷺ) said, "The son of the sister of some people belongs to them}}
\hadithdefcmd{bukhari}{3530}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ أَبَا بَكْرٍ ـ رضى الله عنه ـ دَخَلَ عَلَيْهَا وَعِنْدَهَا جَارِيَتَانِ فِي أَيَّامِ مِنًى تُدَفِّفَانِ وَتَضْرِبَانِ، وَالنَّبِيُّ صلى الله عليه وسلم مُتَغَشٍّ بِثَوْبِهِ، فَانْتَهَرَهُمَا أَبُو بَكْرٍ، فَكَشَفَ النَّبِيُّ صلى الله عليه وسلم عَنْ وَجْهِهِ، فَقَالَ ‏"‏ دَعْهُمَا يَا أَبَا بَكْرٍ، فَإِنَّهَا أَيَّامُ عِيدٍ، وَتِلْكَ الأَيَّامُ أَيَّامُ مِنًى ‏"‏‏.‏ وَقَالَتْ عَائِشَةُ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَسْتُرُنِي، وَأَنَا أَنْظُرُ إِلَى الْحَبَشَةِ، وَهُمْ يَلْعَبُونَ فِي الْمَسْجِدِ فَزَجَرَهُمْ ‏\{‏عُمَرُ‏\}‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ دَعْهُمْ أَمْنًا بَنِي أَرْفَدَةَ ‏"‏‏.‏ يَعْنِي مِنَ الأَمْنِ‏.‏\hadithno{3530}\hadithtrans{Narrated `Aisha:That during the Mina days, Abu Bakr came to her, while there were two girls with her, beating drums, and the Prophet (ﷺ) was (lying) covering himself with his garment. Abu Bakr rebuked the two girls, but the Prophet (ﷺ) uncovered his face and said, "O Abu Bakr! Leave them, for these are the days of Id (festival)." Those days were the days of Mina-. `Aisha added, "I was being screened by the Prophet (ﷺ) while I was watching the Ethiopians playing in the Mosque. `Umar rebuked them, but the Prophet (ﷺ) said, "Leave them, O Bani Arfida! Play. (for) you are safe}}
\hadithdefcmd{bukhari}{3531}{حَدَّثَنِي عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتِ اسْتَأْذَنَ حَسَّانُ النَّبِيَّ صلى الله عليه وسلم فِي هِجَاءِ الْمُشْرِكِينَ، قَالَ ‏ "‏ كَيْفَ بِنَسَبِي ‏"‏‏.‏ فَقَالَ حَسَّانُ لأَسُلَّنَّكَ مِنْهُمْ كَمَا تُسَلُّ الشَّعَرَةُ مِنَ الْعَجِينِ‏.‏ وَعَنْ أَبِيهِ قَالَ ذَهَبْتُ أَسُبُّ حَسَّانَ عِنْدَ عَائِشَةَ فَقَالَتْ لاَ تَسُبُّهُ فَإِنَّهُ كَانَ يُنَافِحُ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3531}\hadithtrans{Narrated `Aisha:Once Hassan bin Thabit asked the permission of the Prophet (ﷺ) to lampoon (i.e. compose satirical poetry defaming) the infidels. The Prophet (ﷺ) said, "What about the fact that I have common descent with them?" Hassan replied, "I shall take you out of them as a hair is taken out of dough." Narrated `Urwa: I started abusing Hassan in front of `Aisha, whereupon she said. "Don't abuse him, for he used to defend the Prophet (with his poetry)}}
\hadithdefcmd{bukhari}{3532}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنِي مَعْنٌ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ مُحَمَّدِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنْ أَبِيهِ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِي خَمْسَةُ أَسْمَاءٍ أَنَا مُحَمَّدٌ، وَأَحْمَدُ، وَأَنَا الْمَاحِي الَّذِي يَمْحُو اللَّهُ بِي الْكُفْرَ، وَأَنَا الْحَاشِرُ الَّذِي يُحْشَرُ النَّاسُ عَلَى قَدَمِي، وَأَنَا الْعَاقِبُ ‏"‏‏.‏\hadithno{3532}\hadithtrans{Narrated Jubair bin Mut`im:Allah's Messenger (ﷺ) said, "I have five names: I am Muhammad and Ahmad; I am Al-Mahi through whom Allah will eliminate infidelity; I am Al-Hashir who will be the first to be resurrected, the people being resurrected thereafter; and I am also Al-`Aqib (i.e. There will be no prophet after me)}}
\hadithdefcmd{bukhari}{3533}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ تَعْجَبُونَ كَيْفَ يَصْرِفُ اللَّهُ عَنِّي شَتْمَ قُرَيْشٍ وَلَعْنَهُمْ يَشْتِمُونَ مُذَمَّمًا وَيَلْعَنُونَ مُذَمَّمًا وَأَنَا مُحَمَّدٌ ‏"‏‏.‏\hadithno{3533}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Doesn't it astonish you how Allah protects me from the Quraish's abusing and cursing? They abuse Mudhammam and curse Mudhammam while I am Muhammad (and not Mudhammam)}}
\hadithdefcmd{bukhari}{3534}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا سَلِيمٌ، حَدَّثَنَا سَعِيدُ بْنُ مِينَاءَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَثَلِي وَمَثَلُ الأَنْبِيَاءِ كَرَجُلٍ بَنَى دَارًا فَأَكْمَلَهَا وَأَحْسَنَهَا، إِلاَّ مَوْضِعَ لَبِنَةٍ، فَجَعَلَ النَّاسُ يَدْخُلُونَهَا وَيَتَعَجَّبُونَ، وَيَقُولُونَ لَوْلاَ مَوْضِعُ اللَّبِنَةِ ‏"‏‏.‏\hadithno{3534}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) said, "My similitude in comparison with the other prophets is that of a man who has built a house completely and excellently except for a place of one brick. When the people enter the house, they admire its beauty and say: 'But for the place of this brick (how splendid the house will be)}}
\hadithdefcmd{bukhari}{3535}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ مَثَلِي وَمَثَلَ الأَنْبِيَاءِ مِنْ قَبْلِي كَمَثَلِ رَجُلٍ بَنَى بَيْتًا فَأَحْسَنَهُ وَأَجْمَلَهُ، إِلاَّ مَوْضِعَ لَبِنَةٍ مِنْ زَاوِيَةٍ، فَجَعَلَ النَّاسُ يَطُوفُونَ بِهِ وَيَعْجَبُونَ لَهُ، وَيَقُولُونَ هَلاَّ وُضِعَتْ هَذِهِ اللَّبِنَةُ قَالَ فَأَنَا اللَّبِنَةُ، وَأَنَا خَاتِمُ النَّبِيِّينَ ‏"‏‏.‏\hadithno{3535}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "My similitude in comparison with the other prophets before me, is that of a man who has built a house nicely and beautifully, except for a place of one brick in a corner. The people go about it and wonder at its beauty, but say: 'Would that this brick be put in its place!' So I am that brick, and I am the last of the Prophets}}
\hadithdefcmd{bukhari}{3536}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم تُوُفِّيَ وَهْوَ ابْنُ ثَلاَثٍ وَسِتِّينَ‏.‏ وَقَالَ ابْنُ شِهَابٍ وَأَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ مِثْلَهُ‏.‏\hadithno{3536}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) died when he was sixty three years old}}
\hadithdefcmd{bukhari}{3537}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم فِي السُّوقِ فَقَالَ رَجُلٌ يَا أَبَا الْقَاسِمِ‏.‏ فَالْتَفَتَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ سَمُّوا بِاسْمِي، وَلاَ تَكْتَنُوا بِكُنْيَتِي ‏"‏‏.‏\hadithno{3537}\hadithtrans{Narrated Anas:While the Prophet (ﷺ) was in the market, a man called (somebody), "O Abu-l-Qasim!' The Prophet (ﷺ) turned to him and said "Name yourselves after me but do not call yourselves by my Kuniya}}
\hadithdefcmd{bukhari}{3538}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا شُعْبَةُ، عَنْ مَنْصُورٍ، عَنْ سَالِمٍ، عَنْ جَابِرٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تَسَمَّوْا بِاسْمِي، وَلاَ تَكْتَنُوا بِكُنْيَتِي ‏"‏\hadithno{3538}\hadithtrans{Narrated Jabir:The Prophet (ﷺ) said, "Name yourselves after me, but do not call yourselves by my Kuniya}}
\hadithdefcmd{bukhari}{3539}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، عَنْ أَيُّوبَ، عَنِ ابْنِ سِيرِينَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏ "‏ سَمُّوا بِاسْمِي، وَلاَ تَكْتَنُوا بِكُنْيَتِي ‏"‏\hadithno{3539}\hadithtrans{Narrated Abu Huraira:Abu-l-Qasim said, "Name yourselves after me, but do not call yourselves by my Kuniya}}
\hadithdefcmd{bukhari}{3540}{حَدَّثَنِي إِسْحَاقُ، أَخْبَرَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الْجُعَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، رَأَيْتُ السَّائِبَ بْنَ يَزِيدَ ابْنَ أَرْبَعٍ وَتِسْعِينَ جَلْدًا مُعْتَدِلاً فَقَالَ قَدْ عَلِمْتُ مَا مُتِّعْتُ بِهِ سَمْعِي وَبَصَرِي إِلاَّ بِدُعَاءِ رَسُولِ اللَّهِ صلى الله عليه وسلم، إِنَّ خَالَتِي ذَهَبَتْ بِي إِلَيْهِ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَ أُخْتِي شَاكٍ فَادْعُ اللَّهَ‏.‏ قَالَ فَدَعَا لِي‏.‏\hadithno{3540}\hadithtrans{Narrated Al-Ju'aid bin `Abdur Rahman:I saw As-Sa'ib bin Yazid when he was ninety-four years old, quite strong and of straight figure. He said, "I know that I enjoyed my hearing and seeing powers only because of the invocation of Allah's Apostle . My aunt took me to him and said, 'O Allah's Messenger (ﷺ)! My nephew is sick; will you invoke Allah for him?' So he invoked (Allah) for me}}
\hadithdefcmd{bukhari}{3541}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدِ اللَّهِ، حَدَّثَنَا حَاتِمٌ، عَنِ الْجُعَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ السَّائِبَ بْنَ يَزِيدَ، قَالَ ذَهَبَتْ بِي خَالَتِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ ابْنَ أُخْتِي‏.‏ وَقَعَ فَمَسَحَ رَأْسِي وَدَعَا لِي بِالْبَرَكَةِ، وَتَوَضَّأَ فَشَرِبْتُ مِنْ وَضُوئِهِ، ثُمَّ قُمْتُ خَلْفَ ظَهْرِهِ فَنَظَرْتُ إِلَى خَاتَمٍ بَيْنَ كَتِفَيْهِ‏.‏ قَالَ ابْنُ عُبَيْدِ اللَّهِ الْحُجْلَةُ مِنْ حُجَلِ الْفَرَسِ الَّذِي بَيْنَ عَيْنَيْهِ‏.‏ قَالَ إِبْرَاهِيمُ بْنُ حَمْزَةَ مِثْلَ زِرِّ الْحَجَلَةِ\hadithno{3541}\hadithtrans{Narrated As-Sa'ib bin Yazid:My aunt took me to Allah's Messenger (ﷺ) and said, "O Allah's Messenger (ﷺ)! My nephew is sick."' The Prophet (ﷺ) passed his hands over my head and blessed me. Then he performed ablution and I drank the remaining water, and standing behind him, I saw the seal in between his shoulders}}
\hadithdefcmd{bukhari}{3542}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ عُمَرَ بْنِ سَعِيدِ بْنِ أَبِي حُسَيْنٍ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عُقْبَةَ بْنِ الْحَارِثِ، قَالَ صَلَّى أَبُو بَكْرٍ ـ رضى الله عنه ـ الْعَصْرَ، ثُمَّ خَرَجَ يَمْشِي فَرَأَى الْحَسَنَ يَلْعَبُ مَعَ الصِّبْيَانِ، فَحَمَلَهُ عَلَى عَاتِقِهِ وَقَالَ بِأَبِي شَبِيهٌ بِالنَّبِيِّ لاَ شَبِيهٌ بِعَلِيٍّ‏.‏ وَعَلِيٌّ يَضْحَكُ‏.‏\hadithno{3542}\hadithtrans{Narrated `Uqba bin Al-Harith:(Once) Abu Bakr offered the `Asr prayer and then went out walking and saw Al-Hasan playing with the boys. He lifted him on to his shoulders and said, " Let my parents be sacrificed for your sake! (You) resemble the Prophet (ﷺ) and not `Ali," while `Ali was smiling}}
\hadithdefcmd{bukhari}{3543}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَبِي جُحَيْفَةَ ـ رضى الله عنه ـ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَكَانَ الْحَسَنُ يُشْبِهُهُ‏.‏\hadithno{3543}\hadithtrans{Narrated Abu Juhaifa:I saw the Prophet, and Al-Hasan resembled him}}
\hadithdefcmd{bukhari}{3544}{حَدَّثَنِي عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا ابْنُ فُضَيْلٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، قَالَ سَمِعْتُ أَبَا جُحَيْفَةَ ـ رضى الله عنه ـ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَكَانَ الْحَسَنُ بْنُ عَلِيٍّ ـ عَلَيْهِمَا السَّلاَمُ ـ يُشْبِهُهُ قُلْتُ لأَبِي جُحَيْفَةَ صِفْهُ لِي‏.‏ قَالَ كَانَ أَبْيَضَ قَدْ شَمِطَ‏.‏ وَأَمَرَ لَنَا النَّبِيُّ صلى الله عليه وسلم بِثَلاَثَ عَشْرَةَ قَلُوصًا قَالَ فَقُبِضَ النَّبِيُّ صلى الله عليه وسلم قَبْلَ أَنْ نَقْبِضَهَا‏.‏\hadithno{3544}\hadithtrans{Narrated Isma`il bin Abi Khalid:I heard Abu Juhaifa saying, "I saw the Prophet, and Al-Hasan bin `Ali resembled him." I said to Abu- Juhaifa, "Describe him for me." He said, "He was white and his beard was black with some white hair. He promised to give us 13 young she-camels, but he expired before we could get them}}
\hadithdefcmd{bukhari}{3545}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ وَهْبٍ أَبِي جُحَيْفَةَ السُّوَائِيِّ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم وَرَأَيْتُ بَيَاضًا مِنْ تَحْتِ شَفَتِهِ السُّفْلَى الْعَنْفَقَةَ‏.‏\hadithno{3545}\hadithtrans{Narrated Wahb Abu Juhaifa As-Suwai:I saw the Prophet (ﷺ) and saw some white hair below his lower lip above the chin}}
\hadithdefcmd{bukhari}{3546}{حَدَّثَنَا عِصَامُ بْنُ خَالِدٍ، حَدَّثَنَا حَرِيزُ بْنُ عُثْمَانَ، أَنَّهُ سَأَلَ عَبْدَ اللَّهِ بْنَ بُسْرٍ صَاحِبَ النَّبِيِّ صلى الله عليه وسلم قَالَ أَرَأَيْتَ النَّبِيَّ صلى الله عليه وسلم كَانَ شَيْخًا قَالَ كَانَ فِي عَنْفَقَتِهِ شَعَرَاتٌ بِيضٌ‏.‏\hadithno{3546}\hadithtrans{Narrated Hariz bin `Uthman:That he asked `Abdullah bin Busr (i.e. the companion of the Prophet), "Did you see the Prophet (ﷺ) when he was old?" He said, "He had a few white hairs between the lower lip and the chin}}
\hadithdefcmd{bukhari}{3547}{حَدَّثَنِي ابْنُ بُكَيْرٍ، قَالَ حَدَّثَنِي اللَّيْثُ، عَنْ خَالِدٍ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَصِفُ النَّبِيَّ صلى الله عليه وسلم قَالَ كَانَ رَبْعَةً مِنَ الْقَوْمِ، لَيْسَ بِالطَّوِيلِ وَلاَ بِالْقَصِيرِ، أَزْهَرَ اللَّوْنِ لَيْسَ بِأَبْيَضَ أَمْهَقَ وَلاَ آدَمَ، لَيْسَ بِجَعْدٍ قَطَطٍ وَلاَ سَبْطٍ رَجِلٍ، أُنْزِلَ عَلَيْهِ وَهْوَ ابْنُ أَرْبَعِينَ، فَلَبِثَ بِمَكَّةَ عَشْرَ سِنِينَ يُنْزَلُ عَلَيْهِ وَبِالْمَدِينَةِ عَشْرَ سِنِينَ، وَلَيْسَ فِي رَأْسِهِ وَلِحْيَتِهِ عِشْرُونَ شَعَرَةً بَيْضَاءَ‏.‏ قَالَ رَبِيعَةُ فَرَأَيْتُ شَعَرًا مِنْ شَعَرِهِ، فَإِذَا هُوَ أَحْمَرُ فَسَأَلْتُ فَقِيلَ احْمَرَّ مِنَ الطِّيبِ‏.‏\hadithno{3547}\hadithtrans{Narrated Rabi`a bin Abi `Abdur-Rahman:I heard Anas bin Malik describing the Prophet (ﷺ) saying, "He was of medium height amongst the people, neither tall nor short; he had a rosy color, neither absolutely white nor deep brown; his hair was neither completely curly nor quite lank. Divine Inspiration was revealed to him when he was forty years old. He stayed ten years in Mecca receiving the Divine Inspiration, and stayed in Medina for ten more years. When he expired, he had scarcely twenty white hairs in his head and beard." Rabi`a said, "I saw some of his hairs and it was red. When I asked about that, I was told that it turned red because of scent}}
\hadithdefcmd{bukhari}{3548}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ سَمِعَهُ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْسَ بِالطَّوِيلِ الْبَائِنِ وَلاَ بِالْقَصِيرِ، وَلاَ بِالأَبْيَضِ الأَمْهَقِ، وَلَيْسَ بِالآدَمِ وَلَيْسَ بِالْجَعْدِ الْقَطَطِ وَلاَ بِالسَّبْطِ، بَعَثَهُ اللَّهُ عَلَى رَأْسِ أَرْبَعِينَ سَنَةً، فَأَقَامَ بِمَكَّةَ عَشْرَ سِنِينَ، وَبِالْمَدِينَةِ عَشْرَ سِنِينَ، فَتَوَفَّاهُ اللَّهُ، وَلَيْسَ فِي رَأْسِهِ وَلِحْيَتِهِ عِشْرُونَ شَعْرَةً بَيْضَاءَ‏.‏\hadithno{3548}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) was neither very tall nor short, neither absolutely white nor deep brown. His hair was neither curly nor lank. Allah sent him (as an Apostle) when he was forty years old. Afterwards he resided in Mecca for ten years and in Medina for ten more years. When Allah took him unto Him, there were scarcely twenty white hairs in his head and beard}}
\hadithdefcmd{bukhari}{3549}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ أَبُو عَبْدِ اللَّهِ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ يُوسُفَ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَحْسَنَ النَّاسِ وَجْهًا وَأَحْسَنَهُ خَلْقًا، لَيْسَ بِالطَّوِيلِ الْبَائِنِ وَلاَ بِالْقَصِيرِ‏.‏\hadithno{3549}\hadithtrans{Narrated Al-Bara:Allah's Messenger (ﷺ) was the handsomest of all the people, and had the best appearance. He was neither very tall nor short}}
\hadithdefcmd{bukhari}{3550}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، قَالَ سَأَلْتُ أَنَسًا هَلْ خَضَبَ النَّبِيُّ صلى الله عليه وسلم قَالَ لاَ، إِنَّمَا كَانَ شَىْءٌ فِي صُدْغَيْهِ‏.‏\hadithno{3550}\hadithtrans{Narrated Qatada:I asked Anas, "Did the Prophet (ﷺ) use to dye (his) hair?" He said, "No, for there were only a few white hairs on his temples}}
\hadithdefcmd{bukhari}{3551}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم مَرْبُوعًا، بَعِيدَ مَا بَيْنَ الْمَنْكِبَيْنِ، لَهُ شَعَرٌ يَبْلُغُ شَحْمَةَ أُذُنِهِ، رَأَيْتُهُ فِي حُلَّةٍ حَمْرَاءَ، لَمْ أَرَ شَيْئًا قَطُّ أَحْسَنَ مِنْهُ‏.‏ قَالَ يُوسُفُ بْنُ أَبِي إِسْحَاقَ عَنْ أَبِيهِ إِلَى مَنْكِبَيْهِ‏.‏\hadithno{3551}\hadithtrans{Narrated Al-Bara:The Prophet (ﷺ) was of moderate height having broad shoulders (long) hair reaching his ear-lobes. Once I saw him in a red cloak and I had never seen a more handsome man than him}}
\hadithdefcmd{bukhari}{3552}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي إِسْحَاقَ، قَالَ سُئِلَ الْبَرَاءُ أَكَانَ وَجْهُ النَّبِيِّ صلى الله عليه وسلم مِثْلَ السَّيْفِ قَالَ لاَ بَلْ مِثْلَ الْقَمَرِ‏.‏\hadithno{3552}\hadithtrans{Narrated Abu 'Is-haq:Al-Bara' was asked, "Was the face of the Prophet (as bright) as a sword?" He said, "No, but (as bright) as a moon}}
\hadithdefcmd{bukhari}{3553}{حَدَّثَنَا الْحَسَنُ بْنُ مَنْصُورٍ أَبُو عَلِيٍّ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ الأَعْوَرُ، بِالْمَصِّيصَةِ حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، قَالَ سَمِعْتُ أَبَا جُحَيْفَةَ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْهَاجِرَةِ إِلَى الْبَطْحَاءِ فَتَوَضَّأَ ثُمَّ صَلَّى الظُّهْرَ رَكْعَتَيْنِ، وَالْعَصْرَ رَكْعَتَيْنِ، وَبَيْنَ يَدَيْهِ عَنَزَةٌ‏.‏ ‏\{‏قَالَ شُعْبَةُ‏\}‏ وَزَادَ فِيهِ عَوْنٌ عَنْ أَبِيهِ أَبِي جُحَيْفَةَ قَالَ كَانَ يَمُرُّ مِنْ وَرَائِهَا الْمَرْأَةُ، وَقَامَ النَّاسُ فَجَعَلُوا يَأْخُذُونَ يَدَيْهِ، فَيَمْسَحُونَ بِهَا وُجُوهَهُمْ، قَالَ فَأَخَذْتُ بِيَدِهِ، فَوَضَعْتُهَا عَلَى وَجْهِي، فَإِذَا هِيَ أَبْرَدُ مِنَ الثَّلْجِ، وَأَطْيَبُ رَائِحَةً مِنَ الْمِسْكِ‏.‏\hadithno{3553}\hadithtrans{Narrated Abu Juhaifa:Once Allah's Messenger (ﷺ) went to Al-Batha' at noon, performed the ablution and offered' a two rak`at Zuhr prayer and a two-rak`at `Asr prayer while a spearheaded stick was planted before him and the passersby were passing in front of it. (After the prayer), the people got up and held the hands of the Prophet and passed them on their faces. I also took his hand and kept it on my face and noticed that it was colder than ice, and its smell was nicer than musk}}
\hadithdefcmd{bukhari}{3554}{حَدَّثَنَا عَبْدَانُ، حَدَّثَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم أَجْوَدَ النَّاسِ، وَأَجْوَدُ مَا يَكُونُ فِي رَمَضَانَ، حِينَ يَلْقَاهُ جِبْرِيلُ، وَكَانَ جِبْرِيلُ ـ عَلَيْهِ السَّلاَمُ ـ يَلْقَاهُ فِي كُلِّ لَيْلَةٍ مِنْ رَمَضَانَ، فَيُدَارِسُهُ الْقُرْآنَ فَلَرَسُولُ اللَّهِ صلى الله عليه وسلم أَجْوَدُ بِالْخَيْرِ مِنَ الرِّيحِ الْمُرْسَلَةِ‏.‏\hadithno{3554}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) was the most generous of all the people, and he used to become more generous in Ramadan when Gabriel met him. Gabriel used to meet him every night during Ramadan to revise the Qur'an with him. Allah's Messenger (ﷺ) then used to be more generous than the fast wind}}
\hadithdefcmd{bukhari}{3555}{حَدَّثَنَا يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي ابْنُ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَلَيْهَا مَسْرُورًا تَبْرُقُ أَسَارِيرُ وَجْهِهِ، فَقَالَ ‏ "‏ أَلَمْ تَسْمَعِي مَا قَالَ الْمُدْلِجِيُّ لِزَيْدٍ وَأُسَامَةَ ـ وَرَأَى أَقْدَامَهُمَا ـ إِنَّ بَعْضَ هَذِهِ الأَقْدَامِ مِنْ بَعْضٍ ‏"‏‏.‏\hadithno{3555}\hadithtrans{Narrated `Aisha:That Allah's Messenger (ﷺ) came to her in a happy mood with his features glittering with joy, and said, "Have you not heard what the Qaif has said about Zaid and Us-ama? He saw their feet and remarked. These belong to each other." (i.e. They are father and son)}}
\hadithdefcmd{bukhari}{3556}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ كَعْبٍ، أَنَّ عَبْدَ اللَّهِ بْنَ كَعْبٍ، قَالَ سَمِعْتُ كَعْبَ بْنَ مَالِكٍ، يُحَدِّثُ حِينَ تَخَلَّفَ عَنْ تَبُوكَ، قَالَ فَلَمَّا سَلَّمْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهْوَ يَبْرُقُ وَجْهُهُ مِنَ السُّرُورِ، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا سُرَّ اسْتَنَارَ وَجْهُهُ، حَتَّى كَأَنَّهُ قِطْعَةُ قَمَرٍ، وَكُنَّا نَعْرِفُ ذَلِكَ مِنْهُ‏.‏\hadithno{3556}\hadithtrans{Narrated `Abdullah bin Ka`b:I heard Ka`b bin Malik talking after his failure to join (the Ghazwa of) Tabuk. He said, "When I greeted Allah's Messenger (ﷺ) whose face was glittering with happiness, for whenever Allah's Messenger (ﷺ) was happy, his face used to glitter, as if it was a piece of the moon, and we used to recognize it (i.e. his happiness) from his face}}
\hadithdefcmd{bukhari}{3557}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَمْرٍو، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ بُعِثْتُ مِنْ خَيْرِ قُرُونِ بَنِي آدَمَ قَرْنًا فَقَرْنًا، حَتَّى كُنْتُ مِنَ الْقَرْنِ الَّذِي كُنْتُ فِيهِ ‏"‏‏.‏\hadithno{3557}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "I have been sent (as an Apostle) in the best of all the generations of Adam's offspring since their Creation}}
\hadithdefcmd{bukhari}{3558}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَسْدِلُ شَعَرَهُ، وَكَانَ الْمُشْرِكُونَ يَفْرُقُونَ رُءُوسَهُمْ فَكَانَ أَهْلُ الْكِتَابِ يَسْدِلُونَ رُءُوسَهُمْ، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُحِبُّ مُوَافَقَةَ أَهْلِ الْكِتَابِ فِيمَا لَمْ يُؤْمَرْ فِيهِ بِشَىْءٍ، ثُمَّ فَرَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَأْسَهُ‏.‏\hadithno{3558}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) used to let his hair hang down while the infidels used to part their hair. The people of the Scriptures were used to letting their hair hang down and Allah's Messenger (ﷺ) liked to follow the people of the Scriptures in the matters about which he was not instructed otherwise. Then Allah's Messenger (ﷺ) parted his hair}}
\hadithdefcmd{bukhari}{3559}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو ـ رضى الله عنهما ـ قَالَ لَمْ يَكُنِ النَّبِيُّ صلى الله عليه وسلم فَاحِشًا وَلاَ مُتَفَحِّشًا وَكَانَ يَقُولُ ‏ "‏ إِنَّ مِنْ خِيَارِكُمْ أَحْسَنَكُمْ أَخْلاَقًا ‏"‏‏.‏\hadithno{3559}\hadithtrans{Narrated `Abdullah bin `Amr:The Prophet (ﷺ) never used bad language neither a "Fahish nor a Mutafahish. He used to say "The best amongst you are those who have the best manners and character." (See Hadith No. 56 (B) Vol}}
\hadithdefcmd{bukhari}{3560}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ مَا خُيِّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَمْرَيْنِ إِلاَّ أَخَذَ أَيْسَرَهُمَا، مَا لَمْ يَكُنْ إِثْمًا، فَإِنْ كَانَ إِثْمًا كَانَ أَبْعَدَ النَّاسِ مِنْهُ، وَمَا انْتَقَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِنَفْسِهِ، إِلاَّ أَنْ تُنْتَهَكَ حُرْمَةُ اللَّهِ فَيَنْتَقِمَ لِلَّهِ بِهَا‏.‏\hadithno{3560}\hadithtrans{Narrated `Aisha:Whenever Allah's Messenger (ﷺ) was given the choice of one of two matters, he would choose the easier of the two, as long as it was not sinful to do so, but if it was sinful to do so, he would not approach it. Allah's Messenger (ﷺ) never took revenge (over anybody) for his own sake but (he did) only when Allah's Legal Bindings were outraged in which case he would take revenge for Allah's Sake}}
\hadithdefcmd{bukhari}{3561}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ مَا مَسِسْتُ حَرِيرًا وَلاَ دِيبَاجًا أَلْيَنَ مِنْ كَفِّ النَّبِيِّ صلى الله عليه وسلم، وَلاَ شَمِمْتُ رِيحًا قَطُّ أَوْ عَرْفًا قَطُّ أَطْيَبَ مِنْ رِيحِ أَوْ عَرْفِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3561}\hadithtrans{Narrated Anas:I have never touched silk or Dibaj (i.e. thick silk) softer than the palm of the Prophet (ﷺ) nor have I smelt a perfume nicer than the sweat of the Prophet}}
\hadithdefcmd{bukhari}{3562}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي عُتْبَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم أَشَدَّ حَيَاءً مِنَ الْعَذْرَاءِ فِي خِدْرِهَا‏.‏\hadithno{3562}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) was shier than a veiled virgin girl}}
\hadithdefcmd{bukhari}{3562p2}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، وَابْنُ، مَهْدِيٍّ قَالاَ حَدَّثَنَا شُعْبَةُ، مِثْلَهُ وَإِذَا كَرِهَ شَيْئًا عُرِفَ فِي وَجْهِهِ‏.‏\hadithno{3562.2}\hadithtrans{Narrated Shuba:A similar Hadith (i e. No. 762) with this addition: And if he (i.e. the Prophet) disliked something, the sign of aversion would appear on his face}}
\hadithdefcmd{bukhari}{3563}{حَدَّثَنِي عَلِيُّ بْنُ الْجَعْدِ، أَخْبَرَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ مَا عَابَ النَّبِيُّ صلى الله عليه وسلم طَعَامًا قَطُّ، إِنِ اشْتَهَاهُ أَكَلَهُ، وَإِلاَّ تَرَكَهُ‏.‏\hadithno{3563}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) never criticized any food (presented to him), but he would eat it if he liked it; otherwise, he would leave it (without expressing his dislike)}}
\hadithdefcmd{bukhari}{3564}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا بَكْرُ بْنُ مُضَرَ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنِ الأَعْرَجِ، عَنْ عَبْدِ اللَّهِ بْنِ مَالِكٍ ابْنِ بُحَيْنَةَ الأَسْدِيِّ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا سَجَدَ فَرَّجَ بَيْنَ يَدَيْهِ حَتَّى نَرَى إِبْطَيْهِ‏.‏ قَالَ وَقَالَ ابْنُ بُكَيْرٍ حَدَّثَنَا بَكْرٌ بَيَاضَ إِبْطَيْهِ‏.‏\hadithno{3564}\hadithtrans{Narrated `Abdullah bin Malik bin Buhaina Al-Asdi:When the Prophet (ﷺ) prostrated, he used to keep his arms so widely apart that we used to see his armpits. (The sub-narrator, Ibn Bukair said, "The whiteness of his armpits)}}
\hadithdefcmd{bukhari}{3565}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، أَنَّ أَنَسًا ـ رضى الله عنه ـ حَدَّثَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ لاَ يَرْفَعُ يَدَيْهِ فِي شَىْءٍ مِنْ دُعَائِهِ، إِلاَّ فِي الاِسْتِسْقَاءِ، فَإِنَّهُ كَانَ يَرْفَعُ يَدَيْهِ حَتَّى يُرَى بَيَاضُ إِبْطَيْهِ‏.‏ وَقَالَ أَبُو مُوسَى دَعَا النَّبِيُّ صَلَّى اللَّهُ عَلَيْهِ وَسَلَّمَ وَرَفَعَ يَدَيْهِ وَرَأَيْتُ بَيَاضَ إِبْطَيْهِ\hadithno{3565}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) did not use to raise his hands in his invocations except in the Istisqa (i.e. invoking Allah for the rain) in which he used to raise his hands so high that one could see the whiteness of his armpits. (Note: It may be that Anas did not see the Prophet (ﷺ) raising his hands but it has been narrated that the Prophet (ﷺ) used to raise his hands for invocations other than Istisqa. See Hadith No. 612 Vol. 5. and Hadith No. 807 \& 808 Vol}}
\hadithdefcmd{bukhari}{3566}{حَدَّثَنَا الْحَسَنُ بْنُ الصَّبَّاحِ، حَدَّثَنَا مُحَمَّدُ بْنُ سَابِقٍ، حَدَّثَنَا مَالِكُ بْنُ مِغْوَلٍ، قَالَ سَمِعْتُ عَوْنَ بْنَ أَبِي جُحَيْفَةَ، ذَكَرَ عَنْ أَبِيهِ، قَالَ دُفِعْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهْوَ بِالأَبْطَحِ فِي قُبَّةٍ كَانَ بِالْهَاجِرَةِ، خَرَجَ بِلاَلٌ فَنَادَى بِالصَّلاَةِ، ثُمَّ دَخَلَ فَأَخْرَجَ فَضْلَ وَضُوءِ رَسُولِ اللَّهِ صلى الله عليه وسلم، فَوَقَعَ النَّاسُ عَلَيْهِ يَأْخُذُونَ مِنْهُ، ثُمَّ دَخَلَ فَأَخْرَجَ الْعَنَزَةَ، وَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ سَاقَيْهِ فَرَكَزَ الْعَنَزَةَ، ثُمَّ صَلَّى الظُّهْرَ رَكْعَتَيْنِ وَالْعَصْرَ رَكْعَتَيْنِ، يَمُرُّ بَيْنَ يَدَيْهِ الْحِمَارُ وَالْمَرْأَةُ‏.‏\hadithno{3566}\hadithtrans{Narrated Abu Juhaifa:By chance I went to the Prophet (ﷺ) at noon while he was at Al-Abtah (resting) in a tent. Bilal came out (of the tent) and pronounced the Adhan for the prayer, and entering again, he brought out the water which was left after Allah's Messenger (ﷺ) had performed the ablution. The people rushed to take some of the water. Bilal again went in and brought out a spear-headed stick, and then Allah's Messenger (ﷺ) came out. As if I were now looking at the whiteness of his leg. Bilal fixed the stick and the Prophet (ﷺ) offered a two-rak`at Zuhr prayer and a two-rak`at `Asr prayer, while women and donkeys were passing in front of the Prophet (beyond the stick)}}
\hadithdefcmd{bukhari}{3568}{حَدَّثَنِي الْحَسَنُ بْنُ صَبَّاحٍ الْبَزَّارُ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُحَدِّثُ حَدِيثًا لَوْ عَدَّهُ الْعَادُّ لأَحْصَاهُ‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّهُ قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ أَلاَ يُعْجِبُكَ أَبُو فُلاَنٍ جَاءَ فَجَلَسَ إِلَى جَانِبِ حُجْرَتِي يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم، يُسْمِعُنِي ذَلِكَ وَكُنْتُ أُسَبِّحُ فَقَامَ قَبْلَ أَنْ أَقْضِيَ سُبْحَتِي، وَلَوْ أَدْرَكْتُهُ لَرَدَدْتُ عَلَيْهِ، إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَكُنْ يَسْرُدُ الْحَدِيثَ كَسَرْدِكُمْ‏.‏\hadithno{3568}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) used to talk so clearly that if somebody wanted to count the number of his words, he could do so. Narrated `Urwa bin Az-Zubair: `Aisha said (to me), "Don't you wonder at Abu so-and-so who came and sat by my dwelling and started relating the traditions of Allah's Messenger (ﷺ) intending to let me hear that, while I was performing an optional prayer. He left before I finished my optional prayer. Had I found him still there. I would have said to him, 'Allah's Messenger (ﷺ) never talked so quickly and vaguely as you do}}
\hadithdefcmd{bukhari}{3569}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَأَلَ عَائِشَةَ ـ رضى الله عنها ـ كَيْفَ كَانَتْ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَمَضَانَ قَالَتْ مَا كَانَ يَزِيدُ فِي رَمَضَانَ وَلاَ غَيْرِهِ عَلَى إِحْدَى عَشْرَةَ رَكْعَةً، يُصَلِّي أَرْبَعَ رَكَعَاتٍ فَلاَ تَسْأَلْ عَنْ حُسْنِهِنَّ وَطُولِهِنَّ، ثُمَّ يُصَلِّي أَرْبَعًا فَلاَ تَسْأَلْ عَنْ حُسْنِهِنَّ وَطُولِهِنَّ، ثُمَّ يُصَلِّي ثَلاَثًا فَقُلْتُ يَا رَسُولَ اللَّهِ تَنَامُ قَبْلَ أَنْ تُوتِرَ قَالَ ‏ "‏ تَنَامُ عَيْنِي وَلاَ يَنَامُ قَلْبِي ‏"‏‏.‏\hadithno{3569}\hadithtrans{Narrated Abu Salama bin `Abdur-Rahman:That he asked `Aisha "How was the prayer of Allah's Messenger (ﷺ) in the month of Ramadan?" She replied, "He used not to pray more than eleven rak`at whether in Ramadan or in any other month. He used to offer four rak`at, let alone their beauty and length, and then four rak`at, let alone their beauty and length. Afterwards he would offer three rak`at. I said, 'O Allah's Messenger (ﷺ)! Do you go to bed before offering the witr prayer?' He said, 'My eyes sleep, but my heart does not sleep}}
\hadithdefcmd{bukhari}{3570}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، عَنْ شَرِيكِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يُحَدِّثُنَا عَنْ لَيْلَةِ، أُسْرِيَ بِالنَّبِيِّ صلى الله عليه وسلم مِنْ مَسْجِدِ الْكَعْبَةِ جَاءَ ثَلاَثَةُ نَفَرٍ قَبْلَ أَنْ يُوحَى إِلَيْهِ، وَهُوَ نَائِمٌ فِي مَسْجِدِ الْحَرَامِ، فَقَالَ أَوَّلُهُمْ أَيُّهُمْ هُوَ فَقَالَ أَوْسَطُهُمْ هُوَ خَيْرُهُمْ وَقَالَ آخِرُهُمْ خُذُوا خَيْرَهُمْ‏.‏ فَكَانَتْ تِلْكَ، فَلَمْ يَرَهُمْ حَتَّى جَاءُوا لَيْلَةً أُخْرَى، فِيمَا يَرَى قَلْبُهُ، وَالنَّبِيُّ صلى الله عليه وسلم نَائِمَةٌ عَيْنَاهُ وَلاَ يَنَامُ قَلْبُهُ وَكَذَلِكَ الأَنْبِيَاءُ تَنَامُ أَعْيُنُهُمْ وَلاَ تَنَامُ قُلُوبُهُمْ، فَتَوَلاَّهُ جِبْرِيلُ ثُمَّ عَرَجَ بِهِ إِلَى السَّمَاءِ‏.‏\hadithno{3570}\hadithtrans{Narrated Sharik bin `Abdullah bin Abi Namir:I heard Anas bin Malik telling us about the night when the Prophet (ﷺ) was made to travel from the Ka`ba Mosque. Three persons (i.e. angels) came to the Prophet (ﷺ) before he was divinely inspired was an Apostle), while he was sleeping in Al-Masjid-ul-Haram. The first (of the three angels) said, "Which of them is he?" The second said, "He is the best of them." That was all that happened then, and he did not see them till they came at another night and he perceived their presence with his heart, for the eyes of the Prophet (ﷺ) were closed when he was asleep, but his heart was not asleep (not unconscious). This is characteristic of all the prophets: Their eyes sleep but their hearts do not sleep. Then Gabriel took charge of the Prophet (ﷺ) and ascended along with him to the Heaven}}
\hadithdefcmd{bukhari}{3571}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا سَلْمُ بْنُ زَرِيرٍ، سَمِعْتُ أَبَا رَجَاءٍ، قَالَ حَدَّثَنَا عِمْرَانُ بْنُ حُصَيْنٍ، أَنَّهُمْ كَانُوا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي مَسِيرٍ، فَأَدْلَجُوا لَيْلَتَهُمْ حَتَّى إِذَا كَانَ وَجْهُ الصُّبْحِ عَرَّسُوا فَغَلَبَتْهُمْ أَعْيُنُهُمْ حَتَّى ارْتَفَعَتِ الشَّمْسُ، فَكَانَ أَوَّلَ مَنِ اسْتَيْقَظَ مِنْ مَنَامِهِ أَبُو بَكْرٍ، وَكَانَ لاَ يُوقَظُ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ مَنَامِهِ حَتَّى يَسْتَيْقِظَ، فَاسْتَيْقَظَ عُمَرُ فَقَعَدَ أَبُو بَكْرٍ عِنْدَ رَأْسِهِ فَجَعَلَ يُكَبِّرُ وَيَرْفَعُ صَوْتَهُ، حَتَّى اسْتَيْقَظَ النَّبِيُّ صلى الله عليه وسلم فَنَزَلَ وَصَلَّى بِنَا الْغَدَاةَ، فَاعْتَزَلَ رَجُلٌ مِنَ الْقَوْمِ لَمْ يُصَلِّ مَعَنَا فَلَمَّا انْصَرَفَ قَالَ ‏"‏ يَا فُلاَنُ مَا يَمْنَعُكَ أَنْ تُصَلِّيَ مَعَنَا ‏"‏‏.‏ قَالَ أَصَابَتْنِي جَنَابَةٌ‏.‏ فَأَمَرَهُ أَنْ يَتَيَمَّمَ بِالصَّعِيدِ، ثُمَّ صَلَّى وَجَعَلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فِي رَكُوبٍ بَيْنَ يَدَيْهِ، وَقَدْ عَطِشْنَا عَطَشًا شَدِيدًا فَبَيْنَمَا نَحْنُ نَسِيرُ إِذَا نَحْنُ بِامْرَأَةٍ سَادِلَةٍ رِجْلَيْهَا بَيْنَ مَزَادَتَيْنِ، فَقُلْنَا لَهَا أَيْنَ الْمَاءُ فَقَالَتْ إِنَّهُ لاَ مَاءَ‏.‏ فَقُلْنَا كَمْ بَيْنَ أَهْلِكِ وَبَيْنَ الْمَاءِ قَالَتْ يَوْمٌ وَلَيْلَةٌ‏.‏ فَقُلْنَا انْطَلِقِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏ قَالَتْ وَمَا رَسُولُ اللَّهِ فَلَمْ نُمَلِّكْهَا مِنْ أَمْرِهَا حَتَّى اسْتَقْبَلْنَا بِهَا النَّبِيَّ صلى الله عليه وسلم، فَحَدَّثَتْهُ بِمِثْلِ الَّذِي حَدَّثَتْنَا غَيْرَ أَنَّهَا حَدَّثَتْهُ أَنَّهَا مُؤْتِمَةٌ، فَأَمَرَ بِمَزَادَتَيْهَا فَمَسَحَ فِي الْعَزْلاَوَيْنِ، فَشَرِبْنَا عِطَاشًا أَرْبَعِينَ رَجُلاً حَتَّى رَوِينَا، فَمَلأْنَا كُلَّ قِرْبَةٍ مَعَنَا وَإِدَاوَةٍ، غَيْرَ أَنَّهُ لَمْ نَسْقِ بَعِيرًا وَهْىَ تَكَادُ تَنِضُّ مِنَ الْمِلْءِ ثُمَّ قَالَ ‏"‏ هَاتُوا مَا عِنْدَكُمْ ‏"‏‏.‏ فَجُمِعَ لَهَا مِنَ الْكِسَرِ وَالتَّمْرِ، حَتَّى أَتَتْ أَهْلَهَا قَالَتْ لَقِيتُ أَسْحَرَ النَّاسِ، أَوْ هُوَ نَبِيٌّ كَمَا زَعَمُوا، فَهَدَى اللَّهُ ذَاكَ الصِّرْمَ بِتِلْكَ الْمَرْأَةِ فَأَسْلَمَتْ وَأَسْلَمُوا‏.‏\hadithno{3571}\hadithtrans{Narrated `Imran bin Husain:That they were with the Prophet (ﷺ) on a journey. They travelled the whole night, and when dawn approached, they took a rest and sleep overwhelmed them till the sun rose high in the sky. The first to get up was Abu Bakr. Allah's Messenger (ﷺ) used not to be awakened from his sleep, but he would wake up by himself. `Umar woke up and then Abu Bakr sat by the side of the Prophet's head and started saying: Allahu-Akbar raising his voice till the Prophet (ﷺ) woke up, (and after traveling for a while) he dismounted and led us in the morning prayer. A man amongst the people failed to join us in the prayer. When the Prophet (ﷺ) had finished the prayer, he asked (the man), "O so-and-so! What prevented you from offering the prayer with us?" He replied, "I am Junub." Allah's Apostle ordered him to perform Tayammam with clean earth. The man then offered the prayer. Allah's Messenger (ﷺ) ordered me and a few others to go ahead of him. We had become very thirsty. While we were on our way (looking for water), we came across a lady (riding an animal), hanging her legs between two water-skins. We asked her, "Where can we get water?" She replied, "Oh ! There is no water." We asked, "how far is your house from the water?" She replied, "A distance of a day and a night travel." We said, "Come on to Allah's Messenger (ﷺ)." She asked, "What is Allah's Messenger (ﷺ)?" So we brought her to Allah's Messenger (ﷺ) against her will, and she told him what she had told us before and added that she was the mother of orphans. So the Prophet (ﷺ) ordered that her two water-skins be brought and he rubbed the mouths of the water-skins. As we were thirsty, we drank till we quenched our thirst and we were forty men. We also filled all our waterskins and other utensils with water, but we did not water the camels. The waterskin was so full that it was almost about to burst. The Prophet (ﷺ) then said, "Bring what (foodstuff) you have." So some dates and pieces of bread were collected for the lady, and when she went to her people, she said, "I have met either the greatest magician or a prophet as the people claim." So Allah guided the people of that village through that lady. She embraced Islam and they all embraced Islam}}
\hadithdefcmd{bukhari}{3572}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِإِنَاءٍ وَهْوَ بِالزَّوْرَاءِ، فَوَضَعَ يَدَهُ فِي الإِنَاءِ، فَجَعَلَ الْمَاءُ يَنْبُعُ مِنْ بَيْنِ أَصَابِعِهِ، فَتَوَضَّأَ الْقَوْمُ‏.‏ قَالَ قَتَادَةُ قُلْتُ لأَنَسٍ كَمْ كُنْتُمْ قَالَ ثَلاَثَمِائَةٍ، أَوْ زُهَاءَ ثَلاَثِمِائَةٍ‏.‏\hadithno{3572}\hadithtrans{Narrated Anas:A bowl of water was brought to the Prophet (ﷺ) while he was at Az-Zawra. He placed his hand in it and the water started flowing among his fingers. All the people performed ablution (with that water). Qatada asked Anas, "How many people were you?" Anas replied, "Three hundred or nearly three hundred}}
\hadithdefcmd{bukhari}{3573}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَحَانَتْ صَلاَةُ الْعَصْرِ، فَالْتُمِسَ الْوَضُوءُ فَلَمْ يَجِدُوهُ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِوَضُوءٍ، فَوَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ فِي ذَلِكَ الإِنَاءِ، فَأَمَرَ النَّاسَ أَنْ يَتَوَضَّئُوا مِنْهُ، فَرَأَيْتُ الْمَاءَ يَنْبُعُ مِنْ تَحْتِ أَصَابِعِهِ، فَتَوَضَّأَ النَّاسُ حَتَّى تَوَضَّئُوا مِنْ عِنْدِ آخِرِهِمْ‏.‏\hadithno{3573}\hadithtrans{Narrated Anas bin Malik:I saw Allah's Messenger (ﷺ) at the 'time when the `Asr prayer was due. Then the people were searching for water for ablution but they could not find any. Then some water was brought to Allah's Messenger (ﷺ) and he placed his hand in the pot and ordered the people to perform the ablution with the water. I saw water flowing from underneath his fingers and the people started performing the ablution till all of them did it}}
\hadithdefcmd{bukhari}{3574}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مُبَارَكٍ، حَدَّثَنَا حَزْمٌ، قَالَ سَمِعْتُ الْحَسَنَ، قَالَ حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم فِي بَعْضِ مَخَارِجِهِ وَمَعَهُ نَاسٌ مِنْ أَصْحَابِهِ، فَانْطَلَقُوا يَسِيرُونَ، فَحَضَرَتِ الصَّلاَةُ فَلَمْ يَجِدُوا مَاءً يَتَوَضَّئُونَ، فَانْطَلَقَ رَجُلٌ مِنَ الْقَوْمِ، فَجَاءَ بِقَدَحٍ مِنْ مَاءٍ يَسِيرٍ فَأَخَذَهُ النَّبِيُّ صلى الله عليه وسلم فَتَوَضَّأَ، ثُمَّ مَدَّ أَصَابِعَهُ الأَرْبَعَ عَلَى الْقَدَحِ ثُمَّ قَالَ ‏ "‏ قُومُوا فَتَوَضَّئُوا ‏"‏‏.‏ فَتَوَضَّأَ، الْقَوْمُ حَتَّى بَلَغُوا فِيمَا يُرِيدُونَ مِنَ الْوَضُوءِ، وَكَانُوا سَبْعِينَ أَوْ نَحْوَهُ‏.‏\hadithno{3574}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) went out on one of his journeys with some of his companions. They went on walking till the time of the prayer became due. They could not find water to perform the ablution. One of them went away and brought a little amount of water in a pot. The Prophet (ﷺ) took it and performed the ablution, and then stretched his four fingers on to the pot and said (to the people), "Get up to perform the ablution." They started performing the ablution till all of them did it, and they were seventy or so persons}}
\hadithdefcmd{bukhari}{3575}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُنِيرٍ، سَمِعَ يَزِيدَ، أَخْبَرَنَا حُمَيْدٌ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ حَضَرَتِ الصَّلاَةُ فَقَامَ مَنْ كَانَ قَرِيبَ الدَّارِ مِنَ الْمَسْجِدِ يَتَوَضَّأُ، وَبَقِيَ قَوْمٌ، فَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِمِخْضَبٍ مِنْ حِجَارَةٍ فِيهِ مَاءٌ، فَوَضَعَ كَفَّهُ فَصَغُرَ الْمِخْضَبُ أَنْ يَبْسُطَ فِيهِ كَفَّهُ، فَضَمَّ أَصَابِعَهُ فَوَضَعَهَا فِي الْمِخْضَبِ، فَتَوَضَّأَ الْقَوْمُ كُلُّهُمْ جَمِيعًا‏.‏ قُلْتُ كَمْ كَانُوا قَالَ ثَمَانُونَ رَجُلاً‏.‏\hadithno{3575}\hadithtrans{Narrated Humaid:Anas bin Malik said, "Once the time of the prayer became due and the people whose houses were close to the Mosque went to their houses to perform ablution, while the others remained (sitting there). A stone pot containing water was brought to the Prophet, who wanted to put his hand in it, but It was too small for him to spread his hand in it, and so he had to bring his fingers together before putting his hand in the pot. Then all the people performed the ablution (with that water)." I asked Anas, "How many persons were they." He replied, "There were eighty men}}
\hadithdefcmd{bukhari}{3576}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُسْلِمٍ، حَدَّثَنَا حُصَيْنٌ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ قَالَ عَطِشَ النَّاسُ يَوْمَ الْحُدَيْبِيَةِ، وَالنَّبِيُّ صلى الله عليه وسلم بَيْنَ يَدَيْهِ رَكْوَةٌ فَتَوَضَّأَ فَجَهَشَ النَّاسُ نَحْوَهُ، فَقَالَ ‏ "‏ مَا لَكُمْ ‏"‏‏.‏ قَالُوا لَيْسَ عِنْدَنَا مَاءٌ نَتَوَضَّأُ وَلاَ نَشْرَبُ إِلاَّ مَا بَيْنَ يَدَيْكَ، فَوَضَعَ يَدَهُ فِي الرَّكْوَةِ فَجَعَلَ الْمَاءُ يَثُورُ بَيْنَ أَصَابِعِهِ كَأَمْثَالِ الْعُيُونِ، فَشَرِبْنَا وَتَوَضَّأْنَا‏.‏ قُلْتُ كَمْ كُنْتُمْ قَالَ لَوْ كُنَّا مِائَةَ أَلْفٍ لَكَفَانَا، كُنَّا خَمْسَ عَشْرَةَ مِائَةً‏.‏\hadithno{3576}\hadithtrans{Narrated Salim bin Abi Aj-Jad:Jabir bin `Abdullah said, "The people became very thirsty on the day of Al-Hudaibiya (Treaty). A small pot containing some water was in front of the Prophet (ﷺ) and when he had finished the ablution, the people rushed towards him. He asked, 'What is wrong with you?' They replied, 'We have no water either for performing ablution or for drinking except what is present in front of you.' So he placed his hand in that pot and the water started flowing among his fingers like springs. We all drank and performed ablution (from it)." I asked Jabir, "How many were you?" he replied, "Even if we had been one-hundred-thousand, it would have been sufficient for us, but we were fifteen-hundred}}
\hadithdefcmd{bukhari}{3577}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ ـ رضى الله عنه ـ قَالَ كُنَّا يَوْمَ الْحُدَيْبِيَةِ أَرْبَعَ عَشْرَةَ مِائَةً، وَالْحُدَيْبِيَةُ بِئْرٌ فَنَزَحْنَاهَا حَتَّى لَمْ نَتْرُكْ فِيهَا قَطْرَةً، فَجَلَسَ النَّبِيُّ صلى الله عليه وسلم عَلَى شَفِيرِ الْبِئْرِ، فَدَعَا بِمَاءٍ فَمَضْمَضَ وَمَجَّ فِي الْبِئْرِ، فَمَكَثْنَا غَيْرَ بَعِيدٍ ثُمَّ اسْتَقَيْنَا حَتَّى رَوِينَا وَرَوَتْ ـ أَوْ صَدَرَتْ ـ رَكَائِبُنَا‏.‏\hadithno{3577}\hadithtrans{Narrated Al-Bara:We were one-thousand-and-four-hundred persons on the day of Al-Hudaibiya (Treaty), and (at) Al- Hudaibiya (there) was a well. We drew out its water not leaving even a single drop. The Prophet (ﷺ) sat at the edge of the well and asked for some water with which he rinsed his mouth and then he threw it out into the well. We stayed for a short while and then drew water from the well and quenched our thirst, and even our riding animals drank water to their satisfaction}}
\hadithdefcmd{bukhari}{3578}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ أَبُو طَلْحَةَ لأُمِّ سُلَيْمٍ لَقَدْ سَمِعْتُ صَوْتَ، رَسُولِ اللَّهِ صلى الله عليه وسلم ضَعِيفًا، أَعْرِفُ فِيهِ الْجُوعَ فَهَلْ عِنْدَكِ مِنْ شَىْءٍ قَالَتْ نَعَمْ‏.‏ فَأَخْرَجَتْ أَقْرَاصًا مِنْ شَعِيرٍ، ثُمَّ أَخْرَجَتْ خِمَارًا لَهَا فَلَفَّتِ الْخُبْزَ بِبَعْضِهِ، ثُمَّ دَسَّتْهُ تَحْتَ يَدِي وَلاَثَتْنِي بِبَعْضِهِ، ثُمَّ أَرْسَلَتْنِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَذَهَبْتُ بِهِ، فَوَجَدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ وَمَعَهُ النَّاسُ، فَقُمْتُ عَلَيْهِمْ فَقَالَ لِي رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ آرْسَلَكَ أَبُو طَلْحَةَ ‏"‏‏.‏ فَقُلْتُ نَعَمْ‏.‏ قَالَ بِطَعَامٍ‏.‏ فَقُلْتُ نَعَمْ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِمَنْ مَعَهُ ‏"‏ قُومُوا ‏"‏‏.‏ فَانْطَلَقَ وَانْطَلَقْتُ بَيْنَ أَيْدِيهِمْ حَتَّى جِئْتُ أَبَا طَلْحَةَ فَأَخْبَرْتُهُ‏.‏ فَقَالَ أَبُو طَلْحَةَ يَا أُمَّ سُلَيْمٍ، قَدْ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالنَّاسِ، وَلَيْسَ عِنْدَنَا مَا نُطْعِمُهُمْ‏.‏ فَقَالَتِ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ فَانْطَلَقَ أَبُو طَلْحَةَ حَتَّى لَقِيَ رَسُولَ اللَّهِ صلى الله عليه وسلم، فَأَقْبَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَبُو طَلْحَةَ مَعَهُ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلُمِّي يَا أُمَّ سُلَيْمٍ مَا عِنْدَكِ ‏"‏‏.‏ فَأَتَتْ بِذَلِكَ الْخُبْزِ، فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَفُتَّ، وَعَصَرَتْ أُمُّ سُلَيْمٍ عُكَّةً فَأَدَمَتْهُ، ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِيهِ مَا شَاءَ اللَّهُ أَنْ يَقُولَ، ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ ‏"‏‏.‏ فَأَذِنَ لَهُمْ، فَأَكَلُوا حَتَّى شَبِعُوا ثُمَّ خَرَجُوا، ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ ‏"‏‏.‏ فَأَذِنَ لَهُمْ، فَأَكَلُوا حَتَّى شَبِعُوا ثُمَّ خَرَجُوا، ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ ‏"‏‏.‏ فَأَذِنَ لَهُمْ، فَأَكَلُوا حَتَّى شَبِعُوا ثُمَّ خَرَجُوا ثُمَّ قَالَ ‏"‏ ائْذَنْ لِعَشَرَةٍ ‏"‏‏.‏ فَأَكَلَ الْقَوْمُ كُلُّهُمْ وَشَبِعُوا، وَالْقَوْمُ سَبْعُونَ ـ أَوْ ثَمَانُونَ ـ رَجُلاً‏.‏\hadithno{3578}\hadithtrans{Narrated Anas bin Malik:Abu Talha said to Um Sulaim, "I have noticed feebleness in the voice of Allah's Messenger (ﷺ) which I think, is caused by hunger. Have you got any food?" She said, "Yes." She brought out some loaves of barley and took out a veil belonging to her, and wrapped the bread in part of it and put it under my arm and wrapped part of the veil round me and sent me to Allah's Messenger (ﷺ). I went carrying it and found Allah's Messenger (ﷺ) in the Mosque sitting with some people. When I stood there, Allah's Messenger (ﷺ) asked, "Has Abu Talha sent you?" I said, "Yes". He asked, "With some food? I said, "Yes" Allah's Apostle then said to the men around him, "Get up!" He set out (accompanied by them) and I went ahead of them till I reached Abu Talha and told him (of the Prophet's visit). Abu Talha said, "O Um Sulaim! Allah's Messenger (ﷺ) is coming with the people and we have no food to feed them." She said, "Allah and His Apostle know better." So Abu Talha went out to receive Allah's Messenger (ﷺ). Allah's Apostle came along with Abu Talha. Allah's Messenger (ﷺ) said, "O Um Sulaim! Bring whatever you have." She brought the bread which Allah's Messenger (ﷺ) ordered to be broken into pieces. Um Sulaim poured on them some butter from an oilskin. Then Allah's Messenger (ﷺ) recited what Allah wished him to recite, and then said, "Let ten persons come (to share the meal)." Ten persons were admitted, ate their fill and went out. Then he again said, "Let another ten do the same." They were admitted, ate their fill and went out. Then he again said, '"'Let another ten persons (do the same.)" They were admitted, ate their fill and went out. Then he said, "Let another ten persons come." In short, all of them ate their fill, and they were seventy or eighty men}}
\hadithdefcmd{bukhari}{3579}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو أَحْمَدَ الزُّبَيْرِيُّ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا نَعُدُّ الآيَاتِ بَرَكَةً وَأَنْتُمْ تَعُدُّونَهَا تَخْوِيفًا، كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَقَلَّ الْمَاءُ فَقَالَ ‏"‏ اطْلُبُوا فَضْلَةً مِنْ مَاءٍ ‏"‏‏.‏ فَجَاءُوا بِإِنَاءٍ فِيهِ مَاءٌ قَلِيلٌ، فَأَدْخَلَ يَدَهُ فِي الإِنَاءِ، ثُمَّ قَالَ ‏"‏ حَىَّ عَلَى الطَّهُورِ الْمُبَارَكِ، وَالْبَرَكَةُ مِنَ اللَّهِ ‏"‏ فَلَقَدْ رَأَيْتُ الْمَاءَ يَنْبُعُ مِنْ بَيْنِ أَصَابِعِ رَسُولِ اللَّهِ صلى الله عليه وسلم، وَلَقَدْ كُنَّا نَسْمَعُ تَسْبِيحَ الطَّعَامِ وَهْوَ يُؤْكَلُ‏.‏\hadithno{3579}\hadithtrans{Narrated `Abdullah:We used to consider miracles as Allah's Blessings, but you people consider them to be a warning. Once we were with Allah's Messenger (ﷺ) on a journey, and we ran short of water. He said, "Bring the water remaining with you." The people brought a utensil containing a little water. He placed his hand in it and said, "Come to the blessed water, and the Blessing is from Allah." I saw the water flowing from among the fingers of Allah's Messenger (ﷺ) , and no doubt, we heard the meal glorifying Allah, when it was being eaten (by him)}}
\hadithdefcmd{bukhari}{3580}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا زَكَرِيَّاءُ، قَالَ حَدَّثَنِي عَامِرٌ، قَالَ حَدَّثَنِي جَابِرٌ ـ رضى الله عنه ـ أَنَّ أَبَاهُ، تُوُفِّيَ وَعَلَيْهِ دَيْنٌ، فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ إِنَّ أَبِي تَرَكَ عَلَيْهِ دَيْنًا وَلَيْسَ عِنْدِي إِلاَّ مَا يُخْرِجُ نَخْلُهُ، وَلاَ يَبْلُغُ مَا يُخْرِجُ سِنِينَ مَا عَلَيْهِ، فَانْطَلِقْ مَعِي لِكَىْ لاَ يُفْحِشَ عَلَىَّ الْغُرَمَاءُ‏.‏ فَمَشَى حَوْلَ بَيْدَرٍ مِنْ بَيَادِرِ التَّمْرِ فَدَعَا ثَمَّ آخَرَ، ثُمَّ جَلَسَ عَلَيْهِ فَقَالَ ‏ "‏ انْزِعُوهُ ‏"‏‏.‏ فَأَوْفَاهُمُ الَّذِي لَهُمْ، وَبَقِيَ مِثْلُ مَا أَعْطَاهُمْ‏.‏\hadithno{3580}\hadithtrans{Narrated Jabir:My father had died in debt. So I came to the Prophet (ﷺ) and said, "My father (died) leaving unpaid debts, and I have nothing except the yield of his date palms; and their yield for many years will not cover his debts. So please come with me, so that the creditors may not misbehave with me." The Prophet (ﷺ) went round one of the heaps of dates and invoked (Allah), and then did the same with another heap and sat on it and said, "Measure (for them)." He paid them their rights and what remained was as much as had been paid to them}}
\hadithdefcmd{bukhari}{3581}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مُعْتَمِرٌ، عَنْ أَبِيهِ، حَدَّثَنَا أَبُو عُثْمَانَ، أَنَّهُ حَدَّثَهُ عَبْدُ الرَّحْمَنِ بْنُ أَبِي بَكْرٍ ـ رضى الله عنهما ـ أَنَّ أَصْحَابَ، الصُّفَّةِ كَانُوا أُنَاسًا فُقَرَاءَ، وَأَنَّ النَّبِيَّ ـ صلى الله عليه وسلم قَالَ مَرَّةً ‏ "‏ مَنْ كَانَ عِنْدَهُ طَعَامُ اثْنَيْنِ فَلْيَذْهَبْ بِثَالِثٍ، وَمَنْ كَانَ عِنْدَهُ طَعَامُ أَرْبَعَةٍ فَلْيَذْهَبْ بِخَامِسٍ أَوْ سَادِسٍ ‏"‏‏.‏ أَوْ كَمَا قَالَ، وَأَنَّ أَبَا بَكْرٍ جَاءَ بِثَلاَثَةٍ وَانْطَلَقَ النَّبِيُّ صلى الله عليه وسلم بِعَشَرَةٍ، وَأَبُو بَكْرٍ وَثَلاَثَةً، قَالَ فَهْوَ أَنَا وَأَبِي وَأُمِّي ـ وَلاَ أَدْرِي هَلْ قَالَ امْرَأَتِي وَخَادِمِي ـ بَيْنَ بَيْتِنَا وَبَيْنَ بَيْتِ أَبِي بَكْرٍ، وَأَنَّ أَبَا بَكْرٍ تَعَشَّى عِنْدَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ لَبِثَ حَتَّى صَلَّى الْعِشَاءَ، ثُمَّ رَجَعَ فَلَبِثَ حَتَّى تَعَشَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَاءَ بَعْدَ مَا مَضَى مِنَ اللَّيْلِ مَا شَاءَ اللَّهُ، قَالَتْ لَهُ امْرَأَتُهُ مَا حَبَسَكَ عَنْ أَضْيَافِكَ أَوْ ضَيْفِكَ‏.‏ قَالَ أَوَ عَشَّيْتِهِمْ قَالَتْ أَبَوْا حَتَّى تَجِيءَ، قَدْ عَرَضُوا عَلَيْهِمْ فَغَلَبُوهُمْ، فَذَهَبْتُ فَاخْتَبَأْتُ، فَقَالَ يَا غُنْثَرُ‏.‏ فَجَدَّعَ وَسَبَّ وَقَالَ كُلُوا وَقَالَ لاَ أَطْعَمُهُ أَبَدًا‏.‏ قَالَ وَايْمُ اللَّهِ مَا كُنَّا نَأْخُذُ مِنَ اللُّقْمَةِ إِلاَّ رَبَا مِنْ أَسْفَلِهَا أَكْثَرُ مِنْهَا حَتَّى شَبِعُوا، وَصَارَتْ أَكْثَرَ مِمَّا كَانَتْ قَبْلُ، فَنَظَرَ أَبُو بَكْرٍ فَإِذَا شَىْءٌ أَوْ أَكْثَرُ قَالَ لاِمْرَأَتِهِ يَا أُخْتَ بَنِي فِرَاسٍ‏.‏ قَالَتْ لاَ وَقُرَّةِ عَيْنِي لَهْىَ الآنَ أَكْثَرُ مِمَّا قَبْلُ بِثَلاَثِ مَرَّاتٍ‏.‏ فَأَكَلَ مِنْهَا أَبُو بَكْرٍ، وَقَالَ إِنَّمَا كَانَ الشَّيْطَانُ ـ يَعْنِي يَمِينَهُ ـ ثُمَّ أَكَلَ مِنْهَا لُقْمَةً، ثُمَّ حَمَلَهَا إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَصْبَحَتْ عِنْدَهُ‏.‏ وَكَانَ بَيْنَنَا وَبَيْنَ قَوْمٍ عَهْدٌ، فَمَضَى الأَجَلُ، فَتَفَرَّقْنَا اثْنَا عَشَرَ رَجُلاً مَعَ كُلِّ رَجُلٍ مِنْهُمْ أُنَاسٌ‏.‏ اللَّهُ أَعْلَمُ كَمْ مَعَ كُلِّ رَجُلٍ، غَيْرَ أَنَّهُ بَعَثَ مَعَهُمْ، قَالَ أَكَلُوا مِنْهَا أَجْمَعُونَ‏.‏ أَوْ كَمَا قَالَ‏.‏ وَغَيْرُهُ يَقُولُ فَعَرَفْنَا مِنْ الْعِرَافَةِ\hadithno{3581}\hadithtrans{Narrated `Abdur-Rahman bin Abi Bakr:The companions of Suffa were poor people. The Prophet (ﷺ) once said, "Whoever has food enough for two persons, should take a third one (from among them), and whoever has food enough for four persons, should take a fifth or a sixth (or said something similar)." Abu Bakr brought three persons while the Prophet (ﷺ) took ten. And Abu Bakr with his three family members (who were I, my father and my mother) (the sub-narrator is in doubt whether `Abdur-Rahman said, "My wife and my servant who was common for both my house and Abu Bakr's house.") Abu Bakr took his supper with the Prophet (ﷺ) and stayed there till he offered the `Isha' prayers. He returned and stayed till Allah's Messenger (ﷺ) took his supper. After a part of the night had passed, he returned to his house. His wife said to him, "What has detained you from your guests?" He said, "Have you served supper to them?" She said, "They refused to take supper until you come. They (i.e. some members of the household) presented the meal to them but they refused (to eat)" I went to hide myself and he said, "O Ghunthar!" He invoked Allah to cause my ears to be cut and he rebuked me. He then said (to them): Please eat!" and added, I will never eat the meal." By Allah, whenever we took a handful of the meal, the meal grew from underneath more than that handful till everybody ate to his satisfaction; yet the remaining food was more than the original meal. Abu Bakr saw that the food was as much or more than the original amount. He called his wife, "O sister of Bani Firas!" She said, "O pleasure of my eyes. The food has been tripled in quantity." Abu Bakr then started eating thereof and said, "It (i.e. my oath not to eat) was because of Satan." He took a handful from it, and carried the rest to the Prophet. So that food was with the Prophet (ﷺ). There was a treaty between us and some people, and when the period of that treaty had elapsed, he divided us into twelve groups, each being headed by a man. Allah knows how many men were under the command of each leader. Anyhow, the Prophet (ﷺ) surely sent a leader with each group. Then all of them ate of that meal}}
\hadithdefcmd{bukhari}{3582}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادٌ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، وَعَنْ يُونُسَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ أَصَابَ أَهْلَ الْمَدِينَةِ قَحْطٌ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم، فَبَيْنَا هُوَ يَخْطُبُ يَوْمَ جُمُعَةٍ إِذْ قَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ هَلَكَتِ الْكُرَاعُ، هَلَكَتِ الشَّاءُ، فَادْعُ اللَّهَ يَسْقِينَا، فَمَدَّ يَدَيْهِ وَدَعَا‏.‏ قَالَ أَنَسٌ وَإِنَّ السَّمَاءَ لَمِثْلُ الزُّجَاجَةِ فَهَاجَتْ رِيحٌ أَنْشَأَتْ سَحَابًا ثُمَّ اجْتَمَعَ، ثُمَّ أَرْسَلَتِ السَّمَاءُ عَزَالِيَهَا، فَخَرَجْنَا نَخُوضُ الْمَاءَ حَتَّى أَتَيْنَا مَنَازِلَنَا، فَلَمْ نَزَلْ نُمْطَرُ إِلَى الْجُمُعَةِ الأُخْرَى، فَقَامَ إِلَيْهِ ذَلِكَ الرَّجُلُ ـ أَوْ غَيْرُهُ ـ فَقَالَ يَا رَسُولَ اللَّهِ، تَهَدَّمَتِ الْبُيُوتُ، فَادْعُ اللَّهَ يَحْبِسْهُ‏.‏ فَتَبَسَّمَ ثُمَّ قَالَ ‏ "‏ حَوَالَيْنَا وَلاَ عَلَيْنَا ‏"‏‏.‏ فَنَظَرْتُ إِلَى السَّحَابِ تَصَدَّعَ حَوْلَ الْمَدِينَةِ كَأَنَّهُ إِكْلِيلٌ‏.‏\hadithno{3582}\hadithtrans{Narrated Anas:Once during the lifetime of Allah's Messenger (ﷺ), the people of Medina suffered from drought. So while the Prophet was delivering a sermon on a Friday a man got up saying, "O Allah's Messenger (ﷺ)! The horses and sheep have perished. Will you invoke Allah to bless us with rain?" The Prophet (ﷺ) lifted both his hands and invoked. The sky at that time was as clear as glass. Suddenly a wind blew, raising clouds that gathered together, and it started raining heavily. We came out (of the Mosque) wading through the flowing water till we reached our homes. It went on raining till the next Friday, when the same man or some other man stood up and said, "O Allah's Messenger (ﷺ)! The houses have collapsed; please invoke Allah to withhold the rain." On that the Prophet (ﷺ) smiled and said, "O Allah, (let it rain) around us and not on us." I then looked at the clouds to see them separating forming a sort of a crown round Medina}}
\hadithdefcmd{bukhari}{3583}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ كَثِيرٍ أَبُو غَسَّانَ، حَدَّثَنَا أَبُو حَفْصٍ ـ وَاسْمُهُ عُمَرُ بْنُ الْعَلاَءِ أَخُو أَبِي عَمْرِو بْنِ الْعَلاَءِ ـ قَالَ سَمِعْتُ نَافِعًا، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ كَانَ النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ إِلَى جِذْعٍ فَلَمَّا اتَّخَذَ الْمِنْبَرَ تَحَوَّلَ إِلَيْهِ، فَحَنَّ الْجِذْعُ فَأَتَاهُ فَمَسَحَ يَدَهُ عَلَيْهِ‏.‏ وَقَالَ عَبْدُ الْحَمِيدِ أَخْبَرَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا مُعَاذُ بْنُ الْعَلاَءِ، عَنْ نَافِعٍ، بِهَذَا‏.‏ وَرَوَاهُ أَبُو عَاصِمٍ عَنِ ابْنِ أَبِي رَوَّادٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3583}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) used to deliver his sermons while standing beside a trunk of a datepalm. When he had the pulpit made, he used it instead. The trunk started crying and the Prophet (ﷺ) went to it, rubbing his hand over it (to stop its crying)}}
\hadithdefcmd{bukhari}{3584}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ أَيْمَنَ، قَالَ سَمِعْتُ أَبِي، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُومُ يَوْمَ الْجُمُعَةِ إِلَى شَجَرَةٍ أَوْ نَخْلَةٍ، فَقَالَتِ امْرَأَةٌ مِنَ الأَنْصَارِ ـ أَوْ رَجُلٌ ـ يَا رَسُولَ اللَّهِ أَلاَ نَجْعَلُ لَكَ مِنْبَرًا قَالَ ‏"‏ إِنْ شِئْتُمْ ‏"‏‏.‏ فَجَعَلُوا لَهُ مِنْبَرًا، فَلَمَّا كَانَ يَوْمُ الْجُمُعَةِ دُفِعَ إِلَى الْمِنْبَرِ، فَصَاحَتِ النَّخْلَةُ صِيَاحَ الصَّبِيِّ، ثُمَّ نَزَلَ النَّبِيُّ صلى الله عليه وسلم فَضَمَّهُ إِلَيْهِ تَئِنُّ أَنِينَ الصَّبِيِّ، الَّذِي يُسَكَّنُ، قَالَ ‏"‏ كَانَتْ تَبْكِي عَلَى مَا كَانَتْ تَسْمَعُ مِنَ الذِّكْرِ عِنْدَهَا ‏"‏‏.‏\hadithno{3584}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) used to stand by a tree or a date-palm on Friday. Then an Ansari woman or man said. "O Allah's Messenger (ﷺ)! Shall we make a pulpit for you?" He replied, "If you wish." So they made a pulpit for him and when it was Friday, he proceeded towards the pulpit (for delivering the sermon). The datepalm cried like a child! The Prophet (ﷺ) descended (the pulpit) and embraced it while it continued moaning like a child being quietened. The Prophet (ﷺ) said, "It was crying for (missing) what it used to hear of religious knowledge given near to it}}
\hadithdefcmd{bukhari}{3585}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ بْنِ بِلاَلٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، قَالَ أَخْبَرَنِي حَفْصُ بْنُ عُبَيْدِ اللَّهِ بْنِ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ ـ رضى الله عنهما ـ يَقُولُ كَانَ الْمَسْجِدُ مَسْقُوفًا عَلَى جُذُوعٍ مِنْ نَخْلٍ فَكَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا خَطَبَ يَقُومُ إِلَى جِذْعٍ مِنْهَا، فَلَمَّا صُنِعَ لَهُ الْمِنْبَرُ، وَكَانَ عَلَيْهِ فَسَمِعْنَا لِذَلِكَ الْجِذْعِ صَوْتًا كَصَوْتِ الْعِشَارِ، حَتَّى جَاءَ النَّبِيُّ صلى الله عليه وسلم فَوَضَعَ يَدَهُ عَلَيْهَا فَسَكَنَتْ‏.‏\hadithno{3585}\hadithtrans{Narrated Anas bin Malik:That he heard Jabir bin `Abdullah saying, "The roof of the Mosque was built over trunks of datepalms working as pillars. When the Prophet (ﷺ) delivered a sermon, he used to stand by one of those trunks till the pulpit was made for him, and he used it instead. Then we heard the trunk sending a sound like of a pregnant she-camel till the Prophet (ﷺ) came to it, and put his hand over it, then it became quiet}}
\hadithdefcmd{bukhari}{3586}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ،‏.‏ حَدَّثَنِي بِشْرُ بْنُ خَالِدٍ، حَدَّثَنَا مُحَمَّدٌ، عَنْ شُعْبَةَ، عَنْ سُلَيْمَانَ، سَمِعْتُ أَبَا وَائِلٍ، يُحَدِّثُ عَنْ حُذَيْفَةَ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ ـ رضى الله عنه ـ قَالَ أَيُّكُمْ يَحْفَظُ قَوْلَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْفِتْنَةِ فَقَالَ حُذَيْفَةُ أَنَا أَحْفَظُ كَمَا قَالَ‏.‏ قَالَ هَاتِ إِنَّكَ لَجَرِيءٌ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فِتْنَةُ الرَّجُلِ فِي أَهْلِهِ وَمَالِهِ وَجَارِهِ تُكَفِّرُهَا الصَّلاَةُ وَالصَّدَقَةُ وَالأَمْرُ بِالْمَعْرُوفِ وَالنَّهْىُ عَنِ الْمُنْكَرِ ‏"‏‏.‏ قَالَ لَيْسَتْ هَذِهِ، وَلَكِنِ الَّتِي تَمُوجُ كَمَوْجِ الْبَحْرِ‏.‏ قَالَ يَا أَمِيرَ الْمُؤْمِنِينَ لاَ بَأْسَ عَلَيْكَ مِنْهَا، إِنَّ بَيْنَكَ وَبَيْنَهَا بَابًا مُغْلَقًا‏.‏ قَالَ يُفْتَحُ الْبَابُ أَوْ يُكْسَرُ قَالَ لاَ بَلْ يُكْسَرُ‏.‏ قَالَ ذَاكَ أَحْرَى أَنْ لاَ يُغْلَقَ‏.‏ قُلْنَا عَلِمَ الْبَابَ قَالَ نَعَمْ، كَمَا أَنَّ دُونَ غَدٍ اللَّيْلَةَ، إِنِّي حَدَّثْتُهُ حَدِيثًا لَيْسَ بِالأَغَالِيطِ‏.‏ فَهِبْنَا أَنْ نَسْأَلَهُ، وَأَمَرْنَا مَسْرُوقًا، فَسَأَلَهُ فَقَالَ مَنِ الْبَابُ قَالَ عُمَرُ‏.‏\hadithno{3586}\hadithtrans{Narrated Hudhaifa:Once `Umar bin Al-Khattab said, "Who amongst you remembers the statement of Allah's Apostle regarding the afflictions?" Hudhaifa replied, "I remember what he said exactly." `Umar said, "Tell (us), you are really a daring man!" Hudhaifa said, "Allah's Messenger (ﷺ) said, 'A man's afflictions (i.e. wrong deeds) concerning his relation to his family, his property and his neighbors are expiated by his prayers, giving in charity and enjoining what is good and forbidding what is evil.' " `Umar said, "I don't mean these afflictions but the afflictions that will be heaving up and down like waves of the sea." Hudhaifa replied, "O chief of the believers! You need not fear those (afflictions) as there is a closed door between you and them." `Umar asked, "Will that door be opened or broken?" Hudhaifa replied, "No, it will be broken." `Umar said, "Then it is very likely that the door will not be closed again." Later on the people asked Hudhaifa, "Did `Umar know what that door meant?" He said, "Yes, `Umar knew it as everyone knows that there will be night before the tomorrow morning. I narrated to `Umar an authentic narration, not lies." We dared not ask Hudhaifa; therefore we requested Masruq who asked him, "What does the door stand for?" He said, "`Umar}}
\hadithdefcmd{bukhari}{3589}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا قَوْمًا نِعَالُهُمُ الشَّعَرُ، وَحَتَّى تُقَاتِلُوا التُّرْكَ، صِغَارَ الأَعْيُنِ، حُمْرَ الْوُجُوهِ، ذُلْفَ الأُنُوفِ كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطْرَقَةُ ‏"‏‏.‏ "«وَتَجِدُونَ مِنْ خَيْرِ النَّاسِ أَشَدَّهُمْ كَرَاهِيَةً لِهَذَا الأَمْرِ، حَتَّى يَقَعَ فِيهِ، وَالنَّاسُ مَعَادِنُ، خِيَارُهُمْ فِي الْجَاهِلِيَّةِ خِيَارُهُمْ فِي الإِسْلاَمِ." "وَلَيَأْتِيَنَّ عَلَى أَحَدِكُمْ زَمَانٌ لأَنْ يَرَانِي أَحَبُّ إِلَيْهِ مِنْ أَنْ يَكُونَ لَهُ مِثْلُ أَهْلِهِ وَمَالِهِ\hadithno{3589}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The Hour will not be established till you fight a nation wearing hairy shoes, and till you fight the Turks, who will have small eyes, red faces and flat noses; and their faces will be like flat shields. And you will find that the best people are those who hate responsibility of ruling most of all till they are chosen to be the rulers. And the people are of different natures: The best in the pre-Islamic period are the best in Islam. A time will come when any of you will love to see me rather than to have his family and property doubled}}
\hadithdefcmd{bukhari}{3590}{حَدَّثَنِي يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تُقَاتِلُوا خُوزًا وَكَرْمَانَ مِنَ الأَعَاجِمِ، حُمْرَ الْوُجُوهِ، فُطْسَ الأُنُوفِ، صِغَارَ الأَعْيُنِ، وُجُوهُهُمُ الْمَجَانُّ الْمُطْرَقَةُ، نِعَالُهُمُ الشَّعَرُ ‏"‏‏.‏ تَابَعَهُ غَيْرُهُ عَنْ عَبْدِ الرَّزَّاقِ‏.‏\hadithno{3590}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The Hour will not be established till you fight with the Khudh and the Kirman from among the non-Arabs. They will be of red faces, flat noses and small eyes; their faces will look like flat shields, and their shoes will be of hair}}
\hadithdefcmd{bukhari}{3591}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ قَالَ إِسْمَاعِيلُ أَخْبَرَنِي قَيْسٌ، قَالَ أَتَيْنَا أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ فَقَالَ صَحِبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ثَلاَثَ سِنِينَ لَمْ أَكُنْ فِي سِنِيَّ أَحْرَصَ عَلَى أَنْ أَعِيَ الْحَدِيثَ مِنِّي فِيهِنَّ سَمِعْتُهُ يَقُولُ وَقَالَ هَكَذَا بِيَدِهِ ‏ "‏ بَيْنَ يَدَىِ السَّاعَةِ تُقَاتِلُونَ قَوْمًا نِعَالُهُمُ الشَّعَرُ، وَهُوَ هَذَا الْبَارِزُ ‏"‏‏.‏ وَقَالَ سُفْيَانُ مَرَّةً وَهُمْ أَهْلُ الْبَازَرِ‏.‏\hadithno{3591}\hadithtrans{Narrated Abu Huraira:I enjoyed the company of Allah's Messenger (ﷺ) for three years, and during the other years of my life, never was I so anxious to understand the (Prophet's) traditions as I was during those three years. I heard him saying, beckoning with his hand in this way, "Before the Hour you will fight with people who will have hairy shoes and live in Al-Bariz." (Sufyan, the sub-narrator once said, "And they are the people of Al-Bazar)}}
\hadithdefcmd{bukhari}{3592}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، سَمِعْتُ الْحَسَنَ، يَقُولُ حَدَّثَنَا عَمْرُو بْنُ تَغْلِبَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ بَيْنَ يَدَىِ السَّاعَةِ تُقَاتِلُونَ قَوْمًا يَنْتَعِلُونَ الشَّعَرَ، وَتُقَاتِلُونَ قَوْمًا كَأَنَّ وُجُوهَهُمُ الْمَجَانُّ الْمُطْرَقَةُ ‏"‏‏.‏\hadithno{3592}\hadithtrans{Narrated `Umar bin Taghlib:I heard Allah's Messenger (ﷺ) saying, "Near the Hour you will fight with people who will wear hairy shoes; and you will also fight people with flat faces like shields}}
\hadithdefcmd{bukhari}{3593}{حَدَّثَنَا الْحَكَمُ بْنُ نَافِعٍ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ تُقَاتِلُكُمُ الْيَهُودُ فَتُسَلَّطُونَ عَلَيْهِمْ ثُمَّ يَقُولُ الْحَجَرُ يَا مُسْلِمُ، هَذَا يَهُودِيٌّ وَرَائِي فَاقْتُلْهُ ‏"‏‏.‏\hadithno{3593}\hadithtrans{Narrated `Abdullah bin `Umar:I heard Allah's Messenger (ﷺ) saying, "The Jews will fight with you, and you will be given victory over them so that a stone will say, 'O Muslim! There is a Jew behind me; kill him}}
\hadithdefcmd{bukhari}{3594}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ جَابِرٍ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَأْتِي عَلَى النَّاسِ زَمَانٌ يَغْزُونَ، فَيُقَالُ فِيكُمْ مَنْ صَحِبَ الرَّسُولَ صلى الله عليه وسلم فَيَقُولُونَ نَعَمْ‏.‏ فَيُفْتَحُ عَلَيْهِمْ، ثُمَّ يَغْزُونَ فَيُقَالُ لَهُمْ هَلْ فِيكُمْ مَنْ صَحِبَ مَنْ صَحِبَ الرَّسُولَ صلى الله عليه وسلم فَيَقُولُونَ نَعَمْ‏.‏ فَيُفْتَحُ لَهُمْ ‏"‏‏.‏\hadithno{3594}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "A time will come when the people will wage holy war, and it will be asked, 'Is there any amongst you who has enjoyed the company of Allah's Messenger (ﷺ)?' They will say: 'Yes.' And then victory will be bestowed upon them. They will wage holy war again, and it will be asked: 'Is there any among you who has enjoyed the company of the companions of Allah's Messenger (ﷺ) ?' They will say: 'Yes.' And then victory will be bestowed on them}}
\hadithdefcmd{bukhari}{3595}{حَدَّثَنِي مُحَمَّدُ بْنُ الْحَكَمِ، أَخْبَرَنَا النَّضْرُ، أَخْبَرَنَا إِسْرَائِيلُ، أَخْبَرَنَا سَعْدٌ الطَّائِيُّ، أَخْبَرَنَا مُحِلُّ بْنُ خَلِيفَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ بَيْنَا أَنَا عِنْدَ النَّبِيِّ، صلى الله عليه وسلم إِذْ أَتَاهُ رَجُلٌ فَشَكَا إِلَيْهِ الْفَاقَةَ، ثُمَّ أَتَاهُ آخَرُ، فَشَكَا قَطْعَ السَّبِيلِ‏.‏ فَقَالَ ‏"‏ يَا عَدِيُّ هَلْ رَأَيْتَ الْحِيرَةَ ‏"‏‏.‏ قُلْتُ لَمْ أَرَهَا وَقَدْ أُنْبِئْتُ عَنْهَا‏.‏ قَالَ ‏"‏ فَإِنْ طَالَتْ بِكَ حَيَاةٌ لَتَرَيَنَّ الظَّعِينَةَ تَرْتَحِلُ مِنَ الْحِيرَةِ، حَتَّى تَطُوفَ بِالْكَعْبَةِ، لاَ تَخَافُ أَحَدًا إِلاَّ اللَّهَ ‏"‏ ـ قُلْتُ فِيمَا بَيْنِي وَبَيْنَ نَفْسِي فَأَيْنَ دُعَّارُ طَيِّئٍ الَّذِينَ قَدْ سَعَّرُوا الْبِلاَدَ ‏"‏ وَلَئِنْ طَالَتْ بِكَ حَيَاةٌ لَتُفْتَحَنَّ كُنُوزُ كِسْرَى ‏"‏‏.‏ قُلْتُ كِسْرَى بْنِ هُرْمُزَ قَالَ ‏"‏ كِسْرَى بْنِ هُرْمُزَ، وَلَئِنْ طَالَتْ بِكَ حَيَاةٌ، لَتَرَيَنَّ الرَّجُلَ يُخْرِجُ مِلْءَ كَفِّهِ مِنْ ذَهَبٍ أَوْ فِضَّةٍ، يَطْلُبُ مَنْ يَقْبَلُهُ مِنْهُ، فَلاَ يَجِدُ أَحَدًا يَقْبَلُهُ مِنْهُ، وَلَيَلْقَيَنَّ اللَّهَ أَحَدُكُمْ يَوْمَ يَلْقَاهُ، وَلَيْسَ بَيْنَهُ وَبَيْنَهُ تُرْجُمَانٌ يُتَرْجِمُ لَهُ‏.‏ فَيَقُولَنَّ أَلَمْ أَبْعَثْ إِلَيْكَ رَسُولاً فَيُبَلِّغَكَ فَيَقُولُ بَلَى‏.‏ فَيَقُولُ أَلَمْ أُعْطِكَ مَالاً وَأُفْضِلْ عَلَيْكَ فَيَقُولُ بَلَى‏.‏ فَيَنْظُرُ عَنْ يَمِينِهِ فَلاَ يَرَى إِلاَّ جَهَنَّمَ، وَيَنْظُرُ عَنْ يَسَارِهِ فَلاَ يَرَى إِلاَّ جَهَنَّمَ ‏"‏‏.‏ قَالَ عَدِيٌّ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ اتَّقُوا النَّارَ وَلَوْ بِشِقَّةِ تَمْرَةٍ، فَمَنْ لَمْ يَجِدْ شِقَّةَ تَمْرَةٍ فَبِكَلِمَةٍ طَيِّبَةٍ ‏"‏‏.‏ قَالَ عَدِيٌّ فَرَأَيْتُ الظَّعِينَةَ تَرْتَحِلُ مِنَ الْحِيرَةِ حَتَّى تَطُوفَ بِالْكَعْبَةِ، لاَ تَخَافُ إِلاَّ اللَّهَ، وَكُنْتُ فِيمَنِ افْتَتَحَ كُنُوزَ كِسْرَى بْنِ هُرْمُزَ، وَلَئِنْ طَالَتْ بِكُمْ حَيَاةٌ لَتَرَوُنَّ مَا قَالَ النَّبِيُّ أَبُو الْقَاسِمِ صلى الله عليه وسلم ‏"‏ يُخْرِجُ مِلْءَ كَفِّهِ ‏"‏‏.‏\hadithno{3595}\hadithtrans{Narrated `Adi bin Hatim:While I was in the city of the Prophet, a man came and complained to him (the Prophet, ) of destitution and poverty. Then another man came and complained of robbery (by highwaymen). The Prophet said, "Adi! Have you been to Al-Hira?" I said, "I haven't been to it, but I was informed about it." He said, "If you should live for a long time, you will certainly see that a lady in a Howdah traveling from Al-Hira will (safely reach Mecca and) perform the Tawaf of the Ka`ba, fearing none but Allah." I said to myself, "What will happen to the robbers of the tribe of Tai who have spread evil throughout the country?" The Prophet (ﷺ) further said, "If you should live long, the treasures of Khosrau will be opened (and taken as spoils)." I asked, "You mean Khosrau, son of Hurmuz?" He said, "Khosrau, son of Hurmuz. And if you should live long, you will see that one will carry a handful of gold or silver and go out looking for a person to accept it from him, but will find none to accept it from him. And any of you, when meeting Allah, will meet Him without needing an interpreter between him and Allah to interpret for him, and Allah will say to him: 'Didn't I send a messenger to teach you?' He will say: 'Yes.' Allah will say: 'Didn't I give you wealth and do you favors?' He will say: 'Yes.' Then he will look to his right and see nothing but Hell, and look to his left and see nothing but Hell." `Adi further said: I heard the Prophet (ﷺ) saying, "Save yourself from the (Hell) Fire even with half a date (to be given in charity) and if you do not find a half date, then with a good pleasant word." `Adi added: (later on) I saw a lady in a Howdah traveling from Al-Hira till she performed the Tawaf of the Ka`ba, fearing none but Allah. And I was one of those who opened (conquered) the treasures of Khosrau, son of Hurmuz. If you should live long, you will see what the Prophet (ﷺ) Abu-l-Qasim had said: 'A person will come out with a handful of gold...etc}}
\hadithdefcmd{bukhari}{3595p2}{حَدَّثَنِي عَبْدُ اللَّهِ، حَدَّثَنَا أَبُو عَاصِمٍ، أَخْبَرَنَا سَعْدَانُ بْنُ بِشْرٍ، حَدَّثَنَا أَبُو مُجَاهِدٍ، حَدَّثَنَا مُحِلُّ بْنُ خَلِيفَةَ، سَمِعْتُ عَدِيًّا، كُنْتُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{3595.2}\hadithtrans{Narrated `Adi:as above (i.e. Hadith No)}}
\hadithdefcmd{bukhari}{3596}{حَدَّثَنِي سَعِيدُ بْنُ شُرَحْبِيلَ، حَدَّثَنَا لَيْثٌ، عَنْ يَزِيدَ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ يَوْمًا فَصَلَّى عَلَى أَهْلِ أُحُدٍ صَلاَتَهُ عَلَى الْمَيِّتِ، ثُمَّ انْصَرَفَ إِلَى الْمِنْبَرِ، فَقَالَ ‏ "‏ إِنِّي فَرَطُكُمْ، وَأَنَا شَهِيدٌ عَلَيْكُمْ، إِنِّي وَاللَّهِ لأَنْظُرُ إِلَى حَوْضِي الآنَ، وَإِنِّي قَدْ أُعْطِيتُ خَزَائِنَ مَفَاتِيحِ الأَرْضِ، وَإِنِّي وَاللَّهِ مَا أَخَافُ بَعْدِي أَنْ تُشْرِكُوا، وَلَكِنْ أَخَافُ أَنْ تَنَافَسُوا فِيهَا ‏"‏‏.‏\hadithno{3596}\hadithtrans{Narrated `Uqba bin `Amr:The Prophet (ﷺ) once came out and offered the funeral prayer for the martyrs of Uhud, and proceeded to the pulpit and said, "I shall be your predecessor and a witness on you, and I am really looking at my sacred Fount now, and no doubt, I have been given the keys of the treasures of the world. By Allah, I am not afraid that you will worship others along with Allah, but I am afraid that you will envy and fight one another for worldly fortunes}}
\hadithdefcmd{bukhari}{3597}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ أُسَامَةَ ـ رضى الله عنه ـ قَالَ أَشْرَفَ النَّبِيُّ صلى الله عليه وسلم عَلَى أُطُمٍ مِنَ الآطَامِ، فَقَالَ ‏ "‏ هَلْ تَرَوْنَ مَا أَرَى إِنِّي أَرَى الْفِتَنَ تَقَعُ خِلاَلَ بُيُوتِكُمْ مَوَاقِعَ الْقَطْرِ ‏"‏‏.‏\hadithno{3597}\hadithtrans{Narrated Usama:Once the Prophet (ﷺ) stood on one of the high buildings (of Medina) and said, "Do you see what I see? I see affliction pouring among your houses like raindrops}}
\hadithdefcmd{bukhari}{3598}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ زَيْنَبَ ابْنَةَ أَبِي سَلَمَةَ، حَدَّثَتْهُ أَنَّ أُمَّ حَبِيبَةَ بِنْتَ أَبِي سُفْيَانَ حَدَّثَتْهَا عَنْ زَيْنَبَ بِنْتِ جَحْشٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَيْهَا فَزِعًا يَقُولُ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ، وَيْلٌ لِلْعَرَبِ مِنْ شَرٍّ قَدِ اقْتَرَبَ، فُتِحَ الْيَوْمَ مِنْ رَدْمِ يَأْجُوجَ وَمَأْجُوجَ مِثْلُ هَذَا ‏"‏‏.‏ وَحَلَّقَ بِإِصْبَعِهِ وَبِالَّتِي تَلِيهَا، فَقَالَتْ زَيْنَبُ فَقُلْتُ يَا رَسُولَ اللَّهِ أَنَهْلِكُ وَفِينَا الصَّالِحُونَ قَالَ ‏"‏ نَعَمْ، إِذَا كَثُرَ الْخَبَثُ ‏"‏‏.‏\hadithno{3598}\hadithtrans{Narrated Zainab bint Jahsh:That the Prophet (ﷺ) came to her in a state of fear saying, "None has the right to be worshiped but Allah! Woe to the Arabs because of evil that has come near. Today a hole has been made in the wall of Gog and Magog as large as this." pointing with two of his fingers making a circle. Zainab said, "I said, 'O Allah's Messenger (ﷺ)! Shall we be destroyed though amongst us there are pious people? ' He said, 'Yes, if evil increases}}
\hadithdefcmd{bukhari}{3599}{وَعَنِ الزُّهْرِيِّ، حَدَّثَتْنِي هِنْدُ بِنْتُ الْحَارِثِ، أَنَّ أُمَّ سَلَمَةَ، قَالَتِ اسْتَيْقَظَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ سُبْحَانَ اللَّهِ، مَاذَا أُنْزِلَ مِنَ الْخَزَائِنِ وَمَاذَا أُنْزِلَ مِنَ الْفِتَنِ ‏"‏‏.‏\hadithno{3599}\hadithtrans{Um Salama said:The Prophet (ﷺ) woke up and said, "Glorified be Allah: What great (how many) treasures have been sent down, and what great (how many ) afflictions have been sent down}}
\hadithdefcmd{bukhari}{3600}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي سَلَمَةَ بْنِ الْمَاجِشُونِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ قَالَ قَالَ لِي إِنِّي أَرَاكَ تُحِبُّ الْغَنَمَ، وَتَتَّخِذُهَا، فَأَصْلِحْهَا وَأَصْلِحْ رُعَامَهَا، فَإِنِّي سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَأْتِي عَلَى النَّاسِ زَمَانٌ تَكُونُ الْغَنَمُ فِيهِ خَيْرَ مَالِ الْمُسْلِمِ، يَتْبَعُ بِهَا شَعَفَ الْجِبَالِ ـ أَوْ سَعَفَ الْجِبَالِ ـ فِي مَوَاقِعِ الْقَطْرِ، يَفِرُّ بِدِينِهِ مِنَ الْفِتَنِ ‏"‏‏.‏\hadithno{3600}\hadithtrans{Narrated Sasaa:Abu Sa`id Al-Khudri said to me, "I notice that you like sheep and you keep them; so take care of them and their food, for I have heard Allah's Messenger (ﷺ) saying, 'A time will come upon the people when the best of a Muslim's property will be sheep, which he will take to the tops of mountains and to the places of rain-falls to run away with his religion in order to save it from afflictions}}
\hadithdefcmd{bukhari}{3602}{حَدَّثَنَا عَبْدُ الْعَزِيزِ الأُوَيْسِيُّ، حَدَّثَنَا إِبْرَاهِيمُ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ سَتَكُونُ فِتَنٌ، الْقَاعِدُ فِيهَا خَيْرٌ مِنَ الْقَائِمِ، وَالْقَائِمُ فِيهَا خَيْرٌ مِنَ الْمَاشِي، وَالْمَاشِي فِيهَا خَيْرٌ مِنَ السَّاعِي، وَمَنْ يُشْرِفْ لَهَا تَسْتَشْرِفْهُ، وَمَنْ وَجَدَ مَلْجَأً أَوْ مَعَاذًا فَلْيَعُذْ بِهِ ‏"‏‏.‏ وَعَنِ ابْنِ شِهَابٍ، حَدَّثَنِي أَبُو بَكْرِ بْنُ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مُطِيعِ بْنِ الأَسْوَدِ، عَنْ نَوْفَلِ بْنِ مُعَاوِيَةَ،، مِثْلَ حَدِيثِ أَبِي هُرَيْرَةَ هَذَا، إِلاَّ أَنَّ أَبَا بَكْرٍ، يَزِيدُ ‏"‏ مِنَ الصَّلاَةِ صَلاَةٌ مَنْ فَاتَتْهُ فَكَأَنَّمَا وُتِرَ أَهْلَهُ وَمَالَهُ ‏"‏‏.‏\hadithno{3602}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "There will be afflictions (and at the time) the sitting person will be better than the standing one, and the standing one will be better than the walking, and the walking will be better than the running. And whoever will look towards those afflictions, they will overtake him, and whoever will find a refuge or a shelter, should take refuge in it." The same narration is reported by Abu Bakr, with the addition, "(The Prophet (ﷺ) said), 'Among the prayers there is a prayer the missing of which will be to one like losing one's family and property}}
\hadithdefcmd{bukhari}{3603}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنِ ابْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ سَتَكُونُ أَثَرَةٌ وَأُمُورٌ تُنْكِرُونَهَا ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ فَمَا تَأْمُرُنَا قَالَ ‏"‏ تُؤَدُّونَ الْحَقَّ الَّذِي عَلَيْكُمْ، وَتَسْأَلُونَ اللَّهَ الَّذِي لَكُمْ ‏"‏‏.‏\hadithno{3603}\hadithtrans{Narrated Ibn Mas`ud:The Prophet (ﷺ) said, "Soon others will be preferred to you, and there will be things which you will not like." The companions of the Prophet (ﷺ) asked, "O Allah's Messenger (ﷺ)! What do you order us to do (in this case)? " He said, "(I order you) to give the rights that are on you and to ask your rights from Allah}}
\hadithdefcmd{bukhari}{3604}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ، حَدَّثَنَا أَبُو مَعْمَرٍ، إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يُهْلِكُ النَّاسَ هَذَا الْحَىُّ مِنْ قُرَيْشٍ ‏"‏‏.‏ قَالُوا فَمَا تَأْمُرُنَا قَالَ ‏"‏ لَوْ أَنَّ النَّاسَ اعْتَزَلُوهُمْ ‏"‏‏.‏ قَالَ مَحْمُودٌ حَدَّثَنَا أَبُو دَاوُدَ أَخْبَرَنَا شُعْبَةُ عَنْ أَبِي التَّيَّاحِ سَمِعْتُ أَبَا زُرْعَةَ‏.‏\hadithno{3604}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "This branch from Quraish will ruin the people." The companions of the Prophet (ﷺ) asked, "What do you order us to do (then)?" He said, "I would suggest that the people keep away from them}}
\hadithdefcmd{bukhari}{3605}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَكِّيُّ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى بْنِ سَعِيدٍ الأُمَوِيُّ، عَنْ جَدِّهِ، قَالَ كُنْتُ مَعَ مَرْوَانَ وَأَبِي هُرَيْرَةَ فَسَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ سَمِعْتُ الصَّادِقَ الْمَصْدُوقَ، يَقُولُ ‏ "‏ هَلاَكُ أُمَّتِي عَلَى يَدَىْ غِلْمَةٍ مِنْ قُرَيْشٍ ‏"‏‏.‏ فَقَالَ مَرْوَانُ غِلْمَةٌ‏.‏ قَالَ أَبُو هُرَيْرَةَ إِنْ شِئْتَ أَنْ أُسَمِّيَهُمْ بَنِي فُلاَنٍ وَبَنِي فُلاَنٍ‏.‏\hadithno{3605}\hadithtrans{Narrated Sa`id Al-Umawi:I was with Marwan and Abu Huraira and heard Abu Huraira saying, "I heard the trustworthy, truly inspired one (i.e. the Prophet (ﷺ) ) saying, 'The destruction of my followers will be brought about by the hands of some youngsters from Quraish." Marwan asked, "Youngsters?" Abu Huraira said, "If you wish, I would name them: They are the children of so-and-so and the children of so-and-so}}
\hadithdefcmd{bukhari}{3606}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنِي ابْنُ جَابِرٍ، قَالَ حَدَّثَنِي بُسْرُ بْنُ عُبَيْدِ اللَّهِ الْحَضْرَمِيُّ، قَالَ حَدَّثَنِي أَبُو إِدْرِيسَ الْخَوْلاَنِيُّ، أَنَّهُ سَمِعَ حُذَيْفَةَ بْنَ الْيَمَانِ، يَقُولُ كَانَ النَّاسُ يَسْأَلُونَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْخَيْرِ، وَكُنْتُ أَسْأَلُهُ عَنِ الشَّرِّ مَخَافَةَ أَنْ يُدْرِكَنِي‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّا كُنَّا فِي جَاهِلِيَّةٍ وَشَرٍّ، فَجَاءَنَا اللَّهُ بِهَذَا الْخَيْرِ، فَهَلْ بَعْدَ هَذَا الْخَيْرِ مِنْ شَرٍّ قَالَ ‏"‏ نَعَمْ ‏"‏‏.‏ قُلْتُ وَهَلْ بَعْدَ ذَلِكَ الشَّرِّ مِنْ خَيْرٍ قَالَ ‏"‏ نَعَمْ، وَفِيهِ دَخَنٌ ‏"‏‏.‏ قُلْتُ وَمَا دَخَنُهُ قَالَ ‏"‏ قَوْمٌ يَهْدُونَ بِغَيْرِ هَدْيِي تَعْرِفُ مِنْهُمْ وَتُنْكِرُ ‏"‏‏.‏ قُلْتُ فَهَلْ بَعْدَ ذَلِكَ الْخَيْرِ مِنْ شَرٍّ قَالَ ‏"‏ نَعَمْ دُعَاةٌ إِلَى أَبْوَابِ جَهَنَّمَ، مَنْ أَجَابَهُمْ إِلَيْهَا قَذَفُوهُ فِيهَا ‏"‏‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ صِفْهُمْ لَنَا فَقَالَ ‏"‏ هُمْ مِنْ جِلْدَتِنَا، وَيَتَكَلَّمُونَ بِأَلْسِنَتِنَا ‏"‏ قُلْتُ فَمَا تَأْمُرُنِي إِنْ أَدْرَكَنِي ذَلِكَ قَالَ ‏"‏ تَلْزَمُ جَمَاعَةَ الْمُسْلِمِينَ وَإِمَامَهُمْ ‏"‏‏.‏ قُلْتُ فَإِنْ لَمْ يَكُنْ لَهُمْ جَمَاعَةٌ وَلاَ إِمَامٌ قَالَ ‏"‏ فَاعْتَزِلْ تِلْكَ الْفِرَقَ كُلَّهَا، وَلَوْ أَنْ تَعَضَّ بِأَصْلِ شَجَرَةٍ حَتَّى يُدْرِكَكَ الْمَوْتُ وَأَنْتَ عَلَى ذَلِكَ ‏"‏‏.‏\hadithno{3606}\hadithtrans{Narrated Hudhaifa bin Al-Yaman:The people used to ask Allah's Messenger (ﷺ) about good, but I used to ask him about evil for fear that it might overtake me. Once I said, "O Allah's Messenger (ﷺ)! We were in ignorance and in evil and Allah has bestowed upon us the present good; will there be any evil after this good?" He said, "Yes." I asked, "Will there be good after that evil?" He said, "Yes, but it would be tained with Dakhan (i.e. Little evil)." I asked, "What will its Dakhan be?" He said, "There will be some people who will lead (people) according to principles other than my tradition. You will see their actions and disapprove of them." I said, "Will there be any evil after that good?" He said, "Yes, there will be some people who will invite others to the doors of Hell, and whoever accepts their invitation to it will be thrown in it (by them)." I said, "O Allah's Messenger (ﷺ)! Describe those people to us." He said, "They will belong to us and speak our language" I asked, "What do you order me to do if such a thing should take place in my life?" He said, "Adhere to the group of Muslims and their Chief." I asked, "If there is neither a group (of Muslims) nor a chief (what shall I do)?" He said, "Keep away from all those different sects, even if you had to bite (i.e. eat) the root of a tree, till you meet Allah while you are still in that state}}
\hadithdefcmd{bukhari}{3607}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنِي يَحْيَى بْنُ سَعِيدٍ، عَنْ إِسْمَاعِيلَ، حَدَّثَنِي قَيْسٌ، عَنْ حُذَيْفَةَ ـ رضى الله عنه ـ قَالَ تَعَلَّمَ أَصْحَابِي الْخَيْرَ وَتَعَلَّمْتُ الشَّرَّ‏.‏\hadithno{3607}\hadithtrans{Narrated Hudhaifa:My companions learned (something about) good (through asking the Prophet) while I learned (something about) evil}}
\hadithdefcmd{bukhari}{3608}{حَدَّثَنَا الْحَكَمُ بْنُ نَافِعٍ، حَدَّثَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَقْتَتِلَ فِئَتَانِ دَعْوَاهُمَا وَاحِدَةٌ ‏"‏‏.‏\hadithno{3608}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Day of (Judgment) will not be established till there is a war between two groups whose claims (or religion) will be the same}}
\hadithdefcmd{bukhari}{3609}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ هَمَّامٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى يَقْتَتِلَ فِئَتَانِ، فَيَكُونَ بَيْنَهُمَا مَقْتَلَةٌ عَظِيمَةٌ، دَعْوَاهُمَا وَاحِدَةٌ، وَلاَ تَقُومُ السَّاعَةُ حَتَّى يُبْعَثَ دَجَّالُونَ كَذَّابُونَ قَرِيبًا مِنْ ثَلاَثِينَ، كُلُّهُمْ يَزْعُمُ أَنَّهُ رَسُولُ اللَّهِ ‏"‏‏.‏\hadithno{3609}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The Hour will not be established till there is a war between two groups among whom there will be a great number of casualties, though the claims (or religion) of both of them will be one and the same. And the Hour will not be established till there appear about thirty liars, all of whom will be claiming to be the messengers of Allah}}
\hadithdefcmd{bukhari}{3610}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ قَالَ بَيْنَمَا نَحْنُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهْوَ يَقْسِمُ قَسْمًا أَتَاهُ ذُو الْخُوَيْصِرَةِ ـ وَهْوَ رَجُلٌ مِنْ بَنِي تَمِيمٍ ـ فَقَالَ يَا رَسُولَ اللَّهِ اعْدِلْ‏.‏ فَقَالَ ‏"‏ وَيْلَكَ، وَمَنْ يَعْدِلُ إِذَا لَمْ أَعْدِلْ قَدْ خِبْتَ وَخَسِرْتَ إِنْ لَمْ أَكُنْ أَعْدِلُ ‏"‏‏.‏ فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ ائْذَنْ لِي فِيهِ، فَأَضْرِبَ عُنُقَهُ‏.‏ فَقَالَ ‏"‏ دَعْهُ فَإِنَّ لَهُ أَصْحَابًا، يَحْقِرُ أَحَدُكُمْ صَلاَتَهُ مَعَ صَلاَتِهِمْ وَصِيَامَهُ مَعَ صِيَامِهِمْ، يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ تَرَاقِيَهُمْ، يَمْرُقُونَ مِنَ الدِّينِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ، يُنْظَرُ إِلَى نَصْلِهِ فَلاَ يُوجَدُ فِيهِ شَىْءٌ، ثُمَّ يُنْظَرُ إِلَى رِصَافِهِ فَمَا يُوجَدُ فِيهِ شَىْءٌ، ثُمَّ يُنْظَرُ إِلَى نَضِيِّهِ ـ وَهْوَ قِدْحُهُ ـ فَلاَ يُوجَدُ فِيهِ شَىْءٌ، ثُمَّ يُنْظَرُ إِلَى قُذَذِهِ فَلاَ يُوجَدُ فِيهِ شَىْءٌ، قَدْ سَبَقَ الْفَرْثَ وَالدَّمَ، آيَتُهُمْ رَجُلٌ أَسْوَدُ إِحْدَى عَضُدَيْهِ مِثْلُ ثَدْىِ الْمَرْأَةِ، أَوْ مِثْلُ الْبَضْعَةِ تَدَرْدَرُ وَيَخْرُجُونَ عَلَى حِينِ فُرْقَةٍ مِنَ النَّاسِ ‏"‏‏.‏ قَالَ أَبُو سَعِيدٍ فَأَشْهَدُ أَنِّي سَمِعْتُ هَذَا الْحَدِيثَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم، وَأَشْهَدُ أَنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ قَاتَلَهُمْ وَأَنَا مَعَهُ، فَأَمَرَ بِذَلِكَ الرَّجُلِ، فَالْتُمِسَ فَأُتِيَ بِهِ حَتَّى نَظَرْتُ إِلَيْهِ عَلَى نَعْتِ النَّبِيِّ صلى الله عليه وسلم الَّذِي نَعَتَهُ‏.‏\hadithno{3610}\hadithtrans{Narrated Abu Sa`id Al-Khudri:While we were with Allah's Messenger (ﷺ) who was distributing (i.e. some property), there came Dhu-l- Khuwaisira, a man from the tribe of Bani Tamim and said, "O Allah's Messenger (ﷺ)! Do Justice." The Prophet said, "Woe to you! Who could do justice if I did not? I would be a desperate loser if I did not do justice." `Umar said, "O Allah's Messenger (ﷺ)! Allow me to chop his head off." The Prophet (ﷺ) said, "Leave him, for he has companions who pray and fast in such a way that you will consider your fasting negligible in comparison to theirs. They recite Qur'an but it does not go beyond their throats (i.e. they do not act on it) and they will desert Islam as an arrow goes through a victim's body, so that the hunter, on looking at the arrow's blade, would see nothing on it; he would look at its Risaf and see nothing: he would look at its Nadi and see nothing, and he would look at its Qudhadh ( 1 ) and see nothing (neither meat nor blood), for the arrow has been too fast even for the blood and excretions to smear. The sign by which they will be recognized is that among them there will be a black man, one of whose arms will resemble a woman's breast or a lump of meat moving loosely. Those people will appear when there will be differences amongst the people." I testify that I heard this narration from Allah's Messenger (ﷺ) and I testify that `Ali bin Abi Talib fought with such people, and I was in his company. He ordered that the man (described by the Prophet (ﷺ) ) should be looked for. The man was brought and I looked at him and noticed that he looked exactly as the Prophet (ﷺ) had described him}}
\hadithdefcmd{bukhari}{3611}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ خَيْثَمَةَ، عَنْ سُوَيْدِ بْنِ غَفَلَةَ، قَالَ قَالَ عَلِيٌّ ـ رضى الله عنه ـ إِذَا حَدَّثْتُكُمْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلأَنْ أَخِرَّ مِنَ السَّمَاءِ أَحَبُّ إِلَىَّ مِنْ أَنْ أَكْذِبَ عَلَيْهِ، وَإِذَا حَدَّثْتُكُمْ فِيمَا بَيْنِي وَبَيْنَكُمْ، فَإِنَّ الْحَرْبَ خَدْعَةٌ، سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَأْتِي فِي آخِرِ الزَّمَانِ قَوْمٌ حُدَثَاءُ الأَسْنَانِ، سُفَهَاءُ الأَحْلاَمِ، يَقُولُونَ مِنْ خَيْرِ قَوْلِ الْبَرِيَّةِ، يَمْرُقُونَ مِنَ الإِسْلاَمِ كَمَا يَمْرُقُ السَّهْمُ مِنَ الرَّمِيَّةِ، لاَ يُجَاوِزُ إِيمَانُهُمْ حَنَاجِرَهُمْ، فَأَيْنَمَا لَقِيتُمُوهُمْ فَاقْتُلُوهُمْ، فَإِنَّ قَتْلَهُمْ أَجْرٌ لِمَنْ قَتَلَهُمْ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏\hadithno{3611}\hadithtrans{Narrated `Ali:I relate the traditions of Allah's Messenger (ﷺ) to you for I would rather fall from the sky than attribute something to him falsely. But when I tell you a thing which is between you and me, then no doubt, war is guile. I heard Allah's Messenger (ﷺ) saying, "In the last days of this world there will appear some young foolish people who will use (in their claim) the best speech of all people (i.e. the Qur'an) and they will abandon Islam as an arrow going through the game. Their belief will not go beyond their throats (i.e. they will have practically no belief), so wherever you meet them, kill them, for he who kills them shall get a reward on the Day of Resurrection}}
\hadithdefcmd{bukhari}{3612}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، حَدَّثَنَا قَيْسٌ، عَنْ خَبَّابِ بْنِ الأَرَتِّ، قَالَ شَكَوْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهْوَ مُتَوَسِّدٌ بُرْدَةً لَهُ فِي ظِلِّ الْكَعْبَةِ، قُلْنَا لَهُ أَلاَ تَسْتَنْصِرُ لَنَا أَلاَ تَدْعُو اللَّهَ لَنَا قَالَ ‏ "‏ كَانَ الرَّجُلُ فِيمَنْ قَبْلَكُمْ يُحْفَرُ لَهُ فِي الأَرْضِ فَيُجْعَلُ فِيهِ، فَيُجَاءُ بِالْمِنْشَارِ، فَيُوضَعُ عَلَى رَأْسِهِ فَيُشَقُّ بِاثْنَتَيْنِ، وَمَا يَصُدُّهُ ذَلِكَ عَنْ دِينِهِ، وَيُمْشَطُ بِأَمْشَاطِ الْحَدِيدِ، مَا دُونَ لَحْمِهِ مِنْ عَظْمٍ أَوْ عَصَبٍ، وَمَا يَصُدُّهُ ذَلِكَ عَنْ دِينِهِ، وَاللَّهِ لَيُتِمَّنَّ هَذَا الأَمْرَ حَتَّى يَسِيرَ الرَّاكِبُ مِنْ صَنْعَاءَ إِلَى حَضْرَمَوْتَ، لاَ يَخَافُ إِلاَّ اللَّهَ أَوِ الذِّئْبَ عَلَى غَنَمِهِ، وَلَكِنَّكُمْ تَسْتَعْجِلُونَ ‏"‏‏.‏\hadithno{3612}\hadithtrans{Narrated Khabbab bin Al-Arat:We complained to Allah's Messenger (ﷺ) (of the persecution inflicted on us by the infidels) while he was sitting in the shade of the Ka`ba, leaning over his Burd (i.e. covering sheet). We said to him, "Would you seek help for us? Would you pray to Allah for us?" He said, "Among the nations before you a (believing) man would be put in a ditch that was dug for him, and a saw would be put over his head and he would be cut into two pieces; yet that (torture) would not make him give up his religion. His body would be combed with iron combs that would remove his flesh from the bones and nerves, yet that would not make him abandon his religion. By Allah, this religion (i.e. Islam) will prevail till a traveler from Sana (in Yemen) to Hadrarmaut will fear none but Allah, or a wolf as regards his sheep, but you (people) are hasty}}
\hadithdefcmd{bukhari}{3613}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَزْهَرُ بْنُ سَعْدٍ، حَدَّثَنَا ابْنُ عَوْنٍ، قَالَ أَنْبَأَنِي مُوسَى بْنُ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم افْتَقَدَ ثَابِتَ بْنَ قَيْسٍ، فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ، أَنَا أَعْلَمُ لَكَ عِلْمَهُ‏.‏ فَأَتَاهُ فَوَجَدَهُ جَالِسًا فِي بَيْتِهِ مُنَكِّسًا رَأْسَهُ، فَقَالَ مَا شَأْنُكَ فَقَالَ شَرٌّ، كَانَ يَرْفَعُ صَوْتَهُ فَوْقَ صَوْتِ النَّبِيِّ صلى الله عليه وسلم فَقَدْ حَبِطَ عَمَلُهُ، وَهْوَ مِنْ أَهْلِ النَّارِ‏.‏ فَأَتَى الرَّجُلُ فَأَخْبَرَهُ أَنَّهُ قَالَ كَذَا وَكَذَا‏.‏ فَقَالَ مُوسَى بْنُ أَنَسٍ فَرَجَعَ الْمَرَّةَ الآخِرَةَ بِبِشَارَةٍ عَظِيمَةٍ، فَقَالَ ‏ "‏ اذْهَبْ إِلَيْهِ فَقُلْ لَهُ إِنَّكَ لَسْتَ مِنْ أَهْلِ النَّارِ، وَلَكِنْ مِنْ أَهْلِ الْجَنَّةِ ‏"‏‏.‏\hadithno{3613}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) noticed the absence of Thabit bin Qais. A man said, "O Allah's Messenger (ﷺ)! I shall bring you his news." So he went to him and saw him sitting in his house drooping his head (sadly). He asked Thabit, "What's the matter?" Thabit replied, "An evil situation: A man used to raise his voice over the voice of the Prophet (ﷺ) and so all his good deeds have been annulled and he is from the people of Hell." The man went back and told the Prophet (ﷺ) that Thabit had said so-and-so. (The sub-narrator, Musa bin Anas said, "The man went to Thabit again with glad tidings)." The Prophet (ﷺ) said to him, "Go and say to Thabit: 'You are not from the people of Fire, but from the people of Paradise}}
\hadithdefcmd{bukhari}{3614}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ ـ رضى الله عنهما ـ قَرَأَ رَجُلٌ الْكَهْفَ وَفِي الدَّارِ الدَّابَّةُ فَجَعَلَتْ تَنْفِرُ فَسَلَّمَ، فَإِذَا ضَبَابَةٌ ـ أَوْ سَحَابَةٌ ـ غَشِيَتْهُ، فَذَكَرَهُ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ اقْرَأْ فُلاَنُ، فَإِنَّهَا السَّكِينَةُ نَزَلَتْ لِلْقُرْآنِ، أَوْ تَنَزَّلَتْ لِلْقُرْآنِ ‏"‏‏.‏\hadithno{3614}\hadithtrans{Narrated Al-Bara' bin `Azib:A man recited Surat-al-Kahf (in his prayer) and in the house there was a (riding) animal which got frightened and started jumping. The man finished his prayer with Taslim, but behold! A mist or a cloud hovered over him. He informed the Prophet (ﷺ) of that and the Prophet (ﷺ) said, "O so-and-so! Recite, for this (mist or cloud) was a sign of peace descending for the recitation of Qur'an}}
\hadithdefcmd{bukhari}{3615}{حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ، حَدَّثَنَا أَحْمَدُ بْنُ يَزِيدَ بْنِ إِبْرَاهِيمَ أَبُو الْحَسَنِ الْحَرَّانِيُّ، حَدَّثَنَا زُهَيْرُ بْنُ مُعَاوِيَةَ، حَدَّثَنَا أَبُو إِسْحَاقَ، سَمِعْتُ الْبَرَاءَ بْنَ عَازِبٍ، يَقُولُ جَاءَ أَبُو بَكْرٍ ـ رضى الله عنه ـ إِلَى أَبِي فِي مَنْزِلِهِ، فَاشْتَرَى مِنْهُ رَحْلاً فَقَالَ لِعَازِبٍ ابْعَثِ ابْنَكَ يَحْمِلْهُ مَعِي‏.‏ قَالَ فَحَمَلْتُهُ مَعَهُ، وَخَرَجَ أَبِي يَنْتَقِدُ ثَمَنَهُ، فَقَالَ لَهُ أَبِي يَا أَبَا بَكْرٍ حَدِّثْنِي كَيْفَ صَنَعْتُمَا حِينَ سَرَيْتَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ نَعَمْ أَسْرَيْنَا لَيْلَتَنَا، وَمِنَ الْغَدِ حَتَّى قَامَ قَائِمُ الظَّهِيرَةِ، وَخَلاَ الطَّرِيقُ لاَ يَمُرُّ فِيهِ أَحَدٌ، فَرُفِعَتْ لَنَا صَخْرَةٌ طَوِيلَةٌ، لَهَا ظِلٌّ لَمْ تَأْتِ عَلَيْهِ الشَّمْسُ فَنَزَلْنَا عِنْدَهُ، وَسَوَّيْتُ لِلنَّبِيِّ صلى الله عليه وسلم مَكَانًا بِيَدِي يَنَامُ عَلَيْهِ، وَبَسَطْتُ فِيهِ فَرْوَةً، وَقُلْتُ نَمْ يَا رَسُولَ اللَّهِ، وَأَنَا أَنْفُضُ لَكَ مَا حَوْلَكَ‏.‏ فَنَامَ وَخَرَجْتُ أَنْفُضُ مَا حَوْلَهُ، فَإِذَا أَنَا بِرَاعٍ مُقْبِلٍ بِغَنَمِهِ إِلَى الصَّخْرَةِ يُرِيدُ مِنْهَا مِثْلَ الَّذِي أَرَدْنَا فَقُلْتُ لِمَنْ أَنْتَ يَا غُلاَمُ فَقَالَ لِرَجُلٍ مِنْ أَهْلِ الْمَدِينَةِ أَوْ مَكَّةَ‏.‏ قُلْتُ أَفِي غَنَمِكَ لَبَنٌ قَالَ نَعَمُ‏.‏ قُلْتُ أَفَتَحْلُبُ قَالَ نَعَمْ‏.‏ فَأَخَذَ شَاةً‏.‏ فَقُلْتُ انْفُضِ الضَّرْعَ مِنَ التُّرَابِ وَالشَّعَرِ وَالْقَذَى‏.‏ قَالَ فَرَأَيْتُ الْبَرَاءَ يَضْرِبُ إِحْدَى يَدَيْهِ عَلَى الأُخْرَى يَنْفُضُ، فَحَلَبَ فِي قَعْبٍ كُثْبَةً مِنْ لَبَنٍ، وَمَعِي إِدَاوَةٌ حَمَلْتُهَا لِلنَّبِيِّ صلى الله عليه وسلم يَرْتَوِي مِنْهَا، يَشْرَبُ وَيَتَوَضَّأُ، فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَكَرِهْتُ أَنْ أُوقِظَهُ، فَوَافَقْتُهُ حِينَ اسْتَيْقَظَ، فَصَبَبْتُ مِنَ الْمَاءِ عَلَى اللَّبَنِ حَتَّى بَرَدَ أَسْفَلُهُ، فَقُلْتُ اشْرَبْ يَا رَسُولَ اللَّهِ ـ قَالَ ـ فَشَرِبَ، حَتَّى رَضِيتُ ثُمَّ قَالَ ‏"‏ أَلَمْ يَأْنِ لِلرَّحِيلِ ‏"‏‏.‏ قُلْتُ بَلَى ـ قَالَ ـ فَارْتَحَلْنَا بَعْدَ مَا مَالَتِ الشَّمْشُ، وَاتَّبَعَنَا سُرَاقَةُ بْنُ مَالِكٍ، فَقُلْتُ أُتِينَا يَا رَسُولَ اللَّهِ‏.‏ فَقَالَ ‏"‏ لاَ تَحْزَنْ، إِنَّ اللَّهَ مَعَنَا ‏"‏‏.‏ فَدَعَا عَلَيْهِ النَّبِيُّ صلى الله عليه وسلم فَارْتَطَمَتْ بِهِ فَرَسُهُ إِلَى بَطْنِهَا ـ أُرَى فِي جَلَدٍ مِنَ الأَرْضِ، شَكَّ زُهَيْرٌ ـ فَقَالَ إِنِّي أُرَاكُمَا قَدْ دَعَوْتُمَا عَلَىَّ فَادْعُوَا لِي، فَاللَّهُ لَكُمَا أَنْ أَرُدَّ عَنْكُمَا الطَّلَبَ‏.‏ فَدَعَا لَهُ النَّبِيُّ صلى الله عليه وسلم فَنَجَا فَجَعَلَ لاَ يَلْقَى أَحَدًا إِلاَّ قَالَ كَفَيْتُكُمْ مَا هُنَا‏.‏ فَلاَ يَلْقَى أَحَدًا إِلاَّ رَدَّهُ‏.‏ قَالَ وَوَفَى لَنَا‏.‏\hadithno{3615}\hadithtrans{Narrated Al-Bara' bin `Azib:Abu Bakr came to my father who was at home and purchased a saddle from him. He said to `Azib, "Tell your son to carry it with me." So I carried it with him and my father followed us so as to take the price (of the saddle). My father said, "O Abu Bakr! Tell me what happened to you on your night journey with Allah's Messenger (ﷺ) (during Migration)." He said, "Yes, we travelled the whole night and also the next day till midday. when nobody could be seen on the way ( because of the severe heat) . Then there appeared a long rock having shade beneath it, and the sunshine had not come to it yet. So we dismounted there and I levelled a place and covered it with an animal hide or dry grass for the Prophet (ﷺ) to sleep on (for a while). I then said, 'Sleep, O Allah's Messenger (ﷺ), and I will guard you.' So he slept and I went out to guard him. Suddenly I saw a shepherd coming with his sheep to that rock with the same intention we had when we came to it. I asked (him), 'To whom do you belong, O boy?' He replied, 'I belong to a man from Medina or Mecca.' I said, 'Do your sheep have milk?' He said, 'Yes.' I said, 'Will you milk for us?' He said, 'Yes.' He caught hold of a sheep and I asked him to clean its teat from dust, hairs and dirt. (The sub-narrator said that he saw Al-Bara' striking one of his hands with the other, demonstrating how the shepherd removed the dust.) The shepherd milked a little milk in a wooden container and I had a leather container which I carried for the Prophet (ﷺ) to drink and perform the ablution from. I went to the Prophet, hating to wake him up, but when I reached there, the Prophet (ﷺ) had already awakened; so I poured water over the middle part of the milk container, till the milk was cold. Then I said, 'Drink, O Allah's Messenger (ﷺ)!' He drank till I was pleased. Then he asked, 'Has the time for our departure come?' I said, 'Yes.' So we departed after midday. Suraqa bin Malik followed us and I said, 'We have been discovered, O Allah's Messenger (ﷺ)!' He said, Don't grieve for Allah is with us.' The Prophet (ﷺ) invoked evil on him (i.e. Suraqa) and so the legs of his horse sank into the earth up to its belly. (The subnarrator, Zuhair is not sure whether Abu Bakr said, "(It sank) into solid earth.") Suraqa said, 'I see that you have invoked evil on me. Please invoke good on me, and by Allah, I will cause those who are seeking after you to return.' The Prophet (ﷺ) invoked good on him and he was saved. Then, whenever he met somebody on the way, he would say, 'I have looked for him here in vain.' So he caused whomever he met to return. Thus Suraqa fulfilled his promise}}
\hadithdefcmd{bukhari}{3616}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُخْتَارٍ، حَدَّثَنَا خَالِدٌ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَى أَعْرَابِيٍّ ـ يَعُودُهُ ـ قَالَ وَكَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا دَخَلَ عَلَى مَرِيضٍ يَعُودُهُ قَالَ لاَ بَأْسَ طَهُورٌ إِنْ شَاءَ اللَّهُ‏.‏ فَقَالَ لَهُ ‏"‏ لاَ بَأْسَ طَهُورٌ إِنْ شَاءَ اللَّهُ ‏"‏‏.‏ قَالَ قُلْتَ طَهُورٌ كَلاَّ بَلْ هِيَ حُمَّى تَفُورُ ـ أَوْ تَثُورُ ـ عَلَى شَيْخٍ كَبِيرٍ، تُزِيرُهُ الْقُبُورَ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَنَعَمْ إِذًا ‏"‏‏.‏\hadithno{3616}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) paid a visit to a sick bedouin. The Prophet (ﷺ) when visiting a patient used to say, "No harm will befall you! May Allah cure you! May Allah cure you!" So the Prophet (ﷺ) said to the bedouin. "No harm will befall you. May Allah cure you!" The bedouin said, "You say, may Allah cure me? No, for it is a fever which boils in (the body of) an old man, and will lead him to the grave." The Prophet (ﷺ) said, "Yes, then may it be as you say}}
\hadithdefcmd{bukhari}{3617}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ كَانَ رَجُلٌ نَصْرَانِيًّا فَأَسْلَمَ وَقَرَأَ الْبَقَرَةَ وَآلَ عِمْرَانَ، فَكَانَ يَكْتُبُ لِلنَّبِيِّ صلى الله عليه وسلم، فَعَادَ نَصْرَانِيًّا فَكَانَ يَقُولُ مَا يَدْرِي مُحَمَّدٌ إِلاَّ مَا كَتَبْتُ لَهُ، فَأَمَاتَهُ اللَّهُ فَدَفَنُوهُ، فَأَصْبَحَ وَقَدْ لَفَظَتْهُ الأَرْضُ فَقَالُوا هَذَا فِعْلُ مُحَمَّدٍ وَأَصْحَابِهِ، لَمَّا هَرَبَ مِنْهُمْ نَبَشُوا عَنْ صَاحِبِنَا‏.‏ فَأَلْقُوهُ فَحَفَرُوا لَهُ فَأَعْمَقُوا، فَأَصْبَحَ وَقَدْ لَفَظَتْهُ الأَرْضُ، فَقَالُوا هَذَا فِعْلُ مُحَمَّدٍ وَأَصْحَابِهِ نَبَشُوا عَنْ صَاحِبِنَا لَمَّا هَرَبَ مِنْهُمْ‏.‏ فَأَلْقَوْهُ فَحَفَرُوا لَهُ، وَأَعْمَقُوا لَهُ فِي الأَرْضِ مَا اسْتَطَاعُوا، فَأَصْبَحَ قَدْ لَفَظَتْهُ الأَرْضُ، فَعَلِمُوا أَنَّهُ لَيْسَ مِنَ النَّاسِ فَأَلْقَوْهُ‏.‏\hadithno{3617}\hadithtrans{Narrated Anas:There was a Christian who embraced Islam and read Surat-al-Baqara and Al-`Imran, and he used to write (the revelations) for the Prophet. Later on he returned to Christianity again and he used to say: "Muhammad knows nothing but what I have written for him." Then Allah caused him to die, and the people buried him, but in the morning they saw that the earth had thrown his body out. They said, "This is the act of Muhammad and his companions. They dug the grave of our companion and took his body out of it because he had run away from them." They again dug the grave deeply for him, but in the morning they again saw that the earth had thrown his body out. They said, "This is an act of Muhammad and his companions. They dug the grave of our companion and threw his body outside it, for he had run away from them." They dug the grave for him as deep as they could, but in the morning they again saw that the earth had thrown his body out. So they believed that what had befallen him was not done by human beings and had to leave him thrown (on the ground)}}
\hadithdefcmd{bukhari}{3618}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ وَأَخْبَرَنِي ابْنُ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا هَلَكَ كِسْرَى فَلاَ كِسْرَى بَعْدَهُ، وَإِذَا هَلَكَ قَيْصَرُ فَلاَ قَيْصَرَ بَعْدَهُ، وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَتُنْفِقُنَّ كُنُوزَهُمَا فِي سَبِيلِ اللَّهِ ‏"‏‏.‏\hadithno{3618}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When Khosrau perishes, there will be no (more) Khosrau after him, and when Caesar perishes, there will be no more Caesar after him. By Him in Whose Hands Muhammad's life is, you will spend the treasures of both of them in Allah's Cause}}
\hadithdefcmd{bukhari}{3619}{حَدَّثَنَا قَبِيصَةُ، حَدَّثَنَا سُفْيَانُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، رَفَعَهُ قَالَ ‏ "‏ إِذَا هَلَكَ كِسْرَى فَلاَ كِسْرَى بَعْدَهُ ـ وَذَكَرَ وَقَالَ ـ لَتُنْفَقَنَّ كُنُوزُهُمَا فِي سَبِيلِ اللَّهِ ‏"‏‏.‏\hadithno{3619}\hadithtrans{Narrated Jabir bin Samura:The Prophet (ﷺ) said, "When Khosrau perishes, there will be no more Khosrau after him, and when Caesar perishes, there will be no more Caesar after him." The Prophet (ﷺ) also said, "You will spend the treasures of both of them in Allah's Cause}}
\hadithdefcmd{bukhari}{3621}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي حُسَيْنٍ، حَدَّثَنَا نَافِعُ بْنُ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَدِمَ مُسَيْلِمَةُ الْكَذَّابُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَجَعَلَ يَقُولُ إِنْ جَعَلَ لِي مُحَمَّدٌ الأَمْرَ مِنْ بَعْدِهِ تَبِعْتُهُ‏.‏ وَقَدِمَهَا فِي بَشَرٍ كَثِيرٍ مِنْ قَوْمِهِ، فَأَقْبَلَ إِلَيْهِ رَسُولُ اللَّهِ صلى الله عليه وسلم وَمَعَهُ ثَابِتُ بْنُ قَيْسِ بْنِ شَمَّاسٍ، وَفِي يَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم قِطْعَةُ جَرِيدٍ، حَتَّى وَقَفَ عَلَى مُسَيْلِمَةَ فِي أَصْحَابِهِ فَقَالَ ‏"‏ لَوْ سَأَلْتَنِي هَذِهِ الْقِطْعَةَ مَا أَعْطَيْتُكَهَا، وَلَنْ تَعْدُوَ أَمْرَ اللَّهِ فِيكَ، وَلَئِنْ أَدْبَرْتَ لَيَعْقِرَنَّكَ اللَّهُ، وَإِنِّي لأَرَاكَ الَّذِي أُرِيتُ فِيكَ مَا رَأَيْتُ ‏"‏‏.‏ فَأَخْبَرَنِي أَبُو هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ بَيْنَمَا أَنَا نَائِمٌ رَأَيْتُ فِي يَدَىَّ سِوَارَيْنِ مِنْ ذَهَبٍ، فَأَهَمَّنِي شَأْنُهُمَا، فَأُوحِيَ إِلَىَّ فِي الْمَنَامِ أَنِ انْفُخْهُمَا، فَنَفَخْتُهُمَا فَطَارَا فَأَوَّلْتُهُمَا كَذَّابَيْنِ يَخْرُجَانِ بَعْدِي ‏"‏‏.‏ فَكَانَ أَحَدُهُمَا الْعَنْسِيَّ وَالآخَرُ مُسَيْلِمَةَ الْكَذَّابَ صَاحِبَ الْيَمَامَةِ‏.‏\hadithno{3621}\hadithtrans{Narrated Ibn `Abbas:Musailama-al-Kadhdhab (i.e. the liar) came in the life-time of Allah's Messenger (ﷺ) with many of his people (to Medina) and said, "If Muhammad makes me his successor, I will follow him." Allah's Messenger (ﷺ) went up to him with Thabit bin Qais bin Shams; and Allah's Messenger (ﷺ) was carrying a piece of a datepalm leaf in his hand. He stood before Musailama (and his companions) and said, "If you asked me even this piece (of a leaf), I would not give it to you. You cannot avoid the fate you are destined to, by Allah. If you reject Islam, Allah will destroy you. I think that you are most probably the same person whom I have seen in the dream." Abu Huraira told me that Allah's Messenger (ﷺ); said, "While I was sleeping, I saw (in a dream) two gold bracelets round my arm, and that worried me too much. Then I was instructed divinely in my dream, to blow them off and so I blew them off, and they flew away. I interpreted the two bracelets as symbols of two liars who would appear after me. And so one of them was Al-Ansi and the other was Musailama Al-Kadhdhab from Al-Yamama}}
\hadithdefcmd{bukhari}{3622}{حَدَّثَنِي مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا حَمَّادُ بْنُ أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ، عَنْ جَدِّهِ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى ـ أُرَاهُ ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ رَأَيْتُ فِي الْمَنَامِ أَنِّي أُهَاجِرُ مِنْ مَكَّةَ إِلَى أَرْضٍ بِهَا نَخْلٌ، فَذَهَبَ وَهَلِي إِلَى أَنَّهَا الْيَمَامَةُ أَوْ هَجَرُ، فَإِذَا هِيَ الْمَدِينَةُ يَثْرِبُ، وَرَأَيْتُ فِي رُؤْيَاىَ هَذِهِ أَنِّي هَزَزْتُ سَيْفًا فَانْقَطَعَ صَدْرُهُ، فَإِذَا هُوَ مَا أُصِيبَ مِنَ الْمُؤْمِنِينَ يَوْمَ أُحُدٍ، ثُمَّ هَزَزْتُهُ بِأُخْرَى فَعَادَ أَحْسَنَ مَا كَانَ، فَإِذَا هُوَ مَا جَاءَ اللَّهُ بِهِ مِنَ الْفَتْحِ وَاجْتِمَاعِ الْمُؤْمِنِينَ، وَرَأَيْتُ فِيهَا بَقَرًا وَاللَّهُ خَيْرٌ فَإِذَا هُمُ الْمُؤْمِنُونَ يَوْمَ أُحُدٍ، وَإِذَا الْخَيْرُ مَا جَاءَ اللَّهُ مِنَ الْخَيْرِ، وَثَوَابِ الصِّدْقِ الَّذِي آتَانَا اللَّهُ بَعْدَ يَوْمِ بَدْرٍ ‏"‏‏.‏\hadithno{3622}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "In a dream I saw myself migrating from Mecca to a place having plenty of date trees. I thought that it was Al-Yamama or Hajar, but it came to be Medina i.e. Yathrib. In the same dream I saw myself moving a sword and its blade got broken. It came to symbolize the defeat which the Muslims suffered from, on the Day of Uhud. I moved the sword again, and it became normal as before, and that was the symbol of the victory Allah bestowed upon Muslims and their gathering together. I saw cows in my dream, and by Allah, that was a blessing, and they symbolized the believers on the Day of Uhud. And the blessing was the good Allah bestowed upon us and the reward of true belief which Allah gave us after the day of Badr}}
\hadithdefcmd{bukhari}{3624}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا زَكَرِيَّاءُ، عَنْ فِرَاسٍ، عَنْ عَامِرٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ أَقْبَلَتْ فَاطِمَةُ تَمْشِي، كَأَنَّ مِشْيَتَهَا مَشْىُ النَّبِيِّ صلى الله عليه وسلم فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَرْحَبًا بِابْنَتِي ‏"‏‏.‏ ثُمَّ أَجْلَسَهَا عَنْ يَمِينِهِ أَوْ عَنْ شِمَالِهِ، ثُمَّ أَسَرَّ إِلَيْهَا حَدِيثًا، فَبَكَتْ فَقُلْتُ لَهَا لِمَ تَبْكِينَ ثُمَّ أَسَرَّ إِلَيْهَا حَدِيثًا فَضَحِكَتْ فَقُلْتُ مَا رَأَيْتُ كَالْيَوْمِ فَرَحًا أَقْرَبَ مِنْ حُزْنٍ، فَسَأَلْتُهَا عَمَّا قَالَ‏.‏ فَقَالَتْ مَا كُنْتُ لأُفْشِيَ سِرَّ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى قُبِضَ النَّبِيُّ صلى الله عليه وسلم فَسَأَلْتُهَا فَقَالَتْ أَسَرَّ إِلَىَّ ‏"‏ إِنَّ جِبْرِيلَ كَانَ يُعَارِضُنِي الْقُرْآنَ كُلَّ سَنَةٍ مَرَّةً، وَإِنَّهُ عَارَضَنِي الْعَامَ مَرَّتَيْنِ، وَلاَ أُرَاهُ إِلاَّ حَضَرَ أَجَلِي، وَإِنَّكِ أَوَّلُ أَهْلِ بَيْتِي لَحَاقًا بِي ‏"‏‏.‏ فَبَكَيْتُ فَقَالَ ‏"‏ أَمَا تَرْضَيْنَ أَنْ تَكُونِي سَيِّدَةَ نِسَاءِ أَهْلِ الْجَنَّةِ ـ أَوْ نِسَاءِ الْمُؤْمِنِينَ ‏"‏‏.‏ فَضَحِكْتُ لِذَلِكَ‏.‏\hadithno{3624}\hadithtrans{Narrated `Aisha:Once Fatima came walking and her gait resembled the gait of the Prophet (ﷺ) . The Prophet (ﷺ) said, "Welcome, O my daughter!" Then he made her sit on his right or on his left side, and then he told her a secret and she started weeping. I asked her, "Why are you weeping?" He again told her a secret and she started laughing. I said, "I never saw happiness so near to sadness as I saw today." I asked her what the Prophet (ﷺ) had told her. She said, "I would never disclose the secret of Allah's Messenger (ﷺ)." When the Prophet (ﷺ) died, I asked her about it. She replied. "The Prophet (ﷺ) said: 'Every year Gabriel used to revise the Qur'an with me once only, but this year he has done so twice. I think this portends my death, and you will be the first of my family to follow me.' So I started weeping. Then he said. 'Don't you like to be the chief of all the ladies of Paradise or the chief of the believing women? So I laughed for that}}
\hadithdefcmd{bukhari}{3626}{حَدَّثَنِي يَحْيَى بْنُ قَزَعَةَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ دَعَا النَّبِيُّ صلى الله عليه وسلم فَاطِمَةَ ابْنَتَهُ فِي شَكْوَاهُ الَّذِي قُبِضَ فِيهِ، فَسَارَّهَا بِشَىْءٍ فَبَكَتْ، ثُمَّ دَعَاهَا، فَسَارَّهَا فَضَحِكَتْ، قَالَتْ فَسَأَلْتُهَا عَنْ ذَلِكَ‏.‏ فَقَالَتْ سَارَّنِي النَّبِيُّ صلى الله عليه وسلم فَأَخْبَرَنِي أَنَّهُ يُقْبَضُ فِي وَجَعِهِ الَّذِي تُوُفِّيَ فِيهِ فَبَكَيْتُ، ثُمَّ سَارَّنِي فَأَخْبَرَنِي أَنِّي أَوَّلُ أَهْلِ بَيْتِهِ أَتْبَعُهُ فَضَحِكْتُ‏.‏\hadithno{3626}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) in his fatal illness, called his daughter Fatima and told her a secret because of which she started weeping. Then he called her and told her another secret, and she started laughing. When I asked her about that, she replied, The Prophet (ﷺ) told me that he would die in his fatal illness, and so I wept, but then he secretly told me that from amongst his family, I would be the first to join him, and so I laughed}}
\hadithdefcmd{bukhari}{3627}{حَدَّثَنَا مُحَمَّدُ بْنُ عَرْعَرَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ عُمَرُ بْنُ الْخَطَّابِ ـ رضى الله عنه ـ يُدْنِي ابْنَ عَبَّاسٍ، فَقَالَ لَهُ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ إِنَّ لَنَا أَبْنَاءً مِثْلَهُ‏.‏ فَقَالَ إِنَّهُ مِنْ حَيْثُ تَعْلَمُ‏.‏ فَسَأَلَ عُمَرُ ابْنَ عَبَّاسٍ عَنْ هَذِهِ الآيَةِ ‏\{‏إِذَا جَاءَ نَصْرُ اللَّهِ وَالْفَتْحُ‏\}‏‏.‏ فَقَالَ أَجَلُ رَسُولِ اللَّهِ صلى الله عليه وسلم أَعْلَمَهُ إِيَّاهُ‏.‏ قَالَ مَا أَعْلَمُ مِنْهَا إِلاَّ مَا تَعْلَمُ‏.‏\hadithno{3627}\hadithtrans{Narrated Sa`id bin Jubair:About Ibn `Abbas: `Umar bin Al-Khattab used to treat Ibn `Abbas very favorably `Abdur Rahman bin `Auf said to him. "We also have sons that are equal to him (but you are partial to him.)" `Umar said, "It is because of his knowledge." Then `Umar asked Ibn `Abbas about the interpretation of the Verse:- 'When come the Help of Allah and the conquest (of Mecca) (110.1) Ibn `Abbas said. "It portended the death of Allah's Messenger (ﷺ), which Allah had informed him of." `Umar said, "I do not know from this Verse but what you know}}
\hadithdefcmd{bukhari}{3628}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سُلَيْمَانَ بْنِ حَنْظَلَةَ بْنِ الْغَسِيلِ، حَدَّثَنَا عِكْرِمَةُ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي مَرَضِهِ الَّذِي مَاتَ فِيهِ بِمِلْحَفَةٍ قَدْ عَصَّبَ بِعِصَابَةٍ دَسْمَاءَ، حَتَّى جَلَسَ عَلَى الْمِنْبَرِ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏ "‏ أَمَّا بَعْدُ فَإِنَّ النَّاسَ يَكْثُرُونَ وَيَقِلُّ الأَنْصَارُ، حَتَّى يَكُونُوا فِي النَّاسِ بِمَنْزِلَةِ الْمِلْحِ فِي الطَّعَامِ، فَمَنْ وَلِيَ مِنْكُمْ شَيْئًا يَضُرُّ فِيهِ قَوْمًا، وَيَنْفَعُ فِيهِ آخَرِينَ، فَلْيَقْبَلْ مِنْ مُحْسِنِهِمْ، وَيَتَجَاوَزْ عَنْ مُسِيئِهِمْ ‏"‏‏.‏ فَكَانَ آخِرَ مَجْلِسٍ جَلَسَ بِهِ النَّبِيُّ صلى الله عليه وسلم‏.‏\hadithno{3628}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) in his fatal illness came out, wrapped with a sheet, and his head was wrapped with an oiled bandage. He sat on the pulpit, and praising and glorifying Allah, he said, "Now then, people will increase but the Ansar will decrease in number, so much so that they, compared with the people, will be just like the salt in the meals. So, if any of you should take over the authority by which he can either benefit some people or harm some others, he should accept the goodness of their good people (i.e. Ansar) and excuse the faults of their wrong-doers." That was the last gathering which the Prophet (ﷺ) attended}}
\hadithdefcmd{bukhari}{3629}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا حُسَيْنٌ الْجُعْفِيُّ، عَنْ أَبِي مُوسَى، عَنِ الْحَسَنِ، عَنْ أَبِي بَكْرَةَ ـ رضى الله عنه ـ أَخْرَجَ النَّبِيُّ صلى الله عليه وسلم ذَاتَ يَوْمٍ الْحَسَنَ فَصَعِدَ بِهِ عَلَى الْمِنْبَرِ، فَقَالَ ‏ "‏ ابْنِي هَذَا سَيِّدٌ، وَلَعَلَّ اللَّهَ أَنْ يُصْلِحَ بِهِ بَيْنَ فِئَتَيْنِ مِنَ الْمُسْلِمِينَ ‏"‏‏.‏\hadithno{3629}\hadithtrans{Narrated Abu Bakra:Once the Prophet (ﷺ) brought out Al-Hasan and took him up the pulpit along with him and said, "This son of mine is a Saiyid (i.e. chief) and I hope that Allah will help him bring about reconciliation between two Muslim groups}}
\hadithdefcmd{bukhari}{3630}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَعَى جَعْفَرًا وَزَيْدًا قَبْلَ أَنْ يَجِيءَ خَبَرُهُمْ، وَعَيْنَاهُ تَذْرِفَانِ‏.‏\hadithno{3630}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) had informed us of the death of Ja`far and Zaid before the news of their death reached us, and his eyes were shedding tears}}
\hadithdefcmd{bukhari}{3631}{حَدَّثَنِي عَمْرُو بْنُ عَبَّاسٍ، حَدَّثَنَا ابْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ هَلْ لَكُمْ مِنْ أَنْمَاطٍ ‏"‏‏.‏ قُلْتُ وَأَنَّى يَكُونُ لَنَا الأَنْمَاطُ قَالَ ‏"‏ أَمَا إِنَّهُ سَيَكُونُ لَكُمُ الأَنْمَاطُ ‏"‏‏.‏ فَأَنَا أَقُولُ لَهَا ـ يَعْنِي امْرَأَتَهُ ـ أَخِّرِي عَنِّي أَنْمَاطَكِ‏.‏ فَتَقُولُ أَلَمْ يَقُلِ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّهَا سَتَكُونُ لَكُمُ الأَنْمَاطُ ‏"‏‏.‏ فَأَدَعُهَا‏.‏\hadithno{3631}\hadithtrans{Narrated Jabir:(Once) the Prophet (ﷺ) said, "Have you got carpets?" I replied, "Whence can we get carpets?" He said, "But you shall soon have carpets." I used to say to my wife, "Remove your carpets from my sight," but she would say, "Didn't the Prophet (ﷺ) tell you that you would soon have carpets?" So I would give up my request}}
\hadithdefcmd{bukhari}{3632}{حَدَّثَنِي أَحْمَدُ بْنُ إِسْحَاقَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ انْطَلَقَ سَعْدُ بْنُ مُعَاذٍ مُعْتَمِرًا ـ قَالَ ـ فَنَزَلَ عَلَى أُمَيَّةَ بْنِ خَلَفٍ أَبِي صَفْوَانَ، وَكَانَ أُمَيَّةُ إِذَا انْطَلَقَ إِلَى الشَّأْمِ فَمَرَّ بِالْمَدِينَةِ نَزَلَ عَلَى سَعْدٍ، فَقَالَ أُمَيَّةُ لِسَعْدٍ انْتَظِرْ حَتَّى إِذَا انْتَصَفَ النَّهَارُ، وَغَفَلَ النَّاسُ انْطَلَقْتُ فَطُفْتُ، فَبَيْنَا سَعْدٌ يَطُوفُ إِذَا أَبُو جَهْلٍ فَقَالَ مَنْ هَذَا الَّذِي يَطُوفُ بِالْكَعْبَةِ فَقَالَ سَعْدٌ أَنَا سَعْدٌ‏.‏ فَقَالَ أَبُو جَهْلٍ تَطُوفُ بِالْكَعْبَةِ آمِنًا، وَقَدْ آوَيْتُمْ مُحَمَّدًا وَأَصْحَابَهُ فَقَالَ نَعَمْ‏.‏ فَتَلاَحَيَا بَيْنَهُمَا‏.‏ فَقَالَ أُمَيَّةُ لِسَعْدٍ لاَ تَرْفَعْ صَوْتَكَ عَلَى أَبِي الْحَكَمِ، فَإِنَّهُ سَيِّدُ أَهْلِ الْوَادِي‏.‏ ثُمَّ قَالَ سَعْدٌ وَاللَّهِ لَئِنْ مَنَعْتَنِي أَنْ أَطُوفَ بِالْبَيْتِ لأَقْطَعَنَّ مَتْجَرَكَ بِالشَّأْمِ‏.‏ قَالَ فَجَعَلَ أُمَيَّةُ يَقُولُ لِسَعْدٍ لاَ تَرْفَعْ صَوْتَكَ‏.‏ وَجَعَلَ يُمْسِكُهُ، فَغَضِبَ سَعْدٌ فَقَالَ دَعْنَا عَنْكَ، فَإِنِّي سَمِعْتُ مُحَمَّدًا صلى الله عليه وسلم يَزْعُمُ أَنَّهُ قَاتِلُكَ‏.‏ قَالَ إِيَّاىَ قَالَ نَعَمْ‏.‏ قَالَ وَاللَّهِ مَا يَكْذِبُ مُحَمَّدٌ إِذَا حَدَّثَ‏.‏ فَرَجَعَ إِلَى امْرَأَتِهِ، فَقَالَ أَمَا تَعْلَمِينَ مَا قَالَ لِي أَخِي الْيَثْرِبِيُّ قَالَتْ وَمَا قَالَ قَالَ زَعَمَ أَنَّهُ سَمِعَ مُحَمَّدًا يَزْعُمُ أَنَّهُ قَاتِلِي‏.‏ قَالَتْ فَوَاللَّهِ مَا يَكْذِبُ مُحَمَّدٌ‏.‏ قَالَ فَلَمَّا خَرَجُوا إِلَى بَدْرٍ، وَجَاءَ الصَّرِيخُ قَالَتْ لَهُ امْرَأَتُهُ أَمَا ذَكَرْتَ مَا قَالَ لَكَ أَخُوكَ الْيَثْرِبِيُّ قَالَ فَأَرَادَ أَنْ لاَ يَخْرُجَ، فَقَالَ لَهُ أَبُو جَهْلٍ إِنَّكَ مِنْ أَشْرَافِ الْوَادِي، فَسِرْ يَوْمًا أَوْ يَوْمَيْنِ، فَسَارَ مَعَهُمْ فَقَتَلَهُ اللَّهُ‏.‏\hadithno{3632}\hadithtrans{Narrated `Abdullah bin Mas`ud:Sa`d bin Mu`adh came to Mecca with the intention of performing `Umra, and stayed at the house of Umaiya bin Khalaf Abi Safwan, for Umaiya himself used to stay at Sa`d's house when he passed by Medina on his way to Sham. Umaiya said to Sa`d, "Will you wait till midday when the people are (at their homes), then you may go and perform the Tawaf round the Ka`ba?" So, while Sa`d was going around the Ka`ba, Abu Jahl came and asked, "Who is that who is performing Tawaf?" Sa`d replied, "I am Sa`d." Abu Jahl said, "Are you circumambulating the Ka`ba safely although you have given refuge to Muhammad and his companions?" Sa`d said, "Yes," and they started quarreling. Umaiya said to Sa`d, "Don't shout at Abi-l-Hakam (i.e. Abu Jahl), for he is chief of the valley (of Mecca)." Sa`d then said (to Abu Jahl). 'By Allah, if you prevent me from performing the Tawaf of the Ka`ba, I will spoil your trade with Sham." Umaiya kept on saying to Sa`d, "Don't raise your voice." and kept on taking hold of him. Sa`d became furious and said, (to Umaiya), "Be away from me, for I have heard Muhammad saying that he will kill you." Umaiya said, "Will he kill me?" Sa`d said, "Yes,." Umaiya said, "By Allah! When Muhammad says a thing, he never tells a lie." Umaiya went to his wife and said to her, "Do you know what my brother from Yathrib (i.e. Medina) has said to me?" She said, "What has he said?" He said, "He claims that he has heard Muhammad claiming that he will kill me." She said, By Allah! Muhammad never tells a lie." So when the infidels started to proceed for Badr (Battle) and declared war (against the Muslims), his wife said to him, "Don't you remember what your brother from Yathrib told you?" Umaiya decided not to go but Abu Jahl said to him, "You are from the nobles of the valley (of Mecca), so you should accompany us for a day or two." He went with them and thus Allah got him killed}}
\hadithdefcmd{bukhari}{3633}{حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الْمُغِيرَةِ، عَنْ أَبِيهِ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ رَأَيْتُ النَّاسَ مُجْتَمِعِينَ فِي صَعِيدٍ، فَقَامَ أَبُو بَكْرٍ فَنَزَعَ ذَنُوبًا أَوْ ذَنُوبَيْنِ، وَفِي بَعْضِ نَزْعِهِ ضَعْفٌ، وَاللَّهُ يَغْفِرُ لَهُ، ثُمَّ أَخَذَهَا عُمَرُ، فَاسْتَحَالَتْ بِيَدِهِ غَرْبًا، فَلَمْ أَرَ عَبْقَرِيًّا فِي النَّاسِ يَفْرِي فَرِيَّهُ، حَتَّى ضَرَبَ النَّاسُ بِعَطَنٍ ‏"‏‏.‏ وَقَالَ هَمَّامٌ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ فَنَزَعَ أَبُو بَكْرٍ ذَنُوبَيْنِ ‏"‏‏.‏\hadithno{3633}\hadithtrans{Narrated `Abdullah:Allah's Messenger (ﷺ) said, "I saw (in a dream) the people assembled in a gathering, and then Abu Bakr got up and drew one or two buckets of water (from a well) but there was weakness in his drawing. May Allah forgive him. Then `Umar took the bucket and in his hands it turned into a very large bucket. I had never seen anyone amongst: the people who could draw the water as strongly as `Umar till all the people drank their fill and watered their camels that knelt down there}}
\hadithdefcmd{bukhari}{3634}{حَدَّثَنِي عَبَّاسُ بْنُ الْوَلِيدِ النَّرْسِيُّ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ سَمِعْتُ أَبِي، حَدَّثَنَا أَبُو عُثْمَانَ، قَالَ أُنْبِئْتُ أَنَّ جِبْرِيلَ ـ عَلَيْهِ السَّلاَمُ ـ أَتَى النَّبِيَّ صلى الله عليه وسلم وَعِنْدَهُ أُمُّ سَلَمَةَ، فَجَعَلَ يُحَدِّثُ ثُمَّ قَامَ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم لأُمِّ سَلَمَةَ ‏ "‏ مَنْ هَذَا ‏"‏‏.‏ أَوْ كَمَا قَالَ‏.‏ قَالَ قَالَتْ هَذَا دِحْيَةُ‏.‏ قَالَتْ أُمُّ سَلَمَةَ ايْمُ اللَّهِ مَا حَسِبْتُهُ إِلاَّ إِيَّاهُ حَتَّى سَمِعْتُ خُطْبَةَ نَبِيِّ اللَّهِ صلى الله عليه وسلم يُخْبِرُ جِبْرِيلَ أَوْ كَمَا قَالَ‏.‏ قَالَ فَقُلْتُ لأَبِي عُثْمَانَ مِمَّنْ سَمِعْتَ هَذَا قَالَ مِنْ أُسَامَةَ بْنِ زَيْدٍ‏.‏\hadithno{3634}\hadithtrans{Narrated Abu `Uthman:I got the news that Gabriel came to the Prophet (ﷺ) while Um Salama was present. Gabriel started talking (to the Prophet (ﷺ) and then left. The Prophet (ﷺ) said to Um Salama, "(Do you know) who it was?" (or a similar question). She said, "It was Dihya (a handsome person amongst the companions of the Prophet (ﷺ) )." Later on Um Salama said, "By Allah! I thought he was none but Dihya, till I heard the Prophet (ﷺ) talking about Gabriel in his sermon." (The Sub-narrator asked Abu `Uthman, "From where have you heard this narration?" He replied, "From Usama bin Zaid)}}
\hadithdefcmd{bukhari}{3635}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، أَخْبَرَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ الْيَهُودَ، جَاءُوا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرُوا لَهُ أَنَّ رَجُلاً مِنْهُمْ وَامْرَأَةً زَنَيَا فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا تَجِدُونَ فِي التَّوْرَاةِ فِي شَأْنِ الرَّجْمِ ‏"‏‏.‏ فَقَالُوا نَفْضَحُهُمْ وَيُجْلَدُونَ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ كَذَبْتُمْ، إِنَّ فِيهَا الرَّجْمَ‏.‏ فَأَتَوْا بِالتَّوْرَاةِ فَنَشَرُوهَا، فَوَضَعَ أَحَدُهُمْ يَدَهُ عَلَى آيَةِ الرَّجْمِ، فَقَرَأَ مَا قَبْلَهَا وَمَا بَعْدَهَا‏.‏ فَقَالَ لَهُ عَبْدُ اللَّهِ بْنُ سَلاَمٍ ارْفَعْ يَدَكَ‏.‏ فَرَفَعَ يَدَهُ فَإِذَا فِيهَا آيَةُ الرَّجْمِ‏.‏ فَقَالُوا صَدَقَ يَا مُحَمَّدُ، فِيهَا آيَةُ الرَّجْمِ‏.‏ فَأَمَرَ بِهِمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَرُجِمَا‏.‏ قَالَ عَبْدُ اللَّهِ فَرَأَيْتُ الرَّجُلَ يَجْنَأُ عَلَى الْمَرْأَةِ يَقِيهَا الْحِجَارَةَ‏.‏\hadithno{3635}\hadithtrans{Narrated `Abdullah bin `Umar:The Jews came to Allah's Messenger (ﷺ) and told him that a man and a woman from amongst them had committed illegal sexual intercourse. Allah's Messenger (ﷺ) said to them, "What do you find in the Torah (old Testament) about the legal punishment of Ar-Rajm (stoning)?" They replied, (But) we announce their crime and lash them." `Abdullah bin Salam said, "You are telling a lie; Torah contains the order of Rajm." They brought and opened the Torah and one of them placed his hand on the Verse of Rajm and read the verses preceding and following it. `Abdullah bin Salam said to him, "Lift your hand." When he lifted his hand, the Verse of Rajm was written there. They said, "Muhammad has told the truth; the Torah has the Verse of Rajm. The Prophet (ﷺ) then gave the order that both of them should be stoned to death. (`Abdullah bin `Umar said, "I saw the man leaning over the woman to shelter her from the stones)}}
\hadithdefcmd{bukhari}{3636}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ أَبِي مَعْمَرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ ـ رضى الله عنه ـ قَالَ انْشَقَّ الْقَمَرُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم شِقَّتَيْنِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ اشْهَدُوا ‏"‏‏.‏\hadithno{3636}\hadithtrans{Narrated `Abdullah bin Masud:During the lifetime of the Prophet (ﷺ) the moon was split into two parts and on that the Prophet (ﷺ) said, "Bear witness (to this)}}
\hadithdefcmd{bukhari}{3637}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا يُونُسُ، حَدَّثَنَا شَيْبَانُ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ،‏.‏ وَقَالَ لِي خَلِيفَةُ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ أَنَّهُ حَدَّثَهُمْ أَنَّ أَهْلَ مَكَّةَ سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْ يُرِيَهُمْ آيَةً، فَأَرَاهُمُ انْشِقَاقَ الْقَمَرِ‏.‏\hadithno{3637}\hadithtrans{Narrated Anas:That the Meccan people requested Allah's Messenger (ﷺ) to show them a miracle, and so he showed them the splitting of the moon}}
\hadithdefcmd{bukhari}{3638}{حَدَّثَنِي خَلَفُ بْنُ خَالِدٍ الْقُرَشِيُّ، حَدَّثَنَا بَكْرُ بْنُ مُضَرَ، عَنْ جَعْفَرِ بْنِ رَبِيعَةَ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما أَنَّ الْقَمَرَ، انْشَقَّ فِي زَمَانِ النَّبِيِّ صلى الله عليه وسلم‏\hadithno{3638}\hadithtrans{Narrated Ibn `Abbas:The moon was split into two parts during the lifetime of the Prophet}}
\hadithdefcmd{bukhari}{3639}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذٌ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسٌ ـ رضى الله عنه ـ أَنَّ رَجُلَيْنِ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم خَرَجَا مِنْ عِنْدِ النَّبِيِّ صلى الله عليه وسلم فِي لَيْلَةٍ مُظْلِمَةٍ وَمَعَهُمَا مِثْلُ الْمِصْبَاحَيْنِ، يُضِيآنِ بَيْنَ أَيْدِيهِمَا، فَلَمَّا افْتَرَقَا صَارَ مَعَ كُلِّ وَاحِدٍ مِنْهُمَا وَاحِدٌ حَتَّى أَتَى أَهْلَهُ‏.‏\hadithno{3639}\hadithtrans{Narrated Anas:Once two men from the companions of Allah's Messenger (ﷺ) went out of the house of the Prophet (ﷺ) on a very dark night. They were accompanied by two things that resembled two lamps lighting the way in front of them, and when they parted, each of them was accompanied by one of those two things (lamps) till they reached their homes}}
\hadithdefcmd{bukhari}{3640}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي الأَسْوَدِ، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، حَدَّثَنَا قَيْسٌ، سَمِعْتُ الْمُغِيرَةَ بْنَ شُعْبَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَزَالُ نَاسٌ مِنْ أُمَّتِي ظَاهِرِينَ حَتَّى يَأْتِيَهُمْ أَمْرُ اللَّهِ وَهُمْ ظَاهِرُونَ ‏"‏‏.‏\hadithno{3640}\hadithtrans{Narrated Al-Mughira bin Shu`ba:The Prophet (ﷺ) said, "Some of my followers will remain victorious (and on the right path) till the Last Day comes, and they will still be victorious}}
\hadithdefcmd{bukhari}{3641}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنِي ابْنُ جَابِرٍ، قَالَ حَدَّثَنِي عُمَيْرُ بْنُ هَانِئٍ، أَنَّهُ سَمِعَ مُعَاوِيَةَ، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَزَالُ مِنْ أُمَّتِي أُمَّةٌ قَائِمَةٌ بِأَمْرِ اللَّهِ، لاَ يَضُرُّهُمْ مَنْ خَذَلَهُمْ وَلاَ مَنْ خَالَفَهُمْ حَتَّى يَأْتِيَهُمْ أَمْرُ اللَّهِ وَهُمْ عَلَى ذَلِكَ ‏"‏‏.‏ قَالَ عُمَيْرٌ فَقَالَ مَالِكُ بْنُ يُخَامِرَ قَالَ مُعَاذٌ وَهُمْ بِالشَّأْمِ‏.‏ فَقَالَ مُعَاوِيَةُ هَذَا مَالِكٌ يَزْعُمُ أَنَّهُ سَمِعَ مُعَاذًا يَقُولُ وَهُمْ بِالشَّامِ‏.‏\hadithno{3641}\hadithtrans{Narrated Muawiya:I heard the Prophet (ﷺ) saying, "A group of people amongst my followers will remain obedient to Allah's orders and they will not be harmed by anyone who will not help them or who will oppose them, till Allah's Order (the Last Day) comes upon them while they are still on the right path}}
\hadithdefcmd{bukhari}{3643}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا شَبِيبُ بْنُ غَرْقَدَةَ، قَالَ سَمِعْتُ الْحَىَّ، يُحَدِّثُونَ عَنْ عُرْوَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَعْطَاهُ دِينَارًا يَشْتَرِي بِهِ شَاةً، فَاشْتَرَى لَهُ بِهِ شَاتَيْنِ، فَبَاعَ إِحْدَاهُمَا بِدِينَارٍ وَجَاءَهُ بِدِينَارٍ وَشَاةٍ، فَدَعَا لَهُ بِالْبَرَكَةِ فِي بَيْعِهِ، وَكَانَ لَوِ اشْتَرَى التُّرَابَ لَرَبِحَ فِيهِ‏.‏ قَالَ سُفْيَانُ كَانَ الْحَسَنُ بْنُ عُمَارَةَ جَاءَنَا بِهَذَا الْحَدِيثِ عَنْهُ، قَالَ سَمِعَهُ شَبِيبٌ مِنْ عُرْوَةَ، فَأَتَيْتُهُ فَقَالَ شَبِيبٌ إِنِّي لَمْ أَسْمَعْهُ مِنْ عُرْوَةَ، قَالَ سَمِعْتُ الْحَىَّ يُخْبِرُونَهُ عَنْهُ‏.‏ وَلَكِنْ سَمِعْتُهُ يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ الْخَيْرُ مَعْقُودٌ بِنَوَاصِي الْخَيْلِ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏‏.‏ قَالَ وَقَدْ رَأَيْتُ فِي دَارِهِ سَبْعِينَ فَرَسًا‏.‏ قَالَ سُفْيَانُ يَشْتَرِي لَهُ شَاةً كَأَنَّهَا أُضْحِيَّةٌ‏.‏\hadithno{3643}\hadithtrans{Narrated `Urwa:That the Prophet (ﷺ) gave him one Dinar so as to buy a sheep for him. `Urwa bought two sheep for him with the money. Then he sold one of the sheep for one Dinar, and brought one Dinar and a sheep to the Prophet. On that, the Prophet (ﷺ) invoked Allah to bless him in his deals. So `Urwa used to gain (from any deal) even if he bought dust. (In another narration) `Urwa said, "I heard Allah's Messenger (ﷺ) saying, "There is always goodness in horses till the Day of Resurrection." (The subnarrator added, "I saw 70 horses in `Urwa's house.') (Sufyan said, "The Prophet (ﷺ) asked `Urwa to buy a sheep for him as a sacrifice}}
\hadithdefcmd{bukhari}{3644}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْخَيْلُ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏‏.‏\hadithno{3644}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "There is always goodness in horses till the Day of Resurrection}}
\hadithdefcmd{bukhari}{3645}{حَدَّثَنَا قَيْسُ بْنُ حَفْصٍ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ أَنَسًا، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْخَيْلُ مَعْقُودٌ فِي نَوَاصِيهَا الْخَيْرُ ‏"‏‏.‏\hadithno{3645}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "There is always goodness in horses}}
\hadithdefcmd{bukhari}{3646}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِي صَالِحٍ السَّمَّانِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ الْخَيْلُ لِثَلاَثَةٍ لِرَجُلٍ أَجْرٌ، وَلِرَجُلٍ سِتْرٌ وَعَلَى رَجُلٍ وِزْرٌ‏.‏ فَأَمَّا الَّذِي لَهُ أَجْرٌ، فَرَجُلٌ رَبَطَهَا فِي سَبِيلِ اللَّهِ، فَأَطَالَ لَهَا فِي مَرْجٍ أَوْ رَوْضَةٍ، وَمَا أَصَابَتْ فِي طِيَلِهَا مِنَ الْمَرْجِ أَوِ الرَّوْضَةِ كَانَتْ لَهُ حَسَنَاتٍ، وَلَوْ أَنَّهَا قَطَعَتْ طِيَلَهَا، فَاسْتَنَّتْ شَرَفًا أَوْ شَرَفَيْنِ، كَانَتْ أَرْوَاثُهَا حَسَنَاتٍ لَهُ، وَلَوْ أَنَّهَا مَرَّتْ بِنَهْرٍ فَشَرِبَتْ، وَلَمْ يُرِدْ أَنْ يَسْقِيَهَا، كَانَ ذَلِكَ لَهُ حَسَنَاتٍ، وَرَجُلٌ رَبَطَهَا تَغَنِّيًا وَسِتْرًا وَتَعَفُّفًا، لَمْ يَنْسَ حَقَّ اللَّهِ فِي رِقَابِهَا وَظُهُورِهَا، فَهِيَ لَهُ كَذَلِكَ سِتْرٌ‏.‏ وَرَجُلٌ رَبَطَهَا فَخْرًا وَرِيَاءً، وَنِوَاءً لأَهْلِ الإِسْلاَمِ فَهْىَ وِزْرٌ‏.‏ وَسُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنِ الْحُمُرِ فَقَالَ ‏"‏ مَا أُنْزِلَ عَلَىَّ فِيهَا إِلاَّ هَذِهِ الآيَةُ الْجَامِعَةُ الْفَاذَّةُ ‏\{‏فَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ خَيْرًا يَرَهُ * وَمَنْ يَعْمَلْ مِثْقَالَ ذَرَّةٍ شَرًّا يَرَهُ‏\}‏\hadithno{3646}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "A horse may be kept for one of three purposes: for a man it may be a source of reward; for another it may be a means of living; and for a third it may be a burden (a source of committing sins). As for the one for whom it is a source of reward, he is the one who keeps his horse for the sake of Jihad in Allah's Cause; he ties it with a long rope on a pasture or in a garden. So whatever its rope allows it to eat, will be regarded as good rewardable deeds (for its owner). And if it breaks off its rope and jumps over one or two hillocks, even its dung will be considered amongst his good deeds. And if it passes by a river and drinks water from it, that will be considered as good deeds for his benefit) even if he has had no intention of watering it. A horse is a shelter for the one who keeps it so that he may earn his living honestly and takes it as a refuge to keep him from following illegal ways (of gaining money), and does not forget the rights of Allah (i.e. paying the Zakat and allowing others to use it for Allah's Sake). But a horse is a burden (and a source of committing sins for him who keeps it out of pride and pretense and with the intention of harming the Muslims." The Prophet (ﷺ) was asked about donkeys. He replied, "Nothing has been revealed to me concerning them except this comprehensive Verse (which covers everything) :--'Then whosoever has done good equal to the weight of an atom (or a small ant), Shall see it (its reward) And whosoever has done evil equal to the weight of an atom (or a small ) ant), Shall see it (Its punishment)}}
\hadithdefcmd{bukhari}{3647}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا أَيُّوبُ، عَنْ مُحَمَّدٍ، سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ يَقُولُ صَبَّحَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَيْبَرَ بُكْرَةً وَقَدْ خَرَجُوا بِالْمَسَاحِي، فَلَمَّا رَأَوْهُ قَالُوا مُحَمَّدٌ وَالْخَمِيسُ‏.‏ وَأَحَالُوا إِلَى الْحِصْنِ يَسْعَوْنَ، فَرَفَعَ النَّبِيُّ صلى الله عليه وسلم يَدَيْهِ وَقَالَ ‏ "‏ اللَّهُ أَكْبَرُ، خَرِبَتْ خَيْبَرُ، إِنَّا إِذَا نَزَلْنَا بِسَاحَةِ قَوْمٍ فَسَاءَ صَبَاحُ الْمُنْذَرِينَ ‏"‏‏.‏\hadithno{3647}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) reached Khaibar in the early morning and the people of Khaibar came out with their spades, and when they saw the Prophet (ﷺ) they said, "Muhammad and his army!" and returned hurriedly to take refuge in the fort. The Prophet (ﷺ) raised his hands and said, "Allah is Greater! Khaibar is ruined ! If we approach a nation, then miserable is the morning of those who are warned}}
\hadithdefcmd{bukhari}{3648}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا ابْنُ أَبِي الْفُدَيْكِ، عَنِ ابْنِ أَبِي ذِئْبٍ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي سَمِعْتُ مِنْكَ كَثِيرًا فَأَنْسَاهُ‏.‏ قَالَ ‏"‏ ابْسُطْ رِدَاءَكَ ‏"‏‏.‏ فَبَسَطْتُ فَغَرَفَ بِيَدِهِ فِيهِ، ثُمَّ قَالَ ‏"‏ ضُمَّهُ ‏"‏ فَضَمَمْتُهُ، فَمَا نَسِيتُ حَدِيثًا بَعْدُ‏.‏\hadithno{3648}\hadithtrans{Narrated Abu Huraira:I said, "O Allah's Messenger (ﷺ)! I hear many narrations from you but I forget them." He said, "Spread your covering sheet." I spread my sheet and he moved both his hands as if scooping something and emptied them in the sheet and said, "Wrap it." I wrapped it round my body, and since then I have never forgotten}}
