% Auto-generated chapter 40 for abudawud
% Hadiths in this chapter: 143

\hadithdefcmd{abudawud}{4351}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، أَنَّ عَلِيًّا، عَلَيْهِ السَّلاَمُ أَحْرَقَ نَاسًا ارْتَدُّوا عَنِ الإِسْلاَمِ فَبَلَغَ ذَلِكَ ابْنَ عَبَّاسٍ فَقَالَ لَمْ أَكُنْ لأَحْرِقَهُمْ بِالنَّارِ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تُعَذِّبُوا بِعَذَابِ اللَّهِ ‏"‏ ‏.‏ وَكُنْتُ قَاتِلَهُمْ بِقَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ بَدَّلَ دِينَهُ فَاقْتُلُوهُ ‏"‏ ‏.‏ فَبَلَغَ ذَلِكَ عَلِيًّا عَلَيْهِ السَّلاَمُ فَقَالَ وَيْحَ ابْنَ عَبَّاسٍ ‏.‏\hadithno{4351}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6922)}\hadithtrans{‘Ikrimah said:‘Ali burned some people who retreated from Islam. When Ibn ‘Abbas was informed of it, he said: If it had been I, I would not have burned them, for the Messenger of Allah (ﷺ) said: Do not inflict Allah’s punishment on anyone, but would have had killed them on account of the statement of the Messenger of Allah (ﷺ). The Apostle said: Kill those who change their religion. When ‘Ali was informed about it he said: How truly Ibn ‘Abbas said}}
\hadithdefcmd{abudawud}{4352}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ دَمُ رَجُلٍ مُسْلِمٍ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ إِلاَّ بِإِحْدَى ثَلاَثٍ الثَّيِّبُ الزَّانِي وَالنَّفْسُ بِالنَّفْسِ وَالتَّارِكُ لِدِينِهِ الْمُفَارِقُ لِلْجَمَاعَةِ ‏"‏ ‏.‏\hadithno{4352}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6878) Sahih Muslim (1676)}\hadithtrans{Abd Allah (b. Mas`ud) reported the Messenger of Allah (peace be upon him) as saying:The blood of a Muslim man who testifies that there is no god but Allah and that I am the Messenger of Allah should not be lawfully shed but only for one of three reasons: married fornicator, soul for soul, and one who deserts his religion separating himself from the community}}
\hadithdefcmd{abudawud}{4353}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ الْبَاهِلِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَحِلُّ دَمُ امْرِئٍ مُسْلِمٍ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنَّ مُحَمَّدًا رَسُولُ اللَّهِ إِلاَّ بِإِحْدَى ثَلاَثٍ رَجُلٌ زَنَى بَعْدَ إِحْصَانٍ فَإِنَّهُ يُرْجَمُ وَرَجُلٌ خَرَجَ مُحَارِبًا لِلَّهِ وَرَسُولِهِ فَإِنَّهُ يُقْتَلُ أَوْ يُصْلَبُ أَوْ يُنْفَى مِنَ الأَرْضِ أَوْ يَقْتُلُ نَفْسًا فَيُقْتَلُ بِهَا ‏"‏ ‏.‏\hadithno{4353}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) Said: The blood of a Muslim man who testifies that there is no god but Allah and that Muhammad is Allah's Apostle should not lawfully be shed except only for one of three reasons: a man who committed fornication after marriage, in which case he should be stoned; one who goes forth to fight with Allah and His Apostle, in which case he should be killed or crucified or exiled from the land; or one who commits murder for which he is killed}}
\hadithdefcmd{abudawud}{4354}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، - قَالَ مُسَدَّدٌ - حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا حُمَيْدُ بْنُ هِلاَلٍ، حَدَّثَنَا أَبُو بُرْدَةَ، قَالَ قَالَ أَبُو مُوسَى أَقْبَلْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَمَعِي رَجُلاَنِ مِنَ الأَشْعَرِيِّينَ أَحَدُهُمَا عَنْ يَمِينِي وَالآخَرُ عَنْ يَسَارِي فَكِلاَهُمَا سَأَلَ الْعَمَلَ وَالنَّبِيُّ صلى الله عليه وسلم سَاكِتٌ فَقَالَ ‏"‏ مَا تَقُولُ يَا أَبَا مُوسَى ‏"‏ ‏.‏ أَوْ ‏"‏ يَا عَبْدَ اللَّهِ بْنَ قَيْسٍ ‏"‏ ‏.‏ قُلْتُ وَالَّذِي بَعَثَكَ بِالْحَقِّ مَا أَطْلَعَانِي عَلَى مَا فِي أَنْفُسِهِمَا وَمَا شَعَرْتُ أَنَّهُمَا يَطْلُبَانِ الْعَمَلَ ‏.‏ قَالَ وَكَأَنِّي أَنْظُرُ إِلَى سِوَاكِهِ تَحْتَ شَفَتِهِ قَلَصَتْ قَالَ ‏"‏ لَنْ نَسْتَعْمِلَ - أَوْ لاَ نَسْتَعْمِلُ - عَلَى عَمَلِنَا مَنْ أَرَادَهُ وَلَكِنِ اذْهَبْ أَنْتَ يَا أَبَا مُوسَى أَوْ يَا عَبْدَ اللَّهِ بْنَ قَيْسٍ ‏"‏ ‏.‏ فَبَعَثَهُ عَلَى الْيَمَنِ ثُمَّ أَتْبَعَهُ مُعَاذَ بْنَ جَبَلٍ قَالَ فَلَمَّا قَدِمَ عَلَيْهِ مُعَاذٌ قَالَ انْزِلْ ‏.‏ وَأَلْقَى لَهُ وِسَادَةً فَإِذَا رَجُلٌ عِنْدَهُ مُوثَقٌ قَالَ مَا هَذَا قَالَ هَذَا كَانَ يَهُودِيًّا فَأَسْلَمَ ثُمَّ رَاجَعَ دِينَهُ دِينَ السُّوءِ ‏.‏ قَالَ لاَ أَجْلِسُ حَتَّى يُقْتَلَ قَضَاءُ اللَّهِ وَرَسُولِهِ ‏.‏ قَالَ اجْلِسْ نَعَمْ ‏.‏ قَالَ لاَ أَجْلِسُ حَتَّى يُقْتَلَ قَضَاءُ اللَّهِ وَرَسُولِهِ ‏.‏ ثَلاَثَ مَرَّاتٍ فَأَمَرَ بِهِ فَقُتِلَ ثُمَّ تَذَاكَرَا قِيَامَ اللَّيْلِ فَقَالَ أَحَدُهُمَا مُعَاذُ بْنُ جَبَلٍ أَمَّا أَنَا فَأَنَامُ وَأَقُومُ - أَوْ أَقُومُ وَأَنَامُ - وَأَرْجُو فِي نَوْمَتِي مَا أَرْجُو فِي قَوْمَتِي ‏.‏\hadithno{4354}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6923) Sahih Muslim (1824)}\hadithtrans{Abu Burdah said on the authority of Abu Musa :I went to the Prophet (ﷺ) while two men who were Ash’ arIs were with me. One of them was on my right and the other on my left side. Bothe of them asked him for employment. The prophet (ﷺ) was silent. He asked : What do you say Abu Musa, or ‘Abd Allah b. Qais (Abu Musa’s name)? I replied: By him who has sent you with truth, they did not inform me of what they had in their hearts, and I did not know that they would ask for an employment. He said : I have the scene before my eyes that he had his toothstick below his lip which receded. He (the prophet) said: We will never or will not put in charge of our work anyone who asks for it. But go, ye, Abu Musa, or ‘Abd Allah b. Qais. He then sent him as a Governor of the Yemen, After him he sent Muadh b. Jabal. When Muadh came to him, he said: come down , and he put a cushion for him. He saw that a man was chained with him. He asked : What is this? He replied: He was a Jew and he accepted Islam. He then converted to his religion, an evil religion. He said: I will not sit until he is killed according to the decision of Allah and his Apostle (ﷺ). He said: Yes, be seated. He said: I will not sit until he is killed according to the decision of Allah and his Apostle (peace be upon him). He said it three times. He then commanded for it and he was killed. Both of them then discussed the question of prayer and vigilance at night. One of them, probably Muadh, said : So far as I am concerned, I sleep and I keep vigilance: I keep vigilance and I sleep: I hope for the same reward for my sleep as for my vigilance}}
\hadithdefcmd{abudawud}{4355}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا الْحِمَّانِيُّ، - يَعْنِي عَبْدَ الْحَمِيدِ بْنَ عَبْدِ الرَّحْمَنِ - عَنْ طَلْحَةَ بْنِ يَحْيَى، وَبُرَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَدِمَ عَلَىَّ مُعَاذٌ وَأَنَا بِالْيَمَنِ، وَرَجُلٌ، كَانَ يَهُودِيًّا فَأَسْلَمَ فَارْتَدَّ عَنِ الإِسْلاَمِ، فَلَمَّا قَدِمَ مُعَاذٌ قَالَ لاَ أَنْزِلُ عَنْ دَابَّتِي حَتَّى يُقْتَلَ ‏.‏ فَقُتِلَ ‏.‏ قَالَ أَحَدُهُمَا وَكَانَ قَدِ اسْتُتِيبَ قَبْلَ ذَلِكَ ‏.‏\hadithno{4355}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Mu'adh ibn Jabal: AbuMusa said: Mu'adh came to me when I was in the Yemen. A man who was Jew embraced Islam and then retreated from Islam. When Mu'adh came, he said: I will not come down from my mount until he is killed. He was then killed. One of them said: He was asked to repent before that}}
\hadithdefcmd{abudawud}{4356}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا حَفْصٌ، حَدَّثَنَا الشَّيْبَانِيُّ، عَنْ أَبِي بُرْدَةَ، بِهَذِهِ الْقِصَّةِ قَالَ فَأُتِيَ أَبُو مُوسَى بِرَجُلٍ قَدِ ارْتَدَّ عَنِ الإِسْلاَمِ، فَدَعَاهُ عِشْرِينَ لَيْلَةً أَوْ قَرِيبًا مِنْهَا فَجَاءَ مُعَاذٌ فَدَعَاهُ فَأَبَى فَضُرِبَ عُنُقُهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ عَنْ أَبِي بُرْدَةَ لَمْ يَذْكُرْ الاِسْتِتَابَةَ وَرَوَاهُ ابْنُ فُضَيْلٍ عَنِ الشَّيْبَانِيِّ عَنْ سَعِيدِ بْنِ أَبِي بُرْدَةَ عَنْ أَبِيهِ عَنْ أَبِي مُوسَى وَلَمْ يَذْكُرْ فِيهِ الاِسْتِتَابَةَ ‏.‏\hadithno{4356}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Burdah said:A man who turned back from Islam was brought to Abu Musa. He invited him to repent for twenty days or about so. Muadh then came and invited him (to embrace Islam) but he refused. So he was beheaded}}
\hadithdefcmd{abudawud}{4357}{حَدَّثَنَا ابْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الْمَسْعُودِيُّ، عَنِ الْقَاسِمِ، بِهَذِهِ الْقِصَّةِ قَالَ فَلَمْ يَنْزِلْ حَتَّى ضُرِبَ عُنُقُهُ وَمَا اسْتَتَابَهُ ‏.‏\hadithno{4357}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{The tradition mention above has also been transmitted by Abu Musa through a different chain if narrators. But there is no mention of demand of repentance}}
\hadithdefcmd{abudawud}{4358}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ الْمَرْوَزِيُّ، حَدَّثَنَا عَلِيُّ بْنُ الْحُسَيْنِ بْنِ وَاقِدٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ عَبْدُ اللَّهِ بْنُ سَعْدِ بْنِ أَبِي سَرْحٍ يَكْتُبُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَأَزَلَّهُ الشَّيْطَانُ فَلَحِقَ بِالْكُفَّارِ فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُقْتَلَ يَوْمَ الْفَتْحِ فَاسْتَجَارَ لَهُ عُثْمَانُ بْنُ عَفَّانَ فَأَجَارَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4358}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: Abdullah ibn AbuSarh used to write (the revelation) for the Messenger of Allah (ﷺ). Satan made him slip, and he joined the infidels. The Messenger of Allah (ﷺ) commanded to kill him on the day of Conquest (of Mecca). Uthman ibn Affan sought protection for him. The Messenger of Allah (ﷺ) gave him protection}}
\hadithdefcmd{abudawud}{4359}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَحْمَدُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا أَسْبَاطُ بْنُ نَصْرٍ، قَالَ زَعَمَ السُّدِّيُّ عَنْ مُصْعَبِ بْنِ سَعْدٍ، عَنْ سَعْدٍ، قَالَ لَمَّا كَانَ يَوْمُ فَتْحِ مَكَّةَ اخْتَبَأَ عَبْدُ اللَّهِ بْنُ سَعْدِ بْنِ أَبِي سَرْحٍ عِنْدَ عُثْمَانَ بْنِ عَفَّانَ فَجَاءَ بِهِ حَتَّى أَوْقَفَهُ عَلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ بَايِعْ عَبْدَ اللَّهِ ‏.‏ فَرَفَعَ رَأْسَهُ فَنَظَرَ إِلَيْهِ ثَلاَثًا كُلُّ ذَلِكَ يَأْبَى فَبَايَعَهُ بَعْدَ ثَلاَثٍ ثُمَّ أَقْبَلَ عَلَى أَصْحَابِهِ فَقَالَ ‏"‏ أَمَا كَانَ فِيكُمْ رَجُلٌ رَشِيدٌ يَقُومُ إِلَى هَذَا حَيْثُ رَآنِي كَفَفْتُ يَدِي عَنْ بَيْعَتِهِ فَيَقْتُلَهُ ‏"‏ ‏.‏ فَقَالُوا مَا نَدْرِي يَا رَسُولَ اللَّهِ مَا فِي نَفْسِكَ أَلاَّ أَوْمَأْتَ إِلَيْنَا بِعَيْنِكَ قَالَ ‏"‏ إِنَّهُ لاَ يَنْبَغِي لِنَبِيٍّ أَنْ تَكُونَ لَهُ خَائِنَةُ الأَعْيُنِ ‏"‏ ‏.‏\hadithno{4359}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Sa'd ibn AbuWaqqas: On the day of the conquest of Mecca, Abdullah ibn Sa'd ibn AbuSarh hid himself with Uthman ibn Affan. He brought him and made him stand before the Prophet (ﷺ), and said: Accept the allegiance of Abdullah, Messenger of Allah! He raised his head and looked at him three times, refusing him each time, but accepted his allegiance after the third time. Then turning to his companions, he said: Was not there a wise man among you who would stand up to him when he saw that I had withheld my hand from accepting his allegiance, and kill him? They said: We did not know what you had in your heart, Messenger of Allah! Why did you not give us a signal with your eye? He said: It is not advisable for a Prophet to play deceptive tricks with the eyes}}
\hadithdefcmd{abudawud}{4360}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي إِسْحَاقَ، عَنِ الشَّعْبِيِّ، عَنْ جَرِيرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِذَا أَبَقَ الْعَبْدُ إِلَى الشِّرْكِ فَقَدْ حَلَّ دَمُهُ ‏"‏ ‏.‏\hadithno{4360}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Jarir reported the prophet (ﷺ) as saying:When a slave runs away and reverts to polytheism, he may lawfully be killed}}
\hadithdefcmd{abudawud}{4361}{حَدَّثَنَا عَبَّادُ بْنُ مُوسَى الْخُتَّلِيُّ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ الْمَدَنِيُّ، عَنْ إِسْرَائِيلَ، عَنْ عُثْمَانَ الشَّحَّامِ، عَنْ عِكْرِمَةَ، قَالَ حَدَّثَنَا ابْنُ عَبَّاسٍ، أَنَّ أَعْمَى، كَانَتْ لَهُ أُمُّ وَلَدٍ تَشْتُمُ النَّبِيَّ صلى الله عليه وسلم وَتَقَعُ فِيهِ فَيَنْهَاهَا فَلاَ تَنْتَهِي وَيَزْجُرُهَا فَلاَ تَنْزَجِرُ - قَالَ - فَلَمَّا كَانَتْ ذَاتَ لَيْلَةٍ جَعَلَتْ تَقَعُ فِي النَّبِيِّ صلى الله عليه وسلم وَتَشْتِمُهُ فَأَخَذَ الْمِغْوَلَ فَوَضَعَهُ فِي بَطْنِهَا وَاتَّكَأَ عَلَيْهَا فَقَتَلَهَا فَوَقَعَ بَيْنَ رِجْلَيْهَا طِفْلٌ فَلَطَخَتْ مَا هُنَاكَ بِالدَّمِ فَلَمَّا أَصْبَحَ ذُكِرَ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَجَمَعَ النَّاسَ فَقَالَ ‏"‏ أَنْشُدُ اللَّهَ رَجُلاً فَعَلَ مَا فَعَلَ لِي عَلَيْهِ حَقٌّ إِلاَّ قَامَ ‏"‏ ‏.‏ فَقَامَ الأَعْمَى يَتَخَطَّى النَّاسَ وَهُوَ يَتَزَلْزَلُ حَتَّى قَعَدَ بَيْنَ يَدَىِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَنَا صَاحِبُهَا كَانَتْ تَشْتِمُكَ وَتَقَعُ فِيكَ فَأَنْهَاهَا فَلاَ تَنْتَهِي وَأَزْجُرُهَا فَلاَ تَنْزَجِرُ وَلِي مِنْهَا ابْنَانِ مِثْلُ اللُّؤْلُؤَتَيْنِ وَكَانَتْ بِي رَفِيقَةً فَلَمَّا كَانَتِ الْبَارِحَةَ جَعَلَتْ تَشْتِمُكَ وَتَقَعُ فِيكَ فَأَخَذْتُ الْمِغْوَلَ فَوَضَعْتُهُ فِي بَطْنِهَا وَاتَّكَأْتُ عَلَيْهَا حَتَّى قَتَلْتُهَا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَلاَ اشْهَدُوا أَنَّ دَمَهَا هَدَرٌ ‏"‏ ‏.‏\hadithno{4361}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah Ibn Abbas: A blind man had a slave-mother who used to abuse the Prophet (ﷺ) and disparage him. He forbade her but she did not stop. He rebuked her but she did not give up her habit. One night she began to slander the Prophet (ﷺ) and abuse him. So he took a dagger, placed it on her belly, pressed it, and killed her. A child who came between her legs was smeared with the blood that was there. When the morning came, the Prophet (ﷺ) was informed about it. He assembled the people and said: I adjure by Allah the man who has done this action and I adjure him by my right to him that he should stand up. Jumping over the necks of the people and trembling the man stood up. He sat before the Prophet (ﷺ) and said: Messenger of Allah! I am her master; she used to abuse you and disparage you. I forbade her, but she did not stop, and I rebuked her, but she did not abandon her habit. I have two sons like pearls from her, and she was my companion. Last night she began to abuse and disparage you. So I took a dagger, put it on her belly and pressed it till I killed her. Thereupon the Prophet (ﷺ) said: Oh be witness, no retaliation is payable for her blood}}
\hadithdefcmd{abudawud}{4362}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَعَبْدُ اللَّهِ بْنُ الْجَرَّاحِ، عَنْ جَرِيرٍ، عَنْ مُغِيرَةَ، عَنِ الشَّعْبِيِّ، عَنْ عَلِيٍّ، رَضِيَ اللَّهُ عَنْهُ أَنَّ يَهُودِيَّةً، كَانَتْ تَشْتِمُ النَّبِيَّ صلى الله عليه وسلم وَتَقَعُ فِيهِ فَخَنَقَهَا رَجُلٌ حَتَّى مَاتَتْ فَأَبْطَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم دَمَهَا ‏.‏\hadithno{4362}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: A Jewess used to abuse the Prophet (ﷺ) and disparage him. A man strangled her till she died. The Messenger of Allah (ﷺ) declared that no recompense was payable for her blood}}
\hadithdefcmd{abudawud}{4363}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ يُونُسَ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ح وَحَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، وَنُصَيْرُ بْنُ الْفَرَجِ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ يَزِيدَ بْنِ زُرَيْعٍ، عَنْ يُونُسَ بْنِ عُبَيْدٍ، عَنْ حُمَيْدِ بْنِ هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُطَرِّفٍ، عَنْ أَبِي بَرْزَةَ، قَالَ كُنْتُ عِنْدَ أَبِي بَكْرٍ رَضِيَ اللَّهُ عَنْهُ فَتَغَيَّظَ عَلَى رَجُلٍ فَاشْتَدَّ عَلَيْهِ فَقُلْتُ تَأْذَنُ لِي يَا خَلِيفَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَضْرِبُ عُنُقَهُ قَالَ فَأَذْهَبَتْ كَلِمَتِي غَضَبَهُ فَقَامَ فَدَخَلَ فَأَرْسَلَ إِلَىَّ فَقَالَ مَا الَّذِي قُلْتَ آنِفًا قُلْتُ ائْذَنْ لِي أَضْرِبْ عُنُقَهُ ‏.‏ قَالَ أَكُنْتَ فَاعِلاً لَوْ أَمَرْتُكَ قُلْتُ نَعَمْ ‏.‏ قَالَ لاَ وَاللَّهِ مَا كَانَتْ لِبَشَرٍ بَعْدَ مُحَمَّدٍ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا لَفْظُ يَزِيدَ قَالَ أَحْمَدُ بْنُ حَنْبَلٍ أَىْ لَمْ يَكُنْ لأَبِي بَكْرٍ أَنْ يَقْتُلَ رَجُلاً إِلاَّ بِإِحْدَى الثَّلاَثِ الَّتِي قَالَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم كُفْرٌ بَعْدَ إِيمَانٍ أَوْ زِنًا بَعْدَ إِحْصَانٍ أَوْ قَتْلُ نَفْسٍ بِغَيْرِ نَفْسٍ وَكَانَ لِلنَّبِيِّ صلى الله عليه وسلم أَنْ يَقْتُلَ ‏.‏\hadithno{4363}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuBakr: AbuBarzah said: I was with AbuBakr. He became angry at a man and uttered hot words. I said: Do you permit me, Caliph of the Messenger of Allah (ﷺ), that I cut off his neck? These words of mine removed his anger; he stood and went in. He then sent for me and said: What did you say just now? I said: (I had said:) Permit me that I cut off his neck. He said: Would you do it if I ordered you? I said: Yes. He said: No, I swear by Allah, this is not allowed for any man after Muhammad (ﷺ). Abu Dawud said: This is Yazid's version. Ahmad bin Hanbal said: That is, Abu Bakr has no powers to slay a man except for three reasons which the Messenger of Allah (ﷺ) had mentioned: disbelief after belief, fornication after marriage, or killing a man without (murdering) any man by him. The Prophet (ﷺ) had powers to kill}}
\hadithdefcmd{abudawud}{4364}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ قَوْمًا، مِنْ عُكْلٍ - أَوْ قَالَ مِنْ عُرَيْنَةَ - قَدِمُوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَاجْتَوَوُا الْمَدِينَةَ فَأَمَرَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم بِلِقَاحٍ وَأَمَرَهُمْ أَنْ يَشْرَبُوا مِنْ أَبْوَالِهَا وَأَلْبَانِهَا فَانْطَلَقُوا فَلَمَّا صَحُّوا قَتَلُوا رَاعِيَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاسْتَاقُوا النَّعَمَ فَبَلَغَ النَّبِيَّ صلى الله عليه وسلم خَبَرُهُمْ مِنْ أَوَّلِ النَّهَارِ فَأَرْسَلَ النَّبِيُّ صلى الله عليه وسلم فِي آثَارِهِمْ فَمَا ارْتَفَعَ النَّهَارُ حَتَّى جِيءَ بِهِمْ فَأَمَرَ بِهِمْ فَقُطِعَتْ أَيْدِيهِمْ وَأَرْجُلُهُمْ وَسُمِّرَ أَعْيُنُهُمْ وَأُلْقُوا فِي الْحَرَّةِ يَسْتَسْقُونَ فَلاَ يُسْقَوْنَ ‏.‏ قَالَ أَبُو قِلاَبَةَ فَهَؤُلاَءِ قَوْمٌ سَرَقُوا وَقَتَلُوا وَكَفَرُوا بَعْدَ إِيمَانِهِمْ وَحَارَبُوا اللَّهَ وَرَسُولَهُ ‏.‏\hadithno{4364}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (233) Sahih Muslim (1671)}\hadithtrans{Anas b. Malik said:Some people of ‘Ukl or ‘Urainah’ came to the Messenger of Allah (ﷺ) and found Madinah unhealthy. So the Messenger of Allah (ﷺ) ordered them to go to the camels (of the sadaqah) and ordered them to drink some of their urine and milk. They went there when they became well, they killed the herdsman of the Messenger of Allah (ﷺ) and drove off the camels. The news about them reached the prophet (ﷺ) early in the morning. So he sent people in pursuit of them, and they were brought when they day had risen high. He ordered and their hands and feet were cut off and nails were drawn into their eyes, and they were thrown out of Harrah. They begged for water but were not supplied water. Abu Qilabah said: They were people who had stolen, killed, apostatized after their faith and fought against Allah and his Apostle (ﷺ)}}
\hadithdefcmd{abudawud}{4365}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَيُّوبَ، بِإِسْنَادِهِ بِهَذَا الْحَدِيثِ قَالَ فِيهِ فَأَمَرَ بِمَسَامِيرَ فَأُحْمِيَتْ فَكَحَلَهُمْ وَقَطَّعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَمَا حَسَمَهُمْ ‏.‏\hadithno{4365}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by the narrator Ayyub through different chain. This version has :So he (the prophet) order nails to be heated and had them blinded with them, and he had their hands and feet cut off, and did not cauterise them to stop the flow of blood}}
\hadithdefcmd{abudawud}{4366}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ بْنِ سُفْيَانَ، قَالَ أَخْبَرَنَا ح، وَحَدَّثَنَا عَمْرُو بْنُ عُثْمَانَ، حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى، - يَعْنِي ابْنَ أَبِي كَثِيرٍ - عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، بِهَذَا الْحَدِيثِ قَالَ فِيهِ فَبَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي طَلَبِهِمْ قَافَةً فَأُتِيَ بِهِمْ ‏.‏ قَالَ فَأَنْزَلَ اللَّهُ تَبَارَكَ وَتَعَالَى فِي ذَلِكَ ‏\{‏ إِنَّمَا جَزَاءُ الَّذِينَ يُحَارِبُونَ اللَّهَ وَرَسُولَهُ وَيَسْعَوْنَ فِي الأَرْضِ فَسَادًا ‏\}‏ الآيَةَ ‏.‏\hadithno{4366}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Anas. B. Malik through a different chain of narrators. This version says :The Messenger of Allah (ﷺ) sent some people who were experts in tracking in pursuit of them and they were brought (to him). Allah , the Exalted, then revealed the verse about it : “ The punishment of those who wage war against Allah and his Apostle and strive for mischief through the land}}
\hadithdefcmd{abudawud}{4367}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا ثَابِتٌ، وَقَتَادَةُ، وَحُمَيْدٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، ذَكَرَ هَذَا الْحَدِيثَ قَالَ أَنَسٌ فَلَقَدْ رَأَيْتُ أَحَدَهُمْ يَكْدِمُ الأَرْضَ بِفِيهِ عَطَشًا حَتَّى مَاتُوا ‏.‏\hadithno{4367}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Anas. B. Malik through a different chain of narrators. This version has :Anas said : I saw one of them biting the earth with this mouth (teeth) on account of thirst and this they died}}
\hadithdefcmd{abudawud}{4368}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ هِشَامٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، بِهَذَا الْحَدِيثِ نَحْوَهُ زَادَ ثُمَّ نَهَى عَنِ الْمُثْلَةِ وَلَمْ يَذْكُرْ مِنْ خِلاَفٍ ‏.‏ وَرَوَاهُ شُعْبَةُ عَنْ قَتَادَةَ وَسَلاَّمِ بْنِ مِسْكِينٍ عَنْ ثَابِتٍ جَمِيعًا عَنْ أَنَسٍ لَمْ يَذْكُرَا مِنْ خِلاَفٍ ‏.‏ وَلَمْ أَجِدْ فِي حَدِيثِ أَحَدٍ قَطَعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ مِنْ خِلاَفٍ ‏.‏ إِلاَّ فِي حَدِيثِ حَمَّادِ بْنِ سَلَمَةَ ‏.‏\hadithno{4368}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1501، 5685)}\hadithtrans{A similar tradition has also been transmitted by Anas bin Malik through a different chain of narrators. This version adds:He then forbade disfiguring. This version does not mention the words “ from opposite sides” . This tradition has been narrated by Shu’bah from Qatadah and Salam bin Miskin from Thabit on the authority of Anas. They did not mention the words “from opposite side”. I did not find these words “their hands and feet were cut off from opposite sides”. In any version except in the version of Hammad bin Salamah}}
\hadithdefcmd{abudawud}{4369}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ أَبِي الزِّنَادِ، عَنْ عَبْدِ اللَّهِ بْنِ عُبَيْدِ اللَّهِ، - قَالَ أَحْمَدُ هُوَ يَعْنِي عَبْدَ اللَّهِ بْنَ عُبَيْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ - عَنِ ابْنِ عُمَرَ أَنَّ نَاسًا أَغَارُوا عَلَى إِبِلِ النَّبِيِّ صلى الله عليه وسلم فَاسْتَاقُوهَا وَارْتَدُّوا عَنِ الإِسْلاَمِ وَقَتَلُوا رَاعِيَ رَسُولِ اللَّهِ صلى الله عليه وسلم مُؤْمِنًا فَبَعَثَ فِي آثَارِهِمْ فَأُخِذُوا فَقَطَعَ أَيْدِيَهُمْ وَأَرْجُلَهُمْ وَسَمَلَ أَعْيُنَهُمْ ‏.‏ قَالَ وَنَزَلَتْ فِيهِمْ آيَةُ الْمُحَارَبَةِ وَهُمُ الَّذِينَ أَخْبَرَ عَنْهُمْ أَنَسُ بْنُ مَالِكٍ الْحَجَّاجَ حِينَ سَأَلَهُ ‏.‏\hadithno{4369}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Umar: Some people raided the camels of the Prophet (ﷺ), drove them off, and apostatised. They killed the herdsman of the Messenger of Allah (ﷺ) who was a believer. He (the Prophet) sent (people) in pursuit of them and they were caught. He had their hands and feet cut off, and their eyes put out. The verse regarding fighting against Allah and His Prophet (ﷺ) was then revealed. These were the people about whom Anas ibn Malik informed al-Hajjaj when he asked him}}
\hadithdefcmd{abudawud}{4370}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي اللَّيْثُ بْنُ سَعْدٍ، عَنْ مُحَمَّدِ بْنِ الْعَجْلاَنِ، عَنْ أَبِي الزِّنَادِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا قَطَعَ الَّذِينَ سَرَقُوا لِقَاحَهُ وَسَمَلَ أَعْيُنَهُمْ بِالنَّارِ عَاتَبَهُ اللَّهُ تَعَالَى فِي ذَلِكَ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏ إِنَّمَا جَزَاءُ الَّذِينَ يُحَارِبُونَ اللَّهَ وَرَسُولَهُ وَيَسْعَوْنَ فِي الأَرْضِ فَسَادًا أَنْ يُقَتَّلُوا أَوْ يُصَلَّبُوا ‏\}‏ الآيَةَ ‏.‏\hadithno{4370}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuzZinad: When the Messenger of Allah (ﷺ) cut off (the hands and feet of) those who had stolen his camels and he had their eyes put out by fire (heated nails), Allah reprimanded him on that (action), and Allah, the Exalted, revealed: "The punishment of those who wage war against Allah and His Apostle and strive with might and main for mischief through the land is execution or crucifixion}}
\hadithdefcmd{abudawud}{4371}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، قَالَ أَخْبَرَنَا ح، وَحَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، قَالَ كَانَ هَذَا قَبْلَ أَنْ تَنْزِلَ الْحُدُودُ يَعْنِي حَدِيثَ أَنَسٍ ‏.‏\hadithno{4371}\hadithgrade{Al-Albani: Daif Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5686)}\hadithtrans{Muhammad bin Sirin said :This happened before the prescribed punishments(hudud) were revealed, meaning the tradition of Anas}}
\hadithdefcmd{abudawud}{4372}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ ثَابِتٍ، حَدَّثَنَا عَلِيُّ بْنُ حُسَيْنٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏\{‏ إِنَّمَا جَزَاءُ الَّذِينَ يُحَارِبُونَ اللَّهَ وَرَسُولَهُ وَيَسْعَوْنَ فِي الأَرْضِ فَسَادًا أَنْ يُقَتَّلُوا أَوْ يُصَلَّبُوا أَوْ تُقَطَّعَ أَيْدِيهِمْ وَأَرْجُلُهُمْ مِنْ خِلاَفٍ أَوْ يُنْفَوْا مِنَ الأَرْضِ ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ غَفُورٌ رَحِيمٌ ‏\}‏ نَزَلَتْ هَذِهِ الآيَةُ فِي الْمُشْرِكِينَ فَمَنْ تَابَ مِنْهُمْ قَبْلَ أَنْ يُقْدَرَ عَلَيْهِ لَمْ يَمْنَعْهُ ذَلِكَ أَنْ يُقَامَ فِيهِ الْحَدُّ الَّذِي أَصَابَهُ ‏.‏\hadithno{4372}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The verse "The punishment of those who wage war against Allah and His Apostle, and strive with might and main for mischief through the land is execution, or crucifixion, or the cutting off of hands and feet from opposite side or exile from the land...most merciful" was revealed about polytheists. If any of them repents before they are arrested, it does not prevent from inflicting on him the prescribed punishment which he deserves}}
\hadithdefcmd{abudawud}{4373}{حَدَّثَنَا يَزِيدُ بْنُ خَالِدِ بْنِ عَبْدِ اللَّهِ بْنِ مَوْهَبٍ الْهَمْدَانِيُّ، قَالَ حَدَّثَنِي ح، وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ الثَّقَفِيُّ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ قُرَيْشًا، أَهَمَّهُمْ شَأْنُ الْمَرْأَةِ الْمَخْزُومِيَّةِ الَّتِي سَرَقَتْ فَقَالُوا مَنْ يُكَلِّمُ فِيهَا تَعْنِي رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالُوا وَمَنْ يَجْتَرِئُ إِلاَّ أُسَامَةُ بْنُ زَيْدٍ حِبُّ رَسُولِ اللَّهِ صلى الله عليه وسلم فَكَلَّمَهُ أُسَامَةُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أُسَامَةُ أَتَشْفَعُ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ ‏"‏ ‏.‏ ثُمَّ قَامَ فَاخْتَطَبَ فَقَالَ ‏"‏ إِنَّمَا هَلَكَ الَّذِينَ مِنْ قَبْلِكُمْ أَنَّهُمْ كَانُوا إِذَا سَرَقَ فِيهِمُ الشَّرِيفُ تَرَكُوهُ وَإِذَا سَرَقَ فِيهِمُ الضَّعِيفُ أَقَامُوا عَلَيْهِ الْحَدَّ وَايْمُ اللَّهِ لَوْ أَنَّ فَاطِمَةَ بِنْتَ مُحَمَّدٍ سَرَقَتْ لَقَطَعْتُ يَدَهَا ‏"‏ ‏.‏\hadithno{4373}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3732) Sahih Muslim (1688)}\hadithtrans{‘A’ishah said:The Quraish were anxious about the Makhzumi woman who had committed theft, They said : Who will speak to the Messenger of Allah(ﷺ) about her ? Then they said: Who will be bold enough for it but Uasmah bin Zaid, the prophet’s (ﷺ) friend! So Usamah spoke to him, and the Messenger of Allah(ﷺ) said : Are you interceding regarding one of the punishments prescribed by Allah ? He then got up and gave an address, saying : What destroyed your predecessors was just that when a person of rank among them committed a theft, They left him alone , and when a weak one of them committed a theft, they inflicted the prescribed punishment on him . I swear by Allah that if Fatimah daughter of Muhammad should steal, I would have her hand cut off}}
\hadithdefcmd{abudawud}{4374}{حَدَّثَنَا عَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ كَانَتِ امْرَأَةٌ مَخْزُومِيَّةٌ تَسْتَعِيرُ الْمَتَاعَ وَتَجْحَدُهُ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم بِقَطْعِ يَدِهَا وَقَصَّ نَحْوَ حَدِيثِ اللَّيْثِ قَالَ فَقَطَعَ النَّبِيُّ صلى الله عليه وسلم يَدَهَا ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى ابْنُ وَهْبٍ هَذَا الْحَدِيثَ عَنْ يُونُسَ عَنِ الزُّهْرِيِّ وَقَالَ فِيهِ كَمَا قَالَ اللَّيْثُ إِنَّ امْرَأَةً سَرَقَتْ فِي عَهْدِ النَّبِيِّ صلى الله عليه وسلم فِي غَزْوَةِ الْفَتْحِ ‏.‏ وَرَوَاهُ اللَّيْثُ عَنْ يُونُسَ عَنِ ابْنِ شِهَابٍ بِإِسْنَادِهِ فَقَالَ اسْتَعَارَتِ امْرَأَةٌ ‏.‏ وَرَوَى مَسْعُودُ بْنُ الأَسْوَدِ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا الْخَبَرِ قَالَ سُرِقَتْ قَطِيفَةٌ مِنْ بَيْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ أَبُو الزُّبَيْرِ عَنْ جَابِرٍ أَنَّ امْرَأَةً سَرَقَتْ فَعَاذَتْ بِزَيْنَبَ بِنْتِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{4374}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3475، 3732) Sahih Muslim (1688)}\hadithtrans{’A’ishah said:A Makhzumi woman used to borrow goods and deny having received them, so the prophet (ﷺ) gave orders that her hand should be cut off. The narrator than transmitted the rest of the tradition like that of al-laith, saying : So the prophet (ﷺ) had her hand cut off. Abu dawud said: Ibn Wahb transmitted this tradition from Yunus on the authority of al-Zuhri, and in this version he said al-Laith has said: A woman committed theft during the lifetime of the Prophet (ﷺ) on the occasion of the Conquest (of Mecca). It has been transmitted by al-Laith from Yunus on the authority of Ibn Shihab through his chain of narrators. He said in this version: A woman borrowed goods. Mas'ud bin al-Aswad also transmitted a similar tradition from the Prophet (ﷺ) and said: A velvet was stolen from the house of the Messenger of Allah (ﷺ). Abu Dawud said: Abu al-Zubair reported on the authority of Jabir: A woman committed theft and took refuge with Zainab daughter of Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{4375}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، وَمُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، قَالاَ أَخْبَرَنَا ابْنُ أَبِي فُدَيْكٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ زَيْدٍ، - نَسَبَهُ جَعْفَرٌ إِلَى سَعِيدِ بْنِ زَيْدِ بْنِ عَمْرِو بْنِ نُفَيْلٍ - عَنْ مُحَمَّدِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَقِيلُوا ذَوِي الْهَيْئَاتِ عَثَرَاتِهِمْ إِلاَّ الْحُدُودَ ‏"‏ ‏.‏\hadithno{4375}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) Said: Forgive the people of good qualities their slips, but not faults to which prescribed penalties apply}}
\hadithdefcmd{abudawud}{4376}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، قَالَ سَمِعْتُ ابْنَ جُرَيْجٍ، يُحَدِّثُ عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تَعَافَوُا الْحُدُودَ فِيمَا بَيْنَكُمْ فَمَا بَلَغَنِي مِنْ حَدٍّ فَقَدْ وَجَبَ ‏"‏ ‏.‏\hadithno{4376}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Prophet (ﷺ) said: Forgive the infliction of prescribed penalties among yourselves, for any prescribed penalty of which I hear must be carried out}}
\hadithdefcmd{abudawud}{4377}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ يَزِيدَ بْنِ نُعَيْمٍ، عَنْ أَبِيهِ، أَنَّ مَاعِزًا، أَتَى النَّبِيَّ صلى الله عليه وسلم فَأَقَرَّ عِنْدَهُ أَرْبَعَ مَرَّاتٍ فَأَمَرَ بِرَجْمِهِ وَقَالَ لِهَزَّالٍ ‏ "‏ لَوْ سَتَرْتَهُ بِثَوْبِكَ كَانَ خَيْرًا لَكَ ‏"‏ ‏.‏\hadithno{4377}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Nu'aym: Ma'iz came to the Prophet (ﷺ) and admitted (having committed adultery) four times in his presence so he ordered him to be stoned to death, but said to Huzzal: If you had covered him with your garment, it would have been better for you}}
\hadithdefcmd{abudawud}{4378}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ الْمُنْكَدِرِ، أَنَّ هَزَّالاً، أَمَرَ مَاعِزًا أَنْ يَأْتِيَ النَّبِيَّ صلى الله عليه وسلم فَيُخْبِرَهُ ‏.‏\hadithno{4378}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Ibn al-Muakadir said:Huzzal had ordered Ma’iz to go to the prophet (ﷺ) and tell him(about his having committed adultery)}}
\hadithdefcmd{abudawud}{4379}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا الْفِرْيَابِيُّ، حَدَّثَنَا إِسْرَائِيلُ، حَدَّثَنَا سِمَاكُ بْنُ حَرْبٍ، عَنْ عَلْقَمَةَ بْنِ وَائِلٍ، عَنْ أَبِيهِ، أَنَّ امْرَأَةً، خَرَجَتْ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم تُرِيدُ الصَّلاَةَ فَتَلَقَّاهَا رَجُلٌ فَتَجَلَّلَهَا فَقَضَى حَاجَتَهُ مِنْهَا فَصَاحَتْ وَانْطَلَقَ فَمَرَّ عَلَيْهَا رَجُلٌ فَقَالَتْ إِنَّ ذَاكَ فَعَلَ بِي كَذَا وَكَذَا وَمَرَّتْ عِصَابَةٌ مِنَ الْمُهَاجِرِينَ فَقَالَتْ إِنَّ ذَلِكَ الرَّجُلَ فَعَلَ بِي كَذَا وَكَذَا ‏.‏ فَانْطَلَقُوا فَأَخَذُوا الرَّجُلَ الَّذِي ظَنَّتْ أَنَّهُ وَقَعَ عَلَيْهَا فَأَتَوْهَا بِهِ فَقَالَتْ نَعَمْ هُوَ هَذَا ‏.‏ فَأَتَوْا بِهِ النَّبِيَّ صلى الله عليه وسلم فَلَمَّا أَمَرَ بِهِ قَامَ صَاحِبُهَا الَّذِي وَقَعَ عَلَيْهَا فَقَالَ يَا رَسُولَ اللَّهِ أَنَا صَاحِبُهَا ‏.‏ فَقَالَ ‏"‏ اذْهَبِي فَقَدْ غَفَرَ اللَّهُ لَكِ ‏"‏ ‏.‏ وَقَالَ لِلرَّجُلِ قَوْلاً حَسَنًا ‏.‏ قَالَ أَبُو دَاوُدَ يَعْنِي الرَّجُلَ الْمَأْخُوذَ وَقَالَ لِلرَّجُلِ الَّذِي وَقَعَ عَلَيْهَا ‏"‏ ارْجُمُوهُ ‏"‏ ‏.‏ فَقَالَ ‏"‏ لَقَدْ تَابَ تَوْبَةً لَوْ تَابَهَا أَهْلُ الْمَدِينَةِ لَقُبِلَ مِنْهُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ أَسْبَاطُ بْنُ نَصْرٍ أَيْضًا عَنْ سِمَاكٍ ‏.‏\hadithno{4379}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Wa'il ibn Hujr: When a woman went out in the time of the Prophet (ﷺ) for prayer, a man attacked her and overpowered (raped) her. She shouted and he went off, and when a man came by, she said: That (man) did such and such to me. And when a company of the Emigrants came by, she said: That man did such and such to me. They went and seized the man whom they thought had had intercourse with her and brought him to her. She said: Yes, this is he. Then they brought him to the Messenger of Allah (ﷺ). When he (the Prophet) was about to pass sentence, the man who (actually) had assaulted her stood up and said: Messenger of Allah, I am the man who did it to her. He (the Prophet) said to her: Go away, for Allah has forgiven you. But he told the man some good words (AbuDawud said: meaning the man who was seized), and of the man who had had intercourse with her, he said: Stone him to death. He also said: He has repented to such an extent that if the people of Medina had repented similarly, it would have been accepted from them. Abu Dawud said: Asbat bin Nasr has also transmitted it from Simak}}
\hadithdefcmd{abudawud}{4380}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَبِي الْمُنْذِرِ، مَوْلَى أَبِي ذَرٍّ عَنْ أَبِي أُمَيَّةَ الْمَخْزُومِيِّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أُتِيَ بِلِصٍّ قَدِ اعْتَرَفَ اعْتِرَافًا وَلَمْ يُوجَدْ مَعَهُ مَتَاعٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا إِخَالُكَ سَرَقْتَ ‏"‏ ‏.‏ قَالَ بَلَى ‏.‏ فَأَعَادَ عَلَيْهِ مَرَّتَيْنِ أَوْ ثَلاَثًا فَأَمَرَ بِهِ فَقُطِعَ وَجِيءَ بِهِ فَقَالَ ‏"‏ اسْتَغْفِرِ اللَّهَ وَتُبْ إِلَيْهِ ‏"‏ ‏.‏ فَقَالَ أَسْتَغْفِرُ اللَّهَ وَأَتُوبُ إِلَيْهِ فَقَالَ ‏"‏ اللَّهُمَّ تُبْ عَلَيْهِ ‏"‏ ‏.‏ ثَلاَثًا ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ عَمْرُو بْنُ عَاصِمٍ عَنْ هَمَّامٍ عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ قَالَ عَنْ أَبِي أُمَيَّةَ رَجُلٍ مِنَ الأَنْصَارِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{4380}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuUmayyah al-Makhzumi: A thief who had accepted (having committed theft) was brought to the Prophet (ﷺ), but no good were found with him. The Messenger of Allah (ﷺ), said to him: I do not think you have stolen. He said: Yes, I have. He repeated it twice or thrice. So he gave orders. His hand was cut off and he was then brought to him. He said: Ask Allah's pardon and turn to Him in repentance. He said: I ask Allah's pardon and turn to Him in repentance. He (the Prophet) then said: O Allah, accept his repentance. Abu Dawud said: It has been transmitted by 'Amr b. Asim, from Hammam, from Ishaq b. 'Abd Allah from Abu Ummayyah, a man of the Ansar from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{4381}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا عُمَرُ بْنُ عَبْدِ الْوَاحِدِ، عَنِ الأَوْزَاعِيِّ، قَالَ حَدَّثَنِي أَبُو عَمَّارٍ، حَدَّثَنِي أَبُو أُمَامَةَ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَصَبْتُ حَدًّا فَأَقِمْهُ عَلَىَّ ‏.‏ قَالَ ‏"‏ تَوَضَّأْتَ حِينَ أَقْبَلْتَ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ هَلْ صَلَّيْتَ مَعَنَا حِينَ صَلَّيْنَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ اذْهَبْ فَإِنَّ اللَّهَ تَعَالَى قَدْ عَفَا عَنْكَ ‏"‏ ‏.‏\hadithno{4381}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (2765)}\hadithtrans{Abu ‘Umamah said :A man came to the prophet (ﷺ) and said : Messenger of Allah ! I have committed a crime which involves prescribed punishment so inflict it on me . He said : Have you not performed ablution when you came? He said : Yes, He said: Have you not prayed with us when we prayed ? He said : Yes .He then said : Go off, for Allah, the Exalted, forgave you}}
\hadithdefcmd{abudawud}{4382}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ نَجْدَةَ، حَدَّثَنَا بَقِيَّةُ، حَدَّثَنَا صَفْوَانُ، حَدَّثَنَا أَزْهَرُ بْنُ عَبْدِ اللَّهِ الْحَرَازِيُّ، أَنَّ قَوْمًا، مِنَ الْكَلاَعِيِّينَ سُرِقَ لَهُمْ مَتَاعٌ فَاتَّهَمُوا أُنَاسًا مِنَ الْحَاكَةِ فَأَتَوُا النُّعْمَانَ بْنَ بَشِيرٍ صَاحِبَ النَّبِيِّ صلى الله عليه وسلم فَحَبَسَهُمْ أَيَّامًا ثُمَّ خَلَّى سَبِيلَهُمْ فَأَتَوُا النُّعْمَانَ فَقَالُوا خَلَّيْتَ سَبِيلَهُمْ بِغَيْرِ ضَرْبٍ وَلاَ امْتِحَانٍ ‏.‏ فَقَالَ النُّعْمَانُ مَا شِئْتُمْ إِنْ شِئْتُمْ أَنْ أَضْرِبَهُمْ فَإِنْ خَرَجَ مَتَاعُكُمْ فَذَاكَ وَإِلاَّ أَخَذْتُ مِنْ ظُهُورِكُمْ مِثْلَ مَا أَخَذْتُ مِنْ ظُهُورِهِمْ ‏.‏ فَقَالُوا هَذَا حُكْمُكَ فَقَالَ هَذَا حُكْمُ اللَّهِ وَحُكْمُ رَسُولِهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو دَاوُدَ إِنَّمَا أَرْهَبَهُمْ بِهَذَا الْقَوْلِ أَىْ لاَ يَجِبُ الضَّرْبُ إِلاَّ بَعْدَ الاِعْتِرَافِ ‏.‏\hadithno{4382}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Azhar ibn Abdullah al-Harari said:Some goods of the people of Kila' were stolen. They accused some men of the weavers (of theft). They came to an-Nu'man ibn Bashir, the companion of the Prophet (ﷺ). He confined them for some days and then set them free. They came to an-Nu'man and said: You have set them free without beating and investigation. An-Nu'man said: What do you want? You want me to beat them. If your goods are found with them, then it is all right; otherwise, I shall take (retaliation) from your back as I have taken from their backs. They asked: Is this your decision? He said: This is the decision of Allah and His Apostle (ﷺ). Abu Dawud said: By this statement he frightened them ; that is, beating is not necessary except after acknowledgement}}
\hadithdefcmd{abudawud}{4383}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، قَالَ سَمِعْتُهُ مِنْهُ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقْطَعُ فِي رُبْعِ دِينَارٍ فَصَاعِدًا ‏.‏\hadithno{4383}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6789) Sahih Muslim (1684)}\hadithtrans{‘A’ishah said:The prophet (ﷺ) used to cut off a thief’s hand for a quarter of a dinar and upwards}}
\hadithdefcmd{abudawud}{4384}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، وَوَهْبُ بْنُ بَيَانٍ، قَالاَ حَدَّثَنَا ح، وَحَدَّثَنَا ابْنُ السَّرْحِ، قَالَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، وَعَمْرَةَ، عَنْ عَائِشَةَ، رضى الله عنها عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تُقْطَعُ يَدُ السَّارِقِ فِي رُبْعِ دِينَارٍ فَصَاعِدًا ‏"‏ ‏.‏ قَالَ أَحْمَدُ بْنُ صَالِحٍ الْقَطْعُ فِي رُبْعِ دِينَارٍ فَصَاعِدًا ‏.‏\hadithno{4384}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6790) Sahih Muslim (1684)}\hadithtrans{‘A’ishah reported the prophet (ﷺ) as saying :A thief’s hand should be cut off for a quarter of a dinar and upwards. Ahmed b. Salih said: The amputation (of a thief’s hand) is for a quarter of a dinar and upwards}}
\hadithdefcmd{abudawud}{4385}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَطَعَ فِي مِجَنٍّ ثَمَنُهُ ثَلاَثَةُ دَرَاهِمَ ‏.‏\hadithno{4385}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6795) Sahih Muslim (1686)}\hadithtrans{Ibn ‘Umar’ said:The Messenger of Allah (ﷺ) had thief’s hand cut off for a shield worth three dirhams}}
\hadithdefcmd{abudawud}{4386}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي إِسْمَاعِيلُ بْنُ أُمَيَّةَ، أَنَّ نَافِعًا، مَوْلَى عَبْدِ اللَّهِ بْنِ عُمَرَ حَدَّثَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ حَدَّثَهُمْ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَطَعَ يَدَ رَجُلٍ سَرَقَ تُرْسًا مِنْ صُفَّةِ النِّسَاءِ ثَمَنُهُ ثَلاَثَةُ دَرَاهِمَ ‏.‏\hadithno{4386}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1686)}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) had a man's hand cut off who had stolen from the place reserved for women a shield whose price was three dirhams}}
\hadithdefcmd{abudawud}{4387}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ أَبِي السَّرِيِّ الْعَسْقَلاَنِيُّ، - وَهَذَا لَفْظُهُ وَهُوَ أَتَمُّ - قَالاَ حَدَّثَنَا ابْنُ نُمَيْرٍ عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ عَنْ أَيُّوبَ بْنِ مُوسَى عَنْ عَطَاءٍ عَنِ ابْنِ عَبَّاسٍ قَالَ قَطَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَ رَجُلٍ فِي مِجَنٍّ قِيمَتُهُ دِينَارٌ أَوْ عَشْرَةُ دَرَاهِمَ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ مُحَمَّدُ بْنُ سَلَمَةَ وَسَعْدَانُ بْنُ يَحْيَى عَنِ ابْنِ إِسْحَاقَ بِإِسْنَادِهِ ‏.‏\hadithno{4387}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) had a man's hand cut off for (stealing) a shield whose price was a dinar or ten dirhams. Abu Dawud said: Muhammad bin Salamah and Sa'dan bin Yahya have transmitted it from Ibn Ishaq through his chain of narrators}}
\hadithdefcmd{abudawud}{4388}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، أَنَّ عَبْدًا، سَرَقَ وَدِيًّا مِنْ حَائِطِ رَجُلٍ فَغَرَسَهُ فِي حَائِطِ سَيِّدِهِ فَخَرَجَ صَاحِبُ الْوَدِيِّ يَلْتَمِسُ وَدِيَّهُ فَوَجَدَهُ فَاسْتَعْدَى عَلَى الْعَبْدِ مَرْوَانَ بْنَ الْحَكَمِ وَهُوَ أَمِيرُ الْمَدِينَةِ يَوْمَئِذٍ فَسَجَنَ مَرْوَانُ الْعَبْدَ وَأَرَادَ قَطْعَ يَدِهِ فَانْطَلَقَ سَيِّدُ الْعَبْدِ إِلَى رَافِعِ بْنِ خَدِيجٍ فَسَأَلَهُ عَنْ ذَلِكَ فَأَخْبَرَهُ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ إِنَّ مَرْوَانَ أَخَذَ غُلاَمِي وَهُوَ يُرِيدُ قَطْعَ يَدِهِ وَأَنَا أُحِبُّ أَنْ تَمْشِيَ مَعِي إِلَيْهِ فَتُخْبِرَهُ بِالَّذِي سَمِعْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَشَى مَعَهُ رَافِعُ بْنُ خَدِيجٍ حَتَّى أَتَى مَرْوَانَ بْنَ الْحَكَمِ فَقَالَ لَهُ رَافِعٌ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ قَطْعَ فِي ثَمَرٍ وَلاَ كَثَرٍ ‏"‏ ‏.‏ فَأَمَرَ مَرْوَانُ بِالْعَبْدِ فَأُرْسِلَ ‏.‏ قَالَ أَبُو دَاوُدَ الْكَثَرُ الْجُمَّارُ ‏.‏\hadithno{4388}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Rafi' ibn Khadij: Muhammad ibn Yahya ibn Hibban said: A slave stole a plant of a palm-tree from the orchard of a man and planted it in the orchard of his master. The owner of the plant went out in search of the plant and he found it. He solicited help against the slave from Marwan ibn al-Hakam who was the Governor of Medina at that time. Marwan confined the slave and intended to cut off his hand. The slave's master went to Rafi' ibn Khadij and asked him about it. He told him that he had heard the Messenger of Allah (ﷺ) say: The hand is not to be cut off for taking fruit or the pith of the palm-tree. The man then said: Marwan has seized my slave and wants to cut off his hand. I wish you to go with me to him and tell him that which you have heard from the Messenger of Allah (ﷺ). So Rafi' ibn Khadij went with him and came to Marwan ibn al-Hakam. Rafi' said to him: I heard the Messenger of Allah (ﷺ) say: The hand is not to be cut off for taking fruit or the pith of the palm-tree. So Marwan gave orders to release the slave and then he was released. Abu Dawud said: Kathar means pith of the palm-tree}}
\hadithdefcmd{abudawud}{4389}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا يَحْيَى، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، بِهَذَا الْحَدِيثِ قَالَ فَجَلَدَهُ مَرْوَانُ جَلَدَاتٍ وَخَلَّى سَبِيلَهُ ‏.‏\hadithno{4389}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Sahih}\hadithtrans{This tradition has also been transmitted by Muhammad bin Yahya bin Hibban through a different chain of narrators. This version adds :Marwan gave him some lashes and let him go}}
\hadithdefcmd{abudawud}{4390}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ سُئِلَ عَنِ الثَّمَرِ الْمُعَلَّقِ فَقَالَ ‏ "‏ مَنْ أَصَابَ بِفِيهِ مِنْ ذِي حَاجَةٍ غَيْرَ مُتَّخِذٍ خُبْنَةً فَلاَ شَىْءَ عَلَيْهِ وَمَنْ خَرَجَ بِشَىْءٍ مِنْهُ فَعَلَيْهِ غَرَامَةُ مِثْلَيْهِ وَالْعُقُوبَةُ وَمَنْ سَرَقَ مِنْهُ شَيْئًا بَعْدَ أَنْ يُئْوِيَهُ الْجَرِينُ فَبَلَغَ ثَمَنَ الْمِجَنِّ فَعَلَيْهِ الْقَطْعُ وَمَنْ سَرَقَ دُونَ ذَلِكَ فَعَلَيْهِ غَرَامَةُ مِثْلَيْهِ وَالْعُقُوبَةُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الْجَرِينُ الْجُوخَانُ ‏.‏\hadithno{4390}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: The Messenger of Allah (ﷺ) was asked about fruit which was bung up and said: If a needy person takes some with his mouth and does not take a supply away in his garment, there is nothing on him, but he who carries any of it is to be fined twice the value and punished, and he who steals any of it after it has been put in the place where dates are dried to have his hand cut off if their value reaches the value of a shield. If he steals a thing less in value than it, he is to be find twice the value and punished. Abu Dawud said: Jarin means the place where dates are dried}}
\hadithdefcmd{abudawud}{4391}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ قَالَ أَبُو الزُّبَيْرِ قَالَ جَابِرُ بْنُ عَبْدِ اللَّهِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ عَلَى الْمُنْتَهِبِ قَطْعٌ وَمَنِ انْتَهَبَ نُهْبَةً مَشْهُورَةً فَلَيْسَ مِنَّا ‏"‏ ‏.‏\hadithno{4391}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: Cutting of hand is not to be inflicted on one who plunders, but he who plunders conspicuously does not belong to us}}
\hadithdefcmd{abudawud}{4392}{وَبِهَذَا الإِسْنَادِ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ عَلَى الْخَائِنِ قَطْعٌ ‏"‏ ‏.‏\hadithno{4392}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Jabir ibn Abdullah: He also said through this chain: The Messenger of Allah (ﷺ) said: Cutting of the hand is not to be inflicted on one who is treacherous}}
\hadithdefcmd{abudawud}{4393}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ زَادَ ‏ "‏ وَلاَ عَلَى الْمُخْتَلِسِ قَطْعٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَانِ الْحَدِيثَانِ لَمْ يَسْمَعْهُمَا ابْنُ جُرَيْجٍ مِنْ أَبِي الزُّبَيْرِ وَبَلَغَنِي عَنْ أَحْمَدَ بْنِ حَنْبَلٍ أَنَّهُ قَالَ إِنَّمَا سَمِعَهُمَا ابْنُ جُرَيْجٍ مِنْ يَاسِينَ الزَّيَّاتِ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَدْ رَوَاهُمَا الْمُغِيرَةُ بْنُ مُسْلِمٍ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{4393}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Jabir through a different chain of narrators. This version adds :Cutting of the hand is not be inflicted on one who snatches something. Abu Dawud said : Ibn Juraij did not hear these two traditions from Abu al-Zubair, I have been informed by Ahmad. B. Hanbal saving : Ibn Juraij heard them from Yasin al-Zayyat. Aby Dawud said: Al-Mughirah b. Muslim has transmitted it from Abu al-Zubair from Jabir From the prophet(ﷺ)}}
\hadithdefcmd{abudawud}{4394}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عَمْرُو بْنُ حَمَّادِ بْنِ طَلْحَةَ، حَدَّثَنَا أَسْبَاطٌ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ حُمَيْدِ ابْنِ أُخْتِ، صَفْوَانَ عَنْ صَفْوَانَ بْنِ أُمَيَّةَ، قَالَ كُنْتُ نَائِمًا فِي الْمَسْجِدِ عَلَى خَمِيصَةٍ لِي ثَمَنُ ثَلاَثِينَ دِرْهَمًا فَجَاءَ رَجُلٌ فَاخْتَلَسَهَا مِنِّي فَأُخِذَ الرَّجُلُ فَأُتِيَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَمَرَ بِهِ لِيُقْطَعَ ‏.‏ قَالَ فَأَتَيْتُهُ فَقُلْتُ أَنَقْطَعُهُ مِنْ أَجْلِ ثَلاَثِينَ دِرْهَمًا أَنَا أَبِيعُهُ وَأُنْسِئُهُ ثَمَنَهَا قَالَ ‏ "‏ فَهَلاَّ كَانَ هَذَا قَبْلَ أَنْ تَأْتِيَنِي بِهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ زَائِدَةُ عَنْ سِمَاكٍ عَنْ جُعَيْدِ بْنِ جُحَيْرٍ قَالَ نَامَ صَفْوَانُ ‏.‏ وَرَوَاهُ مُجَاهِدٌ وَطَاوُسٌ أَنَّهُ كَانَ نَائِمًا فَجَاءَ سَارِقٌ فَسَرَقَ خَمِيصَةً مِنْ تَحْتِ رَأْسِهِ ‏.‏ وَرَوَاهُ أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ قَالَ فَاسْتَلَّهُ مِنْ تَحْتِ رَأْسِهِ فَاسْتَيْقَظَ فَصَاحَ بِهِ فَأُخِذَ ‏.‏ وَرَوَاهُ الزُّهْرِيُّ عَنْ صَفْوَانَ بْنِ عَبْدِ اللَّهِ قَالَ فَنَامَ فِي الْمَسْجِدِ وَتَوَسَّدَ رِدَاءَهُ فَجَاءَهُ سَارِقٌ فَأَخَذَ رِدَاءَهُ فَأُخِذَ السَّارِقُ فَجِيءَ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{4394}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Safwan bin Umayyah: I was sleeping in the mosque on a cloak mine whose price was thirty dirhams. A man came and pinched it away from me. The man was seized and brought to the Messenger of Allah (ﷺ). He ordered that his hand should be cut off. I came to him and said: Do you cut off only for thirty dirhams ? I sell it to him and make the payment of its price a loan ? He said: Why did you not do so before bringing him to me ? Abu Dawud said: Za'idah has also transmitted it from Simak from Ju'ayd ibn Hujayr. He said: Safwan slept. Mujahid and Tawus said: While he was sleeping a thief came and stole the cloak from beneath his head. The version of AbuSalamah ibn AbdurRahman has: He snatched it away from beneath his head and he awoke. He cried and he (the thief) was seized. Az-Zuhri narrated from Safwan ibn Abdullah. His version has: He slept in the mosque and used his cloak as pillow. A thief came and took his cloak. The thief was seized and brought to the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{4395}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، وَمَخْلَدُ بْنُ خَالِدٍ، - الْمَعْنَى - قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، - قَالَ مَخْلَدٌ عَنْ مَعْمَرٍ، - عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ امْرَأَةً، مَخْزُومِيَّةً كَانَتْ تَسْتَعِيرُ الْمَتَاعَ وَتَجْحَدُهُ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم بِهَا فَقُطِعَتْ يَدُهَا ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ جُوَيْرِيَةُ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ أَوْ عَنْ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ زَادَ فِيهِ وَأَنَّ النَّبِيَّ صلى الله عليه وسلم قَامَ خَطِيبًا فَقَالَ ‏ "‏ هَلْ مِنِ امْرَأَةٍ تَائِبَةٍ إِلَى اللَّهِ عَزَّ وَجَلَّ وَرَسُولِهِ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ وَتِلْكَ شَاهِدَةٌ فَلَمْ تَقُمْ وَلَمْ تَتَكَلَّمْ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ ابْنُ غَنْجٍ عَنْ نَافِعٍ عَنْ صَفِيَّةَ بِنْتِ أَبِي عُبَيْدٍ قَالَ فِيهِ فَشَهِدَ عَلَيْهَا ‏.‏\hadithno{4395}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn ‘Umar said:A Makhzuml woman used to borrow goods and deny having received them, so the prophet (ﷺ) gave orders and her hand was cut off. Abu Dawud said: Juwairiyyah has transmitted it from Nafi from Ibn ‘Umar or from Safiyyah daughter of Abu ‘Ubaid. This version adds: The prophet (ﷺ) got up and gave an address saying : Is there any woman who repents to Allah, the Exalted, and to his Apostle? He said it three times, That( woman) was present there but she did not get up and speak. Ibn Ghunj transmitted it from Nafi from Safiyyah daughter of Abu ‘Ubaid. This version has : He witnessed to her}}
\hadithdefcmd{abudawud}{4396}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا أَبُو صَالِحٍ، عَنِ اللَّيْثِ، قَالَ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ كَانَ عُرْوَةُ يُحَدِّثُ أَنَّ عَائِشَةَ رضى الله عنها قَالَتِ اسْتَعَارَتِ امْرَأَةٌ - تَعْنِي - حُلِيًّا عَلَى أَلْسِنَةِ أُنَاسٍ يُعْرَفُونَ وَلاَ تُعْرَفُ هِيَ فَبَاعَتْهُ فَأُخِذَتْ فَأُتِيَ بِهَا النَّبِيُّ صلى الله عليه وسلم فَأَمَرَ بِقَطْعِ يَدِهَا وَهِيَ الَّتِي شَفَعَ فِيهَا أُسَامَةُ بْنُ زَيْدٍ وَقَالَ فِيهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مَا قَالَ ‏.‏\hadithno{4396}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2648) Sahih Muslim (1688)}\hadithtrans{Narrated Aisha, Ummul Mu'minin: A woman borrowed jewellery through some known persons and she herself was unknown. She then sold them. She was seized and brought to the Prophet (ﷺ). He gave orders that her hand should be cut off. It is this woman about whom Usamah interceded and of her the Messenger of Allah (ﷺ) said whatever he said}}
\hadithdefcmd{abudawud}{4397}{حَدَّثَنَا عَبَّاسُ بْنُ عَبْدِ الْعَظِيمِ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَتِ امْرَأَةٌ مَخْزُومِيَّةٌ تَسْتَعِيرُ الْمَتَاعَ وَتَجْحَدُهُ فَأَمَرَ النَّبِيُّ صلى الله عليه وسلم بِقَطْعِ يَدِهَا وَقَصَّ نَحْوَ حَدِيثِ قُتَيْبَةَ عَنِ اللَّيْثِ عَنِ ابْنِ شِهَابٍ زَادَ فَقَطَعَ النَّبِيُّ صلى الله عليه وسلم يَدَهَا ‏.‏\hadithno{4397}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1688)}\hadithtrans{‘A’ishah said :A Makhzuml woman used to borrow goods and deny having received them. The prophet (ﷺ) gave orders that her hand should be cut off. He (the narrator) then narrated the tradition similar to the one transmitted by Qutaibah from al-Laith from Ibn Shahib. This version adds: The prophet(ﷺ) had her hand cut off}}
\hadithdefcmd{abudawud}{4398}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ حَمَّادٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، رضى الله عنها أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رُفِعَ الْقَلَمُ عَنْ ثَلاَثَةٍ عَنِ النَّائِمِ حَتَّى يَسْتَيْقِظَ وَعَنِ الْمُبْتَلَى حَتَّى يَبْرَأَ وَعَنِ الصَّبِيِّ حَتَّى يَكْبَرَ ‏"‏ ‏.‏\hadithno{4398}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) said: There are three (persons) whose actions are not recorded: a sleeper till he awakes, an idiot till he is restored to reason, and a boy till he reaches puberty}}
\hadithdefcmd{abudawud}{4399}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي ظَبْيَانَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أُتِيَ عُمَرُ بِمَجْنُونَةٍ قَدْ زَنَتْ فَاسْتَشَارَ فِيهَا أُنَاسًا فَأَمَرَ بِهَا عُمَرُ أَنْ تُرْجَمَ فَمُرَّ بِهَا عَلَى عَلِيِّ بْنِ أَبِي طَالِبٍ رِضْوَانُ اللَّهِ عَلَيْهِ فَقَالَ مَا شَأْنُ هَذِهِ قَالُوا مَجْنُونَةُ بَنِي فُلاَنٍ زَنَتْ فَأَمَرَ بِهَا عُمَرُ أَنْ تُرْجَمَ ‏.‏ قَالَ فَقَالَ ارْجِعُوا بِهَا ثُمَّ أَتَاهُ فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ أَمَا عَلِمْتَ أَنَّ الْقَلَمَ قَدْ رُفِعَ عَنْ ثَلاَثَةٍ عَنِ الْمَجْنُونِ حَتَّى يَبْرَأَ وَعَنِ النَّائِمِ حَتَّى يَسْتَيْقِظَ وَعَنِ الصَّبِيِّ حَتَّى يَعْقِلَ قَالَ بَلَى ‏.‏ قَالَ فَمَا بَالُ هَذِهِ تُرْجَمُ قَالَ لاَ شَىْءَ ‏.‏ قَالَ فَأَرْسِلْهَا ‏.‏ قَالَ فَأَرْسَلَهَا ‏.‏ قَالَ فَجَعَلَ يُكَبِّرُ ‏.‏\hadithno{4399}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: Ibn Abbas said: A lunatic woman who had committed adultery was brought to Umar. He consulted the people and ordered that she should be stoned. Ali ibn AbuTalib passed by and said: What is the matter with this (woman)? They said: This is a lunatic woman belonging to a certain family. She has committed adultery. Umar has given orders that she should be stoned. He said: Take her back. He then came to him and said: Commander of the Faithful, do you not know that there are three people whose actions are not recorded: a lunatic till he is restored to reason, a sleeper till he awakes, and a boy till he reaches puberty? He said: Yes. He then asked: Why is it that this woman is being stoned? He said: There is nothing. He then said: Let her go. He (Umar) let her go and began to utter: Allah is most great}}
\hadithdefcmd{abudawud}{4400}{حَدَّثَنَا يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ، نَحْوَهُ وَقَالَ أَيْضًا حَتَّى يَعْقِلَ ‏.‏ وَقَالَ وَعَنِ الْمَجْنُونِ حَتَّى يُفِيقَ ‏.‏ قَالَ فَجَعَلَ عُمَرُ يُكَبِّرُ ‏.‏\hadithno{4400}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{A similar tradition has also been transmitted by al-A’mash through a different chain of narrators. He also said :“... . Till he reaches puberty , and a lunatic till he is restored to consciousness.” ‘Umar then began to utter: Allah is most great}}
\hadithdefcmd{abudawud}{4401}{حَدَّثَنَا ابْنُ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي جَرِيرُ بْنُ حَازِمٍ، عَنْ سُلَيْمَانَ بْنِ مِهْرَانَ، عَنْ أَبِي ظَبْيَانَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مُرَّ عَلَى عَلِيِّ بْنِ أَبِي طَالِبٍ رضى الله عنه بِمَعْنَى عُثْمَانَ ‏.‏ قَالَ أَوَمَا تَذْكُرُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رُفِعَ الْقَلَمُ عَنْ ثَلاَثَةٍ عَنِ الْمَجْنُونِ الْمَغْلُوبِ عَلَى عَقْلِهِ حَتَّى يُفِيقَ وَعَنِ النَّائِمِ حَتَّى يَسْتَيْقِظَ وَعَنِ الصَّبِيِّ حَتَّى يَحْتَلِمَ ‏"‏ ‏.‏ قَالَ صَدَقْتَ قَالَ فَخَلَّى عَنْهَا سَبِيلَهَا ‏.‏\hadithno{4401}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: Ibn Abbas said: A lunatic woman passed by Ali ibn AbuTalib. He then mentioned the rest of the tradition to the same effect as Uthman mentioned. This version has: Do you not remember that the Messenger of Allah (ﷺ) has said: There are three whose actions are not recorded: a lunatic whose mind is deranged till he is restored to consciousness, a sleeper till he awakes, and a boy till he reaches puberty?}}
\hadithdefcmd{abudawud}{4402}{حَدَّثَنَا هَنَّادٌ، عَنْ أَبِي الأَحْوَصِ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، - الْمَعْنَى - عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِي ظَبْيَانَ، - قَالَ هَنَّادٌ - الْجَنْبِيِّ قَالَ أُتِيَ عُمَرُ بِامْرَأَةٍ قَدْ فَجَرَتْ فَأَمَرَ بِرَجْمِهَا فَمَرَّ عَلِيٌّ رضى الله عنه فَأَخَذَهَا فَخَلَّى سَبِيلَهَا فَأُخْبِرَ عُمَرُ قَالَ ادْعُوا لِي عَلِيًّا ‏.‏ فَجَاءَ عَلِيٌّ رضى الله عنه فَقَالَ يَا أَمِيرَ الْمُؤْمِنِينَ لَقَدْ عَلِمْتَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رُفِعَ الْقَلَمُ عَنْ ثَلاَثَةٍ عَنِ الصَّبِيِّ حَتَّى يَبْلُغَ وَعَنِ النَّائِمِ حَتَّى يَسْتَيْقِظَ وَعَنِ الْمَعْتُوهِ حَتَّى يَبْرَأَ ‏"‏ ‏.‏ وَإِنَّ هَذِهِ مَعْتُوهَةُ بَنِي فُلاَنٍ لَعَلَّ الَّذِي أَتَاهَا أَتَاهَا وَهِيَ فِي بَلاَئِهَا ‏.‏ قَالَ فَقَالَ عُمَرُ لاَ أَدْرِي ‏.‏ فَقَالَ عَلِيٌّ عَلَيْهِ السَّلاَمُ وَأَنَا لاَ أَدْرِي ‏.‏\hadithno{4402}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: AbuZubyan said: A woman who had committed adultery was brought to Umar. He gave orders that she should be stoned. Ali passed by just then. He seized her and let her go. Umar was informed of it. He said: Ask Ali to come to me. Ali came to him and said: Commander of the Faithful, you know that the Messenger of Allah (ﷺ) said: There are three (people) whose actions are not recorded: A boy till he reaches puberty, a sleeper till he awakes, a lunatic till he is restored to reason. This is an idiot (mad) woman belonging to the family of so and so. Someone might have done this action with her when she suffered the fit of lunacy. Umar said: I do not know. Ali said: I do not know}}
\hadithdefcmd{abudawud}{4403}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، عَنْ خَالِدٍ، عَنْ أَبِي الضُّحَى، عَنْ عَلِيٍّ، عَلَيْهِ السَّلاَمُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ رُفِعَ الْقَلَمُ عَنْ ثَلاَثَةٍ عَنِ النَّائِمِ حَتَّى يَسْتَيْقِظَ وَعَنِ الصَّبِيِّ حَتَّى يَحْتَلِمَ وَعَنِ الْمَجْنُونِ حَتَّى يَعْقِلَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ابْنُ جُرَيْجٍ عَنِ الْقَاسِمِ بْنِ يَزِيدَ عَنْ عَلِيٍّ رضى الله عنه عَنِ النَّبِيِّ صلى الله عليه وسلم زَادَ فِيهِ ‏"‏ وَالْخَرِفِ ‏"‏ ‏.‏\hadithno{4403}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: The Prophet (ﷺ) said: There are three (persons) whose actions are not recorded: a sleeper till he awakes, a boy till he reaches puberty, and a lunatic till he comes to reason. Abu Dawud said: Ibn Juraij has transmitted it from Al-Qasim b. Yazid on the authority of 'Ali from the Prophet (ﷺ). This version adds: "and an old man who is feeble-minded}}
\hadithdefcmd{abudawud}{4404}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، أَخْبَرَنَا عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ، حَدَّثَنِي عَطِيَّةُ الْقُرَظِيُّ، قَالَ كُنْتُ مِنْ سَبْىِ بَنِي قُرَيْظَةَ فَكَانُوا يَنْظُرُونَ فَمَنْ أَنْبَتَ الشَّعْرَ قُتِلَ وَمَنْ لَمْ يُنْبِتْ لَمْ يُقْتَلْ فَكُنْتُ فِيمَنْ لَمْ يُنْبِتْ ‏.‏\hadithno{4404}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Atiyyah al-Qurazi: I was among the captives of Banu Qurayzah. They (the Companions) examined us, and those who had begun to grow hair (pubes) were killed, and those who had not were not killed. I was among those who had not grown hair}}
\hadithdefcmd{abudawud}{4405}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، بِهَذَا الْحَدِيثِ قَالَ فَكَشَفُوا عَانَتِي فَوَجَدُوهَا لَمْ تَنْبُتْ فَجَعَلُونِي فِي السَّبْىِ ‏.‏\hadithno{4405}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by ‘Abd al- Malik b. ‘Umar through a different chain of narrators. This version has:They uncovered my private parts, and when they found that the hair had not begun to grow they put me among the captives}}
\hadithdefcmd{abudawud}{4406}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم عُرِضَهُ يَوْمَ أُحُدٍ وَهُوَ ابْنُ أَرْبَعَ عَشْرَةَ سَنَةً فَلَمْ يُجِزْهُ وَعُرِضَهُ يَوْمَ الْخَنْدَقِ وَهُوَ ابْنُ خَمْسَ عَشْرَةَ سَنَةً فَأَجَازَهُ ‏.‏\hadithno{4406}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4097) Sahih Muslim (1868)}\hadithtrans{Ibn ‘Umar said:He was presented before the prophet (ﷺ) on the day of Uhd when he was fourteen years old, but he did not allow him (to participate in the battle). He was again presented before him on the day of Khandaq when he was fifteen years old, Then he allowed him}}
\hadithdefcmd{abudawud}{4407}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، قَالَ قَالَ نَافِعٌ حَدَّثْتُ بِهَذَا الْحَدِيثِ، عُمَرَ بْنَ عَبْدِ الْعَزِيزِ فَقَالَ إِنَّ هَذَا الْحَدُّ بَيْنَ الصَّغِيرِ وَالْكَبِيرِ ‏.‏\hadithno{4407}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1868)}\hadithtrans{Nafi ‘said:When I mentioned this tradition to ‘Umar.b.’Abd al-Aziz he said : This prescribed punishment is between the minor and the major}}
\hadithdefcmd{abudawud}{4408}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي حَيْوَةُ بْنُ شُرَيْحٍ، عَنْ عَيَّاشِ بْنِ عَبَّاسٍ الْقِتْبَانِيِّ، عَنْ شُيَيْمِ بْنِ بَيْتَانَ، وَيَزِيدَ بْنِ صُبْحٍ الأَصْبَحِيِّ، عَنْ جُنَادَةَ بْنِ أَبِي أُمَيَّةَ، قَالَ كُنَّا مَعَ بُسْرِ بْنِ أَرْطَاةَ فِي الْبَحْرِ فَأُتِيَ بِسَارِقٍ يُقَالُ لَهُ مِصْدَرٌ قَدْ سَرَقَ بُخْتِيَّةً فَقَالَ قَدْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ تُقْطَعُ الأَيْدِي فِي السَّفَرِ ‏"‏ ‏.‏ وَلَوْلاَ ذَلِكَ لَقَطَعْتُهُ ‏.‏\hadithno{4408}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Busr ibn Artat: Junadah ibn AbuUmayyah said: We were with Busr ibn Artat on the sea (on an expedition). A thief called Misdar who had stolen a bukhti she-camel was brought. He said: I heard the Messenger of Allah (ﷺ) say: Hands are not to be cut off during a warlike expedition. Had it not been so, I would have cut it off}}
\hadithdefcmd{abudawud}{4409}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَبِي عِمْرَانَ، عَنِ الْمُشَعَّثِ بْنِ طَرِيفٍ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَبَا ذَرٍّ ‏"‏ ‏.‏ قُلْتُ لَبَّيْكَ يَا رَسُولَ اللَّهِ وَسَعْدَيْكَ ‏.‏ فَقَالَ ‏"‏ كَيْفَ أَنْتَ إِذَا أَصَابَ النَّاسَ مَوْتٌ يَكُونُ الْبَيْتُ فِيهِ بِالْوَصِيفِ ‏"‏ ‏.‏ يَعْنِي الْقَبْرَ ‏.‏ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ أَوْ مَا خَارَ اللَّهُ لِي وَرَسُولُهُ ‏.‏ قَالَ ‏"‏ عَلَيْكَ بِالصَّبْرِ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ تَصْبِرُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ حَمَّادُ بْنُ أَبِي سُلَيْمَانَ يُقْطَعُ النَّبَّاشُ لأَنَّهُ دَخَلَ عَلَى الْمَيِّتِ بَيْتَهُ ‏.‏\hadithno{4409}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuDharr: The Messenger of Allah (ﷺ) said to me: O AbuDharr: I replied: At your service and at your pleasure, Messenger of Allah! He said: how will you do when death smites people, and a house, meaning a grave, will cost as much as a slave. I said: Allah and His Apostle know best, or he said: What Allah and His Apostle choose for me. He said: Show endurance, or he said: You may show endurance. Abu Dawud said: Hammad b. Abi Sulaiman said: The hand of one who rifles a grave should be cut off because he had entered the deceased's house}}
\hadithdefcmd{abudawud}{4410}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عُبَيْدِ بْنِ عَقِيلٍ الْهِلاَلِيُّ، حَدَّثَنَا جَدِّي، عَنْ مُصْعَبِ بْنِ ثَابِتِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ جِيءَ بِسَارِقٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏"‏ اقْتُلُوهُ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّمَا سَرَقَ ‏.‏ فَقَالَ ‏"‏ اقْطَعُوهُ ‏"‏ ‏.‏ قَالَ فَقُطِعَ ثُمَّ جِيءَ بِهِ الثَّانِيَةَ فَقَالَ ‏"‏ اقْتُلُوهُ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّمَا سَرَقَ ‏.‏ فَقَالَ ‏"‏ اقْطَعُوهُ ‏"‏ ‏.‏ قَالَ فَقُطِعَ ثُمَّ جِيءَ بِهِ الثَّالِثَةَ فَقَالَ ‏"‏ اقْتُلُوهُ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّمَا سَرَقَ ‏.‏ قَالَ ‏"‏ اقْطَعُوهُ ‏"‏ ‏.‏ ثُمَّ أُتِيَ بِهِ الرَّابِعَةَ فَقَالَ ‏"‏ اقْتُلُوهُ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ إِنَّمَا سَرَقَ ‏.‏ قَالَ ‏"‏ اقْطَعُوهُ ‏"‏ ‏.‏ فَأُتِيَ بِهِ الْخَامِسَةَ فَقَالَ ‏"‏ اقْتُلُوهُ ‏"‏ ‏.‏ قَالَ جَابِرٌ فَانْطَلَقْنَا بِهِ فَقَتَلْنَاهُ ثُمَّ اجْتَرَرْنَاهُ فَأَلْقَيْنَاهُ فِي بِئْرٍ وَرَمَيْنَا عَلَيْهِ الْحِجَارَةَ ‏.‏\hadithno{4410}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: A thief was brought to the Prophet (ﷺ). He said: Kill him. The people said: He has committed theft, Messenger of Allah! Then he said: Cut off his hand. So his (right) hand was cut off. He was brought a second time and he said: Kill him. The people said: He has committed theft, Messenger of Allah! Then he said: Cut off his foot. So his (left) foot was cut off. He was brought a third time and he said: Kill him. The people said: He has committed theft, Messenger of Allah! So he said: Cut off his hand. (So his (left) hand was cut off.) He was brought a fourth time and he said: Kill him. The people said: He has committed theft, Messenger of Allah! So he said: Cut off his foot. So his (right) foot was cut off. He was brought a fifth time and he said: Kill him. So we took him away and killed him. We then dragged him and cast him into a well and threw stones over him}}
\hadithdefcmd{abudawud}{4411}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ، حَدَّثَنَا الْحَجَّاجُ، عَنْ مَكْحُولٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مُحَيْرِيزٍ، قَالَ سَأَلْنَا فَضَالَةَ بْنَ عُبَيْدٍ عَنْ تَعْلِيقِ الْيَدِ، فِي الْعُنُقِ لِلسَّارِقِ أَمِنَ السُّنَّةِ هُوَ قَالَ أُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِسَارِقٍ فَقُطِعَتْ يَدُهُ ثُمَّ أُمِرَ بِهَا فَعُلِّقَتْ فِي عُنُقِهِ ‏.‏\hadithno{4411}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abd al-Rahman b. Muhariz said: We asked Fadalah b. 'Ubaid about the hanging the (amputated) hand on the neck of a thief whether it was a sunnan. He said: A thief was brought to the Messenger of Allah (ﷺ) and his hand was cut off. Thereafter he commanded for it, and it was hung on his neck}}
\hadithdefcmd{abudawud}{4412}{حَدَّثَنَا مُوسَى، - يَعْنِي ابْنَ إِسْمَاعِيلَ - حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُمَرَ بْنِ أَبِي سَلَمَةَ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا سَرَقَ الْمَمْلُوكُ فَبِعْهُ وَلَوْ بِنَشٍّ ‏"‏ ‏.‏\hadithno{4412}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) as saying: When a slave steals, sell him, even though it be for half an uqiyah}}
\hadithdefcmd{abudawud}{4413}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ ثَابِتٍ الْمَرْوَزِيُّ، حَدَّثَنِي عَلِيُّ بْنُ الْحُسَيْنِ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏\{‏ وَاللاَّتِي يَأْتِينَ الْفَاحِشَةَ مِنْ نِسَائِكُمْ فَاسْتَشْهِدُوا عَلَيْهِنَّ أَرْبَعَةً مِنْكُمْ فَإِنْ شَهِدُوا فَأَمْسِكُوهُنَّ فِي الْبُيُوتِ حَتَّى يَتَوَفَّاهُنَّ الْمَوْتُ أَوْ يَجْعَلَ اللَّهُ لَهُنَّ سَبِيلاً ‏\}‏ وَذَكَرَ الرَّجُلَ بَعْدَ الْمَرْأَةِ ثُمَّ جَمَعَهُمَا فَقَالَ ‏\{‏ وَاللَّذَانِ يَأْتِيَانِهَا مِنْكُمْ فَآذُوهُمَا فَإِنْ تَابَا وَأَصْلَحَا فَأَعْرِضُوا عَنْهُمَا ‏\}‏ فَنَسَخَ ذَلِكَ بِآيَةِ الْجَلْدِ فَقَالَ ‏\{‏ الزَّانِيَةُ وَالزَّانِي فَاجْلِدُوا كُلَّ وَاحِدٍ مِنْهُمَا مِائَةَ جَلْدَةٍ ‏\}‏ ‏.‏\hadithno{4413}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn ‘Abbas said:The Qur’anic verse goes: “If any of your woman are guilty of lewdness, take the evidence of four (reliable) witnesses from amongst you against them, and if they testify, Confine them to houses until death do chain them or Allah ordains for them some (other) way. Allah then mentioned man after woman and combined them in another verse : “If two men among you are guilty of lewdness, punish them both. If they repent and amend, leave them alone. This command was abrogated by the verse relating to flogging : “The woman and the man guilty of adultery or fornication – flog each of them with one hundred stripes}}
\hadithdefcmd{abudawud}{4414}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ ثَابِتٍ، حَدَّثَنَا مُوسَى، - يَعْنِي ابْنَ مَسْعُودٍ - عَنْ شِبْلٍ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، قَالَ السَّبِيلُ الْحَدُّ قَالَ سُفْيَانُ ‏\{‏ فَآذُوهُمَا ‏\}‏ الْبِكْرَانِ ‏\{‏ فَأَمْسِكُوهُنَّ فِي الْبُيُوتِ ‏\}‏ الثَّيِّبَاتِ ‏.‏\hadithno{4414}\hadithgrade{Al-Albani: Hasan Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Mujahid said:“Apponting a way in the verse (iv.15) means prescribed punishment. Sufiyan said: “Punish them “refers to unmarried, and “confine them to houses” refers to the women who are married}}
\hadithdefcmd{abudawud}{4415}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ حِطَّانَ بْنِ عَبْدِ اللَّهِ الرَّقَاشِيِّ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خُذُوا عَنِّي خُذُوا عَنِّي قَدْ جَعَلَ اللَّهُ لَهُنَّ سَبِيلاً الثَّيِّبُ بِالثَّيِّبِ جَلْدُ مِائَةٍ وَرَمْىٌ بِالْحِجَارَةِ وَالْبِكْرُ بِالْبِكْرِ جَلْدُ مِائَةٍ وَنَفْىُ سَنَةٍ ‏"‏ ‏.‏\hadithno{4415}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1690)}\hadithtrans{‘Ubadah b. al-Samit reported the Messenger of Allah(ﷺ) as sayings:Receive my teachings, receive my teachings. Allah has appointed a way for those women. If the parties have been married, they shall receive a hundred lashes and stoned to death. If the parties are unmarried, they shall receive a hundred lashes and banished for a year}}
\hadithdefcmd{abudawud}{4416}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، وَمُحَمَّدُ بْنُ الصَّبَّاحِ بْنِ سُفْيَانَ، قَالاَ حَدَّثَنَا هُشَيْمٌ، عَنْ مَنْصُورٍ، عَنِ الْحَسَنِ، بِإِسْنَادِ يَحْيَى وَمَعْنَاهُ قَالاَ ‏ "‏ جَلْدُ مِائَةٍ وَالرَّجْمُ ‏"‏ ‏.‏\hadithno{4416}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1690)}\hadithtrans{A similar tradition has been transmitted by al-Hasan through a chain of Yahya and to the same effect. This version adds:They shall receive a hundred lashes and toned to death}}
\hadithdefcmd{abudawud}{4417}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ الطَّائِيُّ، حَدَّثَنَا الرَّبِيعُ بْنُ رَوْحِ بْنِ خُلَيْدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ خَالِدٍ، - يَعْنِي الْوَهْبِيَّ - حَدَّثَنَا الْفَضْلُ بْنُ دَلْهَمٍ، عَنِ الْحَسَنِ، عَنْ سَلَمَةَ بْنِ الْمُحَبَّقِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ فَقَالَ نَاسٌ لِسَعْدِ بْنِ عُبَادَةَ يَا أَبَا ثَابِتٍ قَدْ نَزَلَتِ الْحُدُودُ لَوْ أَنَّكَ وَجَدْتَ مَعَ امْرَأَتِكَ رَجُلاً كَيْفَ كُنْتَ صَانِعًا قَالَ كُنْتُ ضَارِبَهُمَا بِالسَّيْفِ حَتَّى يَسْكُتَا أَفَأَنَا أَذْهَبُ فَأَجْمَعُ أَرْبَعَةَ شُهَدَاءَ فَإِلَى ذَلِكَ قَدْ قَضَى الْحَاجَةَ ‏.‏ فَانْطَلَقُوا فَاجْتَمَعُوا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا يَا رَسُولَ اللَّهِ أَلَمْ تَرَ إِلَى أَبِي ثَابِتٍ قَالَ كَذَا وَكَذَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَفَى بِالسَّيْفِ شَاهِدًا ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ لاَ لاَ أَخَافُ أَنْ يَتَتَايَعَ فِيهَا السَّكْرَانُ وَالْغَيْرَانُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى وَكِيعٌ أَوَّلَ هَذَا الْحَدِيثِ عَنِ الْفَضْلِ بْنِ دَلْهَمٍ عَنِ الْحَسَنِ عَنْ قَبِيصَةَ بْنِ حُرَيْثٍ عَنْ سَلَمَةَ بْنِ الْمُحَبَّقِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَإِنَّمَا هَذَا إِسْنَادُ حَدِيثِ ابْنِ الْمُحَبَّقِ أَنَّ رَجُلاً وَقَعَ عَلَى جَارِيَةِ امْرَأَتِهِ ‏.‏ قَالَ أَبُو دَاوُدَ الْفَضْلُ بْنُ دَلْهَمٍ لَيْسَ بِالْحَافِظِ كَانَ قَصَّابًا بِوَاسِطَ ‏.‏\hadithno{4417}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ubadah ibn as-Samit: The tradition mentioned above (No. 4401) has also been transmitted by Ubadah ibn as-Samit through a different chain of narrators. This version has: The people said to Sa'd ibn Ubadah: AbuThabit, the prescribed punishments have been revealed: if you find a man with your wife, what will you do? He said: I shall strike them with a sword so much that they become silent (i.e. die). Should I go and gather four witnesses? Until that (time) the need would be fulfilled. So they went away and gathered with the Messenger of Allah (ﷺ) and said: Messenger of Allah! did you not see AbuThabit. He said so-and-so. The Messenger of Allah (ﷺ) said: The sword is a sufficient witness. He then said: No, no, a furious and a jealous man may follow this course. Abu Dawud said: This tradition has been transmitted by Waki' from al-Fadl b. Dilham from al-Hasan, from Qabisah b. Huraith, from Salamah b. al-Muhabbaq, from the Prophet (ﷺ). And this is the chain of the tradition narrated by Ibn al-Muhabbaq to the effect that a man had sexual intercourse with a slave girl of his wife. Abu Dawud said: Al-Fadl b. Dilham was not the memoriser of traditions. He was a butcher in Wasit}}
\hadithdefcmd{abudawud}{4418}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّ عُمَرَ، - يَعْنِي ابْنَ الْخَطَّابِ - رضى الله عنه خَطَبَ فَقَالَ إِنَّ اللَّهَ بَعَثَ مُحَمَّدًا صلى الله عليه وسلم بِالْحَقِّ وَأَنْزَلَ عَلَيْهِ الْكِتَابَ فَكَانَ فِيمَا أَنْزَلَ عَلَيْهِ آيَةُ الرَّجْمِ فَقَرَأْنَاهَا وَوَعَيْنَاهَا وَرَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَرَجَمْنَا مِنْ بَعْدِهِ وَإِنِّي خَشِيتُ - إِنْ طَالَ بِالنَّاسِ الزَّمَانُ - أَنْ يَقُولَ قَائِلٌ مَا نَجِدُ آيَةَ الرَّجْمِ فِي كِتَابِ اللَّهِ فَيَضِلُّوا بِتَرْكِ فَرِيضَةٍ أَنْزَلَهَا اللَّهُ تَعَالَى فَالرَّجْمُ حَقٌّ عَلَى مَنْ زَنَى مِنَ الرِّجَالِ وَالنِّسَاءِ إِذَا كَانَ مُحْصَنًا إِذَا قَامَتِ الْبَيِّنَةُ أَوْ كَانَ حَمْلٌ أَوِ اعْتِرَافٌ وَايْمُ اللَّهِ لَوْلاَ أَنْ يَقُولَ النَّاسُ زَادَ عُمَرُ فِي كِتَابِ اللَّهِ عَزَّ وَجَلَّ لَكَتَبْتُهَا ‏.‏\hadithno{4418}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6829) Sahih Muslim (1691)}\hadithtrans{‘Abd Allah b. ‘Abbas said:‘Umar b. al-Khattab gave an address saying: Allah sent Muhammad (ﷺ) with truth and sent down the Books of him, and the verse of stoning was included in what He sent down to him. We read it and memorized it. The Messenger of Allah (ﷺ) had people stoned to death and we have done it also since his death. I am afraid the people might say with the passage of time: We do not find the verse of stoning in the Books of Allah, and thus they stray by abandoning a duty which Allah had received. Stoning is a duty laid down (by Allah) for married men and women who commit fornication when proof is established, or if there is pregnancy, or a confession. I swear by Allah, had it not been so that the people might say: ‘Umar made an addition to Allah’s Book, I would have written it (there)}}
\hadithdefcmd{abudawud}{4419}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامِ بْنِ سَعْدٍ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ نُعَيْمِ بْنِ هَزَّالٍ، عَنْ أَبِيهِ، قَالَ كَانَ مَاعِزُ بْنُ مَالِكٍ يَتِيمًا فِي حِجْرِ أَبِي ‏.‏ فَأَصَابَ جَارِيَةً مِنَ الْحَىِّ فَقَالَ لَهُ أَبِي ائْتِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَخْبِرْهُ بِمَا صَنَعْتَ لَعَلَّهُ يَسْتَغْفِرُ لَكَ وَإِنَّمَا يُرِيدُ بِذَلِكَ رَجَاءَ أَنْ يَكُونَ لَهُ مَخْرَجًا فَأَتَاهُ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي زَنَيْتُ فَأَقِمْ عَلَىَّ كِتَابَ اللَّهِ ‏.‏ فَأَعْرَضَ عَنْهُ فَعَادَ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي زَنَيْتُ فَأَقِمْ عَلَىَّ كِتَابَ اللَّهِ ‏.‏ حَتَّى قَالَهَا أَرْبَعَ مِرَارٍ ‏.‏ قَالَ صلى الله عليه وسلم ‏"‏ إِنَّكَ قَدْ قُلْتَهَا أَرْبَعَ مَرَّاتٍ فَبِمَنْ ‏"‏ ‏.‏ قَالَ بِفُلاَنَةَ ‏.‏ قَالَ ‏"‏ هَلْ ضَاجَعْتَهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ هَلْ بَاشَرْتَهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ هَلْ جَامَعْتَهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ فَأَمَرَ بِهِ أَنْ يُرْجَمَ فَأُخْرِجَ بِهِ إِلَى الْحَرَّةِ ‏.‏ فَلَمَّا رُجِمَ فَوَجَدَ مَسَّ الْحِجَارَةِ جَزِعَ فَخَرَجَ يَشْتَدُّ فَلَقِيَهُ عَبْدُ اللَّهِ بْنُ أُنَيْسٍ وَقَدْ عَجَزَ أَصْحَابُهُ فَنَزَعَ لَهُ بِوَظِيفِ بَعِيرٍ فَرَمَاهُ بِهِ فَقَتَلَهُ ثُمَّ أَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ ‏"‏ هَلاَّ تَرَكْتُمُوهُ لَعَلَّهُ أَنْ يَتُوبَ فَيَتُوبَ اللَّهُ عَلَيْهِ ‏"‏ ‏.‏\hadithno{4419}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Nu'aym ibn Huzzal: Yazid ibn Nu'aym ibn Huzzal, on his father's authority said: Ma'iz ibn Malik was an orphan under the protection of my father. He had illegal sexual intercourse with a slave-girl belonging to a clan. My father said to him: Go to the Messenger of Allah (ﷺ) and inform him of what you have done, for he may perhaps ask Allah for your forgiveness. His purpose in that was simply a hope that it might be a way of escape for him. So he went to him and said: Messenger of Allah! I have committed fornication, so inflict on me the punishment ordained by Allah. He (the Prophet) turned away from him, so he came back and said: Messenger of Allah! I have committed fornication, so inflict on me the punishment ordained by Allah. He (again) turned away from him, so he came back and said: Messenger of Allah! I have committed fornication, so inflict on me the punishment ordained by Allah. When he uttered it four times, the Messenger of Allah (ﷺ) said: You have said it four times. With whom did you commit it? He replied: With so and so. He asked: Did you lie down with her? He replied: Yes. He asked: Had your skin been in contact with hers? He replied. Yes. He asked: Did you have intercourse with her? He said: Yes. So he (the Prophet) gave orders that he should be stoned to death. He was then taken out to the Harrah, and while he was being stoned he felt the effect of the stones and could not bear it and fled. But Abdullah ibn Unays encountered him when those who had been stoning him could not catch up with him. He threw the bone of a camel's foreleg at him, which hit him and killed him. They then went to the Prophet (ﷺ) and reported it to him. He said: Why did you not leave him alone. Perhaps he might have repented and been forgiven by Allah}}
\hadithdefcmd{abudawud}{4420}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، قَالَ ذَكَرْتُ لِعَاصِمِ بْنِ عُمَرَ بْنِ قَتَادَةَ قِصَّةَ مَاعِزِ بْنِ مَالِكٍ فَقَالَ لِي حَدَّثَنِي حَسَنُ بْنُ مُحَمَّدِ بْنِ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ حَدَّثَنِي ذَلِكَ، مِنْ قَوْلِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏"‏ فَهَلاَّ تَرَكْتُمُوهُ ‏"‏ ‏.‏ مَنْ شِئْتُمْ مِنْ رِجَالِ أَسْلَمَ مِمَّنْ لاَ أَتَّهِمُ ‏.‏ قَالَ وَلَمْ أَعْرِفْ هَذَا الْحَدِيثَ قَالَ فَجِئْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ فَقُلْتُ إِنَّ رِجَالاً مِنْ أَسْلَمَ يُحَدِّثُونَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لَهُمْ حِينَ ذَكَرُوا لَهُ جَزَعَ مَاعِزٍ مِنَ الْحِجَارَةِ حِينَ أَصَابَتْهُ ‏"‏ أَلاَّ تَرَكْتُمُوهُ ‏"‏ ‏.‏ وَمَا أَعْرِفُ الْحَدِيثَ قَالَ يَا ابْنَ أَخِي أَنَا أَعْلَمُ النَّاسِ بِهَذَا الْحَدِيثِ كُنْتُ فِيمَنْ رَجَمَ الرَّجُلَ إِنَّا لَمَّا خَرَجْنَا بِهِ فَرَجَمْنَاهُ فَوَجَدَ مَسَّ الْحِجَارَةِ صَرَخَ بِنَا يَا قَوْمِ رُدُّونِي إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِنَّ قَوْمِي قَتَلُونِي وَغَرُّونِي مِنْ نَفْسِي وَأَخْبَرُونِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم غَيْرُ قَاتِلِي فَلَمْ نَنْزِعْ عَنْهُ حَتَّى قَتَلْنَاهُ فَلَمَّا رَجَعْنَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَخْبَرْنَاهُ قَالَ ‏"‏ فَهَلاَّ تَرَكْتُمُوهُ وَجِئْتُمُونِي بِهِ ‏"‏ ‏.‏ لِيَسْتَثْبِتَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْهُ فَأَمَّا لِتَرْكِ حَدٍّ فَلاَ قَالَ فَعَرَفْتُ وَجْهَ الْحَدِيثِ ‏.‏\hadithno{4420}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: Muhammad ibn Ishaq said: I mentioned the story of Ma'iz ibn Malik to Asim ibn Umar ibn Qatadah. He said to me: Hasan ibn Muhammad ibn Ali ibn AbuTalib said to me: Some men of the tribe of Aslam whom I do not blame and whom you like have transmitted to me the saying of the Messenger of Allah (ﷺ): Why did you not leave him alone? He said: But I did not understand this tradition. So I went to Jabir ibn Abdullah and said (to him): Some men of the tribe of Aslam narrate that the Messenger of Allah (ﷺ) said when they mentioned to him the anxiety of Ma'iz when the stones hurt him: "Why did you not leave him alone?' But I do not know this tradition. He said: My cousin, I know this tradition more than the people. I was one of those who had stoned the man. When we came out with him, stoned him and he felt the effect of the stones, he cried: O people! return me to the Messenger of Allah (ﷺ). My people killed me and deceived me; they told me that the Messenger of Allah (ﷺ) would not kill me. We did not keep away from him till we killed him. When we returned to the Messenger of Allah (ﷺ) we informed him of it. He said: Why did you not leave him alone and bring him to me? and he said this so that the Messenger of Allah (ﷺ) might ascertain it from him. But he did not say this to abandon the prescribed punishment. He said: I then understood the intent of the tradition}}
\hadithdefcmd{abudawud}{4421}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي الْحَذَّاءَ - عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ مَاعِزَ بْنَ مَالِكٍ، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ إِنَّهُ زَنَى ‏.‏ فَأَعْرَضَ عَنْهُ فَأَعَادَ عَلَيْهِ مِرَارًا فَأَعْرَضَ عَنْهُ فَسَأَلَ قَوْمَهُ ‏"‏ أَمَجْنُونٌ هُوَ ‏"‏ ‏.‏ قَالُوا لَيْسَ بِهِ بَأْسٌ ‏.‏ قَالَ ‏"‏ أَفَعَلْتَ بِهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَأَمَرَ بِهِ أَنْ يُرْجَمَ فَانْطُلِقَ بِهِ فَرُجِمَ وَلَمْ يُصَلِّ عَلَيْهِ ‏.‏\hadithno{4421}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: Ma'iz ibn Malik came to the Prophet (ﷺ) and said that he had committed fornication and he (the Prophet) turned away from him. He repeated it many times, but he (the Prophet) turned away from him. He asked his people: Is he mad? They replied: There is no defect in him. He asked: Have you done it with her? He replied: Yes. so he ordered that he should be stoned to death. He was taken out and stoned to death, and he (the Prophet) did not pray over him}}
\hadithdefcmd{abudawud}{4422}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكٍ، عَنْ جَابِرِ بْنِ سَمُرَةَ، قَالَ رَأَيْتُ مَاعِزَ بْنَ مَالِكٍ حِينَ جِيءَ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم رَجُلاً قَصِيرًا أَعْضَلَ لَيْسَ عَلَيْهِ رِدَاءٌ فَشَهِدَ عَلَى نَفْسِهِ أَرْبَعَ مَرَّاتٍ أَنَّهُ قَدْ زَنَى ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَلَعَلَّكَ قَبَّلْتَهَا ‏"‏ ‏.‏ قَالَ لاَ وَاللَّهِ إِنَّهُ قَدْ زَنَى الآخِرُ ‏.‏ قَالَ فَرَجَمَهُ ثُمَّ خَطَبَ فَقَالَ ‏"‏ أَلاَ كُلَّمَا نَفَرْنَا فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ خَلَفَ أَحَدُهُمْ لَهُ نَبِيبٌ كَنَبِيبِ التَّيْسِ يَمْنَحُ إِحْدَاهُنَّ الْكُثْبَةَ أَمَا إِنَّ اللَّهَ إِنْ يُمَكِّنِّي مِنْ أَحَدٍ مِنْهُمْ إِلاَّ نَكَلْتُهُ عَنْهُنَّ ‏"‏ ‏.‏\hadithno{4422}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Muslim (1692)}\hadithtrans{Jabir b. Samurah said:I saw Ma’iz b. Malik when he was brought to the Prophet (ﷺ). He was a small and muscular man. He did not wear the loose outer garment. He made confession about him four times that he committed fornication. The Messenger of Allah (ﷺ) said: Perhaps you kissed her. He said that this most discarded man has committed fornication. He said: So he had him stoned to death and gave an address, saying: Beware, whenever we go out on an expedition in the path of Allah, one of them (I.e. the people) lags behind with a bleating sound like that of a he-goat, and gives modicum of his milk(i.e. sperm) to one of the women. If Allah gives control over any of them, I shall deter him from them (i.e. women) by punishing him severely}}
\hadithdefcmd{abudawud}{4423}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ سِمَاكٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ سَمُرَةَ، بِهَذَا الْحَدِيثِ وَالأَوَّلُ أَتَمُّ قَالَ فَرَدَّهُ مَرَّتَيْنِ ‏.‏ قَالَ سِمَاكٌ فَحَدَّثْتُ بِهِ سَعِيدَ بْنَ جُبَيْرٍ فَقَالَ إِنَّهُ رَدَّهُ أَرْبَعَ مَرَّاتٍ ‏.‏\hadithno{4423}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih Muslim (1692)}\hadithtrans{Simak said:I heard this tradition from Jabir b. Samurah. But the first version is more perfect. This version has: He repeated twice, Simak said: I narrated to Sa’id b. Jubair. He said: He repeated it four times}}
\hadithdefcmd{abudawud}{4424}{حَدَّثَنَا عَبْدُ الْغَنِيِّ بْنُ أَبِي عَقِيلٍ الْمِصْرِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ - قَالَ قَالَ شُعْبَةُ فَسَأَلْتُ سِمَاكًا عَنِ الْكُثْبَةِ فَقَالَ اللَّبَنُ الْقَلِيلُ ‏.‏\hadithno{4424}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Shu’bah said:I asked Simak about the meaning of KUTHBAH. He said: A small quantity of milk}}
\hadithdefcmd{abudawud}{4425}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِمَاعِزِ بْنِ مَالِكٍ ‏"‏ أَحَقٌّ مَا بَلَغَنِي عَنْكَ ‏"‏ ‏.‏ قَالَ وَمَا بَلَغَكَ عَنِّي قَالَ ‏"‏ بَلَغَنِي عَنْكَ أَنَّكَ وَقَعْتَ عَلَى جَارِيَةِ بَنِي فُلاَنٍ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَشَهِدَ أَرْبَعَ شَهَادَاتٍ فَأَمَرَ بِهِ فَرُجِمَ ‏.‏\hadithno{4425}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1693)}\hadithtrans{Ibn ‘Abbas said:The Messenger of Allah (ﷺ) asked Ma’iz b. Malik : Is what I have heard about you is true? He said: What have you heard about me? He said: I have heard that you have had intercourse with a girl belonging to the family of so and so. He said: Yes. He then testified four times. He (The prophet) then gave order regarding him and he was stoned to death}}
\hadithdefcmd{abudawud}{4426}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، أَخْبَرَنَا أَبُو أَحْمَدَ، أَخْبَرَنَا إِسْرَائِيلُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ مَاعِزُ بْنُ مَالِكٍ إِلَى النَّبِيِّ صلى الله عليه وسلم فَاعْتَرَفَ بِالزِّنَا مَرَّتَيْنِ فَطَرَدَهُ ثُمَّ جَاءَ فَاعْتَرَفَ بِالزِّنَا مَرَّتَيْنِ فَقَالَ ‏ "‏ شَهِدْتَ عَلَى نَفْسِكَ أَرْبَعَ مَرَّاتٍ اذْهَبُوا بِهِ فَارْجُمُوهُ ‏"‏ ‏.‏\hadithno{4426}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: Ma'iz ibn Malik came to the Prophet (ﷺ) and admitted fornication twice. But he drove him away. He then came and admitted fornication twice. But he drove him away. He then came and admitted fornication twice. He (the Prophet) said: You have testified to yourself four times. Take him away and stone him to death}}
\hadithdefcmd{abudawud}{4427}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا جَرِيرٌ، حَدَّثَنِي يَعْلَى، عَنْ عِكْرِمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ وَعُقْبَةُ بْنُ مُكْرَمٍ قَالاَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ حَدَّثَنَا أَبِي قَالَ سَمِعْتُ يَعْلَى بْنَ حَكِيمٍ يُحَدِّثُ عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِمَاعِزِ بْنِ مَالِكٍ ‏"‏ لَعَلَّكَ قَبَّلْتَ أَوْ غَمَزْتَ أَوْ نَظَرْتَ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ أَفَنِكْتَهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ فَعِنْدَ ذَلِكَ أَمَرَ بِرَجْمِهِ ‏.‏ وَلَمْ يَذْكُرْ مُوسَى عَنِ ابْنِ عَبَّاسٍ وَهَذَا لَفْظُ وَهْبٍ ‏.‏\hadithno{4427}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan Sahih Bukhari (6824)}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said to Ma'iz ibn Malik: Perhaps you kissed, or squeezed, or looked. He said: No. He then said: Did you have intercourse with her? He said: Yes. On the (reply) he (the Prophet) gave order that he should be stoned to death. The narrator did not mention "on the authority of Ibn 'Abbas". This is Wahb's version}}
\hadithdefcmd{abudawud}{4428}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنِ ابْنِ جُرَيْجٍ، قَالَ أَخْبَرَنِي أَبُو الزُّبَيْرِ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ الصَّامِتِ ابْنَ عَمِّ أَبِي هُرَيْرَةَ، أَخْبَرَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ جَاءَ الأَسْلَمِيُّ إِلَى نَبِيِّ اللَّهِ صلى الله عليه وسلم فَشَهِدَ عَلَى نَفْسِهِ أَنَّهُ أَصَابَ امْرَأَةً حَرَامًا أَرْبَعَ مَرَّاتٍ كُلُّ ذَلِكَ يُعْرِضُ عَنْهُ النَّبِيُّ صلى الله عليه وسلم فَأَقْبَلَ فِي الْخَامِسَةِ فَقَالَ ‏"‏ أَنِكْتَهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ حَتَّى غَابَ ذَلِكَ مِنْكَ فِي ذَلِكَ مِنْهَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ كَمَا يَغِيبُ الْمِرْوَدُ فِي الْمُكْحُلَةِ وَالرِّشَاءُ فِي الْبِئْرِ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ فَهَلْ تَدْرِي مَا الزِّنَا ‏"‏ ‏.‏ قَالَ نَعَمْ أَتَيْتُ مِنْهَا حَرَامًا مَا يَأْتِي الرَّجُلُ مِنِ امْرَأَتِهِ حَلاَلاً ‏.‏ قَالَ ‏"‏ فَمَا تُرِيدُ بِهَذَا الْقَوْلِ ‏"‏ ‏.‏ قَالَ أُرِيدُ أَنْ تُطَهِّرَنِي ‏.‏ فَأَمَرَ بِهِ فَرُجِمَ فَسَمِعَ النَّبِيُّ صلى الله عليه وسلم رَجُلَيْنِ مِنْ أَصْحَابِهِ يَقُولُ أَحَدُهُمَا لِصَاحِبِهِ انْظُرْ إِلَى هَذَا الَّذِي سَتَرَ اللَّهُ عَلَيْهِ فَلَمْ تَدَعْهُ نَفْسُهُ حَتَّى رُجِمَ رَجْمَ الْكَلْبِ ‏.‏ فَسَكَتَ عَنْهُمَا ثُمَّ سَارَ سَاعَةً حَتَّى مَرَّ بِجِيفَةِ حِمَارٍ شَائِلٍ بِرِجْلِهِ فَقَالَ ‏"‏ أَيْنَ فُلاَنٌ وَفُلاَنٌ ‏"‏ ‏.‏ فَقَالاَ نَحْنُ ذَانِ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ انْزِلاَ فَكُلاَ مِنْ جِيفَةِ هَذَا الْحِمَارِ ‏"‏ ‏.‏ فَقَالاَ يَا نَبِيَّ اللَّهِ مَنْ يَأْكُلُ مِنْ هَذَا قَالَ ‏"‏ فَمَا نِلْتُمَا مِنْ عِرْضِ أَخِيكُمَا آنِفًا أَشَدُّ مِنْ أَكْلٍ مِنْهُ وَالَّذِي نَفْسِي بِيَدِهِ إِنَّهُ الآنَ لَفِي أَنْهَارِ الْجَنَّةِ يَنْقَمِسُ فِيهَا ‏"‏ ‏.‏\hadithno{4428}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: A man of the tribe of Aslam came to the Prophet (ﷺ) and testified four times against himself that he had had illicit intercourse with a woman, while all the time the Prophet (ﷺ) was turning away from him. Then when he confessed a fifth time, he turned round and asked: Did you have intercourse with her? He replied: Yes. He asked: Have you done it so that your sexual organ penetrated hers? He replied: Yes. He asked: Have you done it like a collyrium stick when enclosed in its case and a rope in a well? He replied: Yes. He asked: Do you know what fornication is? He replied: Yes. I have done with her unlawfully what a man may lawfully do with his wife. He then asked: What do you want from what you have said? He said: I want you to purify me. So he gave orders regarding him and he was stoned to death. Then the Prophet (ﷺ) heard one of his companions saying to another: Look at this man whose fault was concealed by Allah but who would not leave the matter alone, so that he was stoned like a dog. He said nothing to them but walked on for a time till he came to the corpse of an ass with its legs in the air. He asked: Where are so and so? They said: Here we are, Messenger of Allah (ﷺ)! He said: Go down and eat some of this ass's corpse. They replied: Messenger of Allah! Who can eat any of this? He said: The dishonour you have just shown to your brother is more serious than eating some of it. By Him in Whose hand my soul is, he is now among the rivers of Paradise and plunging into them}}
\hadithdefcmd{abudawud}{4429}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنَا أَبُو الزُّبَيْرِ، عَنِ ابْنِ عَمِّ أَبِي هُرَيْرَةَ، عَنْ أَبِي هُرَيْرَةَ، بِنَحْوِهِ زَادَ وَاخْتَلَفُوا فَقَالَ بَعْضُهُمْ رُبِطَ إِلَى شَجَرَةٍ وَقَالَ بَعْضُهُمْ وَقَفَ ‏.‏\hadithno{4429}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{A similar tradition has also been transmitted by Abu Hurrairah through a different chain of narrators. This version adds:The narrator Hasan b. “All said: The transmitters have differed in the wordings (of this tradition) reported to me. Some said: He (Ma’iz) was tied to a tree, and others said: He was made to stand}}
\hadithdefcmd{abudawud}{4430}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُتَوَكِّلِ الْعَسْقَلاَنِيُّ، وَالْحَسَنُ بْنُ عَلِيٍّ، قَالاَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَجُلاً، مِنْ أَسْلَمَ جَاءَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَاعْتَرَفَ بِالزِّنَا فَأَعْرَضَ عَنْهُ ثُمَّ اعْتَرَفَ فَأَعْرَضَ عَنْهُ حَتَّى شَهِدَ عَلَى نَفْسِهِ أَرْبَعَ شَهَادَاتٍ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَبِكَ جُنُونٌ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ أَحْصَنْتَ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ فَأَمَرَ بِهِ النَّبِيُّ صلى الله عليه وسلم فَرُجِمَ فِي الْمُصَلَّى فَلَمَّا أَذْلَقَتْهُ الْحِجَارَةُ فَرَّ فَأُدْرِكَ فَرُجِمَ حَتَّى مَاتَ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم خَيْرًا وَلَمْ يُصَلِّ عَلَيْهِ ‏.‏\hadithno{4430}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir b. ‘Abd Allah said:A man of the tribe of Asalam came to the Messenger of Allah (ﷺ) and made confession of fornication. He (the prophet) turned away from him. When he testified against him four times, the Prophet (ﷺ) said: Are you mad? He said: No. he asked: Are you married? He replied: Yes. The Prophet (ﷺ) then commanded regarding him and he was stoned in the place of prayer. Then when the stones hurt him, he fled, but was overtaken and stoned to death. The Prophet (ﷺ) then spoke well of him and did not pray over him}}
\hadithdefcmd{abudawud}{4431}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - ح وَحَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، عَنْ يَحْيَى بْنِ زَكَرِيَّا، - وَهَذَا لَفْظُهُ - عَنْ دَاوُدَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، قَالَ لَمَّا أَمَرَ النَّبِيُّ صلى الله عليه وسلم بِرَجْمِ مَاعِزِ بْنِ مَالِكٍ خَرَجْنَا بِهِ إِلَى الْبَقِيعِ فَوَاللَّهِ مَا أَوْثَقْنَاهُ وَلاَ حَفَرْنَا لَهُ وَلَكِنَّهُ قَامَ لَنَا ‏.‏ - قَالَ أَبُو كَامِلٍ قَالَ - فَرَمَيْنَاهُ بِالْعِظَامِ وَالْمَدَرِ وَالْخَزَفِ فَاشْتَدَّ وَاشْتَدَدْنَا خَلْفَهُ حَتَّى أَتَى عُرْضَ الْحَرَّةِ فَانْتَصَبَ لَنَا فَرَمَيْنَاهُ بِجَلاَمِيدِ الْحَرَّةِ حَتَّى سَكَتَ - قَالَ - فَمَا اسْتَغْفَرَ لَهُ وَلاَ سَبَّهُ ‏.‏\hadithno{4431}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1694)}\hadithtrans{Abu Sa’id said:When the Prophet (May peace e upon him) commanded to stone Ma’iz b. Malik, we took him out to Baql. I swear by Allah, we did not tie him, nor did we dig a pit for him. But he was standing before us. The narrator Abu Kamil said: So we threw at him bones, clods of mud and pieces of earthenware. He ran away and we ran after him till he came to a side of the Harrah. He stood there before us and we threw at him big stones of the Harrah until he died. He (the Prophet) did not ask forgiveness for him, nor did he speak ill of him}}
\hadithdefcmd{abudawud}{4432}{حَدَّثَنَا مُؤَمَّلُ بْنُ هِشَامٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَلَيْسَ بِتَمَامِهِ قَالَ ذَهَبُوا يَسُبُّونَهُ فَنَهَاهُمْ قَالَ ذَهَبُوا يَسْتَغْفِرُونَ لَهُ فَنَهَاهُمْ قَالَ ‏ "‏ هُوَ رَجُلٌ أَصَابَ ذَنْبًا حَسِيبُهُ اللَّهُ ‏"‏ ‏.‏\hadithno{4432}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Nadrah said:A man came to Prophet (ﷺ). He then mentioned a similar tradition but not completely. This version has: People began to speak ill of him but he (the Prophet) forbade them. Then they began to ask forgiveness from him, but he forbade them by saying. He is a man who had committed a sin. Allah will call him to account himself}}
\hadithdefcmd{abudawud}{4433}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرِ بْنِ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ يَعْلَى بْنِ الْحَارِثِ، حَدَّثَنَا أَبِي، عَنْ غَيْلاَنَ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اسْتَنْكَهَ مَاعِزًا ‏.‏\hadithno{4433}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1695)}\hadithtrans{Buraidah said. :The Prophet (ﷺ) smelt the breath of Ma’iz}}
\hadithdefcmd{abudawud}{4434}{حَدَّثَنَا أَحْمَدُ بْنُ إِسْحَاقَ الأَهْوَازِيُّ، حَدَّثَنَا أَبُو أَحْمَدَ، حَدَّثَنَا بَشِيرُ بْنُ الْمُهَاجِرِ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ كُنَّا أَصْحَابَ رَسُولِ اللَّهِ نَتَحَدَّثُ أَنَّ الْغَامِدِيَّةَ وَمَاعِزَ بْنَ مَالِكٍ لَوْ رَجَعَا بَعْدَ اعْتِرَافِهِمَا أَوْ قَالَ لَوْ لَمْ يَرْجِعَا بَعْدَ اعْتِرَافِهِمَا لَمْ يَطْلُبْهُمَا وَإِنَّمَا رَجَمَهُمَا عِنْدَ الرَّابِعَةِ ‏.‏\hadithno{4434}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Buraydah ibn al-Hasib: We, the Companions of the Messenger of Allah (ﷺ), used to talk mutually: Would that al-Ghamidiyyah and Ma'iz ibn Malik had withdrawn after their confession; or he said: Had they not withdrawn after their confession, he would not have pursued them (for punishment). He had them stoned after the fourth (confession)}}
\hadithdefcmd{abudawud}{4435}{حَدَّثَنَا عَبْدَةُ بْنُ عَبْدِ اللَّهِ، وَمُحَمَّدُ بْنُ دَاوُدَ بْنِ صُبَيْحٍ، قَالَ عَبْدَةُ أَخْبَرَنَا حَرَمِيُّ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ عُلاَثَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، أَنَّ خَالِدَ بْنَ اللَّجْلاَجِ، حَدَّثَهُ أَنَّ اللَّجْلاَجَ أَبَاهُ أَخْبَرَهُ أَنَّهُ، كَانَ قَاعِدًا يَعْتَمِلُ فِي السُّوقِ فَمَرَّتِ امْرَأَةٌ تَحْمِلُ صَبِيًّا فَثَارَ النَّاسُ مَعَهَا وَثُرْتُ فِيمَنْ ثَارَ فَانْتَهَيْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ يَقُولُ ‏"‏ مَنْ أَبُو هَذَا مَعَكِ ‏"‏ ‏.‏ فَسَكَتَتْ فَقَالَ شَابٌّ حَذْوَهَا أَنَا أَبُوهُ يَا رَسُولَ اللَّهِ ‏.‏ فَأَقْبَلَ عَلَيْهَا فَقَالَ ‏"‏ مَنْ أَبُو هَذَا مَعَكِ ‏"‏ ‏.‏ قَالَ الْفَتَى أَنَا أَبُوهُ يَا رَسُولَ اللَّهِ ‏.‏ فَنَظَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى بَعْضِ مَنْ حَوْلَهُ يَسْأَلُهُمْ عَنْهُ فَقَالُوا مَا عَلِمْنَا إِلاَّ خَيْرًا ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَحْصَنْتَ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ فَأَمَرَ بِهِ فَرُجِمَ ‏.‏ قَالَ فَخَرَجْنَا بِهِ فَحَفَرْنَا لَهُ حَتَّى أَمْكَنَّا ثُمَّ رَمَيْنَاهُ بِالْحِجَارَةِ حَتَّى هَدَأَ فَجَاءَ رَجُلٌ يَسْأَلُ عَنِ الْمَرْجُومِ فَانْطَلَقْنَا بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقُلْنَا هَذَا جَاءَ يَسْأَلُ عَنِ الْخَبِيثِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَهُوَ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ ‏"‏ ‏.‏ فَإِذَا هُوَ أَبُوهُ فَأَعَنَّاهُ عَلَى غُسْلِهِ وَتَكْفِينِهِ وَدَفْنِهِ وَمَا أَدْرِي قَالَ وَالصَّلاَةِ عَلَيْهِ أَمْ لاَ ‏.‏ وَهَذَا حَدِيثُ عَبْدَةَ وَهُوَ أَتَمُّ ‏.‏\hadithno{4435}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Al-Lajlaj al-Amiri: I was working in the market. A woman passed carrying a child. The people rushed towards her, and I also rushed along with them. I then went to the Prophet (ﷺ) while he was asking: Who is the father of this (child) who is with you? She remained silent. A young man by her side said: I am his father, Messenger of Allah! He then turned towards her and asked: Who is the father of this child with you? The young man said: I am his father, Messenger of Allah! The Messenger of Allah (ﷺ) then looked at some of those who were around him and asked them about him. They said: We only know good (about him). The Prophet (ﷺ) said to him: Are you married? He said: Yes. So he gave orders regarding him and he was stoned to death. He (the narrator) said: We took him out, dug a pit for him and put him in it. We then threw stones at him until he died. A man then came asking about the man who was stoned. We brought him to the Prophet (ﷺ) and said: This man has come asking about the wicked man. The Messenger of Allah (ﷺ) said: He is more agreeable than the fragrance of musk in the eyes of Allah. The man was his father. We then helped him in washing, shrouding and burying him. (The narrator said:) I do not know whether he said or did not say "in praying over him." This is the tradition of Abdah, and it is more accurate}}
\hadithdefcmd{abudawud}{4436}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا صَدَقَةُ بْنُ خَالِدٍ، ح وَحَدَّثَنَا نَصْرُ بْنُ عَاصِمٍ الأَنْطَاكِيُّ، حَدَّثَنَا الْوَلِيدُ، جَمِيعًا قَالاَ حَدَّثَنَا مُحَمَّدٌ، - قَالَ هِشَامٌ مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الشُّعَيْثِيُّ - عَنْ مَسْلَمَةَ بْنِ عَبْدِ اللَّهِ الْجُهَنِيِّ، عَنْ خَالِدِ بْنِ اللَّجْلاَجِ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِبَعْضِ هَذَا الْحَدِيثِ ‏.‏\hadithno{4436}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Isnaad; Zubair Ali Zai: Hasan}\hadithtrans{A part of tradition has also been transmitted by al-Lajlaj from the Prophet (ﷺ) through a different chain of narrators}}
\hadithdefcmd{abudawud}{4437}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا طَلْقُ بْنُ غَنَّامٍ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَفْصٍ، حَدَّثَنَا أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَجُلاً أَتَاهُ فَأَقَرَّ عِنْدَهُ أَنَّهُ زَنَى بِامْرَأَةٍ سَمَّاهَا لَهُ فَبَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْمَرْأَةِ فَسَأَلَهَا عَنْ ذَلِكَ فَأَنْكَرَتْ أَنْ تَكُونَ زَنَتْ فَجَلَدَهُ الْحَدَّ وَتَرَكَهَا ‏.‏\hadithno{4437}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Sahl ibn Sa'd: A man came to the Prophet (ﷺ) and confessed before him that he had committed fornication with a woman whom he named. The Messenger of Allah (ﷺ) sent for the woman and asked her about it. But she denied that she had committed fornication. So he inflicted the prescribed punishment of flogging on him, and let her go}}
\hadithdefcmd{abudawud}{4438}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا ح، وَحَدَّثَنَا ابْنُ السَّرْحِ، - الْمَعْنَى - قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَجُلاً، زَنَى بِامْرَأَةٍ فَأَمَرَ بِهِ النَّبِيُّ صلى الله عليه وسلم فَجُلِدَ الْحَدَّ ثُمَّ أُخْبِرَ أَنَّهُ مُحْصَنٌ فَأَمَرَ بِهِ فَرُجِمَ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذَا الْحَدِيثَ مُحَمَّدُ بْنُ بَكْرٍ الْبُرْسَانِيُّ عَنِ ابْنِ جُرَيْجٍ مَوْقُوفًا عَلَى جَابِرٍ ‏.‏ وَرَوَاهُ أَبُو عَاصِمٍ عَنِ ابْنِ جُرَيْجٍ بِنَحْوِ ابْنِ وَهْبٍ لَمْ يَذْكُرِ النَّبِيَّ صلى الله عليه وسلم قَالَ إِنَّ رَجُلاً زَنَى فَلَمْ يَعْلَمْ بِإِحْصَانِهِ فَجُلِدَ ثُمَّ عَلِمَ بِإِحْصَانِهِ فَرُجِمَ ‏.‏\hadithno{4438}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: A man committed fornication with a woman. So the Messenger of Allah (ﷺ) ordered regarding him and the prescribed punishment of flogging was inflicted on him. He was then informed that he was married. So he commanded regarding him and he was stoned to death. Abu Dawud said: This tradition has been transmitted by Muhammad b. Bakr al-Barsani from Ibn Juraij as a statement of Jabir, and Abu 'Asim has transmitted it from Ibn Juraid similar to that of Ibn Wahb. He did not mention the Prophet (ﷺ). But he said: A man committed fornication, but did not know that he was married ; so he was flogged. It was then known that he was married, so he was stoned to death}}
\hadithdefcmd{abudawud}{4439}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ أَبُو يَحْيَى الْبَزَّازُ، أَخْبَرَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَجُلاً، زَنَى بِامْرَأَةٍ فَلَمْ يَعْلَمْ بِإِحْصَانِهِ فَجُلِدَ ثُمَّ عَلِمَ بِإِحْصَانِهِ فَرُجِمَ ‏.‏\hadithno{4439}\hadithgrade{Al-Albani: Daif Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Jabir said:A man committed fornication with a woman. It was not known that he was married. So he was flogged. It was then known that he was married, so he was stoned to death}}
\hadithdefcmd{abudawud}{4440}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، أَنَّ هِشَامًا الدَّسْتَوَائِيَّ، وَأَبَانَ بْنَ يَزِيدَ، حَدَّثَاهُمُ - الْمَعْنَى، - عَنْ يَحْيَى، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمُهَلَّبِ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ امْرَأَةً، - قَالَ فِي حَدِيثِ أَبَانَ مِنْ جُهَيْنَةَ - أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ إِنَّهَا زَنَتْ وَهِيَ حُبْلَى ‏.‏ فَدَعَا النَّبِيُّ صلى الله عليه وسلم وَلِيًّا لَهَا فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَحْسِنْ إِلَيْهَا فَإِذَا وَضَعَتْ فَجِئْ بِهَا ‏"‏ ‏.‏ فَلَمَّا أَنْ وَضَعَتْ جَاءَ بِهَا فَأَمَرَ بِهَا النَّبِيُّ صلى الله عليه وسلم فَشُكَّتْ عَلَيْهَا ثِيَابُهَا ثُمَّ أَمَرَ بِهَا فَرُجِمَتْ ثُمَّ أَمَرَهُمْ فَصَلَّوْا عَلَيْهَا فَقَالَ عُمَرُ يَا رَسُولَ اللَّهِ تُصَلِّي عَلَيْهَا وَقَدْ زَنَتْ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَقَدْ تَابَتْ تَوْبَةً لَوْ قُسِّمَتْ بَيْنَ سَبْعِينَ مِنْ أَهْلِ الْمَدِينَةِ لَوَسِعَتْهُمْ وَهَلْ وَجَدْتَ أَفْضَلَ مِنْ أَنْ جَادَتْ بِنَفْسِهَا ‏"‏ ‏.‏ لَمْ يَقُلْ عَنْ أَبَانَ فَشُكَّتْ عَلَيْهَا ثِيَابُهَا ‏.‏\hadithno{4440}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1696)}\hadithtrans{Narrated Imran ibn Husayn: A woman belonging to the tribe of Juhaynah (according to the version of Aban) came to the Prophet (ﷺ) and said that she had committed fornication and that she was pregnant. The Messenger of Allah (ﷺ) called her guardian. Then the Messenger of Allah (ﷺ) said to him: Be good to her, and when she bears a child, bring her (to me). When she gave birth to the child, he brought her (to him). The Prophet (ﷺ) gave orders regarding her, and her clothes were tied to her. He then commanded regarding her and she was stoned to death. He commanded the people (to pray) and they prayed over her. Thereupon Umar said: Are you praying over her, Messenger of Allah, when she has committed fornication? He said: By Him in Whose hand my soul is, she has repented to such an extent that if it were divided among the seventy people of Medina, it would have been enough for them all. And what do you find better than the fact that she gave her life. Aban did not say in his version: Then her clothes were tied to her}}
\hadithdefcmd{abudawud}{4441}{حَدَّثَنَا مُحَمَّدُ بْنُ الْوَزِيرِ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، قَالَ فَشُكَّتْ عَلَيْهَا ثِيَابُهَا ‏.‏ يَعْنِي فَشُدَّتْ ‏.‏\hadithno{4441}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Al-Auza’i said:The word shukkta means tied, meaning her clothes were tied on her}}
\hadithdefcmd{abudawud}{4442}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى الرَّازِيُّ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنْ بَشِيرِ بْنِ الْمُهَاجِرِ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ أَبِيهِ، أَنَّ امْرَأَةً، - يَعْنِي مِنْ غَامِدَ - أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَتْ إِنِّي قَدْ فَجَرْتُ ‏.‏ فَقَالَ ‏"‏ ارْجِعِي ‏"‏ ‏.‏ فَرَجَعَتْ فَلَمَّا كَانَ الْغَدُ أَتَتْهُ فَقَالَتْ لَعَلَّكَ أَنْ تَرُدَّنِي كَمَا رَدَدْتَ مَاعِزَ بْنَ مَالِكٍ فَوَاللَّهِ إِنِّي لَحُبْلَى ‏.‏ فَقَالَ لَهَا ‏"‏ ارْجِعِي ‏"‏ ‏.‏ فَرَجَعَتْ فَلَمَّا كَانَ الْغَدُ أَتَتْهُ فَقَالَ لَهَا ‏"‏ ارْجِعِي حَتَّى تَلِدِي ‏"‏ ‏.‏ فَرَجَعَتْ فَلَمَّا وَلَدَتْ أَتَتْهُ بِالصَّبِيِّ فَقَالَتْ هَذَا قَدْ وَلَدْتُهُ ‏.‏ فَقَالَ لَهَا ‏"‏ ارْجِعِي فَأَرْضِعِيهِ حَتَّى تَفْطِمِيهِ ‏"‏ ‏.‏ فَجَاءَتْ بِهِ وَقَدْ فَطَمَتْهُ وَفِي يَدِهِ شَىْءٌ يَأْكُلُهُ فَأَمَرَ بِالصَّبِيِّ فَدُفِعَ إِلَى رَجُلٍ مِنَ الْمُسْلِمِينَ وَأَمَرَ بِهَا فَحُفِرَ لَهَا وَأَمَرَ بِهَا فَرُجِمَتْ وَكَانَ خَالِدٌ فِيمَنْ يَرْجُمُهَا فَرَجَمَهَا بِحَجَرٍ فَوَقَعَتْ قَطْرَةٌ مِنْ دَمِهَا عَلَى وَجْنَتِهِ فَسَبَّهَا فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَهْلاً يَا خَالِدُ فَوَالَّذِي نَفْسِي بِيَدِهِ لَقَدْ تَابَتْ تَوْبَةً لَوْ تَابَهَا صَاحِبُ مَكْسٍ لَغُفِرَ لَهُ ‏"‏ ‏.‏ وَأَمَرَ بِهَا فَصُلِّيَ عَلَيْهَا فَدُفِنَتْ ‏.‏\hadithno{4442}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1695)}\hadithtrans{Buraidah said:A woman of Ghamid came to the Prophet (ﷺ) and said: I have committed fornication. He said: Go back. She returned, and on the next day she came to him again, and said: Perhaps you want to send me back as you did to Ma’iz b. Malik. I swear by Allah, I am pregnant. He said to her: Go back. She then returned and came to him the next day. He said to her: Go back until you give birth to a child. She then returned. When she gave birth to a child, she brought the child to him, and said: Here it is! I have given birth to it. He said: Go back, and suckle him until you wean him. When she had weaned him, she brought him (the boy) to him with something in his hand which he was eating. The boy was then given to a certain man of the Muslims and he (the Prophet) commanded regarding her. So a pit was dug for her, and he gave orders about her and she was stoned to death. Khalid was one of those who were throwing stones at her. He threw a stone at her. When a drop blood fell on his cheeks, he abused her. The Prophet (ﷺ) said to him: Gently, Khalid. By Him in whose hand my soul is, she has reported to such an extent that if one who wrongfully takes extra tax were to repent to a like extent, he would be forgiven. Then giving command regarding her, prayed over her and she was buried}}
\hadithdefcmd{abudawud}{4443}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، عَنْ زَكَرِيَّا أَبِي عِمْرَانَ، قَالَ سَمِعْتُ شَيْخًا، يُحَدِّثُ عَنِ ابْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَجَمَ امْرَأَةً فَحُفِرَ لَهَا إِلَى الثَّنْدُوَةِ ‏.‏ قَالَ أَبُو دَاوُدَ أَفْهَمَنِي رَجُلٌ عَنْ عُثْمَانَ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ الْغَسَّانِيُّ جُهَيْنَةُ وَغَامِدٌ وَبَارِقٌ وَاحِدٌ ‏.‏\hadithno{4443}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Zakariya Abi 'Imran: I heard an old man who transmitted from Abu Bakrah on this father's authority that the Prophet (ﷺ) had a woman stoned and a pit was dug up to her breasts. Abu Dawud said: A man made me understand it from 'Uthman (b. Abi Shaibah) Abu Dawud said: Al-Ghassani said: Juhainah, Ghamid and Bariq as the same}}
\hadithdefcmd{abudawud}{4444}{قَالَ أَبُو دَاوُدَ حُدِّثْتُ عَنْ عَبْدِ الصَّمَدِ بْنِ عَبْدِ الْوَارِثِ، قَالَ حَدَّثَنَا زَكَرِيَّا بْنُ سُلَيْمٍ، بِإِسْنَادِهِ نَحْوَهُ زَادَ ثُمَّ رَمَاهَا بِحَصَاةٍ مِثْلَ الْحُمُّصَةِ ثُمَّ قَالَ ‏ "‏ ارْمُوا وَاتَّقُوا الْوَجْهَ ‏"‏ ‏.‏ فَلَمَّا طَفِئَتْ أَخْرَجَهَا فَصَلَّى عَلَيْهَا وَقَالَ فِي التَّوْبَةِ نَحْوَ حَدِيثِ بُرَيْدَةَ ‏.‏\hadithno{4444}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Abu Dawud said:A similar tradition has been transmitted by Zakariya b. Salim through a different chain of narrators. This version adds: He (the Prophet) then threw a pebble like a gram at her. He then said: Throw at her and avoid her face. When se died, he took her out and prayed over her. About repentance he said similar to the tradition on Buraidah}}
\hadithdefcmd{abudawud}{4445}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّهُمَا أَخْبَرَاهُ أَنَّ رَجُلَيْنِ اخْتَصَمَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ أَحَدُهُمَا يَا رَسُولَ اللَّهِ اقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ ‏.‏ وَقَالَ الآخَرُ وَكَانَ أَفْقَهَهُمَا أَجَلْ يَا رَسُولَ اللَّهِ فَاقْضِ بَيْنَنَا بِكِتَابِ اللَّهِ وَائْذَنْ لِي أَنْ أَتَكَلَّمَ ‏.‏ قَالَ ‏"‏ تَكَلَّمْ ‏"‏ ‏.‏ قَالَ إِنَّ ابْنِي كَانَ عَسِيفًا عَلَى هَذَا - وَالْعَسِيفُ الأَجِيرُ - فَزَنَى بِامْرَأَتِهِ فَأَخْبَرُونِي أَنَّمَا عَلَى ابْنِي الرَّجْمَ فَافْتَدَيْتُ مِنْهُ بِمِائَةِ شَاةٍ وَبِجَارِيَةٍ لِي ثُمَّ إِنِّي سَأَلْتُ أَهْلَ الْعِلْمِ فَأَخْبَرُونِي أَنَّمَا عَلَى ابْنِي جَلْدُ مِائَةٍ وَتَغْرِيبُ عَامٍ وَإِنَّمَا الرَّجْمُ عَلَى امْرَأَتِهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا وَالَّذِي نَفْسِي بِيَدِهِ لأَقْضِيَنَّ بَيْنَكُمَا بِكِتَابِ اللَّهِ أَمَّا غَنَمُكَ وَجَارِيَتُكَ فَرَدٌّ إِلَيْكَ ‏"‏ ‏.‏ وَجَلَدَ ابْنَهُ مِائَةً وَغَرَّبَهُ عَامًا وَأَمَرَ أُنَيْسًا الأَسْلَمِيَّ أَنْ يَأْتِيَ امْرَأَةَ الآخَرِ فَإِنِ اعْتَرَفَتْ رَجَمَهَا فَاعْتَرَفَتْ فَرَجَمَهَا ‏.‏\hadithno{4445}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6633، 6634) Sahih Muslim (1698)}\hadithtrans{Abu Hurairah and Zaid b. Khalid al-Juhani said:Two men brought a dispute before the Messenger of Allah (ﷺ). One of them said: Pronounce judgement between us in accordance with Allah’s Book, Messenger of Allah! The other who had more understanding said: Yes, Messenger of Allah! Pronounce judgement between us in accordance with Allah’s Book, and allow me to speak. He (the Prophet) said: Speak, He then said: My son who was a hired servant with this(man) committed fornication with his wife, and when I was told that my son must be stoned to death, I ransomed him with a hundred sheep and a slave girl of mine; but when I asked the learned, they told me that my son should receive a hundred lashes and be banished for a year, and that stoning to death applied only to man’s wife. The apostle of Allah (ﷺ) replied: By him in whose hand my soul is, I shall certainly pronounce judgment between you in accordance with Allah’s Book. Your sheep and your slave girl must be returned to you, and your son shall receive a hundred lashes and be banished for a year. And he commanded Unias al-Aslami go to that man’s wife, and if she confessed, he should stone her to death. She confessed and he stoned her}}
\hadithdefcmd{abudawud}{4446}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، قَالَ قَرَأْتُ عَلَى مَالِكِ بْنِ أَنَسٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ قَالَ إِنَّ الْيَهُودَ جَاءُوا إِلَى النَّبِيِّ صلى الله عليه وسلم فَذَكَرُوا لَهُ أَنَّ رَجُلاً مِنْهُمْ وَامْرَأَةً زَنَيَا فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا تَجِدُونَ فِي التَّوْرَاةِ فِي شَأْنِ الزِّنَا ‏"‏ ‏.‏ فَقَالُوا نَفْضَحُهُمْ وَيُجْلَدُونَ ‏.‏ فَقَالَ عَبْدُ اللَّهِ بْنُ سَلاَمٍ كَذَبْتُمْ إِنَّ فِيهَا الرَّجْمَ ‏.‏ فَأَتَوْا بِالتَّوْرَاةِ فَنَشَرُوهَا فَجَعَلَ أَحَدُهُمْ يَدَهُ عَلَى آيَةِ الرَّجْمِ ثُمَّ جَعَلَ يَقْرَأُ مَا قَبْلَهَا وَمَا بَعْدَهَا فَقَالَ لَهُ عَبْدُ اللَّهِ بْنُ سَلاَمٍ ارْفَعْ يَدَكَ ‏.‏ فَرَفَعَهَا فَإِذَا فِيهَا آيَةُ الرَّجْمِ فَقَالُوا صَدَقَ يَا مُحَمَّدُ فِيهَا آيَةُ الرَّجْمِ ‏.‏ فَأَمَرَ بِهِمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَرُجِمَا ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ عُمَرَ فَرَأَيْتُ الرَّجُلَ يَحْنِي عَلَى الْمَرْأَةِ يَقِيهَا الْحِجَارَةَ ‏.‏\hadithno{4446}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6841) Sahih Muslim (1699)}\hadithtrans{Ibn ‘Umar said:some jews came to the Messenger of Allah (ﷺ) and mentioned to him that a man and a women of their number had committed fornication. The Messenger of Allah (ﷺ) asked them: What do you find in the Torah about stoning? They replied: We disgrace them and they should be flogged. ‘Abd Allah b. Salam said: You lie; it contains (instruction for) stoning. So they brought the Torah and spread it out, and one of them put his hand over the verse of stoning and read what preceded it and what followed it. ‘Abd Allah b. Salam said to him: Lift your hand. When he did so, the verse of stoning was seen to be in it. They then said: He has spoken the truth, Muhammad, the verse of stoning is in it. The Messenger of Allah (ﷺ) then gave command regarding them, and they were stoned to death. ‘Abd Allah b. ‘Umar said: I saw the man leaning on the woman protecting her from the stones}}
\hadithdefcmd{abudawud}{4447}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ مَرُّوا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِيَهُودِيٍّ قَدْ حُمِّمَ وَجْهُهُ وَهُوَ يُطَافُ بِهِ فَنَاشَدَهُمْ مَا حَدُّ الزَّانِي فِي كِتَابِهِمْ قَالَ فَأَحَالُوهُ عَلَى رَجُلٍ مِنْهُمْ فَنَشَدَهُ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَا حَدُّ الزَّانِي فِي كِتَابِكُمْ ‏"‏ ‏.‏ فَقَالَ الرَّجْمُ وَلَكِنْ ظَهَرَ الزِّنَا فِي أَشْرَافِنَا فَكَرِهْنَا أَنْ يُتْرَكَ الشَّرِيفُ وَيُقَامَ عَلَى مَنْ دُونَهُ فَوَضَعْنَا هَذَا عَنَّا ‏.‏ فَأَمَرَ بِهِ رَسُولُ اللَّهِ صلى الله عليه وسلم فَرُجِمَ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ إِنِّي أَوَّلُ مَنْ أَحْيَا مَا أَمَاتُوا مِنْ كِتَابِكَ ‏"‏ ‏.‏\hadithno{4447}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1700)}\hadithtrans{Al-Bara’ b. Azib said:The people passed by the Messenger of Allah (ﷺ) with a jew whose face blackened with charcoal and he was being taken around. He adjured them by Allah and asked: What is the prescribed punishment for a fornicator in your Divine book? He (the narrator) said: They referred him to a man of them. The Prophet (ﷺ) adjured him and asked: What is the punishment for a fornication in your Divine Book? He replied: Stoning. But fornication spread among our people of rank, so we disliked that a person of rank should be left alone and the punishment be inflicted on one who is lower in rank than him. So we suspended it for us. The Messenger of Allah (ﷺ) then commanded regarding him and he was stoned to death. He then said: O Allah! I am the first to give life to a command of Thy Book which they had killed}}
\hadithdefcmd{abudawud}{4448}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ مُرَّ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِيَهُودِيٍّ مُحَمَّمٍ مَجْلُودٍ فَدَعَاهُمْ فَقَالَ ‏"‏ هَكَذَا تَجِدُونَ حَدَّ الزَّانِي ‏"‏ ‏.‏ فَقَالُوا نَعَمْ ‏.‏ فَدَعَا رَجُلاً مِنْ عُلَمَائِهِمْ قَالَ لَهُ ‏"‏ نَشَدْتُكَ بِاللَّهِ الَّذِي أَنْزَلَ التَّوْرَاةَ عَلَى مُوسَى هَكَذَا تَجِدُونَ حَدَّ الزَّانِي فِي كِتَابِكُمْ ‏"‏ ‏.‏ فَقَالَ اللَّهُمَّ لاَ وَلَوْلاَ أَنَّكَ نَشَدْتَنِي بِهَذَا لَمْ أُخْبِرْكَ نَجِدُ حَدَّ الزَّانِي فِي كِتَابِنَا الرَّجْمَ وَلَكِنَّهُ كَثُرَ فِي أَشْرَافِنَا فَكُنَّا إِذَا أَخَذْنَا الرَّجُلَ الشَّرِيفَ تَرَكْنَاهُ وَإِذَا أَخَذْنَا الرَّجُلَ الضَّعِيفَ أَقَمْنَا عَلَيْهِ الْحَدَّ فَقُلْنَا تَعَالَوْا فَنَجْتَمِعَ عَلَى شَىْءٍ نُقِيمُهُ عَلَى الشَّرِيفِ وَالْوَضِيعِ فَاجْتَمَعْنَا عَلَى التَّحْمِيمِ وَالْجَلْدِ وَتَرَكْنَا الرَّجْمَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اللَّهُمَّ إِنِّي أَوَّلُ مَنْ أَحْيَا أَمْرَكَ إِذْ أَمَاتُوهُ ‏"‏ ‏.‏ فَأَمَرَ بِهِ فَرُجِمَ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ يَا أَيُّهَا الرَّسُولُ لاَ يَحْزُنْكَ الَّذِينَ يُسَارِعُونَ فِي الْكُفْرِ ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ يَقُولُونَ إِنْ أُوتِيتُمْ هَذَا فَخُذُوهُ وَإِنْ لَمْ تُؤْتَوْهُ فَاحْذَرُوا ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ وَمَنْ لَمْ يَحْكُمْ بِمَا أَنْزَلَ اللَّهُ فَأُولَئِكَ هُمُ الْكَافِرُونَ ‏\}‏ فِي الْيَهُودِ إِلَى قَوْلِهِ ‏\{‏ وَمَنْ لَمْ يَحْكُمْ بِمَا أَنْزَلَ اللَّهُ فَأُولَئِكَ هُمُ الظَّالِمُونَ ‏\}‏ فِي الْيَهُودِ إِلَى قَوْلِهِ ‏\{‏ وَمَنْ لَمْ يَحْكُمْ بِمَا أَنْزَلَ اللَّهُ فَأُولَئِكَ هُمُ الْفَاسِقُونَ ‏\}‏ قَالَ هِيَ فِي الْكُفَّارِ كُلُّهَا يَعْنِي هَذِهِ الآيَةَ ‏.‏\hadithno{4448}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1700)}\hadithtrans{Narrated Al-Bara' ibn Azib: The people passed by the Messenger of Allah (ﷺ) with a Jew who was blackened with charcoal and who was being flogged. He called them and said: Is this the prescribed punishment for a fornicator? They said: Yes. He then called on a learned man among them and asked him: I adjure you by Allah Who revealed the Torah to Moses, do you find this prescribed punishment for a fornicator in your divine Book? He said: By Allah, no. If you had not adjured me about this, I should not have informed you. We find stoning to be prescribed punishment for a fornicator in our Divine Book. But it (fornication) became frequent in our people of rank; so when we seized a person of rank, we left him alone, and when we seized a weak person, we inflicted the prescribed punishment on him. So we said: Come, let us agree on something which may be enforced equally on people of higher and lower rank. So we agreed to blacken the face of a criminal with charcoal, and flog him, and we abandoned stoning. The Messenger of Allah (ﷺ) then said: O Allah, I am the first to give life to Thy command which they have killed. So he commanded regarding him (the Jew) and he was stoned to death. Allah Most High then sent down: "O Apostle, let not those who race one another into unbelief, make thee grieve..." up to "They say: If you are given this, take it, but if not, beware!...." up to "And if any do fail to judge by (the light of) what Allah hath revealed, they are (no better than) unbelievers," about Jews, up to "And if any do fail to judge by (the right of) what Allah hath revealed, they are no better than) wrong-doers" about Jews: and revealed the verses up to "And if any do fail to judge by (the light of) what Allah hath revealed, they are (no better than) those who rebel." About this he said: This whole verse was revealed about the infidels}}
\hadithdefcmd{abudawud}{4449}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي هِشَامُ بْنُ سَعْدٍ، أَنَّ زَيْدَ بْنَ أَسْلَمَ، حَدَّثَهُ عَنِ ابْنِ عُمَرَ، قَالَ أَتَى نَفَرٌ مِنْ يَهُودَ فَدَعَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم إِلَى الْقُفِّ فَأَتَاهُمْ فِي بَيْتِ الْمِدْرَاسِ فَقَالُوا يَا أَبَا الْقَاسِمِ إِنَّ رَجُلاً مِنَّا زَنَى بِامْرَأَةٍ فَاحْكُمْ بَيْنَهُمْ فَوَضَعُوا لِرَسُولِ اللَّهِ صلى الله عليه وسلم وِسَادَةً فَجَلَسَ عَلَيْهَا ثُمَّ قَالَ ‏"‏ ائْتُونِي بِالتَّوْرَاةِ ‏"‏ ‏.‏ فَأُتِيَ بِهَا فَنَزَعَ الْوِسَادَةَ مِنْ تَحْتِهِ فَوَضَعَ التَّوْرَاةَ عَلَيْهَا ثُمَّ قَالَ ‏"‏ آمَنْتُ بِكِ وَبِمَنْ أَنْزَلَكِ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ ائْتُونِي بِأَعْلَمِكُمْ ‏"‏ ‏.‏ فَأُتِيَ بِفَتًى شَابٍّ ثُمَّ ذَكَرَ قِصَّةَ الرَّجْمِ نَحْوَ حَدِيثِ مَالِكٍ عَنْ نَافِعٍ ‏.‏\hadithno{4449}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah Ibn Umar: A group of Jews came and invited the Messenger of Allah (ﷺ) to Quff. So he visited them in their school. They said: AbulQasim, one of our men has committed fornication with a woman; so pronounce judgment upon them. They placed a cushion for the Messenger of Allah (ﷺ) who sat on it and said: Bring the Torah. It was then brought. He then withdrew the cushion from beneath him and placed the Torah on it saying: I believed in thee and in Him Who revealed thee. He then said: Bring me one who is learned among you. Then a young man was brought. The transmitter then mentioned the rest of the tradition of stoning similar to the one transmitted by Malik from Nafi'(No)}}
\hadithdefcmd{abudawud}{4450}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنَا رَجُلٌ، مِنْ مُزَيْنَةَ ح وَحَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنَا يُونُسُ، قَالَ قَالَ مُحَمَّدُ بْنُ مُسْلِمٍ سَمِعْتُ رَجُلاً، مِنْ مُزَيْنَةَ مِمَّنْ يَتَّبِعُ الْعِلْمَ وَيَعِيهِ - ثُمَّ اتَّفَقَا - وَنَحْنُ عِنْدَ سَعِيدِ بْنِ الْمُسَيَّبِ فَحَدَّثَنَا عَنْ أَبِي هُرَيْرَةَ - وَهَذَا حَدِيثُ مَعْمَرٍ وَهُوَ أَتَمُّ - قَالَ زَنَى رَجُلٌ مِنَ الْيَهُودِ وَامْرَأَةٌ فَقَالَ بَعْضُهُمْ لِبَعْضٍ اذْهَبُوا بِنَا إِلَى هَذَا النَّبِيِّ فَإِنَّهُ نَبِيٌّ بُعِثَ بِالتَّخْفِيفِ فَإِنْ أَفْتَانَا بِفُتْيَا دُونَ الرَّجْمِ قَبِلْنَاهَا وَاحْتَجَجْنَا بِهَا عِنْدَ اللَّهِ قُلْنَا فُتْيَا نَبِيٍّ مِنْ أَنْبِيَائِكَ - قَالَ - فَأَتَوُا النَّبِيَّ صلى الله عليه وسلم وَهُوَ جَالِسٌ فِي الْمَسْجِدِ فِي أَصْحَابِهِ فَقَالُوا يَا أَبَا الْقَاسِمِ مَا تَرَى فِي رَجُلٍ وَامْرَأَةٍ زَنَيَا فَلَمْ يُكَلِّمْهُمْ كَلِمَةً حَتَّى أَتَى بَيْتَ مِدْرَاسِهِمْ فَقَامَ عَلَى الْبَابِ فَقَالَ ‏"‏ أَنْشُدُكُمْ بِاللَّهِ الَّذِي أَنْزَلَ التَّوْرَاةَ عَلَى مُوسَى مَا تَجِدُونَ فِي التَّوْرَاةِ عَلَى مَنْ زَنَى إِذَا أُحْصِنَ ‏"‏ ‏.‏ قَالُوا يُحَمَّمُ وَيُجَبَّهُ وَيُجْلَدُ - وَالتَّجْبِيَةُ أَنْ يُحْمَلَ الزَّانِيَانِ عَلَى حِمَارٍ وَتُقَابَلَ أَقْفِيَتُهُمَا وَيُطَافَ بِهِمَا - قَالَ وَسَكَتَ شَابٌّ مِنْهُمْ فَلَمَّا رَآهُ النَّبِيُّ صلى الله عليه وسلم سَكَتَ أَلَظَّ بِهِ النِّشْدَةَ فَقَالَ اللَّهُمَّ إِذْ نَشَدْتَنَا فَإِنَّا نَجِدُ فِي التَّوْرَاةِ الرَّجْمَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَمَا أَوَّلُ مَا ارْتَخَصْتُمْ أَمْرَ اللَّهِ ‏"‏ ‏.‏ قَالَ زَنَى ذُو قَرَابَةٍ مَعَ مَلِكٍ مِنْ مُلُوكِنَا فَأَخَّرَ عَنْهُ الرَّجْمَ ثُمَّ زَنَى رَجُلٌ فِي أُسْرَةٍ مِنَ النَّاسِ فَأَرَادَ رَجْمَهُ فَحَالَ قَوْمُهُ دُونَهُ وَقَالُوا لاَ يُرْجَمُ صَاحِبُنَا حَتَّى تَجِيءَ بِصَاحِبِكَ فَتَرْجُمَهُ فَاصْطَلَحُوا عَلَى هَذِهِ الْعُقُوبَةِ بَيْنَهُمْ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ فَإِنِّي أَحْكُمُ بِمَا فِي التَّوْرَاةِ ‏"‏ ‏.‏ فَأَمَرَ بِهِمَا فَرُجِمَا ‏.‏ قَالَ الزُّهْرِيُّ فَبَلَغَنَا أَنَّ هَذِهِ الآيَةَ نَزَلَتْ فِيهِمْ ‏\{‏ إِنَّا أَنْزَلْنَا التَّوْرَاةَ فِيهَا هُدًى وَنُورٌ يَحْكُمُ بِهَا النَّبِيُّونَ الَّذِينَ أَسْلَمُوا ‏\}‏ كَانَ النَّبِيُّ صلى الله عليه وسلم مِنْهُمْ ‏.‏\hadithno{4450}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: (This is Ma'mar's version which is more accurate.) A man and a woman of the Jews committed fornication. Some of them said to the others: Let us go to this Prophet, for he has been sent with an easy law. If he gives a judgment lighter than stoning, we shall accept it, and argue about it with Allah, saying: It is a judgment of one of your prophets. So they came to the Prophet (ﷺ) who was sitting in the mosque among his companions. They said: AbulQasim, what do you think about a man and a woman who committed fornication? He did not speak to them a word till he went to their school. He stood at the gate and said: I adjure you by Allah Who revealed the Torah to Moses, what (punishment) do you find in the Torah for a person who commits fornication, if he is married? They said: He shall be blackened with charcoal, taken round a donkey among the people, and flogged. A young man among them kept silent. When the Prophet (ﷺ) emphatically adjured him, he said: By Allah, since you have adjured us (we inform you that) we find stoning in the Torah (is the punishment for fornication). The Prophet (ﷺ) said: So when did you lessen the severity of Allah's command? He said: A relative of one of our kings had committed fornication, but his stoning was suspended. Then a man of a family of common people committed fornication. He was to have been stoned, but his people intervened and said: Our man shall not be stoned until you bring your man and stone him. So they made a compromise on this punishment between them. The Prophet (ﷺ) said: So I decide in accordance with what the Torah says. He then commanded regarding them and they were stoned to death. Az-Zuhri said: We have been informed that this verse was revealed about them: "It was We Who revealed the Law (to Moses): therein was guidance and light. By its standard have been judged the Jews, by the Prophet who bowed (as in Islam) to Allah's will}}
\hadithdefcmd{abudawud}{4451}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى أَبُو الأَصْبَغِ الْحَرَّانِيُّ، قَالَ حَدَّثَنِي مُحَمَّدٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنِ الزُّهْرِيِّ، قَالَ سَمِعْتُ رَجُلاً، مِنْ مُزَيْنَةَ يُحَدِّثُ سَعِيدَ بْنَ الْمُسَيَّبِ عَنْ أَبِي هُرَيْرَةَ، قَالَ زَنَى رَجُلٌ وَامْرَأَةٌ مِنَ الْيَهُودِ وَقَدْ أُحْصِنَا حِينَ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ وَقَدْ كَانَ الرَّجْمُ مَكْتُوبًا عَلَيْهِمْ فِي التَّوْرَاةِ فَتَرَكُوهُ وَأَخَذُوا بِالتَّجْبِيَةِ يُضْرَبُ مِائَةً بِحَبْلٍ مَطْلِيٍّ بِقَارٍ وَيُحْمَلُ عَلَى حِمَارٍ وَجْهُهُ مِمَّا يَلِي دُبُرَ الْحِمَارِ فَاجْتَمَعَ أَحْبَارٌ مِنْ أَحْبَارِهِمْ فَبَعَثُوا قَوْمًا آخَرِينَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا سَلُوهُ عَنْ حَدِّ الزَّانِي ‏.‏ وَسَاقَ الْحَدِيثَ قَالَ فِيهِ قَالَ وَلَمْ يَكُونُوا مِنْ أَهْلِ دِينِهِ فَيَحْكُمَ بَيْنَهُمْ فَخُيِّرَ فِي ذَلِكَ قَالَ ‏\{‏ فَإِنْ جَاءُوكَ فَاحْكُمْ بَيْنَهُمْ أَوْ أَعْرِضْ عَنْهُمْ ‏\}‏ ‏.‏\hadithno{4451}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah said:A man and a woman of the Jews who were married committed fornication at the time when the Messenger of Allah (ﷺ) came to Medina. Stoning was a prescribed punishment for them in accordance with the Torah, but they abandoned it and followed tajbiyyah, meaning, the man was beaten a hundred times with a rope painted with tar and was seated on a donkey with his face towards the tail of the donkey. Their rabbis then assembled and sent some people to the Messenger of Allah (ﷺ). They said to them: Ask him about the prescribed punishment for fornication. The transmitter then mentioned the rest of the tradition. They version adds: They were not the followers of his religion, and he (the prophet) was to pronounce judgment between them. So he was given a choice in this verse:”If they do come to thee, either judge between them, or decline to interfere}}
\hadithdefcmd{abudawud}{4452}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى الْبَلْخِيُّ، حَدَّثَنَا أَبُو أُسَامَةَ، قَالَ مُجَالِدٌ أَخْبَرَنَا عَنْ عَامِرٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ جَاءَتِ الْيَهُودُ بِرَجُلٍ وَامْرَأَةٍ مِنْهُمْ زَنَيَا فَقَالَ ائْتُونِي بِأَعْلَمِ رَجُلَيْنِ مِنْكُمْ فَأَتَوْهُ بِابْنَىْ صُورِيَا فَنَشَدَهُمَا ‏"‏ كَيْفَ تَجِدَانِ أَمْرَ هَذَيْنِ فِي التَّوْرَاةِ ‏"‏ ‏.‏ قَالاَ نَجِدُ فِي التَّوْرَاةِ إِذَا شَهِدَ أَرْبَعَةٌ أَنَّهُمْ رَأَوْا ذَكَرَهُ فِي فَرْجِهَا مِثْلَ الْمِيلِ فِي الْمُكْحُلَةِ رُجِمَا ‏.‏ قَالَ ‏"‏ فَمَا يَمْنَعُكُمَا أَنْ تَرْجُمُوهُمَا ‏"‏ ‏.‏ قَالاَ ذَهَبَ سُلْطَانُنَا فَكَرِهْنَا الْقَتْلَ فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِالشُّهُودِ فَجَاءُوا بِأَرْبَعَةٍ فَشَهِدُوا أَنَّهُمْ رَأَوْا ذَكَرَهُ فِي فَرْجِهَا مِثْلَ الْمِيلِ فِي الْمُكْحُلَةِ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِرَجْمِهِمَا ‏.‏\hadithno{4452}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Jabir b. ‘Abd Allah said:The Jews brought a man and a woman of them who had committed fornication. He said: Bring me two learned men or yours. So they brought the two sons of Suriya. He adjured them and said: How do you think about the matter if these two persons bear witness to the effect that they have seen his sexual organ in her female organ (penetrated) like a collyrium stick when enclosed in its case, they will be stoned to death. He asked: What is there which prevents you from stoning them: They replied : Our rule has gone, so we disapproved of killing. The Messenger of Allah (ﷺ) then called four witnesses. They brought four witnesses. Who testified that they had seen his sexual organ (penetrated) in her female organ like a collyrium stick when enclosed in its case. The Prophet (ﷺ) then gave orders for stoning them}}
\hadithdefcmd{abudawud}{4453}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ هُشَيْمٍ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، وَالشَّعْبِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ لَمْ يَذْكُرْ فَدَعَا بِالشُّهُودِ فَشَهِدُوا ‏.‏\hadithno{4453}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{A similar tradition has also been transmitted by Ibrahim and al-Sha’bi from the Prophet (ﷺ) through a different chain of narrators. But this version does not mention the words:He called the witnesses who testified}}
\hadithdefcmd{abudawud}{4454}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ هُشَيْمٍ، عَنِ ابْنِ شُبْرُمَةَ، عَنِ الشَّعْبِيِّ، بِنَحْوٍ مِنْهُ ‏.‏\hadithno{4454}\hadithgrade{Al-Albani: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{A similar tradition has also been transmitted by al-Sha’bi through a different chain of narrators}}
\hadithdefcmd{abudawud}{4455}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَسَنٍ الْمِصِّيصِيُّ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ حَدَّثَنَا ابْنُ جُرَيْجٍ، أَنَّهُ سَمِعَ أَبَا الزُّبَيْرِ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ رَجَمَ النَّبِيُّ صلى الله عليه وسلم رَجُلاً مِنَ الْيَهُودِ وَامْرَأَةً زَنَيَا ‏.‏\hadithno{4455}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1701)}\hadithtrans{Jabir bin ‘Abd Allah said:The Prophet (ﷺ) had a man and a woman of the Jews who had committed fornication stoned to death}}
\hadithdefcmd{abudawud}{4456}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا خَالِدُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُطَرِّفٌ، عَنْ أَبِي الْجَهْمِ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ بَيْنَا أَنَا أَطُوفُ، عَلَى إِبِلٍ لِي ضَلَّتْ إِذْ أَقْبَلَ رَكْبٌ أَوْ فَوَارِسُ مَعَهُمْ لِوَاءٌ فَجَعَلَ الأَعْرَابُ يُطِيفُونَ بِي لِمَنْزِلَتِي مِنَ النَّبِيِّ صلى الله عليه وسلم إِذْ أَتَوْا قُبَّةً فَاسْتَخْرَجُوا مِنْهَا رَجُلاً فَضَرَبُوا عُنُقَهُ فَسَأَلْتُ عَنْهُ فَذَكَرُوا أَنَّهُ أَعْرَسَ بِامْرَأَةِ أَبِيهِ ‏.‏\hadithno{4456}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Al-Bara' ibn Azib: while I was wandering in search of my camels which had strayed, a caravan or some horsemen carrying a standard came forward. The bedouin began to go round me for my position with the Prophet (ﷺ). They came to a domed structure, took out a man from it, and struck his neck. I asked about him. They told me that he had married his father's wife}}
\hadithdefcmd{abudawud}{4457}{حَدَّثَنَا عَمْرُو بْنُ قُسَيْطٍ الرَّقِّيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَمْرٍو، عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ عَدِيِّ بْنِ ثَابِتٍ، عَنْ يَزِيدَ بْنِ الْبَرَاءِ، عَنْ أَبِيهِ، قَالَ لَقِيتُ عَمِّي وَمَعَهُ رَايَةٌ فَقُلْتُ لَهُ أَيْنَ تُرِيدُ قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى رَجُلٍ نَكَحَ امْرَأَةَ أَبِيهِ فَأَمَرَنِي أَنْ أَضْرِبَ عُنُقَهُ وَآخُذَ مَالَهُ ‏.‏\hadithno{4457}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Al-Bara' ibn Azib: I met my uncle who was carrying a standard. I asked him: Where are you going? He said: The Messenger of Allah (ﷺ) has sent me to a man who has married his father's wife. He has ordered me to cut off his head and take his property}}
\hadithdefcmd{abudawud}{4458}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، حَدَّثَنَا قَتَادَةُ، عَنْ خَالِدِ بْنِ عُرْفُطَةَ، عَنْ حَبِيبِ بْنِ سَالِمٍ، أَنَّ رَجُلاً، يُقَالُ لَهُ عَبْدُ الرَّحْمَنِ بْنُ حُنَيْنٍ وَقَعَ عَلَى جَارِيَةِ امْرَأَتِهِ فَرُفِعَ إِلَى النُّعْمَانِ بْنِ بَشِيرٍ وَهُوَ أَمِيرٌ عَلَى الْكُوفَةِ فَقَالَ لأَقْضِيَنَّ فِيكَ بِقَضِيَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم إِنْ كَانَتْ أَحَلَّتْهَا لَكَ جَلَدْتُكَ مِائَةً وَإِنْ لَمْ تَكُنْ أَحَلَّتْهَا لَكَ رَجَمْتُكَ بِالْحِجَارَةِ ‏.‏ فَوَجَدُوهُ قَدْ أَحَلَّتْهَا لَهُ فَجَلَدَهُ مِائَةً ‏.‏ قَالَ قَتَادَةُ كَتَبْتُ إِلَى حَبِيبِ بْنِ سَالِمٍ فَكَتَبَ إِلَىَّ بِهَذَا ‏.‏\hadithno{4458}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated An-Nu'man ibn Bashir: Habib ibn Salim said: A man called AbdurRahman ibn Hunayn had intercourse with his wife's slave-girl. The matter was brought to an-Nu'man ibn Bashir who was the Governor of Kufah. He said: I shall decide between you in accordance with the decision of the Messenger of Allah (ﷺ). If she made her lawful for you, I shall flog you one hundred lashes. If she did not make her lawful for you, I shall stone you to death. So they found that she had made her lawful for him. He, therefore, flogged him one hundred lashes. Qatadah said: I wrote to Habib b. Salim; so he wrote this (tradition) to me}}
\hadithdefcmd{abudawud}{4459}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ أَبِي بِشْرٍ، عَنْ خَالِدِ بْنِ عُرْفُطَةَ، عَنْ حَبِيبِ بْنِ سَالِمٍ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الرَّجُلِ يَأْتِي جَارِيَةَ امْرَأَتِهِ قَالَ ‏ "‏ إِنْ كَانَتْ أَحَلَّتْهَا لَهُ جُلِدَ مِائَةً وَإِنْ لَمْ تَكُنْ أَحَلَّتْهَا لَهُ رَجَمْتُهُ ‏"‏ ‏.‏\hadithno{4459}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated An-Nu'man ibn Bashir: The Prophet (ﷺ) said: about a man who had (unlawful) intercourse with his wife's slave girl: If she made her lawful for him, he will be flogged one hundred lashes; if she did not make her lawful for him, I shall stone him}}
\hadithdefcmd{abudawud}{4460}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ قَبِيصَةَ بْنِ حُرَيْثٍ، عَنْ سَلَمَةَ بْنِ الْمُحَبَّقِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى فِي رَجُلٍ وَقَعَ عَلَى جَارِيَةِ امْرَأَتِهِ إِنْ كَانَ اسْتَكْرَهَهَا فَهِيَ حُرَّةٌ وَعَلَيْهِ لِسَيِّدَتِهَا مِثْلُهَا فَإِنْ كَانَتْ طَاوَعَتْهُ فَهِيَ لَهُ وَعَلَيْهِ لِسَيِّدَتِهَا مِثْلُهَا ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ يُونُسُ بْنُ عُبَيْدٍ وَعَمْرُو بْنُ دِينَارٍ وَمَنْصُورُ بْنُ زَاذَانَ وَسَلاَّمٌ عَنِ الْحَسَنِ هَذَا الْحَدِيثَ بِمَعْنَاهُ لَمْ يَذْكُرْ يُونُسُ وَمَنْصُورٌ قَبِيصَةَ ‏.‏\hadithno{4460}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Salamah ibn al-Muhabbaq: The Messenger of Allah (ﷺ) made a decision about a man who had intercourse with his wife's slave-girl as follows. If he forced her, she is free, and he shall give her mistress a slave-girl similar to her; if she asked him to have intercourse voluntarily, she will belong to him, and he shall give her mistress a slave-girl similar to her. Abu Dawud said: This tradition has been transmitted by Yunus b. 'Ubaid, 'Amr b. Dinar, Mansur b. Zadhan and Salam from al-Hasan to the same effect. But yunus and Mansur did not mention Qabisah}}
\hadithdefcmd{abudawud}{4461}{حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ الدِّرْهَمِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَلَمَةَ بْنِ الْمُحَبَّقِ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ إِلاَّ أَنَّهُ قَالَ وَإِنْ كَانَتْ طَاوَعَتْهُ فَهِيَ حُرَّةٌ وَمِثْلُهَا مِنْ مَالِهِ لِسَيِّدَتِهَا ‏.‏\hadithno{4461}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Salamah ibn al-Muhabbaq: A similar tradition (to the No. 4445) has also been transmitted by Salamah ibn al-Muhabbaq from the Prophet (ﷺ). This version has: If she asked her to have intercourse with her voluntarily, then she and a similar slave-girl would be given to her mistress from his property}}
\hadithdefcmd{abudawud}{4462}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ عَلِيٍّ النُّفَيْلِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ وَجَدْتُمُوهُ يَعْمَلُ عَمَلَ قَوْمِ لُوطٍ فَاقْتُلُوا الْفَاعِلَ وَالْمَفْعُولَ بِهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ سُلَيْمَانُ بْنُ بِلاَلٍ عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو مِثْلَهُ وَرَوَاهُ عَبَّادُ بْنُ مَنْصُورٍ عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ رَفَعَهُ وَرَوَاهُ ابْنُ جُرَيْجٍ عَنْ إِبْرَاهِيمَ عَنْ دَاوُدَ بْنِ الْحُصَيْنِ عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ رَفَعَهُ ‏.‏\hadithno{4462}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: If you find anyone doing as Lot's people did, kill the one who does it, and the one to whom it is done. Abu Dawud said: A similar tradition has also been transmitted by Sulaiman b. Bilal from 'Amr b. Abi 'Umar. And 'Abbad b. Mansur transmitted it from 'Ikrimah on the authority of Ibn 'Abbas who transmitted it from the Prophet (ﷺ). It has also been transmitted by Ibn Juraij from Ibrahim from Dawud b. Al-Husain from 'Ikrimah on the authority of Ibn 'Abbas who transmitted it from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{4463}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ رَاهَوَيْهِ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي ابْنُ خُثَيْمٍ، قَالَ سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، وَمُجَاهِدًا، يُحَدِّثَانِ عَنِ ابْنِ عَبَّاسٍ، فِي الْبِكْرِ يُوجَدُ عَلَى اللُّوطِيَّةِ قَالَ يُرْجَمُ ‏.‏ قَالَ أَبُو دَاوُدَ حَدِيثُ عَاصِمٍ يُضَعِّفُ حَدِيثَ عَمْرِو بْنِ أَبِي عَمْرٍو ‏.‏\hadithno{4463}\hadithgrade{Al-Albani: Sahih Isnaad Mauquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Isnaad Mauquf; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: If a man who is not married is seized committing sodomy, he will be stoned to death. Abu Dawud said: The tradition of 'Asim proved the tradition of 'Amir b. Abi 'Amr as weak}}
\hadithdefcmd{abudawud}{4464}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، حَدَّثَنِي عَمْرُو بْنُ أَبِي عَمْرٍو، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَتَى بَهِيمَةً فَاقْتُلُوهُ وَاقْتُلُوهَا مَعَهُ ‏"‏ ‏.‏ قَالَ قُلْتُ لَهُ مَا شَأْنُ الْبَهِيمَةِ قَالَ مَا أُرَاهُ إِلاَّ قَالَ ذَلِكَ أَنَّهُ كَرِهَ أَنْ يُؤْكَلَ لَحْمُهَا وَقَدْ عُمِلَ بِهَا ذَلِكَ الْعَمَلُ ‏.‏ قَالَ أَبُو دَاوُدَ لَيْسَ هَذَا بِالْقَوِيِّ ‏.‏\hadithno{4464}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: If anyone has sexual intercourse with an animal, kill him and kill it along with him. I (Ikrimah) said: I asked him (Ibn Abbas): What offence can be attributed to the animal/ He replied: I think he (the Prophet) disapproved of its flesh being eaten when such a thing had been done to it. Abu Dawud said: This is not a strong tradition}}
\hadithdefcmd{abudawud}{4465}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، أَنَّ شَرِيكًا، وَأَبَا الأَحْوَصِ، وَأَبَا، بَكْرِ بْنَ عَيَّاشٍ حَدَّثُوهُمْ عَنْ عَاصِمٍ، عَنْ أَبِي رَزِينٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَيْسَ عَلَى الَّذِي يَأْتِي الْبَهِيمَةَ حَدٌّ ‏.‏ قَالَ أَبُو دَاوُدَ كَذَا قَالَ عَطَاءٌ وَقَالَ الْحَكَمُ أَرَى أَنْ يُجْلَدَ وَلاَ يَبْلُغَ بِهِ الْحَدَّ ‏.‏ وَقَالَ الْحَسَنُ هُوَ بِمَنْزِلَةِ الزَّانِي ‏.‏ قَالَ أَبُو دَاوُدَ حَدِيثُ عَاصِمٍ يُضَعِّفُ حَدِيثَ عَمْرِو بْنِ أَبِي عَمْرٍو ‏.‏\hadithno{4465}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Asim reported from Abu Razin on the authority of Ibn 'Abbas saying:There is no prescribed punishment for one who has sexual intercourse with an animal. Abu Dawud said: 'Ata is also so. Al Hakam said: I think he should be flogged, but the number should not reach the one of the prescribed punishment. Al-Hasan said: He is like a fornicator. Abu Dawud said: THe tradition of 'Asim proves the tradition of 'Amr b. Abi 'Amr as weak}}
\hadithdefcmd{abudawud}{4466}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا طَلْقُ بْنُ غَنَّامٍ، حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَفْصٍ، حَدَّثَنَا أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَجُلاً أَتَاهُ فَأَقَرَّ عِنْدَهُ أَنَّهُ زَنَى بِامْرَأَةٍ سَمَّاهَا لَهُ فَبَعَثَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْمَرْأَةِ فَسَأَلَهَا عَنْ ذَلِكَ فَأَنْكَرَتْ أَنْ تَكُونَ زَنَتْ فَجَلَدَهُ الْحَدَّ وَتَرَكَهَا ‏.‏\hadithno{4466}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{Narrated Sahl ibn Sa'd: A man came to the Prophet (ﷺ) and made acknowledgment before him that he had committed fornication with a woman whom he named. The Messenger of Allah (ﷺ) sent someone to the woman and he asked her about it. She denied that she had committed fornication. So he gave him the prescribed punishment of lashes and left her}}
\hadithdefcmd{abudawud}{4467}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا مُوسَى بْنُ هَارُونَ الْبُرْدِيُّ، حَدَّثَنَا هِشَامُ بْنُ يُوسُفَ، عَنِ الْقَاسِمِ بْنِ فَيَّاضٍ الأَبْنَاوِيِّ، عَنْ خَلاَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنِ ابْنِ الْمُسَيَّبِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَجُلاً، مِنْ بَكْرِ بْنِ لَيْثٍ أَتَى النَّبِيَّ صلى الله عليه وسلم فَأَقَرَّ أَنَّهُ زَنَى بِامْرَأَةٍ أَرْبَعَ مَرَّاتٍ فَجَلَدَهُ مِائَةً وَكَانَ بِكْرًا ثُمَّ سَأَلَهُ الْبَيِّنَةَ عَلَى الْمَرْأَةِ فَقَالَتْ كَذَبَ وَاللَّهِ يَا رَسُولَ اللَّهِ فَجَلَدَهُ حَدَّ الْفِرْيَةِ ثَمَانِينَ ‏.‏\hadithno{4467}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: A man of Bakr ibn Layth came to the Prophet (ﷺ) and made confession four times that he had committed fornication with a woman, so he had a hundred lashes administered to him. The man had not been married. He then asked him to produce proof against the woman, and she said: I swear by Allah, Messenger of Allah, that he has lied. Then he was given the punishment of eighty lashes of falsehood}}
\hadithdefcmd{abudawud}{4468}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا أَبُو الأَحْوَصِ، حَدَّثَنَا سِمَاكٌ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، قَالاَ قَالَ عَبْدُ اللَّهِ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنِّي عَالَجْتُ امْرَأَةً مِنْ أَقْصَى الْمَدِينَةِ فَأَصَبْتُ مِنْهَا مَا دُونَ أَنْ أَمَسَّهَا فَأَنَا هَذَا فَأَقِمْ عَلَىَّ مَا شِئْتَ ‏.‏ فَقَالَ عُمَرُ قَدْ سَتَرَ اللَّهُ عَلَيْكَ لَوْ سَتَرْتَ عَلَى نَفْسِكَ ‏.‏ فَلَمْ يَرُدَّ عَلَيْهِ النَّبِيُّ صلى الله عليه وسلم شَيْئًا فَانْطَلَقَ الرَّجُلُ فَأَتْبَعَهُ النَّبِيُّ صلى الله عليه وسلم رَجُلاً فَدَعَاهُ فَتَلاَ عَلَيْهِ ‏\{‏ وَأَقِمِ الصَّلاَةَ طَرَفَىِ النَّهَارِ وَزُلَفًا مِنَ اللَّيْلِ ‏\}‏ إِلَى آخِرِ الآيَةِ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ يَا رَسُولَ اللَّهِ أَلَهُ خَاصَّةً أَمْ لِلنَّاسِ كَافَّةً فَقَالَ ‏"‏ بَلْ لِلنَّاسِ كَافَّةً ‏"‏ ‏.‏\hadithno{4468}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (526) Sahih Muslim (2763)}\hadithtrans{‘Abd Allah (b. Mas’ud) said:A man came to the Prophet (ﷺ) and said: I contacted directly a women at the furthest part of the city (i.e., Medina), and I did with her everything except sexual intercourse. So here I am; inflict any punishment you wish. Thereupon ‘Umar said: Allah has concealed your fault; it would have been better if you also had concealed it yourself. The Prophet (ﷺ) sent a men after him. (When he came) he recited the verse: “And establish regular prayers at the two ends of the day and at the approaches of the night. . .” up to the end of the verse. A man from the people got up and asked: Is it particular to him, Messenger of Allah, or for the people in general? He replied: It is all the people}}
\hadithdefcmd{abudawud}{4469}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، عَنْ أَبِي هُرَيْرَةَ، وَزَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ عَنِ الأَمَةِ إِذَا زَنَتْ وَلَمْ تُحْصَنْ قَالَ ‏ "‏ إِنْ زَنَتْ فَاجْلِدُوهَا ثُمَّ إِنْ زَنَتْ فَاجْلِدُوهَا ثُمَّ إِنْ زَنَتْ فَاجْلِدُوهَا ثُمَّ إِنْ زَنَتْ فَبِيعُوهَا وَلَوْ بِضَفِيرٍ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ لاَ أَدْرِي فِي الثَّالِثَةِ أَوِ الرَّابِعَةِ وَالضَّفِيرُ الْحَبْلُ ‏.‏\hadithno{4469}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2153، 2154) Sahih Muslim (1703)}\hadithtrans{Abu Hurairah and Zaid b. Khalid al-Juhani said:The Messenger of Allah (ﷺ) was asked about a slave-woman who commits fornication, and she is not married: If she commits fornication, flog her: if she commits fornication again flog her; if only for a rope of hair (dafir). Ibn Shihab: I do not know whether he (the Prophet) said it is a third or a fourth time}}
\hadithdefcmd{abudawud}{4470}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ الْمَقْبُرِيُّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا زَنَتْ أَمَةُ أَحَدِكُمْ فَلْيَحُدَّهَا وَلاَ يُعَيِّرْهَا ثَلاَثَ مِرَارٍ فَإِنْ عَادَتْ فِي الرَّابِعَةِ فَلْيَجْلِدْهَا وَلْيَبِعْهَا بِضَفِيرٍ أَوْ بِحَبْلٍ مِنْ شَعْرٍ ‏"‏ ‏.‏\hadithno{4470}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1703)}\hadithtrans{Abu Hurairah reported the Prophet (ﷺ) as saying:When the slave-woman of any of you commits fornication, he should inflict the prescribed punishment on her, but not hurl reproaches at her. This is to be done up to three times. If she a fourth time, he should flog her, and sell her even if only for a rope of hair}}
\hadithdefcmd{abudawud}{4471}{حَدَّثَنَا ابْنُ نُفَيْلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ قَالَ فِي كُلِّ مَرَّةٍ ‏"‏ فَلْيَضْرِبْهَا كِتَابُ اللَّهِ وَلاَ يُثَرِّبْ عَلَيْهَا ‏"‏ ‏.‏ وَقَالَ فِي الرَّابِعَةِ ‏"‏ فَإِنْ عَادَتْ فَلْيَضْرِبْهَا كِتَابُ اللَّهِ ثُمَّ لْيَبِعْهَا وَلَوْ بِحَبْلٍ مِنْ شَعْرٍ ‏"‏ ‏.‏\hadithno{4471}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Zubair Ali Zai: Sahih Bukhari (6839) Sahih Muslim (1703)}\hadithtrans{This tradition has been transmitted by Abu Hurairah from the Prophet (ﷺ). This version has:He said each time: He should give her the appropriate beating according to Allah’s Book, but not Hurl reproaches at her. He said a fourth time: If she does it again, he should give her the appropriate beating according to Allah’s Book, and then should sell her even if only for a rope of hair}}
\hadithdefcmd{abudawud}{4472}{حَدَّثَنَا أَحْمَدُ بْنُ سَعِيدٍ الْهَمْدَانِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَبُو أُمَامَةَ بْنُ سَهْلِ بْنِ حُنَيْفٍ، أَنَّهُ أَخْبَرَهُ بَعْضُ، أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الأَنْصَارِ أَنَّهُ اشْتَكَى رَجُلٌ مِنْهُمْ حَتَّى أُضْنِيَ فَعَادَ جِلْدَةً عَلَى عَظْمٍ فَدَخَلَتْ عَلَيْهِ جَارِيَةٌ لِبَعْضِهِمْ فَهَشَّ لَهَا فَوَقَعَ عَلَيْهَا فَلَمَّا دَخَلَ عَلَيْهِ رِجَالُ قَوْمِهِ يَعُودُونَهُ أَخْبَرَهُمْ بِذَلِكَ وَقَالَ اسْتَفْتُوا لِي رَسُولَ اللَّهِ صلى الله عليه وسلم فَإِنِّي قَدْ وَقَعْتُ عَلَى جَارِيَةٍ دَخَلَتْ عَلَىَّ ‏.‏ فَذَكَرُوا ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَقَالُوا مَا رَأَيْنَا بِأَحَدٍ مِنَ النَّاسِ مِنَ الضُّرِّ مِثْلَ الَّذِي هُوَ بِهِ لَوْ حَمَلْنَاهُ إِلَيْكَ لَتَفَسَّخَتْ عِظَامُهُ مَا هُوَ إِلاَّ جِلْدٌ عَلَى عَظْمٍ فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يَأْخُذُوا لَهُ مِائَةَ شِمْرَاخٍ فَيَضْرِبُوهُ بِهَا ضَرْبَةً وَاحِدَةً ‏.‏\hadithno{4472}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Umamah b. Sahl Hunaif: AbuUmamah ibn Sahl ibn Hunayf said that some companions of the Messenger of Allah (ﷺ) told that one of their men suffered so much from some illness that he pined away until he was skin and bone (i.e. only a skeleton). A slave-girl of someone visited him, and he was cheered by her and had unlawful intercourse with her. When his people came to visit the patient, he told them about it. He said: Ask the Messenger of Allah (ﷺ) about the legal verdict for me, for I have had unlawful intercourse with a slave-girl who visited me. So they mentioned it to the Messenger of Allah (ﷺ) saying: We have never seen anyone (so weak) from illness as he is. If we bring him to you, his bones will disintegrate. He is only skin and bone. So the Messenger of Allah (ﷺ) commanded them to take one hundred twigs and strike him once}}
\hadithdefcmd{abudawud}{4473}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا إِسْرَائِيلُ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنْ أَبِي جَمِيلَةَ، عَنْ عَلِيٍّ، رضى الله عنه قَالَ فَجَرَتْ جَارِيَةٌ لآلِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ يَا عَلِيُّ انْطَلِقْ فَأَقِمْ عَلَيْهَا الْحَدَّ ‏"‏ ‏.‏ فَانْطَلَقْتُ فَإِذَا بِهَا دَمٌ يَسِيلُ لَمْ يَنْقَطِعْ فَأَتَيْتُهُ فَقَالَ ‏"‏ يَا عَلِيُّ أَفَرَغْتَ ‏"‏ ‏.‏ قُلْتُ أَتَيْتُهَا وَدَمُهَا يَسِيلُ ‏.‏ فَقَالَ ‏"‏ دَعْهَا حَتَّى يَنْقَطِعَ دَمُهَا ثُمَّ أَقِمْ عَلَيْهَا الْحَدَّ وَأَقِيمُوا الْحُدُودَ عَلَى مَا مَلَكَتْ أَيْمَانُكُمْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ أَبُو الأَحْوَصِ عَنْ عَبْدِ الأَعْلَى وَرَوَاهُ شُعْبَةُ عَنْ عَبْدِ الأَعْلَى فَقَالَ فِيهِ ‏"‏ لاَ تَضْرِبْهَا حَتَّى تَضَعَ ‏"‏ ‏.‏ وَالأَوَّلُ أَصَحُّ ‏.‏\hadithno{4473}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: A slave-girl belonging to the house of the Messenger of Allah (ﷺ) committed fornication. He (the Prophet) said: Rush up, Ali, and inflict the prescribed punishment on her. I then hurried up, and saw that blood was flowing from her, and did not stop. So I came to him and he said: Have you finished inflicting (punishment on her)? I said: I went to her while her blood was flowing. He said: Leave her alone till her bleeding stops; then inflict the prescribed punishment on her. And inflict the prescribed punishment on those whom your right hands possess (i.e. slaves). Abu Dawud said: A similar tradition has been transmitted by Abu al-Ahwas from 'Abd al-A'la, and also by Shu'bah from 'Abd al-A'la. This version has: He said: Do not give her beating until she gives birth to a child. But the former (version) is sounder}}
\hadithdefcmd{abudawud}{4474}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ الثَّقَفِيُّ، وَمَالِكُ بْنُ عَبْدِ الْوَاحِدِ الْمِسْمَعِيُّ، - وَهَذَا حَدِيثُهُ - أَنَّ ابْنَ أَبِي عَدِيٍّ، حَدَّثَهُمْ عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، رضى الله عنها قَالَتْ لَمَّا نَزَلَ عُذْرِي قَامَ النَّبِيُّ صلى الله عليه وسلم عَلَى الْمِنْبَرِ فَذَكَرَ ذَاكَ وَتَلاَ - تَعْنِي الْقُرْآنَ - فَلَمَّا نَزَلَ مِنَ الْمِنْبَرِ أَمَرَ بِالرَّجُلَيْنِ وَالْمَرْأَةِ فَضُرِبُوا حَدَّهُمْ ‏.‏\hadithno{4474}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: When my vindication came down, the Prophet (ﷺ) mounted the pulpit and mentioned that, and recited the Qur'an. Then when he came down from the pulpit he ordered regarding the two men and the woman, and they were given the prescribed punishment}}
\hadithdefcmd{abudawud}{4475}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، بِهَذَا الْحَدِيثِ لَمْ يَذْكُرْ عَائِشَةَ قَالَ فَأَمَرَ بِرَجُلَيْنِ وَامْرَأَةٍ مِمَّنْ تَكَلَّمَ بِالْفَاحِشَةِ حَسَّانَ بْنِ ثَابِتٍ وَمِسْطَحِ بْنِ أُثَاثَةَ ‏.‏ قَالَ النُّفَيْلِيُّ وَيَقُولُونَ الْمَرْأَةُ حَمْنَةُ بِنْتُ جَحْشٍ ‏.‏\hadithno{4475}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Lighairihi; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{The tradition mentioned above (No. 4459) has also been transmitted by Muhammad ibn Ishaq through a different chain of narrators. But he did not mention Aisha. This version has:He (the Prophet) commanded regarding the two men and the woman who spoke obscenity were Hassan ibn Thabit and Mistah ibn Uthathah. An-Nufayl said: It is said that the woman was Hammah daughter of Jahsh}}
\hadithdefcmd{abudawud}{4476}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، - وَهَذَا حَدِيثُهُ - قَالاَ حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ مُحَمَّدِ بْنِ عَلِيِّ بْنِ رُكَانَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَقِتْ فِي الْخَمْرِ حَدًّا ‏.‏ وَقَالَ ابْنُ عَبَّاسٍ شَرِبَ رَجُلٌ فَسَكِرَ فَلُقِيَ يَمِيلُ فِي الْفَجِّ فَانْطُلِقَ بِهِ إِلَى النَّبِيِّ صلى الله عليه وسلم فَلَمَّا حَاذَى بِدَارِ الْعَبَّاسِ انْفَلَتَ فَدَخَلَ عَلَى الْعَبَّاسِ فَالْتَزَمَهُ فَذُكِرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَضَحِكَ وَقَالَ ‏ "‏ أَفَعَلَهَا ‏"‏ ‏.‏ وَلَمْ يَأْمُرْ فِيهِ بِشَىْءٍ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا مِمَّا تَفَرَّدَ بِهِ أَهْلُ الْمَدِينَةِ حَدِيثُ الْحَسَنِ بْنِ عَلِيٍّ هَذَا ‏.‏\hadithno{4476}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) did not prescribe any punishment for drinking wine. Ibn Abbas said: A man who had drunk wine and become intoxicated was found staggering on the road, so he was taken to the Prophet (ﷺ). When he was opposite al-Abbas's house, he escaped, and going in to al-Abbas, he grasped hold of him. When that was mentioned to the Prophet (ﷺ), he laughed and said: Did he do that? and he gave no command regarding him. Abu Dawud said: This tradition of al-Hasan b. 'Ali has been transmitted only by the people of Medina}}
\hadithdefcmd{abudawud}{4477}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو ضَمْرَةَ، عَنْ يَزِيدَ بْنِ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أُتِيَ بِرَجُلٍ قَدْ شَرِبَ فَقَالَ ‏"‏ اضْرِبُوهُ ‏"‏ ‏.‏ قَالَ أَبُو هُرَيْرَةَ فَمِنَّا الضَّارِبُ بِيَدِهِ وَالضَّارِبُ بِنَعْلِهِ وَالضَّارِبُ بِثَوْبِهِ فَلَمَّا انْصَرَفَ قَالَ بَعْضُ الْقَوْمِ أَخْزَاكَ اللَّهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَقُولُوا هَكَذَا لاَ تُعِينُوا عَلَيْهِ الشَّيْطَانَ ‏"‏ ‏.‏\hadithno{4477}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6777)}\hadithtrans{Abu Hurairah said:When a man who had drunk wine was brought to the Messenger of Allah (ﷺ), he said: Beat him. Abu Hurairah said: Some struck him with their hands, some with their garment. When he turned his face, some people said: Allah put you shame! The Messenger of Allah (ﷺ) said: Do not say like that and help the devil to get power over him}}
\hadithdefcmd{abudawud}{4478}{حَدَّثَنَا مُحَمَّدُ بْنُ دَاوُدَ بْنِ أَبِي نَاجِيَةَ الإِسْكَنْدَرَانِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يَحْيَى بْنُ أَيُّوبَ، وَحَيْوَةُ بْنُ شُرَيْحٍ، وَابْنُ، لَهِيعَةَ عَنِ ابْنِ الْهَادِ، بِإِسْنَادِهِ وَمَعْنَاهُ قَالَ فِيهِ بَعْدَ الضَّرْبِ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَصْحَابِهِ ‏"‏ بَكِّتُوهُ ‏"‏ ‏.‏ فَأَقْبَلُوا عَلَيْهِ يَقُولُونَ مَا اتَّقَيْتَ اللَّهَ مَا خَشِيتَ اللَّهَ وَمَا اسْتَحَيْتَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ أَرْسَلُوهُ وَقَالَ فِي آخِرِهِ ‏"‏ وَلَكِنْ قُولُوا اللَّهُمَّ اغْفِرْ لَهُ اللَّهُمَّ ارْحَمْهُ ‏"‏ ‏.‏ وَبَعْضُهُمْ يَزِيدُ الْكَلِمَةَ وَنَحْوَهَا ‏.‏\hadithno{4478}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn al- Had through a different chain of narrators to the same effect. He said after the word “beating”:The Messenger of Allah (ﷺ) then said to his Companions: Reproach him, and they faced him and said: You have not respected Allah, you have not feared Allah and you have not shown shame before the Messenger of Allah (ﷺ). Then they released him. Some have also added similar words}}
\hadithdefcmd{abudawud}{4479}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، - الْمَعْنَى - عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم جَلَدَ فِي الْخَمْرِ بِالْجَرِيدِ وَالنِّعَالِ وَجَلَدَ أَبُو بَكْرٍ رضى الله عنه أَرْبَعِينَ فَلَمَّا وَلِيَ عُمَرُ دَعَا النَّاسَ فَقَالَ لَهُمْ إِنَّ النَّاسَ قَدْ دَنَوْا مِنَ الرِّيفِ - وَقَالَ مُسَدَّدٌ مِنَ الْقُرَى وَالرِّيفِ - فَمَا تَرَوْنَ فِي حَدِّ الْخَمْرِ فَقَالَ لَهُ عَبْدُ الرَّحْمَنِ بْنُ عَوْفٍ نَرَى أَنْ تَجْعَلَهُ كَأَخَفِّ الْحُدُودِ ‏.‏ فَجَلَدَ فِيهِ ثَمَانِينَ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ابْنُ أَبِي عَرُوبَةَ عَنْ قَتَادَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ جَلَدَ بِالْجَرِيدِ وَالنِّعَالِ أَرْبَعِينَ ‏.‏ وَرَوَاهُ شُعْبَةُ عَنْ قَتَادَةَ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ضَرَبَ بِجَرِيدَتَيْنِ نَحْوَ الأَرْبَعِينَ ‏.‏\hadithno{4479}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6773) Sahih Muslim (1706)}\hadithtrans{Anas b. Malik said:The Prophet (ﷺ) gave a beating with palm-branches and sandals for drinking wine and Abu Bakr gave lashes. When ‘Umar came to power, he called upon people and said to them: The people are living now near watering placing, and, according to Musaddad’s version, “near villages and watering places, so what do you say about the punishment for (drinking) wine? ‘Abd al-Rahman b. ‘Awf said: We think that you should prescribe the lightest punishment. So he fixed eight lashes for it. Abu Dawud said: It has also been transmitted by Ibn Al 'Arubah from Qatadah from the Prophet (ﷺ) to the effect that he gave a beating forty times with palm branches and sandals. And Shu'bah narrated it from Qatadah on the authority of Anas from Prophet (ﷺ). This version has: He gave a beating with two palm-branches about forty times}}
\hadithdefcmd{abudawud}{4480}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، وَمُوسَى بْنُ إِسْمَاعِيلَ، - الْمَعْنَى - قَالاَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا عَبْدُ اللَّهِ الدَّانَاجُ، حَدَّثَنِي حُضَيْنُ بْنُ الْمُنْذِرِ الرَّقَاشِيُّ، - هُوَ أَبُو سَاسَانَ - قَالَ شَهِدْتُ عُثْمَانَ بْنَ عَفَّانَ وَأُتِيَ بِالْوَلِيدِ بْنِ عُقْبَةَ فَشَهِدَ عَلَيْهِ حُمْرَانُ وَرَجُلٌ آخَرُ فَشَهِدَ أَحَدُهُمَا أَنَّهُ رَآهُ شَرِبَهَا - يَعْنِي الْخَمْرَ - وَشَهِدَ الآخَرُ أَنَّهُ رَآهُ يَتَقَيَّأُهَا فَقَالَ عُثْمَانُ إِنَّهُ لَمْ يَتَقَيَّأْهَا حَتَّى شَرِبَهَا ‏.‏ فَقَالَ لِعَلِيٍّ رضى الله عنه أَقِمْ عَلَيْهِ الْحَدَّ ‏.‏ فَقَالَ عَلِيٌّ لِلْحَسَنِ أَقِمْ عَلَيْهِ الْحَدَّ ‏.‏ فَقَالَ الْحَسَنُ وَلِّ حَارَّهَا مَنْ تَوَلَّى قَارَّهَا ‏.‏ فَقَالَ عَلِيٌّ لِعَبْدِ اللَّهِ بْنِ جَعْفَرٍ أَقِمْ عَلَيْهِ الْحَدَّ ‏.‏ قَالَ فَأَخَذَ السَّوْطَ فَجَلَدَهُ وَعَلِيٌّ يَعُدُّ فَلَمَّا بَلَغَ أَرْبَعِينَ قَالَ حَسْبُكَ جَلَدَ النَّبِيُّ صلى الله عليه وسلم أَرْبَعِينَ - أَحْسِبُهُ قَالَ - وَجَلَدَ أَبُو بَكْرٍ أَرْبَعِينَ وَعُمَرُ ثَمَانِينَ وَكُلٌّ سُنَّةٌ وَهَذَا أَحَبُّ إِلَىَّ ‏.‏\hadithno{4480}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1707)}\hadithtrans{Hudayn ibn al-Mundhir ar-Ruqashi, who was AbuSasan, said:I was present with Uthman ibn Affan when al-Walid ibn Uqbah was brought to him. Humran and another man bore witness against him (for drinking wine). One of them testified that he had seen him drinking wine, and the other testified that he had seen him vomiting it. Uthman said: He could not vomit it, unless he did not drink it. He said to Ali: Inflict the prescribed punishment on him. Ali said to al-Hasan: Inflict the prescribed punishment on him. Al-Hasan said: He who has enjoyed its pleasure should also bear its burden. So Ali said to Abdullah ibn Ja'far: Inflict the prescribed punishment on him. He took a whip and struck him with it while Ali was counting. When he reached (struck) forty (lashes), he said: It is sufficient. The Prophet (ﷺ) gave forty lashes. I think he also said: "And AbuBakr gave forty lashes, and Uthman eighty. This is all sunnah (standard practice). And this is dearer to me}}
\hadithdefcmd{abudawud}{4481}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ أَبِي عَرُوبَةَ، عَنِ الدَّانَاجِ، عَنْ حُضَيْنِ بْنِ الْمُنْذِرِ، عَنْ عَلِيٍّ، رضى الله عنه قَالَ جَلَدَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْخَمْرِ وَأَبُو بَكْرٍ أَرْبَعِينَ وَكَمَّلَهَا عُمَرُ ثَمَانِينَ وَكُلٌّ سُنَّةٌ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَالَ الأَصْمَعِيُّ وَلِّ حَارَّهَا مَنْ تَوَلَّى قَارَّهَا وَلِّ شَدِيدَهَا مَنْ تَوَلَّى هَيِّنَهَا ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا كَانَ سَيِّدَ قَوْمِهِ حُضَيْنُ بْنُ الْمُنْذِرِ أَبُو سَاسَانَ ‏.‏\hadithno{4481}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1707)}\hadithtrans{Narrated Ali ibn AbuTalib: The Messenger of Allah (ﷺ) and AbuBakr gave forty lashes for drinking wine and Umar made it eighty. And all this is sunnah, the model and standard practice. Abu Dawud said: Al-Asma'i explaning the maxim, "He who enjoys its cold should bear its heat," said: He who enjoys the easy if it should also take the responsibility of the hard of it. Abu Dawud said: Hudain b. al-Mundhir Abu Sasan was the leader of his tribe}}
\hadithdefcmd{abudawud}{4482}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، عَنْ عَاصِمٍ، عَنْ أَبِي صَالِحٍ، ذَكْوَانَ عَنْ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا شَرِبُوا الْخَمْرَ فَاجْلِدُوهُمْ ثُمَّ إِنْ شَرِبُوا فَاجْلِدُوهُمْ ثُمَّ إِنْ شَرِبُوا فَاجْلِدُوهُمْ ثُمَّ إِنْ شَرِبُوا فَاقْتُلُوهُمْ ‏"‏ ‏.‏\hadithno{4482}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Mu'awiyah ibn AbuSufyan: The Prophet (ﷺ) said: If they (the people) drink wine, flog them, again if they drink it, flog them. Again if they drink it, kill them}}
\hadithdefcmd{abudawud}{4483}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ حُمَيْدِ بْنِ يَزِيدَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ بِهَذَا الْمَعْنَى قَالَ وَأَحْسِبُهُ قَالَ فِي الْخَامِسَةِ ‏ "‏ إِنْ شَرِبَهَا فَاقْتُلُوهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَا فِي حَدِيثِ أَبِي غُطَيْفٍ فِي الْخَامِسَةِ ‏.‏\hadithno{4483}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Muhyi Al-Din Abdul Hamid: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Ibn ‘Umar through a different chain of narrators to the same effect. This version has :I think he said for the fifth time: If he drinks it, kill him. Abu Dawud said: And similarly the word “a fifth time” occurs in the tradition of Abu Ghutaif}}
\hadithdefcmd{abudawud}{4484}{حَدَّثَنَا نَصْرُ بْنُ عَاصِمٍ الأَنْطَاكِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ الْوَاسِطِيُّ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الْحَارِثِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا سَكِرَ فَاجْلِدُوهُ ثُمَّ إِنْ سَكِرَ فَاجْلِدُوهُ ثُمَّ إِنْ سَكِرَ فَاجْلِدُوهُ فَإِنْ عَادَ الرَّابِعَةَ فَاقْتُلُوهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَا حَدِيثُ عُمَرَ بْنِ أَبِي سَلَمَةَ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ إِذَا شَرِبَ الْخَمْرَ فَاجْلِدُوهُ فَإِنْ عَادَ الرَّابِعَةَ فَاقْتُلُوهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَا حَدِيثُ سُهَيْلٍ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ إِنْ شَرِبُوا الرَّابِعَةَ فَاقْتُلُوهُمْ ‏"‏ ‏.‏ وَكَذَا حَدِيثُ ابْنِ أَبِي نُعْمٍ عَنِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَكَذَا حَدِيثُ عَبْدِ اللَّهِ بْنِ عَمْرٍو عَنِ النَّبِيِّ صلى الله عليه وسلم وَالشَّرِيدِ عَنِ النَّبِيِّ صلى الله عليه وسلم وَفِي حَدِيثِ الْجَدَلِيِّ عَنْ مُعَاوِيَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ فَإِنْ عَادَ فِي الثَّالِثَةِ أَوِ الرَّابِعَةِ فَاقْتُلُوهُ ‏"‏ ‏.‏\hadithno{4484}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If he is intoxicated, flog him; again if he is intoxicated, flog him; again if he is intoxicated, flog him if he does it again a fourth time, kill him. Abu Dawud said: And there is a similar tradition of Umar ibn AbuSalamah, from his father, on the authority of AbuHurayrah, from the Prophet (ﷺ): If he drinks wine, flog him if he does it so again, a fourth time, kill him. Abu Dawud said: And there is similar tradition of Suhail from Abu Salih on the authority of Abu Hurairah, from the Prophet (ﷺ): It they drink a fourth time, kill them. And there is similar tradition of Ibn Abi Nu'm on the authority of Ibn 'Umar from Prophet (ﷺ). There is also similar tradition of 'Abd Allah b. 'Amr from the Prophet (ﷺ), and from Sharid from the Prophet (ﷺ). And in the tradition of al-Jadli from Mu'awiyah, the Prophet (ﷺ) said: If he does so again third or fourth time, kill him}}
\hadithdefcmd{abudawud}{4485}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، حَدَّثَنَا سُفْيَانُ، قَالَ الزُّهْرِيُّ أَخْبَرَنَا عَنْ قَبِيصَةَ بْنِ ذُؤَيْبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ شَرِبَ الْخَمْرَ فَاجْلِدُوهُ فَإِنْ عَادَ فَاجْلِدُوهُ فَإِنْ عَادَ فَاجْلِدُوهُ فَإِنْ عَادَ فِي الثَّالِثَةِ أَوِ الرَّابِعَةِ فَاقْتُلُوهُ ‏"‏ ‏.‏ فَأُتِيَ بِرَجُلٍ قَدْ شَرِبَ فَجَلَدَهُ ثُمَّ أُتِيَ بِهِ فَجَلَدَهُ ثُمَّ أُتِيَ بِهِ فَجَلَدَهُ ثُمَّ أُتِيَ بِهِ فَجَلَدَهُ وَرَفَعَ الْقَتْلَ فَكَانَتْ رُخْصَةً ‏.‏ قَالَ سُفْيَانُ حَدَّثَ الزُّهْرِيُّ بِهَذَا الْحَدِيثِ وَعِنْدَهُ مَنْصُورُ بْنُ الْمُعْتَمِرِ وَمُخَوَّلُ بْنُ رَاشِدٍ فَقَالَ لَهُمَا كُونَا وَافِدَىْ أَهْلِ الْعِرَاقِ بِهَذَا الْحَدِيثِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذَا الْحَدِيثَ الشَّرِيدُ بْنُ سُوَيْدٍ وَشُرَحْبِيلُ بْنُ أَوْسٍ وَعَبْدُ اللَّهِ بْنُ عَمْرٍو وَعَبْدُ اللَّهِ بْنُ عُمَرَ وَأَبُو غُطَيْفٍ الْكِنْدِيُّ وَأَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{4485}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Qabisah ibn Dhuwayb: The Prophet (ﷺ) said: If anyone drinks wine, flog him; if he repeats it, flog him, and if he repeats it, flog him. If he does it again a third or a fourth time, kill him. A man who had drunk wine was brought (to him) and he gave him lashes. He was again brought to him, and he flogged him. He was again brought to him and he flogged him. He was again brought to him and he flogged him. The punishment of killing (for drinking) was repealed, and a concession was allowed. Sufyan said: Al-Zuhri transmitted this tradition when Mansur b. al-Mu'tamir amd Mukhawwal b. Rashid were present with him. He said to them: Take this tradition as a present to the people of Iraq. Abu Dawud said: This tradition has been transmitted by al-Sharid b. Suwaid, Sharahbil b. Aws, 'Abd Allah b. 'Amr, 'Abd Allah b. 'Umar, Abu Ghutaif al-Kindi, and Abu Salamah b. 'Abd al-Rahman from Abu Hurairah}}
\hadithdefcmd{abudawud}{4486}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى الْفَزَارِيُّ، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي حُصَيْنٍ، عَنْ عُمَيْرِ بْنِ سَعِيدٍ، عَنْ عَلِيٍّ، رضى الله عنه قَالَ لاَ أَدِي - أَوْ مَا كُنْتُ لأَدِيَ - مَنْ أَقَمْتُ عَلَيْهِ حَدًّا إِلاَّ شَارِبَ الْخَمْرِ فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمْ يَسُنَّ فِيهِ شَيْئًا إِنَّمَا هُوَ شَىْءٌ قُلْنَاهُ نَحْنُ ‏.‏\hadithno{4486}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{’Ali said:I shall not pay blood-money or (he said) : I am not going to pay blood-money for him on whom I inflicted the prescribed punishment except for the one who drank wine, for the Messenger of Allah (ﷺ) did not prescribe anything definite. It is a thing which we have decided (by agreement) ourselves}}
\hadithdefcmd{abudawud}{4487}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ الْمِصْرِيُّ ابْنُ أَخِي، رِشْدِينَ بْنِ سَعْدٍ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنَا أُسَامَةُ بْنُ زَيْدٍ، أَنَّ ابْنَ شِهَابٍ، حَدَّثَهُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَزْهَرَ، قَالَ كَأَنِّي أَنْظُرُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الآنَ وَهُوَ فِي الرِّحَالِ يَلْتَمِسُ رَحْلَ خَالِدِ بْنِ الْوَلِيدِ فَبَيْنَمَا هُوَ كَذَلِكَ إِذْ أُتِيَ بِرَجُلٍ قَدْ شَرِبَ الْخَمْرَ فَقَالَ لِلنَّاسِ ‏ "‏ اضْرِبُوهُ ‏"‏ ‏.‏ فَمِنْهُمْ مَنْ ضَرَبَهُ بِالنِّعَالِ وَمِنْهُمْ مَنْ ضَرَبَهُ بِالْعَصَا وَمِنْهُمْ مَنْ ضَرَبَهُ بِالْمِيتَخَةِ - قَالَ ابْنُ وَهْبٍ الْجَرِيدَةُ الرَّطْبَةُ - ثُمَّ أَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم تُرَابًا مِنَ الأَرْضِ فَرَمَى بِهِ فِي وَجْهِهِ ‏.‏\hadithno{4487}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbdurRahman ibn Azhar: I can still picture myself looking at the Messenger of Allah (ﷺ) who was among the camps of the Companions seeking the camp of Khalid ibn al-Walid, when a man who had drunk wine was brought before him. He asked the people: Beat him. Some struck him with sandals, some with sticks and some with fresh branches of the palm-tree (mitakhah). Ibn Wahb said: This (mitakhah) means green palm fronds. Then the apostle of Allah (ﷺ) took some dust from the ground and threw it on his face}}
\hadithdefcmd{abudawud}{4488}{حَدَّثَنَا ابْنُ السَّرْحِ، قَالَ وَجَدْتُ فِي كِتَابِ خَالِي عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ الْحَمِيدِ عَنْ عُقَيْلٍ أَنَّ ابْنَ شِهَابٍ أَخْبَرَهُ أَنَّ عَبْدَ اللَّهِ بْنَ عَبْدِ الرَّحْمَنِ بْنِ الأَزْهَرِ أَخْبَرَهُ عَنْ أَبِيهِ قَالَ أُتِيَ النَّبِيُّ صلى الله عليه وسلم بِشَارِبٍ وَهُوَ بِحُنَيْنٍ فَحَثَى فِي وَجْهِهِ التُّرَابَ ثُمَّ أَمَرَ أَصْحَابَهُ فَضَرَبُوهُ بِنِعَالِهِمْ وَمَا كَانَ فِي أَيْدِيهِمْ حَتَّى قَالَ لَهُمُ ‏ "‏ ارْفَعُوا ‏"‏ ‏.‏ فَرَفَعُوا فَتُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ جَلَدَ أَبُو بَكْرٍ فِي الْخَمْرِ أَرْبَعِينَ ثُمَّ جَلَدَ عُمَرُ أَرْبَعِينَ صَدْرًا مِنْ إِمَارَتِهِ ثُمَّ جَلَدَ ثَمَانِينَ فِي آخِرِ خِلاَفَتِهِ ثُمَّ جَلَدَ عُثْمَانُ الْحَدَّيْنِ كِلَيْهِمَا ثَمَانِينَ وَأَرْبَعِينَ ثُمَّ أَثْبَتَ مُعَاوِيَةُ الْحَدَّ ثَمَانِينَ ‏.‏\hadithno{4488}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbdurRahman ibn al-Azhar: A man who had drunk wine was brought before the Prophet (ﷺ) when he was in Hunayn. He threw some dust on his face. He then ordered his Companions and they beat him with their sandals and whatever they had in their hands. He then said to them: Leave him, and they left him. The Messenger of Allah (ﷺ) then died, and AbuBakr gave forty lashes for drinking wine, and then Umar in the beginning of his Caliphate inflicted forty stripes and at the end of his Caliphate he inflicted eighty stripes. Uthman (after him) inflicted both punishments, eighty and forty stripes, and finally Mu'awiyah established eighty stripes}}
\hadithdefcmd{abudawud}{4489}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا أُسَامَةُ بْنُ زَيْدٍ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَزْهَرَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم غَدَاةَ الْفَتْحِ وَأَنَا غُلاَمٌ شَابٌّ يَتَخَلَّلُ النَّاسَ يَسْأَلُ عَنْ مَنْزِلِ خَالِدِ بْنِ الْوَلِيدِ فَأُتِيَ بِشَارِبٍ فَأَمَرَهُمْ فَضَرَبُوهُ بِمَا فِي أَيْدِيهِمْ فَمِنْهُمْ مَنْ ضَرَبَهُ بِالسَّوْطِ وَمِنْهُمْ مَنْ ضَرَبَهُ بِعَصًا وَمِنْهُمْ مَنْ ضَرَبَهُ بِنَعْلِهِ وَحَثَى رَسُولُ اللَّهِ صلى الله عليه وسلم التُّرَابَ فَلَمَّا كَانَ أَبُو بَكْرٍ أُتِيَ بِشَارِبٍ فَسَأَلَهُمْ عَنْ ضَرْبِ النَّبِيِّ صلى الله عليه وسلم الَّذِي ضَرَبَهُ فَحَزَرُوهُ أَرْبَعِينَ فَضَرَبَ أَبُو بَكْرٍ أَرْبَعِينَ فَلَمَّا كَانَ عُمَرُ كَتَبَ إِلَيْهِ خَالِدُ بْنُ الْوَلِيدِ إِنَّ النَّاسَ قَدِ انْهَمَكُوا فِي الشُّرْبِ وَتَحَاقَرُوا الْحَدَّ وَالْعُقُوبَةَ ‏.‏ قَالَ هُمْ عِنْدَكَ فَسَلْهُمْ ‏.‏ وَعِنْدَهُ الْمُهَاجِرُونَ الأَوَّلُونَ فَسَأَلَهُمْ فَأَجْمَعُوا عَلَى أَنْ يَضْرِبَ ثَمَانِينَ ‏.‏ قَالَ وَقَالَ عَلِيٌّ إِنَّ الرَّجُلَ إِذَا شَرِبَ افْتَرَى فَأَرَى أَنْ يَجْعَلَهُ كَحَدِّ الْفِرْيَةِ ‏.‏ قَالَ أَبُو دَاوُدَ أَدْخَلَ عُقَيْلُ بْنُ خَالِدٍ بَيْنَ الزُّهْرِيِّ وَبَيْنَ ابْنِ الأَزْهَرِ فِي هَذَا الْحَدِيثِ عَبْدَ اللَّهِ بْنَ عَبْدِ الرَّحْمَنِ بْنِ الأَزْهَرِ عَنْ أَبِيهِ ‏.‏\hadithno{4489}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbdurRahman ibn Azhar: I saw the Messenger of Allah (ﷺ) on the morning of the conquest of Mecca when I was a young boy. He was walking among the people, seeking the camp of Khalid ibn al-Walid. A man who had drunk wine was brought (before him) and he ordered them (to beat him). So they beat him with what they had in their hands. Some struck him with whips, some with sticks and some with sandals. The Messenger of Allah (ﷺ) threw some dust on his face. When a man who had drunk wine was brought before AbuBakr, he asked them (i.e. the people) about the number of beatings which they gave him. They numbered it forty. So AbuBakr gave him forty lashes. When Umar came to power, Khalid ibn al-Walid wrote to him: The people have become addicted to drinking wine and they look down upon the prescribed punishment and its penalty. He said: They are with you, ask them. The immigrants who embraced Islam in the beginning were with him. He asked them and they agreed on the fact that (a drunkard) should be given eighty lashes. Ali said: When a man drinks wine, he tells lies. I, therefore, think that he should be prescribed punishment that is prescribed for telling lies.. Abu Dawud said: 'Uqail b. Khalid included in the chain of this tradition: "Abd Allah b. Abd al-Rahman b. al-Azhar from his father" between al-Zuhri and Ibn al-Azhar}}
\hadithdefcmd{abudawud}{4490}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا صَدَقَةُ، - يَعْنِي ابْنَ خَالِدٍ - حَدَّثَنَا الشُّعَيْثِيُّ، عَنْ زُفَرَ بْنِ وَثِيمَةَ، عَنْ حَكِيمِ بْنِ حِزَامٍ، أَنَّهُ قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُسْتَقَادَ فِي الْمَسْجِدِ وَأَنْ تُنْشَدَ فِيهِ الأَشْعَارُ وَأَنْ تُقَامَ فِيهِ الْحُدُودُ ‏.‏\hadithno{4490}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Hakim ibn Hizam: The Messenger of Allah (ﷺ) forbade to take retaliation in the mosque, to recite verses in it and to inflict the prescribed punishments in it}}
\hadithdefcmd{abudawud}{4491}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جَابِرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِي بُرْدَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُجْلَدُ فَوْقَ عَشْرِ جَلَدَاتٍ إِلاَّ فِي حَدٍّ مِنْ حُدُودِ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{4491}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih Bukhari (6848) Sahih Muslim (1708)}\hadithtrans{Abu Burdah reported the Messenger of Allah (ﷺ) as saying:No more than ten lashes are to be given, except in the case of one of the punishment prescribed by Allah, the Exalted}}
\hadithdefcmd{abudawud}{4492}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، أَنَّ بُكَيْرَ بْنَ الأَشَجِّ، حَدَّثَهُ عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ جَابِرٍ، أَنَّ أَبَاهُ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا بُرْدَةَ الأَنْصَارِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ فَذَكَرَ مَعْنَاهُ ‏.‏\hadithno{4492}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Burdah al-Ansari through a different chain of narrators. This version has:I heard the Messenger of Allah (ﷺ) say. . . He then mentioned the tradition to the same effect}}
\hadithdefcmd{abudawud}{4493}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عُمَرَ، - يَعْنِي ابْنَ أَبِي سَلَمَةَ - عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا ضَرَبَ أَحَدُكُمْ فَلْيَتَّقِ الْوَجْهَ ‏"‏ ‏.‏\hadithno{4493}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: When one of you inflicts a beating, he should avoid striking the face}}
