% Auto-generated chapter 8 for tirmidhi
% Hadiths in this chapter: 127

\hadithdefcmd{tirmidhi}{682}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ بْنِ كُرَيْبٍ حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ أَوَّلُ لَيْلَةٍ مِنْ شَهْرِ رَمَضَانَ صُفِّدَتِ الشَّيَاطِينُ وَمَرَدَةُ الْجِنِّ وَغُلِّقَتْ أَبْوَابُ النَّارِ فَلَمْ يُفْتَحْ مِنْهَا بَابٌ. وَفُتِّحَتْ أَبْوَابُ الْجَنَّةِ فَلَمْ يُغْلَقْ مِنْهَا بَابٌ وَيُنَادِي مُنَادٍ يَا بَاغِيَ الْخَيْرِ أَقْبِلْ وَيَا بَاغِيَ الشَّرِّ أَقْصِرْ وَلِلَّهِ عُتَقَاءُ مِنَ النَّارِ وَذَلِكَ كُلَّ لَيْلَةٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ وَابْنِ مَسْعُودٍ وَسَلْمَانَ ‏.‏\hadithno{682}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah said: "On the first night of the month of Ramadan, the Shayatin are shackled, the jinns are restrained, the gates of the Fires are shut such that no gate among them would be opened. The gates of Paradise are opened such that no gate among them would be closed, and a caller calls: 'O seeker of the good; come near!' and 'O seeker of evil; stop! For there are those whom Allah frees from the Fire.' And that is every night}}
\hadithdefcmd{tirmidhi}{683}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، وَالْمُحَارِبِيُّ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ صَامَ رَمَضَانَ وَقَامَهُ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَنْ قَامَ لَيْلَةَ الْقَدْرِ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ الَّذِي رَوَاهُ أَبُو بَكْرِ بْنُ عَيَّاشٍ حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ رِوَايَةِ أَبِي بَكْرِ بْنِ عَيَّاشٍ عَنِ الأَعْمَشِ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ إِلاَّ مِنْ حَدِيثِ أَبِي بَكْرٍ ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ عَنْ هَذَا الْحَدِيثِ، فَقَالَ حَدَّثَنَا الْحَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، قَوْلَهُ ‏"‏ إِذَا كَانَ أَوَّلُ لَيْلَةٍ مِنْ شَهْرِ رَمَضَانَ ‏"‏ ‏.‏ فَذَكَرَ الْحَدِيثَ ‏.‏ قَالَ مُحَمَّدٌ وَهَذَا أَصَحُّ عِنْدِي مِنْ حَدِيثِ أَبِي بَكْرِ بْنِ عَيَّاشٍ ‏.‏\hadithno{683}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah said: "Whoever fasts Ramadan and stands (in the night prayer) for it out of faith and seeking a reward (from Allah), he will be forgiven what preceded of his sins. Whoever stands (in the night prayer) on the Night of Al-Qadr out of faith and seeking a reward (from Allah), he will be forgiven what preceded of his sins}}
\hadithdefcmd{tirmidhi}{684}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَقَدَّمُوا الشَّهْرَ بِيَوْمٍ وَلاَ بِيَوْمَيْنِ إِلاَّ أَنْ يُوَافِقَ ذَلِكَ صَوْمًا كَانَ يَصُومُهُ أَحَدُكُمْ صُومُوا لِرُؤْيَتِهِ وَأَفْطِرُوا لِرُؤْيَتِهِ فَإِنْ غُمَّ عَلَيْكُمْ فَعُدُّوا ثَلاَثِينَ ثُمَّ أَفْطِرُوا ‏"‏ ‏.‏ رَوَى مَنْصُورُ بْنُ الْمُعْتَمِرِ عَنْ رِبْعِيِّ بْنِ حِرَاشٍ عَنْ بَعْضِ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم بِنَحْوِ هَذَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ بَعْضِ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ كَرِهُوا أَنْ يَتَعَجَّلَ الرَّجُلُ بِصِيَامٍ قَبْلَ دُخُولِ شَهْرِ رَمَضَانَ لِمَعْنَى رَمَضَانَ وَإِنْ كَانَ رَجُلٌ يَصُومُ صَوْمًا فَوَافَقَ صِيَامُهُ ذَلِكَ فَلاَ بَأْسَ بِهِ عِنْدَهُمْ ‏.‏\hadithno{684}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "Do not precede the month with a day nor with two days, unless that fast falls on a day that one of you would have (normally) fasted. Fast with its sighting and break fast with its sighting, and if it is cloudy, then count for thirty days, and then break (the fast)}}
\hadithdefcmd{tirmidhi}{685}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ عَلِيِّ بْنِ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَقَدَّمُوا شَهْرَ رَمَضَانَ بِصِيَامٍ قَبْلَهُ بِيَوْمٍ أَوْ يَوْمَيْنِ إِلاَّ أَنْ يَكُونَ رَجُلٌ كَانَ يَصُومُ صَوْمًا فَلْيَصُمْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{685}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah said: "Do no precede the month of Ramadan by fasting a day or two before it, unless it is the case of a man who normally performs some fast, then let him fast it}}
\hadithdefcmd{tirmidhi}{686}{حَدَّثَنَا أَبُو سَعِيدٍ عَبْدُ اللَّهِ بْنُ سَعِيدٍ الأَشَجُّ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ عَمْرِو بْنِ قَيْسٍ الْمُلاَئِيِّ، عَنْ أَبِي إِسْحَاقَ، عَنْ صِلَةَ بْنِ زُفَرَ، قَالَ كُنَّا عِنْدَ عَمَّارِ بْنِ يَاسِرٍ فَأُتِيَ بِشَاةٍ مَصْلِيَّةٍ فَقَالَ كُلُوا ‏.‏ فَتَنَحَّى بَعْضُ الْقَوْمِ فَقَالَ إِنِّي صَائِمٌ ‏.‏ فَقَالَ عَمَّارٌ مَنْ صَامَ الْيَوْمَ الَّذِي يَشُكُّ فِيهِ النَّاسُ فَقَدْ عَصَى أَبَا الْقَاسِمِ صلى الله عليه وسلم ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَمَّارٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَمَنْ بَعْدَهُمْ مِنَ التَّابِعِينَ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَمَالِكُ بْنُ أَنَسٍ وَعَبْدُ اللَّهِ بْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ كَرِهُوا أَنْ يَصُومَ الرَّجُلُ الْيَوْمَ الَّذِي يُشَكُّ فِيهِ وَرَأَى أَكْثَرُهُمْ إِنْ صَامَهُ فَكَانَ مِنْ شَهْرِ رَمَضَانَ أَنْ يَقْضِيَ يَوْمًا مَكَانَهُ ‏.‏\hadithno{686}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Silah bin Zufar said:"We were with Ammar bin Yasir when a roasted sheep was brought and he said: 'Eat.' Someone among the people said: 'I am fasting.' So Ammar said: 'Whoever fasts on a day in which there is doubt, then he has disobeyed Abul-Qasim (pbuh)}}
\hadithdefcmd{tirmidhi}{687}{حَدَّثَنَا مُسْلِمُ بْنُ حَجَّاجٍ، حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَحْصُوا هِلاَلَ شَعْبَانَ لِرَمَضَانَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ لاَ نَعْرِفُهُ مِثْلَ هَذَا إِلاَّ مِنْ حَدِيثِ أَبِي مُعَاوِيَةَ ‏.‏ وَالصَّحِيحُ مَا رُوِيَ عَنْ مُحَمَّدِ بْنِ عَمْرٍو عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تَقَدَّمُوا شَهْرَ رَمَضَانَ بِيَوْمٍ وَلاَ يَوْمَيْنِ ‏"‏ ‏.‏ وَهَكَذَا رُوِيَ عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ عَنْ أَبِي سَلَمَةَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوُ حَدِيثِ مُحَمَّدِ بْنِ عَمْرٍو اللَّيْثِيِّ ‏.‏\hadithno{687}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah said: "Count the (the appearances of) the crescent of Sha'ban for Ramadan}}
\hadithdefcmd{tirmidhi}{688}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَصُومُوا قَبْلَ رَمَضَانَ صُومُوا لِرُؤْيَتِهِ وَأَفْطِرُوا لِرُؤْيَتِهِ فَإِنْ حَالَتْ دُونَهُ غَيَايَةٌ فَأَكْمِلُوا ثَلاَثِينَ يَوْمًا ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَأَبِي بَكْرَةَ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ عَنْهُ مِنْ غَيْرِ وَجْهٍ ‏.‏\hadithno{688}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated that :the Messenger of Allah said: "Do not fast before Ramadan. Fast with its sighting, and break fast with its sighting, and if it is obscured from you, then complete thirty days}}
\hadithdefcmd{tirmidhi}{689}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَحْيَى بْنُ زَكَرِيَّا بْنِ أَبِي زَائِدَةَ، أَخْبَرَنِي عِيسَى بْنُ دِينَارٍ، عَنْ أَبِيهِ، عَنْ عَمْرِو بْنِ الْحَارِثِ بْنِ أَبِي ضِرَارٍ، عَنِ ابْنِ مَسْعُودٍ، قَالَ مَا صُمْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم تِسْعًا وَعِشْرِينَ أَكْثَرُ مِمَّا صُمْنَا ثَلاَثِينَ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَأَبِي هُرَيْرَةَ وَعَائِشَةَ وَسَعْدِ بْنِ أَبِي وَقَّاصٍ وَابْنِ عَبَّاسٍ وَابْنِ عُمَرَ وَأَنَسٍ وَجَابِرٍ وَأُمِّ سَلَمَةَ وَأَبِي بَكْرَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الشَّهْرُ يَكُونُ تِسْعًا وَعِشْرِينَ ‏"‏ ‏.‏\hadithno{689}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn Mas`ud said:"What I fasted with the Prophet that was twenty-nine (days), was more than what we fasted that was thirty." (He said): There are narrations on this topic from `Umar, Abu Hurairah, `A'isha, Sa`d bin Abi Waqqas, Ibn `Abbas, Ibn `Umar, Anas, Jabir, Umm Salamah, Abu Bakrah, that the Prophet (ﷺ) said: "The month is twenty nine (days)}}
\hadithdefcmd{tirmidhi}{690}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّهُ قَالَ آلَى رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ نِسَائِهِ شَهْرًا فَأَقَامَ فِي مَشْرُبَةٍ تِسْعًا وَعِشْرِينَ يَوْمًا قَالُوا يَا رَسُولَ اللَّهِ إِنَّكَ آلَيْتَ شَهْرًا فَقَالَ ‏ "‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{690}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Anas narrated:"The Messenger of Allah vowed to stay away from his wives for a month, so he stayed in a loft for twenty-nine days. They said: 'O Messenger of Allah, your vow was for a month,' so he said: 'The month is twenty-nine (days)}}
\hadithdefcmd{tirmidhi}{691}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا الْوَلِيدُ بْنُ أَبِي ثَوْرٍ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنِّي رَأَيْتُ الْهِلاَلَ ‏.‏ قَالَ ‏"‏ أَتَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ أَتَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ يَا بِلاَلُ أَذِّنْ فِي النَّاسِ أَنْ يَصُومُوا غَدًا ‏"‏ ‏.‏ حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا حُسَيْنٌ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ سِمَاكٍ، نَحْوَهُ بِهَذَا الإِسْنَادِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ فِيهِ اخْتِلاَفٌ ‏.‏ وَرَوَى سُفْيَانُ الثَّوْرِيُّ، وَغَيْرُهُ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً وَأَكْثَرُ أَصْحَابِ سِمَاكٍ رَوَوْا عَنْ سِمَاكٍ عَنْ عِكْرِمَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ قَالُوا تُقْبَلُ شَهَادَةُ رَجُلٍ وَاحِدٍ فِي الصِّيَامِ ‏.‏ وَبِهِ يَقُولُ ابْنُ الْمُبَارَكِ وَالشَّافِعِيُّ وَأَحْمَدُ وَأَهْلُ الْكُوفَةِ ‏.‏ قَالَ إِسْحَاقُ لاَ يُصَامُ إِلاَّ بِشَهَادَةِ رَجُلَيْنِ ‏.‏ وَلَمْ يَخْتَلِفْ أَهْلُ الْعِلْمِ فِي الإِفْطَارِ أَنَّهُ لاَ يُقْبَلُ فِيهِ إِلاَّ شَهَادَةُ رَجُلَيْنِ ‏.‏\hadithno{691}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"A Bedouin came to the Prophet and said: 'I have seen the crescent.' So he said: 'Do you testify that none has the right to be worshipped but Allah? Do you testify that Muhammad is the Messenger of Allah?' He said: 'Yes.' So he said: 'O Bilal! Announce to the people that they should fast tomorrow}}
\hadithdefcmd{tirmidhi}{692}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ الْبَصْرِيُّ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ شَهْرَا عِيدٍ لاَ يَنْقُصَانِ رَمَضَانُ وَذُو الْحِجَّةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي بَكْرَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ قَالَ أَحْمَدُ مَعْنَى هَذَا الْحَدِيثِ ‏"‏ شَهْرَا عِيدٍ لاَ يَنْقُصَانِ ‏"‏ ‏.‏ يَقُولُ لاَ يَنْقُصَانِ مَعًا فِي سَنَةٍ وَاحِدَةٍ شَهْرُ رَمَضَانَ وَذُو الْحِجَّةِ إِنْ نَقَصَ أَحَدُهُمَا تَمَّ الآخَرُ ‏.‏ وَقَالَ إِسْحَاقُ مَعْنَاهُ ‏"‏ لاَ يَنْقُصَانِ ‏"‏ يَقُولُ وَإِنْ كَانَ تِسْعًا وَعِشْرِينَ فَهُوَ تَمَامٌ غَيْرُ نُقْصَانٍ ‏.‏ وَعَلَى مَذْهَبِ إِسْحَاقَ يَكُونُ يَنْقُصُ الشَّهْرَانِ مَعًا فِي سَنَةٍ وَاحِدَةٍ ‏.‏\hadithno{692}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abdur-Rahman bin Abi Bakrah narrated from his father that :the Messenger of Allah said: "The two months of Eid will not both be deficient: Ramadn and Dhul-Hijjah}}
\hadithdefcmd{tirmidhi}{693}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي حَرْمَلَةَ، أَخْبَرَنِي كُرَيْبٌ، أَنَّ أُمَّ الْفَضْلِ بِنْتَ الْحَارِثِ، بَعَثَتْهُ إِلَى مُعَاوِيَةَ بِالشَّامِ ‏.‏ قَالَ فَقَدِمْتُ الشَّامَ فَقَضَيْتُ حَاجَتَهَا وَاسْتُهِلَّ عَلَىَّ هِلاَلُ رَمَضَانَ وَأَنَا بِالشَّامِ فَرَأَيْنَا الْهِلاَلَ لَيْلَةَ الْجُمُعَةِ ثُمَّ قَدِمْتُ الْمَدِينَةَ فِي آخِرِ الشَّهْرِ فَسَأَلَنِي ابْنُ عَبَّاسٍ ثُمَّ ذَكَرَ الْهِلاَلَ فَقَالَ مَتَى رَأَيْتُمُ الْهِلاَلَ فَقُلْتُ رَأَيْنَاهُ لَيْلَةَ الْجُمُعَةِ ‏.‏ فَقَالَ أَأَنْتَ رَأَيْتَهُ لَيْلَةَ الْجُمُعَةِ فَقُلْتُ رَآهُ النَّاسُ وَصَامُوا وَصَامَ مُعَاوِيَةُ ‏.‏ قَالَ لَكِنْ رَأَيْنَاهُ لَيْلَةَ السَّبْتِ فَلاَ نَزَالُ نَصُومُ حَتَّى نُكْمِلَ ثَلاَثِينَ يَوْمًا أَوْ نَرَاهُ ‏.‏ فَقُلْتُ أَلاَ تَكْتَفِي بِرُؤْيَةِ مُعَاوِيَةَ وَصِيَامِهِ قَالَ لاَ هَكَذَا أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ أَنَّ لِكُلِّ أَهْلِ بَلَدٍ رُؤْيَتَهُمْ ‏.‏\hadithno{693}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Muhammad bin Abi Harmalah narrated:"Kuraib informed me that Umm Al-Fadl bin Al-Harith sent him to Mu'awiyah in Ash-Sham. He said: 'So I arrived in Ash-Sham and finished her errand, and I saw the crescent of Ramadan while I was in Ash-Sham. We saw the crescent on the night of Friday. Then I arrived in Al-Madinah at the end of the month. Ibn Abbas was questioning me, then he mentioned the crescent and he said: "When did you see the crescent?" I said: "We saw it n the night of Friday." He said: "Did you see it on the night of Friday?" I said: "The people saw it, so they fasted, and Mu'awiyah fasted." He said: "But we saw it on the night of Saturday, so we will not stop fasting until we complete thirty days or we see it." So I said: "Is not the sighting and fasting of Mu'awiyah enough for you?" He said: "This is not how the Messenger of Allah ordered us}}
\hadithdefcmd{tirmidhi}{694}{حَدَّثَنَا مُحَمَّدُ بْنُ عُمَرَ بْنِ عَلِيٍّ الْمُقَدَّمِيُّ، حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ وَجَدَ تَمْرًا فَلْيُفْطِرْ عَلَيْهِ وَمَنْ لاَ فَلْيُفْطِرْ عَلَى مَاءٍ فَإِنَّ الْمَاءَ طَهُورٌ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ سَلْمَانَ بْنِ عَامِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ لاَ نَعْلَمُ أَحَدًا رَوَاهُ عَنْ شُعْبَةَ مِثْلَ هَذَا غَيْرَ سَعِيدِ بْنِ عَامِرٍ وَهُوَ حَدِيثٌ غَيْرُ مَحْفُوظٍ وَلاَ نَعْلَمُ لَهُ أَصْلاً مِنْ حَدِيثِ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ عَنْ أَنَسٍ ‏.‏ وَقَدْ رَوَى أَصْحَابُ شُعْبَةَ هَذَا الْحَدِيثَ عَنْ شُعْبَةَ عَنْ عَاصِمٍ الأَحْوَلِ عَنْ حَفْصَةَ بِنْتِ سِيرِينَ عَنِ الرَّبَابِ عَنْ سَلْمَانَ بْنِ عَامِرٍ عَنِ النَّبِيِّ صلى الله عليه وسلم وَهُوَ أَصَحُّ مِنْ حَدِيثِ سَعِيدِ بْنِ عَامِرٍ ‏.‏ وَهَكَذَا رَوَوْا عَنْ شُعْبَةَ عَنْ عَاصِمٍ عَنْ حَفْصَةَ بِنْتِ سِيرِينَ عَنْ سَلْمَانَ وَلَمْ يَذْكُرْ فِيهِ شُعْبَةُ عَنِ الرَّبَابِ ‏.‏ وَالصَّحِيحُ مَا رَوَاهُ سُفْيَانُ الثَّوْرِيُّ وَابْنُ عُيَيْنَةَ وَغَيْرُ وَاحِدٍ عَنْ عَاصِمٍ الأَحْوَلِ عَنْ حَفْصَةَ بِنْتِ سِيرِينَ عَنِ الرَّبَابِ عَنْ سَلْمَانَ بْنِ عَامِرٍ ‏.‏ وَابْنُ عَوْنٍ يَقُولُ عَنْ أُمِّ الرَّائِحِ بِنْتِ صُلَيْعٍ عَنْ سَلْمَانَ بْنِ عَامِرٍ ‏.‏ وَالرَّبَابُ هِيَ أُمُّ الرَّائِحِ ‏.‏\hadithno{694}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated that :the Messenger of Allah said: "Whoever has dried dates, then let him break the fast with that, and whoever does not, then let him break the fast with water, for indeed water is purifying}}
\hadithdefcmd{tirmidhi}{695}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمٍ الأَحْوَلِ، ح وَحَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، ‏.‏ وَحَدَّثَنَا قُتَيْبَةُ، قَالَ أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنِ الرَّبَابِ، عَنْ سَلْمَانَ بْنِ عَامِرٍ الضَّبِّيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا أَفْطَرَ أَحَدُكُمْ فَلْيُفْطِرْ عَلَى تَمْرٍ ‏"‏ ‏.‏ زَادَ ابْنُ عُيَيْنَةَ ‏"‏ فَإِنَّهُ بَرَكَةٌ فَمَنْ لَمْ يَجِدْ فَلْيُفْطِرْ عَلَى مَاءٍ فَإِنَّهُ طَهُورٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{695}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Salman bin Amir Ad-Dabbi narrated that :the Prophet said: "When one of you breaks his fast, then let him do so with dried dates. And whoever does not find dates, then water, for it is purifying}}
\hadithdefcmd{tirmidhi}{696}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ ‏ "‏ كَانَ النَّبِيُّ صلى الله عليه وسلم يُفْطِرُ قَبْلَ أَنْ يُصَلِّيَ عَلَى رُطَبَاتٍ فَإِنْ لَمْ تَكُنْ رُطَبَاتٌ فَتُمَيْرَاتٍ فَإِنْ لَمْ تَكُنْ تُمَيْرَاتٌ حَسَا حَسَوَاتٍ مِنْ مَاءٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ قَالَ أَبُو عِيسَى وَرُوِيَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُفْطِرُ فِي الشِّتَاءِ عَلَى تَمَرَاتٍ وَفِي الصَّيْفِ عَلَى الْمَاءِ ‏.‏\hadithno{696}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Anas bin Malik narrated:"The Messenger of Allah would break the fast with fresh dates before performing Salat. If there were no fresh dates then (he would break the fast) with dried dates, and if there were no dried dates then he would take a few sips of water}}
\hadithdefcmd{tirmidhi}{697}{أَخْبَرَنِي مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا إِسْحَاقُ بْنُ جَعْفَرِ بْنِ مُحَمَّدٍ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، عَنْ عُثْمَانَ بْنِ مُحَمَّدٍ الأَخْنَسِيِّ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الصَّوْمُ يَوْمَ تَصُومُونَ وَالْفِطْرُ يَوْمَ تُفْطِرُونَ وَالأَضْحَى يَوْمَ تُضَحُّونَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَفَسَّرَ بَعْضُ أَهْلِ الْعِلْمِ هَذَا الْحَدِيثَ فَقَالَ إِنَّمَا مَعْنَى هَذَا أَنَّ الصَّوْمَ وَالْفِطْرَ مَعَ الْجَمَاعَةِ وَعُظْمِ النَّاسِ ‏.‏\hadithno{697}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "The fast is the day the people fast, the breaking of the fast is the day the people break their fast, and the sacrifice is the day the people sacrifice}}
\hadithdefcmd{tirmidhi}{698}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَاصِمِ بْنِ عُمَرَ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَقْبَلَ اللَّيْلُ وَأَدْبَرَ النَّهَارُ وَغَابَتِ الشَّمْسُ فَقَدْ أَفْطَرْتَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ أَبِي أَوْفَى وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{698}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Umar bin Al-Khattab narrated that:The Messenger of Allah said: "When the night advances and the day retreats, and the sun is hidden, then the fast is to be broken}}
\hadithdefcmd{tirmidhi}{699}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ أَبِي حَازِمٍ، ح قَالَ وَأَخْبَرَنَا أَبُو مُصْعَبٍ، قِرَاءَةً عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَزَالُ النَّاسُ بِخَيْرٍ مَا عَجَّلُوا الْفِطْرَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ وَعَائِشَةَ وَأَنَسِ بْنِ مَالِكٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَهْلِ بْنِ سَعْدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَهُوَ الَّذِي اخْتَارَهُ أَهْلُ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمُ اسْتَحَبُّوا تَعْجِيلَ الْفِطْرِ ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{699}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Sahl bin Sa'd narrated that :the Messenger of Allah said: "The people will remain upon goodness as long as they hasten to break the fast}}
\hadithdefcmd{tirmidhi}{700}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، عَنْ قُرَّةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ أَحَبُّ عِبَادِي إِلَىَّ أَعْجَلُهُمْ فِطْرًا ‏"‏ ‏.‏\hadithno{700}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah said: "Allah, Mighty and Sublime is He, said: 'Those of My worshippers who are most beloved to me are the quickest to break their fast}}
\hadithdefcmd{tirmidhi}{701}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، أَخْبَرَنَا أَبُو عَاصِمٍ، وَأَبُو الْمُغِيرَةِ، عَنِ الأَوْزَاعِيِّ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{701}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated:(A Hadith similar to no. 700 with a different chain)}}
\hadithdefcmd{tirmidhi}{702}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ أَبِي عَطِيَّةَ، قَالَ دَخَلْتُ أَنَا وَمَسْرُوقٌ، عَلَى عَائِشَةَ فَقُلْنَا يَا أُمَّ الْمُؤْمِنِينَ رَجُلاَنِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَحَدُهُمَا يُعَجِّلُ الإِفْطَارَ وَيُعَجِّلُ الصَّلاَةَ وَالآخَرُ يُؤَخِّرُ الإِفْطَارَ وَيُؤَخِّرُ الصَّلاَةَ ‏.‏ قَالَتْ أَيُّهُمَا يُعَجِّلُ الإِفْطَارَ وَيُعَجِّلُ الصَّلاَةَ قُلْنَا عَبْدُ اللَّهِ بْنُ مَسْعُودٍ ‏.‏ قَالَتْ هَكَذَا صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ وَالآخَرُ أَبُو مُوسَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَأَبُو عَطِيَّةَ اسْمُهُ مَالِكُ بْنُ أَبِي عَامِرٍ الْهَمْدَانِيُّ وَيُقَالُ مَالِكُ بْنُ عَامِرٍ الْهَمْدَانِيُّ وَابْنُ عَامِرٍ أَصَحُّ ‏.‏\hadithno{702}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Atiyyah said:"Masruq and I entered upon Aishah and we said: 'O Mother of the Believers! There are two men from the Companions of Muhammad, one of them hastens to break the fasts and he hastens to perform Salat. The other delays breaking the fast and he delays the Salat.' She said: 'Which of them hastens to break the fast and hastens to perform the Salat?' We said that it was Abdullah bin Mas'ud. She said: 'This is how the Messenger of Allah did it.' And the other was Abu Musa}}
\hadithdefcmd{tirmidhi}{703}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا أَبُو دَاوُدَ الطَّيَالِسِيُّ، حَدَّثَنَا هِشَامٌ الدَّسْتَوَائِيُّ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ تَسَحَّرْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ قُمْنَا إِلَى الصَّلاَةِ ‏.‏ قَالَ قُلْتُ كَمْ كَانَ قَدْرُ ذَلِكَ قَالَ قَدْرُ خَمْسِينَ آيَةً ‏.‏\hadithno{703}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas (bin Malik) narrated that :Zaid bin Thabit said: "We ate Sahar with the Messenger of Allah, then we stood for the Salat." I (Anas) said: "How long was that?" He said: "About the lengthy of fifty Ayahs}}
\hadithdefcmd{tirmidhi}{704}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ، بِنَحْوِهِ إِلاَّ أَنَّهُ قَالَ قَدْرُ قِرَاءَةِ خَمْسِينَ آيَةً ‏.‏ قَالَ وَفِي الْبَابِ عَنْ حُذَيْفَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ زَيْدِ بْنِ ثَابِتٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَبِهِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ اسْتَحَبُّوا تَأْخِيرَ السُّحُورِ ‏.‏\hadithno{704}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Anas (bin Malik) narrated:(Another chain) except that he said: "About the length for reciting fifty Ayahs}}
\hadithdefcmd{tirmidhi}{705}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا مُلاَزِمُ بْنُ عَمْرٍو، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ النُّعْمَانِ، عَنْ قَيْسِ بْنِ طَلْقٍ، حَدَّثَنِي أَبِي طَلْقُ بْنُ عَلِيٍّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كُلُوا وَاشْرَبُوا وَلاَ يَهِيدَنَّكُمُ السَّاطِعُ الْمُصْعِدُ وَكُلُوا وَاشْرَبُوا حَتَّى يَعْتَرِضَ لَكُمُ الأَحْمَرُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَدِيِّ بْنِ حَاتِمٍ وَأَبِي ذَرٍّ وَسَمُرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ طَلْقِ بْنِ عَلِيٍّ حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّهُ لاَ يَحْرُمُ عَلَى الصَّائِمِ الأَكْلُ وَالشُّرْبُ حَتَّى يَكُونَ الْفَجْرُ الأَحْمَرُ الْمُعْتَرِضُ ‏.‏ وَبِهِ يَقُولُ عَامَّةُ أَهْلِ الْعِلْمِ ‏.‏\hadithno{705}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Talq bin Ali narrated that :The Messenger of Allah said: "Eat and drink, and do not be disturbed by the rising glow, eat and drink until the redness appears to you on the horizon}}
\hadithdefcmd{tirmidhi}{706}{حَدَّثَنَا هَنَّادٌ، وَيُوسُفُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ أَبِي هِلاَلٍ، عَنْ سَوَادَةَ بْنِ حَنْظَلَةَ، هُوَ الْقُشَيْرِيُّ عَنْ سَمُرَةَ بْنِ جُنْدَبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَمْنَعَنَّكُمْ مِنْ سُحُورِكُمْ أَذَانُ بِلاَلٍ وَلاَ الْفَجْرُ الْمُسْتَطِيلُ وَلَكِنِ الْفَجْرُ الْمُسْتَطِيرُ فِي الأُفُقِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{706}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Samurah bin Jundub narrated that :the Messenger of Allah said: "Do not let the Adhan of Bilal prevent you from your Sahar, nor the drawn out Fajr, but the Fajr that spreads on the horizon}}
\hadithdefcmd{tirmidhi}{707}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَمْ يَدَعْ قَوْلَ الزُّورِ وَالْعَمَلَ بِهِ فَلَيْسَ لِلَّهِ حَاجَةٌ بِأَنْ يَدَعَ طَعَامَهُ وَشَرَابَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{707}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "Whoever does not leave false speech, and acting according to it, then Allah is not in any need of him leaving his food and his drink}}
\hadithdefcmd{tirmidhi}{708}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، وَعَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ تَسَحَّرُوا فَإِنَّ فِي السُّحُورِ بَرَكَةً ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَجَابِرِ بْنِ عَبْدِ اللَّهِ وَابْنِ عَبَّاسٍ وَعَمْرِو بْنِ الْعَاصِ وَالْعِرْبَاضِ بْنِ سَارِيَةَ وَعُتْبَةَ بْنِ عَبْدٍ وَأَبِي الدَّرْدَاءِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{708}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Anas bin Malik narrated that :the Messenger of Allah said: "Partake of Sahar, for indeed there is a blessing in the Sahar}}
\hadithdefcmd{tirmidhi}{709}{وَرُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ فَصْلُ مَا بَيْنَ صِيَامِنَا وَصِيَامِ أَهْلِ الْكِتَابِ أَكْلَةُ السَّحَرِ ‏"‏ ‏.‏ حَدَّثَنَا بِذَلِكَ قُتَيْبَةُ حَدَّثَنَا اللَّيْثُ عَنْ مُوسَى بْنِ عَلِيٍّ عَنْ أَبِيهِ عَنْ أَبِي قَيْسٍ مَوْلَى عَمْرِو بْنِ الْعَاصِ عَنْ عَمْرِو بْنِ الْعَاصِ عَنِ النَّبِيِّ صلى الله عليه وسلم بِذَلِكَ ‏.‏ قَالَ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَهْلُ مِصْرَ يَقُولُونَ مُوسَى بْنُ عَلِيٍّ وَأَهْلُ الْعِرَاقِ يَقُولُونَ مُوسَى بْنُ عُلَىٍّ وَهُوَ مُوسَى بْنُ عَلِيِّ بْنِ رَبَاحٍ اللَّخْمِيُّ ‏.‏\hadithno{709}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Amr bin Al-As narrated :(similar to no. 708) from the Prophet}}
\hadithdefcmd{tirmidhi}{710}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ إِلَى مَكَّةَ عَامَ الْفَتْحِ فَصَامَ حَتَّى بَلَغَ كُرَاعَ الْغَمِيمِ وَصَامَ النَّاسُ مَعَهُ فَقِيلَ لَهُ إِنَّ النَّاسَ قَدْ شَقَّ عَلَيْهِمُ الصِّيَامُ وَإِنَّ النَّاسَ يَنْظُرُونَ فِيمَا فَعَلْتَ ‏.‏ فَدَعَا بِقَدَحٍ مِنْ مَاءٍ بَعْدَ الْعَصْرِ فَشَرِبَ وَالنَّاسُ يَنْظُرُونَ إِلَيْهِ فَأَفْطَرَ بَعْضُهُمْ وَصَامَ بَعْضُهُمْ فَبَلَغَهُ أَنَّ نَاسًا صَامُوا فَقَالَ ‏"‏ أُولَئِكَ الْعُصَاةُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ كَعْبِ بْنِ عَاصِمٍ وَابْنِ عَبَّاسٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ جَابِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لَيْسَ مِنَ الْبِرِّ الصِّيَامُ فِي السَّفَرِ ‏"‏ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي الصَّوْمِ فِي السَّفَرِ فَرَأَى بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ الْفِطْرَ فِي السَّفَرِ أَفْضَلُ حَتَّى رَأَى بَعْضُهُمْ عَلَيْهِ الإِعَادَةَ إِذَا صَامَ فِي السَّفَرِ ‏.‏ وَاخْتَارَ أَحْمَدُ وَإِسْحَاقُ الْفِطْرَ فِي السَّفَرِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِنْ وَجَدَ قُوَّةً فَصَامَ فَحَسَنٌ وَهُوَ أَفْضَلُ وَإِنْ أَفْطَرَ فَحَسَنٌ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكِ بْنِ أَنَسٍ وَعَبْدِ اللَّهِ بْنِ الْمُبَارَكِ ‏.‏ وَقَالَ الشَّافِعِيُّ وَإِنَّمَا مَعْنَى قَوْلِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لَيْسَ مِنَ الْبِرِّ الصِّيَامُ فِي السَّفَرِ ‏"‏ ‏.‏ وَقَوْلُهُ حِينَ بَلَغَهُ أَنَّ نَاسًا صَامُوا فَقَالَ ‏"‏ أُولَئِكَ الْعُصَاةُ ‏"‏ ‏.‏ فَوَجْهُ هَذَا إِذَا لَمْ يَحْتَمِلْ قَلْبُهُ قَبُولَ رُخْصَةِ اللَّهِ فَأَمَّا مَنْ رَأَى الْفِطْرَ مُبَاحًا وَصَامَ وَقَوِيَ عَلَى ذَلِكَ فَهُوَ أَعْجَبُ إِلَىَّ ‏.‏\hadithno{710}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Jabir bin Abdullah narrated:"The Messenger of Allah went to Makkah in the Year of the Conquest, so he fasted until he reached Kura Al-Ghamim and the people were fasting with him. Then it was said to him: 'The fast has become difficult for the people, and they are watching you to see what you will do.' So after Asr, he called for a cup of water and drank it while the people were looking at him. Some of them broke the fast while some of them continued their fasting. It was conveyed to him that people were still fasting, so he said: "Those are the disobedient}}
\hadithdefcmd{tirmidhi}{711}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ حَمْزَةَ بْنَ عَمْرٍو الأَسْلَمِيَّ، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الصَّوْمِ فِي السَّفَرِ وَكَانَ يَسْرُدُ الصَّوْمَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنْ شِئْتَ فَصُمْ وَإِنْ شِئْتَ فَأَفْطِرْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَنَسِ بْنِ مَالِكٍ وَأَبِي سَعِيدٍ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَبِي الدَّرْدَاءِ وَحَمْزَةَ بْنِ عَمْرٍو الأَسْلَمِيِّ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ أَنَّ حَمْزَةَ بْنَ عَمْرٍو سَأَلَ النَّبِيَّ صلى الله عليه وسلم حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{711}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Aishah narrated that :Hamzah bin Amr Al-Aslami asked the Messenger of Allah about fasting while traveling, and he fasted regularly. So the Messenger of Allah said: 'If you wish then fast, and if you wish then break (the fast)}}
\hadithdefcmd{tirmidhi}{712}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ سَعِيدِ بْنِ يَزِيدَ أَبِي مَسْلَمَةَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كُنَّا نُسَافِرُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَمَضَانَ فَمَا يَعِيبُ عَلَى الصَّائِمِ صَوْمَهُ وَلاَ عَلَى الْمُفْطِرِ إِفْطَارَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{712}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Sa'eed (Al-Khudri) narrated:"We were on a journey with the Messenger of Allah during the month of Ramadan. No one objected to the fast of the one fasting nor the fast breaking of the one who broke his fast}}
\hadithdefcmd{tirmidhi}{713}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا الْجُرَيْرِيُّ، ح قَالَ وَحَدَّثَنَا سُفْيَانُ بْنُ وَكِيعٍ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ كُنَّا نُسَافِرُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمِنَّا الصَّائِمُ وَمِنَّا الْمُفْطِرُ فَلاَ يَجِدُ الْمُفْطِرُ عَلَى الصَّائِمِ وَلاَ الصَّائِمُ عَلَى الْمُفْطِرِ فَكَانُوا يَرَوْنَ أَنَّهُ مَنْ وَجَدَ قُوَّةً فَصَامَ فَحَسَنٌ وَمَنْ وَجَدَ ضَعْفًا فَأَفْطَرَ فَحَسَنٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{713}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Sa'eed Al-Khudri narrated:"We were on a journey with the Messenger of Allah. Some of us were fasting and some of us broke their fast. The one who broke their fast had no objection to the one who fasted, and the one who fasted had no objection to the one who broke his fast. They saw that whoever had the strength to fast then that was good, and whoever was weak, then breaking it was better}}
\hadithdefcmd{tirmidhi}{714}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مَعْمَرِ بْنِ أَبِي حُيَيَّةَ، عَنِ ابْنِ الْمُسَيَّبِ، أَنَّهُ سَأَلَهُ عَنِ الصَّوْمِ، فِي السَّفَرِ فَحَدَّثَ أَنَّ عُمَرَ بْنَ الْخَطَّابِ قَالَ غَزَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَمَضَانَ غَزْوَتَيْنِ يَوْمَ بَدْرٍ وَالْفَتْحِ فَأَفْطَرْنَا فِيهِمَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عُمَرَ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ أَمَرَ بِالْفِطْرِ فِي غَزْوَةٍ غَزَاهَا ‏.‏ وَقَدْ رُوِيَ عَنْ عُمَرَ بْنِ الْخَطَّابِ نَحْوُ هَذَا أَنَّهُ رَخَّصَ فِي الإِفْطَارِ عِنْدَ لِقَاءِ الْعَدُوِّ وَبِهِ يَقُولُ بَعْضُ أَهْلِ الْعِلْمِ ‏.‏\hadithno{714}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ma'mar bin Abi Huyaiyah narrated that:he asked Ibn Al-Musaiyab about fasting on a journey, so he narrated to him that Umar bin Al-Khattab said: "We fought in two battles along with the Messenger of Allah during Ramadan; the Day of Badr, and the Conquest (of Makkah), so we broke our fast during them}}
\hadithdefcmd{tirmidhi}{715}{حَدَّثَنَا أَبُو كُرَيْبٍ، وَيُوسُفُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا أَبُو هِلاَلٍ، عَنْ عَبْدِ اللَّهِ بْنِ سَوَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، رَجُلٌ مِنْ بَنِي عَبْدِ اللَّهِ بْنِ كَعْبٍ قَالَ أَغَارَتْ عَلَيْنَا خَيْلُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَوَجَدْتُهُ يَتَغَدَّى فَقَالَ ‏"‏ ادْنُ فَكُلْ ‏"‏ ‏.‏ فَقُلْتُ إِنِّي صَائِمٌ ‏.‏ فَقَالَ ‏"‏ ادْنُ أُحَدِّثْكَ عَنِ الصَّوْمِ أَوِ الصِّيَامِ إِنَّ اللَّهَ تَعَالَى وَضَعَ عَنِ الْمُسَافِرِ الصَّوْمَ وَشَطْرَ الصَّلاَةِ وَعَنِ الْحَامِلِ أَوِ الْمُرْضِعِ الصَّوْمَ أَوِ الصِّيَامَ ‏"‏ ‏.‏ وَاللَّهِ لَقَدْ قَالَهُمَا النَّبِيُّ صلى الله عليه وسلم كِلْتَيْهِمَا أَوْ إِحْدَاهُمَا فَيَا لَهْفَ نَفْسِي أَنْ لاَ أَكُونَ طَعِمْتُ مِنْ طَعَامِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي أُمَيَّةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسِ بْنِ مَالِكٍ الْكَعْبِيِّ حَدِيثٌ حَسَنٌ وَلاَ نَعْرِفُ لأَنَسِ بْنِ مَالِكٍ هَذَا عَنِ النَّبِيِّ صلى الله عليه وسلم غَيْرَ هَذَا الْحَدِيثِ الْوَاحِدِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ الْحَامِلُ وَالْمُرْضِعُ تُفْطِرَانِ وَتَقْضِيَانِ وَتُطْعِمَانِ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ وَمَالِكٌ وَالشَّافِعِيُّ وَأَحْمَدُ ‏.‏ وَقَالَ بَعْضُهُمْ تُفْطِرَانِ وَتُطْعِمَانِ وَلاَ قَضَاءَ عَلَيْهِمَا وَإِنْ شَاءَتَا قَضَتَا وَلاَ إِطْعَامَ عَلَيْهِمَا ‏.‏ وَبِهِ يَقُولُ إِسْحَاقُ ‏.‏\hadithno{715}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Anas bin Malik, a man from Banu Abdullah bin Ka'b said:"Some cavalry man of the Messenger of Allah came galloping upon us, so I came to the Messenger of Allah and found him having lunch. He said: "Come and eat." I said: 'I am fasting.' So he said: 'Come and I will narrate to you about the fast - or fasting. Indeed Allah Most High lifted (the fast and) half of the Salat from the traveler, and (He lifted) the fast - or fasting - from the pregnant person, or the breast-feeding person.' And by Allah! The Prophet said both of them or one of them. So woe to me! For I did not eat from the meal of the Prophet}}
\hadithdefcmd{tirmidhi}{716}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ الأَعْمَشِ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، وَمُسْلِمٍ الْبَطِينِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، وَعَطَاءٍ، وَمُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ إِنَّ أُخْتِي مَاتَتْ وَعَلَيْهَا صَوْمُ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏.‏ قَالَ ‏"‏ أَرَأَيْتِ لَوْ كَانَ عَلَى أُخْتِكِ دَيْنٌ أَكُنْتِ تَقْضِينَهُ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ فَحَقُّ اللَّهِ أَحَقُّ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ بُرَيْدَةَ وَابْنِ عُمَرَ وَعَائِشَةَ ‏.‏\hadithno{716}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Ibn Abbas narrated:"A woman came to the Prophet and said: 'My sister died while she had two consecutive months of fasting due.' So he said: 'Do you not see that if there was a debt due from your sister then you would have to pay it?' She said: 'Yes.' He said: 'Then the right of Allah is more appropriate}}
\hadithdefcmd{tirmidhi}{717}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدًا، يَقُولُ جَوَّدَ أَبُو خَالِدٍ الأَحْمَرُ هَذَا الْحَدِيثَ عَنِ الأَعْمَشِ، ‏.‏ قَالَ مُحَمَّدٌ وَقَدْ رَوَى غَيْرُ أَبِي خَالِدٍ، عَنِ الأَعْمَشِ، مِثْلَ رِوَايَةِ أَبِي خَالِدٍ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى أَبُو مُعَاوِيَةَ، وَغَيْرُ، وَاحِدٍ، هَذَا الْحَدِيثَ عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ الْبَطِينِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَلَمْ يَذْكُرُوا فِيهِ سَلَمَةَ بْنَ كُهَيْلٍ وَلاَ عَنْ عَطَاءٍ وَلاَ عَنْ مُجَاهِدٍ ‏.‏ وَاسْمُ أَبِي خَالِدٍ سُلَيْمَانُ بْنُ حَيَّانَ ‏.‏\hadithno{717}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated:(A Hadith similar to no. 716 with a different chain)}}
\hadithdefcmd{tirmidhi}{718}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْثَرُ بْنُ الْقَاسِمِ، عَنْ أَشْعَثَ، عَنْ مُحَمَّدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ مَاتَ وَعَلَيْهِ صِيَامُ شَهْرٍ فَلْيُطْعِمْ عَنْهُ مَكَانَ كُلِّ يَوْمٍ مِسْكِينًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ هَذَا الْوَجْهِ وَالصَّحِيحُ عَنِ ابْنِ عُمَرَ مَوْقُوفٌ قَوْلُهُ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي هَذَا الْبَابِ فَقَالَ بَعْضُهُمْ يُصَامُ عَنِ الْمَيِّتِ ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ قَالاَ إِذَا كَانَ عَلَى الْمَيِّتِ نَذْرُ صِيَامٍ يَصُومُ عَنْهُ وَإِذَا كَانَ عَلَيْهِ قَضَاءُ رَمَضَانَ أَطْعَمَ عَنْهُ ‏.‏ وَقَالَ مَالِكٌ وَسُفْيَانُ وَالشَّافِعِيُّ لاَ يَصُومُ أَحَدٌ عَنْ أَحَدٍ ‏.‏ قَالَ وَأَشْعَثُ هُوَ ابْنُ سَوَّارٍ ‏.‏ وَمُحَمَّدٌ هُوَ عِنْدِي ابْنُ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى ‏.‏\hadithno{718}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibn Umar narrated that :the Prophet said: "Whoever died while he had a month to fast, then a needy person should be fed on his behalf in place of every day}}
\hadithdefcmd{tirmidhi}{719}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْمُحَارِبِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثٌ لاَ يُفْطِرْنَ الصَّائِمَ الْحِجَامَةُ وَالْقَىْءُ وَالاِحْتِلاَمُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ الْخُدْرِيِّ حَدِيثٌ غَيْرُ مَحْفُوظٍ ‏.‏ وَقَدْ رَوَى عَبْدُ اللَّهِ بْنُ زَيْدِ بْنِ أَسْلَمَ وَعَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ وَغَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ زَيْدِ بْنِ أَسْلَمَ مُرْسَلاً ‏.‏ وَلَمْ يَذْكُرُوا فِيهِ عَنْ أَبِي سَعِيدٍ ‏.‏ وَعَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ يُضَعَّفُ فِي الْحَدِيثِ ‏.‏ قَالَ سَمِعْتُ أَبَا دَاوُدَ السِّجْزِيَّ يَقُولُ سَأَلْتُ أَحْمَدَ بْنَ حَنْبَلٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ زَيْدِ بْنِ أَسْلَمَ فَقَالَ أَخُوهُ عَبْدُ اللَّهِ بْنُ زَيْدٍ لاَ بَأْسَ بِهِ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدًا يَذْكُرُ عَنْ عَلِيِّ بْنِ عَبْدِ اللَّهِ الْمَدِينِيِّ قَالَ عَبْدُ اللَّهِ بْنُ زَيْدِ بْنِ أَسْلَمَ ثِقَةٌ وَعَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ ضَعِيفٌ ‏.‏ قَالَ مُحَمَّدٌ وَلاَ أَرْوِي عَنْهُ شَيْئًا ‏.‏\hadithno{719}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa'eed Al-Khudri narrated that:the Messenger of Allah said: "Three things do not break the fast of the fasting person: Cupping, vomiting, and the wet dream}}
\hadithdefcmd{tirmidhi}{720}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ ذَرَعَهُ الْقَىْءُ فَلَيْسَ عَلَيْهِ قَضَاءٌ وَمَنِ اسْتَقَاءَ عَمْدًا فَلْيَقْضِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي الدَّرْدَاءِ وَثَوْبَانَ وَفَضَالَةَ بْنِ عُبَيْدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ هِشَامٍ عَنِ ابْنِ سِيرِينَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم إِلاَّ مِنْ حَدِيثِ عِيسَى بْنِ يُونُسَ ‏.‏ وَقَالَ مُحَمَّدٌ لاَ أَرَاهُ مَحْفُوظًا ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم وَلاَ يَصِحُّ إِسْنَادُهُ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي الدَّرْدَاءِ وَثَوْبَانَ وَفَضَالَةَ بْنِ عُبَيْدٍ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَاءَ فَأَفْطَرَ ‏.‏ وَإِنَّمَا مَعْنَى هَذَا أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ صَائِمًا مُتَطَوِّعًا فَقَاءَ فَضَعُفَ فَأَفْطَرَ لِذَلِكَ ‏.‏ هَكَذَا رُوِيَ فِي بَعْضِ الْحَدِيثِ مُفَسَّرًا ‏.‏ وَالْعَمَلُ عِنْدَ أَهْلِ الْعِلْمِ عَلَى حَدِيثِ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّ الصَّائِمَ إِذَا ذَرَعَهُ الْقَىْءُ فَلاَ قَضَاءَ عَلَيْهِ وَإِذَا اسْتَقَاءَ عَمْدًا فَلْيَقْضِ ‏.‏ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{720}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "Whoever is overcome by vomiting, then he is not required to make up (the fast), and whoever vomits on purpose, then he must make it up}}
\hadithdefcmd{tirmidhi}{721}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ حَجَّاجِ بْنِ أَرْطَاةَ، عَنْ قَتَادَةَ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَكَلَ أَوْ شَرِبَ نَاسِيًا فَلاَ يُفْطِرْ فَإِنَّمَا هُوَ رِزْقٌ رَزَقَهُ اللَّهُ ‏"‏ ‏.‏\hadithno{721}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that the Messenger of Allah said:"Whoever eats or drinks forgetfully, then he has not broken (the fast), for it was only a provision that Allah provided for him}}
\hadithdefcmd{tirmidhi}{722}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ عَوْفٍ، عَنِ ابْنِ سِيرِينَ، وَخِلاَسٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ أَوْ نَحْوَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَأُمِّ إِسْحَاقَ الْغَنَوِيَّةِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ وَبِهِ يَقُولُ سُفْيَانُ الثَّوْرِيُّ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ وَقَالَ مَالِكُ بْنُ أَنَسٍ إِذَا أَكَلَ فِي رَمَضَانَ نَاسِيًا فَعَلَيْهِ الْقَضَاءُ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏\hadithno{722}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated:(Another chain) with the same or similar (Hadith as no)}}
\hadithdefcmd{tirmidhi}{723}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، حَدَّثَنَا أَبُو الْمُطَوِّسِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَفْطَرَ يَوْمًا مِنْ رَمَضَانَ مِنْ غَيْرِ رُخْصَةٍ وَلاَ مَرَضٍ لَمْ يَقْضِ عَنْهُ صَوْمُ الدَّهْرِ كُلِّهِ وَإِنْ صَامَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَسَمِعْتُ مُحَمَّدًا يَقُولُ أَبُو الْمُطَوِّسِ اسْمُهُ يَزِيدُ بْنُ الْمُطَوِّسِ وَلاَ أَعْرِفُ لَهُ غَيْرَ هَذَا الْحَدِيثِ ‏.‏\hadithno{723}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah said: "Whoever breaks the fast during Ramadan without an allowance or illness, then if he fasted for all time, his fasting would not make up for it}}
\hadithdefcmd{tirmidhi}{724}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَأَبُو عَمَّارٍ وَالْمَعْنَى وَاحِدٌ وَاللَّفْظُ لَفْظُ أَبِي عَمَّارٍ قَالاَ أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَتَاهُ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ هَلَكْتُ ‏.‏ قَالَ ‏"‏ وَمَا أَهْلَكَكَ ‏"‏ ‏.‏ قَالَ وَقَعْتُ عَلَى امْرَأَتِي فِي رَمَضَانَ ‏.‏ قَالَ ‏"‏ هَلْ تَسْتَطِيعُ أَنْ تُعْتِقَ رَقَبَةً ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَهَلْ تَسْتَطِيعُ أَنْ تَصُومَ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَهَلْ تَسْتَطِيعُ أَنْ تُطْعِمَ سِتِّينَ مِسْكِينًا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ اجْلِسْ ‏"‏ ‏.‏ فَجَلَسَ فَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِعَرَقٍ فِيهِ تَمْرٌ - وَالْعَرَقُ الْمِكْتَلُ الضَّخْمُ قَالَ ‏"‏ تَصَدَّقْ بِهِ ‏"‏ ‏.‏ فَقَالَ مَا بَيْنَ لاَبَتَيْهَا أَحَدٌ أَفْقَرَ مِنَّا ‏.‏ قَالَ فَضَحِكَ النَّبِيُّ صلى الله عليه وسلم حَتَّى بَدَتْ أَنْيَابُهُ ‏.‏ قَالَ ‏"‏ فَخُذْهُ فَأَطْعِمْهُ أَهْلَكَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَعَائِشَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ أَهْلِ الْعِلْمِ فِي مَنْ أَفْطَرَ فِي رَمَضَانَ مُتَعَمِّدًا مِنْ جِمَاعٍ وَأَمَّا مَنْ أَفْطَرَ مُتَعَمِّدًا مِنْ أَكْلٍ أَوْ شُرْبٍ فَإِنَّ أَهْلَ الْعِلْمِ قَدِ اخْتَلَفُوا فِي ذَلِكَ فَقَالَ بَعْضُهُمْ عَلَيْهِ الْقَضَاءُ وَالْكَفَّارَةُ ‏.‏ وَشَبَّهُوا الأَكْلَ وَالشُّرْبَ بِالْجِمَاعِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَإِسْحَاقَ ‏.‏ وَقَالَ بَعْضُهُمْ عَلَيْهِ الْقَضَاءُ وَلاَ كَفَّارَةَ عَلَيْهِ لأَنَّهُ إِنَّمَا ذُكِرَ عَنِ النَّبِيِّ صلى الله عليه وسلم الْكَفَّارَةُ فِي الْجِمَاعِ وَلَمْ تُذْكَرْ عَنْهُ فِي الأَكْلِ وَالشُّرْبِ ‏.‏ وَقَالُوا لاَ يُشْبِهُ الأَكْلُ وَالشُّرْبُ الْجِمَاعَ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ ‏.‏ وَقَالَ الشَّافِعِيُّ وَقَوْلُ النَّبِيِّ صلى الله عليه وسلم لِلرَّجُلِ الَّذِي أَفْطَرَ فَتَصَدَّقَ عَلَيْهِ ‏"‏ خُذْهُ فَأَطْعِمْهُ أَهْلَكَ ‏"‏ ‏.‏ يَحْتَمِلُ هَذَا مَعَانِيَ يَحْتَمِلُ أَنْ تَكُونَ الْكَفَّارَةُ عَلَى مَنْ قَدَرَ عَلَيْهَا وَهَذَا رَجُلٌ لَمْ يَقْدِرْ عَلَى الْكَفَّارَةِ فَلَمَّا أَعْطَاهُ النَّبِيُّ صلى الله عليه وسلم شَيْئًا وَمَلَكَهُ فَقَالَ الرَّجُلُ مَا أَحَدٌ أَفْقَرَ إِلَيْهِ مِنَّا ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ خُذْهُ فَأَطْعِمْهُ أَهْلَكَ ‏"‏ ‏.‏ لأَنَّ الْكَفَّارَةَ إِنَّمَا تَكُونُ بَعْدَ الْفَضْلِ عَنْ قُوتِهِ ‏.‏ وَاخْتَارَ الشَّافِعِيُّ لِمَنْ كَانَ عَلَى مِثْلِ هَذَا الْحَالِ أَنْ يَأْكُلَهُ وَتَكُونَ الْكَفَّارَةُ عَلَيْهِ دَيْنًا فَمَتَى مَا مَلَكَ يَوْمًا مَا كَفَّرَ ‏.‏\hadithno{724}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that:A man came and said: "O Messenger of Allah; I am ruined!" He said: "What has ruined you?" He said: "I had sexual relations with my wife during Ramadan." He said: "Are you able to free a slave?" He said, "No." He said: "Then are you able to fast for two consecutive months?" He said, "No." He said: "Then are you able to feed sixty needy people?" He said, "No." He said: "Sit." So he sat. A big basket full of dates was brought to the Prophet, and he said: "Give it in charity." So he said: "There is no one needier than us between its two mountains." So the Prophet laughing until his pre-molar teeth appeared, and he said: "Then take it to feed your family}}
\hadithdefcmd{tirmidhi}{725}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم مَا لاَ أُحْصِي يَتَسَوَّكُ وَهُوَ صَائِمٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَامِرِ بْنِ رَبِيعَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ لاَ يَرَوْنَ بِالسِّوَاكِ لِلصَّائِمِ بَأْسًا إِلاَّ أَنَّ بَعْضَ أَهْلِ الْعِلْمِ كَرِهُوا السِّوَاكَ لِلصَّائِمِ بِالْعُودِ الرَّطْبِ وَكَرِهُوا لَهُ السِّوَاكَ آخِرَ النَّهَارِ وَلَمْ يَرَ الشَّافِعِيُّ بِالسِّوَاكِ بَأْسًا أَوَّلَ النَّهَارِ وَلاَ آخِرَهُ وَكَرِهَ أَحْمَدُ وَإِسْحَاقُ السِّوَاكَ آخِرَ النَّهَارِ ‏.‏\hadithno{725}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abdullah bin Amir bin Rabi'ah narrated from his father who said:"I saw the Prophet - (a number of times) such that I was not able to count - using the Siwak while he was fasting}}
\hadithdefcmd{tirmidhi}{726}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ وَاصِلٍ الْكُوفِيُّ، حَدَّثَنَا الْحَسَنُ بْنُ عَطِيَّةَ، حَدَّثَنَا أَبُو عَاتِكَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ اشْتَكَتْ عَيْنِي أَفَأَكْتَحِلُ وَأَنَا صَائِمٌ قَالَ ‏ "‏ نَعَمْ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي رَافِعٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ لَيْسَ إِسْنَادُهُ بِالْقَوِيِّ وَلاَ يَصِحُّ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي هَذَا الْبَابِ شَيْءٌ ‏.‏ وَأَبُو عَاتِكَةَ يُضَعَّفُ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي الْكُحْلِ لِلصَّائِمِ فَكَرِهَهُ بَعْضُهُمْ وَهُوَ قَوْلُ سُفْيَانَ وَابْنِ الْمُبَارَكِ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَرَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ فِي الْكُحْلِ لِلصَّائِمِ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏\hadithno{726}\hadithgrade{Ahmad Muhammad Shakir: Daif Isnaad; Al-Albani: Daif Isnaad; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Anas bin Malik narrated that :a man came to the Prophet and said: "My eyes are bothering me, can I use Kuhl while I am fasting?" He said: "Yes}}
\hadithdefcmd{tirmidhi}{727}{حَدَّثَنَا هَنَّادٌ، وَقُتَيْبَةُ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُقَبِّلُ فِي شَهْرِ الصَّوْمِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ بْنِ الْخَطَّابِ وَحَفْصَةَ وَأَبِي سَعِيدٍ وَأُمِّ سَلَمَةَ وَابْنِ عَبَّاسٍ وَأَنَسٍ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ فِي الْقُبْلَةِ لِلصَّائِمِ فَرَخَّصَ بَعْضُ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم فِي الْقُبْلَةِ لِلشَّيْخِ وَلَمْ يُرَخِّصُوا لِلشَّابِّ مَخَافَةَ أَنْ لاَ يَسْلَمَ لَهُ صَوْمُهُ وَالْمُبَاشَرَةُ عِنْدَهُمْ أَشَدُّ ‏.‏ وَقَدْ قَالَ بَعْضُ أَهْلِ الْعِلْمِ الْقُبْلَةُ تَنْقُصُ الأَجْرَ وَلاَ تُفْطِرُ الصَّائِمَ ‏.‏ وَرَأَوْا أَنَّ لِلصَّائِمِ إِذَا مَلَكَ نَفْسَهُ أَنْ يُقَبِّلَ وَإِذَا لَمْ يَأْمَنْ عَلَى نَفْسِهِ تَرَكَ الْقُبْلَةَ لِيَسْلَمَ لَهُ صَوْمُهُ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَالشَّافِعِيِّ ‏.‏\hadithno{727}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Aishah narrated:"The Prophet would kiss during the month of fasting}}
\hadithdefcmd{tirmidhi}{728}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي مَيْسَرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُبَاشِرُنِي وَهُوَ صَائِمٌ وَكَانَ أَمْلَكَكُمْ لإِرْبِهِ ‏.‏\hadithno{728}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated:"The Messenger of Allah would fondle me while he was fasting, and he had the most control among you of his limb (li irbihi)}}
\hadithdefcmd{tirmidhi}{729}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَبِّلُ وَيُبَاشِرُ وَهُوَ صَائِمٌ وَكَانَ أَمْلَكَكُمْ لإِرْبِهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو مَيْسَرَةَ اسْمُهُ عَمْرُو بْنُ شُرَحْبِيلَ ‏.‏ وَمَعْنَى لإِرْبِهِ لِنَفْسِهِ ‏.‏\hadithno{729}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated:"The Messenger of Allah would kiss and fondle while he was fasting, and he had the most control among you of his limbs}}
\hadithdefcmd{tirmidhi}{730}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ حَفْصَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَمْ يُجْمِعِ الصِّيَامَ قَبْلَ الْفَجْرِ فَلاَ صِيَامَ لَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ حَفْصَةَ حَدِيثٌ لاَ نَعْرِفُهُ مَرْفُوعًا إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَقَدْ رُوِيَ عَنْ نَافِعٍ عَنِ ابْنِ عُمَرَ قَوْلُهُ وَهُوَ أَصَحُّ وَهَكَذَا أَيْضًا رُوِيَ هَذَا الْحَدِيثُ عَنِ الزُّهْرِيِّ مَوْقُوفًا وَلاَ نَعْلَمُ أَحَدًا رَفَعَهُ إِلاَّ يَحْيَى بْنَ أَيُّوبَ ‏.‏ وَإِنَّمَا مَعْنَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ لاَ صِيَامَ لِمَنْ لَمْ يُجْمِعِ الصِّيَامَ قَبْلَ طُلُوعِ الْفَجْرِ فِي رَمَضَانَ أَوْ فِي قَضَاءِ رَمَضَانَ أَوْ فِي صِيَامِ نَذْرٍ إِذَا لَمْ يَنْوِهِ مِنَ اللَّيْلِ لَمْ يُجْزِهِ وَأَمَّا صِيَامُ التَّطَوُّعِ فَمُبَاحٌ لَهُ أَنْ يَنْوِيَهُ بَعْدَ مَا أَصْبَحَ وَهُوَ قَوْلُ الشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏\hadithno{730}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Hafsah narrated that:the Prophet said: "Whoever did not decide to fast before Fajr then there is no fast for him}}
\hadithdefcmd{tirmidhi}{731}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنِ ابْنِ أُمِّ هَانِئٍ، عَنْ أُمِّ هَانِئٍ، قَالَتْ كُنْتُ قَاعِدَةً عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَأُتِيَ بِشَرَابٍ فَشَرِبَ مِنْهُ ثُمَّ نَاوَلَنِي فَشَرِبْتُ مِنْهُ فَقُلْتُ إِنِّي أَذْنَبْتُ فَاسْتَغْفِرْ لِي ‏.‏ فَقَالَ ‏"‏ وَمَا ذَاكِ ‏"‏ ‏.‏ قَالَتْ كُنْتُ صَائِمَةً فَأَفْطَرْتُ ‏.‏ فَقَالَ ‏"‏ أَمِنْ قَضَاءٍ كُنْتِ تَقْضِينَهُ ‏"‏ ‏.‏ قَالَتْ لاَ ‏.‏ قَالَ ‏"‏ فَلاَ يَضُرُّكِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَعَائِشَةَ ‏.‏\hadithno{731}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Umm Hani narrated:"I was sitting with the Prophet when some drink was brought, so he drank from it, then he offered it to me and I drank it. Then I said: 'I have indeed sinned, so seek forgiveness for me.' He said: 'What is that?' I said: 'I was fasting, then I broke the fast.' He said: 'Were you performing a fast that you had to make up?' I said: 'No.' He said: 'Then it is no harm for you}}
\hadithdefcmd{tirmidhi}{732}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شُعْبَةُ، قَالَ كُنْتُ أَسْمَعُ سِمَاكَ بْنَ حَرْبٍ يَقُولُ أَحَدُ ابْنَىْ أُمِّ هَانِئٍ حَدَّثَنِي فَلَقِيتُ، أَنَا أَفْضَلَهُمَا، وَكَانَ، اسْمُهُ جَعْدَةَ وَكَانَتْ أُمُّ هَانِئٍ جَدَّتَهُ فَحَدَّثَنِي عَنْ جَدَّتِهِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَلَيْهَا فَدَعَى بِشَرَابٍ فَشَرِبَ ثُمَّ نَاوَلَهَا فَشَرِبَتْ فَقَالَتْ يَا رَسُولَ اللَّهِ أَمَا إِنِّي كُنْتُ صَائِمَةً ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الصَّائِمُ الْمُتَطَوِّعُ أَمِينُ نَفْسِهِ إِنْ شَاءَ صَامَ وَإِنْ شَاءَ أَفْطَرَ ‏"‏ ‏.‏ قَالَ شُعْبَةُ فَقُلْتُ لَهُ أَأَنْتَ سَمِعْتَ هَذَا مِنْ أُمِّ هَانِئٍ قَالَ لاَ أَخْبَرَنِي أَبُو صَالِحٍ وَأَهْلُنَا عَنْ أُمِّ هَانِئٍ ‏.‏ وَرَوَى حَمَّادُ بْنُ سَلَمَةَ هَذَا الْحَدِيثَ عَنْ سِمَاكِ بْنِ حَرْبٍ فَقَالَ عَنْ هَارُونَ ابْنِ بِنْتِ أُمِّ هَانِئٍ عَنْ أُمِّ هَانِئٍ ‏.‏ وَرِوَايَةُ شُعْبَةَ أَحْسَنُ ‏.‏ هَكَذَا حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ عَنْ أَبِي دَاوُدَ فَقَالَ ‏"‏ أَمِينُ نَفْسِهِ ‏"‏ ‏.‏ وَحَدَّثَنَا غَيْرُ مَحْمُودٍ عَنْ أَبِي دَاوُدَ فَقَالَ ‏"‏ أَمِيرُ نَفْسِهِ أَوْ أَمِينُ نَفْسِهِ ‏"‏ ‏.‏ عَلَى الشَّكِّ وَهَكَذَا رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ شُعْبَةَ ‏"‏ أَمِينُ أَوْ أَمِيرُ نَفْسِهِ ‏"‏ عَلَى الشَّكِّ ‏.‏ قَالَ وَحَدِيثُ أُمِّ هَانِئٍ فِي إِسْنَادِهِ مَقَالٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ الصَّائِمَ الْمُتَطَوِّعَ إِذَا أَفْطَرَ فَلاَ قَضَاءَ عَلَيْهِ إِلاَّ أَنْ يُحِبَّ أَنْ يَقْضِيَهُ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَأَحْمَدَ وَإِسْحَاقَ وَالشَّافِعِيِّ ‏.‏\hadithno{732}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Simak bin Harb narrated:"A person from the offspring of Umm Hani narrated to me - I met one of the most virtuous among them, and his name was Ja'dah, and Umm Hani was his grandmother - he narrated to me from his grandmother that the Messenger of Allah entered upon her and asked for some drink, and he drank. Then he offered it to her and she drank it. Then she said: "O Messenger of Allah! I was fasting." So the Messenger of Allah said: "The one fasting a voluntary fast is the trustee for himself; if he wishes he fasts, and if he wishes he breaks." Shu'bah (one of the narrators) said: "I said to him (Ja'dah), 'Did you hear this from Umm Hani?' He said: 'No Abu Salih and our family informed us of it from Umm Hani}}
\hadithdefcmd{tirmidhi}{733}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ عَمَّتِهِ، عَائِشَةَ بِنْتِ طَلْحَةَ عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا فَقَالَ ‏"‏ هَلْ عِنْدَكُمْ شَيْءٌ ‏"‏ ‏.‏ قَالَتْ قُلْتُ لاَ ‏.‏ قَالَ ‏"‏ فَإِنِّي صَائِمٌ ‏"‏ ‏.‏\hadithno{733}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah, the Mother of the Believers, narrated:"The Messenger of Allah visited me one day and said: 'Do you have anything (to eat)?'" She said: "I said: 'No.' He said: 'Then I am fasting}}
\hadithdefcmd{tirmidhi}{734}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا بِشْرُ بْنُ السَّرِيِّ، عَنْ سُفْيَانَ، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ أُمِّ الْمُؤْمِنِينَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَأْتِينِي فَيَقُولُ ‏"‏ أَعِنْدَكِ غَدَاءٌ ‏"‏ ‏.‏ فَأَقُولُ لاَ ‏.‏ فَيَقُولُ ‏"‏ إِنِّي صَائِمٌ ‏"‏ ‏.‏ قَالَتْ فَأَتَانِي يَوْمًا فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّهُ قَدْ أُهْدِيَتْ لَنَا هَدِيَّةٌ ‏.‏ قَالَ ‏"‏ وَمَا هِيَ ‏"‏ ‏.‏ قَالَتْ قُلْتُ حَيْسٌ ‏.‏ قَالَ ‏"‏ أَمَا إِنِّي قَدْ أَصْبَحْتُ صَائِمًا ‏"‏ ‏.‏ قَالَتْ ثُمَّ أَكَلَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{734}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{Aishah, the Mother of the Believers, narrated:"The Messenger of Allah came to me saying, 'Do you have anything for breakfast?' I said: 'No.' Then he said: 'I am fasting.'" She said: "One day he came to me and I said: 'O Messenger of Allah; I have received a gift for us.' He said: 'What is it?'" She said: "I said 'Hais' He said: 'I began the day fasting'" She said: "Then he ate}}
\hadithdefcmd{tirmidhi}{735}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا كَثِيرُ بْنُ هِشَامٍ، حَدَّثَنَا جَعْفَرُ بْنُ بُرْقَانَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كُنْتُ أَنَا وَحَفْصَةُ، صَائِمَتَيْنِ فَعُرِضَ لَنَا طَعَامٌ اشْتَهَيْنَاهُ فَأَكَلْنَا مِنْهُ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَبَدَرَتْنِي إِلَيْهِ حَفْصَةُ وَكَانَتِ ابْنَةَ أَبِيهَا فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّا كُنَّا صَائِمَتَيْنِ فَعُرِضَ لَنَا طَعَامٌ اشْتَهَيْنَاهُ فَأَكَلْنَا مِنْهُ ‏.‏ قَالَ ‏ "‏ اقْضِيَا يَوْمًا آخَرَ مَكَانَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى صَالِحُ بْنُ أَبِي الأَخْضَرِ وَمُحَمَّدُ بْنُ أَبِي حَفْصَةَ هَذَا الْحَدِيثَ عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ مِثْلَ هَذَا ‏.‏ وَرَوَاهُ مَالِكُ بْنُ أَنَسٍ وَمَعْمَرٌ وَعُبَيْدُ اللَّهِ بْنُ عُمَرَ وَزِيَادُ بْنُ سَعْدٍ وَغَيْرُ وَاحِدٍ مِنَ الْحُفَّاظِ عَنِ الزُّهْرِيِّ عَنْ عَائِشَةَ مُرْسَلاً ‏.‏ وَلَمْ يَذْكُرُوا فِيهِ عَنْ عُرْوَةَ وَهَذَا أَصَحُّ ‏.‏ لأَنَّهُ رُوِيَ عَنِ ابْنِ جُرَيْجٍ، قَالَ سَأَلْتُ الزُّهْرِيَّ قُلْتُ لَهُ أَحَدَّثَكَ عُرْوَةُ عَنْ عَائِشَةَ قَالَ لَمْ أَسْمَعْ مِنْ عُرْوَةَ فِي هَذَا شَيْئًا وَلَكِنِّي سَمِعْتُ فِي خِلاَفَةِ سُلَيْمَانَ بْنِ عَبْدِ الْمَلِكِ مِنْ نَاسٍ عَنْ بَعْضِ مَنْ سَأَلَ عَائِشَةَ عَنْ هَذَا الْحَدِيثِ ‏.‏ حَدَّثَنَا بِذَلِكَ عَلِيُّ بْنُ عِيسَى بْنِ يَزِيدَ الْبَغْدَادِيُّ حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ عَنِ ابْنِ جُرَيْجٍ فَذَكَرَ الْحَدِيثَ ‏.‏ وَقَدْ ذَهَبَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِلَى هَذَا الْحَدِيثِ فَرَأَوْا عَلَيْهِ الْقَضَاءَ إِذَا أَفْطَرَ وَهُوَ قَوْلُ مَالِكِ بْنِ أَنَسٍ ‏.‏\hadithno{735}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"Hafsah and I were both fasting when we were presented some food that we really wanted, so we ate from it. The Messenger of Allah came, and Hafsah beat me to him - she was the daughter of her father - and she said: 'O Messenger of Allah! We were both fasting when we were presented with some food that we wanted, so we ate from it.' He said: 'Make up another day in its place}}
\hadithdefcmd{tirmidhi}{736}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، قَالَتْ مَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم يَصُومُ شَهْرَيْنِ مُتَتَابِعَيْنِ إِلاَّ شَعْبَانَ وَرَمَضَانَ ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أُمِّ سَلَمَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ، أَيْضًا عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ مَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم فِي شَهْرٍ أَكْثَرَ صِيَامًا مِنْهُ فِي شَعْبَانَ كَانَ يَصُومُهُ إِلاَّ قَلِيلاً بَلْ كَانَ يَصُومُهُ كُلَّهُ ‏.‏\hadithno{736}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Umm Salamah narrated:"I did not see the Prophet fasting two consecutive months except for Sha'ban and Ramadan}}
\hadithdefcmd{tirmidhi}{737}{حَدَّثَنَا هَنَّادٌ حَدَّثَنَا عَبْدَةُ عَنْ مُحَمَّدِ بْنِ عَمْرٍو حَدَّثَنَا أَبُو سَلَمَةَ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِذَلِكَ ‏.‏ وَرُوِيَ عَنِ ابْنِ الْمُبَارَكِ أَنَّهُ قَالَ فِي هَذَا الْحَدِيثِ هُوَ جَائِزٌ فِي كَلاَمِ الْعَرَبِ إِذَا صَامَ أَكْثَرَ الشَّهْرِ أَنْ يُقَالَ صَامَ الشَّهْرَ كُلَّهُ وَيُقَالُ قَامَ فُلاَنٌ لَيْلَهُ أَجْمَعَ ‏.‏ وَلَعَلَّهُ تَعَشَّى وَاشْتَغَلَ بِبَعْضِ أَمْرِهِ ‏.‏ كَأَنَّ ابْنَ الْمُبَارَكِ قَدْ رَأَى كِلاَ الْحَدِيثَيْنِ مُتَّفِقَيْنِ يَقُولُ إِنَّمَا مَعْنَى هَذَا الْحَدِيثِ أَنَّهُ كَانَ يَصُومُ أَكْثَرَ الشَّهْرِ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَى سَالِمٌ أَبُو النَّضْرِ وَغَيْرُ وَاحِدٍ هَذَا الْحَدِيثَ عَنْ أَبِي سَلَمَةَ عَنْ عَائِشَةَ نَحْوَ رِوَايَةِ مُحَمَّدِ بْنِ عَمْرٍو ‏.‏\hadithno{737}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{(Another chain, a Hadith similar to no. 736) for that, from Aishah, :from the Prophet}}
\hadithdefcmd{tirmidhi}{738}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنِ الْعَلاَءِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا بَقِيَ نِصْفٌ مِنْ شَعْبَانَ فَلاَ تَصُومُوا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ عَلَى هَذَا اللَّفْظِ ‏.‏ وَمَعْنَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ أَنْ يَكُونَ الرَّجُلُ مُفْطِرًا فَإِذَا بَقِيَ مِنْ شَعْبَانَ شَيْءٌ أَخَذَ فِي الصَّوْمِ لِحَالِ شَهْرِ رَمَضَانَ ‏.‏ وَقَدْ رُوِيَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مَا يُشْبِهُ قَوْلَهُمْ حَيْثُ قَالَ صلى الله عليه وسلم ‏"‏ لاَ تَقَدَّمُوا شَهْرَ رَمَضَانَ بِصِيَامٍ إِلاَّ أَنْ يُوَافِقَ ذَلِكَ صَوْمًا كَانَ يَصُومُهُ أَحَدُكُمْ ‏"‏ ‏.‏ وَقَدْ دَلَّ فِي هَذَا الْحَدِيثِ أَنَّمَا الْكَرَاهِيَةُ عَلَى مَنْ يَتَعَمَّدُ الصِّيَامَ لِحَالِ رَمَضَانَ ‏.‏\hadithno{738}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah said: "When a half of Sha'ban remains then do not fast}}
\hadithdefcmd{tirmidhi}{739}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا الْحَجَّاجُ بْنُ أَرْطَاةَ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ فَقَدْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم لَيْلَةً فَخَرَجْتُ فَإِذَا هُوَ بِالْبَقِيعِ فَقَالَ ‏"‏ أَكُنْتِ تَخَافِينَ أَنْ يَحِيفَ اللَّهُ عَلَيْكِ وَرَسُولُهُ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي ظَنَنْتُ أَنَّكَ أَتَيْتَ بَعْضَ نِسَائِكَ ‏.‏ فَقَالَ ‏"‏ إِنَّ اللَّهَ عَزَّ وَجَلَّ يَنْزِلُ لَيْلَةَ النِّصْفِ مِنْ شَعْبَانَ إِلَى السَّمَاءِ الدُّنْيَا فَيَغْفِرُ لأَكْثَرَ مِنْ عَدَدِ شَعْرِ غَنَمِ كَلْبٍ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ الصِّدِّيقِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ لاَ نَعْرِفُهُ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ الْحَجَّاجِ ‏.‏ وَسَمِعْتُ مُحَمَّدًا يُضَعِّفُ هَذَا الْحَدِيثَ وَقَالَ يَحْيَى بْنُ أَبِي كَثِيرٍ لَمْ يَسْمَعْ مِنْ عُرْوَةَ وَالْحَجَّاجُ بْنُ أَرْطَاةَ لَمْ يَسْمَعْ مِنْ يَحْيَى بْنِ أَبِي كَثِيرٍ ‏.‏\hadithno{739}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"I could not find the Messenger of Allah one night. So I left and found him at Al-Baqi. He said: 'Did you fear that you had been wronged by Allah and His Messenger?' I said: 'O Messenger of Allah! I thought that you had gone to one of your wives.' So he said: 'Indeed Allah, Mighty and Sublime is He, descends to the lowest Heavens during the night of the middle of Sha'ban, to grant forgiveness to more than the number of hairs on the sheep of (Banu) Kalb}}
\hadithdefcmd{tirmidhi}{740}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ الْحِمْيَرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَفْضَلُ الصِّيَامِ بَعْدَ صِيَامِ شَهْرِ رَمَضَانَ شَهْرُ اللَّهِ الْمُحَرَّمُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ ‏.‏\hadithno{740}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah said: "The most virtuous fasting after the month of Ramadan is Allah's month Al-Muharram}}
\hadithdefcmd{tirmidhi}{741}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، قَالَ أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ، عَنِ النُّعْمَانِ بْنِ سَعْدٍ، عَنْ عَلِيٍّ، قَالَ سَأَلَهُ رَجُلٌ فَقَالَ أَىُّ شَهْرٍ تَأْمُرُنِي أَنْ أَصُومَ بَعْدَ شَهْرِ رَمَضَانَ قَالَ لَهُ مَا سَمِعْتُ أَحَدًا يَسْأَلُ عَنْ هَذَا إِلاَّ رَجُلاً سَمِعْتُهُ يَسْأَلُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَأَنَا قَاعِدٌ فَقَالَ يَا رَسُولَ اللَّهِ أَىُّ شَهْرٍ تَأْمُرُنِي أَنْ أَصُومَ بَعْدَ شَهْرِ رَمَضَانَ قَالَ ‏ "‏ إِنْ كُنْتَ صَائِمًا بَعْدَ شَهْرِ رَمَضَانَ فَصُمِ الْمُحَرَّمَ فَإِنَّهُ شَهْرُ اللَّهِ فِيهِ يَوْمٌ تَابَ اللَّهُ فِيهِ عَلَى قَوْمٍ وَيَتُوبُ فِيهِ عَلَى قَوْمٍ آخَرِينَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{741}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{An-Nu'man bin Sa'd narrated:"A man asked Ali: "Which month do you order me to fast after the month of Ramadan?' He said to him, 'I have not heard anyone ask this except for a man whom I heard asking the Messenger of Allah while I was sitting with him. He said: "O Messenger of Allah! Which month do you order me to fast after the month of Ramadan?" He said: "If you will fast after the month of Ramadan, then fast Al-Muharram, for indeed it is Allah's month in which there is a day that Allah accepted the repentance of a people, and in which He accepts the repentance of other people}}
\hadithdefcmd{tirmidhi}{742}{حَدَّثَنَا الْقَاسِمُ بْنُ دِينَارٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، وَطَلْقُ بْنُ غَنَّامٍ، عَنْ شَيْبَانَ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ مِنْ غُرَّةِ كُلِّ شَهْرٍ ثَلاَثَةَ أَيَّامٍ وَقَلَّمَا كَانَ يُفْطِرُ يَوْمَ الْجُمُعَةِ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَبِي هُرَيْرَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَبْدِ اللَّهِ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدِ اسْتَحَبَّ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ صِيَامَ يَوْمِ الْجُمُعَةِ وَإِنَّمَا يُكْرَهُ أَنْ يَصُومَ يَوْمَ الْجُمُعَةِ لاَ يَصُومُ قَبْلَهُ وَلاَ بَعْدَهُ ‏.‏ قَالَ وَرَوَى شُعْبَةُ عَنْ عَاصِمٍ هَذَا الْحَدِيثَ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{742}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah narrated:"The Messenger of Allah would fasting during the beginning of every month for three days, and Friday was the least of the days that he did not fast}}
\hadithdefcmd{tirmidhi}{743}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَصُومُ أَحَدُكُمْ يَوْمَ الْجُمُعَةِ إِلاَّ أَنْ يَصُومَ قَبْلَهُ أَوْ يَصُومَ بَعْدَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَجَابِرٍ وَجُنَادَةَ الأَزْدِيِّ وَجُوَيْرِيَةَ وَأَنَسٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ يَكْرَهُونَ لِلرَّجُلِ أَنْ يَخْتَصَّ يَوْمَ الْجُمُعَةِ بِصِيَامٍ لاَ يَصُومُ قَبْلَهُ وَلاَ بَعْدَهُ ‏.‏ وَبِهِ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{743}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Hurairah narrated that :the Messenger of Allah said: "None of you should fast on Friday unless he fasts before it, or he fasts after it}}
\hadithdefcmd{tirmidhi}{744}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا سُفْيَانُ بْنُ حَبِيبٍ، عَنْ ثَوْرِ بْنِ يَزِيدَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ، عَنْ أُخْتِهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَصُومُوا يَوْمَ السَّبْتِ إِلاَّ فِيمَا افْتَرَضَ اللَّهُ عَلَيْكُمْ فَإِنْ لَمْ يَجِدْ أَحَدُكُمْ إِلاَّ لِحَاءَ عِنَبَةٍ أَوْ عُودَ شَجَرَةٍ فَلْيَمْضُغْهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَمَعْنَى كَرَاهَتِهِ فِي هَذَا أَنْ يَخُصَّ الرَّجُلُ يَوْمَ السَّبْتِ بِصِيَامٍ لأَنَّ الْيَهُودَ تُعَظِّمُ يَوْمَ السَّبْتِ ‏.‏\hadithno{744}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdullah bin Busr narrated from his sister that :the Messenger of Allah said: "Do not fast on Saturday except for what has been made obligatory upon you (by Allah). If one of you does not find but a grape peal or a tree's twig, then let him chew it}}
\hadithdefcmd{tirmidhi}{745}{حَدَّثَنَا أَبُو حَفْصٍ، عَمْرُو بْنُ عَلِيٍّ الْفَلاَّسُ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ ثَوْرِ بْنِ يَزِيدَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ رَبِيعَةَ الْجُرَشِيِّ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَتَحَرَّى صَوْمَ الاِثْنَيْنِ وَالْخَمِيسِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ حَفْصَةَ وَأَبِي قَتَادَةَ وَأَبِي هُرَيْرَةَ وَأُسَامَةَ بْنِ زَيْدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{745}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Aishah narrated:"The Prophet used to try to fast on Mondays and Thursdays}}
\hadithdefcmd{tirmidhi}{746}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو أَحْمَدَ، وَمُعَاوِيَةُ بْنُ هِشَامٍ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، عَنْ خَيْثَمَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ مِنَ الشَّهْرِ السَّبْتَ وَالأَحَدَ وَالاِثْنَيْنِ وَمِنَ الشَّهْرِ الآخَرِ الثُّلاَثَاءَ وَالأَرْبِعَاءَ وَالْخَمِيسَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَرَوَى عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ هَذَا الْحَدِيثَ عَنْ سُفْيَانَ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{746}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"The Messenger of Allah would fast Saturdays, Sundays, and Mondays in one months, and Tuesdays, Wednesdays and Thursdays in the next month}}
\hadithdefcmd{tirmidhi}{747}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ مُحَمَّدِ بْنِ رِفَاعَةَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ تُعْرَضُ الأَعْمَالُ يَوْمَ الاِثْنَيْنِ وَالْخَمِيسِ فَأُحِبُّ أَنْ يُعْرَضَ عَمَلِي وَأَنَا صَائِمٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ فِي هَذَا الْبَابِ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏\hadithno{747}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated that:the Messenger of Allah said: "Deeds are presented on Monday and Thursday, and I love that my deeds be presented while I am fasting}}
\hadithdefcmd{tirmidhi}{748}{حَدَّثَنَا الْحُسَيْنُ بْنُ مُحَمَّدٍ الْحَرِيرِيُّ، وَمُحَمَّدُ بْنُ مَدُّويَهْ، قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، أَخْبَرَنَا هَارُونُ بْنُ سَلْمَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ مُسْلِمٍ الْقُرَشِيِّ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ أَوْ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ صِيَامِ الدَّهْرِ فَقَالَ ‏ "‏ إِنَّ لأَهْلِكَ عَلَيْكَ حَقًّا صُمْ رَمَضَانَ وَالَّذِي يَلِيهِ وَكُلَّ أَرْبِعَاءٍ وَخَمِيسٍ فَإِذًا أَنْتَ قَدْ صُمْتَ الدَّهْرَ وَأَفْطَرْتَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ مُسْلِمٍ الْقُرَشِيِّ حَدِيثٌ غَرِيبٌ ‏.‏ وَرَوَى بَعْضُهُمْ عَنْ هَارُونَ بْنِ سَلْمَانَ عَنْ مُسْلِمِ بْنِ عُبَيْدِ اللَّهِ عَنْ أَبِيهِ ‏.‏\hadithno{748}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ubaidullah (bin Muslim) Al-Qurashi narrated from his father who said:"I asked - or; the Prophet was asked - about fasting daily. So he said: 'Your family has a right over you.' Then he said: 'Fast Ramadan and that which is after it, and every Wednesday and Thursday. If you do that, then you will have fasted daily, as well as broken (the fast)}}
\hadithdefcmd{tirmidhi}{749}{حَدَّثَنَا قُتَيْبَةُ، وَأَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْبَدٍ الزِّمَّانِيِّ، عَنْ أَبِي قَتَادَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ صِيَامُ يَوْمِ عَرَفَةَ إِنِّي أَحْتَسِبُ عَلَى اللَّهِ أَنْ يُكَفِّرَ السَّنَةَ الَّتِي قَبْلَهُ وَالسَّنَةَ الَّتِي بَعْدَهُ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي قَتَادَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدِ اسْتَحَبَّ أَهْلُ الْعِلْمِ صِيَامَ يَوْمِ عَرَفَةَ إِلاَّ بِعَرَفَةَ ‏.‏\hadithno{749}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Qatadah narrated that :the Prophet said: "Fast the Day of Arafah, for indeed I anticipate that Allah will forgive (the sins) of the year after it, and the year before it}}
\hadithdefcmd{tirmidhi}{750}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَفْطَرَ بِعَرَفَةَ وَأَرْسَلَتْ إِلَيْهِ أُمُّ الْفَضْلِ بِلَبَنٍ فَشَرِبَ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَابْنِ عُمَرَ وَأُمِّ الْفَضْلِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ عَنِ ابْنِ عُمَرَ قَالَ حَجَجْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَلَمْ يَصُمْهُ يَعْنِي يَوْمَ عَرَفَةَ وَمَعَ أَبِي بَكْرٍ فَلَمْ يَصُمْهُ وَمَعَ عُمَرَ فَلَمْ يَصُمْهُ وَمَعَ عُثْمَانَ فَلَمْ يَصُمْهُ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ يَسْتَحِبُّونَ الإِفْطَارَ بِعَرَفَةَ لِيَتَقَوَّى بِهِ الرَّجُلُ عَلَى الدُّعَاءِ وَقَدْ صَامَ بَعْضُ أَهْلِ الْعِلْمِ يَوْمَ عَرَفَةَ بِعَرَفَةَ ‏.‏\hadithno{750}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn Abbas narrated:"The Prophet broke (the fast) of Arafah, Umm Fadl sent him some milk to drink}}
\hadithdefcmd{tirmidhi}{751}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَعَلِيُّ بْنُ حُجْرٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، وَإِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ أَبِيهِ، قَالَ سُئِلَ ابْنُ عُمَرَ عَنْ صَوْمِ، يَوْمِ عَرَفَةَ بِعَرَفَةَ فَقَالَ حَجَجْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فَلَمْ يَصُمْهُ وَمَعَ أَبِي بَكْرٍ فَلَمْ يَصُمْهُ وَمَعَ عُمَرَ فَلَمْ يَصُمْهُ وَمَعَ عُثْمَانَ فَلَمْ يَصُمْهُ ‏.‏ وَأَنَا لاَ أَصُومُهُ وَلاَ آمُرُ بِهِ وَلاَ أَنْهَى عَنْهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنِ ابْنِ أَبِي نَجِيحٍ عَنْ أَبِيهِ عَنْ رَجُلٍ عَنِ ابْنِ عُمَرَ ‏.‏ وَأَبُو نَجِيحٍ اسْمُهُ يَسَارٌ ‏وقد سمع من ابن عمر.‏\hadithno{751}\hadithgrade{Ahmad Muhammad Shakir: Sahih Isnaad; Al-Albani: Sahih Isnaad; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abi Najib narrated from his father who said:"Ibn Umar was asked about fasting (the Day of) Arafah (at Arafat). He said: 'I performed Hajj with the Prophet, and he did not fast it, and with Abu Bakr, and he did not fast it, and with Umar, and he did not fast it, and with Uthman, and he did not fast it. I do no fast it, nor order it nor forbid it}}
\hadithdefcmd{tirmidhi}{752}{حَدَّثَنَا قُتَيْبَةُ، وَأَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْبَدٍ الزِّمَّانِيِّ، عَنْ أَبِي قَتَادَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ صِيَامُ يَوْمِ عَاشُورَاءَ إِنِّي أَحْتَسِبُ عَلَى اللَّهِ أَنْ يُكَفِّرَ السَّنَةَ الَّتِي قَبْلَهُ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَلِيٍّ وَمُحَمَّدِ بْنِ صَيْفِيٍّ وَسَلَمَةَ بْنِ الأَكْوَعِ وَهِنْدِ بْنِ أَسْمَاءَ وَابْنِ عَبَّاسٍ وَالرُّبَيِّعِ بِنْتِ مُعَوِّذِ بْنِ عَفْرَاءَ وَعَبْدِ الرَّحْمَنِ بْنِ سَلَمَةَ الْخُزَاعِيِّ عَنْ عَمِّهِ وَعَبْدِ اللَّهِ بْنِ الزُّبَيْرِ ذَكَرُوا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ حَثَّ عَلَى صِيَامِ يَوْمِ عَاشُورَاءَ ‏.‏ قَالَ أَبُو عِيسَى لاَ نَعْلَمُ فِي شَيْءٍ مِنَ الرِّوَايَاتِ أَنَّهُ قَالَ ‏"‏ صِيَامُ يَوْمِ عَاشُورَاءَ كَفَّارَةُ سَنَةٍ ‏"‏ ‏.‏ إِلاَّ فِي حَدِيثِ أَبِي قَتَادَةَ ‏.‏ وَبِحَدِيثِ أَبِي قَتَادَةَ يَقُولُ أَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{752}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Qatadah narrated that :the Prophet said: "Fast the Day of Ashura, for indeed I anticipate that Allah will forgive (the sins of) the year before it}}
\hadithdefcmd{tirmidhi}{753}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ عَاشُورَاءُ يَوْمًا تَصُومُهُ قُرَيْشٌ فِي الْجَاهِلِيَّةِ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُهُ فَلَمَّا قَدِمَ الْمَدِينَةَ صَامَهُ وَأَمَرَ النَّاسَ بِصِيَامِهِ فَلَمَّا افْتُرِضَ رَمَضَانُ كَانَ رَمَضَانُ هُوَ الْفَرِيضَةَ وَتَرَكَ عَاشُورَاءَ فَمَنْ شَاءَ صَامَهُ وَمَنْ شَاءَ تَرَكَهُ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَقَيْسِ بْنِ سَعْدٍ وَجَابِرِ بْنِ سَمُرَةَ وَابْنِ عُمَرَ وَمُعَاوِيَةَ ‏.‏ قَالَ أَبُو عِيسَى وَالْعَمَلُ عِنْدَ أَهْلِ الْعِلْمِ عَلَى حَدِيثِ عَائِشَةَ وَهُوَ حَدِيثٌ صَحِيحٌ لاَ يَرَوْنَ صِيَامَ يَوْمِ عَاشُورَاءَ وَاجِبًا إِلاَّ مَنْ رَغِبَ فِي صِيَامِهِ لِمَا ذُكِرَ فِيهِ مِنَ الْفَضْلِ ‏.‏\hadithno{753}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"Ashura was a day that the Quraish used to fast during Jahiliyyah, and the Messenger of Allah used to fast it. But when (the fast of) Ramadan became obligatory, the Ramadan was the required and Ashura was left. So whoever wanted to, he fasted it, and whoever wanted to, he left it}}
\hadithdefcmd{tirmidhi}{754}{حَدَّثَنَا هَنَّادٌ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ حَاجِبِ بْنِ عُمَرَ، عَنِ الْحَكَمِ بْنِ الأَعْرَجِ، قَالَ انْتَهَيْتُ إِلَى ابْنِ عَبَّاسٍ وَهُوَ مُتَوَسِّدٌ رِدَاءَهُ فِي زَمْزَمَ فَقُلْتُ أَخْبِرْنِي عَنْ يَوْمِ عَاشُورَاءَ أَىُّ يَوْمٍ هُوَ أَصُومُهُ فَقَالَ إِذَا رَأَيْتَ هِلاَلَ الْمُحَرَّمِ فَاعْدُدْ ثُمَّ أَصْبِحْ مِنَ التَّاسِعِ صَائِمًا ‏.‏ قَالَ فَقُلْتُ أَهَكَذَا كَانَ يَصُومُهُ مُحَمَّدٌ صلى الله عليه وسلم قَالَ نَعَمْ ‏.‏\hadithno{754}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Al-Hakam bin Al-Arfaj said:"I met up with Ibn Abbas while he was reclining on his Rida at the Zamzam (well). So I said: 'Inform me about the Day of Ashura. On which day is it fasted?' He said: 'When you see the crescent of Al-Muharram, then count, then fast on the morning of the ninth day.'" He said: 'I said: Is this how Muhammad fasted it?' He said: 'Yes}}
\hadithdefcmd{tirmidhi}{755}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ يُونُسَ، عَنِ الْحَسَنِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ أَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِصَوْمِ عَاشُورَاءَ يَوْمَ الْعَاشِرِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدِ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي يَوْمِ عَاشُورَاءَ فَقَالَ بَعْضُهُمْ يَوْمُ التَّاسِعِ ‏.‏ وَقَالَ بَعْضُهُمْ يَوْمُ الْعَاشِرِ ‏.‏ وَرُوِيَ عَنِ ابْنِ عَبَّاسٍ أَنَّهُ قَالَ صُومُوا التَّاسِعَ وَالْعَاشِرَ وَخَالِفُوا الْيَهُودَ ‏.‏ وَبِهَذَا الْحَدِيثِ يَقُولُ الشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏\hadithno{755}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"The Messenger of Allah ordered fasting the tenth day for the Day of Ashura}}
\hadithdefcmd{tirmidhi}{756}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ مَا رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم صَائِمًا فِي الْعَشْرِ قَطُّ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا رَوَى غَيْرُ وَاحِدٍ عَنِ الأَعْمَشِ عَنْ إِبْرَاهِيمَ عَنِ الأَسْوَدِ عَنْ عَائِشَةَ ‏.‏ وَرَوَى الثَّوْرِيُّ وَغَيْرُهُ هَذَا الْحَدِيثَ عَنْ مَنْصُورٍ عَنْ إِبْرَاهِيمَ أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يُرَ صَائِمًا فِي الْعَشْرِ ‏.‏ وَرَوَى أَبُو الأَحْوَصِ عَنْ مَنْصُورٍ عَنْ إِبْرَاهِيمَ عَنْ عَائِشَةَ ‏.‏ وَلَمْ يَذْكُرْ فِيهِ عَنِ الأَسْوَدِ ‏.‏ وَقَدِ اخْتَلَفُوا عَلَى مَنْصُورٍ فِي هَذَا الْحَدِيثِ وَرِوَايَةُ الأَعْمَشِ أَصَحُّ وَأَوْصَلُ إِسْنَادًا ‏.‏ قَالَ وَسَمِعْتُ أَبَا بَكْرٍ مُحَمَّدُ بْنُ أَبَانَ يَقُولُ سَمِعْتُ وَكِيعًا يَقُولُ الأَعْمَشُ أَحْفَظُ لإِسْنَادِ إِبْرَاهِيمَ مِنْ مَنْصُورٍ ‏.‏\hadithno{756}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated:"I did not see the Prophet fasting at all during the ten}}
\hadithdefcmd{tirmidhi}{757}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ مُسْلِمٍ، هُوَ الْبَطِينُ وَهُوَ ابْنُ عِمْرَانَ عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ أَيَّامٍ الْعَمَلُ الصَّالِحُ فِيهِنَّ أَحَبُّ إِلَى اللَّهِ مِنْ هَذِهِ الأَيَّامِ الْعَشْرِ ‏"‏ ‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ وَلاَ الْجِهَادُ فِي سَبِيلِ اللَّهِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَلاَ الْجِهَادُ فِي سَبِيلِ اللَّهِ إِلاَّ رَجُلٌ خَرَجَ بِنَفْسِهِ وَمَالِهِ فَلَمْ يَرْجِعْ مِنْ ذَلِكَ بِشَيْءٍ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنِ ابْنِ عُمَرَ وَأَبِي هُرَيْرَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَجَابِرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{757}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated that :the Messenger of Allah said: "There are no days in which righteous deeds are more beloved to Allah than those ten days." They said: "O Messenger of Allah! Not even Jihad in Allah Cause?" The Messenger of Allah said: "Not even Jihad in Allah's Cause, unless a man were to out with his self and his wealth and not return from that with anything}}
\hadithdefcmd{tirmidhi}{758}{حَدَّثَنَا أَبُو بَكْرِ بْنُ نَافِعٍ الْبَصْرِيُّ، حَدَّثَنَا مَسْعُودُ بْنُ وَاصِلٍ، عَنْ نَهَّاسِ بْنِ قَهْمٍ، عَنْ قَتَادَةَ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا مِنْ أَيَّامٍ أَحَبُّ إِلَى اللَّهِ أَنْ يُتَعَبَّدَ لَهُ فِيهَا مِنْ عَشْرِ ذِي الْحِجَّةِ يَعْدِلُ صِيَامُ كُلِّ يَوْمٍ مِنْهَا بِصِيَامِ سَنَةٍ وَقِيَامُ كُلِّ لَيْلَةٍ مِنْهَا بِقِيَامِ لَيْلَةِ الْقَدْرِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ مَسْعُودِ بْنِ وَاصِلٍ عَنِ النَّهَّاسِ ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدًا عَنْ هَذَا الْحَدِيثِ فَلَمْ يَعْرِفْهُ مِنْ غَيْرِ هَذَا الْوَجْهِ مِثْلَ هَذَا ‏.‏ وَقَالَ قَدْ رُوِيَ عَنْ قَتَادَةَ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً شَيْءٌ مِنْ هَذَا ‏.‏ وَقَدْ تَكَلَّمَ يَحْيَى بْنُ سَعِيدٍ فِي نَهَّاسِ بْنِ قَهْمٍ مِنْ قِبَلِ حِفْظِهِ ‏.‏\hadithno{758}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah narrated that :the Prophet said: "There are no days more beloved to Allah that He be worshipped in them than the ten days of Dhul-Hijjah, fasting every day of them is the equivalent of fasting a year, and standing every night of them (in prayer) is the equivalent of standing on the Night of Qadr}}
\hadithdefcmd{tirmidhi}{759}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا سَعْدُ بْنُ سَعِيدٍ، عَنْ عُمَرَ بْنِ ثَابِتٍ، عَنْ أَبِي أَيُّوبَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَنْ صَامَ رَمَضَانَ ثُمَّ أَتْبَعَهُ سِتًّا مِنْ شَوَّالٍ فَذَلِكَ صِيَامُ الدَّهْرِ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ جَابِرٍ وَأَبِي هُرَيْرَةَ وَثَوْبَانَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي أَيُّوبَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدِ اسْتَحَبَّ قَوْمٌ صِيَامَ سِتَّةِ أَيَّامٍ مِنْ شَوَّالٍ بِهَذَا الْحَدِيثِ ‏.‏ قَالَ ابْنُ الْمُبَارَكِ هُوَ حَسَنٌ هُوَ مِثْلُ صِيَامِ ثَلاَثَةِ أَيَّامٍ مِنْ كُلِّ شَهْرٍ ‏.‏ قَالَ ابْنُ الْمُبَارَكِ وَيُرْوَى فِي بَعْضِ الْحَدِيثِ ‏"‏ وَيُلْحَقُ هَذَا الصِّيَامُ بِرَمَضَانَ ‏"‏ ‏.‏ وَاخْتَارَ ابْنُ الْمُبَارَكِ أَنْ تَكُونَ سِتَّةَ أَيَّامٍ فِي أَوَّلِ الشَّهْرِ ‏.‏ وَقَدْ رُوِيَ عَنِ ابْنِ الْمُبَارَكِ أَنَّهُ قَالَ إِنْ صَامَ سِتَّةَ أَيَّامٍ مِنْ شَوَّالٍ مُتَفَرِّقًا فَهُوَ جَائِزٌ ‏.‏ قَالَ وَقَدْ رَوَى عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ عَنْ صَفْوَانَ بْنِ سُلَيْمٍ وَسَعْدِ بْنِ سَعِيدٍ عَنْ عُمَرَ بْنِ ثَابِتٍ عَنْ أَبِي أَيُّوبَ عَنِ النَّبِيِّ صلى الله عليه وسلم هَذَا ‏.‏ وَرَوَى شُعْبَةُ عَنْ وَرْقَاءَ بْنِ عُمَرَ عَنْ سَعْدِ بْنِ سَعِيدٍ هَذَا الْحَدِيثَ ‏.‏ وَسَعْدُ بْنُ سَعِيدٍ هُوَ أَخُو يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ وَقَدْ تَكَلَّمَ بَعْضُ أَهْلِ الْحَدِيثِ فِي سَعْدِ بْنِ سَعِيدٍ مِنْ قِبَلِ حِفْظِهِ ‏.‏ حَدَّثَنَا هَنَّادٌ قَالَ أَخْبَرَنَا الْحُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ عَنْ إِسْرَائِيلَ أَبِي مُوسَى عَنِ الْحَسَنِ الْبَصْرِيِّ قَالَ كَانَ إِذَا ذُكِرَ عِنْدَهُ صِيَامُ سِتَّةِ أَيَّامٍ مِنْ شَوَّالٍ فَيَقُولُ وَاللَّهِ لَقَدْ رَضِيَ اللَّهُ بِصِيَامِ هَذَا الشَّهْرِ عَنِ السَّنَةِ كُلِّهَا ‏.‏\hadithno{759}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Ayub narrated that :the Messenger of Allah said: "Whoever fasts Ramadan, then follows it with six from Shawwal, then that is (equal in reward) to fasting everyday}}
\hadithdefcmd{tirmidhi}{760}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ أَبِي الرَّبِيعِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ عَهِدَ إِلَىَّ النَّبِيُّ صلى الله عليه وسلم ثَلاَثَةً أَنْ لاَ أَنَامَ إِلاَّ عَلَى وِتْرٍ وَصَوْمَ ثَلاَثَةِ أَيَّامٍ مِنْ كُلِّ شَهْرٍ وَأَنْ أُصَلِّيَ الضُّحَى ‏.‏\hadithno{760}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Hurairah narrated:"The Messenger of Allah took a covenant from me for three: To not sleep except after performing Witr, to fast three days of every month, and to perform the Duha prayer}}
\hadithdefcmd{tirmidhi}{761}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، قَالَ أَنْبَأَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَامٍ، يُحَدِّثُ عَنْ مُوسَى بْنِ طَلْحَةَ، قَالَ سَمِعْتُ أَبَا ذَرٍّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَبَا ذَرٍّ إِذَا صُمْتَ مِنَ الشَّهْرِ ثَلاَثَةَ أَيَّامٍ فَصُمْ ثَلاَثَ عَشْرَةَ وَأَرْبَعَ عَشْرَةَ وَخَمْسَ عَشْرَةَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي قَتَادَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَقُرَّةَ بْنِ إِيَاسٍ الْمُزَنِيِّ وَعَبْدِ اللَّهِ بْنِ مَسْعُودٍ وَأَبِي عَقْرَبٍ وَابْنِ عَبَّاسٍ وَعَائِشَةَ وَقَتَادَةَ بْنِ مِلْحَانَ وَعُثْمَانَ بْنِ أَبِي الْعَاصِي وَجَرِيرٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي ذَرٍّ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ فِي بَعْضِ الْحَدِيثِ أَنَّ ‏"‏ مَنْ صَامَ ثَلاَثَةَ أَيَّامٍ مِنْ كُلِّ شَهْرٍ كَانَ كَمَنْ صَامَ الدَّهْرَ ‏"‏ ‏.‏\hadithno{761}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abu Dharr narrated that :the Messenger of Allah said: "O Abu Dharr! When you fast three days out of a month, then fast the thirteenth, fourteenth, and fifteenth}}
\hadithdefcmd{tirmidhi}{762}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ أَبِي ذَرٍّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَنْ صَامَ مِنْ كُلِّ شَهْرٍ ثَلاَثَةَ أَيَّامٍ فَذَلِكَ صِيَامُ الدَّهْرِ ‏"‏ ‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ تَصْدِيقَ ذَلِكَ فِي كِتَابِهِ ‏:‏ ‏(‏مَنْ جَاءَ بِالْحَسَنَةِ فَلَهُ عَشْرُ أَمْثَالِهَا ‏)‏ ‏.‏ الْيَوْمُ بِعَشَرَةِ أَيَّامٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ أَبِي شِمْرٍ وَأَبِي التَّيَّاحِ عَنْ أَبِي عُثْمَانَ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{762}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Abu Dharr narrated:"The Messenger of Allah said: 'Whoever fasts three days in every month, then that is (similar to) fasting every day.' Then Allah Mighty and Sublime is He, attested to that in His Book, by revealing: Whoever brings a good deed, shall have ten times the like thereof. So a day is like ten}}
\hadithdefcmd{tirmidhi}{763}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، عَنْ يَزِيدَ الرِّشْكِ، قَالَ سَمِعْتُ مُعَاذَةَ، قَالَتْ قُلْتُ لِعَائِشَةَ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ ثَلاَثَةَ أَيَّامٍ مِنْ كُلِّ شَهْرٍ قَالَتْ نَعَمْ ‏.‏ قُلْتُ مِنْ أَيِّهِ كَانَ يَصُومُ قَالَتْ كَانَ لاَ يُبَالِي مِنْ أَيِّهِ صَامَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَيَزِيدُ الرِّشْكُ هُوَ يَزِيدُ الضُّبَعِيُّ وَهُوَ يَزِيدُ بْنُ الْقَاسِمِ وَهُوَ الْقَسَّامُ وَالرِّشْكُ هُوَ الْقَسَّامُ بِلُغَةِ أَهْلِ الْبَصْرَةِ ‏.‏\hadithno{763}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Yazid Ar-Rishk said:"I heard Mu'adhah saying to Aishah: 'Did the Messenger of Allah fast three days of every month?' She replied in the affirmative. So she said: 'Which of them would he fast?' She said: 'Which of them he would fast was not noticeable}}
\hadithdefcmd{tirmidhi}{764}{حَدَّثَنَا عِمْرَانُ بْنُ مُوسَى الْقَزَّازُ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، حَدَّثَنَا عَلِيُّ بْنُ زَيْدٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ رَبَّكُمْ يَقُولُ كُلُّ حَسَنَةٍ بِعَشْرِ أَمْثَالِهَا إِلَى سَبْعِمِائَةِ ضِعْفٍ وَالصَّوْمُ لِي وَأَنَا أَجْزِي بِهِ الصَّوْمُ جُنَّةٌ مِنَ النَّارِ وَلَخُلُوفُ فَمِ الصَّائِمِ أَطْيَبُ عِنْدَ اللَّهِ مِنْ رِيحِ الْمِسْكِ وَإِنْ جَهِلَ عَلَى أَحَدِكُمْ جَاهِلٌ وَهُوَ صَائِمٌ فَلْيَقُلْ إِنِّي صَائِمٌ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ مُعَاذِ بْنِ جَبَلٍ وَسَهْلِ بْنِ سَعْدٍ وَكَعْبِ بْنِ عُجْرَةَ وَسَلاَمَةَ بْنِ قَيْصَرٍ وَبَشِيرِ ابْنِ الْخَصَاصِيَةِ ‏.‏ وَاسْمُ بَشِيرٍ زَحْمُ بْنُ مَعْبَدٍ وَالْخَصَاصِيَةُ هِيَ أُمُّهُ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{764}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah said: "Indeed your Lord said: 'Every good deed is rewarded with ten of the same up to seven hundred times over. Fasting is for Me, and I shall reward for it.' Fasting is a shield from the Fire. The smell coming from the mouth of the one fasting is more pleasant to Allah than the scent of musk. If one of you is abused by an ignorant person while fasting, then let him say: 'Indeed I am fasting}}
\hadithdefcmd{tirmidhi}{765}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ الْعَقَدِيُّ، عَنْ هِشَامِ بْنِ سَعْدٍ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ فِي الْجَنَّةِ لَبَابًا يُدْعَى الرَّيَّانَ يُدْعَى لَهُ الصَّائِمُونَ فَمَنْ كَانَ مِنَ الصَّائِمِينَ دَخَلَهُ وَمَنْ دَخَلَهُ لَمْ يَظْمَأْ أَبَدًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{765}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sahl bin Sa'd narrated that:The Prophet said: "There is a gate in Paradise called Ar-Raiyyan, those who fast shall be invited into it, and whoever was among those who fasted, then he will enter it; and whoever enters it, he will never thirst again}}
\hadithdefcmd{tirmidhi}{766}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِلصَّائِمِ فَرْحَتَانِ فَرْحَةٌ حِينَ يُفْطِرُ وَفَرْحَةٌ حِينَ يَلْقَى رَبَّهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{766}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah narrated that:The Messenger of Allah said: "There are two joys for the fasting person: the joy when he breaks his fast, and the joy of when he meets his Lord}}
\hadithdefcmd{tirmidhi}{767}{حَدَّثَنَا قُتَيْبَةُ، وَأَحْمَدُ بْنُ عَبْدَةَ الضَّبِّيُّ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْبَدٍ، عَنْ أَبِي قَتَادَةَ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ كَيْفَ بِمَنْ صَامَ الدَّهْرَ قَالَ ‏"‏ لاَ صَامَ وَلاَ أَفْطَرَ ‏"‏ ‏.‏ أَوْ ‏"‏ لَمْ يَصُمْ وَلَمْ يُ��ْطِرْ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو وَعَبْدِ اللَّهِ بْنِ الشِّخِّيرِ وَعِمْرَانَ بْنِ حُصَيْنٍ وَأَبِي مُوسَى ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي قَتَادَةَ حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ كَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ صِيَامَ الدَّهْرِ وَأَجَازَهُ قَوْمٌ آخَرُونَ وَقَالُوا إِنَّمَا يَكُونُ صِيَامُ الدَّهْرِ إِذَا لَمْ يُفْطِرْ يَوْمَ الْفِطْرِ وَيَوْمَ الأَضْحَى وَأَيَّامِ التَّشْرِيقِ فَمَنْ أَفْطَرَ هَذِهِ الأَيَّامَ فَقَدْ خَرَجَ مِنْ حَدِّ الْكَرَاهِيَةِ وَلاَ يَكُونُ قَدْ صَامَ الدَّهْرَ كُلَّهُ ‏.‏ هَكَذَا رُوِيَ عَنْ مَالِكِ بْنِ أَنَسٍ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏ وَقَالَ أَحْمَدُ وَإِسْحَاقُ نَحْوًا مِنْ هَذَا وَقَالاَ لاَ يَجِبُ أَنْ يُفْطِرَ أَيَّامًا غَيْرَ هَذِهِ الْخَمْسَةِ الأَيَّامِ الَّتِي نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْهَا يَوْمِ الْفِطْرِ وَيَوْمِ الأَضْحَى وَأَيَّامَ التَّشْرِيقِ ‏.‏\hadithno{767}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Qatadah said:"It was said: 'O Messenger of Allah! What is the case of the one who fasts daily?' He said: 'He did not fast nor break (the fast).'" Or, he said: "He never fasted nor broke (his fast)}}
\hadithdefcmd{tirmidhi}{768}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ صِيَامِ النَّبِيِّ، صلى الله عليه وسلم قَالَتْ كَانَ يَصُومُ حَتَّى نَقُولَ قَدْ صَامَ وَيُفْطِرُ حَتَّى نَقُولَ قَدْ أَفْطَرَ ‏.‏ قَالَتْ وَمَا صَامَ رَسُولُ اللَّهُ صلى الله عليه وسلم شَهْرًا كَامِلاً إِلاَّ رَمَضَانَ ‏.‏ وَفِي الْبَابِ عَنْ أَنَسٍ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{768}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abdullah bin Shaqiq narrated:"I asked Aishah about the Prophet's fasting.' She said: 'He would fast until we said: "He has fasted" and he would abstain from fasting until we said: "He has abstained from fasting." (She said:) 'The Messenger of Allah did not fast an entire month except Ramadan}}
\hadithdefcmd{tirmidhi}{769}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ سُئِلَ عَنْ صَوْمِ النَّبِيِّ، صلى الله عليه وسلم قَالَ كَانَ يَصُومُ مِنَ الشَّهْرِ حَتَّى نَرَى أَنَّهُ لاَ يُرِيدُ أَنْ يُفْطِرَ مِنْهُ وَيُفْطِرُ حَتَّى نَرَى أَنَّهُ لاَ يُرِيدُ أَنْ يَصُومَ مِنْهُ شَيْئًا وَكُنْتَ لاَ تَشَاءُ أَنْ تَرَاهُ مِنَ اللَّيْلِ مُصَلِّيًا إِلاَّ رَأَيْتَهُ مُصَلِّيًا وَلاَ نَائِمًا إِلاَّ رَأَيْتَهُ نَائِمًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{769}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Jafar bin Humaid narrated that:Anas bin Malik was asked about the Prophet's fasting and he said: "He would fast during a month until we thought that he did not want to abstain from fasting during any of it. And, he would not fast during a month until we thought that he did not want to fast during any of it. (There was no time) that I wanted to see if he was performing Salat during the night, except that I would see him praying, nor to see him sleeping, except that I would see him sleeping}}
\hadithdefcmd{tirmidhi}{770}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، وَسُفْيَانَ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ أَبِي الْعَبَّاسِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَفْضَلُ الصَّوْمِ صَوْمُ أَخِي دَاوُدَ كَانَ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا وَلاَ يَفِرُّ إِذَا لاَقَى ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأَبُو الْعَبَّاسِ هُوَ الشَّاعِرُ الْمَكِّيُّ الأَعْمَى وَاسْمُهُ السَّائِبُ بْنُ فَرُّوخَ ‏.‏ قَالَ بَعْضُ أَهْلِ الْعِلْمِ أَفْضَلُ الصِّيَامِ أَنْ تَصُومَ يَوْمًا وَتُفْطِرَ يَوْمًا ‏.‏ وَيُقَالُ هَذَا هُوَ أَشَدُّ الصِّيَامِ ‏.‏\hadithno{770}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abdullah bin Amr narrated that:The Messenger of Allah said: "The most virtuous fast is the fast of my brother Dawud. He would fast a day, and not fast (the next) day. He would not flee at the time of engagement (with the enemy)}}
\hadithdefcmd{tirmidhi}{771}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي عُبَيْدٍ، مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ قَالَ شَهِدْتُ عُمَرَ بْنَ الْخَطَّابِ فِي يَوْمِ النَّحْرِ بَدَأَ بِالصَّلاَةِ قَبْلَ الْخُطْبَةِ ثُمَّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ صَوْمِ هَذَيْنِ الْيَوْمَيْنِ أَمَّا يَوْمُ الْفِطْرِ فَفِطْرُكُمْ مِنْ صَوْمِكُمْ وَعِيدٌ لِلْمُسْلِمِينَ وَأَمَّا يَوْمُ الأَضْحَى فَكُلُوا مِنْ لُحُومِ نُسُكِكُمْ ‏.‏ قَالَ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَأَبُو عُبَيْدٍ مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ اسْمُهُ سَعْدٌ وَيُقَالُ لَهُ مَوْلَى عَبْدِ الرَّحْمَنِ بْنِ أَزْهَرَ أَيْضًا وَعَبْدُ الرَّحْمَنِ بْنُ أَزْهَرَ هُوَ ابْنُ عَمِّ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ ‏.‏\hadithno{771}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Ubaid, the freed slave of Abdur-Rahman bin Awf narrated:"I witnessed Umar bin Al-Khattab on the Day of Nahr beginning with the Salat before the Khutbah. Then he said: 'I heard the Messenger of Allah prohibit fasting on these two days. As for the Day of Fitr, then it is for you to take a break from your fasting, and a celebration for the Muslims. As for the Day of Adha, then eat from the flesh that you have sacrificed}}
\hadithdefcmd{tirmidhi}{772}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ عَمْرِو بْنِ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ صِيَامَيْنِ يَوْمِ الأَضْحَى وَيَوْمِ الْفِطْرِ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عُمَرَ وَعَلِيٍّ وَعَائِشَةَ وَأَبِي هُرَيْرَةَ وَعُقْبَةَ بْنِ عَامِرٍ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي سَعِيدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَيْهِ عِنْدَ أَهْلِ الْعِلْمِ ‏.‏ قَالَ أَبُو عِيسَى وَعَمْرُو بْنُ يَحْيَى هُوَ ابْنُ عُمَارَةَ بْنِ أَبِي الْحَسَنِ الْمَازِنِيُّ الْمَدَنِيُّ وَهُوَ ثِقَةٌ رَوَى عَنْهُ سُفْيَانُ الثَّوْرِيُّ وَشُعْبَةُ وَمَالِكُ بْنُ أَنَسٍ ‏.‏\hadithno{772}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Sa'eed Al-Khudri narrated:"The Messenger of Allah prohibited two fasts: Fasting the Day of Adha and the Day of Fitr}}
\hadithdefcmd{tirmidhi}{773}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا وَكِيعٌ، عَنْ مُوسَى بْنِ عُلَىٍّ، عَنْ أَبِيهِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَوْمُ عَرَفَةَ وَيَوْمُ النَّحْرِ وَأَيَّامُ التَّشْرِيقِ عِيدُنَا أَهْلَ الإِسْلاَمِ وَهِيَ أَيَّامُ أَكْلٍ وَشُرْبٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَسَعْدٍ وَأَبِي هُرَيْرَةَ وَجَابِرٍ وَنُبَيْشَةَ وَبِشْرِ بْنِ سُحَيْمٍ وَعَبْدِ اللَّهِ بْنِ حُذَافَةَ وَأَنَسٍ وَحَمْزَةَ بْنِ عَمْرٍو الأَسْلَمِيِّ وَكَعْبِ بْنِ مَالِكٍ وَعَائِشَةَ وَعَمْرِو بْنِ الْعَاصِ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ عُقْبَةَ بْنِ عَامِرٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ يَكْرَهُونَ الصِّيَامَ أَيَّامَ التَّشْرِيقِ إِلاَّ أَنَّ قَوْمًا مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ رَخَّصُوا لِلْمُتَمَتِّعِ إِذَا لَمْ يَجِدْ هَدْيًا وَلَمْ يَصُمْ فِي الْعَشْرِ أَنْ يَصُومَ أَيَّامَ التَّشْرِيقِ ‏.‏ وَبِهِ يَقُولُ مَالِكُ بْنُ أَنَسٍ وَالشَّافِعِيُّ وَأَحْمَدُ وَإِسْحَاقُ ‏.‏ قَالَ أَبُو عِيسَى وَأَهْلُ الْعِرَاقِ يَقُولُونَ مُوسَى بْنُ عَلِيِّ بْنِ رَبَاحٍ وَأَهْلُ مِصْرَ يَقُولُونَ مُوسَى بْنُ عُلَىٍّ ‏.‏ وَقَالَ سَمِعْتُ قُتَيْبَةُ يَقُولُ سَمِعْتُ اللَّيْثَ بْنَ سَعْدٍ يَقُولُ قَالَ مُوسَى بْنُ عَلِيٍّ لاَ أَجْعَلُ أَحَدًا فِي حِلٍّ صَغَّرَ اسْمَ أَبِي ‏.‏\hadithno{773}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Uqbah bin Amir narrated that :The Messenger of Allah said: "The Day of Arafah, the Day of Nahr, and the Days of Tashriq are Eid for us. The people of Islam, and they are days of eating and drinking}}
\hadithdefcmd{tirmidhi}{774}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ رَافِعٍ النَّيْسَابُورِيُّ، وَمَحْمُودُ بْنُ غَيْلاَنَ، وَيَحْيَى بْنُ مُوسَى، قَالُوا حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ قَارِظٍ، عَنِ السَّائِبِ بْنِ يَزِيدَ، عَنْ رَافِعِ بْنِ خَدِيجٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أَفْطَرَ الْحَاجِمُ وَالْمَحْجُومُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عَلِيٍّ وَسَعْدٍ وَشَدَّادِ بْنِ أَوْسٍ وَثَوْبَانَ وَأُسَامَةَ بْنِ زَيْدٍ وَعَائِشَةَ وَمَعْقِلِ بْنِ سِنَانٍ وَيُقَالُ ابْنُ يَسَارٍ وَأَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ وَأَبِي مُوسَى وَبِلاَلٍ ‏.‏ قَالَ أَبُو عِيسَى وَحَدِيثُ رَافِعِ بْنِ خَدِيجٍ حَدِيثٌ حَسَنٌ ‏.‏ وَذُكِرَ عَنْ أَحْمَدَ بْنِ حَنْبَلٍ أَنَّهُ قَالَ أَصَحُّ شَيْءٍ فِي هَذَا الْبَابِ حَدِيثُ رَافِعِ بْنِ خَدِيجٍ ‏.‏ وَذُكِرَ عَنْ عَلِيِّ بْنِ عَبْدِ اللَّهِ أَنَّهُ قَالَ أَصَحُّ شَيْءٍ فِي هَذَا الْبَابِ حَدِيثُ ثَوْبَانَ وَشَدَّادِ بْنِ أَوْسٍ لأَنَّ يَحْيَى بْنَ أَبِي كَثِيرٍ رَوَى عَنْ أَبِي قِلاَبَةَ الْحَدِيثَيْنِ جَمِيعًا حَدِيثَ ثَوْبَانَ وَحَدِيثَ شَدَّادِ بْنِ أَوْسٍ ‏.‏ وَقَدْ كَرِهَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمُ الْحِجَامَةَ لِلصَّائِمِ حَتَّى أَنَّ بَعْضَ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم احْتَجَمَ بِاللَّيْلِ مِنْهُمْ أَبُو مُوسَى الأَشْعَرِيُّ وَابْنُ عُمَرَ وَبِهَذَا يَقُولُ ابْنُ الْمُبَارَكِ ‏.‏ قَالَ أَبُو عِيسَى سَمِعْتُ إِسْحَاقَ بْنَ مَنْصُورٍ يَقُولُ قَالَ عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ مَنِ احْتَجَمَ وَهُوَ صَائِمٌ فَعَلَيْهِ الْقَضَاءُ ‏.‏ قَالَ إِسْحَاقُ بْنُ مَنْصُورٍ وَهَكَذَا قَالَ أَحْمَدُ بْنُ حَنْبَلٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ ‏.‏ وَقَالَ أَبُو عِيسَى وَأَخْبَرَنِي الْحَسَنُ بْنُ مُحَمَّدٍ الزَّعْفَرَانِيُّ قَالَ قَالَ الشَّافِعِيُّ قَدْ رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ احْتَجَمَ وَهُوَ صَائِمٌ وَرُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ أَفْطَرَ الْحَاجِمُ وَالْمَحْجُومُ ‏"‏ ‏.‏ وَلاَ أَعْلَمُ وَاحِدًا مِنْ هَذَيْنِ الْحَدِيثَيْنِ ثَابِتًا وَلَوْ تَوَقَّى رَجُلٌ الْحِجَامَةَ وَهُوَ صَائِمٌ كَانَ أَحَبَّ إِلَىَّ وَلَوِ احْتَجَمَ صَائِمٌ لَمْ أَرَ ذَلِكَ أَنْ يُفْطِرَهُ ‏.‏ قَالَ أَبُو عِيسَى هَكَذَا كَانَ قَوْلُ الشَّافِعِيِّ بِبَغْدَادَ وَأَمَّا بِمِصْرَ فَمَالَ إِلَى الرُّخْصَةِ وَلَمْ يَرَ بِالْحِجَامَةِ لِلصَّائِمِ بَأْسًا وَاحْتَجَّ بِأَنَّ النَّبِيَّ صلى الله عليه وسلم احْتَجَمَ فِي حَجَّةِ الْوَدَاعِ وَهُوَ مُحْرِمٌ صَائِمٌ ‏.‏\hadithno{774}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Rafi bin Khadi narrated that:The Prophet said: "The cupper and the one cupped have broke the fast}}
\hadithdefcmd{tirmidhi}{775}{حَدَّثَنَا بِشْرُ بْنُ هِلاَلٍ الْبَصْرِيُّ، حَدَّثَنَا عَبْدُ الْوَارِثِ بْنُ سَعِيدٍ، حَدَّثَنَا أَيُّوبُ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ احْتَجَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ مُحْرِمٌ صَائِمٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَهَكَذَا رَوَى وُهَيْبٌ نَحْوَ رِوَايَةِ عَبْدِ الْوَارِثِ ‏.‏ وَرَوَى إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ عَنْ أَيُّوبَ عَنْ عِكْرِمَةَ مُرْسَلاً وَلَمْ يَذْكُرْ فِيهِ عَنِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{775}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated:"the Messenger of Allah was cupped while he was fasting and in Ihram}}
\hadithdefcmd{tirmidhi}{776}{حَدَّثَنَا أَبُو مُوسَى، مُحَمَّدُ بْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الأَنْصَارِيُّ، عَنْ حَبِيبِ بْنِ الشَّهِيدِ، عَنْ مَيْمُونِ بْنِ مِهْرَانَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم احْتَجَمَ وَهُوَ صَائِمٌ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{776}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ibn Abbas narrated:"The Prophet was cupped while he was fasting}}
\hadithdefcmd{tirmidhi}{777}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم احْتَجَمَ فِيمَا بَيْنَ مَكَّةَ وَالْمَدِينَةِ وَهُوَ مُحْرِمٌ صَائِمٌ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَجَابِرٍ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ إِلَى هَذَا الْحَدِيثِ وَلَمْ يَرَوْا بِالْحِجَامَةِ لِلصَّائِمِ بَأْسًا ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكِ بْنِ أَنَسٍ وَالشَّافِعِيِّ ‏.‏\hadithno{777}\hadithgrade{Ahmad Muhammad Shakir: Munkar; Al-Albani: Munkar; Zubair Ali Zai: Daif}\hadithtrans{Ibn Abbas narrated:"The Prophet was cupped somewhere between Makkah and Al-Madinah and he was fasting and in Ihram}}
\hadithdefcmd{tirmidhi}{778}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، وَخَالِدُ بْنُ الْحَارِثِ، عَنْ سَعِيدِ بْنِ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تُوَاصِلُوا ‏"‏ ‏.‏ قَالُوا فَإِنَّكَ تُوَاصِلُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِنِّي لَسْتُ كَأَحَدِكُمْ إِنَّ رَبِّي يُطْعِمُنِي وَيَسْقِينِي ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأَبِي هُرَيْرَةَ وَعَائِشَةَ وَابْنِ عُمَرَ وَجَابِرٍ وَأَبِي سَعِيدٍ وَبَشِيرِ ابْنِ الْخَصَاصِيَةِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَنَسٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ كَرِهُوا الْوِصَالَ فِي الصِّيَامِ ‏.‏ وَرُوِيَ عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ أَنَّهُ كَانَ يُوَاصِلُ الأَيَّامَ وَلاَ يُفْطِرُ ‏.‏\hadithno{778}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas narrated that :the Messenger of Allah said: "Do not perform Wisal" They said: "But you perform Wisal O Messenger of Allah." He said: "I am not like you are, indeed my Lord feeds me and gives me to drink}}
\hadithdefcmd{tirmidhi}{779}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، قَالَ أَخْبَرَتْنِي عَائِشَةُ، وَأُمُّ سَلَمَةَ زَوْجَا النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُدْرِكُهُ الْفَجْرُ وَهُوَ جُنُبٌ مِنْ أَهْلِهِ ثُمَّ يَغْتَسِلُ فَيَصُومُ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ وَأُمِّ سَلَمَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَهُوَ قَوْلُ سُفْيَانَ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَدْ قَالَ قَوْمٌ مِنَ التَّابِعِينَ إِذَا أَصْبَحَ جُنُبًا يَقْضِي ذَلِكَ الْيَوْمَ ‏.‏ وَالْقَوْلُ الأَوَّلُ أَصَحُّ ‏.‏\hadithno{779}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Abu Bakr Bin Abdur-Rahman bin Al-Harith bin Hashim said:"Aishah and Umm Salamah, the wives of the Prophet informed me that the Prophet would find that it was Fajr while he was Junub from (relations with) his wives, then he would perform Ghusl and fast}}
\hadithdefcmd{tirmidhi}{780}{حَدَّثَنَا أَزْهَرُ بْنُ مَرْوَانَ الْبَصْرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَوَاءٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دُعِيَ أَحَدُكُمْ إِلَى طَعَامٍ فَلْيُجِبْ فَإِنْ كَانَ صَائِمًا فَلْيُصَلِّ ‏"‏ ‏.‏ يَعْنِي الدُّعَاءَ ‏.‏\hadithno{780}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah narrated that:The Prophet said: "When one of you is invited to eat then let him respond, if he is fasting then let him pray." Meaning: supplicate}}
\hadithdefcmd{tirmidhi}{781}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دُعِيَ أَحَدُكُمْ وَهُوَ صَائِمٌ فَلْيَقُلْ إِنِّي صَائِمٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَكِلاَ الْحَدِيثَيْنِ فِي هَذَا الْبَابِ عَنْ أَبِي هُرَيْرَةَ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{781}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated that :The Prophet said: "When one of you is invited (to a meal) and he is fasting, then let him said: 'Indeed I am fasting}}
\hadithdefcmd{tirmidhi}{782}{حَدَّثَنَا قُتَيْبَةُ، وَنَصْرُ بْنُ عَلِيٍّ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَصُومُ الْمَرْأَةُ وَزَوْجُهَا شَاهِدٌ يَوْمًا مِنْ غَيْرِ شَهْرِ رَمَضَانَ إِلاَّ بِإِذْنِهِ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَأَبِي سَعِيدٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ أَبِي الزِّنَادِ عَنْ مُوسَى بْنِ أَبِي عُثْمَانَ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{782}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Abu Hurairah narrated that:The Prophet said: "A woman may not fast a day - other than in the month of Ramadan - while her husband is present, except with his permission}}
\hadithdefcmd{tirmidhi}{783}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ إِسْمَاعِيلَ السُّدِّيِّ، عَنْ عَبْدِ اللَّهِ الْبَهِيِّ، عَنْ عَائِشَةَ، قَالَتْ مَا كُنْتُ أَقْضِي مَا يَكُونُ عَلَىَّ مِنْ رَمَضَانَ إِلاَّ فِي شَعْبَانَ حَتَّى تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ وَقَدْ رَوَى يَحْيَى بْنُ سَعِيدٍ الأَنْصَارِيُّ عَنْ أَبِي سَلَمَةَ عَنْ عَائِشَةَ نَحْوَ هَذَا ‏.‏\hadithno{783}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Aishah narrated:"I would not make up what was due upon me from Ramadan except in Sha'ban, until the Messenger of Allah died}}
\hadithdefcmd{tirmidhi}{784}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكٌ، عَنْ حَبِيبِ بْنِ زَيْدٍ، عَنْ لَيْلَى، عَنْ مَوْلاَتِهَا، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الصَّائِمُ إِذَا أَكَلَ عِنْدَهُ الْمَفَاطِيرُ صَلَّتْ عَلَيْهِ الْمَلاَئِكَةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَرَوَى شُعْبَةُ هَذَا الْحَدِيثَ عَنْ حَبِيبِ بْنِ زَيْدٍ عَنْ لَيْلَى عَنْ جَدَّتِهِ أُمِّ عُمَارَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{784}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Hasan}\hadithtrans{Laila narrated from the one who freed her (Umm Amarah) that:The Prophet said: "When those who are not fasting eat in the presence of the fasting person, the angels send Salat upon him}}
\hadithdefcmd{tirmidhi}{785}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا أَبُو دَاوُدَ، أَخْبَرَنَا شُعْبَةُ، عَنْ حَبِيبِ بْنِ زَيْدٍ، قَالَ سَمِعْتُ مَوْلاَةً، لَنَا يُقَالُ لَهَا لَيْلَى تُحَدِّثُ عَنْ جَدَّتِهِ أُمِّ عُمَارَةَ بِنْتِ كَعْبٍ الأَنْصَارِيَّةِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَيْهَا فَقَدَّمَتْ إِلَيْهِ طَعَامًا فَقَالَ ‏"‏ كُلِي ‏"‏ ‏.‏ فَقَالَتْ إِنِّي صَائِمَةٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ الصَّائِمَ تُصَلِّي عَلَيْهِ الْمَلاَئِكَةُ إِذَا أُكِلَ عِنْدَهُ حَتَّى يَفْرُغُوا ‏"‏ ‏.‏ وَرُبَّمَا قَالَ ‏"‏ حَتَّى يَشْبَعُوا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَهُوَ أَصَحُّ مِنْ حَدِيثِ شَرِيكٍ ‏.‏\hadithno{785}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Habib bin Zaid said:"I heard a freed slave of ours called Laila narrated from [his (Habib's) grandmother] Umm Amarah bint Ka'b Al-Ansar, that the Prophet entered upon her and some food was brought to him. He said: 'Eat.' She said: 'I am fasting.' So the Messenger of Allah said: 'Indeed the angels send Salat upon the fasting person when (others) eat in his presence, until they finish.' And perhaps he said: 'Until they have eaten their fill}}
\hadithdefcmd{tirmidhi}{786}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ حَبِيبِ بْنِ زَيْدٍ، عَنْ مَوْلاَةٍ، لَهُمْ يُقَالُ لَهَا لَيْلَى عَنْ جَدَّتِهِ أُمِّ عُمَارَةَ بِنْتِ كَعْبٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ وَلَمْ يَذْكُرْ فِيهِ ‏ "‏ حَتَّى يَفْرُغُوا أَوْ يَشْبَعُوا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَأُمُّ عُمَارَةَ هِيَ جَدَّةُ حَبِيبِ بْنِ زَيْدٍ الأَنْصَارِيِّ ‏.‏\hadithno{786}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{(Another chain) from Umm Amarah bint Ka'b Al-Ansari:From the Prophet, that is similar, except that he did not mention "Until they finish, or they have eating their fill}}
\hadithdefcmd{tirmidhi}{787}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، عَنْ عُبَيْدَةَ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كُنَّا نَحِيضُ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ نَطْهُرُ فَيَأْمُرُنَا بِقَضَاءِ الصِّيَامِ وَلاَ يَأْمُرُنَا بِقَضَاءِ الصَّلاَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَقَدْ رُوِيَ عَنْ مُعَاذَةَ عَنْ عَائِشَةَ أَيْضًا ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ لاَ نَعْلَمُ بَيْنَهُمُ اخْتِلاَفًا أَنَّ الْحَائِضَ تَقْضِي الصِّيَامَ وَلاَ تَقْضِي الصَّلاَةَ ‏.‏ قَالَ أَبُو عِيسَى وَعُبَيْدَةُ هُوَ ابْنُ مُعَتِّبٍ الضَّبِّيُّ الْكُوفِيُّ يُكْنَى أَبَا عَبْدِ الْكَرِيمِ ‏.‏\hadithno{787}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated:"We would menstruate during the time of the Messenger of Allah, then when we became pure we were ordered to make up the fasts but we were not ordered to make up the Salat}}
\hadithdefcmd{tirmidhi}{788}{حَدَّثَنَا عَبْدُ الْوَهَّابِ بْنُ عَبْدِ الْحَكَمِ الْبَغْدَادِيُّ الْوَرَّاقُ، وَأَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ قَالاَ حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، حَدَّثَنِي إِسْمَاعِيلُ بْنُ كَثِيرٍ، قَالَ سَمِعْتُ عَاصِمَ بْنَ لَقِيطِ بْنِ صَبْرَةَ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ أَخْبِرْنِي عَنِ الْوُضُوءِ، ‏.‏ قَالَ ‏ "‏ أَسْبِغِ الْوُضُوءَ وَخَلِّلْ بَيْنَ الأَصَابِعِ وَبَالِغْ فِي الاِسْتِنْشَاقِ إِلاَّ أَنْ تَكُونَ صَائِمًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ كَرِهَ أَهْلُ الْعِلْمِ السَّعُوطَ لِلصَّائِمِ وَرَأَوْا أَنَّ ذَلِكَ يُفْطِرُهُ وَفِي الْحَدِيثِ مَا يُقَوِّي قَوْلَهُمْ ‏.‏\hadithno{788}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Asim bin Laqit bin Sabrah narrated:From his father who said: "I said. 'O Messenger of Allah! Inform me about Wudu.' So he said: "Perform Wudu well, and go between the fingers, and perform Istinshaq extensively except when fasting}}
\hadithdefcmd{tirmidhi}{789}{حَدَّثَنَا بِشْرُ بْنُ مُعَاذٍ الْعَقَدِيُّ الْبَصْرِيُّ، حَدَّثَنَا أَيُّوبُ بْنُ وَاقِدٍ الْكُوفِيُّ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ نَزَلَ عَلَى قَوْمٍ فَلاَ يَصُومَنَّ تَطَوُّعًا إِلاَّ بِإِذْنِهِمْ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ مُنْكَرٌ لاَ نَعْرِفُ أَحَدًا مِنَ الثِّقَاتِ رَوَى هَذَا الْحَدِيثَ عَنْ هِشَامِ بْنِ عُرْوَةَ ‏.‏ وَقَدْ رَوَى مُوسَى بْنُ دَاوُدَ عَنْ أَبِي بَكْرٍ الْمَدِينِيِّ عَنْ هِشَامِ بْنِ عُرْوَةَ عَنْ أَبِيهِ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوًا مِنْ هَذَا ‏.‏ قَالَ أَبُو عِيسَى وَهَذَا حَدِيثٌ ضَعِيفٌ أَيْضًا ‏.‏ وَأَبُو بَكْرٍ ضَعِيفٌ عِنْدَ أَهْلِ الْحَدِيثِ وَأَبُو بَكْرٍ الْمَدَنِيُّ الَّذِي رَوَى عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ اسْمُهُ الْفَضْلُ بْنُ مُبَشِّرٍ وَهُوَ أَوْثَقُ مِنْ هَذَا وَأَقْدَمُ ‏.‏\hadithno{789}\hadithgrade{Ahmad Muhammad Shakir: Very Daif; Al-Albani: Very Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Aishah narrated that:The Messenger of Allah said: "Whoever stays with a people, then he is not to fast without their permission}}
\hadithdefcmd{tirmidhi}{790}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، وَعُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَعْتَكِفُ الْعَشْرَ الأَوَاخِرَ مِنْ رَمَضَانَ حَتَّى قَبَضَهُ اللَّهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ أُبَىِّ بْنِ كَعْبٍ وَأَبِي لَيْلَى وَأَبِي سَعِيدٍ وَأَنَسٍ وَابْنِ عُمَرَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ وَعَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{790}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Abu Hurairah and Aishah narrated:"The Prophet would perform I'tikaf during the last ten (days) of Ramadan until Allah took him}}
\hadithdefcmd{tirmidhi}{791}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَعْتَكِفَ صَلَّى الْفَجْرَ ثُمَّ دَخَلَ فِي مُعْتَكَفِهِ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ يَحْيَى بْنِ سَعِيدٍ عَنْ عَمْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مُرْسَلاً ‏.‏ رَوَاهُ مَالِكٌ وَغَيْرُ وَاحِدٍ عَنْ يَحْيَى بْنِ سَعِيدٍ عَنْ عَمْرَةَ مُرْسَلاً ‏.‏ وَرَوَاهُ الأَوْزَاعِيُّ وَسُفْيَانُ الثَّوْرِيُّ وَغَيْرُ وَاحِدٍ عَنْ يَحْيَى بْنِ سَعِيدٍ عَنْ عَمْرَةَ عَنْ عَائِشَةَ ‏.‏ وَالْعَمَلُ عَلَى هَذَا الْحَدِيثِ عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ يَقُولُونَ إِذَا أَرَادَ الرَّجُلُ أَنْ يَعْتَكِفَ صَلَّى الْفَجْرَ ثُمَّ دَخَلَ فِي مُعْتَكَفِهِ ‏.‏ وَهُوَ قَوْلُ أَحْمَدَ بْنِ حَنْبَلٍ وَإِسْحَاقَ بْنِ إِبْرَاهِيمَ ‏.‏ وَقَالَ بَعْضُهُمْ إِذَا أَرَادَ أَنْ يَعْتَكِفَ فَلْتَغِبْ لَهُ الشَّمْسُ مِنَ اللَّيْلَةِ الَّتِي يُرِيدُ أَنْ يَعْتَكِفَ فِيهَا مِنَ الْغَدِ وَقَدْ قَعَدَ فِي مُعْتَكَفِهِ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَمَالِكِ بْنِ أَنَسٍ ‏.‏\hadithno{791}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"When the Messenger of Allah wanted to perform I'tikaf, he would perform Fajr prayer and then he would enter his place of I'tikaf}}
\hadithdefcmd{tirmidhi}{792}{حَدَّثَنَا هَارُونُ بْنُ إِسْحَاقَ الْهَمْدَانِيُّ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُجَاوِرُ فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ وَيَقُولُ ‏"‏ تَحَرَّوْا لَيْلَةَ الْقَدْرِ فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ ‏"‏ ‏.‏ وَفِي الْبَابِ عَنْ عُمَرَ وَأُبَىٍّ وَجَابِرِ بْنِ سَمُرَةَ وَجَابِرِ بْنِ عَبْدِ اللَّهِ وَابْنِ عُمَرَ وَالْفَلَتَانِ بْنِ عَاصِمٍ وَأَنَسٍ وَأَبِي سَعِيدٍ وَعَبْدِ اللَّهِ بْنِ أُنَيْسٍ وَأَبِي بَكْرَةَ وَابْنِ عَبَّاسٍ وَبِلاَلٍ وَعُبَادَةَ بْنِ الصَّامِتِ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَوْلُهَا يُجَاوِرُ يَعْنِي يَعْتَكِفُ ‏.‏ وَأَكْثَرُ الرِّوَايَاتِ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ الْتَمِسُوهَا فِي الْعَشْرِ الأَوَاخِرِ فِي كُلِّ وِتْرٍ ‏"‏ ‏.‏ وَرُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم فِي لَيْلَةِ الْقَدْرِ أَنَّهَا لَيْلَةُ إِحْدَى وَعِشْرِينَ وَلَيْلَةُ ثَلاَثٍ وَعِشْرِينَ وَخَمْسٍ وَعِشْرِينَ وَسَبْعٍ وَعِشْرِينَ وَتِسْعٍ وَعِشْرِينَ وَآخِرُ لَيْلَةٍ مِنْ رَمَضَانَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى قَالَ الشَّافِعِيُّ كَأَنَّ هَذَا عِنْدِي وَاللَّهُ أَعْلَمُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُجِيبُ عَلَى نَحْوِ مَا يُسْأَلُ عَنْهُ يُقَالُ لَهُ نَلْتَمِسُهَا فِي لَيْلَةِ كَذَا فَيَقُولُ الْتَمِسُوهَا فِي لَيْلَةِ كَذَا ‏.‏ قَالَ الشَّافِعِيُّ وَأَقْوَى الرِّوَايَاتِ عِنْدِي فِيهَا لَيْلَةُ إِحْدَى وَعِشْرِينَ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ عَنْ أُبَىِّ بْنِ كَعْبٍ أَنَّهُ كَانَ يَحْلِفُ أَنَّهَا لَيْلَةُ سَبْعٍ وَعِشْرِينَ ‏.‏ وَيَقُولُ أَخْبَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِعَلاَمَتِهَا فَعَدَدْنَا وَحَفِظْنَا ‏.‏ وَرُوِيَ عَنْ أَبِي قِلاَبَةَ أَنَّهُ قَالَ لَيْلَةُ الْقَدْرِ تَنْتَقِلُ فِي الْعَشْرِ الأَوَاخِرِ ‏.‏ حَدَّثَنَا بِذَلِكَ عَبْدُ بْنُ حُمَيْدٍ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ عَنْ مَعْمَرٍ عَنْ أَيُّوبَ عَنْ أَبِي قِلاَبَةَ بِهَذَا ‏.‏\hadithno{792}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Aishah narrated:"The Messenger of Allah would Yujawir (stay in I'tikaf) during the last ten (nights) of Ramadan and he said: 'Seek the Night of Al-Qadr during the last ten (nights) of Ramadan}}
\hadithdefcmd{tirmidhi}{793}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى الْكُوفِيُّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، قَالَ قُلْتُ لأُبَىِّ بْنِ كَعْبٍ أَنَّى عَلِمْتَ أَبَا الْمُنْذِرِ أَنَّهَا لَيْلَةُ سَبْعٍ وَعِشْرِينَ قَالَ بَلَى أَخْبَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَنَّهَا لَيْلَةٌ صَبِيحَتُهَا تَطْلُعُ الشَّمْسُ لَيْسَ لَهَا شُعَاعٌ ‏"‏ ‏.‏ فَعَدَدْنَا وَحَفِظْنَا وَاللَّهِ لَقَدْ عَلِمَ ابْنُ مَسْعُودٍ أَنَّهَا فِي رَمَضَانَ وَأَنَّهَا لَيْلَةُ سَبْعٍ وَعِشْرِينَ وَلَكِنْ كَرِهَ أَنْ يُخْبِرَكُمْ فَتَتَّكِلُوا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{793}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Zirr said:"I said to Ubayy bin Ka'b: 'O Abu Al-Mundhir! How do you know that it is the night of the twenty-seventh?' He said: 'Rather, the Messenger of Allah informed us that it is a night (after which) the sun rises without rays, so we counted and we remembered it. By Allah! Ibn Mas'ud learned that it is in Ramadan and that it is the nigh of the twenty-seventh, but he did not want to inform you lest you would depend on it}}
\hadithdefcmd{tirmidhi}{794}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا عُيَيْنَةُ بْنُ عَبْدِ الرَّحْمَنِ، قَالَ حَدَّثَنِي أَبِي قَالَ، ذُكِرَتْ لَيْلَةُ الْقَدْرِ عِنْدَ أَبِي بَكْرَةَ فَقَالَ مَا أَنَا بِمُلْتَمِسِهَا، لِشَيْءٍ سَمِعْتُهُ مِنْ، رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ فِي الْعَشْرِ الأَوَاخِرِ فَإِنِّي سَمِعْتُهُ يَقُولُ ‏ "‏ الْتَمِسُوهَا فِي تِسْعٍ يَبْقَيْنَ أَوْ فِي سَبْعٍ يَبْقَيْنَ أَوْ فِي خَمْسٍ يَبْقَيْنَ أَوْ فِي ثَلاَثٍ أَوْ آخِرِ لَيْلَةٍ ‏"‏ ‏.‏ قَالَ وَكَانَ أَبُو بَكْرَةَ يُصَلِّي فِي الْعِشْرِينَ مِنْ رَمَضَانَ كَصَلاَتِهِ فِي سَائِرِ السَّنَةِ فَإِذَا دَخَلَ الْعَشْرُ اجْتَهَدَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{794}\hadithgrade{Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Uyainah bin Abdur-Rahman narrated:"My father narrated to me: 'The Night of Al-Qadr was mentioned in the presence of Abu Bakrah, so he said: "I do not search for it due to something that I heard from the Messenger of Allah, except for during the last ten (nights); for indeed I heard him say: 'Search for it when nine remain, or; when seven remain, or; when five remain, or; during the last three nights.'" He (Uyainah) said: "During the twenty (nights) of Ramadan, Abu Bakrah used to perform Salat just as he performed Salat during the rest of the year. But when the (last) ten began, he would struggle (performing more Salat during the night)}}
\hadithdefcmd{tirmidhi}{795}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ هُبَيْرَةَ بْنِ يَرِيمَ، عَنْ عَلِيٍّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُوقِظُ أَهْلَهُ فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{795}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ali narrated:"The Prophet would awaken his family during the last ten (nights) of Ramadan}}
\hadithdefcmd{tirmidhi}{796}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، عَنِ الْحَسَنِ بْنِ عُبَيْدِ اللَّهِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَجْتَهِدُ فِي الْعَشْرِ الأَوَاخِرِ مَا لاَ يَجْتَهِدُ فِي غَيْرِهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{796}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Aishah narrated:"The Messenger of Allah would struggle (to perform Salat more) during the last ten (nights) more than he would struggle in the rest of it}}
\hadithdefcmd{tirmidhi}{797}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ نُمَيْرِ بْنِ عَرِيبٍ، عَنْ عَامِرِ بْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْغَنِيمَةُ الْبَارِدَةُ الصَّوْمُ فِي الشِّتَاءِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ مُرْسَلٌ ‏.‏ عَامِرُ بْنُ مَسْعُودٍ لَمْ يُدْرِكِ النَّبِيَّ صلى الله عليه وسلم وَهُوَ وَالِدُ إِبْرَاهِيمَ بْنِ عَامِرٍ الْقُرَشِيِّ الَّذِي رَوَى عَنْهُ شُعْبَةُ وَالثَّوْرِيُّ ‏.‏\hadithno{797}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Amir bin Mas'ud narrated that:The Prophet said: "Fasting during the winter is an easy reward}}
\hadithdefcmd{tirmidhi}{798}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا بَكْرُ بْنُ مُضَرَ، عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ يَزِيدَ، مَوْلَى سَلَمَةَ بْنِ الأَكْوَعِ عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، قَالَ لَمَّا نَزَلَتْ ‏:‏ ‏(‏وَعَلَى الَّذِينَ يُطِيقُونَهُ فِدْيَةٌ طَعَامُ مِسْكِينٍ ‏)‏ كَانَ مَنْ أَرَادَ مِنَّا أَنْ يُفْطِرَ وَيَفْتَدِيَ حَتَّى نَزَلَتِ الآيَةُ الَّتِي بَعْدَهَا فَنَسَخَتْهَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَيَزِيدُ هُوَ ابْنُ أَبِي عُبَيْدٍ مَوْلَى سَلَمَةَ بْنِ الأَكْوَعِ ‏.‏\hadithno{798}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Salamah bin Al-Akwa said:"When the following was revealed: 'And for those upon whom it is difficult, (they may) feed a poor person' - if one of us wanted we would not fast, and pay the ransom, until the Ayah after it was revealed abrogating it}}
\hadithdefcmd{tirmidhi}{799}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ جَعْفَرٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ، أَنَّهُ قَالَ أَتَيْتُ أَنَسَ بْنَ مَالِكٍ فِي رَمَضَانَ وَهُوَ يُرِيدُ سَفَرًا وَقَدْ رُحِلَتْ لَهُ رَاحِلَتُهُ وَلَبِسَ ثِيَابَ السَّفَرِ فَدَعَا بِطَعَامٍ فَأَكَلَ فَقُلْتُ لَهُ سُنَّةٌ قَالَ سُنَّةٌ ‏.‏ ثُمَّ رَكِبَ ‏.‏\hadithno{799}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Muhammad bin Ka'b narrated:"I went to Anas bin Malik during Ramadan and he was about to travel. His mount was prepared for him, and he put on his traveling clothes, then he called for some food to eat, and I said to him: 'Is it Sunnah?' He said: 'It is Sunnah.' Then he rode}}
\hadithdefcmd{tirmidhi}{800}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنِي زَيْدُ بْنُ أَسْلَمَ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ الْمُنْكَدِرِ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ، قَالَ أَتَيْتُ أَنَسَ بْنَ مَالِكٍ فِي رَمَضَانَ فَذَكَرَ نَحْوَهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏ وَمُحَمَّدُ بْنُ جَعْفَرٍ هُوَ ابْنُ أَبِي كَثِيرٍ هُوَ مَدِينِيٌّ ثِقَةٌ وَهُوَ أَخُو إِسْمَاعِيلَ بْنِ جَعْفَرٍ ‏.‏ وَعَبْدُ اللَّهِ بْنُ جَعْفَرٍ هُوَ ابْنُ نَجِيحٍ وَالِدُ عَلِيِّ بْنِ عَبْدِ اللَّهِ الْمَدِينِيِّ وَكَانَ يَحْيَى بْنُ مَعِينٍ يُضَعِّفُهُ ‏.‏ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا الْحَدِيثِ وَقَالُوا لِلْمُسَافِرِ أَنْ يُفْطِرَ فِي بَيْتِهِ قَبْلَ أَنْ يَخْرُجَ وَلَيْسَ لَهُ أَنْ يَقْصُرَ الصَّلاَةَ حَتَّى يَخْرُجَ مِنْ جِدَارِ الْمَدِينَةِ أَوِ الْقَرْيَةِ ‏.‏ وَهُوَ قَوْلُ إِسْحَاقَ بْنِ إِبْرَاهِيمَ الْحَنْظَلِيِّ ‏.‏\hadithno{800}\hadithgrade{Zubair Ali Zai: Sahih}\hadithtrans{(Another chain) from Muhammad bin Ka'b who said:"I went to Anas bin Malik during Ramadan" and he mentioned a similar narration (as no)}}
\hadithdefcmd{tirmidhi}{801}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ سَعْدِ بْنِ طَرِيفٍ، عَنْ عُمَيْرِ بْنِ مَأْمُونٍ، عَنِ الْحَسَنِ بْنِ عَلِيٍّ، قَالَ قَالَ رَسُولُ اللَّهِ ‏ "‏ تُحْفَةُ الصَّائِمِ الدُّهْنُ وَالْمِجْمَرُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لَيْسَ إِسْنَادُهُ بِذَاكَ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ سَعْدِ بْنِ طَرِيفٍ ‏.‏ وَسَعْدُ بْنُ طَرِيفٍ يُضَعَّفُ وَيُقَالُ عُمَيْرُ بْنُ مَأْمُومٍ أَيْضًا ‏.‏\hadithno{801}\hadithgrade{Ahmad Muhammad Shakir: Mawdu; Al-Albani: Mawdu; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Al-Hasan bin Ali narrated that:The Messenger of Allah said: "The gift for the fasting person is (fragrant) oil and a censer}}
\hadithdefcmd{tirmidhi}{802}{حَدَّثَنَا يَحْيَى بْنُ مُوسَى، حَدَّثَنَا يَحْيَى بْنُ الْيَمَانِ، عَنْ مَعْمَرٍ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْفِطْرُ يَوْمَ يُفْطِرُ النَّاسُ وَالأَضْحَى يَوْمَ يُضَحِّي النَّاسُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى سَأَلْتُ مُحَمَّدًا قُلْتُ لَهُ مُحَمَّدُ بْنُ الْمُنْكَدِرِ سَمِعَ مِنْ عَائِشَةَ قَالَ نَعَمْ يَقُولُ فِي حَدِيثِهِ سَمِعْتُ عَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ مِنْ هَذَا الْوَجْهِ ‏.‏\hadithno{802}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated that:The Messenger of Allah said: "Al-Fitr is the day that the people break the fast, and Al-Adha is the day that the people sacrifice}}
\hadithdefcmd{tirmidhi}{803}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، قَالَ أَنْبَأَنَا حُمَيْدٌ الطَّوِيلُ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَعْتَكِفُ فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ فَلَمْ يَعْتَكِفْ عَامًا فَلَمَّا كَانَ فِي الْعَامِ الْمُقْبِلِ اعْتَكَفَ عِشْرِينَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ مِنْ حَدِيثِ أَنَسِ بْنِ مَالِكٍ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي الْمُعْتَكِفِ إِذَا قَطَعَ اعْتِكَافَهُ قَبْلَ أَنْ يُتِمَّهُ عَلَى مَا نَوَى فَقَالَ بَعْضُ أَهْلِ الْعِلْمِ إِذَا نَقَضَ اعْتِكَافَهُ وَجَبَ عَلَيْهِ الْقَضَاءُ ‏.‏ وَاحْتَجُّوا بِالْحَدِيثِ أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ مِنِ اعْتِكَافِهِ فَاعْتَكَفَ عَشْرًا مِنْ شَوَّالٍ ‏.‏ وَهُوَ قَوْلُ مَالِكٍ ‏.‏ وَقَالَ بَعْضُهُمْ إِنْ لَمْ يَكُنْ عَلَيْهِ نَذْرُ اعْتِكَافٍ أَوْ شَيْءٌ أَوْجَبَهُ عَلَى نَفْسِهِ وَكَانَ مُتَطَوِّعًا فَخَرَجَ فَلَيْسَ عَلَيْهِ أَنْ يَقْضِيَ إِلاَّ أَنْ يُحِبَّ ذَلِكَ اخْتِيَارًا مِنْهُ وَلاَ يَجِبُ ذَلِكَ عَلَيْهِ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ ‏.‏ قَالَ الشَّافِعِيُّ فَكُلُّ عَمَلٍ لَكَ أَنْ لاَ تَدْخُلَ فِيهِ فَإِذَا دَخَلْتَ فِيهِ فَخَرَجْتَ مِنْهُ فَلَيْسَ عَلَيْكَ أَنْ تَقْضِيَ إِلاَّ الْحَجَّ وَالْعُمْرَةَ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{803}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Anas bin Malik narrated:"The Prophet would perform I'tikaf during the last ten (nights) of Ramadan. One year he did not perform I'tikaf, so he performed I'tikaf for twenty (nights) in the following year}}
\hadithdefcmd{tirmidhi}{804}{حَدَّثَنَا أَبُو مُصْعَبٍ الْمَدَنِيُّ، قِرَاءَةً عَنْ مَالِكِ بْنِ أَنَسٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، وَعَمْرَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اعْتَكَفَ أَدْنَى إِلَىَّ رَأْسَهُ فَأُرَجِّلُهُ وَكَانَ لاَ يَدْخُلُ الْبَيْتَ إِلاَّ لِحَاجَةِ الإِنْسَانِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ هَكَذَا رَوَاهُ غَيْرُ وَاحِدٍ عَنْ مَالِكٍ عَنِ ابْنِ شِهَابٍ عَنْ عُرْوَةَ وَعَمْرَةَ عَنْ عَائِشَةَ ‏.‏ وَرَوَاهُ بَعْضُهُمْ عَنْ مَالِكٍ عَنِ ابْنِ شِهَابٍ عَنْ عُرْوَةَ عَنْ عَمْرَةَ عَنْ عَائِشَةَ ‏.‏ وَالصَّحِيحُ عَنْ عُرْوَةَ وَعَمْرَةَ عَنْ عَائِشَةَ ‏.‏\hadithno{804}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Aishah narrated:"When the Messenger of Allah performed I'tikaf, he would bring his head near me so I could comb it, and he would not enter the house except for some personal needs}}
\hadithdefcmd{tirmidhi}{805}{حَدَّثَنَا بِذَلِكَ، قُتَيْبَةُ حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، وَعَمْرَةَ، عَنْ عَائِشَةَ، ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ إِذَا اعْتَكَفَ الرَّجُلُ أَنْ لاَ يَخْرُجَ مِنِ اعْتِكَافِهِ إِلاَّ لِحَاجَةِ الإِنْسَانِ وَاجْتَمَعُوا عَلَى هَذَا أَنَّهُ يَخْرُجُ لِقَضَاءِ حَاجَتِهِ لِلْغَائِطِ وَالْبَوْلِ ‏.‏ ثُمَّ اخْتَلَفَ أَهْلُ الْعِلْمِ فِي عِيَادَةِ الْمَرِيضِ وَشُهُودِ الْجُمُعَةِ وَالْجَنَازَةِ لِلْمُعْتَكِفِ فَرَأَى بَعْضُ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنْ يَعُودَ الْمَرِيضَ وَيُشَيِّعَ الْجَنَازَةَ وَيَشْهَدَ الْجُمُعَةَ إِذَا اشْتَرَطَ ذَلِكَ ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ ‏.‏ وَقَالَ بَعْضُهُمْ لَيْسَ لَهُ أَنْ يَفْعَلَ شَيْئًا مِنْ هَذَا وَرَأَوْا لِلْمُعْتَكِفِ إِذَا كَانَ فِي مِصْرٍ يُجَمَّعُ فِيهِ أَنْ لاَ يَعْتَكِفَ إِلاَّ فِي مَسْجِدِ الْجَامِعِ لأَنَّهُمْ كَرِهُوا الْخُرُوجَ لَهُ مِنْ مُعْتَكَفِهِ إِلَى الْجُمُعَةِ وَلَمْ يَرَوْا لَهُ أَنْ يَتْرُكَ الْجُمُعَةَ فَقَالُوا لاَ يَعْتَكِفُ إِلاَّ فِي مَسْجِدِ الْجَامِعِ حَتَّى لاَ يَحْتَاجُ إِلَى أَنْ يَخْرُجَ مِنْ مُعْتَكَفِهِ لِغَيْرِ قَضَاءِ حَاجَةِ الإِنْسَانِ لأَنَّ خُرُوجَهُ لِغَيْرِ قَضَاءِ حَاجَةِ الإِنْسَانِ قَطْعٌ عِنْدَهُمْ لِلاِعْتِكَافِ ‏.‏ وَهُوَ قَوْلُ مَالِكٍ وَالشَّافِعِيِّ ‏.‏ وَقَالَ أَحْمَدُ لاَ يَعُودُ الْمَرِيضَ وَلاَ يَتْبَعُ الْجَنَازَةَ عَلَى حَدِيثِ عَائِشَةَ ‏.‏ وَقَالَ إِسْحَاقُ إِنِ اشْتَرَطَ ذَلِكَ فَلَهُ أَنْ يَتْبَعَ الْجَنَازَةَ وَيَعُودَ الْمَرِيضَ ‏.‏\hadithno{805}\hadithgrade{Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{That was narrated to us by Quraibah :From Al-Laith (a similar narration as no)}}
\hadithdefcmd{tirmidhi}{806}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا مُحَمَّدُ بْنُ الْفُضَيْلِ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنِ الْوَلِيدِ بْنِ عَبْدِ الرَّحْمَنِ الْجُرَشِيِّ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِي ذَرٍّ، قَالَ صُمْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمْ يُصَلِّ بِنَا حَتَّى بَقِيَ سَبْعٌ مِنَ الشَّهْرِ فَقَامَ بِنَا حَتَّى ذَهَبَ ثُلُثُ اللَّيْلِ ثُمَّ لَمْ يَقُمْ بِنَا فِي السَّادِسَةِ وَقَامَ بِنَا فِي الْخَامِسَةِ حَتَّى ذَهَبَ شَطْرُ اللَّيْلِ فَقُلْنَا لَهُ يَا رَسُولَ اللَّهِ لَوْ نَفَّلْتَنَا بَقِيَّةَ لَيْلَتِنَا هَذِهِ فَقَالَ ‏ "‏ إِنَّهُ مَنْ قَامَ مَعَ الإِمَامِ حَتَّى يَنْصَرِفَ كُتِبَ لَهُ قِيَامُ لَيْلَةٍ ‏"‏ ‏.‏ ثُمَّ لَمْ يُصَلِّ بِنَا حَتَّى بَقِيَ ثَلاَثٌ مِنَ الشَّهْرِ وَصَلَّى بِنَا فِي الثَّالِثَةِ وَدَعَا أَهْلَهُ وَنِسَاءَهُ فَقَامَ بِنَا حَتَّى تَخَوَّفْنَا الْفَلاَحَ ‏.‏ قُلْتُ لَهُ وَمَا الْفَلاَحُ قَالَ السُّحُورُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَاخْتَلَفَ أَهْلُ الْعِلْمِ فِي قِيَامِ رَمَضَانَ فَرَأَى بَعْضُهُمْ أَنْ يُصَلِّيَ إِحْدَى وَأَرْبَعِينَ رَكْعَةً مَعَ الْوِتْرِ ‏.‏ وَهُوَ قَوْلُ أَهْلِ الْمَدِينَةِ وَالْعَمَلُ عَلَى هَذَا عِنْدَهُمْ بِالْمَدِينَةِ ‏.‏ وَأَكْثَرُ أَهْلِ الْعِلْمِ عَلَى مَا رُوِيَ عَنْ عُمَرَ وَعَلِيٍّ وَغَيْرِهِمَا مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم عِشْرِينَ رَكْعَةً ‏.‏ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ ‏.‏ وَقَالَ الشَّافِعِيُّ وَهَكَذَا أَدْرَكْتُ بِبَلَدِنَا بِمَكَّةَ يُصَلُّونَ عِشْرِينَ رَكْعَةً ‏.‏ وَقَالَ أَحْمَدُ رُوِيَ فِي هَذَا أَلْوَانٌ ‏.‏ وَلَمْ يَقْضِ فِيهِ بِشَيْءٍ ‏.‏ وَقَالَ إِسْحَاقُ بَلْ نَخْتَارُ إِحْدَى وَأَرْبَعِينَ رَكْعَةً عَلَى مَا رُوِيَ عَنْ أُبَىِّ بْنِ كَعْبٍ ‏.‏ وَاخْتَارَ ابْنُ الْمُبَارَكِ وَأَحْمَدُ وَإِسْحَاقُ الصَّلاَةَ مَعَ الإِمَامِ فِي شَهْرِ رَمَضَانَ ‏.‏ وَاخْتَارَ الشَّافِعِيُّ أَنْ يُصَلِّيَ الرَّجُلُ وَحْدَهُ إِذَا كَانَ قَارِئًا ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ وَالنُّعْمَانِ بْنِ بَشِيرٍ وَابْنِ عَبَّاسٍ ‏.‏\hadithno{806}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Dharr narrated:"We fasted with the Prophet, so he did not pray (the night prayer) with us until seven (nights) of the month remained. Then he (pbuh) led us in prayer until a third of the night had gone, then he did not lead us in prayer on the sixth. Then he led us in prayer on the fifth until half of the night had gone. We said to him: 'O Messenger of Allah! Wouldn't you lead us in prayer for the remainder of the night?' He said: 'Indeed, whoever stands (praying) with the Imam until he finished, then it is recorded for him that he prayed the whole night.; Then he did not lead us in prayer until three (nights) of the month remained. Then he led us in prayer on the third and he called his family and his women to pray with us until we feared missing the Falah" I (Jubair bin Nufair) said to him: "What is the Falah" He said: "The Suhur}}
\hadithdefcmd{tirmidhi}{807}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ فَطَّرَ صَائِمًا كَانَ لَهُ مِثْلُ أَجْرِهِ غَيْرَ أَنَّهُ لاَ يَنْقُصُ مِنْ أَجْرِ الصَّائِمِ شَيْئًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{807}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Zaid bin Khalid Al-Juhani narrated that:The Messenger of Allah said: "Whoever provides the food for a fasting person to break his fast with, then for him is the same reward as his (the fasting person's), without anything being diminished from the reward of the fasting person}}
\hadithdefcmd{tirmidhi}{808}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُرَغِّبُ فِي قِيَامِ رَمَضَانَ مِنْ غَيْرِ أَنْ يَأْمُرَهُمْ بِعَزِيمَةٍ وَيَقُولُ ‏ "‏ مَنْ قَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏ فَتُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالأَمْرُ عَلَى ذَلِكَ ثُمَّ كَانَ الأَمْرُ كَذَلِكَ فِي خِلاَفَةِ أَبِي بَكْرٍ وَصَدْرًا مِنْ خِلاَفَةِ عُمَرَ بْنِ الْخَطَّابِ عَلَى ذَلِكَ ‏.‏ وَفِي الْبَابِ عَنْ عَائِشَةَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ أَيْضًا عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ ‏عن النبي قال أبو عيسى هذا حديث حسن صحيح.‏\hadithno{808}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Abu Hurairah narrated:"The Messenger of Allah would encourage the night prayer in Ramadan without firmly ordering it, and he would say: "Whoever stands (in the night prayer) for Ramadan with faith and seeking the reward (from Allah), then he will be forgiven what has preceded of his sins.' So the Messenger of Allah died and the matter was like that. Then the matter was the same during the Khilafah of Abu Bakr and it continued during a portion of the Khilafah of Umar bin Al-Khattab}}
