% Auto-generated chapter 6 for muslim
% Hadiths in this chapter: 377

\hadithdefcmd{muslim}{1570}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ فُرِضَتِ الصَّلاَةُ رَكْعَتَيْنِ رَكْعَتَيْنِ فِي الْحَضَرِ وَالسَّفَرِ فَأُقِرَّتْ صَلاَةُ السَّفَرِ وَزِيدَ فِي صَلاَةِ الْحَضَرِ ‏.‏\hadithno{1570}\hadithtrans{A'isha, the wife of the Messenger of Allah (ﷺ), reported:The prayer was prescribed as two rak'ahs, two rak'ahs both in journey and at the place of residence. The prayer while travelling remained as it was (originally prescribed), but an addition was made in the prayer (observed) at the place of residence}}
\hadithdefcmd{muslim}{1571}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ فَرَضَ اللَّهُ الصَّلاَةَ حِينَ فَرَضَهَا رَكْعَتَيْنِ ثُمَّ أَتَمَّهَا فِي الْحَضَرِ فَأُقِرَّتْ صَلاَةُ السَّفَرِ عَلَى الْفَرِيضَةِ الأُولَى ‏.‏\hadithno{1571}\hadithtrans{A'isha, the wife of the Messenger of Allah (ﷺ), said Allah prescribed the prayer as two rak'ahs, then it was completed (to four rak'ahs) at the place of residence, but was retained in the same position in journey as it was first made obligatory}}
\hadithdefcmd{muslim}{1572}{وَحَدَّثَنِي عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ الصَّلاَةَ، أَوَّلَ مَا فُرِضَتْ رَكْعَتَيْنِ فَأُقِرَّتْ صَلاَةُ السَّفَرِ وَأُتِمَّتْ صَلاَةُ الْحَضَرِ ‏.‏ قَالَ الزُّهْرِيُّ فَقُلْتُ لِعُرْوَةَ مَا بَالُ عَائِشَةَ تُتِمُّ فِي السَّفَرِ قَالَ إِنَّهَا تَأَوَّلَتْ كَمَا تَأَوَّلَ عُثْمَانُ ‏.‏\hadithno{1572}\hadithtrans{A'isha reported:The prayer was prescribed as consisting of two rak'ahs, the prayer in travelling remained the same, but the prayer at the place of residence was completed. (Zuhri said he asked 'Urwa why 'A'isha said prayer in the complete form during journey, and he replied that she interpreted the matter herself as 'Uthman did)}}
\hadithdefcmd{muslim}{1573}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ وَزُهَيْرُ بْنُ حَرْبٍ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنِ ابْنِ جُرَيْجٍ، عَنِ ابْنِ أَبِي عَمَّارٍ، عَنْ عَبْدِ اللَّهِ بْنِ بَابَيْهِ، عَنْ يَعْلَى بْنِ أُمَيَّةَ، قَالَ قُلْتُ لِعُمَرَ بْنِ الْخَطَّابِ ‏\{‏ لَيْسَ عَلَيْكُمْ جُنَاحٌ أَنْ تَقْصُرُوا، مِنَ الصَّلاَةِ إِنْ خِفْتُمْ أَنْ يَفْتِنَكُمُ الَّذِينَ كَفَرُوا‏\}‏ فَقَدْ أَمِنَ النَّاسُ فَقَالَ عَجِبْتُ مِمَّا عَجِبْتَ مِنْهُ فَسَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ ‏.‏ فَقَالَ ‏"‏ صَدَقَةٌ تَصَدَّقَ اللَّهُ بِهَا عَلَيْكُمْ فَاقْبَلُوا صَدَقَتَهُ ‏"‏ ‏.‏\hadithno{1573}\hadithtrans{Yahya b. Umayya said:I told 'Umar b. al-Khattab that Allah had said:" You may shorten the prayer only if you fear that those who are unbelievers may afflict you" (Qur'an, iv. 101), whereas the people are now safe. He replied: I wondered about it in the same way as you wonder about it, so I asked the Messenger of Allah (ﷺ) about it and he said: It is an act of charity which Allah has done to you, so accept His charity}}
\hadithdefcmd{muslim}{1574}{وَحَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا يَحْيَى، عَنِ ابْنِ جُرَيْجٍ، قَالَ حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي عَمَّارٍ، عَنْ عَبْدِ اللَّهِ بْنِ بَابَيْهِ، عَنْ يَعْلَى بْنِ أُمَيَّةَ، قَالَ قُلْتُ لِعُمَرَ بْنِ الْخَطَّابِ ‏.‏ بِمِثْلِ حَدِيثِ ابْنِ إِدْرِيسَ ‏.‏\hadithno{1574}\hadithtrans{Ya'la b. Umayya reported:I said to 'Umar b. al-Khattab, and the rest of the hadlth is the same}}
\hadithdefcmd{muslim}{1575}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَسَعِيدُ بْنُ مَنْصُورٍ، وَأَبُو الرَّبِيعِ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرُونَ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ بُكَيْرِ بْنِ الأَخْنَسِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ فَرَضَ اللَّهُ الصَّلاَةَ عَلَى لِسَانِ نَبِيِّكُمْ صلى الله عليه وسلم فِي الْحَضَرِ أَرْبَعًا وَفِي السَّفَرِ رَكْعَتَيْنِ وَفِي الْخَوْفِ رَكْعَةً ‏.‏\hadithno{1575}\hadithtrans{Ibn 'Abbas reported:Allah has prescribed the prayer through the word of your Prophet (ﷺ) as four rak'ahs when resident, two when travelling, and one when danger is present}}
\hadithdefcmd{muslim}{1576}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، جَمِيعًا عَنِ الْقَاسِمِ بْنِ مَالِكٍ، - قَالَ عَمْرٌو حَدَّثَنَا قَاسِمُ بْنُ مَالِكٍ الْمُزَنِيُّ، - حَدَّثَنَا أَيُّوبُ بْنُ عَائِذٍ الطَّائِيُّ، عَنْ بُكَيْرِ بْنِ الأَخْنَسِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّ اللَّهَ فَرَضَ الصَّلاَةَ عَلَى لِسَانِ نَبِيِّكُمْ صلى الله عليه وسلم عَلَى الْمُسَافِرِ رَكْعَتَيْنِ وَعَلَى الْمُقِيمِ أَرْبَعًا وَفِي الْخَوْفِ رَكْعَةً ‏.‏\hadithno{1576}\hadithtrans{Ibn 'Abbas reported:Allah has prescribed the prayer by the tongue of your Apostle (ﷺ) as two rak'ahs for the traveller, four for the resident, and one in danger}}
\hadithdefcmd{muslim}{1577}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ مُوسَى بْنِ سَلَمَةَ الْهُذَلِيِّ، قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ كَيْفَ أُصَلِّي إِذَا كُنْتُ بِمَكَّةَ إِذَا لَمْ أُصَلِّ مَعَ الإِمَامِ ‏.‏ فَقَالَ رَكْعَتَيْنِ سُنَّةَ أَبِي الْقَاسِمِ صلى الله عليه وسلم ‏.‏\hadithno{1577}\hadithtrans{Musa b. Salama Hudhali said:I asked Ibn 'Abbas: How should I say prayer when I am in Mecca, and when I do not pray along with the Imam? He said: Two rak'ahs (of prayer) is the Sunnah of Abu'l-Qasim (ﷺ)}}
\hadithdefcmd{muslim}{1578}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ مِنْهَالٍ الضَّرِيرُ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنَا أَبِي جَمِيعًا، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{1578}\hadithtrans{A hadith like this has been narrated by Abu Qatada with the same chain of transmitters}}
\hadithdefcmd{muslim}{1579}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، حَدَّثَنَا عِيسَى بْنُ حَفْصِ بْنِ عَاصِمِ بْنِ عُمَرَ بْنِ الْخَطَّابِ، عَنْ أَبِيهِ، قَالَ صَحِبْتُ ابْنَ عُمَرَ فِي طَرِيقِ مَكَّةَ - قَالَ - فَصَلَّى لَنَا الظُّهْرَ رَكْعَتَيْنِ ثُمَّ أَقْبَلَ وَأَقْبَلْنَا مَعَهُ حَتَّى جَاءَ رَحْلَهُ وَجَلَسَ وَجَلَسْنَا مَعَهُ فَحَانَتْ مِنْهُ الْتِفَاتَةٌ نَحْوَ حَيْثُ صَلَّى فَرَأَى نَاسًا قِيَامًا فَقَالَ مَا يَصْنَعُ هَؤُلاَءِ قُلْتُ يُسَبِّحُونَ ‏.‏ قَالَ لَوْ كُنْتُ مُسَبِّحًا لأَتْمَمْتُ صَلاَتِي يَا ابْنَ أَخِي إِنِّي صَحِبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي السَّفَرِ فَلَمْ يَزِدْ عَلَى رَكْعَتَيْنِ حَتَّى قَبَضَهُ اللَّهُ وَصَحِبْتُ أَبَا بَكْرٍ فَلَمْ يَزِدْ عَلَى رَكْعَتَيْنِ حَتَّى قَبَضَهُ اللَّهُ وَصَحِبْتُ عُمَرَ فَلَمْ يَزِدْ عَلَى رَكْعَتَيْنِ حَتَّى قَبَضَهُ اللَّهُ ثُمَّ صَحِبْتُ عُثْمَانَ فَلَمْ يَزِدْ عَلَى رَكْعَتَيْنِ حَتَّى قَبَضَهُ اللَّهُ وَقَدْ قَالَ اللَّهُ ‏\{‏ لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ أُسْوَةٌ حَسَنَةٌ‏\}‏ ‏.‏\hadithno{1579}\hadithtrans{Hafs b. 'Asim said:I accompanied Ibn 'Umar on the road to Mecca and he led us in two rak'ahs at the noon prayer, then he went forward and we too went along with him to a place where he alighted, and he sat and we sat along with him, and he cast a glance to the side where he said prayer and he saw people standing and asked: What are they doing? I said: They are engaged in glorifying Allah, offering Sunnah prayer. He said: If I had done so I would have perfected my prayer; O my nephew! I accompanied the Messenger of Allah (ﷺ) on a journey, and he made no addittion to two rak'ahs, till Allah called him. I accompanied Abu Bakr and he made no addition to two rak'ahs till Allah caused him to die. I accompanied 'Umar and he made no addition to two rak'ahs till Allah caused him to die. I accompanied 'Uthman and he made no addition to two rak'ahs, till Allah caused him to die, and Allah has said:" There is a model pattern for you in the Messenger of Allah" (al-Qur'an, xxxiii)}}
\hadithdefcmd{muslim}{1580}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَزِيدُ، - يَعْنِي ابْنَ زُرَيْعٍ - عَنْ عُمَرَ بْنِ مُحَمَّدٍ، عَنْ حَفْصِ بْنِ عَاصِمٍ، قَالَ مَرِضْتُ مَرَضًا فَجَاءَ ابْنُ عُمَرَ يَعُودُنِي قَالَ وَسَأَلْتُهُ عَنِ السُّبْحَةِ، فِي السَّفَرِ فَقَالَ صَحِبْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي السَّفَرِ فَمَا رَأَيْتُهُ يُسَبِّحُ وَلَوْ كُنْتُ مُسَبِّحًا لأَتْمَمْتُ وَقَدْ قَالَ اللَّهُ تَعَالَى ‏\{‏ لَقَدْ كَانَ لَكُمْ فِي رَسُولِ اللَّهِ إِسْوَةٌ حَسَنَةٌ‏\}‏\hadithno{1580}\hadithtrans{Hafs b. 'Asim reported:I fell ill and lbn 'Umar came to inquire after my health, and I asked him about the glorification of Allah (i. e. prayer) while travelling. Thereupon he said: I accompanied the Messenger of Allah (ﷺ) on a journey but I did not see him glorifying Him, and were I to glorify (Him). I would have completed the prayer. Allah, the Exalted, has said:" Verily there is a model pattern for you in the Messenger of Allah}}
\hadithdefcmd{muslim}{1581}{حَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، وَأَبُو الرَّبِيعِ الزَّهْرَانِيُّ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالُوا حَدَّثَنَا حَمَّادٌ، وَهُوَ ابْنُ زَيْدٍ ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، كِلاَهُمَا عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الظُّهْرَ بِالْمَدِينَةِ أَرْبَعًا وَصَلَّى الْعَصْرَ بِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ ‏.‏\hadithno{1581}\hadithtrans{Anas reported:The Messenger of Allah (ﷺ) said four rak'ahs in the noon prayer while at Medina, but he offered two rak'ahs in the afternoon prayer at Dhu'l-Hulaifa}}
\hadithdefcmd{muslim}{1582}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُنْكَدِرِ، وَإِبْرَاهِيمُ بْنُ مَيْسَرَةَ، سَمِعَا أَنَسَ بْنَ مَالِكٍ، يَقُولُ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم الظُّهْرَ بِالْمَدِينَةِ أَرْبَعًا وَصَلَّيْتُ مَعَهُ الْعَصْرَ بِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ ‏.‏\hadithno{1582}\hadithtrans{Anas b. Malik is reported to have said:I observed four rak'ahs in the noon prayer with the Messenger of Allah (ﷺ) at Medina, and said two rak'ahs in the afternoon prayer at Dhu'l-Hulaifa}}
\hadithdefcmd{muslim}{1583}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ بَشَّارٍ، كِلاَهُمَا عَنْ غُنْدَرٍ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، غُنْدَرٌ - عَنْ شُعْبَةَ، عَنْ يَحْيَى بْنِ يَزِيدَ الْهُنَائِيِّ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ عَنْ قَصْرِ الصَّلاَةِ، فَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا خَرَجَ مَسِيرَةَ ثَلاَثَةِ أَمْيَالٍ أَوْ ثَلاَثَةِ فَرَاسِخَ - شُعْبَةُ الشَّاكُّ - صَلَّى رَكْعَتَيْنِ ‏.‏\hadithno{1583}\hadithtrans{Yahya b. Yazid al-Huna'i reported:I asked Anas b. Malik about shortening of prayer. He said: When the Messenger of' Allah (ﷺ) had covered a distance of three miles or three farsakh (Shu'ba, one of the narrators, had some doubt about it) he observed two rak'ahs}}
\hadithdefcmd{muslim}{1584}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ بَشَّارٍ، جَمِيعًا عَنِ ابْنِ مَهْدِيٍّ، - قَالَ زُهَيْرٌ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، - حَدَّثَنَا شُعْبَةُ، عَنْ يَزِيدَ بْنِ خُمَيْرٍ، عَنْ حَبِيبِ بْنِ عُبَيْدٍ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، قَالَ خَرَجْتُ مَعَ شُرَحْبِيلَ بْنِ السِّمْطِ إِلَى قَرْيَةٍ عَلَى رَأْسِ سَبْعَةَ عَشَرَ أَوْ ثَمَانِيَةَ عَشَرَ مِيلاً فَصَلَّى رَكْعَتَيْنِ ‏.‏ فَقُلْتُ لَهُ فَقَالَ رَأَيْتُ عُمَرَ صَلَّى بِذِي الْحُلَيْفَةِ رَكْعَتَيْنِ فَقُلْتُ لَهُ فَقَالَ إِنَّمَا أَفْعَلُ كَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُ ‏.‏\hadithno{1584}\hadithtrans{Jubair b. Nufair reported:I went along with Shurahbil b. al-Simt to a village which was situated at a distance of seventeen or eighteen miles, and he said only two rak'ahs of prayer. I said to him (about it) and he said: I saw 'Umar observing two rak'ahs at Dhu'l-Hulaifa and I (too) said to him (about it) and he said: I am doing the same as I saw the Messenger of Allah (ﷺ) doing}}
\hadithdefcmd{muslim}{1585}{وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ ‏.‏ وَقَالَ عَنِ ابْنِ السِّمْطِ، وَلَمْ يُسَمِّ شُرَحْبِيلَ وَقَالَ إِنَّهُ أَتَى أَرْضًا يُقَالُ لَهَا دَوْمِينُ مِنْ حِمْصَ عَلَى رَأْسِ ثَمَانِيَةَ عَشَرَ مِيلاً ‏.‏\hadithno{1585}\hadithtrans{This hadith has been transmitted by Shu'ba with the same chain of narrators and it is narrated from Simt, and the name of Shurahbil has not been mentioned, and he said that he had gone to a place called Dumin, situated at a distance of eighteen miles from Hims}}
\hadithdefcmd{muslim}{1586}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، أَخْبَرَنَا هُشَيْمٌ، عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ الْمَدِينَةِ إِلَى مَكَّةَ فَصَلَّى رَكْعَتَيْنِ رَكْعَتَيْنِ حَتَّى رَجَعَ ‏.‏ قُلْتُ كَمْ أَقَامَ بِمَكَّةَ قَالَ عَشْرًا ‏.‏\hadithno{1586}\hadithtrans{Anas b. Malik reported:We went out from Medina to Mecca with the Messenger of Allah (ﷺ) and he prayed two rak'ahs at each time of prayer till we returned to Medina. I said: For how long did he stay in Mecca? He said: (For) ten (days)}}
\hadithdefcmd{muslim}{1587}{وَحَدَّثَنَاهُ قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، ح وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ عُلَيَّةَ، جَمِيعًا عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِ حَدِيثِ هُشَيْمٍ ‏.‏\hadithno{1587}\hadithtrans{A hadith like this has been narrated by Anas by another chain of transmitters}}
\hadithdefcmd{muslim}{1588}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنِي يَحْيَى بْنُ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ خَرَجْنَا مِنَ الْمَدِينَةِ إِلَى الْحَجِّ ‏.‏ ثُمَّ ذَكَرَ مِثْلَهُ ‏.‏\hadithno{1588}\hadithtrans{Yahya b. Abu Ishaq reported:I heard Anas b. Malik say: We went out for Pilgrimage from Medina. The rest is the same}}
\hadithdefcmd{muslim}{1589}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، جَمِيعًا عَنِ الثَّوْرِيِّ، عَنْ يَحْيَى بْنِ أَبِي إِسْحَاقَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ وَلَمْ يَذْكُرِ الْحَجَّ ‏.‏\hadithno{1589}\hadithtrans{A hadith like this has been transmitted by Anas, but no mention has been made of Pilgrimage}}
\hadithdefcmd{muslim}{1590}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، وَهُوَ ابْنُ الْحَارِثِ عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ صَلَّى صَلاَةَ الْمُسَافِرِ بِمِنًى وَغَيْرِهِ رَكْعَتَيْنِ وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ رَكْعَتَيْنِ صَدْرًا مِنْ خِلاَفَتِهِ ثُمَّ أَتَمَّهَا أَرْبَعًا ‏.‏\hadithno{1590}\hadithtrans{Salim b. 'Abdullah (b. 'Umar) reported on the authority of his father that Allah's Messenger (ﷺ) observed the prayer of a traveller, i. e. two rak'ahs in Mina, and other places; so did Abu Bakr and 'Umar, and 'Uthman too observed two rak'ahs at the beginning of his caliphate, but he then completed four}}
\hadithdefcmd{muslim}{1591}{وَحَدَّثَنَاهُ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، ح وَحَدَّثَنَاهُ إِسْحَاقُ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، جَمِيعًا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ قَالَ بِمِنًى ‏.‏ وَلَمْ يَقُلْ وَغَيْرِهِ ‏.‏\hadithno{1591}\hadithtrans{A hadith like this has been reported by Zuhri, with the same chain of transmitters, and in it mention was made of Mina only, but not of other places}}
\hadithdefcmd{muslim}{1592}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِمِنًى رَكْعَتَيْنِ وَأَبُو بَكْرٍ بَعْدَهُ وَعُمَرُ بَعْدَ أَبِي بَكْرٍ وَعُثْمَانُ صَدْرًا مِنْ خِلاَفَتِهِ ثُمَّ إِنَّ عُثْمَانَ صَلَّى بَعْدُ أَرْبَعًا ‏.‏ فَكَانَ ابْنُ عُمَرَ إِذَا صَلَّى مَعَ الإِمَامِ صَلَّى أَرْبَعًا وَإِذَا صَلاَّهَا وَحْدَهُ صَلَّى رَكْعَتَيْنِ ‏.‏\hadithno{1592}\hadithtrans{Ibn 'Umar reported:The Messenger of Allah (ﷺ) said two rak'ahs at Mina, and Abu Bakr after him, and 'Umar after Abu Bakr, and 'Uthman at the beginning of his caliphate; then 'Uthman observed four rak'ahs, and when Ibn 'Umar prayed with the Imam, he said four rak'ahs, but when he observed prayer alone, he said two rak'ahs}}
\hadithdefcmd{muslim}{1593}{وَحَدَّثَنَاهُ ابْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَحْيَى، وَهُوَ الْقَطَّانُ ح وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، ح وَحَدَّثَنَاهُ ابْنُ نُمَيْرٍ، حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{1593}\hadithtrans{A hadith like this has been narrated by the same chain of transmitters}}
\hadithdefcmd{muslim}{1594}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، سَمِعَ حَفْصَ بْنَ عَاصِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم بِمِنًى صَلاَةَ الْمُسَافِرِ وَأَبُو بَكْرٍ وَعُمَرُ وَعُثْمَانُ ثَمَانِيَ سِنِينَ أَوْ قَالَ سِتَّ سِنِينَ ‏.‏ قَالَ حَفْصٌ وَكَانَ ابْنُ عُمَرَ يُصَلِّي بِمِنًى رَكْعَتَيْنِ ثُمَّ يَأْتِي فِرَاشَهُ ‏.‏ فَقُلْتُ أَىْ عَمِّ لَوْ صَلَّيْتَ بَعْدَهَا رَكْعَتَيْنِ ‏.‏ قَالَ لَوْ فَعَلْتُ لأَتْمَمْتُ الصَّلاَةَ ‏.‏\hadithno{1594}\hadithtrans{Ibn 'Umar reported:The Apostle of Allah (ﷺ) said in Mina the prayer of a traveller (short prayer) ; Abu Bakr and 'Umar did the same and 'Uthmia did it for eight years or six years. Hafs (one of the narrators) said: Ibn 'Umar would also say two rak'ahs at Mina and then go to bed. I said to him: O uncle, I wish you could have said two rak'ahs (of Sunnah prayer after shorenting the Fard prayer). He said: Were I to do that, I would have completed the prayer}}
\hadithdefcmd{muslim}{1595}{وَحَدَّثَنَاهُ يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ يَعْنِي ابْنَ الْحَارِثِ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، قَالَ حَدَّثَنِي عَبْدُ الصَّمَدِ، قَالاَ حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ وَلَمْ يَقُولاَ فِي الْحَدِيثِ بِمِنًى ‏.‏ وَلَكِنْ قَالاَ صَلَّى فِي السَّفَرِ ‏.‏\hadithno{1595}\hadithtrans{This hadith has been narrated by Shu'ba with the same chain of transmitters but no mention has been made of Mina, but they (the narrators) only said:He prayed while travelling}}
\hadithdefcmd{muslim}{1596}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، عَنِ الأَعْمَشِ، حَدَّثَنَا إِبْرَاهِيمُ، قَالَ سَمِعْتُ عَبْدَ الرَّحْمَنِ بْنَ يَزِيدَ، يَقُولُ صَلَّى بِنَا عُثْمَانُ بِمِنًى أَرْبَعَ رَكَعَاتٍ فَقِيلَ ذَلِكَ لِعَبْدِ اللَّهِ بْنِ مَسْعُودٍ فَاسْتَرْجَعَ ثُمَّ قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِنًى رَكْعَتَيْنِ وَصَلَّيْتُ مَعَ أَبِي بَكْرٍ الصِّدِّيقِ بِمِنًى رَكْعَتَيْنِ وَصَلَّيْتُ مَعَ عُمَرَ بْنِ الْخَطَّابِ بِمِنًى رَكْعَتَيْنِ فَلَيْتَ حَظِّي مِنْ أَرْبَعِ رَكَعَاتٍ رَكْعَتَانِ مُتَقَبَّلَتَانِ ‏.‏\hadithno{1596}\hadithtrans{Ibrahim reported:I heard 'Abd al-Rahman as saying; 'Uthman led us four rak'ahs of prayer at Mina. It was reported to Abdullah b. Mas'ud and he recited:" Surely we are Allah's and to Him shall we return," and then said: I prayed with the Messenger of Allah (ﷺ) at Mina two rak'ahs of prayer. I prayed along with Abu Bakr al-Siddiq two rak'ahs of prayer at Mina. I prayed along with 'Umar b. Khattab two rak'ahs of prayer at Mina. I wish I had my share of the two rak'ahs acceptable (to God) for the four rak'ahs}}
\hadithdefcmd{muslim}{1597}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، قَالَ حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا إِسْحَاقُ، وَابْنُ، خَشْرَمٍ قَالاَ أَخْبَرَنَا عِيسَى، كُلُّهُمْ عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏\hadithno{1597}\hadithtrans{A hadith like this has been reported by A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{1598}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ، قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ، قُتَيْبَةُ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ حَارِثَةَ بْنِ وَهْبٍ، قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِنًى - آمَنَ مَا كَانَ النَّاسُ وَأَكْثَرَهُ - رَكْعَتَيْنِ ‏.‏\hadithno{1598}\hadithtrans{Haritha b. Wahb reported:I prayed with the Messenger of Allah (ﷺ) two rak'ahs and most of them offered two rak'ahs only in Mina, while the people felt secure}}
\hadithdefcmd{muslim}{1599}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، حَدَّثَنِي حَارِثَةُ بْنُ وَهْبٍ الْخُزَاعِيُّ، قَالَ صَلَّيْتُ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِمِنًى وَالنَّاسُ أَكْثَرُ مَا كَانُوا فَصَلَّى رَكْعَتَيْنِ فِي حَجَّةِ الْوَدَاعِ ‏.‏ قَالَ مُسْلِمٌ حَارِثَةُ بْنُ وَهْبٍ الْخُزَاعِيُّ هُوَ أَخُو عُبَيْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ لأُمِّهِ ‏.‏\hadithno{1599}\hadithtrans{Wahb al-Khuza'i reported:I prayed behind the Messenger of Allah (ﷺ) at Mina, and there was the greatest number of people, and they prayed two rak'ahs on the occasion of the Farewell Pilgrimage. (Muslim said: Haritha b. Wahb al-Khuza'i is the brother of 'Ubaidullah b. 'Umar son of Khattab from the side of his mother)}}
\hadithdefcmd{muslim}{1600}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، أَذَّنَ بِالصَّلاَةِ فِي لَيْلَةٍ ذَاتِ بَرْدٍ وَرِيحٍ فَقَالَ أَلاَ صَلُّوا فِي الرِّحَالِ ‏.‏ ثُمَّ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُ الْمُؤَذِّنَ إِذَا كَانَتْ لَيْلَةٌ بَارِدَةٌ ذَاتُ مَطَرٍ يَقُولُ ‏ "‏ أَلاَ صَلُّوا فِي الرِّحَالِ ‏"‏ ‏.‏\hadithno{1600}\hadithtrans{Ibn 'Umar announced Adhan for prayer on a cold, windy night. Then added:Pray in your dwellings; and then said: When it was a cold, rainy night, the Messenger of Allah (ﷺ) used to command the Mu'adhdhin to say" Pray in your dwellings}}
\hadithdefcmd{muslim}{1601}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، أَنَّهُ نَادَى بِالصَّلاَةِ فِي لَيْلَةٍ ذَاتِ بَرْدٍ وَرِيحٍ وَمَطَرٍ فَقَالَ فِي آخِرِ نِدَائِهِ أَلاَ صَلُّوا فِي رِحَالِكُمْ أَلاَ صَلُّوا فِي الرِّحَالِ ‏.‏ ثُمَّ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْمُرُ الْمُؤَذِّنَ إِذَا كَانَتْ لَيْلَةٌ بَارِدَةٌ أَوْ ذَاتُ مَطَرٍ فِي السَّفَرِ أَنْ يَقُولَ أَلاَ صَلُّوا فِي رِحَالِكُمْ ‏.‏\hadithno{1601}\hadithtrans{Ibn 'Umar reported that he summoned (people) to pray on a cold, windy and rainy night, and then observed at the end of the Adhin:Pray in your dwellings, pray in your dwellings, and then said: When it was a cold night or it was raining in a journey the Messenger of Allah (may peace he upon him) used to command the Mu'adhdhin to announce: Pray in your dwellings}}
\hadithdefcmd{muslim}{1602}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ نَادَى بِالصَّلاَةِ بِضَجْنَانَ ثُمَّ ذَكَرَ بِمِثْلِهِ وَقَالَ أَلاَ صَلُّوا فِي رِحَالِكُمْ ‏.‏ وَلَمْ يُعِدْ ثَانِيَةً أَلاَ صَلُّوا فِي الرِّحَالِ ‏.‏ مِنْ قَوْلِ ابْنِ عُمَرَ ‏.‏\hadithno{1602}\hadithtrans{Ibn 'Umar reported that he summoned (people) to prayer at a place (known as) Dajnan, and the rest of the hadith is the same, and then said:Pray in your dwellings, but he did not repeat for the second time words of Ibn 'Umar (Pray in your dwellings)}}
\hadithdefcmd{muslim}{1603}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، قَالَ حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَمُطِرْنَا فَقَالَ ‏ "‏ لِيُصَلِّ مَنْ شَاءَ مِنْكُمْ فِي رَحْلِهِ ‏"‏ ‏.‏\hadithno{1603}\hadithtrans{Jabir reported:We set cut with the Messenger of Allah (ﷺ) on a journey when it began to rain. Upon this he said: He who desires may pray in his dwelling}}
\hadithdefcmd{muslim}{1604}{وَحَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ عَبْدِ الْحَمِيدِ، صَاحِبِ الزِّيَادِيِّ عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ قَالَ لِمُؤَذِّنِهِ فِي يَوْمٍ مَطِيرٍ إِذَا قُلْتَ أَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ أَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ فَلاَ تَقُلْ حَىَّ عَلَى الصَّلاَةِ قُلْ صَلُّوا فِي بُيُوتِكُمْ - قَالَ - فَكَأَنَّ النَّاسَ اسْتَنْكَرُوا ذَاكَ فَقَالَ أَتَعْجَبُونَ مِنْ ذَا قَدْ فَعَلَ ذَا مَنْ هُوَ خَيْرٌ مِنِّي إِنَّ الْجُمُعَةَ عَزْمَةٌ وَإِنِّي كَرِهْتُ أَنْ أُحْرِجَكُمْ فَتَمْشُوا فِي الطِّينِ وَالدَّحْضِ ‏.‏\hadithno{1604}\hadithtrans{Abdullah b. 'Abbas reported that he said to the Mu'adhdhin on a rainy day:When you have announced" I testify that there is no god but Allah; I testify that Muhammad is the Messenger of Allah," do not say:" Come to the prayer," but make this announcement:" Say prayer in your houses." He (the narrator) said that the people disapproved of it. Ibn 'Abbas said: Are you astonished at it? He (the Holy Prophet), who is better than I, did it. Jumu'a prayer is no doubt obligatory, but I do not like that I should (force you) to come out and walk in mud and slippery ground}}
\hadithdefcmd{muslim}{1605}{وَحَدَّثَنِيهِ أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - عَنْ عَبْدِ الْحَمِيدِ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ الْحَارِثِ، قَالَ خَطَبَنَا عَبْدُ اللَّهِ بْنُ عَبَّاسٍ فِي يَوْمٍ ذِي رَدْغٍ ‏.‏ وَسَاقَ الْحَدِيثَ بِمَعْنَى حَدِيثِ ابْنِ عُلَيَّةَ وَلَمْ يَذْكُرِ الْجُمُعَةَ وَقَالَ قَدْ فَعَلَهُ مَنْ هُوَ خَيْرٌ مِنِّي ‏.‏ يَعْنِي النَّبِيَّ صلى الله عليه وسلم وَقَالَ أَبُو كَامِلٍ حَدَّثَنَا حَمَّادٌ، عَنْ عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، بِنَحْوِهِ ‏.‏\hadithno{1605}\hadithtrans{Abd al-Hamid reported:I heard 'Abdullah b. al-Harith say: 'Abdullah b. 'Abbas addressed us on a rainy day, and the rest of the hadith is the same, but he made no mention of Jumu'a prayer, and added: He who did it (who commanded us to say prayer in our houses), i. e. the Messenger of Allah (ﷺ), is better than I}}
\hadithdefcmd{muslim}{1606}{وَحَدَّثَنِيهِ أَبُو الرَّبِيعِ الْعَتَكِيُّ، - هُوَ الزَّهْرَانِيُّ - حَدَّثَنَا حَمَّادٌ، - يَعْنِي ابْنَ زَيْدٍ - حَدَّثَنَا أَيُّوبُ، وَعَاصِمٌ الأَحْوَلُ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ فِي حَدِيثِهِ يَعْنِي النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{1606}\hadithtrans{This hadith has been narrated by Ayyub and 'Asim al-Ahwal with the same chain of transmitters, but in this hadith it is not recorded:" i. e. the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1607}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا ابْنُ شُمَيْلٍ، أَخْبَرَنَا شُعْبَةُ، حَدَّثَنَا عَبْدُ الْحَمِيدِ، صَاحِبُ الزِّيَادِيِّ قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ الْحَارِثِ، قَالَ أَذَّنَ مُؤَذِّنُ ابْنِ عَبَّاسٍ يَوْمَ جُمُعَةٍ فِي يَوْمٍ مَطِيرٍ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِ ابْنِ عُلَيَّةَ وَقَالَ وَكَرِهْتُ أَنْ تَمْشُوا فِي الدَّحْضِ وَالزَّلَلِ ‏.‏\hadithno{1607}\hadithtrans{Abdullah b. Harith reported that Ibn 'Abbas commanded the Mu'adhdhin to (summon the people to prayer on Friday and make announcement to say prayer in their houses) when it was rainy, and the rest of the hadith is the same (except this) that he said:I do not like you should walk in muddy slippery place}}
\hadithdefcmd{muslim}{1608}{وَحَدَّثَنَاهُ عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا سَعِيدُ بْنُ عَامِرٍ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، كِلاَهُمَا عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، أَنَّ ابْنَ عَبَّاسٍ، أَمَرَ مُؤَذِّنَهُ - فِي حَدِيثِ مَعْمَرٍ - فِي يَوْمِ جُمُعَةٍ فِي يَوْمٍ مَطِيرٍ ‏.‏ بِنَحْوِ حَدِيثِهِمْ وَذَكَرَ فِي حَدِيثِ مَعْمَرٍ فَعَلَهُ مَنْ هُوَ خَيْرٌ مِنِّي ‏.‏ يَعْنِي النَّبِيَّ صلى الله عليه وسلم ‏.‏\hadithno{1608}\hadithtrans{Abdullah b. Harith reported that the Mu'adhdhin of Ibn 'Abba said Adhan on Friday (and then made the announcement to say prayer in houses) because it was a rainy day; as it has been narrated by Ma'mar and others, and in this hadith it was mentioned:He who did it, i. e. the Messenger of Allah (ﷺ), was better than I}}
\hadithdefcmd{muslim}{1609}{وَحَدَّثَنَاهُ عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا أَحْمَدُ بْنُ إِسْحَاقَ الْحَضْرَمِيُّ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، - قَالَ وُهَيْبٌ لَمْ يَسْمَعْهُ مِنْهُ - قَالَ أَمَرَ ابْنُ عَبَّاسٍ مُؤَذِّنَهُ فِي يَوْمِ جُمُعَةٍ فِي يَوْمٍ مَطِيرٍ ‏.‏ بِنَحْوِ حَدِيثِهِمْ ‏.‏\hadithno{1609}\hadithtrans{A hadith like this that Ibn 'Abbas ordered his Mu'adhdhin (to summon people to prayer and then make announcement to say prayer in their houses) on Friday which was a rainy day, has been transmitted by 'Abdullah b. Harith. Wuhaib, however, says that he did not hear it from him}}
\hadithdefcmd{muslim}{1610}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي سُبْحَتَهُ حَيْثُمَا تَوَجَّهَتْ بِهِ نَاقَتُهُ ‏.‏\hadithno{1610}\hadithtrans{Ibn 'Umar reported that the Messenger of Allah (ﷺ) used to say Nafl prayer on (the back of) his camel in whatever direction it took him}}
\hadithdefcmd{muslim}{1611}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصَلِّي عَلَى رَاحِلَتِهِ حَيْثُ تَوَجَّهَتْ بِهِ ‏.‏\hadithno{1611}\hadithtrans{Ibn 'Umar reported that the Apostle (ﷺ) used to pray on (the back of) his camel in whatever direction it took him}}
\hadithdefcmd{muslim}{1612}{وَحَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عُمَرَ الْقَوَارِيرِيُّ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، قَالَ حَدَّثَنَا سَعِيدُ بْنُ جُبَيْرٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي وَهُوَ مُقْبِلٌ مِنْ مَكَّةَ إِلَى الْمَدِينَةِ عَلَى رَاحِلَتِهِ حَيْثُ كَانَ وَجْهُهُ - قَالَ - وَفِيهِ نَزَلَتْ ‏\{‏ فَأَيْنَمَا تُوَلُّوا فَثَمَّ وَجْهُ اللَّهِ‏\}‏\hadithno{1612}\hadithtrans{Ibn 'Umar reported that the Messenger of Allah (ﷺ) used to say prayer on his camel while coming from Mecca to Medina, in whatever direction his face had turned; and its was (in this context) that this verse was revealed:" So whether you turn thither is Allah's face" (ii)}}
\hadithdefcmd{muslim}{1613}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، أَخْبَرَنَا ابْنُ الْمُبَارَكِ، وَابْنُ أَبِي زَائِدَةَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي كُلُّهُمْ، عَنْ عَبْدِ الْمَلِكِ، بِهَذَا الإِسْنَادِ نَحْوَهُ ‏.‏ وَفِي حَدِيثِ ابْنِ مُبَارَكٍ وَابْنِ أَبِي زَائِدَةَ ثُمَّ تَلاَ ابْنُ عُمَرَ ‏\{‏ فَأَيْنَمَا تُوَلُّوا فَثَمَّ وَجْهُ اللَّهِ‏\}‏ وَقَالَ فِي هَذَا نَزَلَتْ ‏.‏\hadithno{1613}\hadithtrans{This hadith has been narrated by another chain of transmitters and in the one narrated by Ibn Mubarak and Ibn Abu Za'ida (these words are narrated). Ibn 'Umar then recited:" Whether you turn thither is Allah's face," and it was revealed in this context}}
\hadithdefcmd{muslim}{1614}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَمْرِو بْنِ يَحْيَى الْمَازِنِيِّ، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنِ ابْنِ عُمَرَ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي عَلَى حِمَارٍ وَهُوَ مُوَجِّهٌ إِلَى خَيْبَرَ ‏.‏\hadithno{1614}\hadithtrans{Ibn 'Umar reported:I saw the Messenger of Allah (ﷺ) praying (Nafl prayer) on a donkey's back while his face was turned towards Khaibar}}
\hadithdefcmd{muslim}{1615}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي بَكْرِ بْنِ عُمَرَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ، عَنْ سَعِيدِ بْنِ يَسَارٍ، أَنَّهُ قَالَ كُنْتُ أَسِيرُ مَعَ ابْنِ عُمَرَ بِطَرِيقِ مَكَّةَ - قَالَ سَعِيدٌ - فَلَمَّا خَشِيتُ الصُّبْحَ نَزَلْتُ فَأَوْتَرْتُ ثُمَّ أَدْرَكْتُهُ فَقَالَ لِي ابْنُ عُمَرَ أَيْنَ كُنْتَ فَقُلْتُ لَهُ خَشِيتُ الْفَجْرَ فَنَزَلْتُ فَأَوْتَرْتُ ‏.‏ فَقَالَ عَبْدُ اللَّهِ أَلَيْسَ لَكَ فِي رَسُولِ اللَّهِ صلى الله عليه وسلم أُسْوَةٌ فَقُلْتُ بَلَى وَاللَّهِ ‏.‏ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُوتِرُ عَلَى الْبَعِيرِ ‏.‏\hadithno{1615}\hadithtrans{Sa'id b. Yasar reported:I was travelling along with Ibn 'Umar on the way to Mecca. Sa'id said: When I apprehended dawn, I dismounted (the ride) and observed Witr prayer and then again joined him. Ibn 'Umar said to me: Where were you? I said: I apprehended the appearance of dawn, so I dismounted and observed Witr prayer. Upon this 'Abdullah said: Is there not a model pattern for you in the Messenger of Allah (ﷺ)? I said: Yes, by Allah, and (then) he said: The Messenger of Allah (ﷺ) used to observe Witr prayer on the camel's back}}
\hadithdefcmd{muslim}{1616}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّهُ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي عَلَى رَاحِلَتِهِ حَيْثُمَا تَوَجَّهَتْ بِهِ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ دِينَارٍ كَانَ ابْنُ عُمَرَ يَفْعَلُ ذَلِكَ ‏.‏\hadithno{1616}\hadithtrans{Abdullah b. Dinar reported on the authority of Ibn 'Umar that the Messenger of Allah (ﷺ) used to observe prayer on his ride (no matter) in which direction it had its face turned. 'Abdullah b. Dinar said that Ibn 'Umar used to do like that}}
\hadithdefcmd{muslim}{1617}{وَحَدَّثَنِي عِيسَى بْنُ حَمَّادٍ الْمِصْرِيُّ، أَخْبَرَنَا اللَّيْثُ، حَدَّثَنِي ابْنُ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُوتِرُ عَلَى رَاحِلَتِهِ ‏.‏\hadithno{1617}\hadithtrans{Abdullah b. 'Umar reported that the Messenger of Allah (ﷺ) used to observe Witr prayer on his ride}}
\hadithdefcmd{muslim}{1618}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُسَبِّحُ عَلَى الرَّاحِلَةِ قِبَلَ أَىِّ وَجْهٍ تَوَجَّهَ وَيُوتِرُ عَلَيْهَا غَيْرَ أَنَّهُ لاَ يُصَلِّي عَلَيْهَا الْمَكْتُوبَةَ ‏.‏\hadithno{1618}\hadithtrans{Salim b. 'Abdullah reported on the authority of his father that the Messenger of Allah (may peace be. upon him) used to observe Nafl (supererogatory) prayer on his ride no matter in what direction it turned its face, and he observed Witr too on it, but did not observe obligatory prayer on it}}
\hadithdefcmd{muslim}{1619}{وَحَدَّثَنَا عَمْرُو بْنُ سَوَّادٍ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، أَخْبَرَهُ أَنَّ أَبَاهُ أَخْبَرَهُ أَنَّهُ، رَأَى رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي السُّبْحَةَ بِاللَّيْلِ فِي السَّفَرِ عَلَى ظَهْرِ رَاحِلَتِهِ حَيْثُ تَوَجَّهَتْ ‏.‏\hadithno{1619}\hadithtrans{Abdullah b. 'Amir b. Rabi'a has reported on the authority of his father that he had seen the Messenger of Allah (ﷺ) observing Nafl player at night on a journey on the back of his ride in whichever direction it turned its face}}
\hadithdefcmd{muslim}{1620}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا أَنَسُ بْنُ سِيرِينَ، قَالَ تَلَقَّيْنَا أَنَسَ بْنَ مَالِكٍ حِينَ قَدِمَ الشَّامَ فَتَلَقَّيْنَاهُ بِعَيْنِ التَّمْرِ فَرَأَيْتُهُ يُصَلِّي عَلَى حِمَارٍ وَوَجْهُهُ ذَلِكَ الْجَانِبَ - وَأَوْمَأَ هَمَّامٌ عَنْ يَسَارِ الْقِبْلَةِ - فَقُلْتُ لَهُ رَأَيْتُكَ تُصَلِّي لِغَيْرِ الْقِبْلَةِ ‏.‏ قَالَ لَوْلاَ أَنِّي رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَفْعَلُهُ لَمْ أَفْعَلْهُ ‏.‏\hadithno{1620}\hadithtrans{Anas b. Sirin reported:We met Anas b. Malik as he came to Syria at a place known as 'Ain-al-Tamar and saw him observing prayer on the back of his donkey with his face turned in that direction. (Hammam one of the narrators) pointed towards the left of Qibla, so I said to him: I find you observing prayer towards the side other than that of Qibla. Upon this he said: Had I not seen the Messenger of Allah (ﷺ) doing like this, I would not have done so at all}}
\hadithdefcmd{muslim}{1621}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا عَجِلَ بِهِ السَّيْرُ جَمَعَ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ ‏.‏\hadithno{1621}\hadithtrans{Ibn 'Umar reported:When the Messenger of Allah (ﷺ) was in a state of hurry on a journey, he combined the sunset and 'Isha' prayers}}
\hadithdefcmd{muslim}{1622}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، أَنَّ ابْنَ عُمَرَ، كَانَ إِذَا جَدَّ بِهِ السَّيْرُ جَمَعَ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ بَعْدَ أَنْ يَغِيبَ الشَّفَقُ وَيَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا جَدَّ بِهِ السَّيْرُ جَمَعَ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ ‏.‏\hadithno{1622}\hadithtrans{Nafi' reported that when Ibn 'Umar was in a state of hurry on a journey, he combined the sunset and 'Isha' prayers after the twilight had disappeared, and he would say that when the Messenger of Allah (ﷺ) was in a state of hurry on a journey, he combined the sunset and 'Isha' prayers}}
\hadithdefcmd{muslim}{1623}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ وَعَمْرٌو النَّاقِدُ كُلُّهُمْ عَنِ ابْنِ عُيَيْنَةَ، - قَالَ عَمْرٌو حَدَّثَنَا سُفْيَانُ، - عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَجْمَعُ بَيْنَ الْمَغْرِبِ وَالْعِشَاءِ إِذَا جَدَّ بِهِ السَّيْرُ ‏.‏\hadithno{1623}\hadithtrans{Salim reported from his father to be saying:I saw the Messenger of Allah (ﷺ) combining the sunset and Isha' prayers when he was in a hurry on a journey}}
\hadithdefcmd{muslim}{1624}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ أَبَاهُ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم إِذَا أَعْجَلَهُ السَّيْرُ فِي السَّفَرِ يُؤَخِّرُ صَلاَةَ الْمَغْرِبِ حَتَّى يَجْمَعَ بَيْنَهَا وَبَيْنَ صَلاَةِ الْعِشَاءِ ‏.‏\hadithno{1624}\hadithtrans{Salim b. 'Abdullah reported that his father had said:I saw the Messenger of Allah (ﷺ) delaying the sunset prayer till he would combine it with the 'Isha' when he hastened to set out on a journey}}
\hadithdefcmd{muslim}{1625}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُفَضَّلُ، - يَعْنِي ابْنَ فَضَالَةَ - عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا ارْتَحَلَ قَبْلَ أَنْ تَزِيغَ الشَّمْسُ أَخَّرَ الظُّهْرَ إِلَى وَقْتِ الْعَصْرِ ثُمَّ نَزَلَ فَجَمَعَ بَيْنَهُمَا فَإِنْ زَاغَتِ الشَّمْسُ قَبْلَ أَنْ يَرْتَحِلَ صَلَّى الظُّهْرَ ثُمَّ رَكِبَ ‏.‏\hadithno{1625}\hadithtrans{Anas b. Malik reported:When the Messenger of Allah (ﷺ) set out on a journey before the sun declined (from the meridian), he delayed the noon prayer till the afternoon prayer, and then dismounted (his ride) and combined them (noon and afternoon prayers), but if the sun had declined before his setting out on a journey, he observed the noon prayer and then mounted (the ride)}}
\hadithdefcmd{muslim}{1626}{وَحَدَّثَنِي عَمْرٌو النَّاقِدُ، حَدَّثَنَا شَبَابَةُ بْنُ سَوَّارٍ الْمَدَايِنِيُّ، حَدَّثَنَا لَيْثُ بْنُ سَعْدٍ، عَنْ عُقَيْلِ بْنِ خَالِدٍ، عَنِ الزُّهْرِيِّ، عَنْ أَنَسٍ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَجْمَعَ بَيْنَ الصَّلاَتَيْنِ فِي السَّفَرِ أَخَّرَ الظُّهْرَ حَتَّى يَدْخُلَ أَوَّلُ وَقْتِ الْعَصْرِ ثُمَّ يَجْمَعُ بَيْنَهُمَا ‏.‏\hadithno{1626}\hadithtrans{Anas reported:When the Messenger of Allah (ﷺ) intended to combine two prayers on a journey, he delayed the noon prayer till came the early time of the afternoon prayer, and then combined the two}}
\hadithdefcmd{muslim}{1627}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَعَمْرُو بْنُ سَوَّادٍ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، حَدَّثَنِي جَابِرُ بْنُ إِسْمَاعِيلَ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم إِذَا عَجِلَ عَلَيْهِ السَّفَرُ يُؤَخِّرُ الظُّهْرَ إِلَى أَوَّلِ وَقْتِ الْعَصْرِ فَيَجْمَعُ بَيْنَهُمَا وَيُؤَخِّرُ الْمَغْرِبَ حَتَّى يَجْمَعَ بَيْنَهَا وَبَيْنَ الْعِشَاءِ حِينَ يَغِيبُ الشَّفَقُ ‏.‏\hadithno{1627}\hadithtrans{Anas reported that when the Messenger of Allah (ﷺ) had to set out on a journey hurriedly, he delayed the noon prayer to the earlier time for the afternoon prayer, and then he would combine them, and he would delay the sunset prayer to the time when the twilight would disappear and then combine it with the 'Isha' prayer}}
\hadithdefcmd{muslim}{1628}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي الزُّبَيْرِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الظُّهْرَ وَالْعَصْرَ جَمِيعًا وَالْمَغْرِبَ وَالْعِشَاءَ جَمِيعًا فِي غَيْرِ خَوْفٍ وَلاَ سَفَرٍ ‏.‏\hadithno{1628}\hadithtrans{Ibn 'Abbas reported:The Messenger of Allah (ﷺ) observed the noon and afternoon prayers together, and the sunset and Isha' prayers together without being in a state of fear or in a state of journey}}
\hadithdefcmd{muslim}{1629}{وَحَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، وَعَوْنُ بْنُ سَلاَّمٍ، جَمِيعًا عَنْ زُهَيْرٍ، - قَالَ ابْنُ يُونُسَ حَدَّثَنَا زُهَيْرٌ، - حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم الظُّهْرَ وَالْعَصْرَ جَمِيعًا بِالْمَدِينَةِ فِي غَيْرِ خَوْفٍ وَلاَ سَفَرٍ ‏.‏ قَالَ أَبُو الزُّبَيْرِ فَسَأَلْتُ سَعِيدًا لِمَ فَعَلَ ذَلِكَ فَقَالَ سَأَلْتُ ابْنَ عَبَّاسٍ كَمَا سَأَلْتَنِي فَقَالَ أَرَادَ أَنْ لاَ يُحْرِجَ أَحَدًا مِنْ أُمَّتِهِ ‏.‏\hadithno{1629}\hadithtrans{Ibn 'Abbas reported:The Messenger of Allah (ﷺ) observed the noon and afternoon prayers together in Medina without being in a state of fear or in a state of journey. (Abu Zubair said: I asked Sa'id [one of the narrators] why he did that. He said: I asked Ibn 'Abbas as you have asked me, and he replied that he [the Holy Prophet] wanted that no one among his Ummah should be put to [unnecessary] hardship}}
\hadithdefcmd{muslim}{1630}{وَحَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا قُرَّةُ، حَدَّثَنَا أَبُو الزُّبَيْرِ، حَدَّثَنَا سَعِيدُ بْنُ جُبَيْرٍ، حَدَّثَنَا ابْنُ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَمَعَ بَيْنَ الصَّلاَةِ فِي سَفْرَةٍ سَافَرَهَا فِي غَزْوَةِ تَبُوكَ فَجَمَعَ بَيْنَ الظُّهْرِ وَالْعَصْرِ وَالْمَغْرِبِ وَالْعِشَاءِ ‏.‏ قَالَ سَعِيدٌ فَقُلْتُ لاِبْنِ عَبَّاسٍ مَا حَمَلَهُ عَلَى ذَلِكَ قَالَ أَرَادَ أَنْ لاَ يُحْرِجَ أُمَّتَهُ ‏.‏\hadithno{1630}\hadithtrans{Ibn 'Abbas reported that the Messenger of Allah (ﷺ) combined the prayers as he set on a journey in the expedition to Tabuk. He combined the noon prayer with the afternoon prayer and the sunset prayer with the 'Isha' prayer. Sa'id (one of the rawis) said to Ibn 'Abbas:What prompted him to do this? He said: He wanted that his Ummah should not be put to (unnecessary) hardship}}
\hadithdefcmd{muslim}{1631}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ أَبِي الطُّفَيْلِ، عَامِرٍ عَنْ مُعَاذٍ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ فَكَانَ يُصَلِّي الظُّهْرَ وَالْعَصْرَ جَمِيعًا وَالْمَغْرِبَ وَالْعِشَاءَ جَمِيعًا ‏.‏\hadithno{1631}\hadithtrans{Mu'adh reported:We set out with the Messenger of Allah (ﷺ) on the Tabuk expedition, and he observed the noon and afternoon prayers together and the sunset and 'Isha' prayers together}}
\hadithdefcmd{muslim}{1632}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، حَدَّثَنَا أَبُو الزُّبَيْرِ، حَدَّثَنَا عَامِرُ بْنُ وَاثِلَةَ أَبُو الطُّفَيْلِ، حَدَّثَنَا مُعَاذُ بْنُ جَبَلٍ، قَالَ جَمَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ تَبُوكَ بَيْنَ الظُّهْرِ وَالْعَصْرِ وَبَيْنَ الْمَغْرِبِ وَالْعِشَاءِ ‏.‏ قَالَ فَقُلْتُ مَا حَمَلَهُ عَلَى ذَلِكَ قَالَ فَقَالَ أَرَادَ أَنْ لاَ يُحْرِجَ أُمَّتَهُ ‏.‏\hadithno{1632}\hadithtrans{Mu'adh b. Jabal reported:The Messenger of Allah (ﷺ) combined in the expedition to Tabuk the noon prayer with the afternoon prayer and the sunset prayer with the 'Isha' prayer. He (one of the narrators) said: What prompted him to do that? He (Mu'adh) replied that he (the Holy Prophet) wanted that his Ummah should not be put to (unnecessary) hardship}}
\hadithdefcmd{muslim}{1633}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، وَأَبُو سَعِيدٍ الأَشَجُّ - وَاللَّفْظُ لأَبِي كُرَيْبٍ - قَالاَ حَدَّثَنَا وَكِيعٌ، كِلاَهُمَا عَنِ الأَعْمَشِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَمَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ الظُّهْرِ وَالْعَصْرِ وَالْمَغْرِبِ وَالْعِشَاءِ بِالْمَدِينَةِ فِي غَيْرِ خَوْفٍ وَلاَ مَطَرٍ ‏.‏ فِي حَدِيثِ وَكِيعٍ قَالَ قُلْتُ لاِبْنِ عَبَّاسٍ لِمَ فَعَلَ ذَلِكَ قَالَ كَىْ لاَ يُحْرِجَ أُمَّتَهُ ‏.‏ وَفِي حَدِيثِ أَبِي مُعَاوِيَةَ قِيلَ لاِبْنِ عَبَّاسٍ مَا أَرَادَ إِلَى ذَلِكَ قَالَ أَرَادَ أَنْ لاَ يُحْرِجَ أُمَّتَهُ ‏.‏\hadithno{1633}\hadithtrans{Ibn 'Abbas reported that the Messenger of Allah (ﷺ) combined the noon prayer with the afternoon prayer and the sunset prayer with the 'Isha' prayer in Medina without being in a state of danger or rainfall. And in the hadith transmitted by Waki' (the words are):" I said to Ibn 'Abbas: What prompted him to do that? He said: So that his (Prophet's) Ummah should not be put to (unnecessary) hardship." And in the hadith transmitted by Mu'awiya (the words are):" It was said to Ibn 'Abbas: What did he intend thereby? He said he wanted that his Ummah should not be put to unnecessary hardship}}
\hadithdefcmd{muslim}{1634}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرٍو، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم ثَمَانِيًا جَمِيعًا وَسَبْعًا جَمِيعًا ‏.‏ قُلْتُ يَا أَبَا الشَّعْثَاءِ أَظُنُّهُ أَخَّرَ الظُّهْرَ وَعَجَّلَ الْعَصْرَ وَأَخَّرَ الْمَغْرِبَ وَعَجَّلَ الْعِشَاءَ ‏.‏ قَالَ وَأَنَا أَظُنُّ ذَاكَ ‏.‏\hadithno{1634}\hadithtrans{Ibn 'Abbas reported:I observed with the Messenger of Allah (ﷺ) eight (rak'ahs) in combination, and seven rak'ahs in combination. I (one of the narrators) said: O Abd Sha'tha', I think that he (the Holy Prophet) had delayed the noon prayer and hastened the afternoon prayer, and he delayed the sunset prayer and hastened the 'Isha' prayer. He said: I also think so}}
\hadithdefcmd{muslim}{1635}{وَحَدَّثَنَا أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى بِالْمَدِينَةِ سَبْعًا وَثَمَانِيًا الظُّهْرَ وَالْعَصْرَ وَالْمَغْرِبَ وَالْعِشَاءَ ‏.‏\hadithno{1635}\hadithtrans{Ibn 'Abbas reported that the Messenger of Allah (ﷺ) observed in Medina seven (rak'ahs) and eight (rak'ahs), i. e. (be combined) the noon and afternoon prayers (eight rak'ahs) and the sunset and 'Isha' prayers (seven rak'ahs)}}
\hadithdefcmd{muslim}{1636}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، عَنِ الزُّبَيْرِ بْنِ الْخِرِّيتِ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ خَطَبَنَا ابْنُ عَبَّاسٍ يَوْمًا بَعْدَ الْعَصْرِ حَتَّى غَرَبَتِ الشَّمْسُ وَبَدَتِ النُّجُومُ وَجَعَلَ النَّاسُ يَقُولُونَ الصَّلاَةَ الصَّلاَةَ - قَالَ - فَجَاءَهُ رَجُلٌ مِنْ بَنِي تَمِيمٍ لاَ يَفْتُرُ وَلاَ يَنْثَنِي الصَّلاَةَ الصَّلاَةَ ‏.‏ فَقَالَ ابْنُ عَبَّاسٍ أَتُعَلِّمُنِي بِالسُّنَّةِ لاَ أُمَّ لَكَ ‏.‏ ثُمَّ قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم جَمَعَ بَيْنَ الظُّهْرِ وَالْعَصْرِ وَالْمَغْرِبِ وَالْعِشَاءِ ‏.‏ قَالَ عَبْدُ اللَّهِ بْنُ شَقِيقٍ فَحَاكَ فِي صَدْرِي مِنْ ذَلِكَ شَىْءٌ فَأَتَيْتُ أَبَا هُرَيْرَةَ فَسَأَلْتُهُ فَصَدَّقَ مَقَالَتَهُ ‏.‏\hadithno{1636}\hadithtrans{Abdullah b. Shaqiq reported:Ibn 'Abbas one day addressed us in the afternoon (after the afternoon prayer) till the sun disappeared and the stars appeared, and the people began to say: Prayer, prayer. A person from Banu Tamim came there. He neither slackened nor turned away, but (continued crying): Prayer, prayer. Ibn 'Abbas said: May you be deprived of your mother, do you teach me Sunnah? And then he said: I saw the Messenger of Allah (ﷺ) combining the noon and afternoon prayers and the sunset and 'Isha' prayers. 'Abdullah b. Shaqiq said: Some doubt was created in my mind about it. So I came to Abu Huraira and asked him (about it) and he testified his assertion}}
\hadithdefcmd{muslim}{1637}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا عِمْرَانُ بْنُ حُدَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ الْعُقَيْلِيِّ، قَالَ قَالَ رَجُلٌ لاِبْنِ عَبَّاسٍ الصَّلاَةَ فَسَكَتَ ‏.‏ ثُمَّ قَالَ الصَّلاَةَ ‏.‏ فَسَكَتَ ثُمَّ قَالَ الصَّلاَةَ فَسَكَتَ ‏.‏ ثُمَّ قَالَ لاَ أُمَّ لَكَ أَتُعَلِّمُنَا بِالصَّلاَةِ وَكُنَّا نَجْمَعُ بَيْنَ الصَّلاَتَيْنِ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{1637}\hadithtrans{Abdullah b. Shaqiq al-'Uqaili reported:A person said to Ibn 'Abbas (as he delayed the prayer): Prayer. He kept silence. He again said: Prayer. He again kept silence, and he again cried: Prayer. He again kept silence and said: May you be deprived of your mother, do you teach us about prayer? We used to combine two prayers during the life of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1638}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَوَكِيعٌ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، قَالَ لاَ يَجْعَلَنَّ أَحَدُكُمْ لِلشَّيْطَانِ مِنْ نَفْسِهِ جُزْءًا لاَ يَرَى إِلاَّ أَنَّ حَقًّا عَلَيْهِ أَنْ لاَ يَنْصَرِفَ إِلاَّ عَنْ يَمِينِهِ أَكْثَرُ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْصَرِفُ عَنْ شِمَالِهِ ‏.‏\hadithno{1638}\hadithtrans{Abdullah reported:None of you should give a share to Satan out of your self. He should not deem that it is necessary for him to turn but to the right only (after prayer). I saw the Messenger of Allah (ﷺ) turning to the left}}
\hadithdefcmd{muslim}{1639}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، وَعِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَاهُ عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى، جَمِيعًا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{1639}\hadithtrans{A hadith like this has been narrated by A'mash, with the same chain of transmitters}}
\hadithdefcmd{muslim}{1640}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ السُّدِّيِّ، قَالَ سَأَلْتُ أَنَسًا كَيْفَ أَنْصَرِفُ إِذَا صَلَّيْتُ عَنْ يَمِينِي أَوْ عَنْ يَسَارِي قَالَ أَمَّا أَنَا فَأَكْثَرُ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْصَرِفُ عَنْ يَمِينِهِ ‏.‏\hadithno{1640}\hadithtrans{Suddi reported:I asked Anas how I should turn-to the right or to the left-when I say my prayers. He said: I have very often seen the Messenger of Allah (ﷺ) turning to the right}}
\hadithdefcmd{muslim}{1641}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنِ السُّدِّيِّ، عَنْ أَنَسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَنْصَرِفُ عَنْ يَمِينِهِ ‏.‏\hadithno{1641}\hadithtrans{Anas reported:The Apostle of Allah (ﷺ) used to turn to the right (at the end of the prayer)}}
\hadithdefcmd{muslim}{1642}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، أَخْبَرَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ مِسْعَرٍ، عَنْ ثَابِتِ بْنِ عُبَيْدٍ، عَنِ ابْنِ الْبَرَاءِ، عَنِ الْبَرَاءِ، قَالَ كُنَّا إِذَا صَلَّيْنَا خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَحْبَبْنَا أَنْ نَكُونَ عَنْ يَمِينِهِ يُقْبِلُ عَلَيْنَا بِوَجْهِهِ - قَالَ - فَسَمِعْتُهُ يَقُولُ ‏ "‏ رَبِّ قِنِي عَذَابَكَ يَوْمَ تَبْعَثُ - أَوْ تَجْمَعُ - عِبَادَكَ ‏"‏ ‏.‏\hadithno{1642}\hadithtrans{Bara' reported:When we prayed behind the Messenger of Allah (ﷺ) we cherished to be on his right side so that his face would turn towards us (at the end of the prayer), and he (the narrator) said: I heard him say: O my Lord! save me from Thy torment on the Day when Thoil, wouldst raise or gather Thy servants}}
\hadithdefcmd{muslim}{1643}{وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ مِسْعَرٍ، بِهَذَا الإِسْنَادِ وَلَمْ يَذْكُرْ يُقْبِلُ عَلَيْنَا بِوَجْهِهِ ‏.‏\hadithno{1643}\hadithtrans{This hadith has been reported by Mis'ar with the same chain of transmitters, but he made no mention of:" His face would turn towards us}}
\hadithdefcmd{muslim}{1644}{وَحَدَّثَنِي أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ وَرْقَاءَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ صَلاَةَ إِلاَّ الْمَكْتُوبَةُ ‏"‏ ‏.‏ وَحَدَّثَنِيهِ مُحَمَّدُ بْنُ حَاتِمٍ وَابْنُ رَافِعٍ قَالاَ حَدَّثَنَا شَبَابَةُ حَدَّثَنِي وَرْقَاءُ بِهَذَا الإِسْنَادِ ‏.‏\hadithno{1644}\hadithtrans{Abu Huraira reported the Messenger of Allah (ﷺ) as saying:When the prayer commences then there is no prayer (valid), but the obligatory prayer. This hadith has been narrated by Warqa' with the same chain of transmitters}}
\hadithdefcmd{muslim}{1645}{وَحَدَّثَنِي يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، قَالَ سَمِعْتُ عَطَاءَ بْنَ يَسَارٍ، يَقُولُ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا أُقِيمَتِ الصَّلاَةُ فَلاَ صَلاَةَ إِلاَّ الْمَكْتُوبَةُ ‏"‏ ‏.‏\hadithno{1645}\hadithtrans{Abu Huraira reported the Messenger of Allah (ﷺ) as saying:When the prayer commences, there is no prayer but the obligatory one}}
\hadithdefcmd{muslim}{1646}{وَحَدَّثَنَاهُ عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا زَكَرِيَّاءُ بْنُ إِسْحَاقَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{1646}\hadithtrans{A hadith like this has been reported by Ishaq with the same chain of transmitters}}
\hadithdefcmd{muslim}{1647}{وَحَدَّثَنَا حَسَنٌ الْحُلْوَانِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ ‏.‏ قَالَ حَمَّادٌ ثُمَّ لَقِيتُ عَمْرًا فَحَدَّثَنِي بِهِ وَلَمْ يَرْفَعْهُ ‏.‏\hadithno{1647}\hadithtrans{This hadith has been narrated by Abu Huraira with another chain of transmitters. Hammad (one of the narrators) said:I then met 'Amr (the other narrator) and he narrated it to me, but it was not transmitted directly from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1649}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ أَبِيهِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَالِكٍ ابْنِ بُحَيْنَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مَرَّ بِرَجُلٍ يُصَلِّي وَقَدْ أُقِيمَتْ صَلاَةُ الصُّبْحِ فَكَلَّمَهُ بِشَىْءٍ لاَ نَدْرِي مَا هُوَ فَلَمَّا انْصَرَفْنَا أَحَطْنَا نَقُولُ مَاذَا قَالَ لَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ قَالَ لِي ‏ "‏ يُوشِكُ أَنْ يُصَلِّيَ أَحَدُكُمُ الصُّبْحَ أَرْبَعًا ‏"‏ ‏.‏ قَالَ الْقَعْنَبِيُّ عَبْدُ اللَّهِ بْنُ مَالِكٍ ابْنُ بُحَيْنَةَ عَنْ أَبِيهِ ‏.‏ قَالَ أَبُو الْحُسَيْنِ مُسْلِمٌ وَقَوْلُهُ عَنْ أَبِيهِ فِي هَذَا الْحَدِيثِ خَطَأٌ ‏.‏\hadithno{1649}\hadithtrans{Abdullah b. Malik b. Buhaina reported:The Messenger of Allah (ﷺ) happened to pass by a person who was busy in praying while the (Fard of the) dawn prayer had commenced. He said something to him, which we do not know what it was. When we turned back we surrounded him and said: What is it that the Messenger of Allah (ﷺ) said to you? He replied: He (the Holy Prophet) had said to me that he perceived as if one of them was about to observe four (rak'ahs) of the dawn prayer. Qa'nabi reported that 'Abdullah b. Malik b. Buhaina narrated it on the authority of his father. (Abu'l-Husain Muslim said): His assertion that he has narrated this hadith on the authority of his father is not correct}}
\hadithdefcmd{muslim}{1650}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنِ ابْنِ بُحَيْنَةَ، قَالَ أُقِيمَتْ صَلاَةُ الصُّبْحِ فَرَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم رَجُلاً يُصَلِّي وَالْمُؤَذِّنُ يُقِيمُ فَقَالَ ‏ "‏ أَتُصَلِّي الصُّبْحَ أَرْبَعًا ‏"‏ ‏.‏\hadithno{1650}\hadithtrans{Ibn Buhaina reported:The dawn prayer had commenced when the Messen- ger of Allah (ﷺ) saw a person observing prayer, whereas the Mu'adhdhin had pronounced the Iqama. Upon this he (the Holy Prophet) remarked: Do you say four (rak'ahs) of Fard in the dawn prayer?}}
\hadithdefcmd{muslim}{1651}{حَدَّثَنَا أَبُو كَامِلٍ الْجَحْدَرِيُّ، حَدَّثَنَا حَمَّادٌ يَعْنِي ابْنَ زَيْدٍ، ح وَحَدَّثَنِي حَامِدُ بْنُ عُمَرَ الْبَكْرَاوِيُّ، حَدَّثَنَا عَبْدُ الْوَاحِدِ يَعْنِي ابْنَ زِيَادٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، كُلُّهُمْ عَنْ عَاصِمٍ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ الْفَزَارِيُّ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ عَبْدِ اللَّهِ بْنِ سَرْجِسَ، قَالَ دَخَلَ رَجُلٌ الْمَسْجِدَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم فِي صَلاَةِ الْغَدَاةِ فَصَلَّى رَكْعَتَيْنِ فِي جَانِبِ الْمَسْجِدِ ثُمَّ دَخَلَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا سَلَّمَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَا فُلاَنُ بِأَىِّ الصَّلاَتَيْنِ اعْتَدَدْتَ أَبِصَلاَتِكَ وَحْدَكَ أَمْ بِصَلاَتِكَ مَعَنَا ‏"‏ ‏.‏\hadithno{1651}\hadithtrans{Abdullah b. Sarjis reported:A person entered the mosque, while the Messenger of Allah (ﷺ) was leading the dawn prayer. He observed two rak'ahs in a corner of the mosque, and then joined the Messenger of Allah (ﷺ) in prayer. When the Messenger of Allah (ﷺ) had pronounced salutations (he had concluded the prayer), he said: O, so and so, which one out of these two prayers did you count (as your Fard prayer), the one that you observed alone or the prayer that you observed with us?}}
\hadithdefcmd{muslim}{1652}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ الْمَلِكِ بْنِ سَعِيدٍ، عَنْ أَبِي حُمَيْدٍ، - أَوْ عَنْ أَبِي أُسَيْدٍ، - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دَخَلَ أَحَدُكُمُ الْمَسْجِدَ فَلْيَقُلِ اللَّهُمَّ افْتَحْ لِي أَبْوَابَ رَحْمَتِكَ ‏.‏ وَإِذَا خَرَجَ فَلْيَقُلِ اللَّهُمَّ إِنِّي أَسْأَلُكَ مِنْ فَضْلِكَ ‏"‏ ‏.‏ قَالَ مُسْلِمٌ سَمِعْتُ يَحْيَى بْنَ يَحْيَى يَقُولُ كَتَبْتُ هَذَا الْحَدِيثَ مِنْ كِتَابِ سُلَيْمَانَ بْنِ بِلاَلٍ ‏.‏ قَالَ بَلَغَنِي أَنَّ يَحْيَى الْحِمَّانِيَّ يَقُولُ وَأَبِي أُسَيْدٍ ‏.‏\hadithno{1652}\hadithtrans{Abu Usaid reported that the Messenger of Allah (ﷺ) said:When any one of you enters the mosque, he should say:" O Allah! open for me the doors of Thy mercy" ; and when he steps out he should say: 'O Allah! I beg of Thee Thy Grace." (Imam Muslim said: I heard Yahya saying: I transcribed this hadith from the compilation of Sulaiman b. Bilal)}}
\hadithdefcmd{muslim}{1653}{وَحَدَّثَنَا حَامِدُ بْنُ عُمَرَ الْبَكْرَاوِيُّ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا عُمَارَةُ بْنُ غَزِيَّةَ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَبْدِ الْمَلِكِ بْنِ سَعِيدِ بْنِ سُوَيْدٍ الأَنْصَارِيِّ، عَنْ أَبِي حُمَيْدٍ، أَوْ عَنْ أَبِي أُسَيْدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{1653}\hadithtrans{A hadith like this has been narrated from the Messenger of Allah (ﷺ) by Abu Usaid}}
\hadithdefcmd{muslim}{1654}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا مَالِكٌ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَامِرِ بْنِ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَمْرِو بْنِ سُلَيْمٍ الزُّرَقِيِّ، عَنْ أَبِي قَتَادَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دَخَلَ أَحَدُكُمُ الْمَسْجِدَ فَلْيَرْكَعْ رَكْعَتَيْنِ قَبْلَ أَنْ يَجْلِسَ ‏"‏ ‏.‏\hadithno{1654}\hadithtrans{Abu Qatada (a Companion of the Prophet) reported Allah's Messenger (ﷺ) as saying:When any one of you enters the mosque, he should observe two rak'ahs (of Nafl prayer) before sitting}}
\hadithdefcmd{muslim}{1655}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ، عَنْ زَائِدَةَ، قَالَ حَدَّثَنِي عَمْرُو بْنُ يَحْيَى الأَنْصَارِيُّ، حَدَّثَنِي مُحَمَّدُ بْنُ يَحْيَى بْنِ حَبَّانَ، عَنْ عَمْرِو بْنِ سُلَيْمِ بْنِ خَلْدَةَ الأَنْصَارِيِّ، عَنْ أَبِي قَتَادَةَ، صَاحِبِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ دَخَلْتُ الْمَسْجِدَ وَرَسُولُ اللَّهِ صلى الله عليه وسلم جَالِسٌ بَيْنَ ظَهْرَانَىِ النَّاسِ - قَالَ - فَجَلَسْتُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مَنَعَكَ أَنْ تَرْكَعَ رَكْعَتَيْنِ قَبْلَ أَنْ تَجْلِسَ ‏"‏ ‏.‏ قَالَ فَقُلْتُ يَا رَسُولَ اللَّهِ رَأَيْتُكَ جَالِسًا وَالنَّاسُ جُلُوسٌ ‏.‏ قَالَ ‏"‏ فَإِذَا دَخَلَ أَحَدُكُمُ الْمَسْجِدَ فَلاَ يَجْلِسْ حَتَّى يَرْكَعَ رَكْعَتَيْنِ ‏"‏ ‏.‏\hadithno{1655}\hadithtrans{Abu Qatada, a Companion of the Messenger of Allah (ﷺ), said:I entered the mosque, when the Messenger of Allah (ﷺ) had been sitting among people, and I also sat down among them. Upon this the Messenger of Allah (ﷺ) said: What prevented you from offering two rak'ahs (of Nafl prayer) before sitting down? I said: Messenger of Allah, I saw you sitting and people sitting (around you and I, therefore, sat in your company). He (the Holy Prophet) then said: When anyone among you enters the mosque, he should not sit till he has observed two rak'ahs}}
\hadithdefcmd{muslim}{1656}{حَدَّثَنَا أَحْمَدُ بْنُ جَوَّاسٍ الْحَنَفِيُّ أَبُو عَاصِمٍ، حَدَّثَنَا عُبَيْدُ اللَّهِ الأَشْجَعِيُّ، عَنْ سُفْيَانَ، عَنْ مُحَارِبِ بْنِ دِثَارٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كَانَ لِي عَلَى النَّبِيِّ صلى الله عليه وسلم دَيْنٌ فَقَضَانِي وَزَادَنِي وَدَخَلْتُ عَلَيْهِ الْمَسْجِدَ فَقَالَ لِي ‏ "‏ صَلِّ رَكْعَتَيْنِ ‏"‏ ‏.‏\hadithno{1656}\hadithtrans{Jabir b. 'Abdullah reported:The Apostle of Allah (ﷺ) owed me a debt; he paid me back and made an addition (of this). I entered the mosque and he (the Holy Prophet) said to me: Observe two rak'ahs of prayer}}
\hadithdefcmd{muslim}{1657}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَارِبٍ، سَمِعَ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ اشْتَرَى مِنِّي رَسُولُ اللَّهِ صلى الله عليه وسلم بَعِيرًا فَلَمَّا قَدِمَ الْمَدِينَةَ أَمَرَنِي أَنْ آتِيَ الْمَسْجِدَ فَأُصَلِّيَ رَكْعَتَيْنِ ‏.‏\hadithno{1657}\hadithtrans{Jabir b. 'Abdullah reported:The Messenger of Allah (ﷺ) bought a camel from me. When he came back to Medina, he ordered me to come to the mosque and observed two rak'ahs of prayer}}
\hadithdefcmd{muslim}{1658}{وَحَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي الثَّقَفِيَّ - حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ وَهْبِ بْنِ كَيْسَانَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ خَرَجْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزَاةٍ فَأَبْطَأَ بِي جَمَلِي وَأَعْيَى ثُمَّ قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم قَبْلِي وَقَدِمْتُ بِالْغَدَاةِ فَجِئْتُ الْمَسْجِدَ فَوَجَدْتُهُ عَلَى بَابِ الْمَسْجِدِ قَالَ ‏"‏ الآنَ حِينَ قَدِمْتَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ فَدَعْ جَمَلَكَ وَادْخُلْ فَصَلِّ رَكْعَتَيْنِ ‏"‏ ‏.‏ قَالَ فَدَخَلْتُ فَصَلَّيْتُ ثُمَّ رَجَعْتُ ‏.‏\hadithno{1658}\hadithtrans{Jabir b. 'Abdullah reported:I went with the Messenger of Allah (ﷺ) on an expedition and my camel delayed me and I was exhausted. The Messenger of Allah (ﷺ) thus came earlier than I, whereas I came on the next day and went to the mosque and found him (the Holy Prophet) at the gate of the mosque. He said: It is now that you have come. I said. Yes. He said: Leave your camel and enter (the mosque) and observe two rak'ahs. He (the narrator) said: So I entered and observed (two rak'ahs) of prayer and then went back}}
\hadithdefcmd{muslim}{1659}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا الضَّحَّاكُ يَعْنِي أَبَا عَاصِمٍ، ح وَحَدَّثَنِي مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، قَالاَ جَمِيعًا أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي ابْنُ شِهَابٍ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ عَبْدِ اللَّهِ بْنِ كَعْبٍ، أَخْبَرَهُ عَنْ أَبِيهِ عَبْدِ اللَّهِ بْنِ كَعْبٍ، وَعَنْ عَمِّهِ، عُبَيْدِ اللَّهِ بْنِ كَعْبٍ عَنْ كَعْبِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ لاَ يَقْدَمُ مِنْ سَفَرٍ إِلاَّ نَهَارًا فِي الضُّحَى فَإِذَا قَدِمَ بَدَأَ بِالْمَسْجِدِ فَصَلَّى فِيهِ رَكْعَتَيْنِ ثُمَّ جَلَسَ فِيهِ ‏.‏\hadithno{1659}\hadithtrans{Ka'b b. Malik reported:The Messenger of Allah (ﷺ) did not come back from the journey but by day in the forenoon, and when he arrived, he went first to the mosque, and having prayed two rak'ahs in it he sat down in it}}
\hadithdefcmd{muslim}{1660}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ قُلْتُ لِعَائِشَةَ هَلْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي الضُّحَى قَالَتْ لاَ إِلاَّ أَنْ يَجِيءَ مِنْ مَغِيبِهِ ‏.‏\hadithno{1660}\hadithtrans{Abdullah b. Shaqiq reported:I asked 'A'isha whether the Messenger of Allah (ﷺ) used to observe the forenoon prayer. She said: No, but when he came back from the journey}}
\hadithdefcmd{muslim}{1661}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا كَهْمَسُ بْنُ الْحَسَنِ الْقَيْسِيُّ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ قُلْتُ لِعَائِشَةَ أَكَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي الضُّحَى قَالَتْ لاَ إِلاَّ أَنْ يَجِيءَ مِنْ مَغِيبِهِ\hadithno{1661}\hadithtrans{Abdullah b. Shaqiq reported:I aksed 'A'isha whether the Messenger of Allah (ﷺ) used to observe the forenoon prayer. She said: No, except when he came back from a journey}}
\hadithdefcmd{muslim}{1662}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يُصَلِّي سُبْحَةَ الضُّحَى قَطُّ ‏.‏ وَإِنِّي لأُسَبِّحُهَا وَإِنْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيَدَعُ الْعَمَلَ وَهُوَ يُحِبُّ أَنْ يَعْمَلَ بِهِ خَشْيَةَ أَنْ يَعْمَلَ بِهِ النَّاسُ فَيُفْرَضَ عَلَيْهِمْ ‏.‏\hadithno{1662}\hadithtrans{Urwa reported 'A'isha to be sayidg:I have never seen the Messenger of Allah (ﷺ) observing the supererogatory prayer of the forenoon, but I observed it. And if the Messenger of Allah (ﷺ) abandoned any act which he in fact loved to do, it was out of fear that if the people practised it constantly, it might become obligatory for them}}
\hadithdefcmd{muslim}{1663}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا يَزِيدُ، - يَعْنِي الرِّشْكَ - حَدَّثَتْنِي مُعَاذَةُ، أَنَّهَا سَأَلَتْ عَائِشَةَ - رضى الله عنها - كَمْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي صَلاَةَ الضُّحَى قَالَتْ أَرْبَعَ رَكَعَاتٍ وَيَزِيدُ مَا شَاءَ ‏.‏\hadithno{1663}\hadithtrans{Mu'adha asked 'A'isha (Allah be pleased with her) how many rak'ahs Allah's Messenger (ﷺ) prayed at the forenoon prayer. She replied:Four rak'ahs, but sometimes more as he pleased}}
\hadithdefcmd{muslim}{1664}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ يَزِيدَ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ وَقَالَ يَزِيدُ مَا شَاءَ اللَّهُ ‏.‏\hadithno{1664}\hadithtrans{A hadith like this has been reported by the same chain of transmitters, but with this alteration that the transmitter said:" As Allah pleased}}
\hadithdefcmd{muslim}{1665}{وَحَدَّثَنِي يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، عَنْ سَعِيدٍ، حَدَّثَنَا قَتَادَةُ، أَنَّ مُعَاذَةَ الْعَدَوِيَّةَ، حَدَّثَتْهُمْ عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الضُّحَى أَرْبَعًا وَيَزِيدُ مَا شَاءَ اللَّهُ ‏.‏\hadithno{1665}\hadithtrans{Mua'ada 'Adawiyya reported 'A'isha as saying:The Messenger of Allah (ﷺ) used to observe four rak'ahs in the forenoon prayer and he sometimes observed more as Allah pleased}}
\hadithdefcmd{muslim}{1666}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَابْنُ، بَشَّارٍ جَمِيعًا عَنْ مُعَاذِ بْنِ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{1666}\hadithtrans{A hadith like this has been narrated by Qatada with the same chain of transmitters}}
\hadithdefcmd{muslim}{1667}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، قَالَ مَا أَخْبَرَنِي أَحَدٌ، أَنَّهُ رَأَى النَّبِيَّ صلى الله عليه وسلم يُصَلِّي الضُّحَى إِلاَّ أُمُّ هَانِئٍ فَإِنَّهَا حَدَّثَتْ أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ بَيْتَهَا يَوْمَ فَتْحِ مَكَّةَ فَصَلَّى ثَمَانِيَ رَكَعَاتٍ مَا رَأَيْتُهُ صَلَّى صَلاَةً قَطُّ أَخَفَّ مِنْهَا غَيْرَ أَنَّهُ كَانَ يُتِمُّ الرُّكُوعَ وَالسُّجُودَ ‏.‏ وَلَمْ يَذْكُرِ ابْنُ بَشَّارٍ فِي حَدِيثِهِ قَوْلَهُ قَطُّ ‏.‏\hadithno{1667}\hadithtrans{Abd al-Rahman b. Abu Laila reported:No one has ever narrated to me that he saw the Messenger of Allah (ﷺ) observing the forenoon prayer, except Umm Hani. She, however, narrated that the Messenger of Allah (ﷺ) entered her house on the day of the Conquest of Mecca and prayed eight rak'ahs (adding): I never saw a shorter prayer than it except that he performed the bowing and prostration completely. But (one of the narrators) Ibn Bashshar in his narration made no mention of the word:" Never}}
\hadithdefcmd{muslim}{1668}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، قَالاَ أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ حَدَّثَنِي ابْنُ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، أَنَّ أَبَاهُ عَبْدَ اللَّهِ بْنَ الْحَارِثِ بْنِ نَوْفَلٍ، قَالَ سَأَلْتُ وَحَرَصْتُ عَلَى أَنْ أَجِدَ أَحَدًا مِنَ النَّاسِ يُخْبِرُنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سَبَّحَ سُبْحَةَ الضُّحَى فَلَمْ أَجِدْ أَحَدًا يُحَدِّثُنِي ذَلِكَ غَيْرَ أَنَّ أُمَّ هَانِئٍ بِنْتَ أَبِي طَالِبٍ أَخْبَرَتْنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَى بَعْدَ مَا ارْتَفَعَ النَّهَارُ يَوْمَ الْفَتْحِ فَأُتِيَ بِثَوْبٍ فَسُتِرَ عَلَيْهِ فَاغْتَسَلَ ثُمَّ قَامَ فَرَكَعَ ثَمَانِيَ رَكَعَاتٍ لاَ أَدْرِي أَقِيَامُهُ فِيهَا أَطْوَلُ أَمْ رُكُوعُهُ أَمْ سُجُودُهُ كُلُّ ذَلِكَ مِنْهُ مُتَقَارِبٌ - قَالَتْ - فَلَمْ أَرَهُ سَبَّحَهَا قَبْلُ وَلاَ بَعْدُ ‏.‏ قَالَ الْمُرَادِيُّ عَنْ يُونُسَ ‏.‏ وَلَمْ يَقُلْ أَخْبَرَنِي ‏.‏\hadithno{1668}\hadithtrans{Abdullah b. Harith b. Naufal reported:I had been asking about, as I was desirous to find one among people who should inform me, whether the Messenger of Allah (ﷺ) observed the forenoon prayer, but I found none to narrate that to me except Umm Hani, daughter of Abu Talib (the real sister of Hadrat 'Ali), who told me that on the day of the Conquest the Messenger of Allah (ﷺ) came (to our house) after the dawn had (sufficiently) arisen. A cloth was brought and privacy was provided for him (the Holy Prophet). He took a bath and then stood up and observed eight rak'ahs. I do not know whether his Qiyam (standing posture) was longer, or bending or prostration or all of them were of equal duration. She (Umm Hani) further said: I never saw him saying this Nafl prayer prior to it or subsequently. (Al-Muradi narrated on the authority of Yunus that he made no mention of the words:" He informed me)}}
\hadithdefcmd{muslim}{1669}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ أَبِي النَّضْرِ، أَنَّ أَبَا مُرَّةَ، مَوْلَى أُمِّ هَانِئٍ بِنْتِ أَبِي طَالِبٍ أَخْبَرَهُ أَنَّهُ، سَمِعَ أُمَّ هَانِئٍ بِنْتَ أَبِي طَالِبٍ، تَقُولُ ذَهَبْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم عَامَ الْفَتْحِ فَوَجَدْتُهُ يَغْتَسِلُ وَفَاطِمَةُ ابْنَتُهُ تَسْتُرُهُ بِثَوْبٍ - قَالَتْ - فَسَلَّمْتُ فَقَالَ ‏"‏ مَنْ هَذِهِ ‏"‏ ‏.‏ قُلْتُ أُمُّ هَانِئٍ بِنْتُ أَبِي طَالِبٍ ‏.‏ قَالَ ‏"‏ مَرْحَبًا بِأُمِّ هَانِئٍ ‏"‏ ‏.‏ فَلَمَّا فَرَغَ مِنْ غُسْلِهِ قَامَ فَصَلَّى ثَمَانِيَ رَكَعَاتٍ مُلْتَحِفًا فِي ثَوْبٍ وَاحِدٍ ‏.‏ فَلَمَّا انْصَرَفَ قُلْتُ يَا رَسُولَ اللَّهِ زَعَمَ ابْنُ أُمِّي عَلِيُّ بْنُ أَبِي طَالِبٍ أَنَّهُ قَاتِلٌ رَجُلاً أَجَرْتُهُ فُلاَنُ بْنُ هُبَيْرَةَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ أَجَرْنَا مَنْ أَجَرْتِ يَا أُمَّ هَانِئٍ ‏"‏ ‏.‏ قَالَتْ أُمُّ هَانِئٍ وَذَلِكَ ضُحًى ‏.‏\hadithno{1669}\hadithtrans{Abu Murra, the freed slave of Umm Hani, daughter of Abu Talib, reported Umm Hani to be saying:I went to the Messenger of Allah (ﷺ) on the day of the Conquest of Mecca and found him taking a bath, and Fatimah, his daughter, had provided him privacy with the help of a cloth. I gave him salutation and he said: Who is she? I said: It is Umm Hani, daughter of Abu Talib. He (the Holy Prophet) said: Greeting for Umm Hani. When he had completed the bath, he stood up and observed eight rak'ahs wrapped up in one cloth. When he turned back (after the prayer), I said to him: Messenger of Allah, the son of my mother 'Ali b. Abu Talib is going to kill a person, Fulan b. Hubaira whom I have given protection. Upon this the Messenger of Allah (ﷺ) said: We too have given protection whom you have given protection, O Umm Hani. Umm Hani said: It was the forenoon (prayer)}}
\hadithdefcmd{muslim}{1670}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبُ بْنُ خَالِدٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ أَبِي مُرَّةَ، مَوْلَى عَقِيلٍ عَنْ أُمِّ هَانِئٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى فِي بَيْتِهَا عَامَ الْفَتْحِ ثَمَانِيَ رَكَعَاتٍ فِي ثَوْبٍ وَاحِدٍ قَدْ خَالَفَ بَيْنَ طَرَفَيْهِ ‏.‏\hadithno{1670}\hadithtrans{Abu Murra narrated on the authority of Umm Hani that the Messenger of Allah (ﷺ) on the day of the Conquest of Mecca observed in her house eight rak'ahs of prayer in one cloth, its opposite corners having been tied from the opposite sides}}
\hadithdefcmd{muslim}{1671}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ أَسْمَاءَ الضُّبَعِيُّ، حَدَّثَنَا مَهْدِيٌّ، - وَهُوَ ابْنُ مَيْمُونٍ - حَدَّثَنَا وَاصِلٌ، مَوْلَى أَبِي عُيَيْنَةَ عَنْ يَحْيَى بْنِ عُقَيْلٍ، عَنْ يَحْيَى بْنِ يَعْمَرَ، عَنْ أَبِي الأَسْوَدِ الدُّؤَلِيِّ، عَنْ أَبِي ذَرٍّ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ يُصْبِحُ عَلَى كُلِّ سُلاَمَى مِنْ أَحَدِكُمْ صَدَقَةٌ فَكُلُّ تَسْبِيحَةٍ صَدَقَةٌ وَكُلُّ تَحْمِيدَةٍ صَدَقَةٌ وَكُلُّ تَهْلِيلَةٍ صَدَقَةٌ وَكُلُّ تَكْبِيرَةٍ صَدَقَةٌ وَأَمْرٌ بِالْمَعْرُوفِ صَدَقَةٌ وَنَهْىٌ عَنِ الْمُنْكَرِ صَدَقَةٌ وَيُجْزِئُ مِنْ ذَلِكَ رَكْعَتَانِ يَرْكَعُهُمَا مِنَ الضُّحَى ‏"‏ ‏.‏\hadithno{1671}\hadithtrans{Abu Dharr reported Allah's Apostle (ﷺ) as saying:In the morning charity is due from every bone in the body of every one of you. Every utterance of Allah's glorification is an act of charity. Every utterance of praise of Him is an act of charity, every utterance of profession of His Oneness is an act of charity, every utterance of profession of His Greatness is an act of charity, enjoining good is an act of charity, forbidding what is distreputable is an act of charity, and two rak'ahs which one prays in the forenoon will suffice}}
\hadithdefcmd{muslim}{1672}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا أَبُو التَّيَّاحِ، حَدَّثَنِي أَبُو عُثْمَانَ النَّهْدِيُّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَوْصَانِي خَلِيلِي صلى الله عليه وسلم بِثَلاَثٍ بِصِيَامِ ثَلاَثَةِ أَيَّامٍ مِنْ كُلِّ شَهْرٍ وَرَكْعَتَىِ الضُّحَى وَأَنْ أُوتِرَ قَبْلَ أَنْ أَرْقُدَ ‏.‏\hadithno{1672}\hadithtrans{Abu Huraira reported. My friend (the Holy Prophet, may peace be upon him) has instructed me to do three things:three fasts during every month, two rak'ahs of the forenoon prayer, and observing Witr prayer before going to bed}}
\hadithdefcmd{muslim}{1673}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبَّاسٍ الْجُرَيْرِيِّ، وَأَبِي، شِمْرٍ الضُّبَعِيِّ قَالاَ سَمِعْنَا أَبَا عُثْمَانَ النَّهْدِيَّ، يُحَدِّثُ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{1673}\hadithtrans{A hadith like this has been narrated by Abu Huraira by another chain of transmitters}}
\hadithdefcmd{muslim}{1674}{وَحَدَّثَنِي سُلَيْمَانُ بْنُ مَعْبَدٍ، حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُخْتَارٍ، عَنْ عَبْدِ اللَّهِ الدَّانَاجِ، قَالَ حَدَّثَنِي أَبُو رَافِعٍ الصَّائِغُ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، قَالَ أَوْصَانِي خَلِيلِي أَبُو الْقَاسِمِ صلى الله عليه وسلم بِثَلاَثٍ ‏.‏ فَذَكَرَ مِثْلَ حَدِيثِ أَبِي عُثْمَانَ عَنْ أَبِي هُرَيْرَةَ ‏.‏\hadithno{1674}\hadithtrans{Abu Huraira reported:My friend Abu'l-Qasim (ﷺ) instructed me to do three things, and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{1675}{وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالاَ حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ الضَّحَّاكِ بْنِ عُثْمَانَ، عَنْ إِبْرَاهِيمَ بْنِ عَبْدِ اللَّهِ بْنِ حُنَيْنٍ، عَنْ أَبِي مُرَّةَ، مَوْلَى أُمِّ هَانِئٍ عَنْ أَبِي الدَّرْدَاءِ، قَالَ أَوْصَانِي حَبِيبِي صلى الله عليه وسلم بِثَلاَثٍ لَنْ أَدَعَهُنَّ مَا عِشْتُ بِصِيَامِ ثَلاَثَةِ أَيَّامٍ مِنْ كُلِّ شَهْرٍ وَصَلاَةِ الضُّحَى وَبِأَنْ لاَ أَنَامَ حَتَّى أُوتِرَ ‏.‏\hadithno{1675}\hadithtrans{Abu Murra, the freed slave of Umm Hani, narrated on the authority of Abu Darda':My Friend (ﷺ) instructed me in three (acts), and I would never abandon them as long as I live. (And these three things are): Three fasts during every month, the forenoon prayer, and this that I should not sleep till I have observed the Witr prayer}}
\hadithdefcmd{muslim}{1676}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ حَفْصَةَ أُمَّ الْمُؤْمِنِينَ، أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا سَكَتَ الْمُؤَذِّنُ مِنَ الأَذَانِ لِصَلاَةِ الصُّبْحِ وَبَدَا الصُّبْحُ رَكَعَ رَكْعَتَيْنِ خَفِيفَتَيْنِ قَبْلَ أَنْ تُقَامَ الصَّلاَةُ ‏.‏\hadithno{1676}\hadithtrans{Ibn 'Umar reported that Hafsa, the Mother of the Believers, informed him that when the Mu'adhdhin became silent after calling (people) to the dawn prayer, the Messenger of Allah (ﷺ) commenced the dawn (prayer) when it dawned by observing two short rak'ahs before the commencement of the (Fard) prayer}}
\hadithdefcmd{muslim}{1677}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ، وَابْنُ، رُمْحٍ عَنِ اللَّيْثِ بْنِ سَعْدٍ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، كُلُّهُمْ عَنْ نَافِعٍ، بِهَذَا الإِسْنَادِ كَمَا قَالَ مَالِكٌ ‏.‏\hadithno{1677}\hadithtrans{This hadith has been transmitted by Nafi' with the same chain of narrators}}
\hadithdefcmd{muslim}{1678}{وَحَدَّثَنِي أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ الْحَكَمِ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ زَيْدِ بْنِ مُحَمَّدٍ، قَالَ سَمِعْتُ نَافِعًا، يُحَدِّثُ عَنِ ابْنِ عُمَرَ، عَنْ حَفْصَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا طَلَعَ الْفَجْرُ لاَ يُصَلِّي إِلاَّ رَكْعَتَيْنِ خَفِيفَتَيْنِ ‏.‏\hadithno{1678}\hadithtrans{Hafsa reported that when it was dawn, the Messenger of Allah (ﷺ) did not observe (any other prayers) but two short rak'ahs}}
\hadithdefcmd{muslim}{1679}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا النَّضْرُ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{1679}\hadithtrans{A hadith like this has been narrated by Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{1680}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَخْبَرَتْنِي حَفْصَةُ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَضَاءَ لَهُ الْفَجْرُ صَلَّى رَكْعَتَيْنِ ‏.‏\hadithno{1680}\hadithtrans{Hafsa reported:When the dawn appeared, the Messenger of Allah (ﷺ) observed two rak'ahs (of Sunnah prayers)}}
\hadithdefcmd{muslim}{1681}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي رَكْعَتَىِ الْفَجْرِ إِذَا سَمِعَ الأَذَانَ وَيُخَفِّفُهُمَا ‏.‏\hadithno{1681}\hadithtrans{A'isha reported: The Messenger of Allah (ﷺ) used to observe two rak'ahs of Sunnah (prayer) when he heard the Adhin and shortened them}}
\hadithdefcmd{muslim}{1682}{وَحَدَّثَنِيهِ عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا عَلِيٌّ يَعْنِي ابْنَ مُسْهِرٍ، ح وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَاهُ أَبُو بَكْرٍ، وَأَبُو كُرَيْبٍ وَابْنُ نُمَيْرٍ عَنْ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، ح وَحَدَّثَنَاهُ عَمْرٌو النَّاقِدُ، حَدَّثَنَا وَكِيعٌ، كُلُّهُمْ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ وَفِي حَدِيثِ أَبِي أُسَامَةَ إِذَا طَلَعَ الْفَجْرُ ‏.‏\hadithno{1682}\hadithtrans{This hadith has been narrated by the same chain of transmitters and in the hadith narrated by Usama the words are:" When it was dawn}}
\hadithdefcmd{muslim}{1683}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ هِشَامٍ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي رَكْعَتَيْنِ بَيْنَ النِّدَاءِ وَالإِقَامَةِ مِنْ صَلاَةِ الصُّبْحِ ‏.‏\hadithno{1683}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) used to observe two (supererogatory) rak'ahs in between the call to prayer and the Iqama of the dawn prayer}}
\hadithdefcmd{muslim}{1684}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، قَالَ سَمِعْتُ يَحْيَى بْنَ سَعِيدٍ، قَالَ أَخْبَرَنِي مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ عَمْرَةَ، تُحَدِّثُ عَنْ عَائِشَةَ، أَنَّهَا كَانَتْ تَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي رَكْعَتَىِ الْفَجْرِ فَيُخَفِّفُ حَتَّى إِنِّي أَقُولُ هَلْ قَرَأَ فِيهِمَا بِأُمِّ الْقُرْآنِ ‏.‏\hadithno{1684}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) observed two rak'ahs of the dawn prayer and he shortened them (to the extent) that I (out of surprise) said:Did he recite in them Surah Fatiha (only)?}}
\hadithdefcmd{muslim}{1685}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ الأَنْصَارِيِّ، سَمِعَ عَمْرَةَ بِنْتَ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا طَلَعَ الْفَجْرُ صَلَّى رَكْعَتَيْنِ أَقُولُ هَلْ يَقْرَأُ فِيهِمَا بِفَاتِحَةِ الْكِتَابِ ‏.‏\hadithno{1685}\hadithtrans{A'isha reported:When it was dawn, the Messenger of Allah (ﷺ) observed two rak'ahs, and I would say: Does he recite only the opening chapter of the Qur'an in it?}}
\hadithdefcmd{muslim}{1686}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنِ ابْنِ جُرَيْجٍ، قَالَ حَدَّثَنِي عَطَاءٌ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَكُنْ عَلَى شَىْءٍ مِنَ النَّوَافِلِ أَشَدَّ مُعَاهَدَةً مِنْهُ عَلَى رَكْعَتَيْنِ قَبْلَ الصُّبْحِ ‏.‏\hadithno{1686}\hadithtrans{A'isha reported that the Apostle (ﷺ) was not so much particular about observing supererogatory rak'ahs as in case of the two rak'ahs of the dawn prayer}}
\hadithdefcmd{muslim}{1687}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ جَمِيعًا عَنْ حَفْصِ بْنِ غِيَاثٍ، - قَالَ ابْنُ نُمَيْرٍ حَدَّثَنَا حَفْصٌ، - عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، عَنْ عُبَيْدِ بْنِ عُمَيْرٍ، عَنْ عَائِشَةَ، قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فِي شَىْءٍ مِنَ النَّوَافِلِ أَسْرَعَ مِنْهُ إِلَى الرَّكْعَتَيْنِ قَبْلَ الْفَجْرِ ‏.‏\hadithno{1687}\hadithtrans{A'isha reported:I have never seen the Messenger of Allah (ﷺ) hastening as much in observing supererogatory as two rak'ahs before the (Fard) of the dawn prayer}}
\hadithdefcmd{muslim}{1688}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْغُبَرِيُّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ رَكْعَتَا الْفَجْرِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏\hadithno{1688}\hadithtrans{A'isha reported Allah's Messenger as saying:The two rak'ahs at dawn are better than this world and what it contains}}
\hadithdefcmd{muslim}{1689}{وَحَدَّثَنَا يَحْيَى بْنُ حَبِيْبٍ، حَدَّثَنَا مُعْتَمِرٌ، قَالَ قَالَ أَبِي حَدَّثَنَا قَتَادَةُ، عَنْ زُرَارَةَ، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ فِي شَأْنِ الرَّكْعَتَيْنِ عِنْدَ طُلُوعِ الْفَجْرِ ‏ "‏ لَهُمَا أَحَبُّ إِلَىَّ مِنَ الدُّنْيَا جَمِيعًا ‏"‏ ‏.‏\hadithno{1689}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) said about the two (supererogatory) rak'ahs of the dawn:They are dearer to me than the whole world}}
\hadithdefcmd{muslim}{1690}{حَدَّثَنِي مُحَمَّدُ بْنُ عَبَّادٍ، وَابْنُ أَبِي عُمَرَ، قَالاَ حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، عَنْ يَزِيدَ، - هُوَ ابْنُ كَيْسَانَ - عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَرَأَ فِي رَكْعَتَىِ الْفَجْرِ ‏\{‏ قُلْ يَا أَيُّهَا الْكَافِرُونَ‏\}‏ وَ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏\hadithno{1690}\hadithtrans{Abu Huraira reported that the Messenger of Allah (ﷺ) recited in the two (supererogatory) rak'ahs of the dawn (prayer):" Say: O unbelievers," (Qur'an, cix.) and" Say: Allah is one" (cxii)}}
\hadithdefcmd{muslim}{1691}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْفَزَارِيُّ، - يَعْنِي مَرْوَانَ بْنَ مُعَاوِيَةَ - عَنْ عُثْمَانَ بْنِ حَكِيمٍ الأَنْصَارِيِّ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ يَسَارٍ، أَنَّ ابْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقْرَأُ فِي رَكْعَتَىِ الْفَجْرِ فِي الأُولَى مِنْهُمَا ‏\{‏ قُولُوا آمَنَّا بِاللَّهِ وَمَا أُنْزِلَ إِلَيْنَا‏\}‏ الآيَةَ الَّتِي فِي الْبَقَرَةِ وَفِي الآخِرَةِ مِنْهُمَا ‏\{‏ آمَنَّا بِاللَّهِ وَاشْهَدْ بِأَنَّا مُسْلِمُونَ‏\}‏\hadithno{1691}\hadithtrans{Ibn 'Abbas reported that the Messenger of Allah (ﷺ) used to recite in first of the two (supererogatory) rak'ahs of the dawn:"Say: We believed in Allah and what was revealed to us..." verse 136 from Surah Baqara, and in the second of the two: "I believe in Allah and I bear testimony that we are Muslims" (iii)}}
\hadithdefcmd{muslim}{1692}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ عُثْمَانَ بْنِ حَكِيمٍ، عَنْ سَعِيدِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي رَكْعَتَىِ الْفَجْرِ ‏\{‏ قُولُوا آمَنَّا بِاللَّهِ وَمَا أُنْزِلَ إِلَيْنَا‏\}‏ وَالَّتِي فِي آلِ عِمْرَانَ ‏\{‏ تَعَالَوْا إِلَى كَلِمَةٍ سَوَاءٍ بَيْنَنَا وَبَيْنَكُمْ‏\}‏\hadithno{1692}\hadithtrans{Ibn 'Abbas reported that the Messenger of Allah (ﷺ) used to recite in the two (supererogatory) rak'ahs of the dawn prayer:" Say: We believed in Allah and what was revealed to us" and that which is found in Surah Al-i-'lmran:" Come to that word (creed) which is common between you and us" (iii)}}
\hadithdefcmd{muslim}{1693}{وَحَدَّثَنِي عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، عَنْ عُثْمَانَ بْنِ حَكِيمٍ، فِي هَذَا الإِسْنَادِ ‏.‏ بِمِثْلِ حَدِيثِ مَرْوَانَ الْفَزَارِيِّ ‏.‏\hadithno{1693}\hadithtrans{This hadith has been transmitted by another chain of narrators}}
\hadithdefcmd{muslim}{1694}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو خَالِدٍ، - يَعْنِي سُلَيْمَانَ بْنَ حَيَّانَ - عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنِ النُّعْمَانِ بْنِ سَالِمٍ، عَنْ عَمْرِو بْنِ أَوْسٍ، قَالَ حَدَّثَنِي عَنْبَسَةُ بْنُ أَبِي سُفْيَانَ، فِي مَرَضِهِ الَّذِي مَاتَ فِيهِ بِحَدِيثٍ يُتَسَارُّ إِلَيْهِ قَالَ سَمِعْتُ أُمَّ حَبِيبَةَ تَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ صَلَّى اثْنَتَىْ عَشْرَةَ رَكْعَةً فِي يَوْمٍ وَلَيْلَةٍ بُنِيَ لَهُ بِهِنَّ بَيْتٌ فِي الْجَنَّةِ ‏"‏ ‏.‏ قَالَتْ أُمُّ حَبِيبَةَ فَمَا تَرَكْتُهُنَّ مُنْذُ سَمِعْتُهُنَّ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ وَقَالَ عَنْبَسَةُ فَمَا تَرَكْتُهُنَّ مُنْذُ سَمِعْتُهُنَّ مِنْ أُمِّ حَبِيبَةَ ‏.‏ وَقَالَ عَمْرُو بْنُ أَوْسٍ مَا تَرَكْتُهُنَّ مُنْذُ سَمِعْتُهُنَّ مِنْ عَنْبَسَةَ ‏.‏ وَقَالَ النُّعْمَانُ بْنُ سَالِمٍ مَا تَرَكْتُهُنَّ مُنْذُ سَمِعْتُهُنَّ مِنْ عَمْرِو بْنِ أَوْسٍ ‏.‏\hadithno{1694}\hadithtrans{Umm Habiba (the wife of the Holy Prophet) reported Allah's Messenger (ﷺ) as saying:A house will be built in Paradise, for anyone who prays in a day and a night twelve rak'ahs; and she added: I have never abandoned (observing them) since I heard it from the Messenger of Allah (ﷺ). Some of the other narrators said the same words: I have never abandoned (observing them) since I heard (from so and so)}}
\hadithdefcmd{muslim}{1695}{حَدَّثَنِي أَبُو غَسَّانَ الْمِسْمَعِيُّ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، حَدَّثَنَا دَاوُدُ، عَنِ النُّعْمَانِ بْنِ سَالِمٍ، بِهَذَا الإِسْنَادِ ‏ "‏ مَنْ صَلَّى فِي يَوْمٍ ثِنْتَىْ عَشْرَةَ سَجْدَةً تَطَوُّعًا بُنِيَ لَهُ بَيْتٌ فِي الْجَنَّةِ ‏"‏ ‏.‏\hadithno{1695}\hadithtrans{Nu'man b. Salim reported with the same chain of transmitters:He who observed twelve voluntary rak'ahs, a house will be built for him in Paradise}}
\hadithdefcmd{muslim}{1696}{وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ النُّعْمَانِ بْنِ سَالِمٍ، عَنْ عَمْرِو بْنِ أَوْسٍ، عَنْ عَنْبَسَةَ بْنِ أَبِي سُفْيَانَ، عَنْ أُمِّ حَبِيبَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ عَبْدٍ مُسْلِمٍ يُصَلِّي لِلَّهِ كُلَّ يَوْمٍ ثِنْتَىْ عَشْرَةَ رَكْعَةً تَطَوُّعًا غَيْرَ فَرِيضَةٍ إِلاَّ بَنَى اللَّهُ لَهُ بَيْتًا فِي الْجَنَّةِ أَوْ إِلاَّ بُنِيَ لَهُ بَيْتٌ فِي الْجَنَّةِ ‏"‏ ‏.‏ قَالَتْ أُمُّ حَبِيبَةَ فَمَا بَرِحْتُ أُصَلِّيهِنَّ بَعْدُ ‏.‏ وَقَالَ عَمْرٌو مَا بَرِحْتُ أُصَلِّيهِنَّ بَعْدُ ‏.‏ وَقَالَ النُّعْمَانُ مِثْلَ ذَلِكَ ‏.‏\hadithno{1696}\hadithtrans{Umm Habiba, the wife of the Messenger of Allah (ﷺ), reported Allah's Messenger (ﷺ) as saying:If any Muslim servant (of Allah) prays for the sake of Allah twelve rak'ahs (of Sunan) every day, over and above the obligatory ones, Allah will build for him a house in Paradise, or a house will be built for him in Paradise; and I have not abandoned observing them after (hearing it from the Messenger of Allah). (So said also 'Amr and Nu'man)}}
\hadithdefcmd{muslim}{1697}{وَحَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ بِشْرٍ، وَعَبْدُ اللَّهِ بْنُ هَاشِمٍ الْعَبْدِيُّ، قَالاَ حَدَّثَنَا بَهْزٌ، حَدَّثَنَا شُعْبَةُ، قَالَ النُّعْمَانُ بْنُ سَالِمٍ أَخْبَرَنِي قَالَ سَمِعْتُ عَمْرَو بْنَ أَوْسٍ، يُحَدِّثُ عَنْ عَنْبَسَةَ، عَنْ أُمِّ حَبِيبَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ عَبْدٍ مُسْلِمٍ تَوَضَّأَ فَأَسْبَغَ الْوُضُوءَ ثُمَّ صَلَّى لِلَّهِ كُلَّ يَوْمٍ ‏"‏ ‏.‏ فَذَكَرَ بِمِثْلِهِ ‏.‏\hadithno{1697}\hadithtrans{Umm Habiba reported the Messenger of Allah (ﷺ) having said:If any Muslim servant (of Allah) performed ablution, and performed it well, and then observed every day, the rest of the hadith is the same}}
\hadithdefcmd{muslim}{1698}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَحْيَى، - وَهُوَ ابْنُ سَعِيدٍ - عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَبْلَ الظُّهْرِ سَجْدَتَيْنِ وَبَعْدَهَا سَجْدَتَيْنِ وَبَعْدَ الْمَغْرِبِ سَجْدَتَيْنِ وَبَعْدَ الْعِشَاءِ سَجْدَتَيْنِ وَبَعْدَ الْجُمُعَةِ سَجْدَتَيْنِ فَأَمَّا الْمَغْرِبُ وَالْعِشَاءُ وَالْجُمُعَةُ فَصَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم فِي بَيْتِهِ ‏.‏\hadithno{1698}\hadithtrans{Ibn 'Umar reported:I prayed along with Allah's Messenger (ﷺ) two rak'ahs before and two rak'ahs after the noon prayer, two rak'ahs after the sunset prayer and two rak'ahs after the 'Isha' prayer and two rak'ahs after the Friday prayer; and so far as the sunset, 'Isha' and Friday prayers are concerned, I observed (them) along with the Messenger of Allah (ﷺ) in his house}}
\hadithdefcmd{muslim}{1699}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا هُشَيْمٌ، عَنْ خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم عَنْ تَطَوُّعِهِ فَقَالَتْ كَانَ يُصَلِّي فِي بَيْتِي قَبْلَ الظُّهْرِ أَرْبَعًا ثُمَّ يَخْرُجُ فَيُصَلِّي بِالنَّاسِ ثُمَّ يَدْخُلُ فَيُصَلِّي رَكْعَتَيْنِ وَكَانَ يُصَلِّي بِالنَّاسِ الْمَغْرِبَ ثُمَّ يَدْخُلُ فَيُصَلِّي رَكْعَتَيْنِ وَيُصَلِّي بِالنَّاسِ الْعِشَاءَ وَيَدْخُلُ بَيْتِي فَيُصَلِّي رَكْعَتَيْنِ وَكَانَ يُصَلِّي مِنَ اللَّيْلِ تِسْعَ رَكَعَاتٍ فِيهِنَّ الْوِتْرُ وَكَانَ يُصَلِّي لَيْلاً طَوِيلاً قَائِمًا وَلَيْلاً طَوِيلاً قَاعِدًا وَكَانَ إِذَا قَرَأَ وَهُوَ قَائِمٌ رَكَعَ وَسَجَدَ وَهُوَ قَائِمٌ وَإِذَا قَرَأَ قَاعِدًا رَكَعَ وَسَجَدَ وَهُوَ قَاعِدٌ وَكَانَ إِذَا طَلَعَ الْفَجْرُ صَلَّى رَكْعَتَيْنِ ‏.‏\hadithno{1699}\hadithtrans{Abdullah b. Shaqiq said:I asked 'A'isha about the Messenger of Allah's (ﷺ) voluntary prayers, and she replied: Before the noon prayer, he used to pray four rak'ahs in my house; then would go out and lead the people in prayer; then come in and pray two rak'ahs. He would then lead the people in the sunset prayer; then come in and pray two rak'ahs. Then he would lead the people in the 'Isha' prayer, and enter my house and pray two rak'ahs. He would pray nine rak'ahs during the night, including Witr. At night he would pray for a long time standing and for a long time sitting, and when he recited the Holy Qur'an while standing, he would bow and prostrate himself from the standing position, and when he recited while sitting, he would bow and prostrate himself from the sitting position, and when it was dawn he would pray two rak'ahs}}
\hadithdefcmd{muslim}{1700}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا حَمَّادٌ، عَنْ بُدَيْلٍ، وَأَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي لَيْلاً طَوِيلاً فَإِذَا صَلَّى قَائِمًا رَكَعَ قَائِمًا وَإِذَا صَلَّى قَاعِدًا رَكَعَ قَاعِدًا ‏.‏\hadithno{1700}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) would pray in the night for a long time, and when he prayed standing be bowed in a standing posture, and when he prayed sitting, he bowed in a sitting posture}}
\hadithdefcmd{muslim}{1701}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ بُدَيْلٍ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ كُنْتُ شَاكِيًا بِفَارِسَ فَكُنْتُ أُصَلِّي قَاعِدًا فَسَأَلْتُ عَنْ ذَلِكَ عَائِشَةَ فَقَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي لَيْلاً طَوِيلاً قَائِمًا ‏.‏ فَذَكَرَ الْحَدِيثَ ‏.‏\hadithno{1701}\hadithtrans{Abdullah b. Shaqiq reported:I fell ill in Persia and therefore, prayed in a sitting posture, and I asked 'A'isha about it and she said: The Messenger of Allah (ﷺ) prayed for a long time in the night sitting}}
\hadithdefcmd{muslim}{1702}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، عَنْ حُمَيْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ الْعُقَيْلِيِّ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم بِاللَّيْلِ فَقَالَتْ كَانَ يُصَلِّي لَيْلاً طَوِيلاً قَائِمًا وَلَيْلاً طَوِيلاً قَاعِدًا وَكَانَ إِذَا قَرَأَ قَائِمًا رَكَعَ قَائِمًا وَإِذَا قَرَأَ قَاعِدًا رَكَعَ قَاعِدًا ‏.‏\hadithno{1702}\hadithtrans{Abdullah b. Shaqiq al-'Uqaili reported:I asked 'A'isha about the prayer of the Messenger of Allah (ﷺ) during the night (i. e. Tahajjud prayer) She replied: He used to pray for a long time standing and for a long time sitting in the night, and when he recited the Qur'an while standing, he would bow himself from the standing position, and when he recited while sitting, he would bow from the sitting position}}
\hadithdefcmd{muslim}{1703}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ هِشَامِ بْنِ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ الْعُقَيْلِيِّ، قَالَ سَأَلْنَا عَائِشَةَ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُكْثِرُ الصَّلاَةَ قَائِمًا وَقَاعِدًا فَإِذَا افْتَتَحَ الصَّلاَةَ قَائِمًا رَكَعَ قَائِمًا وَإِذَا افْتَتَحَ الصَّلاَةَ قَاعِدًا رَكَعَ قَاعِدًا ‏.‏\hadithno{1703}\hadithtrans{Abdullah b. Shaqiq al-'Uqaili reported:I asked 'A'isha about the prayer of the Messenger of Allah (ﷺ). She said: The Messenger of Allah (ﷺ) would observe prayer (Nafl) in a standing position as well as in a sitting position, and when he commenced the prayer in a standing position, he bowed in this very position, and when he commenced the prayer in a sitting position, he bowed in this very position}}
\hadithdefcmd{muslim}{1704}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، أَخْبَرَنَا حَمَّادٌ يَعْنِي ابْنَ زَيْدٍ، ح قَالَ وَحَدَّثَنَا حَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ نُمَيْرٍ، جَمِيعًا عَنْ هِشَامِ بْنِ عُرْوَةَ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لَهُ - قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ، قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَأُ فِي شَىْءٍ مِنْ صَلاَةِ اللَّيْلِ جَالِسًا حَتَّى إِذَا كَبِرَ قَرَأَ جَالِسًا حَتَّى إِذَا بَقِيَ عَلَيْهِ مِنَ السُّورَةِ ثَلاَثُونَ أَوْ أَرْبَعُونَ آيَةً قَامَ فَقَرَأَهُنَّ ثُمَّ رَكَعَ ‏.‏\hadithno{1704}\hadithtrans{A'isha reported:I did not see the Messenger of Allah (ﷺ) reciting (the Qur'an) in the night prayer in a sitting position, till he grew old and then he recited (it) in a sitting position, but when thirty or forty verses were left out of the Surah, he would then stand up, recite them and then bowed}}
\hadithdefcmd{muslim}{1705}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، وَأَبِي النَّضْرِ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي جَالِسًا فَيَقْرَأُ وَهُوَ جَالِسٌ فَإِذَا بَقِيَ مِنْ قِرَاءَتِهِ قَدْرُ مَا يَكُونُ ثَلاَثِينَ أَوْ أَرْبَعِينَ آيَةً قَامَ فَقَرَأَ وَهُوَ قَائِمٌ ثُمَّ رَكَعَ ثُمَّ سَجَدَ ثُمَّ يَفْعَلُ فِي الرَّكْعَةِ الثَّانِيَةِ مِثْلَ ذَلِكَ ‏.‏\hadithno{1705}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) used to pray while sitting (when he grew old) and he recited in this position and when the recitation equal to thirty or forty verses was left, he would then stand up and recite (for this duration) in a standing position and then bowed himself and then prostrated himself and did the same in the second rak'ah}}
\hadithdefcmd{muslim}{1706}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ أَبُو بَكْرٍ حَدَّثَنَا إِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنِ الْوَلِيدِ بْنِ أَبِي هِشَامٍ، عَنْ أَبِي بَكْرِ بْنِ مُحَمَّدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ وَهُوَ قَاعِدٌ فَإِذَا أَرَادَ أَنْ يَرْكَعَ قَامَ قَدْرَ مَا يَقْرَأُ إِنْسَانٌ أَرْبَعِينَ آيَةً ‏.‏\hadithno{1706}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) used to recite in sitting position (while observing the Tahajjud prayer) and when he intended to bow, he would stand up and recite (for the duration in which) a man (ordinarily) recites forty verses}}
\hadithdefcmd{muslim}{1707}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، حَدَّثَنِي مُحَمَّدُ بْنُ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ بْنِ وَقَّاصٍ، قَالَ قُلْتُ لِعَائِشَةَ كَيْفَ كَانَ يَصْنَعُ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الرَّكْعَتَيْنِ وَهُوَ جَالِسٌ قَالَتْ كَانَ يَقْرَأُ فِيهِمَا فَإِذَا أَرَادَ أَنْ يَرْكَعَ قَامَ فَرَكَعَ ‏.‏\hadithno{1707}\hadithtrans{Alqama b. Waqqas reported:I asked 'A'isha how the Messenger of Allah (ﷺ) did in the two rak'ahs as he (observed them) sitting. She said: He would recite (the Qur'an) in them, and when he intended to bow, he would stand up and then bowed}}
\hadithdefcmd{muslim}{1708}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ قُلْتُ لِعَائِشَةَ هَلْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي وَهُوَ قَاعِدٌ قَالَتْ نَعَمْ بَعْدَ مَا حَطَمَهُ النَّاسُ ‏.‏\hadithno{1708}\hadithtrans{Abdullah b. Shaqiq reported:I asked 'A'isha whether the Messenger of Allah (ﷺ) observed (Nafl) sitting. She said: Yes, when the people had made him old}}
\hadithdefcmd{muslim}{1709}{وَحَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا كَهْمَسٌ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، قَالَ قُلْتُ لِعَائِشَةَ ‏.‏ فَذَكَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِمِثْلِهِ ‏.‏\hadithno{1709}\hadithtrans{Abdullah b. Shaqiq reported:I said to 'A'isha and she made a mention of that (recorded above) about the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1710}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي عُثْمَانُ بْنُ أَبِي سُلَيْمَانَ، أَنَّ أَبَا سَلَمَةَ بْنَ عَبْدِ الرَّحْمَنِ، أَخْبَرَهُ أَنَّ عَائِشَةَ أَخْبَرَتْهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَمُتْ حَتَّى كَانَ كَثِيرٌ مِنْ صَلاَتِهِ وَهُوَ جَالِسٌ ‏.‏\hadithno{1710}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) died (in this very state) that he observed most of his (Nafl) prayers in a sitting position}}
\hadithdefcmd{muslim}{1711}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَحَسَنٌ الْحُلْوَانِيُّ، كِلاَهُمَا عَنْ زَيْدٍ، قَالَ حَسَنٌ حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، حَدَّثَنِي الضَّحَّاكُ بْنُ عُثْمَانَ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا بَدَّنَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَثَقُلَ كَانَ أَكْثَرُ صَلاَتِهِ جَالِسًا ‏.‏\hadithno{1711}\hadithtrans{A'isha reported:When the Messenger of Allah (ﷺ) grew bulky and heavy he would observe (most of his Nafl) prayers sitting}}
\hadithdefcmd{muslim}{1712}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنِ السَّائِبِ بْنِ يَزِيدَ، عَنِ الْمُطَّلِبِ بْنِ أَبِي وَدَاعَةَ السَّهْمِيِّ، عَنْ حَفْصَةَ، أَنَّهَا قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى فِي سُبْحَتِهِ قَاعِدًا حَتَّى كَانَ قَبْلَ وَفَاتِهِ بِعَامٍ فَكَانَ يُصَلِّي فِي سُبْحَتِهِ قَاعِدًا وَكَانَ يَقْرَأُ بِالسُّورَةِ فَيُرَتِّلُهَا حَتَّى تَكُونَ أَطْوَلَ مِنْ أَطْوَلَ مِنْهَا ‏.‏\hadithno{1712}\hadithtrans{Hafsa reported:Never did I see the Messenger of Allah (ﷺ) observing supererogatory prayer sitting till one year before his death when he would observe Nafl prayer in a sitting position, and he would recite the Surah (of the Qur'an) in such a slow-measured tone (that duration of its recital) became more lengthy than the one longer than this}}
\hadithdefcmd{muslim}{1713}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، جَمِيعًا عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّهُمَا قَالاَ بِعَامٍ وَاحِدٍ أَوِ اثْنَيْنِ ‏.‏\hadithno{1713}\hadithtrans{Zuhri reported this hadith with the same chain of transmitters, except this that he made a mention of one year or two years}}
\hadithdefcmd{muslim}{1714}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ حَسَنِ بْنِ صَالِحٍ، عَنْ سِمَاكٍ، قَالَ أَخْبَرَنِي جَابِرُ بْنُ سَمُرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم لَمْ يَمُتْ حَتَّى صَلَّى قَاعِدًا ‏.‏\hadithno{1714}\hadithtrans{Jabir b. Samura reported that the Messenger of Allah (ﷺ) observed (Nafl) prayer sitting before his death}}
\hadithdefcmd{muslim}{1715}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ هِلاَلِ بْنِ يَسَافٍ، عَنْ أَبِي يَحْيَى، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ حُدِّثْتُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ صَلاَةُ الرَّجُلِ قَاعِدًا نِصْفُ الصَّلاَةِ ‏"‏ ‏.‏ قَالَ فَأَتَيْتُهُ فَوَجَدْتُهُ يُصَلِّي جَالِسًا فَوَضَعْتُ يَدِي عَلَى رَأْسِهِ فَقَالَ مَا لَكَ يَا عَبْدَ اللَّهِ بْنَ عَمْرٍو قُلْتُ حُدِّثْتُ يَا رَسُولَ اللَّهِ أَنَّكَ قُلْتَ ‏"‏ صَلاَةُ الرَّجُلِ قَاعِدًا عَلَى نِصْفِ الصَّلاَةِ ‏"‏ ‏.‏ وَأَنْتَ تُصَلِّي قَاعِدًا قَالَ ‏"‏ أَجَلْ وَلَكِنِّي لَسْتُ كَأَحَدٍ مِنْكُمْ ‏"‏ ‏.‏\hadithno{1715}\hadithtrans{Abdullah b. 'Amr reported:It was narrated to me that the Messenger of Allah (ﷺ) had said: The prayer observed by a person sitting is half of the prayer. I came to him (ﷺ) and found him praying in a sitting position. I placed my hand on his head. He said: O 'Abdullah b. 'Amr, what is the matter with you? I said: Messenger of Allah, it has been narrated to me that you said: The prayer of a man in a sitting position is half of the prayer, whereas you are observing prayer sitting. He (the Holy Prophet) said: Yes, it is so, but I am not like anyone amongst you}}
\hadithdefcmd{muslim}{1716}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ جَمِيعًا عَنْ مُحَمَّدِ بْنِ جَعْفَرٍ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، كِلاَهُمَا عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ وَفِي رِوَايَةِ شُعْبَةَ عَنْ أَبِي يَحْيَى الأَعْرَجِ، ‏.‏\hadithno{1716}\hadithtrans{A hadith like this has been narrated by Abu Yahya al-A'raj with the same chain of transmitters}}
\hadithdefcmd{muslim}{1717}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي بِاللَّيْلِ إِحْدَى عَشْرَةَ رَكْعَةً يُوتِرُ مِنْهَا بِوَاحِدَةٍ فَإِذَا فَرَغَ مِنْهَا اضْطَجَعَ عَلَى شِقِّهِ الأَيْمَنِ حَتَّى يَأْتِيَهُ الْمُؤَذِّنُ فَيُصَلِّي رَكْعَتَيْنِ خَفِيفَتَيْنِ ‏.‏\hadithno{1717}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) used to pray eleven rak'ahs at night, observing the Witr with a single rak'ah, and when he had finished them, he lay down on his right side, till the Mu'adhdhin came to him and he (the Holy Prophet) then observed two short rak'ahs (of Sunan of the dawn prayer)}}
\hadithdefcmd{muslim}{1720}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ ثَلاَثَ عَشْرَةَ رَكْعَةً يُوتِرُ مِنْ ذَلِكَ بِخَمْسٍ لاَ يَجْلِسُ فِي شَىْءٍ إِلاَّ فِي آخِرِهَا ‏.‏\hadithno{1720}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) used to observe thirteen rak'ahs of the night prayer. Five out of them consisted of Witr, and he did not sit, but at the end (for salutation)}}
\hadithdefcmd{muslim}{1721}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، ح وَحَدَّثَنَاهُ أَبُو كُرَيْبٍ، حَدَّثَنَا وَكِيعٌ، وَأَبُو أُسَامَةَ كُلُّهُمْ عَنْ هِشَامٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{1721}\hadithtrans{This hadith has been narrated by Hisham with the same chain of transmitters}}
\hadithdefcmd{muslim}{1722}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عِرَاكِ بْنِ مَالِكٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي ثَلاَثَ عَشْرَةَ رَكْعَةً بِرَكْعَتَىِ الْفَجْرِ ‏.‏\hadithno{1722}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) used to pray thirteen rak'ahs during the night including the two rak'ahs (Sunan) of the dawn prayer}}
\hadithdefcmd{muslim}{1723}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَأَلَ عَائِشَةَ كَيْفَ كَانَتْ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَمَضَانَ قَالَتْ مَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَزِيدُ فِي رَمَضَانَ وَلاَ فِي غَيْرِهِ عَلَى إِحْدَى عَشْرَةَ رَكْعَةً يُصَلِّي أَرْبَعًا فَلاَ تَسْأَلْ عَنْ حُسْنِهِنَّ وَطُولِهِنَّ ثُمَّ يُصَلِّي أَرْبَعًا فَلاَ تَسْأَلْ عَنْ حُسْنِهِنَّ وَطُولِهِنَّ ثُمَّ يُصَلِّي ثَلاَثًا فَقَالَتْ عَائِشَةُ فَقُلْتُ يَا رَسُولَ اللَّهِ أَتَنَامُ قَبْلَ أَنْ تُوتِرَ فَقَالَ ‏ "‏ يَا عَائِشَةُ إِنَّ عَيْنَىَّ تَنَامَانِ وَلاَ يَنَامُ قَلْبِي ‏"‏ ‏.‏\hadithno{1723}\hadithtrans{Abu Salama b. Abd al-Rahman asked 'A'isha about the (night) prayer of the Messenger of Allah (ﷺ) during the month of Ramadan. She said:The Messenger of Allah (ﷺ) did not observe either in Ramadan or in other months more than eleven rak'ahs (of the night prayer). He (in the first instance) observed four rak'ahs. Ask not about their excellence and their length (i. e. these were matchless in perfection and length). He again observed four rak'ahs, and ask not about their excellence and their length. He would then observe three rak'ahs (of the Witr prayer). 'A'isha again said: I said: Messenger of Allah, do you sleep before observing the Witr prayer? He said: O 'A'isha, my eyes sleep but my heart does not sleep}}
\hadithdefcmd{muslim}{1724}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ كَانَ يُصَلِّي ثَلاَثَ عَشْرَةَ رَكْعَةً يُصَلِّي ثَمَانَ رَكَعَاتٍ ثُمَّ يُوتِرُ ثُمَّ يُصَلِّي رَكْعَتَيْنِ وَهُوَ جَالِسٌ فَإِذَا أَرَادَ أَنْ يَرْكَعَ قَامَ فَرَكَعَ ثُمَّ يُصَلِّي رَكْعَتَيْنِ بَيْنَ النِّدَاءِ وَالإِقَامَةِ مِنْ صَلاَةِ الصُّبْحِ ‏.‏\hadithno{1724}\hadithtrans{Abu Salama asked 'A'isha about the prayer of the Messenger of Allah (ﷺ) She said:He observed thirteen rak'ahs (in the night prayer). He observed eight rak'ahs and would then observe Witr and then observe two rak'ahs sitting, and when he wanted to bow he stood up and then bowed down, and then observed two rak'ahs in between the Adhan and lqama of the dawn prayer}}
\hadithdefcmd{muslim}{1725}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا حُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، قَالَ سَمِعْتُ أَبَا سَلَمَةَ، ح وَحَدَّثَنِي يَحْيَى بْنُ بِشْرٍ الْحَرِيرِيُّ، حَدَّثَنَا مُعَاوِيَةُ، - يَعْنِي ابْنَ سَلاَّمٍ - عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّهُ سَأَلَ عَائِشَةَ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ بِمِثْلِهِ غَيْرَ أَنَّ فِي حَدِيثِهِمَا تِسْعَ رَكَعَاتٍ قَائِمًا يُوتِرُ مِنْهُنَّ ‏.‏\hadithno{1725}\hadithtrans{Abu Salama reported that he asked 'A'isha about the prayer of the Messenger of Allah (may peace he upon him) (during the night). The rest of the hadith is the same but with this exception that he (the Holy Prophet) observed nine rak'ahs including Witr}}
\hadithdefcmd{muslim}{1726}{وَحَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي لَبِيدٍ، سَمِعَ أَبَا سَلَمَةَ، قَالَ أَتَيْتُ عَائِشَةَ فَقُلْتُ أَىْ أُمَّهْ أَخْبِرِينِي عَنْ صَلاَةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَتْ كَانَتْ صَلاَتُهُ فِي شَهْرِ رَمَضَانَ وَغَيْرِهِ ثَلاَثَ عَشْرَةَ رَكْعَةً بِاللَّيْلِ مِنْهَا رَكْعَتَا الْفَجْرِ ‏.‏\hadithno{1726}\hadithtrans{Abu Salama is reported to have said. I came to 'A'isha. I said:O mother, inform me about the prayer of the Messenger of Allah (ﷺ). She said: His (night prayer) in Ramadan and (during other months) was thirteen rak'ahs at night including two rak'ahs of fajr}}
\hadithdefcmd{muslim}{1727}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا حَنْظَلَةُ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، قَالَ سَمِعْتُ عَائِشَةَ، تَقُولُ كَانَتْ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ اللَّيْلِ عَشَرَ رَكَعَاتٍ وَيُوتِرُ بِسَجْدَةٍ وَيَرْكَعُ رَكْعَتَىِ الْفَجْرِ فَتِلْكَ ثَلاَثَ عَشْرَةَ رَكْعَةً ‏.‏\hadithno{1727}\hadithtrans{It is reported on the authority of 'A'isha that the prayer of Allah's Messenger (ﷺ) in the night consisted of ten rak'ahs. He observed a Witr and two rak'ahs (of Sunan) of the dawn prayer, and thus the total comes to thirteen rak'ahs}}
\hadithdefcmd{muslim}{1728}{وَحَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَأَلْتُ الأَسْوَدَ بْنَ يَزِيدَ عَمَّا حَدَّثَتْهُ عَائِشَةُ، عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ كَانَ يَنَامُ أَوَّلَ اللَّيْلِ وَيُحْيِي آخِرَهُ ثُمَّ إِنْ كَانَتْ لَهُ حَاجَةٌ إِلَى أَهْلِهِ قَضَى حَاجَتَهُ ثُمَّ يَنَامُ فَإِذَا كَانَ عِنْدَ النِّدَاءِ الأَوَّلِ - قَالَتْ - وَثَبَ - وَلاَ وَاللَّهِ مَا قَالَتْ قَامَ - فَأَفَاضَ عَلَيْهِ الْمَاءَ - وَلاَ وَاللَّهِ مَا قَالَتِ اغْتَسَلَ ‏.‏ وَأَنَا أَعْلَمُ مَا تُرِيدُ - وَإِنْ لَمْ يَكُنْ جُنُبًا تَوَضَّأَ وُضُوءَ الرَّجُلِ لِلصَّلاَةِ ثُمَّ صَلَّى الرَّكْعَتَيْنِ ‏.‏\hadithno{1728}\hadithtrans{A'isha thus reported about the (night prayer) of the Messenger of Allah (ﷺ):He used to sleep in the early part of the night, and woke up in the latter part. If he then wished intercourse with his wife, he satisfied his desire, and then went to sleep; and when the first call to prayer was made he jumped up (by Allah, she, i. e. 'A'isha, did not say" he stood up" ), and poured water over him (by Allah she, i. e. 'A'isha, did not say that he took a bath but I know what she meant) and if he did not have an intercourse, he performed ablution, just as a man performs ablution for prayer and then observed two rak'ahs}}
\hadithdefcmd{muslim}{1729}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا عَمَّارُ بْنُ رُزَيْقٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ حَتَّى يَكُونَ آخِرَ صَلاَتِهِ الْوِتْرُ ‏.‏\hadithno{1729}\hadithtrans{A'isha observed that the Messenger of Allah (ﷺ) used to observe prayer in the night and the last of his (night) prayer was Witr}}
\hadithdefcmd{muslim}{1730}{حَدَّثَنِي هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَشْعَثَ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، قَالَ سَأَلْتُ عَائِشَةَ عَنْ عَمَلِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَتْ كَانَ يُحِبُّ الدَّائِمَ ‏.‏ قَالَ قُلْتُ أَىَّ حِينٍ كَانَ يُصَلِّي فَقَالَتْ كَانَ إِذَا سَمِعَ الصَّارِخَ قَامَ فَصَلَّى ‏.‏\hadithno{1730}\hadithtrans{Masruq is reported to have asked 'A'isha about the action (most pleasing to) the Messenger of Allah (ﷺ). She said:He (the Holy Prophet) loved (that action) which one keeps on doing regularly. I said (to 'A'isha): When did he pray (at night)? She replied: When he heard the cock crow, he got up and observed prayer}}
\hadithdefcmd{muslim}{1731}{حَدَّثَنَا أَبُو كُرَيْبٍ، أَخْبَرَنَا ابْنُ بِشْرٍ، عَنْ مِسْعَرٍ، عَنْ سَعْدٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ مَا أَلْفَى رَسُولَ اللَّهِ صلى الله عليه وسلم السَّحَرُ الأَعْلَى فِي بَيْتِي - أَوْ عِنْدِي - إِلاَّ نَائِمًا ‏.‏\hadithno{1731}\hadithtrans{A'isha reported:Never did the earlier part of the dawn find the Messenger of Allah (ﷺ) but sleeping in my house or near me}}
\hadithdefcmd{muslim}{1732}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَنَصْرُ بْنُ عَلِيٍّ، وَابْنُ أَبِي عُمَرَ، قَالَ أَبُو بَكْرٍ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي النَّضْرِ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم إِذَا صَلَّى رَكْعَتَىِ الْفَجْرِ فَإِنْ كُنْتُ مُسْتَيْقِظَةً حَدَّثَنِي وَإِلاَّ اضْطَجَعَ ‏.‏\hadithno{1732}\hadithtrans{A'isha reported:When the Messenger of Allah (ﷺ) had prayed the two rak'ahs (Sunan) of the dawn prayer, he would talk to me if I was awake, otherwise he would lie down}}
\hadithdefcmd{muslim}{1733}{وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ، عَنْ زِيَادِ بْنِ سَعْدٍ، عَنِ ابْنِ أَبِي عَتَّابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{1733}\hadithtrans{A hadith like this has been narrated by 'A'isha by another chain of transmitters}}
\hadithdefcmd{muslim}{1734}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ تَمِيمِ بْنِ سَلَمَةَ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ فَإِذَا أَوْتَرَ قَالَ ‏ "‏ قُومِي فَأَوْتِرِي يَا عَائِشَةُ ‏"‏ ‏.‏\hadithno{1734}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) used to pray in the night and when he observed Witr, he said to me: O 'A'isha, get up and observe Witr}}
\hadithdefcmd{muslim}{1735}{وَحَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنِ الْقَاسِمِ بْنِ مُحَمَّدٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي صَلاَتَهُ بِاللَّيْلِ وَهِيَ مُعْتَرِضَةٌ بَيْنَ يَدَيْهِ فَإِذَا بَقِيَ الْوِتْرُ أَيْقَظَهَا فَأَوْتَرَتْ ‏.‏\hadithno{1735}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) used to offer prayer at night while she lay in front of him, and when the Witr prayer was yet to be observed, he would awaken her and she observed Witr}}
\hadithdefcmd{muslim}{1736}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي يَعْفُورٍ، - وَاسْمُهُ وَاقِدٌ وَلَقَبُهُ وَقْدَانُ - ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَ أَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، كِلاَهُمَا عَنْ مُسْلِمٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ مِنْ كُلِّ اللَّيْلِ قَدْ أَوْتَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَانْتَهَى وِتْرُهُ إِلَى السَّحَرِ ‏.‏\hadithno{1736}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) observed the Witr prayer every night and he completed Witr at the time of dawn}}
\hadithdefcmd{muslim}{1737}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي حَصِينٍ، عَنْ يَحْيَى بْنِ وَثَّابٍ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ مِنْ كُلِّ اللَّيْلِ قَدْ أَوْتَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ أَوَّلِ اللَّيْلِ وَأَوْسَطِهِ وَآخِرِهِ فَانْتَهَى وِتْرُهُ إِلَى السَّحَرِ ‏.‏\hadithno{1737}\hadithtrans{Masruq reported on the authority of 'A'isha that she said that the Messenger Of Allah (ﷺ) used to observe the Witr prayer every night, maybe in the early part of night, at midnight and in the latter part, finishing his Witr at dawn}}
\hadithdefcmd{muslim}{1738}{حَدَّثَنِي عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا حَسَّانُ، - قَاضِي كِرْمَانَ - عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ أَبِي الضُّحَى، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ، قَالَتْ كُلَّ اللَّيْلِ قَدْ أَوْتَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَانْتَهَى وِتْرُهُ إِلَى آخِرِ اللَّيْلِ ‏.‏\hadithno{1738}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) used to observe Witr every night, and he would (at times) complete his Witr at the end of the night}}
\hadithdefcmd{muslim}{1739}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى الْعَنَزِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ، أَنَّ سَعْدَ بْنَ هِشَامِ بْنِ عَامِرٍ، أَرَادَ أَنْ يَغْزُوَ، فِي سَبِيلِ اللَّهِ فَقَدِمَ الْمَدِينَةَ فَأَرَادَ أَنْ يَبِيعَ عَقَارًا لَهُ بِهَا فَيَجْعَلَهُ فِي السِّلاَحِ وَالْكُرَاعِ وَيُجَاهِدَ الرُّومَ حَتَّى يَمُوتَ فَلَمَّا قَدِمَ الْمَدِينَةَ لَقِيَ أُنَاسًا مِنْ أَهْلِ الْمَدِينَةِ فَنَهَوْهُ عَنْ ذَلِكَ وَأَخْبَرُوهُ أَنَّ رَهْطًا سِتَّةً أَرَادُوا ذَلِكَ فِي حَيَاةِ نَبِيِّ اللَّهِ صلى الله عليه وسلم فَنَهَاهُمْ نَبِيُّ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ أَلَيْسَ لَكُمْ فِيَّ أُسْوَةٌ ‏"‏ ‏.‏ فَلَمَّا حَدَّثُوهُ بِذَلِكَ رَاجَعَ امْرَأَتَهُ وَقَدْ كَانَ طَلَّقَهَا وَأَشْهَدَ عَلَى رَجْعَتِهَا فَأَتَى ابْنَ عَبَّاسٍ فَسَأَلَهُ عَنْ وِتْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ابْنُ عَبَّاسٍ أَلاَ أَدُلُّكَ عَلَى أَعْلَمِ أَهْلِ الأَرْضِ بِوِتْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ مَنْ قَالَ عَائِشَةُ ‏.‏ فَأْتِهَا فَاسْأَلْهَا ثُمَّ ائْتِنِي فَأَخْبِرْنِي بِرَدِّهَا عَلَيْكَ فَانْطَلَقْتُ إِلَيْهَا فَأَتَيْتُ عَلَى حَكِيمِ بْنِ أَفْلَحَ فَاسْتَلْحَقْتُهُ إِلَيْهَا فَقَالَ مَا أَنَا بِقَارِبِهَا لأَنِّي نَهَيْتُهَا أَنْ تَقُولَ فِي هَاتَيْنِ الشِّيعَتَيْنِ شَيْئًا فَأَبَتْ فِيهِمَا إِلاَّ مُضِيًّا ‏.‏ - قَالَ - فَأَقْسَمْتُ عَلَيْهِ فَجَاءَ فَانْطَلَقْنَا إِلَى عَائِشَةَ فَاسْتَأْذَنَّا عَلَيْهَا فَأَذِنَتْ لَنَا فَدَخَلْنَا عَلَيْهَا ‏.‏ فَقَالَتْ أَحَكِيمٌ فَعَرَفَتْهُ ‏.‏ فَقَالَ نَعَمْ ‏.‏ فَقَالَتْ مَنْ مَعَكَ قَالَ سَعْدُ بْنُ هِشَامٍ ‏.‏ قَالَتْ مَنْ هِشَامٌ قَالَ ابْنُ عَامِرٍ فَتَرَحَّمَتْ عَلَيْهِ وَقَالَتْ خَيْرًا - قَالَ قَتَادَةُ وَكَانَ أُصِيبَ يَوْمَ أُحُدٍ ‏.‏ فَقُلْتُ يَا أُمَّ الْمُؤْمِنِينَ أَنْبِئِينِي عَنْ خُلُقِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَتْ أَلَسْتَ تَقْرَأُ الْقُرْآنَ قُلْتُ بَلَى ‏.‏ قَالَتْ فَإِنَّ خُلُقَ نَبِيِّ اللَّهِ صلى الله عليه وسلم كَانَ الْقُرْآنَ ‏.‏ - قَالَ - فَهَمَمْتُ أَنْ أَقُومَ وَلاَ أَسْأَلَ أَحَدًا عَنْ شَىْءٍ حَتَّى أَمُوتَ ثُمَّ بَدَا لِي فَقُلْتُ أَنْبِئِينِي عَنْ قِيَامِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَتْ أَلَسْتَ تَقْرَأُ ‏\{‏ يَا أَيُّهَا الْمُزَّمِّلُ‏\}‏ قُلْتُ بَلَى ‏.‏ قَالَتْ فَإِنَّ اللَّهَ عَزَّ وَجَلَّ افْتَرَضَ قِيَامَ اللَّيْلِ فِي أَوَّلِ هَذِهِ السُّورَةِ فَقَامَ نَبِيُّ اللَّهِ صلى الله عليه وسلم وَأَصْحَابُهُ حَوْلاً وَأَمْسَكَ اللَّهُ خَاتِمَتَهَا اثْنَىْ عَشَرَ شَهْرًا فِي السَّمَاءِ حَتَّى أَنْزَلَ اللَّهُ فِي آخِرِ هَذِهِ السُّورَةِ التَّخْفِيفَ فَصَارَ قِيَامُ اللَّيْلِ تَطَوُّعًا بَعْدَ فَرِيضَةٍ ‏.‏ - قَالَ - قُلْتُ يَا أُمَّ الْمُؤْمِنِينَ أَنْبِئِينِي عَنْ وِتْرِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَتْ كُنَّا نُعِدُّ لَهُ سِوَاكَهُ وَطَهُورَهُ فَيَبْعَثُهُ اللَّهُ مَا شَاءَ أَنْ يَبْعَثَهُ مِنَ اللَّيْلِ فَيَتَسَوَّكُ وَيَتَوَضَّأُ وَيُصَلِّي تِسْعَ رَكَعَاتٍ لاَ يَجْلِسُ فِيهَا إِلاَّ فِي الثَّامِنَةِ فَيَذْكُرُ اللَّهَ وَيَحْمَدُهُ وَيَدْعُوهُ ثُمَّ يَنْهَضُ وَلاَ يُسَلِّمُ ثُمَّ يَقُومُ فَيُصَلِّي التَّاسِعَةَ ثُمَّ يَقْعُدُ فَيَذْكُرُ اللَّهَ وَيَحْمَدُهُ وَيَدْعُوهُ ثُمَّ يُسَلِّمُ تَسْلِيمًا يُسْمِعُنَا ثُمَّ يُصَلِّي رَكْعَتَيْنِ بَعْدَ مَا يُسَلِّمُ وَهُوَ قَاعِدٌ فَتِلْكَ إِحْدَى عَشْرَةَ رَكْعَةً يَا بُنَىَّ فَلَمَّا أَسَنَّ نَبِيُّ اللَّهِ صلى الله عليه وسلم وَأَخَذَ اللَّحْمَ أَوْتَرَ بِسَبْعٍ وَصَنَعَ فِي الرَّكْعَتَيْنِ مِثْلَ صَنِيعِهِ الأَوَّلِ فَتِلْكَ تِسْعٌ يَا بُنَىَّ وَكَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم إِذَا صَلَّى صَلاَةً أَحَبَّ أَنْ يُدَاوِمَ عَلَيْهَا وَكَانَ إِذَا غَلَبَهُ نَوْمٌ أَوْ وَجَعٌ عَنْ قِيَامِ اللَّيْلِ صَلَّى مِنَ النَّهَارِ ثِنْتَىْ عَشْرَةَ رَكْعَةً وَلاَ أَعْلَمُ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَرَأَ الْقُرْآنَ كُلَّهُ فِي لَيْلَةٍ وَلاَ صَلَّى لَيْلَةً إِلَى الصُّبْحِ وَلاَ صَامَ شَهْرًا كَامِلاً غَيْرَ رَمَضَانَ ‏.‏ - قَالَ - فَانْطَلَقْتُ إِلَى ابْنِ عَبَّاسِ فَحَدَّثْتُهُ بِحَدِيثِهَا فَقَالَ صَدَقَتْ لَوْ كُنْتُ أَقْرَبُهَا أَوْ أَدْخُلُ عَلَيْهَا لأَتَيْتُهَا حَتَّى تُشَافِهَنِي بِهِ ‏.‏ - قَالَ - قُلْتُ لَوْ عَلِمْتُ أَنَّكَ لاَ تَدْخُلُ عَلَيْهَا مَا حَدَّثْتُكَ حَدِيثَهَا ‏.‏\hadithno{1739}\hadithtrans{Sa'd b. Hisham b. 'Amir decided to participate in the expedition for the sake of Allah, so he came to Medina and he decided to dispose of his property there and buy arms and horses instead and fight against the Romans to the end of his life. When he came to Medina, he met the people of Medina. They dissuaded him to do such a thing, and informed him that a group of six men had decided to do so during the lifetime of the Messenger of Allah (ﷺ) and the Messenger of Allah (ﷺ) forbade them to do it, and said:Is there not for you a model pattern in me? And when they narrated this to him (Sa'd b. Hisham), he returned to his wife, though he had divorced her and made (people) witness to his reconciliation. He then came to Ibn 'Abbas and asked him about the Witr of the Messenger of Allah (ﷺ). Ibn 'Abbas said: Should I not lead you to one who knows best amongst the people of the world about the Witr of the Messenger of Allah (ﷺ)? He said: Who is it? He (Ibn 'Abbas) said: It is 'A'isha. So go to her and ask her (about Witr) and then come to me and inform me about her answer that she would give you. So I came to Hakim b. Aflah and requested him to take me to her. He said: I would not go to her, for I forbade her to speak anything (about the conflict) between the two groupS, but she refused (to accept my advice) and went (to participate in that corflict). I (requested) him (Hakim) with an oath to lead me to her. So we went to 'A'isha and we begged permission to meet her. She granted us permission and we went in. She said: Are you Hakim? (She recognised him.) He replied: Yes. She said: Who is there with you? He said: He is Sa'd b. Hisham. She said: Which Hisham? He said: He is Hisham b. 'Amir. She blessed him ('Amir) with mercy from Allah and spoke good of him (Qatada said that he died as a martyr in Uhud). I said: Mother of the Faithful, tell me about the character of the Messenger of Allah (ﷺ). She said: Don't you read the Qur'an? I said: Yes. Upon this she said: The character of the Messenger of Allah (ﷺ) was the Qur'an. He said: I felt inclined to get up and not ask anything (further) till death. But then I changed my mind and said: Inform me about the observance (of the night prayer) of the Messenger of Allah (ﷺ). She said: Did you not recite:" O thou wrapped up"? He said: Yes. She said: Allah, the Exalted and the Glorious, made the observance of the night prayer at the beginning of this Surah obligatory. So the Messenger of Allah (may peace be upon him and his Companions around him observed this (night prayer) for one year. Allah held back the concluding portion of this Surah for twelve months in the Heaven till (at the end of this period) Allah revealed the concluding verses of this Surah which lightened (the burden of this prayer), and the night prayer became a supererogatory prayer after being an obligatory one. I said: Mother of the Faithful, inform me about the Witr of the Messenger of Allah (ﷺ). She said: I used to prepare tooth stick for him and water for his ablution, and Allah would rouse him to the extent He wished during the night. He would use the tooth stick, and perform ablution, and would offer nine rak'ahs, and would not sit but in the eighth one and would remember Allah, and praise Him and supplicate Him, then he would get up without uttering the salutation and pray the ninth rak'ah. He would then sit, remember, praise Him and supplicate Him and then utter a salutation loud enough for us to hear. He would then pray two rak'ahs sitting after uttering the salutation, and that made eleven rak'ahs. O my son, but when the Messenger of Allah (ﷺ) grew old and put on flesh, he observed Witr of seven, doing in the two rak'ahs as he had done formerly, and that made nine. O my son, and when the Messenger of Allah (ﷺ) observed prayer, he liked to keep on observing it, and when sleep or pain overpowered him and made it impossible (for him) to observe prayer in the night, he prayed twelve rak'ahs daring the day. I am not aware of Allah's Prophet (ﷺ) having recited the whole Qur'an during one single night, or praying through the night till morning, or fasting a complete month, except Ramadan. He (the narrator) said: I then went to Ibn 'Abbas and narrated to him the hadith (transmitted from her), and he said: She says the truth If I went to her and got into her presence, I would have listened to it orally from her. He said: If I were to know that you do not go to her. I would not have transmitted this hadith to you narrated by her}}
\hadithdefcmd{muslim}{1740}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، أَنَّهُ طَلَّقَ امْرَأَتَهُ ثُمَّ انْطَلَقَ إِلَى الْمَدِينَةِ لِيَبِيعَ عَقَارَهُ ‏.‏ فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{1740}\hadithtrans{Zurara b. Aufa said that Sa'd b. Hisham divorced his wife, and then proceeded to Medina to sell his property, and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{1741}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، حَدَّثَنَا قَتَادَةُ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، أَنَّهُ قَالَ انْطَلَقْتُ إِلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ فَسَأَلْتُهُ عَنِ الْوِتْرِ ‏.‏ وَسَاقَ الْحَدِيثَ بِقِصَّتِهِ وَقَالَ فِيهِ قَالَتْ مَنْ هِشَامٌ قُلْتُ ابْنُ عَامِرٍ ‏.‏ قَالَتْ نِعْمَ الْمَرْءُ كَانَ عَامِرٌ أُصِيبَ يَوْمَ أُحُدٍ ‏.‏\hadithno{1741}\hadithtrans{Sa'd b. Hisham reported:I went to 'Abdullah b. 'Abbas and asked him about the Witr prayer, and the rest of the hadith is the same as recorded in this event. She (Hadrat 'A'isha) said: Who is that Hisham? I said: Son of 'Amir. She said: What a fine man 'Amir was! He died as a martyr in the Battle of Uhud}}
\hadithdefcmd{muslim}{1742}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ رَافِعٍ، كِلاَهُمَا عَنْ عَبْدِ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، أَنَّ سَعْدَ بْنَ هِشَامٍ، كَانَ جَارًا لَهُ فَأَخْبَرَهُ أَنَّهُ، طَلَّقَ امْرَأَتَهُ ‏.‏ وَاقْتَصَّ الْحَدِيثَ بِمَعْنَى حَدِيثِ سَعِيدٍ وَفِيهِ قَالَتْ مَنْ هِشَامٌ قَالَ ابْنُ عَامِرٍ ‏.‏ قَالَتْ نِعْمَ الْمَرْءُ كَانَ أُصِيبَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ أُحُدٍ ‏.‏ وَفِيهِ فَقَالَ حَكِيمُ بْنُ أَفْلَحَ أَمَا إِنِّي لَوْ عَلِمْتُ أَنَّكَ لاَ تَدْخُلُ عَلَيْهَا مَا أَنْبَأْتُكَ بِحَدِيثِهَا ‏.‏\hadithno{1742}\hadithtrans{Zurara b. Aufa reported that Sa'd b. Hisham was his neighbour and he informed him that he had divorced his wife and he narrated the hadith like the one transmitted by Sa'd. She ('A'isha) said:Who is Hisham? He said: The son of 'Amir. She said: What a fine man he was; he participated in the Battle of Uhud along with the Messenger of Allah (ﷺ). Hakim b. Aflah said: If I ever knew that you do not go to 'A'isha, I would not have informed you about her hadith (So that you would have gone to her and heard it from her orally)}}
\hadithdefcmd{muslim}{1743}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، جَمِيعًا عَنْ أَبِي عَوَانَةَ، قَالَ سَعِيدٌ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا فَاتَتْهُ الصَّلاَةُ مِنَ اللَّيْلِ مِنْ وَجَعٍ أَوْ غَيْرِهِ صَلَّى مِنَ النَّهَارِ ثِنْتَىْ عَشْرَةَ رَكْعَةً ‏.‏\hadithno{1743}\hadithtrans{A'isha reported that when the Messenger of Allah (ﷺ) missed the night prayer due to pain or any other reason, he observed twelve rak'ahs during the daytime}}
\hadithdefcmd{muslim}{1744}{وَحَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى، - وَهُوَ ابْنُ يُونُسَ - عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ زُرَارَةَ، عَنْ سَعْدِ بْنِ هِشَامٍ الأَنْصَارِيِّ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا عَمِلَ عَمَلاً أَثْبَتَهُ وَكَانَ إِذَا نَامَ مِنَ اللَّيْلِ أَوْ مَرِضَ صَلَّى مِنَ النَّهَارِ ثِنْتَىْ عَشْرَةَ رَكْعَةً ‏.‏ قَالَتْ وَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَامَ لَيْلَةً حَتَّى الصَّبَاحِ وَمَا صَامَ شَهْرًا مُتَتَابِعًا إِلاَّ رَمَضَانَ ‏.‏\hadithno{1744}\hadithtrans{A'isha reported that when the Messenger of Allah (ﷺ) decided upon doing any act, he continued to do it, and when he slept at night or fell sick he observed twelve rak'ahs during the daytime. I am not aware of Allah's Messenger (ﷺ) observing prayer during the whole of the night till morning, or observing fast for a whole month continuously except that of Ramadan}}
\hadithdefcmd{muslim}{1745}{حَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، ح وَحَدَّثَنِي أَبُو الطَّاهِرِ، وَحَرْمَلَةُ، قَالاَ أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنِ السَّائِبِ بْنِ يَزِيدَ، وَعُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، أَخْبَرَاهُ عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدٍ الْقَارِيِّ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ نَامَ عَنْ حِزْبِهِ أَوْ عَنْ شَىْءٍ مِنْهُ فَقَرَأَهُ فِيمَا بَيْنَ صَلاَةِ الْفَجْرِ وَصَلاَةِ الظُّهْرِ كُتِبَ لَهُ كَأَنَّمَا قَرَأَهُ مِنَ اللَّيْلِ ‏"‏ ‏.‏\hadithno{1745}\hadithtrans{Umar b. Khattab reported Allah's Messenger (ﷺ) as saying:Should anyone fall asleep and fail to recite his portion of the Qur'an, or a part of it, if he recites it between the dawn prayer and the noon prayer, it will be recorded for him as though he had recited it during the night}}
\hadithdefcmd{muslim}{1746}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ، نُمَيْرٍ قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ عُلَيَّةَ - عَنْ أَيُّوبَ، عَنِ الْقَاسِمِ الشَّيْبَانِيِّ، أَنَّ زَيْدَ بْنَ أَرْقَمَ، رَأَى قَوْمًا يُصَلُّونَ مِنَ الضُّحَى فَقَالَ أَمَا لَقَدْ عَلِمُوا أَنَّ الصَّلاَةَ فِي غَيْرِ هَذِهِ السَّاعَةِ أَفْضَلُ ‏.‏ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةُ الأَوَّابِينَ حِينَ تَرْمَضُ الْفِصَالُ ‏"‏ ‏.‏\hadithno{1746}\hadithtrans{Zaid b. Arqam, on seeing some people praying in the forenoon, said:They well know that prayer at another time than this is more excellent, for Allah's Messenger (ﷺ) said: The prayer of those who are penitent is observed when your weaned camels feel the heat of the sun}}
\hadithdefcmd{muslim}{1747}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامِ بْنِ أَبِي عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا الْقَاسِمُ الشَّيْبَانِيُّ، عَنْ زَيْدِ بْنِ أَرْقَمَ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى أَهْلِ قُبَاءٍ وَهُمْ يُصَلُّونَ فَقَالَ ‏ "‏ صَلاَةُ الأَوَّابِينَ إِذَا رَمِضَتِ الْفِصَالُ ‏"‏ ‏.‏\hadithno{1747}\hadithtrans{Zaid b. Arqam reported that the Messenger of Allah (ﷺ) went out to the people of Quba' and saw them observing prayer; upon this he said:The prayer of the penitent should be observed when the young weaned camels feel heat of the sun}}
\hadithdefcmd{muslim}{1748}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، وَعَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَجُلاً، سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ صَلاَةِ اللَّيْلِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صَلاَةُ اللَّيْلِ مَثْنَى مَثْنَى فَإِذَا خَشِيَ أَحَدُكُمُ الصُّبْحَ صَلَّى رَكْعَةً وَاحِدَةً تُوتِرُ لَهُ مَا قَدْ صَلَّى ‏"‏ ‏.‏\hadithno{1748}\hadithtrans{Ibn 'Umar reported that a person asked the Messenger of Allah (ﷺ) about the night prayer. The Messenger of Allah (ﷺ) said:Prayer during the night should consist of pairs of rak'ahs, but if one of you fears morning is near, he should pray one rak'ah which will make his prayer an odd number for him}}
\hadithdefcmd{muslim}{1749}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبَّادٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَمْرٌو، عَنْ طَاوُسٍ، عَنِ ابْنِ عُمَرَ، ح وَحَدَّثَنَا الزُّهْرِيُّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، أَنَّ رَجُلاً، سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنْ صَلاَةِ اللَّيْلِ فَقَالَ ‏ "‏ مَثْنَى مَثْنَى فَإِذَا خَشِيتَ الصُّبْحَ فَأَوْتِرْ بِرَكْعَةٍ ‏"‏ ‏.‏\hadithno{1749}\hadithtrans{Salim reported on the authority of his father that a person asked the Messenger of Allah (ﷺ) about the night prayer. He said:It consists of pairs of rak'ahs, but if one fears morning is near, he should make it an odd number by praying one rak'ah}}
\hadithdefcmd{muslim}{1750}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، أَنَّ ابْنَ شِهَابٍ، حَدَّثَهُ أَنَّ سَالِمَ بْنَ عَبْدِ اللَّهِ بْنِ عُمَرَ وَحُمَيْدَ بْنَ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ حَدَّثَاهُ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ، أَنَّهُ قَالَ قَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ صَلاَةُ اللَّيْلِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ صَلاَةُ اللَّيْلِ مَثْنَى مَثْنَى فَإِذَا خِفْتَ الصُّبْحَ فَأَوْتِرْ بِوَاحِدَةٍ ‏"‏ ‏.‏\hadithno{1750}\hadithtrans{Abdullah b. 'Umar reported:A man stood up and said. Messenger of Allah, how is the night prayer? The Messenger of Allah (ﷺ) said: The night prayer consists of pair, but if you apprehend the rise of dawn, make it odd number by observing one rak'ah}}
\hadithdefcmd{muslim}{1751}{وَحَدَّثَنِي أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، وَبُدَيْلٌ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَجُلاً، سَأَلَ النَّبِيَّ صلى الله عليه وسلم وَأَنَا بَيْنَهُ وَبَيْنَ السَّائِلِ فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ صَلاَةُ اللَّيْلِ قَالَ ‏ "‏ مَثْنَى مَثْنَى فَإِذَا خَشِيتَ الصُّبْحَ فَصَلِّ رَكْعَةً وَاجْعَلْ آخِرَ صَلاَتِكَ وِتْرًا ‏"‏ ‏.‏ ثُمَّ سَأَلَهُ رَجُلٌ عَلَى رَأْسِ الْحَوْلِ وَأَنَا بِذَلِكَ الْمَكَانِ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلاَ أَدْرِي هُوَ ذَلِكَ الرَّجُلُ أَوْ رَجُلٌ آخَرُ فَقَالَ لَهُ مِثْلَ ذَلِكَ ‏.‏\hadithno{1751}\hadithtrans{Abdullah b. 'Umar reported:A person asked the Messenger of Allah (ﷺ) as I stood between him (the Holy Prophet) and the inquirer and he said: Messenger of Allah, how is the night prayer? He (the Holy Prophet) said: It consists of pairs of rak'ahs, but if you apprehend morning, you should pray one rak'ah and make the end of your prayer as Witr. Then a person asked him (the Holy Prophet) at the end of the year and I was at that place near the Messenger of Allah (ﷺ) ; but I do not know whether he was the same person or another person, but he (the Holy Prophet) gave him the same reply}}
\hadithdefcmd{muslim}{1752}{وَحَدَّثَنِي أَبُو كَامِلٍ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، وَبُدَيْلٌ، وَعِمْرَانُ بْنُ حُدَيْرٍ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنِ ابْنِ عُمَرَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْغُبَرِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، وَالزُّبَيْرُ بْنُ الْخِرِّيتِ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنِ ابْنِ عُمَرَ، قَالَ سَأَلَ رَجُلٌ النَّبِيَّ صلى الله عليه وسلم ‏.‏ فَذَكَرَا بِمِثْلِهِ وَلَيْسَ فِي حَدِيثِهِمَا ثُمَّ سَأَلَهُ رَجُلٌ عَلَى رَأْسِ الْحَوْلِ وَمَا بَعْدَهُ ‏.‏\hadithno{1752}\hadithtrans{This hadith his been narrated by Ibn 'Umar by another chain of trans- mitters but it does not have these words:" Then a person asked him at the end of the year," and what follows subsequently}}
\hadithdefcmd{muslim}{1753}{وَحَدَّثَنَا هَارُونُ بْنُ مَعْرُوفٍ، وَسُرَيْجُ بْنُ يُونُسَ، وَأَبُو كُرَيْبٍ جَمِيعًا عَنِ ابْنِ أَبِي زَائِدَةَ، - قَالَ هَارُونُ حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، - أَخْبَرَنِي عَاصِمٌ الأَحْوَلُ، عَنْ عَبْدِ اللَّهِ بْنِ شَقِيقٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ بَادِرُوا الصُّبْحَ بِالْوِتْرِ ‏"‏ ‏.‏\hadithno{1753}\hadithtrans{Ibn 'Umar reported the Messenger of Allah (ﷺ) as say- ing:Hasten to pray Witr before morning}}
\hadithdefcmd{muslim}{1754}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، ح وَحَدَّثَنَا ابْنُ رُمْحٍ، أَخْبَرَنَا اللَّيْثُ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، قَالَ مَنْ صَلَّى مِنَ اللَّيْلِ فَلْيَجْعَلْ آخِرَ صَلاَتِهِ وِتْرًا فَإِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَأْمُرُ بِذَلِكَ ‏.‏\hadithno{1754}\hadithtrans{Ibn 'Umar said:He who prayed at night should make Witr the end of his prayer, for the Messenger of Allah (ﷺ) ordered this}}
\hadithdefcmd{muslim}{1755}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَابْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا يَحْيَى، كُلُّهُمْ عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اجْعَلُوا آخِرَ صَلاَتِكُمْ بِاللَّيْلِ وِتْرًا ‏"‏ ‏.‏\hadithno{1755}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:Make Witr the end of your night prayer}}
\hadithdefcmd{muslim}{1756}{وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، قَالَ قَالَ ابْنُ جُرَيْجٍ أَخْبَرَنِي نَافِعٌ، أَنَّ ابْنَ عُمَرَ، كَانَ يَقُولُ مَنْ صَلَّى مِنَ اللَّيْلِ فَلْيَجْعَلْ آخِرَ صَلاَتِهِ وِتْرًا قَبْلَ الصُّبْحِ كَذَلِكَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُهُمْ ‏.‏\hadithno{1756}\hadithtrans{Nafi' reported Ibn 'Umar as saying:He who observed the night prayer should make Witr the end of his prayer before dawn. The Messenger of Allah (ﷺ) used to order them thus}}
\hadithdefcmd{muslim}{1757}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَبِي التَّيَّاحِ، قَالَ حَدَّثَنِي أَبُو مِجْلَزٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْوِتْرُ رَكْعَةٌ مِنْ آخِرِ اللَّيْلِ ‏"‏ ‏.‏\hadithno{1757}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:Witr is a rak'ah at the end of the prayer}}
\hadithdefcmd{muslim}{1758}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَبِي مِجْلَزٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْوِتْرُ رَكْعَةٌ مِنْ آخِرِ اللَّيْلِ ‏"‏ ‏.‏\hadithno{1758}\hadithtrans{Ibn Umar reported Allah's Messenger (ﷺ) as saying:Witr is a rak'ah at the end of the night prayer}}
\hadithdefcmd{muslim}{1759}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الصَّمَدِ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي مِجْلَزٍ، قَالَ سَأَلْتُ ابْنَ عَبَّاسٍ عَنِ الْوِتْرِ، فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ رَكْعَةٌ مِنْ آخِرِ اللَّيْلِ ‏"‏ ‏.‏ وَسَأَلْتُ ابْنَ عُمَرَ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ رَكْعَةٌ مِنْ آخِرِ اللَّيْلِ ‏"‏ ‏.‏\hadithno{1759}\hadithtrans{Abu Mijlaz reported:I asked Ibn 'Abbas about the Witr prayer. He said: I heard the Messenger of Allah (ﷺ) as saying: It is a rak'ah at the end of the night prayer}}
\hadithdefcmd{muslim}{1760}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، وَهَارُونُ بْنُ عَبْدِ اللَّهِ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، قَالَ حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ ابْنَ عُمَرَ، حَدَّثَهُمْ أَنَّ رَجُلاً نَادَى رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ فِي الْمَسْجِدِ فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ أُوتِرُ صَلاَةَ اللَّيْلِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ صَلَّى فَلْيُصَلِّ مَثْنَى مَثْنَى فَإِنْ أَحَسَّ أَنْ يُصْبِحَ سَجَدَ سَجْدَةً فَأَوْتَرَتْ لَهُ مَا صَلَّى ‏"‏ ‏.‏ قَالَ أَبُو كُرَيْبٍ عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ ‏.‏ وَلَمْ يَقُلِ ابْنِ عُمَرَ ‏.‏\hadithno{1760}\hadithtrans{Ibn 'Umar reported:A person called (the attention) of the Messenger of Allah (ﷺ) as he was in the mosque, and said: Messenger of Allah, how should I make the rak'ahs of the night prayer an odd number? Upon this the Messenger of Allah (may peace he upon him) said: He who prays (night prayer) he should observe it in pairs, but if he apprehends the rise of morning, he should observe one rak'ah; that would make the number odd (for the rak'ahs) observed by him. This was narrated by Abu Kuraib 'Ubaidullah b. 'Abdullah and Ibn 'Umar did not make mention of it}}
\hadithdefcmd{muslim}{1761}{حَدَّثَنَا خَلَفُ بْنُ هِشَامٍ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَنَسِ بْنِ سِيرِينَ، قَالَ سَأَلْتُ ابْنَ عُمَرَ قُلْتُ أَرَأَيْتَ الرَّكْعَتَيْنِ قَبْلَ صَلاَةِ الْغَدَاةِ أَأُطِيلُ فِيهِمَا الْقِرَاءَةَ قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ مَثْنَى مَثْنَى وَيُوتِرُ بِرَكْعَةٍ - قَالَ - قُلْتُ إِنِّي لَسْتُ عَنْ هَذَا أَسْأَلُكَ ‏.‏ قَالَ إِنَّكَ لَضَخْمٌ أَلاَ تَدَعُنِي أَسْتَقْرِئُ لَكَ الْحَدِيثَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ مَثْنَى مَثْنَى وَيُوتِرُ بِرَكْعَةٍ وَيُصَلِّي رَكْعَتَيْنِ قَبْلَ الْغَدَاةِ كَأَنَّ الأَذَانَ بِأُذُنَيْهِ ‏.‏ قَالَ خَلَفٌ أَرَأَيْتَ الرَّكْعَتَيْنِ قَبْلَ الْغَدَاةِ وَلَمْ يَذْكُرْ صَلاَةِ ‏.‏\hadithno{1761}\hadithtrans{Anas b. Sirin reported:I asked Ibn 'Umar to tell me about the practice of the Prophet (ﷺ) in regard to two rak'ahs before the dawn prayer: Should I make lengthy recitation in them? He said: The Messenger of Allah (ﷺ) used to observe, the night prayer in pairs and then made the number odd by observing one rak'ah. I said: I am not asking you about it. He said: You are a bulky man, will you not show me the patience to narrate to you the hadith completely? The Messenger of Allah (ﷺ) used to observe the night prayer in pairs and then made the number odd by observing one rak'ah, and then he observed two rak'ahs before dawn quite close to the call for prayer (Khalaf said:" Did you see [yourself the Prophet observing] the two rak'ahs before the dawn?" and he made no mention of prayer}}
\hadithdefcmd{muslim}{1762}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَنَسِ بْنِ سِيرِينَ، قَالَ سَأَلْتُ ابْنَ عُمَرَ ‏.‏ بِمِثْلِهِ وَزَادَ وَيُوتِرُ بِرَكْعَةٍ مِنْ آخِرِ اللَّيْلِ ‏.‏ وَفِيهِ فَقَالَ بَهْ بَهْ إِنَّكَ لَضَخْمٌ ‏.‏\hadithno{1762}\hadithtrans{Anas b. Sirin reported:I asked Ibn 'Umar like this (as recorded in the previous hadith) and he made this addition:" And he (the Holy Prophet) made the end of the night prayer as odd number by one rak'ah." And there is also (this addition):" Stop, stop, you are bulky}}
\hadithdefcmd{muslim}{1763}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ عُقْبَةَ بْنَ حُرَيْثٍ، قَالَ سَمِعْتُ ابْنَ عُمَرَ، يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ صَلاَةُ اللَّيْلِ مَثْنَى مَثْنَى فَإِذَا رَأَيْتَ أَنَّ الصُّبْحَ يُدْرِكُكَ فَأَوْتِرْ بِوَاحِدَةٍ ‏"‏ ‏.‏ فَقِيلَ لاِبْنِ عُمَرَ مَا مَثْنَى مَثْنَى قَالَ أَنْ يُسَلِّمَ فِي كُلِّ رَكْعَتَيْنِ ‏.‏\hadithno{1763}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:The night prayer consists of pairs and when you see the approach of dawn, make this number odd by one rak'ah. It was said to Ibn 'Umar: What does the (word) pair imply? He said: (It means) that salutation is uttered after every two rak'ahs}}
\hadithdefcmd{muslim}{1764}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، عَنْ مَعْمَرٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَوْتِرُوا قَبْلَ أَنْ تُصْبِحُوا ‏"‏ ‏.‏\hadithno{1764}\hadithtrans{Abu Sa'id (al Khudri) reported Allah's Apostle (ﷺ) as saying:Observe Witr prayer before it is morning. Abu Sa'id reported that they (the Prophet's Companions) asked the Messenger of Allah (ﷺ) about Witr (prayer). (In reply to their inquiry) he said: Observe Witr prayer before it is morning}}
\hadithdefcmd{muslim}{1765}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنِي عُبَيْدُ اللَّهِ، عَنْ شَيْبَانَ، عَنْ يَحْيَى، قَالَ أَخْبَرَنِي أَبُو نَضْرَةَ الْعَوَقِيُّ، أَنَّ أَبَا سَعِيدٍ، أَخْبَرَهُمْ أَنَّهُمْ، سَأَلُوا النَّبِيَّ صلى الله عليه وسلم عَنِ الْوِتْرِ فَقَالَ ‏ "‏ أَوْتِرُوا قَبْلَ الصُّبْحِ ‏"‏ ‏.‏\hadithno{1765}\hadithtrans{Abu Sa'id reported that they (some of the Companions) of the Prophet (ﷺ) asked the Messenger of Allah (ﷺ) about Witr. He said:Observe Witr before morning}}
\hadithdefcmd{muslim}{1766}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصٌ، وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ خَافَ أَنْ لاَ يَقُومَ مِنْ آخِرِ اللَّيْلِ فَلْيُوتِرْ أَوَّلَهُ وَمَنْ طَمِعَ أَنْ يَقُومَ آخِرَهُ فَلْيُوتِرْ آخِرَ اللَّيْلِ فَإِنَّ صَلاَةَ آخِرِ اللَّيْلِ مَشْهُودَةٌ وَذَلِكَ أَفْضَلُ ‏"‏ ‏.‏ وَقَالَ أَبُو مُعَاوِيَةَ مَحْضُورَةٌ ‏.‏\hadithno{1766}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) as saying:If anyone is afraid that he may not get up in the latter part of the night, he should observe Witr in the first part of it; and if anyone is eager to get up in the last part of it, he should observe Witr at the end of the night, for prayer at the end of the night is witnessed (by the angels) and that is preferable}}
\hadithdefcmd{muslim}{1767}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، - وَهُوَ ابْنُ عُبَيْدِ اللَّهِ - عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَيُّكُمْ خَافَ أَنْ لاَ يَقُومَ مِنْ آخِرِ اللَّيْلِ فَلْيُوتِرْ ثُمَّ لْيَرْقُدْ وَمَنْ وَثِقَ بِقِيَامٍ مِنَ اللَّيْلِ فَلْيُوتِرْ مِنْ آخِرِهِ فَإِنَّ قِرَاءَةَ آخِرِ اللَّيْلِ مَحْضُورَةٌ وَذَلِكَ أَفْضَلُ ‏"‏ ‏.‏\hadithno{1767}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) as saying:He who amongst you is afraid that he may not be able to get up at the end of the night should observe Witr (in the first part) and then sleep, and he who is confident of getting up and praying at night (i. e. Tahajjud prayer) should observe it at the end of it, for the recitation at the end of the night is witnessed*, and that is better. *: meaning, "by angels" (Sharh an-Nawawi)}}
\hadithdefcmd{muslim}{1768}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا أَبُو عَاصِمٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَفْضَلُ الصَّلاَةِ طُولُ الْقُنُوتِ ‏"‏ ‏.‏\hadithno{1768}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) as saying:The most excellent prayer is that in which the duration of standing is longer}}
\hadithdefcmd{muslim}{1769}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَىُّ الصَّلاَةِ أَفْضَلُ قَالَ ‏ "‏ طُولُ الْقُنُوتِ ‏"‏ ‏.‏ قَالَ أَبُو بَكْرٍ حَدَّثَنَا أَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ ‏.‏\hadithno{1769}\hadithtrans{Jabir reported:The Messenger of Allah (ﷺ) was asked about the prayer which was most excellent. He said: That in which the standing is longer. (This hadith is narrated by another chain of transmitters too)}}
\hadithdefcmd{muslim}{1770}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ فِي اللَّيْلِ لَسَاعَةً لاَ يُوَافِقُهَا رَجُلٌ مُسْلِمٌ يَسْأَلُ اللَّهَ خَيْرًا مِنْ أَمْرِ الدُّنْيَا وَالآخِرَةِ إِلاَّ أَعْطَاهُ إِيَّاهُ وَذَلِكَ كُلَّ لَيْلَةٍ ‏"‏ ‏.‏\hadithno{1770}\hadithtrans{Jabir said he heard Allah's Messenger (ﷺ) say:There is an hour during the night in which no Muslim individual will ask Allah for good in this world and the next without His giving it to him; and that applies to every night}}
\hadithdefcmd{muslim}{1771}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ مِنَ اللَّيْلِ سَاعَةً لاَ يُوَافِقُهَا عَبْدٌ مُسْلِمٌ يَسْأَلُ اللَّهَ خَيْرًا إِلاَّ أَعْطَاهُ إِيَّاهُ ‏"‏ ‏.‏\hadithno{1771}\hadithtrans{Jabir reported:I heard the Messenger of Allah (ﷺ) as saying: There is an hour during the night in which no Muslim bondman will ask Allah for good in this world and the next but He will grant it to him}}
\hadithdefcmd{muslim}{1772}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي عَبْدِ اللَّهِ الأَغَرِّ، وَعَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَنْزِلُ رَبُّنَا تَبَارَكَ وَتَعَالَى كُلَّ لَيْلَةٍ إِلَى السَّمَاءِ الدُّنْيَا حِينَ يَبْقَى ثُلُثُ اللَّيْلِ الآخِرُ فَيَقُولُ مَنْ يَدْعُونِي فَأَسْتَجِيبَ لَهُ وَمَنْ يَسْأَلُنِي فَأُعْطِيَهُ وَمَنْ يَسْتَغْفِرُنِي فَأَغْفِرَ لَهُ ‏"‏ ‏.‏\hadithno{1772}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Our Lord, the Blessed and the Exalted, descends every night to the lowest heaven when one-third of the latter part of the night is left, and says: Who supplicates Me so that I may answer him? Who asks Me so that I may give to him? Who asks Me forgiveness so that I may forgive him?}}
\hadithdefcmd{muslim}{1773}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ عَبْدِ الرَّحْمَنِ الْقَارِيُّ - عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَنْزِلُ اللَّهُ إِلَى السَّمَاءِ الدُّنْيَا كُلَّ لَيْلَةٍ حِينَ يَمْضِي ثُلُثُ اللَّيْلِ الأَوَّلُ فَيَقُولُ أَنَا الْمَلِكُ أَنَا الْمَلِكُ مَنْ ذَا الَّذِي يَدْعُونِي فَأَسْتَجِيبَ لَهُ مَنْ ذَا الَّذِي يَسْأَلُنِي فَأُعْطِيَهُ مَنْ ذَا الَّذِي يَسْتَغْفِرُنِي فَأَغْفِرَ لَهُ فَلاَ يَزَالُ كَذَلِكَ حَتَّى يُضِيءَ الْفَجْرُ ‏"‏ ‏.‏\hadithno{1773}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Allah descends every night to the lowest heaven when one-third of the first part of the night is over and says: I am the Lord; I am the Lord: who is there to supplicate Me so that I answer him? Who is there to beg of Me so that I grant him? Who is there to beg forgiveness from Me so that I forgive him? He continues like this till the day breaks}}
\hadithdefcmd{muslim}{1774}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا أَبُو الْمُغِيرَةِ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنَا يَحْيَى، حَدَّثَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا مَضَى شَطْرُ اللَّيْلِ أَوْ ثُلُثَاهُ يَنْزِلُ اللَّهُ تَبَارَكَ وَتَعَالَى إِلَى السَّمَاءِ الدُّنْيَا فَيَقُولُ هَلْ مِنْ سَائِلٍ يُعْطَى هَلْ مِنْ دَاعٍ يُسْتَجَابُ لَهُ هَلْ مِنْ مُسْتَغْفِرٍ يُغْفَرُ لَهُ حَتَّى يَنْفَجِرَ الصُّبْحُ ‏"‏ ‏.‏\hadithno{1774}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When half of the night or two-third of it is over. Allah, the Blessed and the Exalted, descends to the lowest heaven and says: Is there any beggar, so that he be given? Is there any supplicator so that he be answered? Is there any beggar of forgiveness so that he be forgiven? (And Allah continues it saying) till it is daybreak}}
\hadithdefcmd{muslim}{1775}{حَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنَا مُحَاضِرٌ أَبُو الْمُوَرِّعِ، حَدَّثَنَا سَعْدُ بْنُ سَعِيدٍ، قَالَ أَخْبَرَنِي ابْنُ مَرْجَانَةَ، قَالَ سَمِعْتُ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَنْزِلُ اللَّهُ فِي السَّمَاءِ الدُّنْيَا لِشَطْرِ اللَّيْلِ أَوْ لِثُلُثِ اللَّيْلِ الآخِرِ فَيَقُولُ مَنْ يَدْعُونِي فَأَسْتَجِيبَ لَهُ أَوْ يَسْأَلُنِي فَأُعْطِيَهُ ‏.‏ ثُمَّ يَقُولُ مَنْ يُقْرِضُ غَيْرَ عَدِيمٍ وَلاَ ظَلُومٍ ‏"‏ ‏.‏ قَالَ مُسْلِمٌ ابْنُ مَرْجَانَةَ هُوَ سَعِيدُ بْنُ عَبْدِ اللَّهِ وَمَرْجَانَةُ أُمُّهُ ‏.‏ حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي سُلَيْمَانُ بْنُ بِلاَلٍ، عَنْ سَعْدِ بْنِ سَعِيدٍ، بِهَذَا الإِسْنَادِ وَزَادَ ‏"‏ ثُمَّ يَبْسُطُ يَدَيْهِ تَبَارَكَ وَتَعَالَى يَقُولُ مَنْ يُقْرِضُ غَيْرَ عَدُومٍ وَلاَ ظَلُومٍ ‏"‏ ‏.‏\hadithno{1775}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Allah descends to the lowest heaven at half of the night or at one-third of the latter part and says: Who is there to supplicate Me so that I answer him? Who is there to ask Me so that I grant him? And then says: Who will lend to One Who is neither indigent nor tyrant? (This hadith has been narrated by Sa'd b. Sa'id with the same chain of transmitters with this addition:" Then the Blessed and the Exalted (Lord) stretches His Hands and says: Who will lend to One Who is neither indigent nor tyrant?}}
\hadithdefcmd{muslim}{1776}{حَدَّثَنَا عُثْمَانُ، وَأَبُو بَكْرٍ ابْنَا أَبِي شَيْبَةَ وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ - وَاللَّفْظُ لاِبْنَىْ أَبِي شَيْبَةَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَغَرِّ أَبِي مُسْلِمٍ، يَرْوِيهِ عَنْ أَبِي سَعِيدٍ، وَأَبِي، هُرَيْرَةَ قَالاَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يُمْهِلُ حَتَّى إِذَا ذَهَبَ ثُلُثُ اللَّيْلِ الأَوَّلُ نَزَلَ إِلَى السَّمَاءِ الدُّنْيَا فَيَقُولُ هَلْ مِنْ مُسْتَغْفِرٍ هَلْ مِنْ تَائِبٍ هَلْ مِنْ سَائِلٍ هَلْ مِنْ دَاعٍ حَتَّى يَنْفَجِرَ الْفَجْرُ ‏"‏ ‏.‏\hadithno{1776}\hadithtrans{Abu Sa'id and Abu Huraira reported Allah's Messenger (ﷺ) as saying:Allah waits till when one-third of the first part of the night is over; He descends to the lowest heaven and says: It there any supplicator of forgiveness? Is there any penitant? Is there any petitioner (for mercy and favour)? Is there any solicitor? -till it is daybreak}}
\hadithdefcmd{muslim}{1777}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، بِهَذَا الإِسْنَادِ ‏.‏ غَيْرَ أَنَّ حَدِيثَ، مَنْصُورٍ أَتَمُّ وَأَكْثَرُ ‏.‏\hadithno{1777}\hadithtrans{This hadith is narrated by Ishaq with the same chain uf transmitters except this that the hadith transmitted by Mansur (the above one) is more comprehensive and lengthy}}
\hadithdefcmd{muslim}{1779}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{1779}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who observed prayer at night during Ramadan, because of faith and seeking his reward from Allah, his previous sins would be forgiven}}
\hadithdefcmd{muslim}{1780}{وَحَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُرَغِّبُ فِي قِيَامِ رَمَضَانَ مِنْ غَيْرِ أَنْ يَأْمُرَهُمْ فِيهِ بِعَزِيمَةٍ فَيَقُولُ ‏ "‏ مَنْ قَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏ فَتُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَالأَمْرُ عَلَى ذَلِكَ ثُمَّ كَانَ الأَمْرُ عَلَى ذَلِكَ فِي خِلاَفَةِ أَبِي بَكْرٍ وَصَدْرًا مِنْ خِلاَفَةِ عُمَرَ عَلَى ذَلِكَ ‏.‏\hadithno{1780}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) used to exhort (his Companions) to pray (at night) during Ramadan without commanding them to observe it as an obligatory act, and say: He who observed the night prayer in Ramadan because of faith and seeking his reward (from Allah), all his previous sins would be forgiven. When Allah's Messenger (ﷺ) died, this was the practice, and it continued thus during Abu Bakr's caliphate and the early part of 'Umar's caliphate}}
\hadithdefcmd{muslim}{1781}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، قَالَ حَدَّثَنَا أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ أَبَا هُرَيْرَةَ، حَدَّثَهُمْ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَامَ رَمَضَانَ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَنْ قَامَ لَيْلَةَ الْقَدْرِ إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏ ‏.‏\hadithno{1781}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:He who observed the fasts of Ramadan with faith and seeking reward (from Allah), all his previous sins would be forgiven, and he who observed prayer on Lailat-ul- Qadr with faith and seeking reward (from Allah), all his previous sins would be forgiven}}
\hadithdefcmd{muslim}{1782}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا شَبَابَةُ، حَدَّثَنِي وَرْقَاءُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ يَقُمْ لَيْلَةَ الْقَدْرِ فَيُوَافِقُهَا - أُرَاهُ قَالَ - إِيمَانًا وَاحْتِسَابًا غُفِرَ لَهُ ‏"‏ ‏.‏\hadithno{1782}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying:He who prayed on the Lailat-ul-Qadr (the Majestic Night) knowing that it is (the same night). I (believe) that he (the Prophet also) said: (He who does) it with faith and seeking reward (from Allah), his sins would be forgiven}}
\hadithdefcmd{muslim}{1783}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى فِي الْمَسْجِدِ ذَاتَ لَيْلَةٍ فَصَلَّى بِصَلاَتِهِ نَاسٌ ثُمَّ صَلَّى مِنَ الْقَابِلَةِ فَكَثُرَ النَّاسُ ثُمَّ اجْتَمَعُوا مِنَ اللَّيْلَةِ الثَّالِثَةِ أَوِ الرَّابِعَةِ فَلَمْ يَخْرُجْ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَلَمَّا أَصْبَحَ قَالَ ‏ "‏ قَدْ رَأَيْتُ الَّذِي صَنَعْتُمْ فَلَمْ يَمْنَعْنِي مِنَ الْخُرُوجِ إِلَيْكُمْ إِلاَّ أَنِّي خَشِيتُ أَنْ تُفْرَضَ عَلَيْكُمْ ‏"‏ ‏.‏ قَالَ وَذَلِكَ فِي رَمَضَانَ ‏.‏\hadithno{1783}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) prayed one night in the mosque and people also prayed along with him. He then prayed on the following night and there were many persons. Then on the third or fourth night (many people) gathered there, but the Messenger of Allah (ﷺ) did not come out to them (for leading the Tarawih prayer). When it was morning he said:I saw what you were doing, but I desisted to come to you (and lead the prayer) for I feared that this prayer might become obligatory for you. (He the narrator) said: It was the month of Ramadan}}
\hadithdefcmd{muslim}{1784}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ بْنُ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ مِنْ جَوْفِ اللَّيْلِ فَصَلَّى فِي الْمَسْجِدِ فَصَلَّى رِجَالٌ بِصَلاَتِهِ فَأَصْبَحَ النَّاسُ يَتَحَدَّثُونَ بِذَلِكَ فَاجْتَمَعَ أَكْثَرُ مِنْهُمْ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم فِي اللَّيْلَةِ الثَّانِيَةِ فَصَلَّوْا بِصَلاَتِهِ فَأَصْبَحَ النَّاسُ يَذْكُرُونَ ذَلِكَ فَكَثُرَ أَهْلُ الْمَسْجِدِ مِنَ اللَّيْلَةِ الثَّالِثَةِ فَخَرَجَ فَصَلَّوْا بِصَلاَتِهِ فَلَمَّا كَانَتِ اللَّيْلَةُ الرَّابِعَةُ عَجَزَ الْمَسْجِدُ عَنْ أَهْلِهِ فَلَمْ يَخْرُجْ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم فَطَفِقَ رِجَالٌ مِنْهُمْ يَقُولُونَ الصَّلاَةَ ‏.‏ فَلَمْ يَخْرُجْ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى خَرَجَ لِصَلاَةِ الْفَجْرِ فَلَمَّا قَضَى الْفَجْرَ أَقْبَلَ عَلَى النَّاسِ ثُمَّ تَشَهَّدَ فَقَالَ ‏ "‏ أَمَّا بَعْدُ فَإِنَّهُ لَمْ يَخْفَ عَلَىَّ شَأْنُكُمُ اللَّيْلَةَ وَلَكِنِّي خَشِيتُ أَنْ تُفْرَضَ عَلَيْكُمْ صَلاَةُ اللَّيْلِ فَتَعْجِزُوا عَنْهَا ‏"‏ ‏.‏\hadithno{1784}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) came out during the night and observed prayer in the mosque and some of the people prayed along with him. When it was morning the people talked about this and so a large number of people gathered there. The Messenger of Allah (ﷺ) went out for the second night, and they (the people) prayed along with him. When it was morning the people began to talk about it. So the mosque thronged with people on the third night. He (the Holy Prophet) came out and they prayed along with him. When it was the fourth night, the mosque was filled to its utmost capacity but the Messenger of Allah (ﷺ) did not come out. Some persons among then cried:" Prayer." But the Messenger of Allah (ﷺ) did not come to them till he came out for the morning prayer. When he had completed the morning prayer, he turned his face to the people and recited Tashahhud (I bear testi- mony that there is no god but Allah and I bear testimony that Muhammad is His Messen- ger) and then said: Your affair was not hidden from me in the night, but I was afraid that (my observing prayer continuously) might make the night prayer obligatory for you and you might be unable to perform it}}
\hadithdefcmd{muslim}{1785}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ الرَّازِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي عَبْدَةُ، عَنْ زِرٍّ، قَالَ سَمِعْتُ أُبَىَّ بْنَ كَعْبٍ، يَقُولُ - وَقِيلَ لَهُ إِنَّ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ يَقُولُ مَنْ قَامَ السَّنَةَ أَصَابَ لَيْلَةَ الْقَدْرِ - فَقَالَ أُبَىٌّ وَاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ إِنَّهَا لَفِي رَمَضَانَ - يَحْلِفُ مَا يَسْتَثْنِي - وَوَاللَّهِ إِنِّي لأَعْلَمُ أَىُّ لَيْلَةٍ هِيَ ‏.‏ هِيَ اللَّيْلَةُ الَّتِي أَمَرَنَا بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِقِيَامِهَا هِيَ لَيْلَةُ صَبِيحَةِ سَبْعٍ وَعِشْرِينَ وَأَمَارَتُهَا أَنْ تَطْلُعَ الشَّمْسُ فِي صَبِيحَةِ يَوْمِهَا بَيْضَاءَ لاَ شُعَاعَ لَهَا ‏.‏\hadithno{1785}\hadithtrans{Zirr (b. Hubaish) reported:I heard from Ubayy b. Ka'b a statement made by 'Abdullah b. Mas'ud in which he said: He who gets up for prayer (every night) during the year will hit upon Lailat-ul-Qadr. Ubayy said: By Allah I there is no god but He, that (Lailat-ul-Qadr) is in Ramadhan (He swore without reservation: ) By Allah, I know the night; it is the night on which the Messenger of Allah (ﷺ) commanded us to pray. It is that which precedes the morning of twenty-seventy and its indication is that the sun rises bright on that day without rays}}
\hadithdefcmd{muslim}{1786}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ عَبْدَةَ بْنَ أَبِي لُبَابَةَ، يُحَدِّثُ عَنْ زِرِّ بْنِ حُبَيْشٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ أُبَىٌّ فِي لَيْلَةِ الْقَدْرِ وَاللَّهِ إِنِّي لأَعْلَمُهَا وَأَكْثَرُ عِلْمِي هِيَ اللَّيْلَةُ الَّتِي أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِقِيَامِهَا هِيَ لَيْلَةُ سَبْعٍ وَعِشْرِينَ - وَإِنَّمَا شَكَّ شُعْبَةُ فِي هَذَا الْحَرْفِ - هِيَ اللَّيْلَةُ الَّتِي أَمَرَنَا بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ وَحَدَّثَنِي بِهَا صَاحِبٌ لِي عَنْهُ ‏.‏\hadithno{1786}\hadithtrans{Ubayy b Ka'b reported:By Allah, I know about Lailat-ul Qadr and I know it fully well that it is the twenty-seventh night (during Ramadan) on which the Messenger of Allah (ﷺ) commanded us to observe prayer. (Shu'ba was in doubt about these words:" the night on which the Messenger of Allah [may peace be upon him] commanded us to observe the prayer." This has been transmitted to me by a friend of mine}}
\hadithdefcmd{muslim}{1787}{وَحَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ ‏.‏ نَحْوَهُ وَلَمْ يَذْكُرْ إِنَّمَا شَكَّ شُعْبَةُ ‏.‏ وَمَا بَعْدَهُ ‏.‏\hadithno{1787}\hadithtrans{Shu'ba reported this hadith with the same chain of transmitters, but he made no mention that Shu'ba was in doubt and what follows subsequently}}
\hadithdefcmd{muslim}{1788}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ هَاشِمِ بْنِ حَيَّانَ الْعَبْدِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ مَهْدِيٍّ - حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بِتُّ لَيْلَةً عِنْدَ خَالَتِي مَيْمُونَةَ فَقَامَ النَّبِيُّ صلى الله عليه وسلم مِنَ اللَّيْلِ فَأَتَى حَاجَتَهُ ثُمَّ غَسَلَ وَجْهَهُ وَيَدَيْهِ ثُمَّ نَامَ ثُمَّ قَامَ فَأَتَى الْقِرْبَةَ فَأَطْلَقَ شِنَاقَهَا ثُمَّ تَوَضَّأَ وُضُوءًا بَيْنَ الْوُضُوءَيْنِ وَلَمْ يُكْثِرْ وَقَدْ أَبْلَغَ ثُمَّ قَامَ فَصَلَّى فَقُمْتُ فَتَمَطَّيْتُ كَرَاهِيَةَ أَنْ يَرَى أَنِّي كُنْتُ أَنْتَبِهُ لَهُ فَتَوَضَّأْتُ فَقَامَ فَصَلَّى فَقُمْتُ عَنْ يَسَارِهِ فَأَخَذَ بِيَدِي فَأَدَارَنِي عَنْ يَمِينِهِ فَتَتَامَّتْ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنَ اللَّيْلِ ثَلاَثَ عَشْرَةَ رَكْعَةً ثُمَّ اضْطَجَعَ فَنَامَ حَتَّى نَفَخَ وَكَانَ إِذَا نَامَ نَفَخَ فَأَتَاهُ بِلاَلٌ فَآذَنَهُ بِالصَّلاَةِ فَقَامَ فَصَلَّى وَلَمْ يَتَوَضَّأْ وَكَانَ فِي دُعَائِهِ ‏ "‏ اللَّهُمَّ اجْعَلْ فِي قَلْبِي نُورًا وَفِي بَصَرِي نُورًا وَفِي سَمْعِي نُورًا وَعَنْ يَمِينِي نُورًا وَعَنْ يَسَارِي نُورًا وَفَوْقِي نُورًا وَتَحْتِي نُورًا وَأَمَامِي نُورًا وَخَلْفِي نُورًا وَعَظِّمْ لِي نُورًا ‏"‏ ‏.‏ قَالَ كُرَيْبٌ وَسَبْعًا فِي التَّابُوتِ فَلَقِيتُ بَعْضَ وَلَدِ الْعَبَّاسِ فَحَدَّثَنِي بِهِنَّ فَذَكَرَ عَصَبِي وَلَحْمِي وَدَمِي وَشَعَرِي وَبَشَرِي وَذَكَرَ خَصْلَتَيْنِ ‏.‏\hadithno{1788}\hadithtrans{Ibn `Abbas reported:I spent a night with my maternal aunt (sister of my mother) Maimuna. The Apostle of Allah (ﷺ) got up during the night and relieved himself, then washed his face and hands and went to sleep. He then got up again, and came to the water skin and loosened its straps, then performed good ablution between the two extremes. He then stood up and observed prayer. I also stood up and stretched my body fearing that he might be under the impression that I was there to find out (what he did at night). So I also performed ablution and stood up to pray, but I stood on his left. He took hold of my hand and made me go around to his right side. The Messenger of Allah (ﷺ) completed thirteen rak`ahs of his night prayer. He then lay down and slept and snored (and it was his habit to snore while asleep). Then Bilal came and he informed him about the prayer. He (the Holy Prophet) then stood up for prayer and did not perform ablution, and his supplication included these words: "O Allah, place light in my heart, light in my sight, light in my hearing, light on my right hand, light on my left hand, light above me, light below me, light in front of me, light behind me, and enhance light for me." Kuraib (the narrator) said: There are seven (words more) which are in my heart (but I cannot recall them) and I met some of the descendants of Al-`Abbas and they narrated these words to me and mentioned in them: (Light) in my sinew, in my flesh, in my blood, in my hair, in my skin, and made a mention of two more things}}
\hadithdefcmd{muslim}{1789}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ أَنَّ ابْنَ عَبَّاسٍ، أَخْبَرَهُ أَنَّهُ، بَاتَ لَيْلَةً عِنْدَ مَيْمُونَةَ أُمِّ الْمُؤْمِنِينَ - وَهِيَ خَالَتُهُ - قَالَ فَاضْطَجَعْتُ فِي عَرْضِ الْوِسَادَةِ وَاضْطَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَهْلُهُ فِي طُولِهَا فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى انْتَصَفَ اللَّيْلُ أَوْ قَبْلَهُ بِقَلِيلٍ أَوْ بَعْدَهُ بِقَلِيلٍ اسْتَيْقَظَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَجَعَلَ يَمْسَحُ النَّوْمَ عَنْ وَجْهِهِ بِيَدِهِ ثُمَّ قَرَأَ الْعَشْرَ الآيَاتِ الْخَوَاتِمَ مِنْ سُورَةِ آلِ عِمْرَانَ ثُمَّ قَامَ إِلَى شَنٍّ مُعَلَّقَةٍ فَتَوَضَّأَ مِنْهَا فَأَحْسَنَ وُضُوءَهُ ثُمَّ قَامَ فَصَلَّى ‏.‏ قَالَ ابْنُ عَبَّاسٍ فَقُمْتُ فَصَنَعْتُ مِثْلَ مَا صَنَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ ذَهَبْتُ فَقُمْتُ إِلَى جَنْبِهِ فَوَضَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَهُ الْيُمْنَى عَلَى رَأْسِي وَأَخَذَ بِأُذُنِي الْيُمْنَى يَفْتِلُهَا فَصَلَّى رَكْعَتَيْنِ ثُمَّ رَكْعَتَيْنِ ثُمَّ رَكْعَتَيْنِ ثُمَّ رَكْعَتَيْنِ ثُمَّ رَكْعَتَيْنِ ثُمَّ رَكْعَتَيْنِ ثُمَّ أَوْتَرَ ثُمَّ اضْطَجَعَ حَتَّى جَاءَ الْمُؤَذِّنُ فَقَامَ فَصَلَّى رَكْعَتَيْنِ خَفِيفَتَيْنِ ثُمَّ خَرَجَ فَصَلَّى الصُّبْحَ ‏.‏\hadithno{1789}\hadithtrans{Kuraib, the freed slave of Ibn `Abbas, reported that Ibn `Abbas narrated to him that he spent a night in the house of Maimuna, the mother of the believers, who was his mother's sister. I lay down across the cushion, whereas the Messenger of Allah (ﷺ) and his wife lay down on it length-wise. The Messenger of Allah (ﷺ) slept till midnight, or a little before midnight, or a little after midnight, and then got up and began to cast off the effects of sleep from his face by rubbing with his hand, and then recited the ten concluding verses of Surah Al-`Imran. He then stood up near a hanging water-skin and performed ablution well, and then stood up and prayed, Ibn `Abbas said:I also stood up and did the same, as the Messenger of Allah (ﷺ) had done, and then went to him and stood by his side. The Messenger of Allah (ﷺ) placed his right hand upon my head and took hold of my right ear and twisted it, and then observed a pair of rak`ahs, again a pair of rak`ahs, again a pair of rak`ahs, again a pair of rak`ahs, again a pair of rak`ahs, again a pair of rak`ahs, and then observed Witr and then lay down till the Mu'adhdhin came to him. He (the Holy Prophet) then stood up and observed two short rak`ahs, and then went out (to the mosque) and observed the dawn prayer}}
\hadithdefcmd{muslim}{1790}{وَحَدَّثَنِي مُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ عِيَاضِ بْنِ عَبْدِ اللَّهِ الْفِهْرِيِّ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، بِهَذَا الإِسْنَادِ وَزَادَ ثُمَّ عَمَدَ إِلَى شَجْبٍ مِنْ مَاءٍ فَتَسَوَّكَ وَتَوَضَّأَ وَأَسْبَغَ الْوُضُوءَ وَلَمْ يُهْرِقْ مِنَ الْمَاءِ إِلاَّ قَلِيلاً ثُمَّ حَرَّكَنِي فَقُمْتُ ‏.‏ وَسَائِرُ الْحَدِيثِ نَحْوُ حَدِيثِ مَالِكٍ ‏.‏\hadithno{1790}\hadithtrans{Makhrama b. Sulaiman narrated it with the same chain of narrators and he made this addition:"He then went to the water-skin and brushed his teeth and performed ablution well. He did not pour water but a little. He then awakened me and I stood up," and the rest of the hadith is the same}}
\hadithdefcmd{muslim}{1791}{حَدَّثَنِي هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنَا عَمْرٌو، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ نِمْتُ عِنْدَ مَيْمُونَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَرَسُولُ اللَّهِ صلى الله عليه وسلم عِنْدَهَا تِلْكَ اللَّيْلَةَ فَتَوَضَّأَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَامَ فَصَلَّى فَقُمْتُ عَنْ يَسَارِهِ فَأَخَذَنِي فَجَعَلَنِي عَنْ يَمِينِهِ فَصَلَّى فِي تِلْكَ اللَّيْلَةِ ثَلاَثَ عَشْرَةَ رَكْعَةً ثُمَّ نَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى نَفَخَ وَكَانَ إِذَا نَامَ نَفَخَ ثُمَّ أَتَاهُ الْمُؤَذِّنُ فَخَرَجَ فَصَلَّى وَلَمْ يَتَوَضَّأْ ‏.‏ قَالَ عَمْرٌو فَحَدَّثْتُ بِهِ بُكَيْرَ بْنَ الأَشَجِّ فَقَالَ حَدَّثَنِي كُرَيْبٌ بِذَلِكَ ‏.‏\hadithno{1791}\hadithtrans{Ibn `Abbas reported:I slept (one night) in the house of Maimuna, the wife of the Messenger of Allah (ﷺ), and the Messenger of Allah (ﷺ) was with her that night. He (after sleeping for half of the night got up and) then performed ablution and then stood up and observed prayer. I too stood on his left side. He took hold of me and made me stand on his right side. He (the Holy Prophet) observed thirteen rak`ahs on that night. The Messenger of Allah (ﷺ) then slept and snored and it was a habit with him to snore while sleeping. The Mu'adhdhin then came to him (to inform him about the prayer). He then went out and observed prayer without performing ablution. (`Amr said: Bukair b. Ashajj had narrated it to me)}}
\hadithdefcmd{muslim}{1792}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، أَخْبَرَنَا الضَّحَّاكُ، عَنْ مَخْرَمَةَ بْنِ سُلَيْمَانَ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، قَالَ بِتُّ لَيْلَةً عِنْدَ خَالَتِي مَيْمُونَةَ بِنْتِ الْحَارِثِ فَقُلْتُ لَهَا إِذَا قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَأَيْقِظِينِي ‏.‏ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُمْتُ إِلَى جَنْبِهِ الأَيْسَرِ فَأَخَذَ بِيَدِي فَجَعَلَنِي مِنْ شِقِّهِ الأَيْمَنِ فَجَعَلْتُ إِذَا أَغْفَيْتُ يَأْخُذُ بِشَحْمَةِ أُذُنِي - قَالَ - فَصَلَّى إِحْدَى عَشْرَةَ رَكْعَةً ثُمَّ احْتَبَى حَتَّى إِنِّي لأَسْمَعُ نَفَسَهُ رَاقِدًا فَلَمَّا تَبَيَّنَ لَهُ الْفَجْرُ صَلَّى رَكْعَتَيْنِ خَفِيفَتَيْنِ ‏.‏\hadithno{1792}\hadithtrans{Ibn `Abbas reported:I spent one night in the house of my mother's sister Maimuna, daughter of Al-Harith, and said to her: Awake me when the Messenger of Allah (ﷺ) stands to pray (at night). (She woke me up when) the Messenger of Allah (ﷺ) stood up for prayer. I stood on his left side. He took hold of my hand and made me stand on his right side, and whenever I dozed off he took hold of my earlobe (and made me alert). He (the narrator) said: He (the Holy Prophet) observed eleven rak`ahs. He then sat with his legs drawn and wrapped in his garment and slept so that I could hear his breathing while asleep. And when the dawn appeared, he observed two short rak`ahs of (Sunnah) prayer}}
\hadithdefcmd{muslim}{1793}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، وَمُحَمَّدُ بْنُ حَاتِمٍ، عَنِ ابْنِ عُيَيْنَةَ، - قَالَ ابْنُ أَبِي عُمَرَ حَدَّثَنَا سُفْيَانُ، - عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ بَاتَ عِنْدَ خَالَتِهِ مَيْمُونَةَ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ اللَّيْلِ فَتَوَضَّأَ مِنْ شَنٍّ مُعَلَّقٍ وُضُوءًا خَفِيفًا - قَالَ وَصَفَ وُضُوءَهُ وَجَعَلَ يُخَفِّفُهُ وَيُقَلِّلُهُ - قَالَ ابْنُ عَبَّاسٍ فَقُمْتُ فَصَنَعْتُ مِثْلَ مَا صَنَعَ النَّبِيُّ صلى الله عليه وسلم ثُمَّ جِئْتُ فَقُمْتُ عَنْ يَسَارِهِ فَأَخْلَفَنِي فَجَعَلَنِي عَنْ يَمِينِهِ فَصَلَّى ثُمَّ اضْطَجَعَ فَنَامَ حَتَّى نَفَخَ ثُمَّ أَتَاهُ بِلاَلٌ فَآذَنَهُ بِالصَّلاَةِ فَخَرَجَ فَصَلَّى الصُّبْحَ وَلَمْ يَتَوَضَّأْ ‏.‏ قَالَ سُفْيَانُ وَهَذَا لِلنَّبِيِّ صلى الله عليه وسلم خَاصَّةً لأَنَّهُ بَلَغَنَا أَنَّ النَّبِيَّ صلى الله عليه وسلم تَنَامُ عَيْنَاهُ وَلاَ يَنَامُ قَلْبُهُ ‏.‏\hadithno{1793}\hadithtrans{Ibn `Abbas reported that he spent a night in the house of his maternal aunt, Maimuna. The Messenger of Allah (ﷺ) got up at night and performed a short ablution (taking water) from the water-skin hanging there. (Giving a description of the ablution Ibn `Abbas said:It was short and performed with a little water.) I also got up and did the same as the Messenger of Allah (ﷺ) had done. I then came (to him) and stood on his left. He then made me go around to his right side. He then observed prayer and went to sleep till he began to snore. Bilal came to him and informed him about the prayer. He (the Holy Prophet) then went out and observed the dawn prayer without performing ablution. Sufyan said: It was a special (prerogative of the) Apostle of Allah (ﷺ) for it has been conveyed to us that the eyes of the Messenger of Allah (ﷺ) sleep, but his heart does not sleep}}
\hadithdefcmd{muslim}{1794}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدٌ، - وَهُوَ ابْنُ جَعْفَرٍ - حَدَّثَنَا شُعْبَةُ، عَنْ سَلَمَةَ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بِتُّ فِي بَيْتِ خَالَتِي مَيْمُونَةَ فَبَقَيْتُ كَيْفَ يُصَلِّي رَسُولُ اللَّهِ صلى الله عليه وسلم - قَالَ - فَقَامَ فَبَالَ ثُمَّ غَسَلَ وَجْهَهُ وَكَفَّيْهِ ثُمَّ نَامَ ثُمَّ قَامَ إِلَى الْقِرْبَةِ فَأَطْلَقَ شِنَاقَهَا ثُمَّ صَبَّ فِي الْجَفْنَةِ أَوِ الْقَصْعَةِ فَأَكَبَّهُ بِيَدِهِ عَلَيْهَا ثُمَّ تَوَضَّأَ وُضُوءًا حَسَنًا بَيْنَ الْوُضُوءَيْنِ ثُمَّ قَامَ يُصَلِّي فَجِئْتُ فَقُمْتُ إِلَى جَنْبِهِ فَقُمْتُ عَنْ يَسَارِهِ - قَالَ - فَأَخَذَنِي فَأَقَامَنِي عَنْ يَمِينِهِ فَتَكَامَلَتْ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم ثَلاَثَ عَشْرَةَ رَكْعَةً ثُمَّ نَامَ حَتَّى نَفَخَ وَكُنَّا نَعْرِفُهُ إِذَا نَامَ بِنَفْخِهِ ثُمَّ خَرَجَ إِلَى الصَّلاَةِ فَصَلَّى فَجَعَلَ يَقُولُ فِي صَلاَتِهِ أَوْ فِي سُجُودِهِ ‏ "‏ اللَّهُمَّ اجْعَلْ فِي قَلْبِي نُورًا وَفِي سَمْعِي نُورًا وَفِي بَصَرِي نُورًا وَعَنْ يَمِينِي نُورًا وَعَنْ شِمَالِي نُورًا وَأَمَامِي نُورًا وَخَلْفِي نُورًا وَفَوْقِي نُورًا وَتَحْتِي نُورًا وَاجْعَلْ لِي نُورًا أَوْ قَالَ وَاجْعَلْنِي نُورًا ‏"‏ ‏.‏\hadithno{1794}\hadithtrans{Ibn `Abbas said:I spent the night in the house of my mother's sister, Maimuna, and observed how the Messenger of Allah (ﷺ) prayed (at night). He got up and relieved himself. He then washed his face and hands and then went to sleep. He again got up and went near the water-skin and loosened its straps and then poured some water in a bowl and inclined it with his hands (towards himself). He then performed a good ablution between the two extremes and then stood up to pray. I also came and stood by his left side. He took hold of me and made me stand on his right side. It was in thirteen rak`ahs that the (night) prayer of the Messenger of Allah (ﷺ) was completed. He then slept till he began to snore, and we knew that he had gone to sleep by his snoring. He then went out (for the dawn prayer), and said while praying or prostrating himself: "O Allah! place light in my heart, light in my hearing, light in my sight, light on my right, light on my left, light in front of me, light behind me, light above me, light below me, make light for me," or he said: "Make me light}}
\hadithdefcmd{muslim}{1795}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا النَّضْرُ بْنُ شُمَيْلٍ، أَخْبَرَنَا شُعْبَةُ، حَدَّثَنَا سَلَمَةُ بْنُ كُهَيْلٍ، عَنْ بُكَيْرٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، ‏.‏ قَالَ سَلَمَةُ فَلَقِيتُ كُرَيْبًا فَقَالَ قَالَ ابْنُ عَبَّاسٍ كُنْتُ عِنْدَ خَالَتِي مَيْمُونَةَ فَجَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ غُنْدَرٍ ‏.‏ وَقَالَ ‏ "‏ وَاجْعَلْنِي نُورًا ‏"‏ ‏.‏ وَلَمْ يَشُكَّ ‏.‏\hadithno{1795}\hadithtrans{Salama said:I met Kuraib and he reported Ibn `Abbas as saying: I was with my mother's sister Maimuna and the Messenger of Allah (ﷺ) came there, and then he narrated the rest of the hadith as was narrated by Ghundar and said these words: "Make me light," beyond any doubt}}
\hadithdefcmd{muslim}{1796}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَهَنَّادُ بْنُ السَّرِيِّ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سَعِيدِ بْنِ مَسْرُوقٍ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ أَبِي رِشْدِينٍ، مَوْلَى ابْنِ عَبَّاسٍ عَنِ ابْنِ عَبَّاسٍ، قَالَ بِتُّ عِنْدَ خَالَتِي مَيْمُونَةَ ‏.‏ وَاقْتَصَّ الْحَدِيثَ وَلَمْ يَذْكُرْ غَسْلَ الْوَجْهِ وَالْكَفَّيْنِ غَيْرَ أَنَّهُ قَالَ ثُمَّ أَتَى الْقِرْبَةَ فَحَلَّ شِنَاقَهَا فَتَوَضَّأَ وُضُوءًا بَيْنَ الْوُضُوءَيْنِ ثُمَّ أَتَى فِرَاشَهُ فَنَامَ ثُمَّ قَامَ قَوْمَةً أُخْرَى فَأَتَى الْقِرْبَةَ فَحَلَّ شِنَاقَهَا ثُمَّ تَوَضَّأَ وُضُوءًا هُوَ الْوُضُوءُ وَقَالَ ‏"‏ أَعْظِمْ لِي نُورًا ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ ‏"‏ وَاجْعَلْنِي نُورًا ‏"‏ ‏.‏\hadithno{1796}\hadithtrans{Ibn `Abbas reported:I spent a night in the house of my mother's sister, Maimuna, and then narrated (the rest of the) hadith, but he made no mention of the washing of his face and two hands but he only said: He then came to the water-skin and loosened its straps and performed ablution between the two extremes, and then came to his bed and slept. He then got up for the second time and came to the water-skin and loosened its straps and then performed ablution which was in fact an ablution (it was performed well), and implored (the Lord) thus: "Give me abundant light," and he made no mention of: "Make me light}}
\hadithdefcmd{muslim}{1797}{وَحَدَّثَنِي أَبُو الطَّاهِرِ، حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ سَلْمَانَ الْحَجْرِيِّ، عَنْ عُقَيْلِ بْنِ خَالِدٍ، أَنَّ سَلَمَةَ بْنَ كُهَيْلٍ، حَدَّثَهُ أَنَّ كُرَيْبًا حَدَّثَهُ أَنَّ ابْنَ عَبَّاسٍ بَاتَ لَيْلَةً عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى الْقِرْبَةِ فَسَكَبَ مِنْهَا فَتَوَضَّأَ وَلَمْ يُكْثِرْ مِنَ الْمَاءِ وَلَمْ يُقَصِّرْ فِي الْوُضُوءِ ‏.‏ وَسَاقَ الْحَدِيثَ وَفِيهِ قَالَ وَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَتَئِذٍ تِسْعَ عَشْرَةَ كَلِمَةً ‏.‏ قَالَ سَلَمَةُ حَدَّثَنِيهَا كُرَيْبٌ فَحَفِظْتُ مِنْهَا ثِنْتَىْ عَشْرَةَ وَنَسِيتُ مَا بَقِيَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ اجْعَلْ لِي فِي قَلْبِي نُورًا وَفِي لِسَانِي نُورًا وَفِي سَمْعِي نُورًا وَفِي بَصَرِي نُورًا وَمِنْ فَوْقِي نُورًا وَمِنْ تَحْتِي نُورًا وَعَنْ يَمِينِي نُورًا وَعَنْ شِمَالِي نُورًا وَمِنْ بَيْنِ يَدَىَّ نُورًا وَمِنْ خَلْفِي نُورًا وَاجْعَلْ فِي نَفْسِي نُورًا وَأَعْظِمْ لِي نُورًا ‏"‏ ‏.‏\hadithno{1797}\hadithtrans{Kuraib reported that Ibn `Abbas spent a night in the house of the Messenger of Allah (ﷺ) and he said:The Messenger of Allah (ﷺ) stood near the water-skin and poured water out of it and performed ablution in which he neither used excess of water nor too little of it, and the rest of the hadith is the same, and in this mention is also made (of the fact) that on that night the Messenger of Allah (ﷺ) made supplication before Allah in nineteen words. Kuraib reported: I remember twelve words out of these, but have forgotten the rest. The Messenger of Allah (ﷺ) said: "Place light in my heart, light in my tongue, light in my hearing, light in my sight, light above me, light below me, light on my right, light on my left, light in front of me, light behind me, place light in my soul, and make light abundant for me}}
\hadithdefcmd{muslim}{1798}{وَحَدَّثَنِي أَبُو بَكْرِ بْنُ إِسْحَاقَ، أَخْبَرَنَا ابْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، أَخْبَرَنِي شَرِيكُ بْنُ أَبِي نَمِرٍ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّهُ قَالَ رَقَدْتُ فِي بَيْتِ مَيْمُونَةَ لَيْلَةَ كَانَ النَّبِيُّ صلى الله عليه وسلم عِنْدَهَا لأَنْظُرَ كَيْفَ صَلاَةُ النَّبِيِّ صلى الله عليه وسلم بِاللَّيْلِ - قَالَ - فَتَحَدَّثَ النَّبِيُّ صلى الله عليه وسلم مَعَ أَهْلِهِ سَاعَةً ثُمَّ رَقَدَ ‏.‏ وَسَاقَ الْحَدِيثَ وَفِيهِ ثُمَّ قَامَ فَتَوَضَّأَ وَاسْتَنَّ ‏.‏\hadithno{1798}\hadithtrans{Ibn `Abbas reported:I slept one night in the house of Maimuna when the Messenger of Allah (ﷺ) was there, with a view to seeing the prayer of the Messenger of Allah (ﷺ) at night. The Apostle of Allah (ﷺ) entered into conversation with his wife for a short while, and then went to sleep, and the rest of the hadith is the same and in it mention is made of: "He then got up, performed ablution and brushed his teeth}}
\hadithdefcmd{muslim}{1799}{حَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ حُصَيْنِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ مُحَمَّدِ بْنِ عَلِيِّ بْنِ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبَّاسٍ، أَنَّهُ رَقَدَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَاسْتَيْقَظَ فَتَسَوَّكَ وَتَوَضَّأَ وَهُوَ يَقُولُ ‏\{‏ إِنَّ فِي خَلْقِ السَّمَوَاتِ وَالأَرْضِ وَاخْتِلاَفِ اللَّيْلِ وَالنَّهَارِ لآيَاتٍ لأُولِي الأَلْبَابِ‏\}‏ فَقَرَأَ هَؤُلاَءِ الآيَاتِ حَتَّى خَتَمَ السُّورَةَ ثُمَّ قَامَ فَصَلَّى رَكْعَتَيْنِ فَأَطَالَ فِيهِمَا الْقِيَامَ وَالرُّكُوعَ وَالسُّجُودَ ثُمَّ انْصَرَفَ فَنَامَ حَتَّى نَفَخَ ثُمَّ فَعَلَ ذَلِكَ ثَلاَثَ مَرَّاتٍ سِتَّ رَكَعَاتٍ كُلَّ ذَلِكَ يَسْتَاكُ وَيَتَوَضَّأُ وَيَقْرَأُ هَؤُلاَءِ الآيَاتِ ثُمَّ أَوْتَرَ بِثَلاَثٍ فَأَذَّنَ الْمُؤَذِّنُ فَخَرَجَ إِلَى الصَّلاَةِ وَهُوَ يَقُولُ ‏"‏ اللَّهُمَّ اجْعَلْ فِي قَلْبِي نُورًا وَفِي لِسَانِي نُورًا وَاجْعَلْ فِي سَمْعِي نُورًا وَاجْعَلْ فِي بَصَرِي نُورًا وَاجْعَلْ مِنْ خَلْفِي نُورًا وَمِنْ أَمَامِي نُورًا وَاجْعَلْ مِنْ فَوْقِي نُورًا وَمِنْ تَحْتِي نُورًا ‏.‏ اللَّهُمَّ أَعْطِنِي نُورًا ‏"‏\hadithno{1799}\hadithtrans{Abdullah b. `Abbas reported:He spent (one night) in the house of the Messenger of Allah (ﷺ). He (the Holy Prophet) got up, brushed his teeth and performed ablution and said: "In the creation of the heavens and the earth, and the alternation of the night and the day, there are indeed signs for people of understanding" (al-Qur'an, iii. 190), to the end of the Surah. He then stood up and prayed two rak`ahs, standing, bowing and prostrating himself at length in them. Then he finished, went to sleep and snored. He did that three times, six rak`ahs altogether, each time cleaning his teeth, performing ablution, and reciting these verses. Then he observed three rak`ahs of Witr. The Mu'adhdhin then pronounced the Adhan and he went out for prayer and was saying: "O Allah! place light in my heart, light in my tongue, place light in my hearing, place light in my eyesight, place light behind me, and light in front of me, and place light above me, and light below me. O Allah! grant me light}}
\hadithdefcmd{muslim}{1800}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي عَطَاءٌ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بِتُّ ذَاتَ لَيْلَةٍ عِنْدَ خَالَتِي مَيْمُونَةَ فَقَامَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي مُتَطَوِّعًا مِنَ اللَّيْلِ فَقَامَ النَّبِيُّ صلى الله عليه وسلم إِلَى الْقِرْبَةِ فَتَوَضَّأَ فَقَامَ فَصَلَّى فَقُمْتُ لَمَّا رَأَيْتُهُ صَنَعَ ذَلِكَ فَتَوَضَّأْتُ مِنَ الْقِرْبَةِ ثُمَّ قُمْتُ إِلَى شِقِّهِ الأَيْسَرِ فَأَخَذَ بِيَدِي مِنْ وَرَاءِ ظَهْرِهِ يَعْدِلُنِي كَذَلِكَ مِنْ وَرَاءِ ظَهْرِهِ إِلَى الشِّقِّ الأَيْمَنِ ‏.‏ قُلْتُ أَفِي التَّطَوُّعِ كَانَ ذَلِكَ قَالَ نَعَمْ ‏.‏\hadithno{1800}\hadithtrans{Ibn `Abbas reported:I spent a night in the house of my mother's sister Maimuna. The Apostle of Allah (ﷺ) got up for observing voluntary prayer (Tahajjud) at night. The Apostle of Allah (ﷺ) stood by the water-skin and performed ablution and then stood up and prayed. I also got up when I saw him doing that. I also performed ablution from the water-skin and then stood at his left side. He took hold of my hand from behind his back and then turned me from his back to his right side. I (`Ata', one of the narrators) said: Did it concern the voluntary prayer (at night)? He (Ibn `Abbas) said: Yes}}
\hadithdefcmd{muslim}{1801}{وَحَدَّثَنِي هَارُونُ بْنُ عَبْدِ اللَّهِ، وَمُحَمَّدُ بْنُ رَافِعٍ، قَالاَ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، أَخْبَرَنِي أَبِي قَالَ، سَمِعْتُ قَيْسَ بْنَ سَعْدٍ، يُحَدِّثُ عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بَعَثَنِي الْعَبَّاسُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَهُوَ فِي بَيْتِ خَالَتِي مَيْمُونَةَ فَبِتُّ مَعَهُ تِلْكَ اللَّيْلَةَ فَقَامَ يُصَلِّي مِنَ اللَّيْلِ فَقُمْتُ عَنْ يَسَارِهِ فَتَنَاوَلَنِي مِنْ خَلْفِ ظَهْرِهِ فَجَعَلَنِي عَلَى يَمِينِهِ ‏.‏\hadithno{1801}\hadithtrans{Ibn `Abbas reported:(My father) Al-`Abbas sent me to the Messenger of Allah (ﷺ) and he was in the house of my mother's sister Maimuna and I spent that night along with him. He (the Holy Prophet) got up and prayed at night, and I stood up on his left side. He caught hold of me from behind his back and made me stand on his right side}}
\hadithdefcmd{muslim}{1802}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ عَطَاءٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بِتُّ عِنْدَ خَالَتِي مَيْمُونَةَ ‏.‏ نَحْوَ حَدِيثِ ابْنِ جُرَيْجٍ وَقَيْسِ بْنِ سَعْدٍ ‏.‏\hadithno{1802}\hadithtrans{Ibn `Abbas reported:I spent a night in the house of my mother's sister Maimuna, and the rest of the hadith is the same as narrated above}}
\hadithdefcmd{muslim}{1803}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي جَمْرَةَ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي مِنَ اللَّيْلِ ثَلاَثَ عَشْرَةَ رَكْعَةً ‏.‏\hadithno{1803}\hadithtrans{Abu Jamra reported:I heard Ibn 'Abbas saying that the Messenger of Allah (ﷺ) observed thirteen rak'ahs at night}}
\hadithdefcmd{muslim}{1804}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، أَنَّ عَبْدَ اللَّهِ بْنَ قَيْسِ بْنِ مَخْرَمَةَ، أَخْبَرَهُ عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، أَنَّهُ قَالَ لأَرْمُقَنَّ صَلاَةَ رَسُولِ اللَّهِ صلى الله عليه وسلم اللَّيْلَةَ فَصَلَّى ‏.‏ رَكْعَتَيْنِ خَفِيفَتَيْنِ ثُمَّ صَلَّى رَكْعَتَيْنِ طَوِيلَتَيْنِ طَوِيلَتَيْنِ طَوِيلَتَيْنِ ثُمَّ صَلَّى رَكْعَتَيْنِ وَهُمَا دُونَ اللَّتَيْنِ قَبْلَهُمَا ثُمَّ صَلَّى رَكْعَتَيْنِ وَهُمَا دُونَ اللَّتَيْنِ قَبْلَهُمَا ثُمَّ صَلَّى رَكْعَتَيْنِ وَهُمَا دُونَ اللَّتَيْنِ قَبْلَهُمَا ثُمَّ صَلَّى رَكْعَتَيْنِ وَهُمَا دُونَ اللَّتَيْنِ قَبْلَهُمَا ثُمَّ أَوْتَرَ فَذَلِكَ ثَلاَثَ عَشْرَةَ رَكْعَةً ‏.‏\hadithno{1804}\hadithtrans{Zaid b Khalid al-Juhani said:I would definitely watch at night the prayer observed by the Messenger of Allah (ﷺ). He prayed two short rak'ahs, then two long, long, long rak'ahs, then he prayed two rak'ahs which were shorter than the two preceding rak'ahs, then he prayed two rak'ahs which were shorter than the two preceding, then he prayed two rak'ahs which were shorter than the two preceding, then observed a single one (Witr), making a total of thirteen rak'ahs}}
\hadithdefcmd{muslim}{1805}{وَحَدَّثَنِي حَجَّاجُ بْنُ الشَّاعِرِ، حَدَّثَنِي مُحَمَّدُ بْنُ جَعْفَرٍ الْمَدَائِنِيُّ أَبُو جَعْفَرٍ، حَدَّثَنَا وَرْقَاءُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ كُنْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَانْتَهَيْنَا إِلَى مَشْرَعَةٍ فَقَالَ ‏ "‏ أَلاَ تُشْرِعُ يَا جَابِرُ ‏"‏ ‏.‏ قُلْتُ بَلَى - قَالَ - فَنَزَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَشْرَعْتُ - قَالَ - ثُمَّ ذَهَبَ لِحَاجَتِهِ وَوَضَعْتُ لَهُ وَضُوءًا - قَالَ - فَجَاءَ فَتَوَضَّأَ ثُمَّ قَامَ فَصَلَّى فِي ثَوْبٍ وَاحِدٍ خَالَفَ بَيْنَ طَرَفَيْهِ فَقُمْتُ خَلْفَهُ فَأَخَذَ بِأُذُنِي فَجَعَلَنِي عَنْ يَمِينِهِ ‏.‏\hadithno{1805}\hadithtrans{Jabir b. 'Abdullah reported:I accompanied the Messenger of Allah (ﷺ) in a journey and we reached a watering place. He said: Jabir, are you going to enter it? I said: Yes. The Messenger of Allah (ﷺ) then got down and I entered it. He (the Holy Prophet) then went away to relieve himself and I placed for him water for ablution. He then came back and performed ablution, and then stood and prayed in one garment, having its ends tied from the opposite sides. I stood behind him and he caught hold of my ear and made me stand on his right side}}
\hadithdefcmd{muslim}{1806}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ جَمِيعًا عَنْ هُشَيْمٍ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا هُشَيْمٌ، - أَخْبَرَنَا أَبُو حُرَّةَ، عَنِ الْحَسَنِ، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا قَامَ مِنَ اللَّيْلِ لِيُصَلِّيَ افْتَتَحَ صَلاَتَهُ بِرَكْعَتَيْنِ خَفِيفَتَيْنِ ‏.‏\hadithno{1806}\hadithtrans{A'isha reported that when the Messenger of Allah (ﷺ) stood up at night to pray, he began his prayer with two short rak'ahs}}
\hadithdefcmd{muslim}{1807}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ مُحَمَّدٍ، عَنْ أَبِي، هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا قَامَ أَحَدُكُمْ مِنَ اللَّيْلِ فَلْيَفْتَتِحْ صَلاَتَهُ بِرَكْعَتَيْنِ خَفِيفَتَيْنِ\hadithno{1807}\hadithtrans{Abu Huraira reported Allah's Apostle (ﷺ) as saying When any one of you gets up at night, he should begin the prayer with two short rak'ahs}}
\hadithdefcmd{muslim}{1808}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ طَاوُسٍ، عَنِ ابْنِ، عَبَّاسٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ إِذَا قَامَ إِلَى الصَّلاَةِ مِنْ جَوْفِ اللَّيْلِ ‏ "‏ اللَّهُمَّ لَكَ الْحَمْدُ أَنْتَ نُورُ السَّمَوَاتِ وَالأَرْضِ وَلَكَ الْحَمْدُ أَنْتَ قَيَّامُ السَّمَوَاتِ وَالأَرْضِ وَلَكَ الْحَمْدُ أَنْتَ رَبُّ السَّمَوَاتِ وَالأَرْضِ وَمَنْ فِيهِنَّ أَنْتَ الْحَقُّ وَوَعْدُكَ الْحَقُّ وَقَوْلُكَ الْحَقُّ وَلِقَاؤُكَ حَقٌّ وَالْجَنَّةُ حَقٌّ وَالنَّارُ حَقٌّ وَالسَّاعَةُ حَقٌّ اللَّهُمَّ لَكَ أَسْلَمْتُ وَبِكَ آمَنْتُ وَعَلَيْكَ تَوَكَّلْتُ وَإِلَيْكَ أَنَبْتُ وَبِكَ خَاصَمْتُ وَإِلَيْكَ حَاكَمْتُ فَاغْفِرْ لِي مَا قَدَّمْتُ وَأَخَّرْتُ وَأَسْرَرْتُ وَأَعْلَنْتُ أَنْتَ إِلَهِي لاَ إِلَهَ إِلاَّ أَنْتَ ‏"‏ ‏.‏\hadithno{1808}\hadithtrans{Ibn `Abbas reported that when the Messenger of Allah (ﷺ) got up during the night to pray, he used to say:O Allah, to Thee be the praise Thou art the light of the heavens and the earth. To Thee be the praise; Thou art the Supporter of the heavens and the earth. To Thee be the praise; Thou art the Lord of the heavens and the earth and whatever is therein. Thou art the Truth; Thy promise is True, the meeting with Thee is True. Paradise is true, Hell is true, the Hour is true. O Allah, I submit to Thee; affirm my faith in Thee; repose my trust in Thee, and I return to Thee for repentance; by Thy help I have disputed; and to Thee I have come for decision, so forgive me my earlier and later sins, the sins that I committed in secret and openly. Thou art my God. There is no god but Thee}}
\hadithdefcmd{muslim}{1809}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَابْنُ، نُمَيْرٍ وَابْنُ أَبِي عُمَرَ قَالُوا حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، قَالَ حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، كِلاَهُمَا عَنْ سُلَيْمَانَ الأَحْوَلِ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ أَمَّا حَدِيثُ ابْنِ جُرَيْجٍ فَاتَّفَقَ لَفْظُهُ مَعَ حَدِيثِ مَالِكٍ لَمْ يَخْتَلِفَا إِلاَّ فِي حَرْفَيْنِ قَالَ ابْنُ جُرَيْجٍ مَكَانَ قَيَّامُ قَيِّمُ وَقَالَ وَمَا أَسْرَرْتُ وَأَمَّا حَدِيثُ ابْنِ عُيَيْنَةَ فَفِيهِ بَعْضُ زِيَادَةٍ وَيُخَالِفُ مَالِكًا وَابْنَ جُرَيْجٍ فِي أَحْرُفٍ ‏.‏\hadithno{1809}\hadithtrans{This hadith has been narrated on the authority of Ibn 'Abbas through another chain of transmitters and with slight alteration of two words. Instead of the word Qayyam (Supporter, as used in the above hadith here the word) Qayyim (the Custodian) has been used, and he (further said):" What I did in secret." And in the hadith narrated by Ibn 'Uyaina there is some addition}}
\hadithdefcmd{muslim}{1810}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا مَهْدِيٌّ، - وَهُوَ ابْنُ مَيْمُونٍ - حَدَّثَنَا عِمْرَانُ، الْقَصِيرُ عَنْ قَيْسِ بْنِ سَعْدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ وَاللَّفْظُ قَرِيبٌ مِنْ أَلْفَاظِهِمْ ‏.‏\hadithno{1810}\hadithtrans{This hadith has been narrated by Ibn 'Abbas by another chain of transmitters and the words are nearly the same (as recorded in the above-mentioned hadith)}}
\hadithdefcmd{muslim}{1811}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ حَاتِمٍ، وَعَبْدُ بْنُ حُمَيْدٍ، وَأَبُو مَعْنٍ الرَّقَاشِيُّ قَالُوا حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، حَدَّثَنِي أَبُو سَلَمَةَ، بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ قَالَ سَأَلْتُ عَائِشَةَ أُمَّ الْمُؤْمِنِينَ بِأَىِّ شَىْءٍ كَانَ نَبِيُّ اللَّهِ صلى الله عليه وسلم يَفْتَتِحُ صَلاَتَهُ إِذَا قَامَ مِنَ اللَّيْلِ قَالَتْ كَانَ إِذَا قَامَ مِنَ اللَّيْلِ افْتَتَحَ صَلاَتَهُ ‏ "‏ اللَّهُمَّ رَبَّ جِبْرَائِيلَ وَمِيكَائِيلَ وَإِسْرَافِيلَ فَاطِرَ السَّمَوَاتِ وَالأَرْضِ عَالِمَ الْغَيْبِ وَالشَّهَادَةِ أَنْتَ تَحْكُمُ بَيْنَ عِبَادِكَ فِيمَا كَانُوا فِيهِ يَخْتَلِفُونَ اهْدِنِي لِمَا اخْتُلِفَ فِيهِ مِنَ الْحَقِّ بِإِذْنِكَ إِنَّكَ تَهْدِي مَنْ تَشَاءُ إِلَى صِرَاطٍ مُسْتَقِيمٍ ‏"‏ ‏.‏\hadithno{1811}\hadithtrans{Abd al-Rahman b. 'Auf reported:I asked 'A'isha, the mother of the believers, (to tell me) the words with which the Messenger of Allah (ﷺ) commenced the prayer when he got up at night. She said: When he got up at night he would commence his prayer with these words: O Allah, Lord of Gabriel, and Michael, and Israfil, the Creator of the heavens and the earth, Who knowest the unseen and the seen; Thou decidest amongst Thy servants concerning their differences. Guide me with Thy permission in the divergent views (which the people) hold about Truth, for it is Thou Who guidest whom Thou wilt to the Straight Path}}
\hadithdefcmd{muslim}{1812}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا يُوسُفُ الْمَاجِشُونُ، حَدَّثَنِي أَبِي، عَنْ عَبْدِ، الرَّحْمَنِ الأَعْرَجِ عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ كَانَ إِذَا قَامَ إِلَى الصَّلاَةِ قَالَ ‏"‏ وَجَّهْتُ وَجْهِيَ لِلَّذِي فَطَرَ السَّمَوَاتِ وَالأَرْضَ حَنِيفًا وَمَا أَنَا مِنَ الْمُشْرِكِينَ إِنَّ صَلاَتِي وَنُسُكِي وَمَحْيَاىَ وَمَمَاتِي لِلَّهِ رَبِّ الْعَالَمِينَ لاَ شَرِيكَ لَهُ وَبِذَلِكَ أُمِرْتُ وَأَنَا مِنَ الْمُسْلِمِينَ اللَّهُمَّ أَنْتَ الْمَلِكُ لاَ إِلَهَ إِلاَّ أَنْتَ ‏.‏ أَنْتَ رَبِّي وَأَنَا عَبْدُكَ ظَلَمْتُ نَفْسِي وَاعْتَرَفْتُ بِذَنْبِي فَاغْفِرْ لِي ذُنُوبِي جَمِيعًا إِنَّهُ لاَ يَغْفِرُ الذُّنُوبَ إِلاَّ أَنْتَ وَاهْدِنِي لأَحْسَنِ الأَخْلاَقِ لاَ يَهْدِي لأَحْسَنِهَا إِلاَّ أَنْتَ وَاصْرِفْ عَنِّي سَيِّئَهَا لاَ يَصْرِفُ عَنِّي سَيِّئَهَا إِلاَّ أَنْتَ لَبَّيْكَ وَسَعْدَيْكَ وَالْخَيْرُ كُلُّهُ فِي يَدَيْكَ وَالشَّرُّ لَيْسَ إِلَيْكَ أَنَا بِكَ وَإِلَيْكَ تَبَارَكْتَ وَتَعَالَيْتَ أَسْتَغْفِرُكَ وَأَتُوبُ إِلَيْكَ ‏"‏ ‏.‏ وَإِذَا رَكَعَ قَالَ ‏"‏ اللَّهُمَّ لَكَ رَكَعْتُ وَبِكَ آمَنْتُ وَلَكَ أَسْلَمْتُ خَشَعَ لَكَ سَمْعِي وَبَصَرِي وَمُخِّي وَعَظْمِي وَعَصَبِي ‏"‏ ‏.‏ وَإِذَا رَفَعَ قَالَ ‏"‏ اللَّهُمَّ رَبَّنَا لَكَ الْحَمْدُ مِلْءَ السَّمَوَاتِ وَمِلْءَ الأَرْضِ وَمِلْءَ مَا بَيْنَهُمَا وَمِلْءَ مَا شِئْتَ مِنْ شَىْءٍ بَعْدُ ‏"‏ ‏.‏ وَإِذَا سَجَدَ قَالَ ‏"‏ اللَّهُمَّ لَكَ سَجَدْتُ وَبِكَ آمَنْتُ وَلَكَ أَسْلَمْتُ سَجَدَ وَجْهِي لِلَّذِي خَلَقَهُ وَصَوَّرَهُ وَشَقَّ سَمْعَهُ وَبَصَرَهُ تَبَارَكَ اللَّهُ أَحْسَنُ الْخَالِقِينَ ‏"‏ ‏.‏ ثُمَّ يَكُونُ مِنْ آخِرِ مَا يَقُولُ بَيْنَ التَّشَهُّدِ وَالتَّسْلِيمِ ‏"‏ اللَّهُمَّ اغْفِرْ لِي مَا قَدَّمْتُ وَمَا أَخَّرْتُ وَمَا أَسْرَرْتُ وَمَا أَعْلَنْتُ وَمَا أَسْرَفْتُ وَمَا أَنْتَ أَعْلَمُ بِهِ مِنِّي أَنْتَ الْمُقَدِّمُ وَأَنْتَ الْمُؤَخِّرُ لاَ إِلَهَ إِلاَّ أَنْتَ ‏"‏ ‏.‏\hadithno{1812}\hadithtrans{Ali b. Abu Talib reported that when the Messenger of Allah (ﷺ) got up at night for prayer he would say:I turn my face in complete devotion to One Who is the Originator of the heaven and the earth and I am not of the polytheists. Verily my prayer, my sacrifice, my living and my dying are for Allah, the Lord of the worlds; There is no partner with Him and this is what I have been commanded (to profess and believe) and I am of the believers. O Allah, Thou art the King, there is no god but Thee, Thou art my Lord, and I am Thy bondman. I wronged myself and make a confession of my Sin. Forgive all my sins, for no one forgives the sins but Thee, and guide me in the best of conduct for none but Thee guideth anyone (in) good conduct. Remove sins from me, for none else but Thou can remove sins from me. Here I am at Thy service, and Grace is to Thee and the whole of good is in Thine hand, and one cannot get nearneststo Thee through evil. My (power as well as existence) is due to Thee (Thine grace) and I turn to Thee (for supplication). Thou art blessed and Thou art exalted. I seek forgiveness from Thee and turn to Thee in repentance: and when he would bow, he would say: O Allah, it is for Thee that I bowed. I affirm my faith in Thee and I submit to Thee, and submit humbly before Thee my hearing, my eyesight, my marrow, my bone, my sinew; and when he would raise his head, he would say: O Allah, our Lord, praise is due to Thee, (the praise) with which is filled the heavens and the earth, and with which is filled that (space) which exists between them, and filled with anything that Thou desireth afterward. And when he prostrated himself, he (the Holy Prophet) would say: O Allah, it is to Thee that I prostrate myself and it is in Thee that I affirm my faith, and I submit to Thee. My face is submitted before One Who created it, and shaped it, and opened his faculties of hearing and seeing. Blessed is Allah, the best of Creators; and he would then say between Tashahhud and the pronouncing of salutation: Forgive me of the earlier and later open and secret (sins) and that where I made transgression and that Thou knowest better than I. Thou art the First and the Last. There is no god, but Thee}}
\hadithdefcmd{muslim}{1813}{وَحَدَّثَنَاهُ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ، إِبْرَاهِيمَ أَخْبَرَنَا أَبُو النَّضْرِ، قَالَ حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي سَلَمَةَ، عَنْ عَمِّهِ، الْمَاجِشُونِ بْنِ أَبِي سَلَمَةَ عَنِ الأَعْرَجِ، بِهَذَا الإِسْنَادِ وَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اسْتَفْتَحَ الصَّلاَةَ كَبَّرَ ثُمَّ قَالَ ‏"‏ وَجَّهْتُ وَجْهِي ‏"‏ ‏.‏ وَقَالَ ‏"‏ وَأَنَا أَوَّلُ الْمُسْلِمِينَ ‏"‏ ‏.‏ وَقَالَ وَإِذَا رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا وَلَكَ الْحَمْدُ ‏"‏ ‏.‏ وَقَالَ ‏"‏ وَصَوَّرَهُ فَأَحْسَنَ صُوَرَهُ ‏"‏ ‏.‏ وَقَالَ وَإِذَا سَلَّمَ قَالَ ‏"‏ اللَّهُمَّ اغْفِرْ لِي مَا قَدَّمْتُ ‏"‏ .‏ إِلَى آخِرِ الْحَدِيثِ وَلَمْ يَقُلْ بَيْنَ التَّشَهُّدِ وَالتَّسْلِيمِ ‏.‏\hadithno{1813}\hadithtrans{A'raj reported that when the Messenger of Allah (ﷺ) would start the prayer, he would pronounce takbir (Allah-o-Akbar) and then say:I turn my face (up to Thee), I am the first of the believers; and when he raised his head from ruku' he said: Allah listened to him who praised Him; O our Lord, praise be to Thee; and he said: He shaped (man) and how fine is his shape? And he (the narrator) said: When he pronounced salutation he said: O Allah, forgive me my earlier (sins), to the end of the hadith; and he did not say it between the Tashahhud and salutation (as mentioned above)}}
\hadithdefcmd{muslim}{1814}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو مُعَاوِيَةَ ح وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنْ جَرِيرٍ، كُلُّهُمْ عَنِ الأَعْمَشِ، ح وَحَدَّثَنَا ابْنُ، نُمَيْرٍ - وَاللَّفْظُ لَهُ - حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، عَنْ سَعْدِ بْنِ عُبَيْدَةَ، عَنِ الْمُسْتَوْرِدِ بْنِ الأَحْنَفِ، عَنْ صِلَةَ بْنِ زُفَرَ، عَنْ حُذَيْفَةَ، قَالَ صَلَّيْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ فَافْتَتَحَ الْبَقَرَةَ فَقُلْتُ يَرْكَعُ عِنْدَ الْمِائَةِ ‏.‏ ثُمَّ مَضَى فَقُلْتُ يُصَلِّي بِهَا فِي رَكْعَةٍ فَمَضَى فَقُلْتُ يَرْكَعُ بِهَا ‏.‏ ثُمَّ افْتَتَحَ النِّسَاءَ فَقَرَأَهَا ثُمَّ افْتَتَحَ آلَ عِمْرَانَ فَقَرَأَهَا يَقْرَأُ مُتَرَسِّلاً إِذَا مَرَّ بِآيَةٍ فِيهَا تَسْبِيحٌ سَبَّحَ وَإِذَا مَرَّ بِسُؤَالٍ سَأَلَ وَإِذَا مَرَّ بِتَعَوُّذٍ تَعَوَّذَ ثُمَّ رَكَعَ فَجَعَلَ يَقُولُ ‏"‏ سُبْحَانَ رَبِّيَ الْعَظِيمِ ‏"‏ ‏.‏ فَكَانَ رُكُوعُهُ نَحْوًا مِنْ قِيَامِهِ ثُمَّ قَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ ‏"‏ ‏.‏ ثُمَّ قَامَ طَوِيلاً قَرِيبًا مِمَّا رَكَعَ ثُمَّ سَجَدَ فَقَالَ ‏"‏ سُبْحَانَ رَبِّيَ الأَعْلَى ‏"‏ ‏.‏ فَكَانَ سُجُودُهُ قَرِيبًا مِنْ قِيَامِهِ ‏.‏ قَالَ وَفِي حَدِيثِ جَرِيرٍ مِنَ الزِّيَادَةِ فَقَالَ ‏"‏ سَمِعَ اللَّهُ لِمَنْ حَمِدَهُ رَبَّنَا لَكَ الْحَمْدُ"‏ ‏.‏\hadithno{1814}\hadithtrans{Hudhaifa reported:I prayed with the Messenger of Allah (ﷺ) one night and he started reciting al-Baqara. I thought that he would bow at the end of one hundred verses, but he proceeded on; I then thought that he would perhaps recite the whole (surah) in a rak'ah, but he proceeded and I thought he would perhaps bow on completing (this surah). He then started al-Nisa', and recited it; he then started Al-i-'Imran and recited leisurely. And when he recited the verses which referred to the Glory of Allah, he glorified (by saying Subhan Allah-Glory to my Lord the Great), and when he recited the verses which tell (how the Lord) is to be begged, he (the Holy Prophet) would then beg (from Him), and when he recited the verses dealing with protection from the Lord, he sought (His) protection and would then bow and say: Glory be to my Mighty Lord; his bowing lasted about the same length of time as his standing (and then on returning to the standing posture after ruku') he would say: Allah listened to him who praised Him, and he would then stand about the same length of time as he had spent in bowing. He would then prostrate himself and say: Glory be to my Lord most High, and his prostration lasted nearly the same length of time as his standing. In the hadith transmitted by Jarir the words are:" He (the Holy Prophet) would say:" Allah listened to him who praised Him, our Lord, to Thee i the praise}}
\hadithdefcmd{muslim}{1815}{وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، كِلاَهُمَا عَنْ جَرِيرٍ، - قَالَ عُثْمَانُ حَدَّثَنَا جَرِيرٌ، - عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، قَالَ قَالَ عَبْدُ اللَّهِ صَلَّيْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَطَالَ حَتَّى هَمَمْتُ بِأَمْرِ سَوْءٍ قَالَ قِيلَ وَمَا هَمَمْتَ بِهِ قَالَ هَمَمْتُ أَنْ أَجْلِسَ وَأَدَعَهُ ‏.‏\hadithno{1815}\hadithtrans{Abdullah reported:I prayed with the Messenger of Allah (ﷺ) and he lengthened it till I entertained an evil thought. It was said to him what that thought was. He said: I thought that I should sit down and forsake him}}
\hadithdefcmd{muslim}{1816}{وَحَدَّثَنَاهُ إِسْمَاعِيلُ بْنُ الْخَلِيلِ، وَسُوَيْدُ بْنُ سَعِيدٍ، عَنْ عَلِيِّ بْنِ مُسْهِرٍ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ ‏.‏\hadithno{1816}\hadithtrans{A hadith like this has been narrated by A'mash with the same chain of transmitters}}
\hadithdefcmd{muslim}{1817}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ، قَالَ عُثْمَانُ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ ذُكِرَ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم رَجُلٌ نَامَ لَيْلَةً حَتَّى أَصْبَحَ قَالَ ‏"‏ ذَاكَ رَجُلٌ بَالَ الشَّيْطَانُ فِي أُذُنَيْهِ ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ فِي أُذُنِهِ ‏"‏ ‏.‏\hadithno{1817}\hadithtrans{Abdullah (b. Mas'ud) reported that a mention was made of a man who slept the whole night till morning. He (the Holy Prophet) remarked:That is a man in whose ears (or in whose ear) the devil urinated}}
\hadithdefcmd{muslim}{1818}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، أَنَّ الْحُسَيْنَ بْنَ عَلِيٍّ، حَدَّثَهُ عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم طَرَقَهُ وَفَاطِمَةَ فَقَالَ ‏"‏ أَلاَ تُصَلُّونَ ‏"‏ ‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنَّمَا أَنْفُسُنَا بِيَدِ اللَّهِ فَإِذَا شَاءَ أَنْ يَبْعَثَنَا بَعَثَنَا ‏.‏ فَانْصَرَفَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ قُلْتُ لَهُ ذَلِكَ ثُمَّ سَمِعْتُهُ وَهُوَ مُدْبِرٌ يَضْرِبُ فَخِذَهُ وَيَقُولُ ‏"‏ وَكَانَ الإِنْسَانُ أَكْثَرَ شَىْءٍ جَدَلاً ‏"‏ ‏.‏\hadithno{1818}\hadithtrans{Husain b. 'Ali narrated on the authority of (his father) 'Ali b. Abu Talib that the Messenger of Allah (ﷺ) came one night to see him ('Ali) and Fatimah (the daughter of the Holy Prophet) and said:Don't you observe (Tahajjud) prayer? I ('Ali) said: Messenger of Allah, verily our souls are in the hands of Allah and when He wants to awaken us, He awakens us. The Messenger of Allah (ﷺ) went back when I said this to him. He was striking his hand on his thigh while returning, and I heard him say: Verily the man disputes with many things}}
\hadithdefcmd{muslim}{1819}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالَ عَمْرٌو حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم ‏ "‏ يَعْقِدُ الشَّيْطَانُ عَلَى قَافِيَةِ رَأْسِ أَحَدِكُمْ ثَلاَثَ عُقَدٍ إِذَا نَامَ بِكُلِّ عُقْدَةٍ يَضْرِبُ عَلَيْكَ لَيْلاً طَوِيلاً فَإِذَا اسْتَيْقَظَ فَذَكَرَ اللَّهَ انْحَلَّتْ عُقْدَةٌ وَإِذَا تَوَضَّأَ انْحَلَّتْ عُقْدَتَانِ فَإِذَا صَلَّى انْحَلَّتِ الْعُقَدُ فَأَصْبَحَ نَشِيطًا طَيِّبَ النَّفْسِ وَإِلاَّ أَصْبَحَ خَبِيثَ النَّفْسِ كَسْلاَنَ ‏"‏ ‏.‏\hadithno{1819}\hadithtrans{Abu Huraira transmitted it from the Messenger of Allah (ﷺ):When any one of you goes to sleep, the devil ties three knots at the back of his neck, sealing every knot with:" You have a long night, so sleep." So if one awakes and mentions Allah, a knot will be loosened; if he performs ablution two knots are loosened; and if he prays (all) knots will be loosened, and in the morning he will be active and in good spirits; otherwise we will be in bad spirits and sluggish in the morning}}
\hadithdefcmd{muslim}{1820}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ، عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اجْعَلُوا مِنْ صَلاَتِكُمْ فِي بُيُوتِكُمْ وَلاَ تَتَّخِذُوهَا قُبُورًا ‏"‏ ‏.‏\hadithno{1820}\hadithtrans{Ibn 'Umar reported Allah's Apostle (ﷺ) as saying:Observe some of your prayers in your houses and do not make them graves}}
\hadithdefcmd{muslim}{1821}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، أَخْبَرَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ صَلُّوا فِي بُيُوتِكُمْ وَلاَ تَتَّخِذُوهَا قُبُورًا ‏"‏ ‏.‏\hadithno{1821}\hadithtrans{Ibn 'Umar reported Allah's Apostle (ﷺ) as saying:Pray in your houses, and do not make them graves}}
\hadithdefcmd{muslim}{1822}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا قَضَى أَحَدُكُمُ الصَّلاَةَ فِي مَسْجِدِهِ فَلْيَجْعَلْ لِبَيْتِهِ نَصِيبًا مِنْ صَلاَتِهِ فَإِنَّ اللَّهَ جَاعِلٌ فِي بَيْتِهِ مِنْ صَلاَتِهِ خَيْرًا ‏"‏ ‏.‏\hadithno{1822}\hadithtrans{Jabir reported Allah's Messenger (ﷺ) as saying:When any one of you observes prayer in the mosque he should reserve a part of his prayer for his house, for Allah would make the prayer as a means of betterment in his house}}
\hadithdefcmd{muslim}{1823}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَرَّادٍ الأَشْعَرِيُّ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَثَلُ الْبَيْتِ الَّذِي يُذْكَرُ اللَّهُ فِيهِ وَالْبَيْتِ الَّذِي لاَ يُذْكَرُ اللَّهُ فِيهِ مَثَلُ الْحَىِّ وَالْمَيِّتِ ‏"‏ ‏.‏\hadithno{1823}\hadithtrans{Abu Musa reported Allah's Apostle (ﷺ) as saying:The house in which remembrance of Allah is made and the house in which Allah is not remembered are like the living and the dead}}
\hadithdefcmd{muslim}{1824}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ، - وَهُوَ ابْنُ عَبْدِ الرَّحْمَنِ الْقَارِيُّ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَجْعَلُوا بُيُوتَكُمْ مَقَابِرَ إِنَّ الشَّيْطَانَ يَنْفِرُ مِنَ الْبَيْتِ الَّذِي تُقْرَأُ فِيهِ سُورَةُ الْبَقَرَةِ ‏"‏ ‏.‏\hadithno{1824}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Do not make your houses as graveyards. Satan runs away from the house in which Surah Baqara is recited}}
\hadithdefcmd{muslim}{1825}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا سَالِمٌ أَبُو النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، قَالَ احْتَجَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم حُجَيْرَةً بِخَصَفَةٍ أَوْ حَصِيرٍ فَخَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي فِيهَا - قَالَ - فَتَتَبَّعَ إِلَيْهِ رِجَالٌ وَجَاءُوا يُصَلُّونَ بِصَلاَتِهِ - قَالَ - ثُمَّ جَاءُوا لَيْلَةً فَحَضَرُوا وَأَبْطَأَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْهُمْ - قَالَ - فَلَمْ يَخْرُجْ إِلَيْهِمْ فَرَفَعُوا أَصْوَاتَهُمْ وَحَصَبُوا الْبَابَ فَخَرَجَ إِلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم مُغْضَبًا‏ فَقَالَ لَهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا زَالَ بِكُمْ صَنِيعُكُمْ حَتَّى ظَنَنْتُ أَنَّهُ سَيُكْتَبُ عَلَيْكُمْ فَعَلَيْكُمْ بِالصَّلاَةِ فِي بُيُوتِكُمْ فَإِنَّ خَيْرَ صَلاَةِ الْمَرْءِ فِي بَيْتِهِ إِلاَّ الصَّلاَةَ الْمَكْتُوبَةَ ‏"‏ ‏.‏\hadithno{1825}\hadithtrans{Zaid b. Thabit reported:The Messenger of Allah (ﷺ) made an apartment with the help of the leaves of date trees or of mats. The Messenger of Allah (ﷺ) went out to pray in it. People followed him and came to pray with him. Then they again came one night and waited (for him), but the Messenger of Allah (ﷺ) delayed in coming out to them. And when he did not come out, they cried aloud and threw pebbles at the door. The Messenger of Allah (ﷺ) came out in anger and said to them: By what you have been constantly doing, I was inclined to think that it (prayer) might not become obligatory for you. So you must observe prayer (optional) in your houses, for the prayer observed by a man in the house is better except an obligatory prayer}}
\hadithdefcmd{muslim}{1826}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، قَالَ سَمِعْتُ أَبَا النَّضْرِ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ ثَابِتٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم اتَّخَذَ حُجْرَةً فِي الْمَسْجِدِ مِنْ حَصِيرٍ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم فِيهَا لَيَالِيَ حَتَّى اجْتَمَعَ إِلَيْهِ نَاسٌ ‏.‏ فَذَكَرَ نَحْوَهُ وَزَادَ فِيهِ ‏ "‏ وَلَوْ كُتِبَ عَلَيْكُمْ مَا قُمْتُمْ بِهِ ‏"‏ ‏.‏\hadithno{1826}\hadithtrans{Zaid b. Thabit reported that the Messenger of Allah (ﷺ) made an apartment in the mosque of mats, and he observed in it prayers for many nights till people began to gather around him, and the rest of the hadith is the same but with this addition:" Had this (Nafl) prayer become obligatory for you, you would not be able to observe it}}
\hadithdefcmd{muslim}{1827}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ، - يَعْنِي الثَّقَفِيَّ - حَدَّثَنَا عُبَيْدُ اللَّهِ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم حَصِيرٌ وَكَانَ يُحَجِّرُهُ مِنَ اللَّيْلِ فَيُصَلِّي فِيهِ فَجَعَلَ النَّاسُ يُصَلُّونَ بِصَلاَتِهِ وَيَبْسُطُهُ بِالنَّهَارِ فَثَابُوا ذَاتَ لَيْلَةٍ فَقَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ عَلَيْكُمْ مِنَ الأَعْمَالِ مَا تُطِيقُونَ فَإِنَّ اللَّهَ لاَ يَمَلُّ حَتَّى تَمَلُّوا وَإِنَّ أَحَبَّ الأَعْمَالِ إِلَى اللَّهِ مَا دُووِمَ عَلَيْهِ وَإِنْ قَلَّ ‏"‏ ‏.‏ وَكَانَ آلُ مُحَمَّدٍ صلى الله عليه وسلم إِذَا عَمِلُوا عَمَلاً أَثْبَتُوهُ ‏.‏\hadithno{1827}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) had a mat and he used it for making an apartment during the night and observed prayer in it, and the people began to pray with him, and he spread it (the mat) during the day time. The people crowded round him one night. He (the Holy Prophet) then said:O people, perform such acts as you are capable of doing, for Allah does not grow weary but you will get tired. The acts most pleasing to Allah are those which are done continuously, even if they are small. And it was the habit of the members of Muhammad's (ﷺ) household that whenever they did an act they did it continuously}}
\hadithdefcmd{muslim}{1828}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، أَنَّهُ سَمِعَ أَبَا سَلَمَةَ، يُحَدِّثُ عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم سُئِلَ أَىُّ الْعَمَلِ أَحَبُّ إِلَى اللَّهِ قَالَ ‏ "‏ أَدْوَمُهُ وَإِنْ قَلَّ ‏"‏ ‏.‏\hadithno{1828}\hadithtrans{A'isha is reported to have said that the Messenger of Allah (ﷺ) was asked about the act most pleasing to Allah. He replied:That which is done continuously, even if it is small}}
\hadithdefcmd{muslim}{1829}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ زُهَيْرٌ حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ سَأَلْتُ أُمَّ الْمُؤْمِنِينَ عَائِشَةَ قَالَ قُلْتُ يَا أُمَّ الْمُؤْمِنِينَ كَيْفَ كَانَ عَمَلُ رَسُولِ اللَّهِ صلى الله عليه وسلم هَلْ كَانَ يَخُصُّ شَيْئًا مِنَ الأَيَّامِ قَالَتْ لاَ ‏.‏ كَانَ عَمَلُهُ دِيمَةً وَأَيُّكُمْ يَسْتَطِيعُ مَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْتَطِيعُ\hadithno{1829}\hadithtrans{Alqama reported:I asked 'A'isha, the mother of the believers, saying O mother of the believers, how did the Messenger of Allah (ﷺ) act? Did he choose a particular act for a particular day? She said: No. He act was continuous, and who amongst you is capable of doing what the Messenger of Allah (ﷺ) did?}}
\hadithdefcmd{muslim}{1830}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا سَعْدُ بْنُ سَعِيدٍ، أَخْبَرَنِي الْقَاسِمُ بْنُ مُحَمَّدٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَحَبُّ الأَعْمَالِ إِلَى اللَّهِ تَعَالَى أَدْوَمُهَا وَإِنْ قَلَّ ‏"‏ ‏.‏ قَالَ وَكَانَتْ عَائِشَةُ إِذَا عَمِلَتِ الْعَمَلَ لَزِمَتْهُ ‏.‏\hadithno{1830}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) as saying:The acts most pleasing to Allah are those which are done continuously, even if they are small. and when 'A'isha did any act she did it continuously}}
\hadithdefcmd{muslim}{1831}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ عُلَيَّةَ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ عَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسٍ، قَالَ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَسْجِدَ وَحَبْلٌ مَمْدُودٌ بَيْنَ سَارِيَتَيْنِ فَقَالَ ‏"‏ مَا هَذَا ‏"‏ ‏.‏ قَالُوا لِزَيْنَبَ تُصَلِّي فَإِذَا كَسِلَتْ أَوْ فَتَرَتْ أَمْسَكَتْ بِهِ ‏.‏ فَقَالَ ‏"‏ حُلُّوهُ لِيُصَلِّ أَحَدُكُمْ نَشَاطَهُ فَإِذَا كَسِلَ أَوْ فَتَرَ قَعَدَ ‏"‏ ‏.‏ وَفِي حَدِيثِ زُهَيْرٍ ‏"‏ فَلْيَقْعُدْ ‏"‏ ‏.‏\hadithno{1831}\hadithtrans{Anas reported that the Messenger of Allah (ﷺ) entered the mosque (and he found) a rope tied between the two pillars; so he said:What is this? They said: It is for Zainab. She prays and when she slackens or feels tired she holds it. Upon this he (the Holy Prophet) said: Untie it. Let one pray as long as one feels fresh but when one slackens or becomes tired one must stop it. (And in the hadith transmitted by Zuhair it is:" He should sit down)}}
\hadithdefcmd{muslim}{1832}{وَحَدَّثَنَاهُ شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{1832}\hadithtrans{A hadith like this has been narrated from the Messenger of Allah (ﷺ) on the authority of Anas by another chain of transmitters}}
\hadithdefcmd{muslim}{1833}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، وَمُحَمَّدُ بْنُ سَلَمَةَ الْمُرَادِيُّ، قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم أَخْبَرَتْهُ أَنَّ الْحَوْلاَءَ بِنْتَ تُوَيْتِ بْنِ حَبِيبِ بْنِ أَسَدِ بْنِ عَبْدِ الْعُزَّى مَرَّتْ بِهَا وَعِنْدَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْتُ هَذِهِ الْحَوْلاَءُ بِنْتُ تُوَيْتٍ وَزَعَمُوا أَنَّهَا لاَ تَنَامُ اللَّيْلَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَنَامُ اللَّيْلَ خُذُوا مِنَ الْعَمَلِ مَا تُطِيقُونَ فَوَاللَّهِ لاَ يَسْأَمُ اللَّهُ حَتَّى تَسْأَمُوا ‏"‏ ‏.‏\hadithno{1833}\hadithtrans{Urwa b. Zubair reported that 'A'isha, the wife of the Messenger of Allah (ﷺ), told him that (once) Haula' dint Tuwait b. Habib b. Asad b. 'Abd al-'Uzzi passed by her (at the time) when the Messenger of Allah (ﷺ) was with her. I ('A'Isha) said:It Is Haula' bint Tuwait and they say that she does not sleep at night. Upon this the Messenger of Allah (ﷺ) said: (Oh) she does not sleep at night! Choose an act which you are capable of doing (continuously). By Allah, Allah would not grow weary, but you will grow weary}}
\hadithdefcmd{muslim}{1834}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ بْنِ، عُرْوَةَ ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ، قَالَتْ دَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعِنْدِي امْرَأَةٌ فَقَالَ ‏"‏ مَنْ هَذِهِ ‏"‏ ‏.‏ فَقُلْتُ امْرَأَةٌ لاَ تَنَامُ تُصَلِّي ‏.‏ قَالَ ‏"‏ عَلَيْكُمْ مِنَ الْعَمَلِ مَا تُطِيقُونَ فَوَاللَّهِ لاَ يَمَلُّ اللَّهُ حَتَّى تَمَلُّوا ‏"‏ ‏.‏ وَكَانَ أَحَبَّ الدِّينِ إِلَيْهِ مَا دَاوَمَ عَلَيْهِ صَاحِبُهُ وَفِي حَدِيثِ أَبِي أُسَامَةَ أَنَّهَا امْرَأَةٌ مِنْ بَنِي أَسَدٍ ‏.‏\hadithno{1834}\hadithtrans{A'isha said:The Messenger of Allah (ﷺ) came to me when a woman was sitting with me. He said: Who is she? I said: She is a woman who does not sleep but prays. He said: Do such acts which you are capable of doing. By Allah, Allah does not grow weary but you will grow weary. The religious act most pleasing to Him is one the doer of which does it continuously. (And in the hadith transmitted by Abu Usama [the words are]:" She was a woman from Banu Asad}}
\hadithdefcmd{muslim}{1835}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي ح، وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو أُسَامَةَ، جَمِيعًا عَنْ هِشَامِ بْنِ عُرْوَةَ، ح وَحَدَّثَنَا قُتَيْبَةُ، بْنُ سَعِيدٍ - وَاللَّفْظُ لَهُ - عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نَعَسَ أَحَدُكُمْ فِي الصَّلاَةِ فَلْيَرْقُدْ حَتَّى يَذْهَبَ عَنْهُ النَّوْمُ فَإِنَّ أَحَدَكُمْ إِذَا صَلَّى وَهُوَ نَاعِسٌ لَعَلَّهُ يَذْهَبُ يَسْتَغْفِرُ فَيَسُبُّ نَفْسَهُ ‏"‏ ‏.‏\hadithno{1835}\hadithtrans{A'isha reported Allah's Apostle (ﷺ) as saying:When anyone amongst you dozes in prayer, he should sleep, till sleep is gone, for when one of you prays while dozing he does not know whether he may be asking pardon or vilifying himself}}
\hadithdefcmd{muslim}{1836}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، قَالَ هَذَا مَا حَدَّثَنَا أَبُو هُرَيْرَةَ، عَنْ مُحَمَّدٍ، رَسُولِ اللَّهِ صلى الله عليه وسلم فَذَكَرَ أَحَادِيثَ مِنْهَا وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا قَامَ أَحَدُكُمْ مِنَ اللَّيْلِ فَاسْتَعْجَمَ الْقُرْآنُ عَلَى لِسَانِهِ فَلَمْ يَدْرِ مَا يَقُولُ فَلْيَضْطَجِعْ ‏"‏ ‏.‏\hadithno{1836}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When any one of you gets up at night (for prayer) and his tongue falters in (the recitation) of the Qar'an, and he does not know what he is reciting, he should go to sleep}}
\hadithdefcmd{muslim}{1837}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم سَمِعَ رَجُلاً يَقْرَأُ مِنَ اللَّيْلِ فَقَالَ ‏ "‏ يَرْحَمُهُ اللَّهُ لَقَدْ أَذْكَرَنِي كَذَا وَكَذَا آيَةً كُنْتُ أَسْقَطْتُهَا مِنْ سُورَةِ كَذَا وَكَذَا ‏"‏ ‏.‏\hadithno{1837}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) heard a person reciting the Qur'an at night. Upon this he said:May Allah show mercy to him; he has reminded me of such and such a verse which I had missed in such and such a surah}}
\hadithdefcmd{muslim}{1838}{وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا عَبْدَةُ، وَأَبُو مُعَاوِيَةَ عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَسْتَمِعُ قِرَاءَةَ رَجُلٍ فِي الْمَسْجِدِ ‏.‏ فَقَالَ ‏ "‏ رَحِمَهُ اللَّهُ لَقَدْ أَذْكَرَنِي آيَةً كُنْتُ أُنْسِيتُهَا ‏"‏ ‏.‏\hadithno{1838}\hadithtrans{A'isha reported that the Messenger of Allah (ﷺ) listened to the recitation of the Qur'an by a man in the mosque. Thereupon he said:May Allah have mercy upon him; be reminded me of the verse which I had been made to forget}}
\hadithdefcmd{muslim}{1839}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّمَا مَثَلُ صَاحِبِ الْقُرْآنِ كَمَثَلِ الإِبِلِ الْمُعَقَّلَةِ إِنْ عَاهَدَ عَلَيْهَا أَمْسَكَهَا وَإِنْ أَطْلَقَهَا ذَهَبَتْ ‏"‏ ‏.‏\hadithno{1839}\hadithtrans{Abdullah b. 'Umar reported Allah's Messenger (ﷺ) as saying:The example of a man who has memorised the Qur'an is like that of a hobbled camel. If he remained vigilant, he would be able to retain it (with him), and if he loosened the hobbled camel it would escape}}
\hadithdefcmd{muslim}{1840}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَعُبَيْدُ اللَّهِ بْنُ سَعِيدٍ، قَالُوا حَدَّثَنَا يَحْيَى، وَهُوَ الْقَطَّانُ ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي كُلُّهُمْ، عَنْ عُبَيْدِ اللَّهِ، ح وَحَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ أَيُّوبَ، ح وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ الْمُسَيَّبِيُّ حَدَّثَنَا أَنَسٌ، - يَعْنِي ابْنَ عِيَاضٍ - جَمِيعًا عَنْ مُوسَى بْنِ عُقْبَةَ، كُلُّ هَؤُلاَءِ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ ‏.‏ بِمَعْنَى حَدِيثِ مَالِكٍ وَزَادَ فِي حَدِيثِ مُوسَى بْنِ عُقْبَةَ ‏ "‏ وَإِذَا قَامَ صَاحِبُ الْقُرْآنِ فَقَرَأَهُ بِاللَّيْلِ وَالنَّهَارِ ذَكَرَهُ وَإِذَا لَمْ يَقُمْ بِهِ نَسِيَهُ ‏"‏\hadithno{1840}\hadithtrans{This hadith has been narrated by Ibn 'Umar from the Messenger of Allah (ﷺ), but in the hadith transmited by Musa b. 'Uqba, this addition is made:" When one who had committed the Qur'an to memory (or who is familiar with it) gets up (for night prayer) and recites it night and day, it remains fresh in his mind, but if he does not get up (for prayer and thus does not recite it) he forgets it}}
\hadithdefcmd{muslim}{1841}{وَحَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بِئْسَمَا لأَحَدِهِمْ يَقُولُ نَسِيتُ آيَةَ كَيْتَ وَكَيْتَ بَلْ هُوَ نُسِّيَ اسْتَذْكِرُوا الْقُرْآنَ فَلَهُوَ أَشَدُّ تَفَصِّيًا مِنْ صُدُورِ الرِّجَالِ مِنَ النَّعَمِ بِعُقُلِهَا ‏"‏ ‏.‏\hadithno{1841}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying:What a wretched person is he amongst them who says: I have forgotten such and such a verse. (He should instead of using this expression say): I have been made to forget it. Try to remember the Qur'an for it is more apt to escape from men's minds than a hobbled camel}}
\hadithdefcmd{muslim}{1842}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي وَأَبُو مُعَاوِيَةَ ح وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، - وَاللَّفْظُ لَهُ - قَالَ أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، قَالَ قَالَ عَبْدُ اللَّهِ تَعَاهَدُوا هَذِهِ الْمَصَاحِفَ - وَرُبَّمَا قَالَ الْقُرْآنَ - فَلَهُوَ أَشَدُّ تَفَصِّيًا مِنْ صُدُورِ الرِّجَالِ مِنَ النَّعَمِ مِنْ عُقُلِهِ ‏.‏ قَالَ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَقُلْ أَحَدُكُمْ نَسِيتُ آيَةَ كَيْتَ وَكَيْتَ بَلْ هُوَ نُسِّيَ ‏"‏ ‏.‏\hadithno{1842}\hadithtrans{Abdullah is reported to have said:Keep refreshing your knowledge of the sacred books (or always renew your knowledge of these sacred books) and sometimes he would mention the Qur'an for it is more apt to escape from men's minds than animals which are hobbled, and the Messenger of Allah (ﷺ) said: None of you should say: I forgot such and such a verse, but he has been made to forget}}
\hadithdefcmd{muslim}{1843}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، حَدَّثَنِي عَبْدَةُ، بْنُ أَبِي لُبَابَةَ عَنْ شَقِيقِ بْنِ سَلَمَةَ، قَالَ سَمِعْتُ ابْنَ مَسْعُودٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ بِئْسَمَا لِلرَّجُلِ أَنْ يَقُولَ نَسِيتُ سُورَةَ كَيْتَ وَكَيْتَ أَوْ نَسِيتُ آيَةَ كَيْتَ وَكَيْتَ بَلْ هُوَ نُسِّيَ ‏"‏ ‏.‏\hadithno{1843}\hadithtrans{Ibn Mas'ud reported Allah's Messenger (ﷺ) as saying:Wretched is the man who says: I forgot such and such a sura, or I forget such and such a verse, but he has been made to forget}}
\hadithdefcmd{muslim}{1844}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بَرَّادٍ الأَشْعَرِيُّ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تَعَاهَدُوا هَذَا الْقُرْآنَ فَوَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَهُوَ أَشَدُّ تَفَلُّتًا مِنَ الإِبِلِ فِي عُقُلِهَا ‏"‏ ‏.‏ وَلَفْظُ الْحَدِيثِ لاِبْنِ بَرَّادٍ\hadithno{1844}\hadithtrans{Abu Musa al-Ash'ari reported Allah's Apostle (ﷺ) as saying:Keep refreshing your knowledge of the Qur'an, for I swear by Him in Whose Hand is the life of Mahammad that it is more liable to escape than camels which are hobbled}}
\hadithdefcmd{muslim}{1845}{حَدَّثَنِي عَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، يَبْلُغُ بِهِ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَا أَذِنَ اللَّهُ لِشَىْءٍ مَا أَذِنَ لِنَبِيٍّ يَتَغَنَّى بِالْقُرْآنِ ‏"‏ ‏.‏\hadithno{1845}\hadithtrans{Abu Huraira reported this directly from the Messenger of Allah (ﷺ):God has not listened to anything as He listens to a Prophet reciting the Qur'an in a sweet voice}}
\hadithdefcmd{muslim}{1846}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، ح وَحَدَّثَنِي يُونُسُ، بْنُ عَبْدِ الأَعْلَى أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، كِلاَهُمَا عَنِ ابْنِ شِهَابٍ، بِهَذَا الإِسْنَادِ قَالَ ‏ "‏ كَمَا يَأْذَنُ لِنَبِيٍّ يَتَغَنَّى بِالْقُرْآنِ ‏"‏ ‏.‏\hadithno{1846}\hadithtrans{This hadith has been narrated by Ibn Shihab with the same chain of transmitters with words:" As He listens to a Prophet reciting the Qur'an in a sweet voice}}
\hadithdefcmd{muslim}{1847}{حَدَّثَنِي بِشْرُ بْنُ الْحَكَمِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَزِيدُ، - وَهُوَ ابْنُ الْهَادِ - عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا أَذِنَ اللَّهُ لِشَىْءٍ مَا أَذِنَ لِنَبِيٍّ حَسَنِ الصَّوْتِ يَتَغَنَّى بِالْقُرْآنِ يَجْهَرُ بِهِ ‏"‏ ‏.‏\hadithno{1847}\hadithtrans{Abu Huraira is reported to have heard Allah's Messenger (ﷺ) as saying:Allah does not listen to anything, (more approvingly) as He listens to a Prophet reciting loudly the Qur'an in a sweet voice}}
\hadithdefcmd{muslim}{1848}{وَحَدَّثَنِي ابْنُ أَخِي ابْنِ وَهْبٍ، حَدَّثَنَا عَمِّي عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عُمَرُ بْنُ، مَالِكٍ وَحَيْوَةُ بْنُ شُرَيْحٍ عَنِ ابْنِ الْهَادِ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ سَوَاءً وَقَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ وَلَمْ يَقُلْ سَمِعَ ‏.‏\hadithno{1848}\hadithtrans{This hadith has been narrated with the same chain of transmitters by Ibn al-Had except this that Abu Huraira reported Allah's Messenger (ﷺ) as saying and he did not say:" He heard it}}
\hadithdefcmd{muslim}{1849}{وَحَدَّثَنَا الْحَكَمُ بْنُ مُوسَى، حَدَّثَنَا هِقْلٌ، عَنِ الأَوْزَاعِيِّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا أَذِنَ اللَّهُ لِشَىْءٍ كَأَذَنِهِ لِنَبِيٍّ يَتَغَنَّى بِالْقُرْآنِ يَجْهَرُ بِهِ ‏"‏ ‏.‏\hadithno{1849}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Allah has not heard anything (more pleasing) than listening to the Prophet reciting the Qur'an in a sweet loud voice}}
\hadithdefcmd{muslim}{1850}{وَحَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ مِثْلَ حَدِيثِ يَحْيَى بْنِ أَبِي كَثِيرٍ غَيْرَ أَنَّ ابْنَ أَيُّوبَ قَالَ فِي رِوَايَتِهِ ‏ "‏ كَإِذْنِهِ\hadithno{1850}\hadithtrans{This hadith has been narrated by another chain of transmitters but with a slight modification of words}}
\hadithdefcmd{muslim}{1851}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا مَالِكٌ، - وَهُوَ ابْنُ مِغْوَلٍ - عَنْ عَبْدِ اللَّهِ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ عَبْدَ اللَّهِ بْنَ قَيْسٍ أَوِ الأَشْعَرِيَّ أُعْطِيَ مِزْمَارًا مِنْ مَزَامِيرِ آلِ دَاوُدَ ‏"‏ ‏.‏\hadithno{1851}\hadithtrans{Buraida reported on the authority of his father that the Messenger of Allah (ﷺ) had said:'Abdullah b. Qais or al-Ash'ari has been gifted with a sweet melodious voice out of the voices of the family of David}}
\hadithdefcmd{muslim}{1852}{وَحَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا طَلْحَةُ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأَبِي مُوسَى ‏ "‏ لَوْ رَأَيْتَنِي وَأَنَا أَسْتَمِعُ لِقِرَاءَتِكَ الْبَارِحَةَ لَقَدْ أُوتِيتَ مِزْمَارًا مِنْ مَزَامِيرِ آلِ دَاوُدَ ‏"‏ ‏.‏\hadithno{1852}\hadithtrans{Abu Burda narrated on the authority of Abu Musa that the Messenger of Allah (ﷺ) had said to Abu Musa:If you were to see me, as I was listening to your recitation (of the Qur'an) yester-night (you would have felt delighted). You are in fact endowed with a sweet voice like that of David himself}}
\hadithdefcmd{muslim}{1853}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، وَوَكِيعٌ، عَنْ شُعْبَةَ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مُغَفَّلٍ الْمُزَنِيَّ، يَقُولُ قَرَأَ النَّبِيُّ صلى الله عليه وسلم عَامَ الْفَتْحِ فِي مَسِيرٍ لَهُ سُورَةَ الْفَتْحِ عَلَى رَاحِلَتِهِ فَرَجَّعَ فِي قِرَاءَتِهِ ‏.‏ قَالَ مُعَاوِيَةُ لَوْلاَ أَنِّي أَخَافُ أَنْ يَجْتَمِعَ عَلَىَّ النَّاسُ لَحَكَيْتُ لَكُمْ قِرَاءَتَهُ ‏.‏\hadithno{1853}\hadithtrans{Mu'awiya b. Qurra reported 'Abdullah b. Mughaffal al-Muzani as saying:The Apostle of Allah (ﷺ) recited on his ride Surat al Fath during a journey in the year of the Conquest (of Mecca), and he repeated (the words) in his recitation. Mu'awiya said: If I were not afraid that the people would crowd around me, I would have given a demonstration of (the Prophet's) recitation before you}}
\hadithdefcmd{muslim}{1854}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مُغَفَّلٍ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَوْمَ فَتْحِ مَكَّةَ عَلَى نَاقَتِهِ يَقْرَأُ سُورَةَ الْفَتْحِ ‏.‏ قَالَ فَقَرَأَ ابْنُ مُغَفَّلٍ وَرَجَّعَ ‏.‏ فَقَالَ مُعَاوِيَةُ لَوْلاَ النَّاسُ لأَخَذْتُ لَكُمْ بِذَلِكَ الَّذِي ذَكَرَهُ ابْنُ مُغَفَّلٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1854}\hadithtrans{Mu'awiya b. Qurra is reported to have heard 'Abdullah b. Mughaffal as saying:I saw the Messenger of Allah (ﷺ) reciting Surah Fath on his camel on the day of the Conquest of Mecca. He (the narrator) said: Ibn Mughaffal recited it and repeated it. Mu'awiya said: Had there been (no crowed of) people, I would have given a practical demonstration of that which Ibn Mughaffal had mentioned from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1855}{وَحَدَّثَنَاهُ يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، ح وَحَدَّثَنَا عُبَيْدُ، اللَّهِ بْنُ مُعَاذٍ حَدَّثَنَا أَبِي قَالاَ، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ نَحْوَهُ وَفِي حَدِيثِ خَالِدِ بْنِ الْحَارِثِ قَالَ عَلَى رَاحِلَةٍ يَسِيرُ وَهُوَ يَقْرَأُ سُورَةَ الْفَتْحِ ‏.‏\hadithno{1855}\hadithtrans{This hadlth has been narrated by Khalid al-Harith with the same chain of transmitters (with these words):(The Holy Prophet) was reciting Surat al-Fath as he was travelling on his mount}}
\hadithdefcmd{muslim}{1856}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، أَخْبَرَنَا أَبُو خَيْثَمَةَ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ كَانَ رَجُلٌ يَقْرَأُ سُورَةَ الْكَهْفِ وَعِنْدَهُ فَرَسٌ مَرْبُوطٌ بِشَطَنَيْنِ فَتَغَشَّتْهُ سَحَابَةٌ فَجَعَلَتْ تَدُورُ وَتَدْنُو وَجَعَلَ فَرَسُهُ يَنْفِرُ مِنْهَا فَلَمَّا أَصْبَحَ أَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ ذَلِكَ لَهُ فَقَالَ ‏ "‏ تِلْكَ السَّكِينَةُ تَنَزَّلَتْ لِلْقُرْآنِ ‏"‏ ‏.‏\hadithno{1856}\hadithtrans{Al-Bara' reported that a person was reciting Surat al-Kahf and there was a horse tied with two ropes at his side, a cloud overshadowed him, and as it began to come nearer and nearer his horse began to take fright from it. He went and mentioned that to the Prophet (ﷺ) in the morning, and he (the Holy Prophet) said:That was tranquillity which came down at the recitation of the Qur'an}}
\hadithdefcmd{muslim}{1857}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ، جَعْفَرٍ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ، يَقُولُ قَرَأَ رَجُلٌ الْكَهْفَ وَفِي الدَّارِ دَابَّةٌ فَجَعَلَتْ تَنْفِرُ فَنَظَرَ فَإِذَا ضَبَابَةٌ أَوْ سَحَابَةٌ قَدْ غَشِيَتْهُ قَالَ فَذَكَرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ اقْرَأْ فُلاَنُ فَإِنَّهَا السَّكِينَةُ تَنَزَّلَتْ عِنْدَ الْقُرْآنِ أَوْ تَنَزَّلَتْ لِلْقُرْآنِ ‏"‏ ‏.‏\hadithno{1857}\hadithtrans{Ibn Ishaq reported:I heard al-Bara' as saying that a man recited al-Kahf when an animal was there in the house and it began to take fright. And as he looked around, he found a cloud overshadowing it. He mentioned that to the Messenger of Allah (ﷺ). Upon this he said: O so and so, recite on (the surah) as- Sakina descends at the (recitation of the Qur'an) or on account (of the recitation) of the Qur'an}}
\hadithdefcmd{muslim}{1858}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، وَأَبُو دَاوُدَ قَالاَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ سَمِعْتُ الْبَرَاءَ، يَقُولُ ‏.‏ فَذَكَرَا نَحْوَهُ غَيْرَ أَنَّهُمَا قَالاَ تَنْقُزُ ‏.‏\hadithno{1858}\hadithtrans{This hadith has been narrated on the authority of al-Bara' with a slight modification of words}}
\hadithdefcmd{muslim}{1859}{وَحَدَّثَنِي حَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَحَجَّاجُ بْنُ الشَّاعِرِ، - وَتَقَارَبَا فِي اللَّفْظِ - قَالاَ حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، حَدَّثَنَا يَزِيدُ بْنُ الْهَادِ، أَنَّ عَبْدَ اللَّهِ بْنَ خَبَّابٍ، حَدَّثَهُ أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ حَدَّثَهُ أَنَّ أُسَيْدَ بْنَ حُضَيْرٍ بَيْنَمَا هُوَ لَيْلَةً يَقْرَأُ فِي مِرْبَدِهِ إِذْ جَالَتْ فَرَسُهُ فَقَرَأَ ثُمَّ جَالَتْ أُخْرَى فَقَرَأَ ثُمَّ جَالَتْ أَيْضًا قَالَ أُسَيْدٌ فَخَشِيتُ أَنْ تَطَأَ يَحْيَى فَقُمْتُ إِلَيْهَا فَإِذَا مِثْلُ الظُّلَّةِ فَوْقَ رَأْسِي فِيهَا أَمْثَالُ السُّرُجِ عَرَجَتْ فِي الْجَوِّ حَتَّى مَا أَرَاهَا - قَالَ - فَغَدَوْتُ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ بَيْنَمَا أَنَا الْبَارِحَةَ مِنْ جَوْفِ اللَّيْلِ أَقْرَأُ فِي مِرْبَدِي إِذْ جَالَتْ فَرَسِي ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَإِ ابْنَ حُضَيْرٍ ‏"‏ ‏.‏ قَالَ فَقَرَأْتُ ثُمَّ جَالَتْ أَيْضًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَإِ ابْنَ حُضَيْرٍ ‏"‏ ‏.‏ قَالَ فَقَرَأْتُ ثُمَّ جَالَتْ أَيْضًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَإِ ابْنَ حُضَيْرٍ ‏"‏ ‏.‏ قَالَ فَانْصَرَفْتُ ‏.‏ وَكَانَ يَحْيَى قَرِيبًا مِنْهَا خَشِيتُ أَنْ تَطَأَهُ فَرَأَيْتُ مِثْلَ الظُّلَّةِ فِيهَا أَمْثَالُ السُّرُجِ عَرَجَتْ فِي الْجَوِّ حَتَّى مَا أَرَاهَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تِلْكَ الْمَلاَئِكَةُ كَانَتْ تَسْتَمِعُ لَكَ وَلَوْ قَرَأْتَ لأَصْبَحَتْ يَرَاهَا النَّاسُ مَا تَسْتَتِرُ مِنْهُمْ ‏"‏ ‏.‏\hadithno{1859}\hadithtrans{Abu Sa'id al-Khudri told of Usaid b. Hudair saying that one night he recited the Qur'an in his enclosure, when the horse began to jump about. He again recited and (the horse) again jumped. He again recited and it jumped as before. Usaid said:I was afraid lest it should trample (his son) Yahya. I stood near it (the horse) and saw something like a canopy over my head with what seemed to be lamps in it, rising up in the sky till it disappeared. I went to the Messenger of Allah (ﷺ) on the next day and said: Messenger of Allah, I recited the Qur'an during the night in my enclosure and my horse began to jump. Upon this the Messenger of Allah (ﷺ) said: You should have kept on reciting, Ibn Hudair. He (Ibn Hudair) said: I recited. It jumped (as before). Upon this the Messenger of Allah (ﷺ) again said: You should have kept on reciting, Ibn Hudair. He (Ibn Hudair) said: I recited and it again jumped (as before). The Messenger of Allah (ﷺ) again said: You should kave kept on reciting, Ibu Hudair. He (Ibn Hudair) said: (Messenger of Allah) I finished (the recitation) for Yahya was near (the horse) and I was afraid lest it should trample him. I saw something like a canopy with what seemed to be lamps in it rising up in the sky till it disappeared. Upon this the Messenger of Allah (ﷺ) said: Those were the angels who listened to you; and if you had continued reciting, the people would have seen them in the morning and they would not have concealed themselves from them}}
\hadithdefcmd{muslim}{1860}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو كَامِلٍ الْجَحْدَرِيُّ كِلاَهُمَا عَنْ أَبِي عَوَانَةَ، - قَالَ قُتَيْبَةُ حَدَّثَنَا أَبُو عَوَانَةَ، - عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنْ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلُ الْمُؤْمِنِ الَّذِي يَقْرَأُ الْقُرْآنَ مَثَلُ الأُتْرُجَّةِ رِيحُهَا طَيِّبٌ وَطَعْمُهَا طَيِّبٌ وَمَثَلُ الْمُؤْمِنِ الَّذِي لاَ يَقْرَأُ الْقُرْآنَ مَثَلُ التَّمْرَةِ لاَ رِيحَ لَهَا وَطَعْمُهَا حُلْوٌ وَمَثَلُ الْمُنَافِقِ الَّذِي يَقْرَأُ الْقُرْآنَ مَثَلُ الرَّيْحَانَةِ رِيحُهَا طَيِّبٌ وَطَعْمُهَا مُرٌّ وَمَثَلُ الْمُنَافِقِ الَّذِي لاَ يَقْرَأُ الْقُرْآنَ كَمَثَلِ الْحَنْظَلَةِ لَيْسَ لَهَا رِيحٌ وَطَعْمُهَا مُرٌّ ‏"‏ ‏.‏\hadithno{1860}\hadithtrans{Abu Musa al-Ash'ari reported Allah's Messenger (ﷺ) as saying:A believer who recites the Qur'an is like an orange whose fragrance is sweet and whose taste is sweet; a believer who does not recite the Qur'an is like a date which has no fragrance but has a sweet taste; and the hypocrite who recites the Qur'an is like a basil whose fragrance is sweet, but whose taste is bitter; and a hypocrite who does not recite the Qur'an is like the colocynth which has no fragrance and has a bitter taste}}
\hadithdefcmd{muslim}{1861}{وَحَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، بْنُ سَعِيدٍ عَنْ شُعْبَةَ، كِلاَهُمَا عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّ فِي حَدِيثِ هَمَّامٍ بَدَلَ الْمُنَافِقِ الْفَاجِرِ ‏.‏\hadithno{1861}\hadithtrans{This hadith has been narrated by Qatada with the same chain of transmitters but with one alteration that instead of the word:" hypocrite" (Munafiq), there it is" wicked" (fajir)}}
\hadithdefcmd{muslim}{1862}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَمُحَمَّدُ بْنُ عُبَيْدٍ الْغُبَرِيُّ، جَمِيعًا عَنْ أَبِي عَوَانَةَ، - قَالَ ابْنُ عُبَيْدٍ حَدَّثَنَا أَبُو عَوَانَةَ، - عَنْ قَتَادَةَ، عَنْ زُرَارَةَ بْنِ أَوْفَى، عَنْ سَعْدِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْمَاهِرُ بِالْقُرْآنِ مَعَ السَّفَرَةِ الْكِرَامِ الْبَرَرَةِ وَالَّذِي يَقْرَأُ الْقُرْآنَ وَيَتَتَعْتَعُ فِيهِ وَهُوَ عَلَيْهِ شَاقٌّ لَهُ أَجْرَانِ ‏"‏ ‏.‏\hadithno{1862}\hadithtrans{A'isha reported Allah's Messenger (ﷺ) (as saying):One who is proficient in the Qur'an is associated with the noble, upright, recording angels; and he who falters in it, and finds it difficult for him, will have two rewards}}
\hadithdefcmd{muslim}{1863}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، ح وَحَدَّثَنَا أَبُو بَكْرِ، بْنُ أَبِي شَيْبَةَ حَدَّثَنَا وَكِيعٌ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، كِلاَهُمَا عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ ‏.‏ وَقَالَ فِي حَدِيثِ وَكِيعٍ ‏ "‏ وَالَّذِي يَقْرَأُ وَهُوَ يَشْتَدُّ عَلَيْهِ لَهُ أَجْرَانِ ‏"‏ ‏.‏\hadithno{1863}\hadithtrans{This hadith has been reported with the same chain of transmitters by Qatada except with this change:" He who finds it hard (to recite the Qur'an) will have a double reward}}
\hadithdefcmd{muslim}{1864}{حَدَّثَنَا هَدَّابُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لأُبَىٍّ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي أَنْ أَقْرَأَ عَلَيْكَ ‏"‏ ‏.‏ قَالَ آللَّهُ سَمَّانِي لَكَ قَالَ ‏"‏ اللَّهُ سَمَّاكَ لِي ‏"‏ ‏.‏ قَالَ فَجَعَلَ أُبَىٌّ يَبْكِي ‏.‏\hadithno{1864}\hadithtrans{Anas reported Allah's Messenger (ﷺ) as saying to Ubayy b. Ka'b:Allah has commanded me to recite the Qur'an to you. He said: Did Allah mention me to you by name? He (the Holy Prophet) said: Allah made a mention of your name to me. (On hearing this) Ubayy b. Ka'b wept}}
\hadithdefcmd{muslim}{1865}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ قَتَادَةَ، يُحَدِّثُ عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأُبَىِّ بْنِ كَعْبٍ ‏"‏ إِنَّ اللَّهَ أَمَرَنِي أَنْ أَقْرَأَ عَلَيْكَ ‏\{‏ لَمْ يَكُنِ الَّذِينَ كَفَرُوا‏\}‏ ‏"‏ ‏.‏ قَالَ وَسَمَّانِي لَكَ قَالَ ‏"‏ نَعَمْ ‏"‏ ‏.‏ قَالَ فَبَكَى ‏.‏\hadithno{1865}\hadithtrans{Anas reported Allah's Messenger (ﷺ) as saying to Ubayy b. Ka`b:Allah has commanded me to recite to you:" Those who disbelieve were not..." (al-Qur'an, xcviii. 1). He said: Did He mention me by name? He (the Prophet said): Yes. Upon this he shed tears (of gratitude)}}
\hadithdefcmd{muslim}{1866}{حَدَّثَنَا يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا خَالِدٌ، - يَعْنِي ابْنَ الْحَارِثِ - حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لأُبَىٍّ بِمِثْلِهِ ‏.‏\hadithno{1866}\hadithtrans{Qatada said:I heard Anas saying that the Messenger of Allah (ﷺ) said to Ubayy the same thing}}
\hadithdefcmd{muslim}{1867}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ جَمِيعًا عَنْ حَفْصٍ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، - عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اقْرَأْ عَلَىَّ الْقُرْآنَ ‏"‏ ‏.‏ قَالَ فَقُلْتُ يَا رَسُولَ اللَّهِ أَقْرَأُ عَلَيْكَ وَعَلَيْكَ أُنْزِلَ قَالَ ‏"‏ إِنِّي أَشْتَهِي أَنْ أَسْمَعَهُ مِنْ غَيْرِي ‏"‏ ‏.‏ فَقَرَأْتُ النِّسَاءَ حَتَّى إِذَا بَلَغْتُ ‏\{‏ فَكَيْفَ إِذَا جِئْنَا مِنْ كُلِّ أُمَّةٍ بِشَهِيدٍ وَجِئْنَا بِكَ عَلَى هَؤُلاَءِ شَهِيدًا‏\}‏ رَفَعْتُ رَأْسِي أَوْ غَمَزَنِي رَجُلٌ إِلَى جَنْبِي فَرَفَعْتُ رَأْسِي فَرَأَيْتُ دُمُوعَهُ تَسِيلُ ‏.‏\hadithno{1867}\hadithtrans{Abdullah (b. Mas'ud) reported:The Messenger of Allah (may peace be upon (him) asked me to recite the Qur'an. He said: Messenger of Allah, (how) should I recite to you whereas it has been sent down to you? He (the Holy Prophet) said: I desire to hear it from someone else. So I recited Surat al-Nisa' till I reached the verse: How then shall it be when We shall bring from every people a witness and bring you against them as a witness?" (verse 41). I lifted my head or a person touched me in my side, and so I lifted my head and saw his tears falling (from the Holy Prophet's eyes)}}
\hadithdefcmd{muslim}{1868}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، وَمِنْجَابُ بْنُ الْحَارِثِ التَّمِيمِيُّ، جَمِيعًا عَنْ عَلِيِّ بْنِ مُسْهِرٍ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ وَزَادَ هَنَّادٌ فِي رِوَايَتِهِ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى الْمِنْبَرِ ‏ "‏ اقْرَأْ عَلَىَّ ‏"‏ ‏.‏\hadithno{1868}\hadithtrans{This hadith has been narratted by A'mash with the same chain of transmitters but with this addition:" The Messenger of Allah (ﷺ) was on the pulpit when he asked me to recite to him}}
\hadithdefcmd{muslim}{1869}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنِي مِسْعَرٌ، - وَقَالَ أَبُو كُرَيْبٍ عَنْ مِسْعَرٍ، - عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ إِبْرَاهِيمَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم لِعَبْدِ اللَّهِ بْنِ مَسْعُودٍ ‏"‏ اقْرَأْ عَلَىَّ ‏"‏ ‏.‏ قَالَ أَقْرَأُ عَلَيْكَ وَعَلَيْكَ أُنْزِلَ قَالَ ‏"‏ إِنِّي أُحِبُّ أَنْ أَسْمَعَهُ مِنْ غَيْرِي ‏"‏ قَالَ فَقَرَأَ عَلَيْهِ مِنْ أَوَّلِ سُورَةِ النِّسَاءِ إِلَى قَوْلِهِ ‏\{‏ فَكَيْفَ إِذَا جِئْنَا مِنْ كُلِّ أُمَّةٍ بِشَهِيدٍ وَجِئْنَا بِكَ عَلَى هَؤُلاَءِ شَهِيدًا‏\}‏ فَبَكَى ‏.‏ قَالَ مِسْعَرٌ فَحَدَّثَنِي مَعْنٌ عَنْ جَعْفَرِ بْنِ عَمْرِو بْنِ حُرَيْثٍ عَنْ أَبِيهِ عَنِ ابْنِ مَسْعُودٍ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ شَهِيدًا عَلَيْهِمْ مَا دُمْتُ فِيهِمْ أَوْ مَا كُنْتُ فِيهِمْ ‏"‏ ‏.‏ شَكَّ مِسْعَرٌ ‏.‏\hadithno{1869}\hadithtrans{Ibrahim reported that the Messenger of Allah (ﷺ) asked 'Abdullah b. Mas'ud to recite to him (the Qur'an). He said:Should I recite it to you while it has been sent down or revealed to you? He (the Holy Prophet) said: I love to hear it from someone else. So he ('Abdullah b. Mas'ud) recited to him (from the beginning of Surat al Nisa' up to the verse:" How shall then it be when We bring from every people a witness and bring you as a witness against them?" He (the Holy Prophet) wept (on listening to it). It is narrated on the authority of Ibn Mas'ud through another chain of transmitters that the Messenger of Allah (ﷺ) also said that he had been a witness to his people as long as (said he): I lived among them or I had been among them}}
\hadithdefcmd{muslim}{1870}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنْتُ بِحِمْصَ فَقَالَ لِي بَعْضُ الْقَوْمِ اقْرَأْ عَلَيْنَا ‏.‏ فَقَرَأْتُ عَلَيْهِمْ سُورَةَ يُوسُفَ - قَالَ - فَقَالَ رَجُلٌ مِنَ الْقَوْمِ وَاللَّهِ مَا هَكَذَا أُنْزِلَتْ ‏.‏ قَالَ قُلْتُ وَيْحَكَ وَاللَّهِ لَقَدْ قَرَأْتُهَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لِي ‏ "‏ أَحْسَنْتَ ‏"‏ ‏.‏ فَبَيْنَمَا أَنَا أُكَلِّمُهُ إِذْ وَجَدْتُ مِنْهُ رِيحَ الْخَمْرِ قَالَ فَقُلْتُ أَتَشْرَبُ الْخَمْرَ وَتُكَذِّبُ بِالْكِتَابِ لاَ تَبْرَحُ حَتَّى أَجْلِدَكَ - قَالَ - فَجَلَدْتُهُ الْحَدَّ ‏.‏\hadithno{1870}\hadithtrans{Abdullah (b. Mas'ud) reported:I was in Hims when some of the people asked me to recite the Qur'an to them. So I recited Surah Yusuf to them. One of the persons among the people said: By Allah, this is not how it has been sent down. I said: Woe upon you! By Allah, I recited it to the Messenger of Allah (ﷺ) and he said to me: You have (recited) it well. I was talking with him (the man who objected to my recitation) that I sensed the smell of wine from him. So I said to him. Do you drink wine and belie the Book (of Allah)? You would not depart till I would whip you. So I lashed him according to the prescribed punishment (for the offence of drinking wine)}}
\hadithdefcmd{muslim}{1871}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَلِيُّ بْنُ خَشْرَمٍ، قَالاَ أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، جَمِيعًا عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ ‏.‏ وَلَيْسَ فِي حَدِيثِ أَبِي مُعَاوِيَةَ فَقَالَ لِي ‏ "‏ أَحْسَنْتَ ‏"‏ ‏.‏\hadithno{1871}\hadithtrans{This hadith has been narrated by A'mash with the same chain of transmitters but with an exception that it is not mentioned in it:" He said to me: You recited (the Qur'an) well}}
\hadithdefcmd{muslim}{1872}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو سَعِيدٍ الأَشَجُّ قَالاَ حَدَّثَنَا وَكِيعٌ، عَنِ الأَعْمَشِ،عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيُحِبُّ أَحَدُكُمْ إِذَا رَجَعَ إِلَى أَهْلِهِ أَنْ يَجِدَ فِيهِ ثَلاَثَ خَلِفَاتٍ عِظَامٍ سِمَانٍ ‏"‏ ‏.‏ قُلْنَا نَعَمْ ‏.‏ قَالَ ‏"‏ فَثَلاَثُ آيَاتٍ يَقْرَأُ بِهِنَّ أَحَدُكُمْ فِي صَلاَتِهِ خَيْرٌ لَهُ مِنْ ثَلاَثِ خَلِفَاتٍ عِظَامٍ سِمَانٍ ‏"‏ ‏.‏\hadithno{1872}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Would any one of you like, when he returns to his family, to find there three large, fat, pregnant she-camels? We said: Yes. Upon this he said: Three verses that one of you recites in his prayer are better for him than three large, fat, pregnant she-camels}}
\hadithdefcmd{muslim}{1873}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، عَنْ مُوسَى بْنِ عُلَىٍّ، قَالَ سَمِعْتُ أَبِي يُحَدِّثُ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ خَرَجَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَنَحْنُ فِي الصُّفَّةِ فَقَالَ ‏"‏ أَيُّكُمْ يُحِبُّ أَنْ يَغْدُوَ كُلَّ يَوْمٍ إِلَى بُطْحَانَ أَوْ إِلَى الْعَقِيقِ فَيَأْتِيَ مِنْهُ بِنَاقَتَيْنِ كَوْمَاوَيْنِ فِي غَيْرِ إِثْمٍ وَلاَ قَطْعِ رَحِمٍ ‏"‏ ‏.‏ فَقُلْنَا يَا رَسُولَ اللَّهِ نُحِبُّ ذَلِكَ ‏.‏ قَالَ ‏"‏ أَفَلاَ يَغْدُو أَحَدُكُمْ إِلَى الْمَسْجِدِ فَيَعْلَمَ أَوْ يَقْرَأَ آيَتَيْنِ مِنْ كِتَابِ اللَّهِ عَزَّ وَجَلَّ خَيْرٌ لَهُ مِنْ نَاقَتَيْنِ وَثَلاَثٌ خَيْرٌ لَهُ مِنْ ثَلاَثٍ وَأَرْبَعٌ خَيْرٌ لَهُ مِنْ أَرْبَعٍ وَمِنْ أَعْدَادِهِنَّ مِنَ الإِبِلِ ‏"‏ ‏.‏\hadithno{1873}\hadithtrans{Uqba b. 'Amir reported:When we were in Suffa, the Messenger of Allah (ﷺ) came out and said: Which of you would like to go out every morning to Buthan or al-'Aqiq and bring two large she-camels without being guilty of sin or without severing the ties of kinship? We said: Messenger of Allah, we would like to do it. Upon this he said: Does not one of you go out in the morning to the mosque and teach or recite two verses from the Book of Allah. the Majestic and Glorious? That is better for him than two she-camels, and three verses are better (than three she-camels). and four verses are better for him than four (she-camels), and to on their number in camels}}
\hadithdefcmd{muslim}{1874}{حَدَّثَنِي الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا أَبُو تَوْبَةَ، - وَهُوَ الرَّبِيعُ بْنُ نَافِعٍ - حَدَّثَنَا مُعَاوِيَةُ، - يَعْنِي ابْنَ سَلاَّمٍ - عَنْ زَيْدٍ، أَنَّهُ سَمِعَ أَبَا سَلاَّمٍ، يَقُولُ حَدَّثَنِي أَبُو أُمَامَةَ، الْبَاهِلِيُّ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ اقْرَءُوا الْقُرْآنَ فَإِنَّهُ يَأْتِي يَوْمَ الْقِيَامَةِ شَفِيعًا لأَصْحَابِهِ اقْرَءُوا الزَّهْرَاوَيْنِ الْبَقَرَةَ وَسُورَةَ آلِ عِمْرَانَ فَإِنَّهُمَا تَأْتِيَانِ يَوْمَ الْقِيَامَةِ كَأَنَّهُمَا غَمَامَتَانِ أَوْ كَأَنَّهُمَا غَيَايَتَانِ أَوْ كَأَنَّهُمَا فِرْقَانِ مِنْ طَيْرٍ صَوَافَّ تُحَاجَّانِ عَنْ أَصْحَابِهِمَا اقْرَءُوا سُورَةَ الْبَقَرَةِ فَإِنَّ أَخْذَهَا بَرَكَةٌ وَتَرْكَهَا حَسْرَةٌ وَلاَ تَسْتَطِيعُهَا الْبَطَلَةُ ‏"‏ ‏.‏ قَالَ مُعَاوِيَةُ بَلَغَنِي أَنَّ الْبَطَلَةَ السَّحَرَةُ ‏.‏\hadithno{1874}\hadithtrans{Abu Umama said he heard Allah's Messenger (ﷺ) say:Recite the Qur'an, for on the Day of Resurrection it will come as an intercessor for those who recite It. Recite the two bright ones, al-Baqara and Surah Al 'Imran, for on the Day of Resurrection they will come as two clouds or two shades, or two flocks of birds in ranks, pleading for those who recite them. Recite Surah al-Baqara, for to take recourse to it is a blessing and to give it up is a cause of grief, and the magicians cannot confront it. (Mu'awiya said: It has been conveyed to me that here Batala means magicians)}}
\hadithdefcmd{muslim}{1875}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا يَحْيَى، - يَعْنِي ابْنَ حَسَّانَ - حَدَّثَنَا مُعَاوِيَةُ، بِهَذَا الإِسْنَادِ ‏.‏ مِثْلَهُ غَيْرَ أَنَّهُ قَالَ ‏ "‏ وَكَأَنَّهُمَا ‏"‏ ‏.‏ فِي كِلَيْهِمَا وَلَمْ يَذْكُرْ قَوْلَ مُعَاوِيَةَ بَلَغَنِي ‏.‏\hadithno{1875}\hadithtrans{This hadith has been narrated by Mu'awiya with the same chain of transmitters but with this exception that in this the words of Mu'awiya:" It has been conveyed to me..." have not been mentioned}}
\hadithdefcmd{muslim}{1876}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا يَزِيدُ بْنُ عَبْدِ رَبِّهِ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ مُحَمَّدِ بْنِ مُهَاجِرٍ، عَنِ الْوَلِيدِ بْنِ عَبْدِ الرَّحْمَنِ الْجُرَشِيِّ، عَنْ جُبَيْرِ بْنِ نُفَيْرٍ، قَالَ سَمِعْتُ النَّوَّاسَ، بْنَ سَمْعَانَ الْكِلاَبِيَّ يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ يُؤْتَى بِالْقُرْآنِ يَوْمَ الْقِيَامَةِ وَأَهْلِهِ الَّذِينَ كَانُوا يَعْمَلُونَ بِهِ تَقْدُمُهُ سُورَةُ الْبَقَرَةِ وَآلُ عِمْرَانَ ‏"‏ ‏.‏ وَضَرَبَ لَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم ثَلاَثَةَ أَمْثَالٍ مَا نَسِيتُهُنَّ بَعْدُ قَالَ ‏"‏ كَأَنَّهُمَا غَمَامَتَانِ أَوْ ظُلَّتَانِ سَوْدَاوَانِ بَيْنَهُمَا شَرْقٌ أَوْ كَأَنَّهُمَا حِزْقَانِ مِنْ طَيْرٍ صَوَافَّ تُحَاجَّانِ عَنْ صَاحِبِهِمَا\hadithno{1876}\hadithtrans{An-Nawwas b. Sam'an said he heard the Apostle (ﷺ) say:On the Day of Resurrection the Qur'an and those who acted according to it will be brought with Surah al-Baqara and AI 'Imran preceding them. The Messenger of Allah (ﷺ) likened them to three things, which I did not forget afterwards. He (the Holy Prophet) likened them to two clouds, or two black canopies with light between them, or like two flocks of birds in ranks pleading for one who recited them}}
\hadithdefcmd{muslim}{1877}{حَدَّثَنَا حَسَنُ بْنُ الرَّبِيعِ، وَأَحْمَدُ بْنُ جَوَّاسٍ الْحَنَفِيُّ، قَالاَ حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ عَمَّارِ بْنِ رُزَيْقٍ، عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ بَيْنَمَا جِبْرِيلُ قَاعِدٌ عِنْدَ النَّبِيِّ صلى الله عليه وسلم سَمِعَ نَقِيضًا مِنْ فَوْقِهِ فَرَفَعَ رَأْسَهُ فَقَالَ هَذَا بَابٌ مِنَ السَّمَاءِ فُتِحَ الْيَوْمَ لَمْ يُفْتَحْ قَطُّ إِلاَّ الْيَوْمَ فَنَزَلَ مِنْهُ مَلَكٌ فَقَالَ هَذَا مَلَكٌ نَزَلَ إِلَى الأَرْضِ لَمْ يَنْزِلْ قَطُّ إِلاَّ الْيَوْمَ فَسَلَّمَ وَقَالَ أَبْشِرْ بِنُورَيْنِ أُوتِيتَهُمَا لَمْ يُؤْتَهُمَا نَبِيٌّ قَبْلَكَ فَاتِحَةُ الْكِتَابِ وَخَوَاتِيمُ سُورَةِ الْبَقَرَةِ لَنْ تَقْرَأَ بِحَرْفٍ مِنْهُمَا إِلاَّ أُعْطِيتَهُ ‏.‏\hadithno{1877}\hadithtrans{Ibn 'Abbas reported that while Gabriel was sitting with the Apostle (ﷺ) he heard a creaking sound above him. He lifted his head and said:This is a gate opened in heaven today which had never been opened before. Then when an angel descended through it, he said: This is an angel who came down to the earth who had never come down before. He greeted and said: Rejoice in two lights given to you which have not been given to any prophet before you: Fatihat al-Kitab and the concluding verses of Surah al-Baqara. You will never recite a letter from them for which you will not be given (a reward)}}
\hadithdefcmd{muslim}{1878}{وَحَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا مَنْصُورٌ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ يَزِيدَ قَالَ لَقِيتُ أَبَا مَسْعُودٍ عِنْدَ الْبَيْتِ فَقُلْتُ حَدِيثٌ بَلَغَنِي عَنْكَ فِي الآيَتَيْنِ فِي سُورَةِ الْبَقَرَةِ ‏.‏ فَقَالَ نَعَمْ ‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الآيَتَانِ مِنْ آخِرِ سُورَةِ الْبَقَرَةِ مَنْ قَرَأَهُمَا فِي لَيْلَةٍ كَفَتَاهُ ‏"‏ ‏.‏\hadithno{1878}\hadithtrans{Abd al-Rahman b. Yazid reported:I met Abu Mas'ud near the House (Ka'ba) and said to him: A hadith has been conveyed to me on your authority about the two (concluding verses of Surah al-Baqara. He said: Yes. The Messenger of Allah (ﷺ) (in fact) said: Anyone who recites the two verses at the end of Surah al-Baqara at night, they would suffice for him}}
\hadithdefcmd{muslim}{1879}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا جَرِيرٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، كِلاَهُمَا عَنْ مَنْصُورٍ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{1879}\hadithtrans{This hadith has been narrated by Mansur with the same chain of transmitters}}
\hadithdefcmd{muslim}{1880}{حَدَّثَنَا مِنْجَابُ بْنُ الْحَارِثِ التَّمِيمِيُّ، أَخْبَرَنَا ابْنُ مُسْهِرٍ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ عَلْقَمَةَ بْنِ قَيْسٍ، عَنْ أَبِي مَسْعُودٍ الأَنْصَارِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَرَأَ هَاتَيْنِ الآيَتَيْنِ مِنْ آخِرِ سُورَةِ الْبَقَرَةِ فِي لَيْلَةٍ كَفَتَاهُ ‏"‏ ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ فَلَقِيتُ أَبَا مَسْعُودٍ وَهُوَ يَطُوفُ بِالْبَيْتِ فَسَأَلْتُهُ فَحَدَّثَنِي بِهِ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1880}\hadithtrans{Abu Mas'ud reported Allah's Messenger (ﷺ) as saying:If anyone recites the two verses at the end of Surah al-Baqara at night, they would suffice for him 'Abd al-Rahman said: I met Abu Mas'ud and he was circumambulating the House (of Allah) and asked him about this (tradition) and he narrated it to me from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1881}{وَحَدَّثَنِي عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا عِيسَى يَعْنِي ابْنَ يُونُسَ، ح وَحَدَّثَنَا أَبُو بَكْرِ، بْنُ أَبِي شَيْبَةَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، جَمِيعًا عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، وَعَبْدِ، الرَّحْمَنِ بْنِ يَزِيدَ عَنْ أَبِي مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{1881}\hadithtrans{A hadith like this has been narrated by Abu Mas'ud from the Messenger of Allah (ﷺ) through another chain of transmitters}}
\hadithdefcmd{muslim}{1882}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصٌ، وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ يَزِيدَ، عَنْ أَبِي مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ ‏.‏\hadithno{1882}\hadithtrans{It is through another chain of transmitters that this hadith has been reported by Abu Mas'ud from the Messenger of Allah (ﷺ)}}
\hadithdefcmd{muslim}{1883}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ سَالِمِ، بْنِ أَبِي الْجَعْدِ الْغَطَفَانِيِّ عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ الْيَعْمَرِيِّ، عَنْ أَبِي الدَّرْدَاءِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ حَفِظَ عَشْرَ آيَاتٍ مِنْ أَوَّلِ سُورَةِ الْكَهْفِ عُصِمَ مِنَ الدَّجَّالِ ‏"‏\hadithno{1883}\hadithtrans{Abu Darda' reported Allah's Apostle (ﷺ) as saying:If anyone learns by heart the first ten verses of the Surah al-Kahf, he will be protected from the Dajjal}}
\hadithdefcmd{muslim}{1884}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا هَمَّامٌ، جَمِيعًا عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ قَالَ شُعْبَةُ مِنْ آخِرِ الْكَهْفِ ‏.‏ وَقَالَ هَمَّامٌ مِنْ أَوَّلِ الْكَهْفِ كَمَا قَالَ هِشَامٌ\hadithno{1884}\hadithtrans{This hadith has been transmitted by Qatada with the same chain of transmitters. But Shu'ba (one of the narrators) said:At the end of Surah al-Kahf, but Hammam said: At the beginning of Surah al-Kahf}}
\hadithdefcmd{muslim}{1885}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي السَّلِيلِ، عَنْ عَبْدِ اللَّهِ بْنِ رَبَاحٍ الأَنْصَارِيِّ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا أَبَا الْمُنْذِرِ أَتَدْرِي أَىُّ آيَةٍ مِنْ كِتَابِ اللَّهِ مَعَكَ أَعْظَمُ ‏"‏ ‏.‏ قَالَ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ ‏.‏ قَالَ ‏"‏ يَا أَبَا الْمُنْذِرِ أَتَدْرِي أَىُّ آيَةٍ مِنْ كِتَابِ اللَّهِ مَعَكَ أَعْظَمُ ‏"‏ ‏.‏ قَالَ قُلْتُ اللَّهُ لاَ إِلَهَ إِلاَّ هُوَ الْحَىُّ الْقَيُّومُ ‏.‏ قَالَ فَضَرَبَ فِي صَدْرِي وَقَالَ ‏"‏ وَاللَّهِ لِيَهْنِكَ الْعِلْمُ أَبَا الْمُنْذِرِ ‏"‏ ‏.‏\hadithno{1885}\hadithtrans{Ubayy b. Ka'b said:Allah's Messenger (ﷺ) said: O Abu' al-Mundhir, do you know the verse from the Book of Allah which, according to you, is the greatest? I said: Allah and His Apostle (ﷺ) know best. He again said: Abu'l-Mundhir, do you know the verse from the Book of Allah which, according to you, is the greatest? I said: Allah, there is no god but He, the Living, the Eternal. Thereupon he struck me on my breast and said: May knowledge be pleasant for you, O Abu'l-Mundhir}}
\hadithdefcmd{muslim}{1886}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، وَمُحَمَّدُ بْنُ بَشَّارٍ، قَالَ زُهَيْرٌ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ، عَنْ أَبِي الدَّرْدَاءِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أَيَعْجِزُ أَحَدُكُمْ أَنْ يَقْرَأَ فِي لَيْلَةٍ ثُلُثَ الْقُرْآنِ ‏" قَالُوا : وَكَيْفَ يَقْرَأْ ثُلُثَ الْقُرْآنِ ؟ قَالَ : " قُلْ هُوَ اللَّهُ أَحَدٌ تَعْدِلُ ثُلُثَ الْقُرْآنِ " ‏.‏\hadithno{1886}\hadithtrans{Abu Darda' reported Allah's Apostle (ﷺ) as saying:Is any one of you incapable of reciting a third of the Qur'an in a night? They (the Companions) asked: How could one recite a third of the Qur'an (in a night)? Upon this he (the Holy Prophet) said: "'Say: He is Allah, One' (Qur'an. cxii) is equivalent to a third of the Qur'an}}
\hadithdefcmd{muslim}{1887}{وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ بَكْرٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا أَبَانٌ الْعَطَّارُ، جَمِيعًا عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ ‏.‏ وَفِي حَدِيثِهِمَا مِنْ قَوْلِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ اللَّهَ جَزَّأَ الْقُرْآنَ ثَلاَثَةَ أَجْزَاءٍ فَجَعَلَ قُلْ هُوَ اللَّهُ أَحَدٌ جُزْءًا مِنْ أَجْزَاءِ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{1887}\hadithtrans{This hadith has been narrated by Qatada with the same chain of transmitters in these words:He (the Messenger of Allah) said: Allah divided the Qur'an into three parts, and he made:" Say: He, Allah is One." one part out of the (three) parts of the Qur'an}}
\hadithdefcmd{muslim}{1888}{وَحَدَّثَنِي مُحَمَّدُ بْنُ حَاتِمٍ، وَيَعْقُوبُ بْنُ إِبْرَاهِيمَ، جَمِيعًا عَنْ يَحْيَى، - قَالَ ابْنُ حَاتِمٍ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، - حَدَّثَنَا يَزِيدُ بْنُ كَيْسَانَ، حَدَّثَنَا أَبُو حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ احْشِدُوا فَإِنِّي سَأَقْرَأُ عَلَيْكُمْ ثُلُثَ الْقُرْآنِ ‏"‏ ‏.‏ فَحَشَدَ مَنْ حَشَدَ ثُمَّ خَرَجَ نَبِيُّ اللَّهِ صلى الله عليه وسلم فَقَرَأَ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏ ثُمَّ دَخَلَ فَقَالَ بَعْضُنَا لِبَعْضٍ إِنِّي أُرَى هَذَا خَبَرٌ جَاءَهُ مِنَ السَّمَاءِ فَذَاكَ الَّذِي أَدْخَلَهُ ‏.‏ ثُمَّ خَرَجَ نَبِيُّ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ إِنِّي قُلْتُ لَكُمْ سَأَقْرَأُ عَلَيْكُمْ ثُلُثَ الْقُرْآنِ أَلاَ إِنَّهَا تَعْدِلُ ثُلُثَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{1888}\hadithtrans{It is reported on the authority of Abu Huraira that the Messenger of Allah (ﷺ) said:Get together. for I am going to recite one-third of the Qur'an before you. And those who could get together gathered there. Then the Messenger of Allah (ﷺ) came out and recited:" Say: He, Allah, is One." He then entered (his house). Some of us said to the others: Perhaps there has been some news from the heaven on account of which he has gone Inside (the house). The Apostle of Allah (ﷺ) again came out and said: I told you that I was going to recite one-third of the Qur'in; keep in mind, this (Surah Ikhlas) is equivalent to one-third of the Qur'an}}
\hadithdefcmd{muslim}{1889}{وَحَدَّثَنَا وَاصِلُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا ابْنُ فُضَيْلٍ، عَنْ بَشِيرٍ أَبِي إِسْمَاعِيلَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ خَرَجَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَقْرَأُ عَلَيْكُمْ ثُلُثَ الْقُرْآنِ ‏"‏ ‏.‏ فَقَرَأَ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ * اللَّهُ الصَّمَدُ‏\}‏ حَتَّى خَتَمَهَا ‏.‏\hadithno{1889}\hadithtrans{Abu Huraira reported:The Messenger of Allah (ﷺ) came out to us and said: I am going to recite before you one-third of the Qur'an. He (the Holy Prophet) then recited:" Say: He is Allah, One--Allah, the Eternal," to the end of the Surah}}
\hadithdefcmd{muslim}{1890}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ وَهْبٍ، حَدَّثَنَا عَمِّي عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنَا عَمْرُو بْنُ الْحَارِثِ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، أَنَّ أَبَا الرِّجَالِ، مُحَمَّدَ بْنَ عَبْدِ الرَّحْمَنِ حَدَّثَهُ عَنْ أُمِّهِ، عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ وَكَانَتْ فِي حَجْرِ عَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم عَنْ عَائِشَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ رَجُلاً عَلَى سَرِيَّةٍ وَكَانَ يَقْرَأُ لأَصْحَابِهِ فِي صَلاَتِهِمْ فَيَخْتِمُ بِـ ‏\{‏ قُلْ هُوَ اللَّهُ أَحَدٌ‏\}‏ فَلَمَّا رَجَعُوا ذُكِرَ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ سَلُوهُ لأَىِّ شَىْءٍ يَصْنَعُ ذَلِكَ ‏"‏ ‏.‏ فَسَأَلُوهُ فَقَالَ لأَنَّهَا صِفَةُ الرَّحْمَنِ فَأَنَا أُحِبُّ أَنْ أَقْرَأَ بِهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَخْبِرُوهُ أَنَّ اللَّهَ يُحِبُّهُ\hadithno{1890}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) sent a man in charge of an expedition and he would recite for his Companions during their prayer, ending (recitation) with:" Say, He is God, One." When they returned mention was made of it to the Messenger of Allah (ﷺ). He (the Holy Prophet) told them to ask him why he had done like that. So they asked him and he said: Verily, it is an attribute of the Compassionate One, and (for this reason) I love to recite it. The Messenger of Allah (ﷺ) thereupon said: Inform him that Allah loves him}}
\hadithdefcmd{muslim}{1891}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ بَيَانٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَلَمْ تَرَ آيَاتٍ أُنْزِلَتِ اللَّيْلَةَ لَمْ يُرَ مِثْلُهُنَّ قَطُّ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ الْفَلَقِ‏\}‏ وَ ‏\{‏ قُلْ أَعُوذُ بِرَبِّ النَّاسِ‏\}‏ ‏"‏ ‏.‏\hadithno{1891}\hadithtrans{Uqba b. 'Amir reported Allah's Messenger (ﷺ) as saying:What wonderful verses have been sent down today. the like of which has never been seen! They are:" Say: I seek refuge with the Lord of the dawn," and" Say: I seek refuge with the Lord of men}}
\hadithdefcmd{muslim}{1892}{وَحَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ قَيْسٍ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أُنْزِلَ - أَوْ أُنْزِلَتْ - عَلَىَّ آيَاتٌ لَمْ يُرَ مِثْلُهُنَّ قَطُّ الْمُعَوِّذَتَيْنِ ‏"‏ ‏.‏\hadithno{1892}\hadithtrans{Uqba b. 'Amir reported:The Messenger of Allah (ﷺ) said to me: There have been sent down to me verses the like of which had never been seen before. They are the Mu'awwadhatain}}
\hadithdefcmd{muslim}{1893}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا أَبُو أُسَامَةَ، كِلاَهُمَا عَنْ إِسْمَاعِيلَ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏ وَفِي رِوَايَةِ أَبِي أُسَامَةَ عَنْ عُقْبَةَ، بْنِ عَامِرٍ الْجُهَنِيِّ وَكَانَ مِنْ رُفَعَاءِ أَصْحَابِ مُحَمَّدٍ صلى الله عليه وسلم ‏.‏\hadithno{1893}\hadithtrans{This hadith has been narrated through another chain of transmitters directly from the Companions of Muhammad (ﷺ)}}
\hadithdefcmd{muslim}{1894}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَمْرٌو النَّاقِدُ، وَزُهَيْرُ بْنُ حَرْبٍ، كُلُّهُمْ عَنِ ابْنِ عُيَيْنَةَ، - قَالَ زُهَيْرٌ حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، - حَدَّثَنَا الزُّهْرِيُّ، عَنْ سَالِمٍ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ حَسَدَ إِلاَّ فِي اثْنَتَيْنِ رَجُلٌ آتَاهُ اللَّهُ الْقُرْآنَ فَهُوَ يَقُومُ بِهِ آنَاءَ اللَّيْلِ وَآنَاءَ النَّهَارِ وَرَجُلٌ آتَاهُ اللَّهُ مَالاً فَهُوَ يُنْفِقُهُ آنَاءَ اللَّيْلِ وَآنَاءَ النَّهَارِ ‏"‏ ‏.‏\hadithno{1894}\hadithtrans{Salim narrated on the authority of his father (Ibn 'Umar) that the Messenger of Allah (ﷺ) said:Envy is not justified but in case of two persons only: one who, having been given (knowledge of) the Qur'an by Allah, recites it during the night and day (and also acts upon it) and a man who, having been given wealth by God, spends it during the night and the day (for the welfare of others. seeking the pleasure of the Lord)}}
\hadithdefcmd{muslim}{1895}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ حَسَدَ إِلاَّ عَلَى اثْنَتَيْنِ رَجُلٌ آتَاهُ اللَّهُ هَذَا الْكِتَابَ فَقَامَ بِهِ آنَاءَ اللَّيْلِ وَآنَاءَ النَّهَارِ وَرَجُلٌ آتَاهُ اللَّهُ مَالاً فَتَصَدَّقَ بِهِ آنَاءَ اللَّيْلِ وَآنَاءَ النَّهَارِ ‏"‏ ‏.‏\hadithno{1895}\hadithtrans{Salim son of Abdullah b. 'Umar is reported to have said on the authority of his father that the Messenger of Allah (ﷺ) observed:Envy is not justified but in case of two persons only: one who, having been given (knowledge of) the Qur'an by Allah, recites it during the night and during the day (and acts upon it), and the person who, having been given wealth by God, gives it in charity during the night and the day}}
\hadithdefcmd{muslim}{1896}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ إِسْمَاعِيلَ، عَنْ قَيْسٍ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي وَمُحَمَّدُ بْنُ بِشْرٍ، قَالاَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ قَيْسٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ حَسَدَ إِلاَّ فِي اثْنَتَيْنِ رَجُلٌ آتَاهُ اللَّهُ مَالاً فَسَلَّطَهُ عَلَى هَلَكَتِهِ فِي الْحَقِّ وَرَجُلٌ آتَاهُ اللَّهُ حِكْمَةً فَهُوَ يَقْضِي بِهَا وَيُعَلِّمُهَا ‏"‏ ‏.‏\hadithno{1896}\hadithtrans{Abdullah b. Mas'ud reported Allah's Messenger (ﷺ) as saying:There should be no envy but only in case of two persons: one having been endowed with wealth and power to spend it in the cause of Truth, and (the other) who has been endowed with wisdom and he decides cases with the help of it and teaches it (to others)}}
\hadithdefcmd{muslim}{1897}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنِي أَبِي، عَنِ ابْنِ شِهَابٍ، عَنْ عَامِرِ بْنِ وَاثِلَةَ، أَنَّ نَافِعَ بْنَ عَبْدِ الْحَارِثِ، لَقِيَ عُمَرَ بِعُسْفَانَ وَكَانَ عُمَرُ يَسْتَعْمِلُهُ عَلَى مَكَّةَ فَقَالَ مَنِ اسْتَعْمَلْتَ عَلَى أَهْلِ الْوَادِي فَقَالَ ابْنَ أَبْزَى ‏.‏ قَالَ وَمَنِ ابْنُ أَبْزَى قَالَ مَوْلًى مِنْ مَوَالِينَا ‏.‏ قَالَ فَاسْتَخْلَفْتَ عَلَيْهِمْ مَوْلًى قَالَ إِنَّهُ قَارِئٌ لِكِتَابِ اللَّهِ عَزَّ وَجَلَّ وَإِنَّهُ عَالِمٌ بِالْفَرَائِضِ ‏.‏ قَالَ عُمَرُ أَمَا إِنَّ نَبِيَّكُمْ صلى الله عليه وسلم قَدْ قَالَ ‏ "‏ إِنَّ اللَّهَ يَرْفَعُ بِهَذَا الْكِتَابِ أَقْوَامًا وَيَضَعُ بِهِ آخَرِينَ ‏"‏ ‏.‏\hadithno{1897}\hadithtrans{Amir b. Wathila reported that Nafi' b. 'Abd al-Harith met 'Umar at 'Usfan and 'Umar had employed him as collector in Mecca. He (Hadrat 'Umar) said to him (Nafi'):Whom have you appointed as collector over the people of the valley? He said: Ibn Abza. He said: Who is Ibn Abza? He said: He is one of our freed slaves. He (Hadrat 'Umar) said: So you have appointed a freed slave over them. He said: He is well versed In the Book of Allah. the Exalted and Great, and he is well versed In the commandments and injunctions (of the Shari'ah). 'Umar said: So the Prophet (ﷺ) said: By this Book, Allah would exalt some peoples and degrade others}}
\hadithdefcmd{muslim}{1898}{وَحَدَّثَنِي عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، وَأَبُو بَكْرِ بْنُ إِسْحَاقَ قَالاَ أَخْبَرَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عَامِرُ بْنُ وَاثِلَةَ اللَّيْثِيُّ، أَنَّ نَافِعَ بْنَ، عَبْدِ الْحَارِثِ الْخُزَاعِيَّ لَقِيَ عُمَرَ بْنَ الْخَطَّابِ بِعُسْفَانَ ‏.‏ بِمِثْلِ حَدِيثِ إِبْرَاهِيمَ بْنِ سَعْدٍ عَنِ الزُّهْرِيِّ، ‏.‏\hadithno{1898}\hadithtrans{This hadith has been narrated by Zuhri through another chain of transmitters}}
\hadithdefcmd{muslim}{1899}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدٍ الْقَارِيِّ، قَالَ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ سَمِعْتُ هِشَامَ بْنَ، حَكِيمِ بْنِ حِزَامٍ يَقْرَأُ سُورَةَ الْفُرْقَانِ عَلَى غَيْرِ مَا أَقْرَؤُهَا وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَقْرَأَنِيهَا فَكِدْتُ أَنْ أَعْجَلَ عَلَيْهِ ثُمَّ أَمْهَلْتُهُ حَتَّى انْصَرَفَ ثُمَّ لَبَّبْتُهُ بِرِدَائِهِ فَجِئْتُ بِهِ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي سَمِعْتُ هَذَا يَقْرَأُ سُورَةَ الْفُرْقَانِ عَلَى غَيْرِ مَا أَقْرَأْتَنِيهَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرْسِلْهُ اقْرَأْ ‏"‏ ‏.‏ فَقَرَأَ الْقِرَاءَةَ الَّتِي سَمِعْتُهُ يَقْرَأُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَكَذَا أُنْزِلَتْ ‏"‏ ‏.‏ ثُمَّ قَالَ لِيَ ‏"‏ اقْرَأْ ‏"‏ ‏.‏ فَقَرَأْتُ فَقَالَ ‏"‏ هَكَذَا أُنْزِلَتْ إِنَّ هَذَا الْقُرْآنَ أُنْزِلَ عَلَى سَبْعَةِ أَحْرُفٍ فَاقْرَءُوا مَا تَيَسَّرَ مِنْهُ ‏"‏ ‏.‏\hadithno{1899}\hadithtrans{Umar b. Khattab said:I heard Hisham b. Hakim b. Hizam reciting Surah al-Furqan in a style different from that in which I used to recite it, and in which Allah's Messenger (ﷺ) had taught me to recite it. I was about to dispute with him (on this style) but I delayed till he had finished that (the recitation). Then I caught hold of his cloak and brought him to the Messenger of Allah (ﷺ) and said: Messenger of Allah, I heard this man reciting Surah al-Furqan in a style different from the one in which you taught me to recite. Upon this the Messenger of Allah (ﷺ) told (me) to leave him alone and asked him to recite. He then recited in the style in which I beard him recite it. The Messenger of Allah (ﷺ) then said: Thus was it sent down. He then told me to recite and I recited it, and he said: Thus was it sent down. The Qur'an was sent down in seven dialects. So recite what seems easy therefrom}}
\hadithdefcmd{muslim}{1900}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ، وَعَبْدَ الرَّحْمَنِ بْنَ عَبْدٍ الْقَارِيَّ، أَخْبَرَاهُ أَنَّهُمَا، سَمِعَا عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ سَمِعْتُ هِشَامَ بْنَ حَكِيمٍ، يَقْرَأُ سُورَةَ الْفُرْقَانِ فِي حَيَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ وَسَاقَ الْحَدِيثَ بِمِثْلِهِ وَزَادَ فَكِدْتُ أُسَاوِرُهُ فِي الصَّلاَةِ فَتَصَبَّرْتُ حَتَّى سَلَّمَ ‏.‏\hadithno{1900}\hadithtrans{This hadith has been transmitted thus by 'Umar b. Khattab (with a slight change of words):" I heard Hisham b. Hakim reciting Surah al-Furqan during the lifetime of Allah's Messenger (ﷺ)." The rest is the same but with this addition:" I was about to catch hold of him in prayer, but I exercised patience till he pronounced salutation}}
\hadithdefcmd{muslim}{1901}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالاَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، كَرِوَايَةِ يُونُسَ بِإِسْنَادِهِ ‏.‏\hadithno{1901}\hadithtrans{This hadith has been transmitted by Zuhri}}
\hadithdefcmd{muslim}{1902}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، أَنَّ ابْنَ عَبَّاسٍ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ أَقْرَأَنِي جِبْرِيلُ - عَلَيْهِ السَّلاَمُ - عَلَى حَرْفٍ فَرَاجَعْتُهُ فَلَمْ أَزَلْ أَسْتَزِيدُهُ فَيَزِيدُنِي حَتَّى انْتَهَى إِلَى سَبْعَةِ أَحْرُفٍ ‏"‏ ‏.‏ قَالَ ابْنُ شِهَابٍ بَلَغَنِي أَنَّ تِلْكَ السَّبْعَةَ الأَحْرُفَ إِنَّمَا هِيَ فِي الأَمْرِ الَّذِي يَكُونُ وَاحِدًا لاَ يَخْتَلِفُ فِي حَلاَلٍ وَلاَ حَرَامٍ ‏.‏\hadithno{1902}\hadithtrans{Ibn 'Abbas reported Allah's Messenger (ﷺ) as saying:Gabriel taught me to recite in one style. I replied to him and kept asking him to give more (styles), till he reached seven modes (of recitation). Ibn Shibab said: It has reached me that these seven styles are essentially one, not differing about what is permitted and what is forbidden}}
\hadithdefcmd{muslim}{1903}{وَحَدَّثَنَاهُ عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الإِسْنَادِ\hadithno{1903}\hadithtrans{This hadith has been narrated by Zuhri with the same chain of trans- mitters}}
\hadithdefcmd{muslim}{1904}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، عَنْ عَبْدِ اللَّهِ بْنِ عِيسَى بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، عَنْ جَدِّهِ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ كُنْتُ فِي الْمَسْجِدِ فَدَخَلَ رَجُلٌ يُصَلِّي فَقَرَأَ قِرَاءَةً أَنْكَرْتُهَا عَلَيْهِ ثُمَّ دَخَلَ آخَرُ فَقَرَأَ قِرَاءَةً سِوَى قِرَاءَةِ صَاحِبِهِ فَلَمَّا قَضَيْنَا الصَّلاَةَ دَخَلْنَا جَمِيعًا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ إِنَّ هَذَا قَرَأَ قِرَاءَةً أَنْكَرْتُهَا عَلَيْهِ وَدَخَلَ آخَرُ فَقَرَأَ سِوَى قِرَاءَةِ صَاحِبِهِ فَأَمَرَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَرَءَا فَحَسَّنَ النَّبِيُّ صلى الله عليه وسلم شَأْنَهُمَا فَسُقِطَ فِي نَفْسِي مِنَ التَّكْذِيبِ وَلاَ إِذْ كُنْتُ فِي الْجَاهِلِيَّةِ فَلَمَّا رَأَى رَسُولُ اللَّهِ صلى الله عليه وسلم مَا قَدْ غَشِيَنِي ضَرَبَ فِي صَدْرِي فَفِضْتُ عَرَقًا وَكَأَنَّمَا أَنْظُرُ إِلَى اللَّهِ عَزَّ وَجَلَّ فَرَقًا فَقَالَ لِي ‏"‏ يَا أُبَىُّ أُرْسِلَ إِلَىَّ أَنِ اقْرَإِ الْقُرْآنَ عَلَى حَرْفٍ فَرَدَدْتُ إِلَيْهِ أَنْ هَوِّنْ عَلَى أُمَّتِي ‏.‏\hadithno{1904}\hadithtrans{Ubayy b. Ka'b reported:I was in the mosque when a man entered and prayed and recited (the Qur'in) in a style to which I objected. Then another man entered (the mosque) and recited in a style different from that of his companion. When we had finished the prayer, we all went to Allah's Messenger (ﷺ) and said to him: This man recited in a style to which I objected, and the other entered and recited in a style different from that of his companion. The Messenger of Allah (ﷺ) asked them to recite and so they recited, and the Messenger of Allah (ﷺ) expressed approval of their affairs (their modes of recitation). and there occurred In my mind a sort of denial which did not occur even during the Days of Ignorance. When the Messenger of Allah (ﷺ) saw how I was affected (by a wrong idea), he struck my chest, whereupon I broke into sweating and felt as though I were looking at Allah with fear. He (the Holy Prophet) said to me: Ubayy. a message was sent to me to recite the Qur'an in one dialect, and I replied: Make (things) easy for my people. It was conveyed to me for the second time that it should be recited in two dialects. I again replied to him: Make affairs easy for my people. It was again conveyed to me for the third time to recite in seven dialects And (I was further told): You have got a seeking for every reply that I sent you, which you should seek from Me. I said: O Allah! forgive my people, forgive my people, and I have deferred the third one for the day on which the entire creation will turn to me, including even Ibrahim (peace be upon him) (for intercession)}}
\hadithdefcmd{muslim}{1905}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ بِشْرٍ، حَدَّثَنِي إِسْمَاعِيلُ بْنُ أَبِي، خَالِدٍ حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عِيسَى، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، أَخْبَرَنِي أُبَىُّ بْنُ كَعْبٍ، أَنَّهُ كَانَ جَالِسًا فِي الْمَسْجِدِ إِذْ دَخَلَ رَجُلٌ فَصَلَّى فَقَرَأَ قِرَاءَةً وَاقْتَصَّ الْحَدِيثَ بِمِثْلِ حَدِيثِ ابْنِ نُمَيْرٍ ‏.‏\hadithno{1905}\hadithtrans{Ubayy b. Ka'b reported that he was sitting in a mosque that a person entered it and he observed prayer, and made recitation, the rest of the hadith is the same}}
\hadithdefcmd{muslim}{1906}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا غُنْدَرٌ، عَنْ شُعْبَةَ، ح وَحَدَّثَنَاهُ ابْنُ الْمُثَنَّى، وَابْنُ بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْحَكَمِ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ أُبَىِّ بْنِ كَعْبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ عِنْدَ أَضَاةِ بَنِي غِفَارٍ - قَالَ - فَأَتَاهُ جِبْرِيلُ عَلَيْهِ السَّلاَمُ فَقَالَ إِنَّ اللَّهَ يَأْمُرُكَ أَنْ تَقْرَأَ أُمَّتُكَ الْقُرْآنَ عَلَى حَرْفٍ ‏.‏ فَقَالَ ‏"‏ أَسْأَلُ اللَّهَ مُعَافَاتَهُ وَمَغْفِرَتَهُ وَإِنَّ أُمَّتِي لاَ تُطِيقُ ذَلِكَ ‏"‏ ‏.‏ ثُمَّ أَتَاهُ الثَّانِيَةَ فَقَالَ إِنَّ اللَّهَ يَأْمُرُكَ أَنْ تَقْرَأَ أُمَّتُكَ الْقُرْآنَ عَلَى حَرْفَيْنِ فَقَالَ ‏"‏ أَسْأَلُ اللَّهَ مُعَافَاتَهُ وَمَغْفِرَتَهُ وَإِنَّ أُمَّتِي لاَ تُطِيقُ ذَلِكَ ‏"‏ ‏.‏ ثُمَّ جَاءَهُ الثَّالِثَةَ فَقَالَ إِنَّ اللَّهَ يَأْمُرُكَ أَنْ تَقْرَأَ أُمَّتُكَ الْقُرْآنَ عَلَى ثَلاَثَةِ أَحْرُفٍ ‏.‏ فَقَالَ ‏"‏ أَسْأَلُ اللَّهَ مُعَافَاتَهُ وَمَغْفِرَتَهُ وَإِنَّ أُمَّتِي لاَ تُطِيقُ ذَلِكَ ‏"‏ ‏.‏ ثُمَّ جَاءَهُ الرَّابِعَةَ فَقَالَ إِنَّ اللَّهَ يَأْمُرُكَ أَنْ تَقْرَأَ أُمَّتُكَ الْقُرْآنَ عَلَى سَبْعَةِ أَحْرُفٍ فَأَيُّمَا حَرْفٍ قَرَءُوا عَلَيْهِ فَقَدْ أَصَابُوا ‏.‏\hadithno{1906}\hadithtrans{Ubayy b. Ka'b reported that the Messenger of Allah (ﷺ) was near the tank of Banu Ghifar that Gabriel came to him and said:Allah has commanded you to recite to your people the Qur'an in one dialect. Upon this he said: I ask from Allah pardon and forgiveness. My people are not capable of doing it. He then came for the second time and said: Allah has commanded you that you should recite the Qur'an to your people in two dialects. Upon this he (the Holy prophet) again said: I seek pardon and forgiveness from Allah, my people would not be able to do so. He (Gabriel) came for the third time and said: Allah has commanded you to recite the Qur'an to your people in three dialects. Upon this he said: I ask pardon and forgiveness from Allah. My people would not be able to do it. He then came to him for the fourth time and said: Allah has commanded you to recite the Qur'an to your people in seven dialects, and in whichever dialect they would recite, they would be right}}
\hadithdefcmd{muslim}{1907}{وَحَدَّثَنَاهُ عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، بِهَذَا الإِسْنَادِ مِثْلَهُ ‏.‏\hadithno{1907}\hadithtrans{This hadith has been narrated by Shu'ba with the same chain of transmitters}}
\hadithdefcmd{muslim}{1908}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَابْنُ، نُمَيْرٍ جَمِيعًا عَنْ وَكِيعٍ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا وَكِيعٌ، - عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، قَالَ جَاءَ رَجُلٌ يُقَالُ لَهُ نَهِيكُ بْنُ سِنَانٍ إِلَى عَبْدِ اللَّهِ فَقَالَ يَا أَبَا عَبْدِ الرَّحْمَنِ كَيْفَ تَقْرَأُ هَذَا الْحَرْفَ أَلِفًا تَجِدُهُ أَمْ يَاءً مِنْ مَاءٍ غَيْرِ آسِنٍ أَوْ مِنْ مَاءٍ غَيْرِ يَاسِنٍ قَالَ فَقَالَ عَبْدُ اللَّهِ وَكُلَّ الْقُرْآنِ قَدْ أَحْصَيْتَ غَيْرَ هَذَا قَالَ إِنِّي لأَقْرَأُ الْمُفَصَّلَ فِي رَكْعَةٍ ‏.‏ فَقَالَ عَبْدُ اللَّهِ هَذًّا كَهَذِّ الشِّعْرِ إِنَّ أَقْوَامًا يَقْرَءُونَ الْقُرْآنَ لاَ يُجَاوِزُ تَرَاقِيَهُمْ وَلَكِنْ إِذَا وَقَعَ فِي الْقَلْبِ فَرَسَخَ فِيهِ نَفَعَ إِنَّ أَفْضَلَ الصَّلاَةِ الرُّكُوعُ وَالسُّجُودُ إِنِّي لأَعْلَمُ النَّظَائِرَ الَّتِي كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرُنُ بَيْنَهُنَّ سُورَتَيْنِ فِي كُلِّ رَكْعَةٍ ‏.‏ ثُمَّ قَامَ عَبْدُ اللَّهِ فَدَخَلَ عَلْقَمَةُ فِي إِثْرِهِ ثُمَّ خَرَجَ فَقَالَ قَدْ أَخْبَرَنِي بِهَا ‏.‏ قَالَ ابْنُ نُمَيْرٍ فِي رِوَايَتِهِ جَاءَ رَجُلٌ مِنْ بَنِي بَجِيلَةَ إِلَى عَبْدِ اللَّهِ وَلَمْ يَقُلْ نَهِيكُ بْنُ سِنَانٍ ‏.‏\hadithno{1908}\hadithtrans{Abu Wa'il reported that a person named Nabik b. Sinan came to Abdullah (b. Mas'ud) and said:Abu 'Abd al-Rahman, how do you recite this word (alif) or (ya)? Would you read It as: min ma'in ghaira asin or au min ma'in ghaira ghaira yasin. (al-Qur'an, xlvii. 15)? 'Abdullah said: You (seem to) have memorised the whole of the Qur'an except this. He (again) said: I recite all the mufassal surahs in one rak'ah. Upon this 'Abdullah said: (You must have been reciting It) hastily like the recitation of poetry. Verily. there are people who recite the Qur'an, but it does not go down beyond their collar bones. It is (a fact with the Qur'an) that it is beneficial only when it settles in the heart and is rooted deeply in it. The best of (the acts) in prayer are bowing and prostration. I am quite aware of the occasions when the Messenger of Allah (ﷺ) combined together two surahs in every rak'ah. 'Abdullah then stood up and went out with 'Alqama following in his footstep. He said Ibn Numair had told him that the narration was like that:" A person belonging to Banu Bajila came to 'Abdullah," and he did not mention (the name of) Nahik b. Sinan}}
\hadithdefcmd{muslim}{1909}{وَحَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، قَالَ جَاءَ رَجُلٌ إِلَى عَبْدِ اللَّهِ يُقَالُ لَهُ نَهِيكُ بْنُ سِنَانٍ ‏.‏ بِمِثْلِ حَدِيثِ وَكِيعٍ غَيْرَ أَنَّهُ قَالَ فَجَاءَ عَلْقَمَةُ لِيَدْخُلَ عَلَيْهِ فَقُلْنَا لَهُ سَلْهُ عَنِ النَّظَائِرِ الَّتِي كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ بِهَا فِي رَكْعَةٍ فَدَخَلَ عَلَيْهِ فَسَأَلَهُ ثُمَّ خَرَجَ عَلَيْنَا فَقَالَ عِشْرُونَ سُورَةً مِنَ الْمُفَصَّلِ فِي تَأْلِيفِ عَبْدِ اللَّهِ ‏.‏\hadithno{1909}\hadithtrans{Abu Wa'il reported:A person came to 'Abdullah, who was called Nahik b. Sinan, and the rest of the hadith is the same but for this:" Alqama came to him ('Abdullah b. Mas'ud) and we said to him: Ask him about the manners in which he combined (two surahs) in one rak'ah. So he went to him and asked him and then came to us and said: Twenty are the mufassal surahs in the compilation (of the Qur'an) made by 'Abdullah}}
\hadithdefcmd{muslim}{1910}{وَحَدَّثَنَاهُ إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا الأَعْمَشُ، فِي هَذَا الإِسْنَادِ ‏.‏ بِنَحْوِ حَدِيثِهِمَا وَقَالَ إِنِّي لأَعْرِفُ النَّظَائِرَ الَّتِي كَانَ يَقْرَأُ بِهِنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم اثْنَتَيْنِ فِي رَكْعَةٍ ‏.‏ عِشْرِينَ سُورَةً فِي عَشْرِ رَكَعَاتٍ ‏.‏\hadithno{1910}\hadithtrans{This hadith has been narrated by A'mash with the same chain of transmitters in which ('Abdullah b. Mas'ud) said:" I know the manners in which the Messenger of Allah (ﷺ) recited the two surahs in one rak'ah and then twenty surahs in ten rak'ahs}}
\hadithdefcmd{muslim}{1911}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا مَهْدِيُّ بْنُ مَيْمُونٍ، حَدَّثَنَا وَاصِلٌ الأَحْدَبُ، عَنْ أَبِي، وَائِلٍ قَالَ غَدَوْنَا عَلَى عَبْدِ اللَّهِ بْنِ مَسْعُودٍ يَوْمًا بَعْدَ مَا صَلَّيْنَا الْغَدَاةَ فَسَلَّمْنَا بِالْبَابِ فَأَذِنَ لَنَا - قَالَ - فَمَكَثْنَا بِالْبَابِ هُنَيَّةً - قَالَ - فَخَرَجَتِ الْجَارِيَةُ فَقَالَتْ أَلاَ تَدْخُلُونَ فَدَخَلْنَا فَإِذَا هُوَ جَالِسٌ يُسَبِّحُ فَقَالَ مَا مَنَعَكُمْ أَنْ تَدْخُلُوا وَقَدْ أُذِنَ لَكُمْ فَقُلْنَا لاَ إِلاَّ أَنَّا ظَنَنَّا أَنَّ بَعْضَ أَهْلِ الْبَيْتِ نَائِمٌ ‏.‏ قَالَ ظَنَنْتُمْ بِآلِ ابْنِ أُمِّ عَبْدٍ غَفْلَةً قَالَ ثُمَّ أَقْبَلَ يُسَبِّحُ حَتَّى ظَنَّ أَنَّ الشَّمْسَ قَدْ طَلَعَتْ فَقَالَ يَا جَارِيَةُ انْظُرِي هَلْ طَلَعَتْ قَالَ فَنَظَرَتْ فَإِذَا هِيَ لَمْ تَطْلُعْ فَأَقْبَلَ يُسَبِّحُ حَتَّى إِذَا ظَنَّ أَنَّ الشَّمْسَ قَدْ طَلَعَتْ قَالَ يَا جَارِيَةُ انْظُرِي هَلْ طَلَعَتْ فَنَظَرَتْ فَإِذَا هِيَ قَدْ طَلَعَتْ ‏.‏ فَقَالَ الْحَمْدُ لِلَّهِ الَّذِي أَقَالَنَا يَوْمَنَا هَذَا - فَقَالَ مَهْدِيٌّ وَأَحْسِبُهُ قَالَ - وَلَمْ يُهْلِكْنَا بِذُنُوبِنَا - قَالَ - فَقَالَ رَجُلٌ مِنَ الْقَوْمِ قَرَأْتُ الْمُفَصَّلَ الْبَارِحَةَ كُلَّهُ - قَالَ - فَقَالَ عَبْدُ اللَّهِ هَذًّا كَهَذِّ الشِّعْرِ إِنَّا لَقَدْ سَمِعْنَا الْقَرَائِنَ وَإِنِّي لأَحْفَظُ الْقَرَائِنَ الَّتِي كَانَ يَقْرَؤُهُنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم ثَمَانِيَةَ عَشَرَ مِنَ الْمُفَصَّلِ وَسُورَتَيْنِ مِنْ آلِ حم\hadithno{1911}\hadithtrans{Abu Wa'il reported:One day we went to 'Abdullah b. Mas'ud after we had observed the dawn prayer and we paid salutation at the door. He permitted us to enter, but we stayed for a while at the door, when the slave-girl came out and said: Why don't you come in? So we went in and (we found 'Abdullah b. Mas'ud) sitting and glorifying Allah (i. e. he was busy in dhikr) and he said: What obstructed you from coming in though you had been granted permission for it? We said: There was nothing (behind it) but we entertained the idea that some inmate of the house might be sleeping. He said: Do you presume any idleness on the part of the family of Ibn Umm 'Abd (the mother of Abdullah b. Mas'ud)? He was again busy with the glorification of Allah till he thought that the sun had risen. He said: Girl, see whether (the sun) has arisen. She glanced but it had not risen (by that time). He was again busy with the glorification (of Allah) and he (again) thought that the sun had arisen. She glanced (and confirmed) that, it had risen. Upon this he ('Abdullah b. Mas'ud) said: Praise be to Allah Who did not call us to account for our sins today. Mahdi said: I think that he said, He did not destroy us for our sins. One among the people said: I recited all the mufassal surahs during the night. 'Abdullah said: (You must have recited them) like the (recitation) of poetry. I heard (the Holy Prophet) combining (the sarahs) and I remember the combinations which the Messenger of Allah (ﷺ) made In the recitation (of surahs). These were constituted of eighteen mufassal surahs and two surahs (commencing with) Ha-Mim}}
\hadithdefcmd{muslim}{1912}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنَا حُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنْ مَنْصُورٍ، عَنْ شَقِيقٍ، قَالَ جَاءَ رَجُلٌ مِنْ بَنِي بَجِيلَةَ يُقَالُ لَهُ نَهِيكُ بْنُ سِنَانٍ إِلَى عَبْدِ اللَّهِ فَقَالَ إِنِّي أَقْرَأُ الْمُفَصَّلَ فِي رَكْعَةٍ ‏.‏ فَقَالَ عَبْدُ اللَّهِ هَذًّا كَهَذِّ الشِّعْرِ لَقَدْ عَلِمْتُ النَّظَائِرَ الَّتِي كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرَأُ بِهِنَّ سُورَتَيْنِ فِي رَكْعَةٍ ‏.‏\hadithno{1912}\hadithtrans{Shaqiq reported:A person from Banu Bajila who was called Nabik b. Sinan came to Abdullah and said: I recite mufassal surahs in one rak'ah. Upon this 'Abdullah said: (You recite) like the recitation of poetry. I know the manner in which the Messenger of Allah (ﷺ) recited two surahs in one rak'ah}}
\hadithdefcmd{muslim}{1913}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، أَنَّهُ سَمِعَ أَبَا وَائِلٍ، يُحَدِّثُ أَنَّ رَجُلاً، جَاءَ إِلَى ابْنِ مَسْعُودٍ فَقَالَ إِنِّي قَرَأْتُ الْمُفَصَّلَ اللَّيْلَةَ كُلَّهُ فِي رَكْعَةٍ ‏.‏ فَقَالَ عَبْدُ اللَّهِ هَذًّا كَهَذِّ الشِّعْرِ فَقَالَ عَبْدُ اللَّهِ لَقَدْ عَرَفْتُ النَّظَائِرَ الَّتِي كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْرُنُ بَيْنَهُنَّ - قَالَ - فَذَكَرَ عِشْرِينَ سُورَةً مِنَ الْمُفَصَّلِ سُورَتَيْنِ سُورَتَيْنِ فِي كُلِّ رَكْعَةٍ ‏.‏\hadithno{1913}\hadithtrans{Abu Wa'il reported:A person came to 'Abdullah b. Mas'ud and said: I recited all the mufassal surahs in one rak'ah during the night. 'Abdullah said: You must have recited hastily like the recitation of poetry. 'Abdullah said: I remember well the manner in which the Messenger of Allah (ﷺ) used to combine them, and he then mentioned twenty of the mufassal surahs, and (their combinations in) two in every rak'ah}}
\hadithdefcmd{muslim}{1914}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو إِسْحَاقَ، قَالَ رَأَيْتُ رَجُلاً سَأَلَ الأَسْوَدَ بْنَ يَزِيدَ وَهُوَ يُعَلِّمُ الْقُرْآنَ فِي الْمَسْجِدِ فَقَالَ كَيْفَ تَقْرَأُ هَذِهِ الآيَةَ فَهَلْ مِنْ مُدَّكِرٍ أَدَالاً أَمْ ذَالاً قَالَ بَلْ دَالاً سَمِعْتُ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مُدَّكِرٍ ‏"‏ ‏.‏ دَالاً ‏.‏\hadithno{1914}\hadithtrans{Abu Ishaq reported:I saw a man asking Aswad b. Yazid who taught the Qur'an in the mosque: How do you recite the verse (fahal min muddakir) whether (the word muddakir) Is with (d) or (dh)? He (Aswad) said: It was with (d). I heard Abdullah b. Mas'ud saying that he had heard the Messenger of Allah (ﷺ) reciting (muddakir) with (d)}}
\hadithdefcmd{muslim}{1915}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَانَ يَقْرَأُ هَذَا الْحَرْفَ ‏ "‏ فَهَلْ مِنْ مُدَّكِرٍ ‏"‏ ‏.‏\hadithno{1915}\hadithtrans{Ishaq is reported to have said on the authority of Aswad who quoted on the authority of 'Abdullah b. Mas'ud that the Messenger of Allah (ﷺ) used to recite these words as (fahal min muddakir)}}
\hadithdefcmd{muslim}{1916}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ - وَاللَّفْظُ لأَبِي بَكْرٍ - قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ قَدِمْنَا الشَّامَ فَأَتَانَا أَبُو الدَّرْدَاءِ فَقَالَ أَفِيكُمْ أَحَدٌ يَقْرَأُ عَلَى قِرَاءَةِ عَبْدِ اللَّهِ فَقُلْتُ نَعَمْ أَنَا ‏.‏ قَالَ فَكَيْفَ سَمِعْتَ عَبْدَ اللَّهِ يَقْرَأُ هَذِهِ الآيَةَ ‏\{‏ وَاللَّيْلِ إِذَا يَغْشَى‏\}‏ قَالَ سَمِعْتُهُ يَقْرَأُ ‏\{‏ وَاللَّيْلِ إِذَا يَغْشَى * وَالذَّكَرِ وَالأُنْثَى‏\}‏ ‏.‏ قَالَ وَأَنَا وَاللَّهِ هَكَذَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَؤُهَا وَلَكِنْ هَؤُلاَءِ يُرِيدُونَ أَنْ أَقْرَأَ وَمَا خَلَقَ ‏.‏ فَلاَ أُتَابِعُهُمْ ‏.‏\hadithno{1916}\hadithtrans{Alqama reported. We went to Syria and Abu Darda' came to us and said:Is there anyone among you who recites according to the recitation of Abdullah? I said: Yes, it is I. He again said: How did you hear 'Abdullah reciting this verse: (wa'l-lail-i-idha yaghsha = when the night covers)? He ('Alqama) said: I heard him reciting it (like this) (wa'l-lail-i-idha yaghsha) wa-dhakar wal untha = when the night covers and the males and the females). Upon this he said: By Allah, I heard the Messenger of Allah (ﷺ) reciting in this way, but they (the Muslims of Syria) desire us to recite: (wa ma khalaqa), but I do not yield to their desire}}
\hadithdefcmd{muslim}{1917}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ مُغِيرَةَ، عَنْ إِبْرَاهِيمَ، قَالَ أَتَى عَلْقَمَةُ الشَّامَ فَدَخَلَ مَسْجِدًا فَصَلَّى فِيهِ ثُمَّ قَامَ إِلَى حَلْقَةٍ فَجَلَسَ فِيهَا - قَالَ - فَجَاءَ رَجُلٌ فَعَرَفْتُ فِيهِ تَحَوُّشَ الْقَوْمِ وَهَيْئَتَهُمْ ‏.‏ قَالَ فَجَلَسَ إِلَى جَنْبِي ثُمَّ قَالَ أَتَحْفَظُ كَمَا كَانَ عَبْدُ اللَّهِ يَقْرَأُ فَذَكَرَ بِمِثْلِهِ ‏.‏\hadithno{1917}\hadithtrans{Ibrahim reported:'Alqama came to Syria and entered the mosque and prayed there and then went to a (place where people were sitting in a) circle and he sat therein. Then a person came there and I perceived that the people were annoyed and perturbed (on this arrival). and he sat on my side and then said: Do you remember how 'Abdullah used to recite (the Qur'an)? And then the rest of the hadith was narrated}}
\hadithdefcmd{muslim}{1918}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ السَّعْدِيُّ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ دَاوُدَ بْنِ أَبِي، هِنْدٍ عَنِ الشَّعْبِيِّ، عَنْ عَلْقَمَةَ، قَالَ لَقِيتُ أَبَا الدَّرْدَاءِ فَقَالَ لِي مِمَّنْ أَنْتَ قُلْتُ مِنْ أَهْلِ الْعِرَاقِ ‏.‏ قَالَ مِنْ أَيِّهِمْ قُلْتُ مِنْ أَهْلِ الْكُوفَةِ ‏.‏ قَالَ هَلْ تَقْرَأُ عَلَى قِرَاءَةِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ قَالَ قُلْتُ نَعَمْ ‏.‏ قَالَ فَاقْرَأْ ‏\{‏ وَاللَّيْلِ إِذَا يَغْشَى‏\}‏ قَالَ فَقَرَأْتُ ‏\{‏ وَاللَّيْلِ إِذَا يَغْشَى * وَالنَّهَارِ إِذَا تَجَلَّى * وَالذَّكَرِ وَالأُنْثَى‏\}‏ ‏.‏ قَالَ فَضَحِكَ ثُمَّ قَالَ هَكَذَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَؤُهَا ‏.‏\hadithno{1918}\hadithtrans{Alqama reported:I met Abu Darda', and he said to me: To which country do you belong? I said: I am one of the people of Iraq. He again said: To which city? I replied: City of Kufa. He again said: Do you recite according to the recitation of 'Abdullah b. Mas'ud? I said: Yes. He said: Recite this verse (By the night when it covers) So I recited it: (By the night when it covers, and the day when it shines, and the creating of the male and the female). He laughed and said: I have heard the Messenger of Allah (ﷺ) reciting like this}}
\hadithdefcmd{muslim}{1919}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي عَبْدُ الأَعْلَى، حَدَّثَنَا دَاوُدُ، عَنْ عَامِرٍ، عَنْ عَلْقَمَةَ، قَالَ أَتَيْتُ الشَّامَ فَلَقِيتُ أَبَا الدَّرْدَاءِ فَذَكَرَ بِمِثْلِ حَدِيثِ ابْنِ عُلَيَّةَ ‏.‏\hadithno{1919}\hadithtrans{This hadith has been narrated by another chain of transmitters}}
\hadithdefcmd{muslim}{1920}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الصَّلاَةِ بَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ وَعَنِ الصَّلاَةِ بَعْدَ الصُّبْحِ حَتَّى تَطْلُعَ الشَّمْسُ ‏.‏\hadithno{1920}\hadithtrans{Abu Huraira is reported to have said that the Messenger of Allah (ﷺ) prohibited to observe prayer after the 'Asr prayer till the sun is set, and after the dawn till the sun rises}}
\hadithdefcmd{muslim}{1921}{وَحَدَّثَنَا دَاوُدُ بْنُ رُشَيْدٍ، وَإِسْمَاعِيلُ بْنُ سَالِمٍ، جَمِيعًا عَنْ هُشَيْمٍ، - قَالَ دَاوُدُ حَدَّثَنَا هُشَيْمٌ، - أَخْبَرَنَا مَنْصُورٌ، عَنْ قَتَادَةَ، قَالَ أَخْبَرَنَا أَبُو الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ غَيْرَ، وَاحِدٍ، مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْهُمْ عُمَرُ بْنُ الْخَطَّابِ وَكَانَ أَحَبَّهُمْ إِلَىَّ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الصَّلاَةِ بَعْدَ الْفَجْرِ حَتَّى تَطْلُعَ الشَّمْسُ وَبَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ ‏.‏\hadithno{1921}\hadithtrans{Ibn 'Abbas reported:I heard it from so many Companions of the Messenger of Allah (ﷺ) and one among them is 'Umar b. Khattab, and he is most dear to me among them that the Messenger of Allah (ﷺ) prohibited observing of prayer after the dawn prayer till the sun rose and after the 'Asr till the sun set}}
\hadithdefcmd{muslim}{1922}{وَحَدَّثَنِيهِ زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ شُعْبَةَ، ح وَحَدَّثَنِي أَبُو غَسَّانَ، الْمِسْمَعِيُّ حَدَّثَنَا عَبْدُ الأَعْلَى، حَدَّثَنَا سَعِيدٌ، ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا مُعَاذُ، بْنُ هِشَامٍ حَدَّثَنِي أَبِي كُلُّهُمْ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ غَيْرَ أَنَّ فِي، حَدِيثِ سَعِيدٍ وَهِشَامٍ بَعْدَ الصُّبْحِ حَتَّى تَشْرُقَ الشَّمْسُ ‏.‏\hadithno{1922}\hadithtrans{This hadith has been narrated by Qatada with the same chain of transmitters with a minor alteration of words}}
\hadithdefcmd{muslim}{1923}{وَحَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، أَنَّ ابْنَ شِهَابٍ، أَخْبَرَهُ قَالَ أَخْبَرَنِي عَطَاءُ بْنُ يَزِيدَ اللَّيْثِيُّ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ صَلاَةَ بَعْدَ صَلاَةِ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ وَلاَ صَلاَةَ بَعْدَ صَلاَةِ الْفَجْرِ حَتَّى تَطْلُعَ الشَّمْسُ ‏"‏ ‏.‏\hadithno{1923}\hadithtrans{Abu Sa'id al-Khudri reported Allah's Messenger (ﷺ) as saying:No prayer is valid after the 'Asr prayer till the sun sets and no prayer is valid after the dawn prayer till the sun rises}}
\hadithdefcmd{muslim}{1924}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَتَحَرَّى أَحَدُكُمْ فَيُصَلِّي عِنْدَ طُلُوعِ الشَّمْسِ وَلاَ عِنْدَ غُرُوبِهَا ‏"‏ ‏.‏\hadithno{1924}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:Let not any one of you intend to observe prayer at the time of the rising of the sun or of the setting sun}}
\hadithdefcmd{muslim}{1925}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ، نُمَيْرٍ حَدَّثَنَا أَبِي وَمُحَمَّدُ بْنُ بِشْرٍ، قَالاَ جَمِيعًا حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَحَرَّوْا بِصَلاَتِكُمْ طُلُوعَ الشَّمْسِ وَلاَ غُرُوبَهَا فَإِنَّهَا تَطْلُعُ بِقَرْنَىْ شَيْطَانٍ ‏"‏ ‏.‏\hadithno{1925}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:Do not intend to observe prayer at the time of the rising of the sun nor at its setting, for it rises between the horns of Satan}}
\hadithdefcmd{muslim}{1926}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ، نُمَيْرٍ حَدَّثَنَا أَبِي وَابْنُ، بِشْرٍ قَالُوا جَمِيعًا حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا بَدَا حَاجِبُ الشَّمْسِ فَأَخِّرُوا الصَّلاَةَ حَتَّى تَبْرُزَ وَإِذَا غَابَ حَاجِبُ الشَّمْسِ فَأَخِّرُوا الصَّلاَةَ حَتَّى تَغِيبَ ‏"‏ ‏.‏\hadithno{1926}\hadithtrans{Ibn 'Umar reported Allah's Messenger (ﷺ) as saying:When the rim of the sun starts appearing defer prayer till it completely appears, and when the rim of the sun disappears defer prayer till it completely disappears}}
\hadithdefcmd{muslim}{1927}{وَحَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ خَيْرِ بْنِ نُعَيْمٍ الْحَضْرَمِيِّ، عَنِ ابْنِ هُبَيْرَةَ، عَنْ أَبِي تَمِيمٍ الْجَيْشَانِيِّ، عَنْ أَبِي بَصْرَةَ الْغِفَارِيِّ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم الْعَصْرَ بِالْمُخَمَّصِ فَقَالَ ‏ "‏ إِنَّ هَذِهِ الصَّلاَةَ عُرِضَتْ عَلَى مَنْ كَانَ قَبْلَكُمْ فَضَيَّعُوهَا فَمَنْ حَافَظَ عَلَيْهَا كَانَ لَهُ أَجْرُهُ مَرَّتَيْنِ وَلاَ صَلاَةَ بَعْدَهَا حَتَّى يَطْلُعَ الشَّاهِدُ ‏"‏ ‏.‏ وَالشَّاهِدُ النَّجْمُ ‏.‏\hadithno{1927}\hadithtrans{Abu Basra Ghifari reported:The Messenger of Allah (ﷺ) led us in the 'Asr prayer at (the place known as) Mukhammas, and then said: This prayer was presented to those gone before you, but they lost it, and he who guards it has two rewards in store for him. And no prayer is valid after till the onlooker appears (by onlooker is meant the evening star)}}
\hadithdefcmd{muslim}{1928}{وَحَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، قَالَ حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، عَنْ خَيْرِ بْنِ نُعَيْمٍ الْحَضْرَمِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ هُبَيْرَةَ السَّبَائِيِّ، - وَكَانَ ثِقَةً - عَنْ أَبِي تَمِيمٍ الْجَيْشَانِيِّ، عَنْ أَبِي بَصْرَةَ الْغِفَارِيِّ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم الْعَصْرَ ‏.‏ بِمِثْلِهِ ‏.‏\hadithno{1928}\hadithtrans{This hadith has been narrated by Abu Basra Ghifari through another chain of transmitters}}
\hadithdefcmd{muslim}{1929}{وَحَدَّثَنَا يَحْيَى بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، عَنْ مُوسَى بْنِ عُلَىٍّ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ عُقْبَةَ بْنَ عَامِرٍ الْجُهَنِيَّ، يَقُولُ ثَلاَثُ سَاعَاتٍ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْهَانَا أَنْ نُصَلِّيَ فِيهِنَّ أَوْ أَنْ نَقْبُرَ فِيهِنَّ مَوْتَانَا حِينَ تَطْلُعُ الشَّمْسُ بَازِغَةً حَتَّى تَرْتَفِعَ وَحِينَ يَقُومُ قَائِمُ الظَّهِيرَةِ حَتَّى تَمِيلَ الشَّمْسُ وَحِينَ تَضَيَّفُ الشَّمْسُ لِلْغُرُوبِ حَتَّى تَغْرُبَ ‏.‏\hadithno{1929}\hadithtrans{Uqba b. 'Amir said:There were three times at which Allah's Messenger (ﷺ) forbade us to pray, or bury our dead: When the sun begins to rise till it is fully up, when the sun is at its height at midday till it passes over the meridian, and when the sun draws near to setting till it sets}}
\hadithdefcmd{muslim}{1930}{حَدَّثَنِي أَحْمَدُ بْنُ جَعْفَرٍ الْمَعْقِرِيُّ، حَدَّثَنَا النَّضْرُ بْنُ مُحَمَّدٍ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنَا شَدَّادُ بْنُ عَبْدِ اللَّهِ أَبُو عَمَّارٍ، وَيَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي أُمَامَةَ، - قَالَ عِكْرِمَةُ وَلَقِيَ شَدَّادٌ أَبَا أُمَامَةَ وَوَاثِلَةَ وَصَحِبَ أَنَسًا إِلَى الشَّامِ وَأَثْنَى عَلَيْهِ فَضْلاً وَخَيْرًا - عَنْ أَبِي أُمَامَةَ قَالَ قَالَ عَمْرُو بْنُ عَبَسَةَ السُّلَمِيُّ كُنْتُ وَأَنَا فِي الْجَاهِلِيَّةِ أَظُنُّ أَنَّ النَّاسَ عَلَى ضَلاَلَةٍ وَأَنَّهُمْ لَيْسُوا عَلَى شَىْءٍ وَهُمْ يَعْبُدُونَ الأَوْثَانَ فَسَمِعْتُ بِرَجُلٍ بِمَكَّةَ يُخْبِرُ أَخْبَارًا فَقَعَدْتُ عَلَى رَاحِلَتِي فَقَدِمْتُ عَلَيْهِ فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم مُسْتَخْفِيًا جُرَءَاءُ عَلَيْهِ قَوْمُهُ فَتَلَطَّفْتُ حَتَّى دَخَلْتُ عَلَيْهِ بِمَكَّةَ فَقُلْتُ لَهُ مَا أَنْتَ قَالَ ‏"‏ أَنَا نَبِيٌّ ‏"‏ ‏.‏ فَقُلْتُ وَمَا نَبِيٌّ قَالَ ‏"‏ أَرْسَلَنِي اللَّهُ ‏"‏ ‏.‏ فَقُلْتُ وَبِأَىِّ شَىْءٍ أَرْسَلَكَ قَالَ ‏"‏ أَرْسَلَنِي بِصِلَةِ الأَرْحَامِ وَكَسْرِ الأَوْثَانِ وَأَنْ يُوَحَّدَ اللَّهُ لاَ يُشْرَكُ بِهِ شَىْءٌ ‏"‏ ‏.‏ قُلْتُ لَهُ فَمَنْ مَعَكَ عَلَى هَذَا قَالَ ‏"‏ حُرٌّ وَعَبْدٌ ‏"‏ ‏.‏ قَالَ وَمَعَهُ يَوْمَئِذٍ أَبُو بَكْرٍ وَبِلاَلٌ مِمَّنْ آمَنَ بِهِ ‏.‏ فَقُلْتُ إِنِّي مُتَّبِعُكَ ‏.‏ قَالَ ‏"‏ إِنَّكَ لاَ تَسْتَطِيعُ ذَلِكَ يَوْمَكَ هَذَا أَلاَ تَرَى حَالِي وَحَالَ النَّاسِ وَلَكِنِ ارْجِعْ إِلَى أَهْلِكَ فَإِذَا سَمِعْتَ بِي قَدْ ظَهَرْتُ فَأْتِنِي ‏"‏ ‏.‏ قَالَ فَذَهَبْتُ إِلَى أَهْلِي وَقَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ وَكُنْتُ فِي أَهْلِي فَجَعَلْتُ أَتَخَبَّرُ الأَخْبَارَ وَأَسْأَلُ النَّاسَ حِينَ قَدِمَ الْمَدِينَةَ حَتَّى قَدِمَ عَلَىَّ نَفَرٌ مِنْ أَهْلِ يَثْرِبَ مِنْ أَهْلِ الْمَدِينَةِ فَقُلْتُ مَا فَعَلَ هَذَا الرَّجُلُ الَّذِي قَدِمَ الْمَدِينَةَ فَقَالُوا النَّاسُ إِلَيْهِ سِرَاعٌ وَقَدْ أَرَادَ قَوْمُهُ قَتْلَهُ فَلَمْ يَسْتَطِيعُوا ذَلِكَ ‏.‏ فَقَدِمْتُ الْمَدِينَةَ فَدَخَلْتُ عَلَيْهِ فَقُلْتُ يَا رَسُولَ اللَّهِ أَتَعْرِفُنِي قَالَ ‏"‏ نَعَمْ أَنْتَ الَّذِي لَقِيتَنِي بِمَكَّةَ ‏"‏ ‏.‏ قَالَ فَقُلْتُ بَلَى ‏.‏ فَقُلْتُ يَا نَبِيَّ اللَّهِ أَخْبِرْنِي عَمَّا عَلَّمَكَ اللَّهُ وَأَجْهَلُهُ ‏.‏ أَخْبِرْنِي عَنِ الصَّلاَةِ قَالَ ‏"‏ صَلِّ صَلاَةَ الصُّبْحِ ثُمَّ أَقْصِرْ عَنِ الصَّلاَةِ حَتَّى تَطْلُعَ الشَّمْسُ حَتَّى تَرْتَفِعَ فَإِنَّهَا تَطْلُعُ حِينَ تَطْلُعُ بَيْنَ قَرْنَىْ شَيْطَانٍ وَحِينَئِذٍ يَسْجُدُ لَهَا الْكُفَّارُ ثُمَّ صَلِّ فَإِنَّ الصَّلاَةَ مَشْهُودَةٌ مَحْضُورَةٌ حَتَّى يَسْتَقِلَّ الظِّلُّ بِالرُّمْحِ ثُمَّ أَقْصِرْ عَنِ الصَّلاَةِ فَإِنَّ حِينَئِذٍ تُسْجَرُ جَهَنَّمُ فَإِذَا أَقْبَلَ الْفَىْءُ فَصَلِّ فَإِنَّ الصَّلاَةَ مَشْهُودَةٌ مَحْضُورَةٌ حَتَّى تُصَلِّيَ الْعَصْرَ ثُمَّ أَقْصِرْ عَنِ الصَّلاَةِ حَتَّى تَغْرُبَ الشَّمْسُ فَإِنَّهَا تَغْرُبُ بَيْنَ قَرْنَىْ شَيْطَانٍ وَحِينَئِذٍ يَسْجُدُ لَهَا الْكُفَّارُ ‏"‏ ‏.‏ قَالَ فَقُلْتُ يَا نَبِيَّ اللَّهِ فَالْوُضُوءُ حَدِّثْنِي عَنْهُ قَالَ ‏"‏ مَا مِنْكُمْ رَجُلٌ يُقَرِّبُ وَضُوءَهُ فَيَتَمَضْمَضُ وَيَسْتَنْشِقُ فَيَنْتَثِرُ إِلاَّ خَرَّتْ خَطَايَا وَجْهِهِ وَفِيهِ وَخَيَاشِيمِهِ ثُمَّ إِذَا غَسَلَ وَجْهَهُ كَمَا أَمَرَهُ اللَّهُ إِلاَّ خَرَّتْ خَطَايَا وَجْهِهِ مِنْ أَطْرَافِ لِحْيَتِهِ مَعَ الْمَاءِ ثُمَّ يَغْسِلُ يَدَيْهِ إِلَى الْمِرْفَقَيْنِ إِلاَّ خَرَّتْ خَطَايَا يَدَيْهِ مِنْ أَنَامِلِهِ مَعَ الْمَاءِ ثُمَّ يَمْسَحُ رَأْسَهُ إِلاَّ خَرَّتْ خَطَايَا رَأْسِهِ مِنْ أَطْرَافِ شَعْرِهِ مَعَ الْمَاءِ ثُمَّ يَغْسِلُ قَدَمَيْهِ إِلَى الْكَعْبَيْنِ إِلاَّ خَرَّتْ خَطَايَا رِجْلَيْهِ مِنْ أَنَامِلِهِ مَعَ الْمَاءِ فَإِنْ هُوَ قَامَ فَصَلَّى فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ وَمَجَّدَهُ بِالَّذِي هُوَ لَهُ أَهْلٌ وَفَرَّغَ قَلْبَهُ لِلَّهِ إِلاَّ انْصَرَفَ مِنْ خَطِيئَتِهِ كَهَيْئَتِهِ يَوْمَ وَلَدَتْهُ أُمُّهُ ‏"‏ ‏.‏ فَحَدَّثَ عَمْرُو بْنُ عَبَسَةَ بِهَذَا الْحَدِيثِ أَبَا أُمَامَةَ صَاحِبَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لَهُ أَبُو أُمَامَةَ يَا عَمْرَو بْنَ عَبَسَةَ انْظُرْ مَا تَقُولُ فِي مَقَامٍ وَاحِدٍ يُعْطَى هَذَا الرَّجُلُ فَقَالَ عَمْرٌو يَا أَبَا أُمَامَةَ لَقَدْ كَبِرَتْ سِنِّي وَرَقَّ عَظْمِي وَاقْتَرَبَ أَجَلِي وَمَا بِي حَاجَةٌ أَنْ أَكْذِبَ عَلَى اللَّهِ وَلاَ عَلَى رَسُولِ اللَّهِ لَوْ لَمْ أَسْمَعْهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم إِلاَّ مَرَّةً أَوْ مَرَّتَيْنِ أَوْ ثَلاَثًا - حَتَّى عَدَّ سَبْعَ مَرَّاتٍ - مَا حَدَّثْتُ بِهِ أَبَدًا وَلَكِنِّي سَمِعْتُهُ أَكْثَرَ مِنْ ذَلِكَ ‏.‏\hadithno{1930}\hadithtrans{Amr b. 'Abasa Sulami reported:In the state of the Ignorance (before embracing Islam), I used to think that the people were in error and they were not on anything (which may be called the right path) and worshipped the idols. Meanwhile, I heard of a man in Mecca who was giving news (on the basis of his prophetic knowledge) ; so I sat on my ride and went to him. The Messenger of Allah (ﷺ) was at that time hiding as his people had made life hard for him. I adopted a friendly attitude (towards the Meccans and thus managed) to enter Mecca and go to him (the Holy Prophet) and I said to him: Who are you? He said: I am a Prophet (of Allah). I again said: Who is a Prophet? He said: (I am a Prophet in the sense that) I have been sent by Allah. I said: What is that which you have been sent with? He said: I have been sent to join ties of relationship (with kindness and affection), to break the Idols, and to proclaim the oneness of Allah (in a manner that) nothing is to be associated with Him. I said: Who is with you in this (in these beliefs and practices)? He said: A free man and a slave. He (the narrator) said: Abu Bakr and Bilal were there with him among those who had embraced Islam by that time. I said: I intend to follow you. He said: During these days you would not be able to do so. Don't you see the (hard) condition under which I and (my) people are living? You better go back to your people and when you hear that I have been granted victory, you come to me. So I went to my family. I was in my home when the Messenger of Allah (ﷺ) came to Medina. I was among my people and used to seek news and ask people when he arrived in Medina. Then a group of people belonging to Yathrib (Medina) came. I said (to them): How is that person getting on who has come to Medina? They said: The people are hastening to him, while his people (the polytheists of Mecca) planned to kill him, but they could not do so. I (on hearing it) came to Medina and went to him and said: Messenger of Allah, do you recognise me? He said: Yes, you are the same man who met me at Mecca. I said: It is so. I again said: Prophet of Allah, tell me that which Allah has taught you and which I do not know, tell me about the prayer. He said: Observe the dawn prayer, then stop praying when the sun is rising till it is fully up, for when it rises it comes up between the horns of Satan, and the unbelievers prostrate themselves to it at that time. Then pray, for the prayer is witnessed and attended (by angels) till the shadow becomes about the length of a lance; then cease prayer, for at that time Hell is heated up. Then when the shadow moves forward, pray, for the prayer is witnessed and attended by angels, till you pray the afternoon prayer, then cease prayer till the sun sets, for it sets between the horns of devil, and at that time the unbelievers prostrate themselves before it. I said: Apostle of Allah, tell me about ablution also. He said: None of you who uses water for ablution and rinses his mouth, snuffs up water and blows it, but the sins of his face, and his mouth and his nostrils fall out. When he washes his face, as Allah has commanded him, the sins of his face fall out from the end of his beard with water. Then (when) he washes his forearms up to the elbows, the sins of his arms fall out along with water from his finger-tips. And when he wipes his head, the sins of his head fall out from the points of his hair along with water. And (when) he washes his feet up to the ankles, the sins of his feet fall out from his toes along with water. And if he stands to pray and praises Allah, lauds Him and glorifies Him with what becomes Him and shows wholehearted devotion to Allah, his sins would depart leaving him (as innocent) as he was on the day his mother bore him. 'Amr b. 'Abasa narrated this hadith to Abu Umama, a Companion of the Messenger of Allah (ﷺ), and Abu Umama said to him: 'Amr b. 'Abasa, think what you are saying that such (a great reward) is given to a man at one place (only in the act of ablution and prayer). Upon this 'Amr said: Abu Umama, I have grown old and my bones have become weak and I am at the door of death; what impetus is there for me to attribute a lie to Allah and the Messenger of Allah (ﷺ)? Had I heard it from the Messenger of Allah (ﷺ) once, twice, or three times (even seven times), I would have never narrated it, but I have heard it from him on occasions more than these}}
\hadithdefcmd{muslim}{1931}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمٍ، حَدَّثَنَا بَهْزٌ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ وَهِمَ عُمَرُ إِنَّمَا نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُتَحَرَّى طُلُوعُ الشَّمْسِ وَغُرُوبُهَا ‏.‏\hadithno{1931}\hadithtrans{A'isha reported that 'Umar misconstrued the fact that the Messenger of Allah (ﷺ) had prohibited the observance of prayer at the time of the rising sun and at the time of its setting}}
\hadithdefcmd{muslim}{1932}{وَحَدَّثَنَا حَسَنٌ الْحُلْوَانِيُّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ لَمْ يَدَعْ رَسُولُ اللَّهِ صلى الله عليه وسلم الرَّكْعَتَيْنِ بَعْدَ الْعَصْرِ ‏.‏ قَالَ فَقَالَتْ عَائِشَةُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَتَحَرَّوْا طُلُوعَ الشَّمْسِ وَلاَ غُرُوبَهَا فَتُصَلُّوا عِنْدَ ذَلِكَ ‏"‏ ‏.‏\hadithno{1932}\hadithtrans{A'isha said that the Messenger of Allah (ﷺ) did not abandon observing two rak'ahs after 'Asr, but she reported Allah's Messenger (ﷺ) as saying:Do not get used to observe prayer at the time of the rising sun and at the time of its setting and (exhorted the Muslims) to pray at their times}}
\hadithdefcmd{muslim}{1933}{حَدَّثَنِي حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرٌو، - وَهُوَ ابْنُ الْحَارِثِ - عَنْ بُكَيْرٍ، عَنْ كُرَيْبٍ، مَوْلَى ابْنِ عَبَّاسٍ أَنَّ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، وَعَبْدَ الرَّحْمَنِ، بْنَ أَزْهَرَ وَالْمِسْوَرَ بْنَ مَخْرَمَةَ أَرْسَلُوهُ إِلَى عَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم فَقَالُوا اقْرَأْ عَلَيْهَا السَّلاَمَ مِنَّا جَمِيعًا وَسَلْهَا عَنِ الرَّكْعَتَيْنِ بَعْدَ الْعَصْرِ وَقُلْ إِنَّا أُخْبِرْنَا أَنَّكِ تُصَلِّينَهُمَا وَقَدْ بَلَغَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْهُمَا ‏.‏ قَالَ ابْنُ عَبَّاسٍ وَكُنْتُ أَصْرِفُ مَعَ عُمَرَ بْنِ الْخَطَّابِ النَّاسَ عَنْهَا ‏.‏ قَالَ كُرَيْبٌ فَدَخَلْتُ عَلَيْهَا وَبَلَّغْتُهَا مَا أَرْسَلُونِي بِهِ ‏.‏ فَقَالَتْ سَلْ أُمَّ سَلَمَةَ ‏.‏ فَخَرَجْتُ إِلَيْهِمْ فَأَخْبَرْتُهُمْ بِقَوْلِهَا فَرَدُّونِي إِلَى أُمِّ سَلَمَةَ بِمِثْلِ مَا أَرْسَلُونِي بِهِ إِلَى عَائِشَةَ ‏.‏ فَقَالَتْ أُمُّ سَلَمَةَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْهُمَا ثُمَّ رَأَيْتُهُ يُصَلِّيهِمَا أَمَّا حِينَ صَلاَّهُمَا فَإِنَّهُ صَلَّى الْعَصْرَ ثُمَّ دَخَلَ وَعِنْدِي نِسْوَةٌ مِنْ بَنِي حَرَامٍ مِنَ الأَنْصَارِ فَصَلاَّهُمَا فَأَرْسَلْتُ إِلَيْهِ الْجَارِيَةَ فَقُلْتُ قُومِي بِجَنْبِهِ فَقُولِي لَهُ تَقُولُ أُمُّ سَلَمَةَ يَا رَسُولَ اللَّهِ إِنِّي أَسْمَعُكَ تَنْهَى عَنْ هَاتَيْنِ الرَّكْعَتَيْنِ وَأَرَاكَ تُصَلِّيهِمَا فَإِنْ أَشَارَ بِيَدِهِ فَاسْتَأْخِرِي عَنْهُ - قَالَ - فَفَعَلَتِ الْجَارِيَةُ فَأَشَارَ بِيَدِهِ فَاسْتَأْخَرَتْ عَنْهُ فَلَمَّا انْصَرَفَ قَالَ ‏ "‏ يَا بِنْتَ أَبِي أُمَيَّةَ سَأَلْتِ عَنِ الرَّكْعَتَيْنِ بَعْدَ الْعَصْرِ إِنَّهُ أَتَانِي نَاسٌ مِنْ عَبْدِ الْقَيْسِ بِالإِسْلاَمِ مِنْ قَوْمِهِمْ فَشَغَلُونِي عَنِ الرَّكْعَتَيْنِ اللَّتَيْنِ بَعْدَ الظُّهْرِ فَهُمَا هَاتَانِ ‏"‏ ‏.‏\hadithno{1933}\hadithtrans{Kuraib, the freed slave of Ibn 'Abbas, reported that 'Abdullah b. 'Abbas, 'Abd al-Rahman b. Azhar, al-Miswar b. Makhrama sent him to 'A'isha, the wife of the Messenger of Allah (ﷺ), telling him to give her their greetings, and ask her about the two rak'ahs after the afternoon prayer, (for)" we have heard that you observe them whereas it has been conveyed to us that the Messenger of Allah (ﷺ) prohibited their observance." Ibn 'Abbas said:I along with 'Umar b. al-Khattab dissuaded people to do so (to observe two rak'ahs of prayer). Kuraib said: I went to her ('A'isha) and conveyed to her the message with which I was sent. She said: (Better) ask Umm Salama. So I went to them (those who had sent him to Hadrat 'A'isha) and informed them about what she had said. They sent me back to Umm Salama with that with which I was sent to 'A'isha. Umm Salama said: I beard the Messenger of Allah (ﷺ) prohibiting them, and then afterwards I saw him observing them. And when he observed them (two rak'ahs) he had already observed the 'Asr prayer. Then he (the Holy Prophet) came, while there were with me ladies of Banu Haram, a tribe of the Ansar and he (the Holy Prophet) observed them (the two rak'ahs). I sent a slave-girl to him asking her to stand by his side and say to him that Umm Salama says: Messenger of Allah, I heard you prohibiting these two rak'ahs, whereas I saw you observing them; and if he (the Holy Prophet) points with his hand (to wait), then do wait. The slave-girl did like that. He (the Holy Prophet) pointed out with his hand and she got aside and waited, and when he had finished (the prayer) he said: Daughter of Abu Umayya. you have asked about the two rak'ahs after the 'Asr prayer. Some people of 'Abu al-Qais came to me for embracing Islam and hindered me from observing the two rak'ahs which come after the noon prayer. So those are the two I have been praying}}
\hadithdefcmd{muslim}{1934}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَعَلِيُّ بْنُ حُجْرٍ، قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ، - وَهُوَ ابْنُ جَعْفَرٍ - أَخْبَرَنِي مُحَمَّدٌ، - وَهُوَ ابْنُ أَبِي حَرْمَلَةَ - قَالَ أَخْبَرَنِي أَبُو سَلَمَةَ، أَنَّهُ سَأَلَ عَائِشَةَ عَنِ السَّجْدَتَيْنِ اللَّتَيْنِ، كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّيهِمَا بَعْدَ الْعَصْرِ فَقَالَتْ كَانَ يُصَلِّيهِمَا قَبْلَ الْعَصْرِ ثُمَّ إِنَّهُ شُغِلَ عَنْهُمَا أَوْ نَسِيَهُمَا فَصَلاَّهُمَا بَعْدَ الْعَصْرِ ثُمَّ أَثْبَتَهُمَا وَكَانَ إِذَا صَلَّى صَلاَةً أَثْبَتَهَا ‏.‏ قَالَ يَحْيَى بْنُ أَيُّوبَ قَالَ إِسْمَاعِيلُ تَعْنِي دَاوَمَ عَلَيْهَا ‏.‏\hadithno{1934}\hadithtrans{Abu Salama asked 'A'isha about the two prostrations (i. e. rak'ahs) which the Messenger of Allah (ﷺ) made after the 'Asr. She said:He (the Holy Prophet) observed them before the 'Asr prayer, but then he was hindered to do so, or he forgot them and then he observed them after the 'Asr, and then he continued observing them. (It was his habit) that when he (the Holy Prophet) observed prayer, he then continued observing it. Isma'il said: It implies that he always did that}}
\hadithdefcmd{muslim}{1935}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا جَرِيرٌ، ح وَحَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبِي جَمِيعًا، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ مَا تَرَكَ رَسُولُ اللَّهِ صلى الله عليه وسلم رَكْعَتَيْنِ بَعْدَ الْعَصْرِ عِنْدِي قَطُّ ‏.‏\hadithno{1935}\hadithtrans{A'isha reported:The Messenger of Allah (ﷺ) did not abandon at all observing two rak'ahs after the 'Asr in my house}}
\hadithdefcmd{muslim}{1936}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَلِيُّ بْنُ مُسْهِرٍ، ح وَحَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، - وَاللَّفْظُ لَهُ - أَخْبَرَنَا عَلِيُّ بْنُ مُسْهِرٍ، أَخْبَرَنَا أَبُو إِسْحَاقَ الشَّيْبَانِيُّ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ الأَسْوَدِ عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ صَلاَتَانِ مَا تَرَكَهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَيْتِي قَطُّ سِرًّا وَلاَ عَلاَنِيَةً رَكْعَتَيْنِ قَبْلَ الْفَجْرِ وَرَكْعَتَيْنِ بَعْدَ الْعَصْرِ ‏.‏\hadithno{1936}\hadithtrans{A'isha reported:Two are the prayers which the Messenger of Allah (ﷺ) always observed in my house-openly or secretly-two rak'ahs before the dawn and two rak'ahs after the 'Asr}}
\hadithdefcmd{muslim}{1937}{وَحَدَّثَنَا ابْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالَ ابْنُ الْمُثَنَّى حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الأَسْوَدِ، وَمَسْرُوقٍ، قَالاَ نَشْهَدُ عَلَى عَائِشَةَ أَنَّهَا قَالَتْ مَا كَانَ يَوْمُهُ الَّذِي كَانَ يَكُونُ عِنْدِي إِلاَّ صَلاَّهُمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي بَيْتِي ‏.‏ تَعْنِي الرَّكْعَتَيْنِ بَعْدَ الْعَصْرِ ‏.‏\hadithno{1937}\hadithtrans{Aswad and Masruq reported:We bear testimony to the fact that 'A'isha said: Never was there a day that he (the Holy Prophet) was with me and he did not observe two rak'ahs of prayer in my house, i. e. two rak'ahs after the Asr}}
\hadithdefcmd{muslim}{1938}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ جَمِيعًا عَنِ ابْنِ فُضَيْلٍ، - قَالَ أَبُو بَكْرٍ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، - عَنْ مُخْتَارِ بْنِ فُلْفُلٍ، قَالَ سَأَلْتُ أَنَسَ بْنَ مَالِكٍ عَنِ التَّطَوُّعِ، بَعْدَ الْعَصْرِ فَقَالَ كَانَ عُمَرُ يَضْرِبُ الأَيْدِي عَلَى صَلاَةٍ بَعْدَ الْعَصْرِ وَكُنَّا نُصَلِّي عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم رَكْعَتَيْنِ بَعْدَ غُرُوبِ الشَّمْسِ قَبْلَ صَلاَةِ الْمَغْرِبِ ‏.‏ فَقُلْتُ لَهُ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَّهُمَا قَالَ كَانَ يَرَانَا نُصَلِّيهِمَا ‏.‏ فَلَمْ يَأْمُرْنَا وَلَمْ يَنْهَنَا\hadithno{1938}\hadithtrans{Mukhtar b. Fulful said:I asked Anas b. Malik about the voluntary prayers after the afternoon prayer, and he replied: 'Umar struck hit hands on prayer observed after the 'Asr prayer and we used to observe two rak'ahs after the sun set before the evening prayer during the time of the Messenger of Allah (ﷺ). I said to him: Did the Messenger of Allah (ﷺ) observe them? He said: He saw us observing them, but he neither commanded us nor forbade us to do so}}
\hadithdefcmd{muslim}{1939}{وَحَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ عَبْدِ الْعَزِيزِ، - وَهُوَ ابْنُ صُهَيْبٍ - عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنَّا بِالْمَدِينَةِ فَإِذَا أَذَّنَ الْمُؤَذِّنُ لِصَلاَةِ الْمَغْرِبِ ابْتَدَرُوا السَّوَارِيَ فَيَرْكَعُونَ رَكْعَتَيْنِ رَكْعَتَيْنِ حَتَّى إِنَّ الرَّجُلَ الْغَرِيبَ لَيَدْخُلُ الْمَسْجِدَ فَيَحْسِبُ أَنَّ الصَّلاَةَ قَدْ صُلِّيَتْ مِنْ كَثْرَةِ مَنْ يُصَلِّيهِمَا ‏.‏\hadithno{1939}\hadithtrans{Anas b. Malik reported:When we were in Medina, the moment the Mu'adhdhin made the call to the sunset prayer, the people hastened to the pillars of the mosque and prayed two rak'ahs with the result that any stranger coming into the mosque would think that the obligatory prayer had been observed owing to the number who were praying then}}
\hadithdefcmd{muslim}{1940}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، وَوَكِيعٌ، عَنْ كَهْمَسٍ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ الْمُزَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَيْنَ كُلِّ أَذَانَيْنِ صَلاَةٌ - قَالَهَا ثَلاَثًا قَالَ فِي الثَّالِثَةِ - لِمَنْ شَاءَ ‏"‏ ‏.‏\hadithno{1940}\hadithtrans{Abdullah b. Mughaffal reported Allah's Messenger (ﷺ) u saying:There Is between the two calls (Adhan and Iqama) a prayer. And he mentioned it three times, and at the third time he said: This applies to those who wish to do it}}
\hadithdefcmd{muslim}{1941}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الأَعْلَى، عَنِ الْجُرَيْرِيِّ، عَنْ عَبْدِ اللَّهِ، بْنِ بُرَيْدَةَ عَنْ عَبْدِ اللَّهِ بْنِ مُغَفَّلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ مِثْلَهُ إِلاَّ أَنَّهُ قَالَ فِي الرَّابِعَةِ ‏ "‏ لِمَنْ شَاءَ ‏"‏ ‏.‏\hadithno{1941}\hadithtrans{This hadith has been narrated by Abdullah b. Mughaffal by another chain of transmitters, but with this variation that he (the Holy Prophet) said at the fourth time:" He who wishes (may do to)}}
\hadithdefcmd{muslim}{1942}{حَدَّثَنَا عَبْدُ بْنُ حُمَيْدٍ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمٍ، عَنِ ابْنِ عُمَرَ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْخَوْفِ بِإِحْدَى الطَّائِفَتَيْنِ رَكْعَةً وَالطَّائِفَةُ الأُخْرَى مُوَاجِهَةُ الْعَدُوِّ ثُمَّ انْصَرَفُوا وَقَامُوا فِي مَقَامِ أَصْحَابِهِمْ مُقْبِلِينَ عَلَى الْعَدُوِّ وَجَاءَ أُولَئِكَ ثُمَّ صَلَّى بِهِمُ النَّبِيُّ صلى الله عليه وسلم رَكْعَةً ثُمَّ سَلَّمَ النَّبِيُّ صلى الله عليه وسلم ثُمَّ قَضَى هَؤُلاَءِ رَكْعَةً وَهَؤُلاَءِ رَكْعَةً ‏.‏\hadithno{1942}\hadithtrans{Salim b. Abdullah b. 'Umar reported:The Messenger of Allah (may peace he upon him) led on* of the two groups In one rak'ah of prayer in danger, while the other group faced the -enemy. Then they (the members of the first group) went back and replaced their companions who were facing the enemy. and then they (the members of the second group) came and the Messenger of Allah (ﷺ) led them in one rak'ah of prayer. Then the Messenger of Allah (ﷺ) pronounced salutation, and then they (the members of the Ant group) completed the rak'ah and they (the members of the second group) completed the rak'ah}}
\hadithdefcmd{muslim}{1943}{وَحَدَّثَنِيهِ أَبُو الرَّبِيعِ الزَّهْرَانِيُّ، حَدَّثَنَا فُلَيْحٌ، عَنِ الزُّهْرِيِّ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، بْنِ عُمَرَ عَنْ أَبِيهِ، أَنَّهُ كَانَ يُحَدِّثُ عَنْ صَلاَةِ، رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْخَوْفِ وَيَقُولُ صَلَّيْتُهَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ بِهَذَا الْمَعْنَى ‏.‏\hadithno{1943}\hadithtrans{This hadith has been narrated by another chain of transmitters}}
\hadithdefcmd{muslim}{1944}{وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ سُفْيَانَ، عَنْ مُوسَى بْنِ، عُقْبَةَ عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ صَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْخَوْفِ فِي بَعْضِ أَيَّامِهِ فَقَامَتْ طَائِفَةٌ مَعَهُ وَطَائِفَةٌ بِإِزَاءِ الْعَدُوِّ فَصَلَّى بِالَّذِينَ مَعَهُ رَكْعَةً ثُمَّ ذَهَبُوا وَجَاءَ الآخَرُونَ فَصَلَّى بِهِمْ رَكْعَةً ثُمَّ قَضَتِ الطَّائِفَتَانِ رَكْعَةً رَكْعَةً - قَالَ - وَقَالَ ابْنُ عُمَرَ فَإِذَا كَانَ خَوْفٌ أَكْثَرَ مِنْ ذَلِكَ فَصَلِّ رَاكِبًا أَوْ قَائِمًا تُومِئُ إِيمَاءً ‏.‏\hadithno{1944}\hadithtrans{Ibn Umar reported that the Messenger of Allah (ﷺ) observed prayer in danger on some day (in this way):a group stood with him (the Holy Prophet) (for prayer) and the other group stood In front of the enemy. Then those who were with (him) observed one rak'ah of prayer and they went back and the others came and they observed one rak'ah (with him). Then both the groups completed one rak'ah each. Ibn Umar said: When there is greater danger, then observe prayer even on the ride or with the help of gestures in a standing posture}}
\hadithdefcmd{muslim}{1945}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ شَهِدْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْخَوْفِ فَصَفَّنَا صَفَّيْنِ صَفٌّ خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَالْعَدُوُّ بَيْنَنَا وَبَيْنَ الْقِبْلَةِ فَكَبَّرَ النَّبِيُّ صلى الله عليه وسلم وَكَبَّرْنَا جَمِيعًا ثُمَّ رَكَعَ وَرَكَعْنَا جَمِيعًا ثُمَّ رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ وَرَفَعْنَا جَمِيعًا ثُمَّ انْحَدَرَ بِالسُّجُودِ وَالصَّفُّ الَّذِي يَلِيهِ وَقَامَ الصَّفُّ الْمُؤَخَّرُ فِي نَحْرِ الْعَدُوِّ فَلَمَّا قَضَى النَّبِيُّ صلى الله عليه وسلم السُّجُودَ وَقَامَ الصَّفُّ الَّذِي يَلِيهِ انْحَدَرَ الصَّفُّ الْمُؤَخَّرُ بِالسُّجُودِ وَقَامُوا ثُمَّ تَقَدَّمَ الصَّفُّ الْمُؤَخَّرُ وَتَأَخَّرَ الصَّفُّ الْمُقَدَّمُ ثُمَّ رَكَعَ النَّبِيُّ صلى الله عليه وسلم وَرَكَعْنَا جَمِيعًا ثُمَّ رَفَعَ رَأْسَهُ مِنَ الرُّكُوعِ وَرَفَعْنَا جَمِيعًا ثُمَّ انْحَدَرَ بِالسُّجُودِ وَالصَّفُّ الَّذِي يَلِيهِ الَّذِي كَانَ مُؤَخَّرًا فِي الرَّكْعَةِ الأُولَى وَقَامَ الصَّفُّ الْمُؤَخَّرُ فِي نُحُورِ الْعَدُوِّ فَلَمَّا قَضَى النَّبِيُّ صلى الله عليه وسلم السُّجُودَ وَالصَّفُّ الَّذِي يَلِيهِ انْحَدَرَ الصَّفُّ الْمُؤَخَّرُ بِالسُّجُودِ فَسَجَدُوا ثُمَّ سَلَّمَ النَّبِيُّ صلى الله عليه وسلم وَسَلَّمْنَا جَمِيعًا ‏.‏ قَالَ جَابِرٌ كَمَا يَصْنَعُ حَرَسُكُمْ هَؤُلاَءِ بِأُمَرَائِهِمْ ‏.‏\hadithno{1945}\hadithtrans{Jabir b. 'Abdullah reported:I observed prayer in danger with the Messenger of Allah (ﷺ). We drew ourselves up in two rows, one row behind him with the enemy between us and the Qibla. The Apostle of Allah (ﷺ) said: Allah is Most Great, and we all said it. He then bowed and we all bowed. He then raised his head from bowing, we all raised (our heads). He then went down in prostration along with the row close to him, and the rear row faced the enemy; then when the Messenger of Allah (ﷺ) completed the prostration, ; and then stood up, the row near to him also did it; then went down the rear row in prostration; then they stood up; then the rear row went to the front and the front row went to the rear. Then the Messenger of Allah (may peace he upon him) bowed down and we all bowed. He then raised his head from bowing and we also raised (our heads). He and the row close to him which I had been in the rear then went down in prostration In the first rak'ah, whereas the rear row faced the enemy. And when the Messenger of Allah (ﷺ) and the rear row close to him had finished the prostration, the rear row went down and prostrated themselves; then the Messenger of Allah pronounced the salutation and we also pronounced the salutation. (Jabir said we hadith) as your guards behave with their chiefs}}
\hadithdefcmd{muslim}{1946}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ اللَّهِ بْنِ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا أَبُو الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ غَزَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم قَوْمًا مِنْ جُهَيْنَةَ فَقَاتَلُونَا قِتَالاً شَدِيدًا فَلَمَّا صَلَّيْنَا الظُّهْرَ قَالَ الْمُشْرِكُونَ لَوْ مِلْنَا عَلَيْهِمْ مَيْلَةً لاَقْتَطَعْنَاهُمْ ‏.‏ فَأَخْبَرَ جِبْرِيلُ رَسُولَ اللَّهِ صلى الله عليه وسلم ذَلِكَ فَذَكَرَ ذَلِكَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم - قَالَ - وَقَالُوا إِنَّهُ سَتَأْتِيهِمْ صَلاَةٌ هِيَ أَحَبُّ إِلَيْهِمْ مِنَ الأَوْلاَدِ فَلَمَّا حَضَرَتِ الْعَصْرُ - قَالَ - صَفَّنَا صَفَّيْنِ وَالْمُشْرِكُونَ بَيْنَنَا وَبَيْنَ الْقِبْلَةِ - قَالَ - فَكَبَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَبَّرْنَا وَرَكَعَ فَرَكَعْنَا ثُمَّ سَجَدَ وَسَجَدَ مَعَهُ الصَّفُّ الأَوَّلُ فَلَمَّا قَامُوا سَجَدَ الصَّفُّ الثَّانِي ثُمَّ تَأَخَّرَ الصَّفُّ الأَوَّلُ وَتَقَدَّمَ الصَّفُّ الثَّانِي فَقَامُوا مَقَامَ الأَوَّلِ فَكَبَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَكَبَّرْنَا وَرَكَعَ فَرَكَعْنَا ثُمَّ سَجَدَ وَسَجَدَ مَعَهُ الصَّفُّ الأَوَّلُ وَقَامَ الثَّانِي فَلَمَّا سَجَدَ سَجَدَ الصَّفُّ الثَّانِي ثُمَّ جَلَسُوا جَمِيعًا سَلَّمَ عَلَيْهِمْ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو الزُّبَيْرِ ثُمَّ خَصَّ جَابِرٌ أَنْ قَالَ كَمَا يُصَلِّي أُمَرَاؤُكُمْ هَؤُلاَءِ ‏.‏\hadithno{1946}\hadithtrans{Jabir reported:We fought In the company of the Messenger of Allah (ﷺ) with the tribe of Juhaina. They fought with us terribly. When we had finished the noon prayer, the polytheists said: Had we attacked them at once. we would have killed them. Gabriel informed the Messenger of Allah (ﷺ) about It (about their evil design). The Messenger of Allah (ﷺ) made a mention of it to us, adding that they (the polytheists) had also said: Shortly there would be time for the 'Asr prayer. which is dearer o them (the Muslims) than even their children. So when the time of the 'Asr prayer came. we formed ourselves into two rows, while the polytheists were between us and the Qibla. The Messenger of Allah (ﷺ) said: Allah is Most Great, and we also said so. He bowed and we also bowed. He went down in prostration and the first row prostrated along with him. When they stood up, the second row went down in prostration. Then the first row went into the rear, and the second row came in the front and occupied the place of the first row. The Messenger of Allah (ﷺ) then said: Allah is Most Great, and we also said so. He then bowed, and we also bowed. He then went down in prostration and along with him the row also (went down in prostration), and the second row remained standing. And when the second row had also prostrated and all of them sat down then the Messenger of Allah (ﷺ) pronounced salutation to them. Abu Zubair said: Jabir made a mention specially of this thing: just as your chiefs observe prayer}}
\hadithdefcmd{muslim}{1947}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ، الْقَاسِمِ عَنْ أَبِيهِ، عَنْ صَالِحِ بْنِ خَوَّاتِ بْنِ جُبَيْرٍ، عَنْ سَهْلِ بْنِ أَبِي حَثْمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى بِأَصْحَابِهِ فِي الْخَوْفِ فَصَفَّهُمْ خَلْفَهُ صَفَّيْنِ فَصَلَّى بِالَّذِينَ يَلُونَهُ رَكْعَةً ثُمَّ قَامَ فَلَمْ يَزَلْ قَائِمًا حَتَّى صَلَّى الَّذِينَ خَلْفَهُمْ رَكْعَةً ثُمَّ تَقَدَّمُوا وَتَأَخَّرَ الَّذِينَ كَانُوا قُدَّامَهُمْ فَصَلَّى بِهِمْ رَكْعَةً ثُمَّ قَعَدَ حَتَّى صَلَّى الَّذِينَ تَخَلَّفُوا رَكْعَةً ثُمَّ سَلَّمَ ‏.‏\hadithno{1947}\hadithtrans{Sahl b. Abu Hathma reported that the Messenger of Allah (ﷺ) led his Companions in prayer in danger. He made them stand in two rows behind him. He led them who were close to him in one rak'ah. He then stood up and kept standing till those who were behind them observed one rak'ah. Then they (those standing in the second row) came in front and those who were in front went into the rear. He then led them In one rak'ah. He then sat down, till those who were behind him observed one rak'ah and then pronounced salutation}}
\hadithdefcmd{muslim}{1948}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنْ يَزِيدَ بْنِ رُومَانَ، عَنْ صَالِحِ، بْنِ خَوَّاتٍ عَمَّنْ صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَوْمَ ذَاتِ الرِّقَاعِ صَلاَةَ الْخَوْفِ أَنَّ طَائِفَةً صَفَّتْ مَعَهُ وَطَائِفَةٌ وِجَاهَ الْعَدُوِّ ‏.‏ فَصَلَّى بِالَّذِينَ مَعَهُ رَكْعَةً ثُمَّ ثَبَتَ قَائِمًا وَأَتَمُّوا لأَنْفُسِهِمْ ‏.‏ ثُمَّ انْصَرَفُوا فَصَفُّوا وِجَاهَ الْعَدُوِّ وَجَاءَتِ الطَّائِفَةُ الأُخْرَى فَصَلَّى بِهِمُ الرَّكْعَةَ الَّتِي بَقِيَتْ ثُمَّ ثَبَتَ جَالِسًا وَأَتَمُّوا لأَنْفُسِهِمْ ثُمَّ سَلَّمَ بِهِمْ ‏.‏\hadithno{1948}\hadithtrans{Yazid b. Ruman told on the authority of Salih b. Khawwat on the authority of one who prayed in time of danger with Allah's Messenger (may peace he upon him) at the Battle of Dhat ar-Riqa' that a group formed a row and prayed along with him, and a group faced the enemy. He led the group which was along with him in a rak'ah, then remained standing while they finished the prayer by themselves. Then they departed and formed a row facing the enemy. Then the second group came and he led them in the remaining rak'ah, after which he remained seated while they finished the prayer themselves. He then led them in salutation}}
\hadithdefcmd{muslim}{1949}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا أَبَانُ بْنُ يَزِيدَ، حَدَّثَنَا يَحْيَى، بْنُ أَبِي كَثِيرٍ عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ، قَالَ أَقْبَلْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى إِذَا كُنَّا بِذَاتِ الرِّقَاعِ قَالَ كُنَّا إِذَا أَتَيْنَا عَلَى شَجَرَةٍ ظَلِيلَةٍ تَرَكْنَاهَا لِرَسُولِ اللَّهِ صلى الله عليه وسلم - قَالَ - فَجَاءَ رَجُلٌ مِنَ الْمُشْرِكِينَ وَسَيْفُ رَسُولِ اللَّهِ صلى الله عليه وسلم مُعَلَّقٌ بِشَجَرَةٍ فَأَخَذَ سَيْفَ نَبِيِّ اللَّهِ صلى الله عليه وسلم فَاخْتَرَطَهُ فَقَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَتَخَافُنِي قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ قَالَ فَمَنْ يَمْنَعُكَ مِنِّي قَالَ ‏"‏ اللَّهُ يَمْنَعُنِي مِنْكَ ‏"‏ ‏.‏ قَالَ فَتَهَدَّدَهُ أَصْحَابُ رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَغْمَدَ السَّيْفَ وَعَلَّقَهُ - قَالَ - فَنُودِيَ بِالصَّلاَةِ فَصَلَّى بِطَائِفَةٍ رَكْعَتَيْنِ ثُمَّ تَأَخَّرُوا وَصَلَّى بِالطَّائِفَةِ الأُخْرَى رَكْعَتَيْنِ قَالَ فَكَانَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم أَرْبَعُ رَكَعَاتٍ وَلِلْقَوْمِ رَكْعَتَانِ ‏.‏\hadithno{1949}\hadithtrans{Jabir reported:We went forward with the Messenger of Allah (ﷺ) and when we reached Dhat ar-Riqa', we came to a shady tree which -we left for him One of the polytheists came there and, seeing the sword of the Messenger (ﷺ) hanging by a free. took it up. drew it from the scabbard and said to the Messenger of Allah (ﷺ): Are you afraid of Me? He (the Holy Prophet) said: No. He again said: Who would protect you from me? He said: Allah will protect me from you. The Companions of the Messenger of Allah (ﷺ) threatened him. He sheathed the sword and hung it up. Then call to prayer was made and he (the Holy Prophet) led a group in two rak'ah. Then (the members of this group) withdrew and he led the second group in two rak'ah. So the Messenger of Allah (ﷺ) observed four rak'ah and people observed two rak'ah}}
\hadithdefcmd{muslim}{1950}{وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ الدَّارِمِيُّ، أَخْبَرَنَا يَحْيَى، - يَعْنِي ابْنَ حَسَّانَ - حَدَّثَنَا مُعَاوِيَةُ، - وَهُوَ ابْنُ سَلاَّمٍ - أَخْبَرَنِي يَحْيَى، أَخْبَرَنِي أَبُو سَلَمَةَ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ جَابِرًا، أَخْبَرَهُ أَنَّهُ، صَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْخَوْفِ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِإِحْدَى الطَّائِفَتَيْنِ رَكْعَتَيْنِ ثُمَّ صَلَّى بِالطَّائِفَةِ الأُخْرَى رَكْعَتَيْنِ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم أَرْبَعَ رَكَعَاتٍ وَصَلَّى بِكُلِّ طَائِفَةٍ رَكْعَتَيْنِ ‏.‏\hadithno{1950}\hadithtrans{Abu Salama b. 'Abd al-Rahman reported that Jabir told him that he had observed the prayer in danger with the Messenger of Allah (ﷺ). The Messenger of Allah (ﷺ) (first) led one of the two groups in two rak'ah of prayer. and then led the second group in two rak'ah of prayer. So the Messenger of Allah (ﷺ) observed four rak'ah and led in two rak'ah each of the groups}}
