% Auto-generated chapter 14 for abudawud
% Hadiths in this chapter: 164

\hadithdefcmd{abudawud}{2313}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ شَبُّويَةَ، حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنِ بْنِ وَاقِدٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا كُتِبَ عَلَيْكُمُ الصِّيَامُ كَمَا كُتِبَ عَلَى الَّذِينَ مِنْ قَبْلِكُمْ ‏\}‏ فَكَانَ النَّاسُ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم إِذَا صَلَّوُا الْعَتَمَةَ حَرُمَ عَلَيْهِمُ الطَّعَامُ وَالشَّرَابُ وَالنِّسَاءُ وَصَامُوا إِلَى الْقَابِلَةِ فَاخْتَانَ رَجُلٌ نَفْسَهُ فَجَامَعَ امْرَأَتَهُ وَقَدْ صَلَّى الْعِشَاءَ وَلَمْ يُفْطِرْ فَأَرَادَ اللَّهُ عَزَّ وَجَلَّ أَنْ يَجْعَلَ ذَلِكَ يُسْرًا لِمَنْ بَقِيَ وَرُخْصَةً وَمَنْفَعَةً فَقَالَ سُبْحَانَهُ ‏\{‏ عَلِمَ اللَّهُ أَنَّكُمْ كُنْتُمْ تَخْتَانُونَ أَنْفُسَكُمْ ‏\}‏ ‏.‏ وَكَانَ هَذَا مِمَّا نَفَعَ اللَّهُ بِهِ النَّاسَ وَرَخَّصَ لَهُمْ وَيَسَّرَ ‏.‏\hadithno{2313}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: Ibn Abbas explained the following Qur'anic verse: "O ye who believe! fasting is prescribed for you as it was prescribed for those before you" During the lifetime of the Prophet (ﷺ), when the people offered night prayer, they were asked to abstain from food and drink and (intercourse with) women, they kept fast till the next night. A man betrayed himself and had intercourse with his wife after he had offered the night prayer, and he did not break his fast. So Allah, the Exalted, intended to make it (fasting) easy for those who survived, thus providing a concession and utility. Allah, the Glorified, said: "Allah knoweth what ye used to do secretly among yourselves." By this Allah benefited the people and provided concession and ease to them}}
\hadithdefcmd{abudawud}{2314}{حَدَّثَنَا نَصْرُ بْنُ عَلِيِّ بْنِ نَصْرٍ الْجَهْضَمِيُّ، أَخْبَرَنَا أَبُو أَحْمَدَ، أَخْبَرَنَا إِسْرَائِيلُ، عَنْ إِسْحَاقَ، عَنِ الْبَرَاءِ، قَالَ كَانَ الرَّجُلُ إِذَا صَامَ فَنَامَ لَمْ يَأْكُلْ إِلَى مِثْلِهَا وَإِنَّ صِرْمَةَ بْنَ قَيْسٍ الأَنْصَارِيَّ أَتَى امْرَأَتَهُ وَكَانَ صَائِمًا فَقَالَ عِنْدَكِ شَىْءٌ قَالَتْ لاَ لَعَلِّي أَذْهَبُ فَأَطْلُبُ لَكَ شَيْئًا ‏.‏ فَذَهَبَتْ وَغَلَبَتْهُ عَيْنُهُ فَجَاءَتْ فَقَالَتْ خَيْبَةً لَكَ ‏.‏ فَلَمْ يَنْتَصِفِ النَّهَارُ حَتَّى غُشِيَ عَلَيْهِ وَكَانَ يَعْمَلُ يَوْمَهُ فِي أَرْضِهِ فَذَكَرَ ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَنَزَلَتْ ‏\{‏ أُحِلَّ لَكُمْ لَيْلَةَ الصِّيَامِ الرَّفَثُ إِلَى نِسَائِكُمْ ‏\}‏ قَرَأَ إِلَى قَوْلِهِ ‏\{‏ مِنَ الْفَجْرِ ‏\}‏ ‏.‏\hadithno{2314}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (1915)}\hadithtrans{Al Bara’ (bin Azib) said “When a man fasted and slept, he could not eat till (another nigh) like it.” Sarmah bin Qais Al Ansari came to his wife while he was fasting and asked her Do you have something (to eat)? She replied “No”. Let me go and seek something for you. So, she went out and sleep overcame him. She came (back) and said (to him) .You are deprived (of food). He fainted before noon. He used to work all day long at his land. This was mentioned to the Prophet (ﷺ). So the following verse was revealed. “Permitted to you on the nights of the fasts, is the approach to your wives. They are your garments and ye are their garments. Allah knoweth what yes used to do secretly amongst yourselves. But he turned to you and forgave you. So now associate with them and seek what Allaah hath ordained for you. And eat and drink until the white thread of dawn appears to you. He recited up to the words “of dawn”}}
\hadithdefcmd{abudawud}{2315}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا بَكْرٌ، - يَعْنِي ابْنَ مُضَرَ - عَنْ عَمْرِو بْنِ الْحَارِثِ، عَنْ بُكَيْرٍ، عَنْ يَزِيدَ، مَوْلَى سَلَمَةَ عَنْ سَلَمَةَ بْنِ الأَكْوَعِ، قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ وَعَلَى الَّذِينَ يُطِيقُونَهُ فِدْيَةٌ طَعَامُ مِسْكِينٍ ‏\}‏ كَانَ مَنْ أَرَادَ مِنَّا أَنْ يُفْطِرَ وَيَفْتَدِيَ فَعَلَ حَتَّى نَزَلَتِ الآيَةُ الَّتِي بَعْدَهَا فَنَسَخَتْهَا ‏.‏\hadithno{2315}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (4507) Sahih Muslim (1145)}\hadithtrans{Salamah bin Al Akwa said “After the revelation of the verse “For those who can do it(with hardship) is a ransom, the feeding of one, that is indigent, is one of us intended to leave fast and pay ransom, he could do so.” until the verse following it was revealed and abrogated the (previous) verse.”}}
\hadithdefcmd{abudawud}{2316}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، ‏\{‏ وَعَلَى الَّذِينَ يُطِيقُونَهُ فِدْيَةٌ طَعَامُ مِسْكِينٍ ‏\}‏ فَكَانَ مَنْ شَاءَ مِنْهُمْ أَنْ يَفْتَدِيَ بِطَعَامِ مِسْكِينٍ افْتَدَى وَتَمَّ لَهُ صَوْمُهُ فَقَالَ ‏\{‏ فَمَنْ تَطَوَّعَ خَيْرًا فَهُوَ خَيْرٌ لَهُ وَأَنْ تَصُومُوا خَيْرٌ لَكُمْ ‏\}‏ وَقَالَ ‏\{‏ فَمَنْ شَهِدَ مِنْكُمُ الشَّهْرَ فَلْيَصُمْهُ وَمَنْ كَانَ مَرِيضًا أَوْ عَلَى سَفَرٍ فَعِدَّةٌ مِنْ أَيَّامٍ أُخَرَ ‏\}‏ ‏.‏\hadithno{2316}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn ‘Abbas explain the Qur’anic verse “For those who can do it(with hardship) is a ransom, the feeding of one, that is indigent” said “If one of them wished to pay ransom by providing food to an indigent person he could pay ransom.. Thus, his fast was complete. Allaah, the Exalted pronounced “But he that will give more of his own free will, it is better for him”. Again he pronounced “So every one of you who is present (at his home) during that month should spend it in fasting.” But, if anyone is ill or on a journey the prescribed period (should be made up) by days later}}
\hadithdefcmd{abudawud}{2317}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، حَدَّثَنَا قَتَادَةُ، أَنَّ عِكْرِمَةَ، حَدَّثَهُ أَنَّ ابْنَ عَبَّاسٍ قَالَ أُثْبِتَتْ لِلْحُبْلَى وَالْمُرْضِعِ ‏.‏\hadithno{2317}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Ibn ‘Abbas said “The verse concerning the payment of ransom stands valid for pregnant and sucking woman.”}}
\hadithdefcmd{abudawud}{2318}{حَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ عَزْرَةَ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، ‏\{‏ وَعَلَى الَّذِينَ يُطِيقُونَهُ فِدْيَةٌ طَعَامُ مِسْكِينٍ ‏\}‏ قَالَ كَانَتْ رُخْصَةً لِلشَّيْخِ الْكَبِيرِ وَالْمَرْأَةِ الْكَبِيرَةِ وَهُمَا يُطِيقَانِ الصِّيَامَ أَنْ يُفْطِرَا وَيُطْعِمَا مَكَانَ كُلِّ يَوْمٍ مِسْكِينًا وَالْحُبْلَى وَالْمُرْضِعُ إِذَا خَافَتَا - قَالَ أَبُو دَاوُدَ يَعْنِي عَلَى أَوْلاَدِهِمَا - أَفْطَرَتَا وَأَطْعَمَتَا ‏.‏\hadithno{2318}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: Explaining the verse; "For those who can do it (with hard-ship) is a ransom, the feeding of one, that is indigent," he said: This was a concession granted to the aged man and woman who were able to keep fast; they were allowed to leave the fast and instead feed an indigent person for each fast; (and a concession) to pregnant and suckling woman when they apprehended harm (to themselves)}}
\hadithdefcmd{abudawud}{2319}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الأَسْوَدِ بْنِ قَيْسٍ، عَنْ سَعِيدِ بْنِ عَمْرٍو، - يَعْنِي ابْنَ سَعِيدِ بْنِ الْعَاصِ - عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّا أُمَّةٌ أُمِّيَّةٌ لاَ نَكْتُبُ وَلاَ نَحْسُبُ الشَّهْرُ هَكَذَا وَ هَكَذَا وَهَكَذَا ‏"‏ ‏.‏ وَخَنَسَ سُلَيْمَانُ أُصْبَعَهُ فِي الثَّالِثَةِ يَعْنِي تِسْعًا وَعِشْرِينَ وَثَلاَثِينَ ‏.‏\hadithno{2319}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1913) Sahih Muslim (108)}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: The month consists of twenty-nine days, but do not fast till you sight it (the moon) and do not break your fast till you sight it. If the weather is cloudy, calculate it thirty days. When the twenty-ninth of Sha'ban came, Ibn Umar would send someone (who tried) to sight the moon for him. If it was sighted, then well and good; in case it was not sighted, and there was no cloud and dust before him (on the horizon), he would not keep fast the next day. If there appeared (on the horizon) before him cloud or dust, he would fast the following day. Ibn Umar would end his fasting alone with the people, and did not follow this calculation}}
\hadithdefcmd{abudawud}{2320}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْعَتَكِيُّ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا أَيُّوبُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الشَّهْرُ تِسْعٌ وَعِشْرُونَ فَلاَ تَصُومُوا حَتَّى تَرَوْهُ وَلاَ تُفْطِرُوا حَتَّى تَرَوْهُ فَإِنْ غُمَّ عَلَيْكُمْ فَاقْدُرُوا لَهُ ثَلاَثِينَ ‏"‏ ‏.‏ قَالَ فَكَانَ ابْنُ عُمَرَ إِذَا كَانَ شَعْبَانُ تِسْعًا وَعِشْرِينَ نُظِرَ لَهُ فَإِنْ رُؤِيَ فَذَاكَ وَإِنْ لَمْ يُرَ وَلَمْ يَحُلْ دُونَ مَنْظَرِهِ سَحَابٌ وَلاَ قَتَرَةٌ أَصْبَحَ مُفْطِرًا فَإِنْ حَالَ دُونَ مَنْظَرِهِ سَحَابٌ أَوْ قَتَرَةٌ أَصْبَحَ صَائِمًا ‏.‏ قَالَ فَكَانَ ابْنُ عُمَرَ يُفْطِرُ مَعَ النَّاسِ وَلاَ يَأْخُذُ بِهَذَا الْحِسَابِ ‏.‏\hadithno{2320}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1080)}\hadithtrans{Ibn ‘Umar reported the Apostle of Allaah(ﷺ) as saying “The month consists of twenty nine days, but do not fast till you sight it (the moon) and do not break your fast till you sight it. If the weather is cloudy, calculate it thirty days. When the twenty-ninth of Sha’ban came, Ibn ‘Umar would send someone (who tried) to sight the moon for him. If it was sighted then well and good, in case it was not sighted and there was no cloud and dust before him (on the horizon) he would not keep fast the next day. If there appeared (on the horizon) before him cloud or dust, he would fast the following day. Ibn ‘Umar would end his fasting alone with the people and did not follow this calculation.”}}
\hadithdefcmd{abudawud}{2321}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا عَبْدُ الْوَهَّابِ، حَدَّثَنِي أَيُّوبُ، قَالَ كَتَبَ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ إِلَى أَهْلِ الْبَصْرَةِ بَلَغَنَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ نَحْوَ حَدِيثِ ابْنِ عُمَرَ عَنِ النَّبِيِّ صلى الله عليه وسلم زَادَ وَإِنَّ أَحْسَنَ مَا يُقَدَّرُ لَهُ إِذَا رَأَيْنَا هِلاَلَ شَعْبَانَ لِكَذَا وَكَذَا فَالصَّوْمُ إِنْ شَاءَ اللَّهُ لِكَذَا وَكَذَا إِلاَّ أَنْ تَرَوُا الْهِلاَلَ قَبْلَ ذَلِكَ ‏.‏\hadithno{2321}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ayyub :'Umar b. 'Abd al-'Aziz wrote (a letter) to the people of Basrah: It has reached us from the Messenger of Allah (ﷺ), like the tradition narrated by Ibn 'Umar from the Prophet (ﷺ). This version adds: The best calculation is that when we sight the moon of Sha'ban on such-and-such date, fasting will being on such-and-such dates, Allah willing, except they they sight the moon before that (date)}}
\hadithdefcmd{abudawud}{2322}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، عَنِ ابْنِ أَبِي زَائِدَةَ، عَنْ عِيسَى بْنِ دِينَارٍ، عَنْ أَبِيهِ، عَنْ عَمْرِو بْنِ الْحَارِثِ بْنِ أَبِي ضِرَارٍ، عَنِ ابْنِ مَسْعُودٍ، قَالَ لَمَا صُمْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم تِسْعًا وَعِشْرِينَ أَكْثَرُ مِمَّا صُمْنَا مَعَهُ ثَلاَثِينَ ‏.‏\hadithno{2322}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Mas'ud: We kept fast for twenty-nine days along with the Prophet (ﷺ) more often than we kept fast for thirty days}}
\hadithdefcmd{abudawud}{2323}{حَدَّثَنَا مُسَدَّدٌ، أَنَّ يَزِيدَ بْنَ زُرَيْعٍ، حَدَّثَهُمْ حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ شَهْرَا عِيدٍ لاَ يَنْقُصَانِ رَمَضَانُ وَذُو الْحِجَّةِ ‏"‏ ‏.‏\hadithno{2323}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1912) Sahih Muslim (1089)}\hadithtrans{Narrated Abu Bakrah:The Prophet (ﷺ) as saying: The two months of 'Id (festival), Ramadan and Dhu al-Hijjah, are not defective}}
\hadithdefcmd{abudawud}{2324}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادٌ، - فِي حَدِيثِ أَيُّوبَ - عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، عَنْ أَبِي هُرَيْرَةَ، ذَكَرَ النَّبِيَّ صلى الله عليه وسلم فِيهِ قَالَ ‏ "‏ وَفِطْرُكُمْ يَوْمَ تُفْطِرُونَ وَأَضْحَاكُمْ يَوْمَ تُضَحُّونَ وَكُلُّ عَرَفَةَ مَوْقِفٌ وَكُلُّ مِنًى مَنْحَرٌ وَكُلُّ فِجَاجِ مَكَّةَ مَنْحَرٌ وَكُلُّ جَمْعٍ مَوْقِفٌ ‏"‏ ‏.‏\hadithno{2324}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: The end of Ramadan is on the day when you end it, and the 'Id (festival) of sacrifice is on the day when you sacrifice. The whole of Arafah is the place of staying, and the whole of Mina is the place of sacrifice, and all the roads of Mecca are the place of sacrifice, and the whole of Muzdalifah is the place of staying}}
\hadithdefcmd{abudawud}{2325}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنِي مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَيْسٍ، قَالَ سَمِعْتُ عَائِشَةَ، - رضى الله عنها - تَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَتَحَفَّظُ مِنْ شَعْبَانَ مَا لاَ يَتَحَفَّظُ مِنْ غَيْرِهِ ثُمَّ يَصُومُ لِرُؤْيَةِ رَمَضَانَ فَإِنْ غُمَّ عَلَيْهِ عَدَّ ثَلاَثِينَ يَوْمًا ثُمَّ صَامَ ‏.‏\hadithno{2325}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) used to count the days in Sha'ban in a manner he did not count any other month; then he fasted when he sighted the new moon of Ramadan; but if the weather was cloudy he counted thirty days and then fasted}}
\hadithdefcmd{abudawud}{2326}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّازُ، حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ الضَّبِّيُّ، عَنْ مَنْصُورِ بْنِ الْمُعْتَمِرِ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ حُذَيْفَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُقَدِّمُوا الشَّهْرَ حَتَّى تَرَوُا الْهِلاَلَ أَوْ تُكْمِلُوا الْعِدَّةَ ثُمَّ صُومُوا حَتَّى تَرَوُا الْهِلاَلَ أَوْ تُكْمِلُوا الْعِدَّةَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ سُفْيَانُ وَغَيْرُهُ عَنْ مَنْصُورٍ عَنْ رِبْعِيٍّ عَنْ رَجُلٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم لَمْ يُسَمِّ حُذَيْفَةَ ‏.‏\hadithno{2326}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Hudhayfah: The Prophet (ﷺ) said: Do not fast (for Ramadan) before the coming of the month until you sight the moon or complete the number (of thirty days); then fast until you sight the moon or complete the number (of thirty days)}}
\hadithdefcmd{abudawud}{2327}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا حُسَيْنٌ، عَنْ زَائِدَةَ، عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تُقَدِّمُوا الشَّهْرَ بِصِيَامِ يَوْمٍ وَلاَ يَوْمَيْنِ إِلاَّ أَنْ يَكُونَ شَىْءٌ يَصُومُهُ أَحَدُكُمْ وَلاَ تَصُومُوا حَتَّى تَرَوْهُ ثُمَّ صُومُوا حَتَّى تَرَوْهُ فَإِنْ حَالَ دُونَهُ غَمَامَةٌ فَأَتِمُّوا الْعِدَّةَ ثَلاَثِينَ ثُمَّ أَفْطِرُوا وَ الشَّهْرُ تِسْعٌ وَعِشْرُونَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ حَاتِمُ بْنُ أَبِي صَغِيرَةَ وَشُعْبَةُ وَالْحَسَنُ بْنُ صَالِحٍ عَنْ سِمَاكٍ بِمَعْنَاهُ لَمْ يَقُولُوا ‏"‏ ثُمَّ أَفْطِرُوا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهُوَ حَاتِمُ بْنُ مُسْلِمِ بْنِ أَبِي صَغِيرَةَ وَأَبُو صَغِيرَةَ زَوْجُ أُمِّهِ ‏.‏\hadithno{2327}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: Do not fast one day or two days just before Ramadan except in the case of a man who has been in the habit or observing a fast (on that day); and do not fast until you sight it (the moon). Then fast until you sight it. If a cloud appears on that day (i.e. 29th of Ramadan) then complete the number thirty (days) and then end the fasting: a month consists of twenty-nine days}}
\hadithdefcmd{abudawud}{2328}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ، عَنْ مُطَرِّفٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، وَسَعِيدٍ الْجُرَيْرِيِّ، عَنْ أَبِي الْعَلاَءِ، عَنْ مُطَرِّفٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِرَجُلٍ ‏"‏ هَلْ صُمْتَ مِنْ سَرَرِ شَعْبَانَ شَيْئًا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَإِذَا أَفْطَرْتَ فَصُمْ يَوْمًا ‏"‏ ‏.‏ وَقَالَ أَحَدُهُمَا ‏"‏ يَوْمَيْنِ ‏"‏ ‏.‏\hadithno{2328}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1983) Sahih Muslim (1161)}\hadithtrans{Narrated 'Imran bin Husain:The Messenger of Allah (ﷺ) asked a man: Did you fast the last day of Sha'ban ? He replied: No. He said: If you did not observe a fast, you must fast for a day. One of the two narrators said: For two days}}
\hadithdefcmd{abudawud}{2329}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْعَلاَءِ الزُّبَيْدِيُّ، مِنْ كِتَابِهِ حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْعَلاَءِ، عَنْ أَبِي الأَزْهَرِ الْمُغِيرَةِ بْنِ فَرْوَةَ، قَالَ قَامَ مُعَاوِيَةُ فِي النَّاسِ بِدَيْرِ مِسْحَلٍ الَّذِي عَلَى بَابِ حِمْصَ فَقَالَ يَا أَيُّهَا النَّاسُ إِنَّا قَدْ رَأَيْنَا الْهِلاَلَ يَوْمَ كَذَا وَكَذَا وَأَنَا مُتَقَدِّمٌ بِالصِّيَامِ فَمَنْ أَحَبَّ أَنْ يَفْعَلَهُ فَلْيَفْعَلْهُ ‏.‏ قَالَ فَقَامَ إِلَيْهِ مَالِكُ بْنُ هُبَيْرَةَ السَّبَئِيُّ فَقَالَ يَا مُعَاوِيَةُ أَشَىْءٌ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَمْ شَىْءٌ مِنْ رَأْيِكَ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ صُومُوا الشَّهْرَ وَسِرَّهُ ‏"‏ ‏.‏\hadithno{2329}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Mu'awiyah: AbulAzhar al-Mughirah ibn Farwah said: Mu'awiyah stood among the people at Dayr Mustahill lying at the gate of Hims. He said: O people, we sighted the moon on such-and-such day. We shall fast in advance. Anyone who likes to do so may do it. Malik ibn Hubayrah as-Saba'i stood up and asked: Mu'awiyah, did you hear the Messenger of Allah (ﷺ) say something (about this matter), or is this something on the basis of your opinion? He replied: I heard the Messenger of Allah (ﷺ) as saying: Fast the month (in the beginning) and in the last}}
\hadithdefcmd{abudawud}{2330}{حَدَّثَنَا سُلَيْمَانُ بْنُ عَبْدِ الرَّحْمَنِ الدِّمَشْقِيُّ، - فِي هَذَا الْحَدِيثِ - قَالَ قَالَ الْوَلِيدُ سَمِعْتُ أَبَا عَمْرٍو - يَعْنِي الأَوْزَاعِيَّ - يَقُولُ سِرُّهُ أَوَّلُهُ ‏.‏\hadithno{2330}\hadithgrade{Al-Albani: Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Maqtu; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Sulaiman b. 'Abd al-Rahman al-Dimashqi said about this tradition that al-Walid said:I heard Abu 'Amr al-Auza'i say: The word sirrahu means beginning of the month}}
\hadithdefcmd{abudawud}{2331}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ الْوَاحِدِ، حَدَّثَنَا أَبُو مُسْهِرٍ، قَالَ كَانَ سَعِيدٌ - يَعْنِي ابْنَ عَبْدِ الْعَزِيزِ - يَقُولُ سِرُّهُ أَوَّلُهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَقَالَ بَعْضُهُمْ سِرُّهُ وَسَطُهُ وَقَالُوا آخِرُهُ ‏.‏\hadithno{2331}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ahmad b. 'Abd al-Wahid:On the authority of Abu Mushir. He said: Sa'id, that is, Ibn 'Abd al-'Aziz said: The meaning of the word sirraha is "in the beginning of it (the month)}}
\hadithdefcmd{abudawud}{2332}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ جَعْفَرٍ - أَخْبَرَنِي مُحَمَّدُ بْنُ أَبِي حَرْمَلَةَ، أَخْبَرَنِي كُرَيْبٌ، أَنَّ أُمَّ الْفَضْلِ ابْنَةَ الْحَارِثِ، بَعَثَتْهُ إِلَى مُعَاوِيَةَ بِالشَّامِ قَالَ فَقَدِمْتُ الشَّامَ فَقَضَيْتُ حَاجَتَهَا فَاسْتُهِلَّ رَمَضَانُ وَأَنَا بِالشَّامِ فَرَأَيْنَا الْهِلاَلَ لَيْلَةَ الْجُمُعَةِ ثُمَّ قَدِمْتُ الْمَدِينَةَ فِي آخِرِ الشَّهْرِ فَسَأَلَنِي ابْنُ عَبَّاسٍ ثُمَّ ذَكَرَ الْهِلاَلَ فَقَالَ مَتَى رَأَيْتُمُ الْهِلاَلَ قُلْتُ رَأَيْتُهُ لَيْلَةَ الْجُمُعَةِ ‏.‏ قَالَ أَنْتَ رَأَيْتَهُ قُلْتُ نَعَمْ وَرَآهُ النَّاسُ وَصَامُوا وَصَامَ مُعَاوِيَةُ ‏.‏ قَالَ لَكِنَّا رَأَيْنَاهُ لَيْلَةَ السَّبْتِ فَلاَ نَزَالُ نَصُومُهُ حَتَّى نُكْمِلَ الثَّلاَثِينَ أَوْ نَرَاهُ ‏.‏ فَقُلْتُ أَفَلاَ تَكْتَفِي بِرُؤْيَةِ مُعَاوِيَةَ وَصِيَامِهِ قَالَ لاَ هَكَذَا أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2332}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (1087)}\hadithtrans{Narrated Kuraib:That Umm al-Fadl, daughter of al-Harith, sent him to Mu'aqiyah in Syria. He said: I came to syria and performed her work. The moon of Ramadan appeared while I was in Syria. We sighted the moon on the night of Friday. When I came to Median towards the end of the month (of Ramadan), Ibn 'Abbas asked me about the moon. He said: When did you sight the moon ? I said: I sighted it on the night of Friday. He asked: Did you sight it yourself ? I said: Yes, and the people sighted it. They fasted and Mu'awiyah also fasted. He said: But we sighted it on the night of saturday. Since then we have been fasting until we complete thirty days or we sight it. Then I said: Are the sighting of the moon by Mu'awiyah and his fasts not sufficient for us? He replied: No. The Messenger of Allah (ﷺ) commanded us to do so}}
\hadithdefcmd{abudawud}{2333}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ، حَدَّثَنِي أَبِي، حَدَّثَنَا الأَشْعَثُ، عَنِ الْحَسَنِفِي رَجُلٍ كَانَ بِمِصْرٍ مِنَ الأَمْصَارِ فَصَامَ يَوْمَ الاِثْنَيْنِ وَشَهِدَ رَجُلاَنِ أَنَّهُمَا رَأَيَا الْهِلاَلَ لَيْلَةَ الأَحَدِ فَقَالَ لاَ يَقْضِي ذَلِكَ الْيَوْمَ الرَّجُلُ وَلاَ أَهْلُ مِصْرِهِ إِلاَّ أَنْ يَعْلَمُوا أَنَّ أَهْلَ مِصْرٍ مِنْ أَمْصَارِ الْمُسْلِمِينَ قَدْ صَامُوا يَوْمَ الأَحَدِ فَيَقْضُونَهُ ‏.‏\hadithno{2333}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Shuaib Al Arnaut: Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Al-Hasan said about a person who was in a certain city. He fasted on Monday, and twp persons bore witness that they had sighted the moon on the night of sunday. He said:That man and the people of his city should not fast as an atonement except that they know (for certain) that the people of a certain city of Muslims had fasted on Sunday. In that case they should keep fast as an atonement}}
\hadithdefcmd{abudawud}{2334}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنْ عَمْرِو بْنِ قَيْسٍ، عَنْ أَبِي إِسْحَاقَ، عَنْ صِلَةَ، قَالَ كُنَّا عِنْدَ عَمَّارٍ فِي الْيَوْمِ الَّذِي يُشَكُّ فِيهِ فَأُتِيَ بِشَاةٍ فَتَنَحَّى بَعْضُ الْقَوْمِ فَقَالَ عَمَّارٌ مَنْ صَامَ هَذَا الْيَوْمَ فَقَدْ عَصَى أَبَا الْقَاسِمِ صلى الله عليه وسلم ‏.‏\hadithno{2334}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ammar: AbuIshaq reported on the authority of Silah: We were with Ammar on the day when the appearance of the moon was doubtful. (The meat of) goat was brought to him. Some people kept aloof from (eating) it. Ammar said: He who keeps fast on this day disobeys AbulQasim (i.e. the Prophet) (ﷺ)}}
\hadithdefcmd{abudawud}{2335}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقَدَّمُوا صَوْمَ رَمَضَانَ بِيَوْمٍ وَلاَ يَوْمَيْنِ إِلاَّ أَنْ يَكُونَ صَوْمًا يَصُومُهُ رَجُلٌ فَلْيَصُمْ ذَلِكَ الصَّوْمَ ‏"‏ ‏.‏\hadithno{2335}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1914) Sahih Muslim (1082)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: Do not fast one day or two days just before Ramadan, except in the case of a man who has been in the habit of observing the particular fast, for he may fast on that day}}
\hadithdefcmd{abudawud}{2336}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ تَوْبَةَ الْعَنْبَرِيِّ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ لَمْ يَكُنْ يَصُومُ مِنَ السَّنَةِ شَهْرًا تَامًّا إِلاَّ شَعْبَانَ يَصِلُهُ بِرَمَضَانَ ‏.‏\hadithno{2336}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: She never saw the Prophet (ﷺ) fasting the whole month except Sha'ban which he combined with Ramadan}}
\hadithdefcmd{abudawud}{2337}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، قَالَ قَدِمَ عَبَّادُ بْنُ كَثِيرٍ الْمَدِينَةَ فَمَالَ إِلَى مَجْلِسِ الْعَلاَءِ فَأَخَذَ بِيَدِهِ فَأَقَامَهُ ثُمَّ قَالَ اللَّهُمَّ إِنَّ هَذَا يُحَدِّثُ عَنْ أَبِيهِ عَنْ أَبِي هُرَيْرَةَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا انْتَصَفَ شَعْبَانُ فَلاَ تَصُومُوا ‏"‏ ‏.‏ فَقَالَ الْعَلاَءُ اللَّهُمَّ إِنَّ أَبِي حَدَّثَنِي عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم بِذَلِكَ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ الثَّوْرِيُّ وَشِبْلُ بْنُ الْعَلاَءِ وَأَبُو عُمَيْسٍ وَزُهَيْرُ بْنُ مُحَمَّدٍ عَنِ الْعَلاَءِ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَانَ عَبْدُ الرَّحْمَنِ لاَ يُحَدِّثُ بِهِ قُلْتُ لأَحْمَدَ لِمَ قَالَ لأَنَّهُ كَانَ عِنْدَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَصِلُ شَعْبَانَ بِرَمَضَانَ وَقَالَ عَنِ النَّبِيِّ صلى الله عليه وسلم خِلاَفَهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَلَيْسَ هَذَا عِنْدِي خِلاَفَهُ وَلَمْ يَجِئْ بِهِ غَيْرُ الْعَلاَءِ عَنْ أَبِيهِ ‏.‏\hadithno{2337}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: AbdulAziz ibn Muhammad said: Abbad ibn Kathir came to Medina and went to the assembly of al-Ala'. He caught hold of his hand and made him stand and said: O Allah, he narrates a tradition from his father on the authority of AbuHurayrah who reported the Messenger of Allah (ﷺ) as saying: When the middle of Sha'ban comes, do not fast. Al-Ala' said: O Allah, my father narrated this tradition on the authority of AbuHurayrah from the Prophet (ﷺ)}}
\hadithdefcmd{abudawud}{2338}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحِيمِ أَبُو يَحْيَى الْبَزَّازُ، حَدَّثَنَا سَعِيدُ بْنُ سُلَيْمَانَ، حَدَّثَنَا عَبَّادٌ، عَنْ أَبِي مَالِكٍ الأَشْجَعِيِّ، حَدَّثَنَا حُسَيْنُ بْنُ الْحَارِثِ الْجَدَلِيُّ، - مِنْ جَدِيلَةِ قَيْسٍ أَنَّ أَمِيرَ مَكَّةَ خَطَبَ ثُمَّ قَالَ عَهِدَ إِلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَنْسُكَ لِلرُّؤْيَةِ فَإِنْ لَمْ نَرَهُ وَشَهِدَ شَاهِدَا عَدْلٍ نَسَكْنَا بِشَهَادَتِهِمَا فَسَأَلْتُ الْحُسَيْنَ بْنَ الْحَارِثِ مَنْ أَمِيرُ مَكَّةَ قَالَ لاَ أَدْرِي ‏.‏ ثُمَّ لَقِيَنِي بَعْدُ فَقَالَ هُوَ الْحَارِثُ بْنُ حَاطِبٍ أَخُو مُحَمَّدِ بْنِ حَاطِبٍ ثُمَّ قَالَ الأَمِيرُ إِنَّ فِيكُمْ مَنْ هُوَ أَعْلَمُ بِاللَّهِ وَرَسُولِهِ مِنِّي وَشَهِدَ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ وَأَوْمَأَ بِيَدِهِ إِلَى رَجُلٍ قَالَ الْحُسَيْنُ فَقُلْتُ لِشَيْخٍ إِلَى جَنْبِي مَنْ هَذَا الَّذِي أَوْمَأَ إِلَيْهِ الأَمِيرُ قَالَ هَذَا عَبْدُ اللَّهِ بْنُ عُمَرَ ‏.‏ وَصَدَقَ كَانَ أَعْلَمَ بِاللَّهِ مِنْهُ فَقَالَ بِذَلِكَ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2338}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Umar: Husayn ibn al-Harith al-Jadli from the tribe of Jadilah Qays said: The governor of Mecca delivered a speech and said: The Messenger of Allah (ﷺ) took a pledge from us that we should perform the rites of hajj after sighting the moon. If we do not sight it and two reliable persons bear witness, we should perform the rites of hajj on the basis of their witness. I then asked al-Husayn ibn al-Harith: Who was the governor of Mecca? He replied: I do not know. He then met me later on and told me: He was al-Harith ibn Hatib, brother of Muhammad ibn Hatib. The governor then said: There is among you a man who is more acquainted with Allah and His Apostle than I. He witnessed this from the Messenger of Allah (ﷺ). He then pointed with his hand to a man. Al-Husayn said: I asked an old man beside me: Who is that man to whom the governor has alluded? He said: "This is Abdullah ibn Umar, and he spoke the truth. He was more acquainted with Allah than he. He (Abdullah ibn Umar) said: For this is what the Messenger of Allah (ﷺ) commanded us (to do)}}
\hadithdefcmd{abudawud}{2339}{حَدَّثَنَا مُسَدَّدٌ، وَخَلَفُ بْنُ هِشَامٍ الْمُقْرِئُ، قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيِّ بْنِ حِرَاشٍ، عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ اخْتَلَفَ النَّاسُ فِي آخِرِ يَوْمٍ مِنْ رَمَضَانَ فَقَدِمَ أَعْرَابِيَّانِ فَشَهِدَا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِاللَّهِ لأَهَلاَّ الْهِلاَلَ أَمْسِ عَشِيَّةً فَأَمَرَ رَسُولُ اللَّهِ صلى الله عليه وسلم النَّاسَ أَنْ يُفْطِرُوا زَادَ خَلَفٌ فِي حَدِيثِهِ وَأَنْ يَغْدُوا إِلَى مُصَلاَّهُمْ ‏.‏\hadithno{2339}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Rib'i b. Hirash:On the authority of a man from the Companions of the Prophet (ﷺ): People differed among themselves on the last day of Ramadan (about the appearance of the moon of Shawwal). Then two bedouins came and witnessed before the Prophet (ﷺ) swearing by Allah that they had sighted moon the previous evening. So the Messenger of Allah (ﷺ) commanded the people to break the fast. The narrator Khalaf has added in his version: "and that they should proceed to the place of prayer (for 'Id)}}
\hadithdefcmd{abudawud}{2340}{حَدَّثَنَا مُحَمَّدُ بْنُ بَكَّارِ بْنِ الرَّيَّانِ، حَدَّثَنَا الْوَلِيدُ، - يَعْنِي ابْنَ أَبِي ثَوْرٍ ح وَحَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا الْحُسَيْنُ، - يَعْنِي الْجُعْفِيَّ - عَنْ زَائِدَةَ، - الْمَعْنَى - عَنْ سِمَاكٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنِّي رَأَيْتُ الْهِلاَلَ - قَالَ الْحَسَنُ فِي حَدِيثِهِ يَعْنِي رَمَضَانَ - فَقَالَ ‏"‏ أَتَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ أَتَشْهَدُ أَنَّ مُحَمَّدًا رَسُولُ اللَّهِ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ يَا بِلاَلُ أَذِّنْ فِي النَّاسِ فَلْيَصُومُوا غَدًا ‏"‏ ‏.‏\hadithno{2340}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: A bedouin came to the Prophet (ﷺ) and said: I have sighted the moon. Al-Hasan added in his version: that is, of Ramadan. He asked: Do you testify that there is no god but Allah? He replied: Yes. He again asked: Do you testify that Muhammad is the Messenger of Allah? He replied: Yes. and he testified that he had sighted the moon. He said: Bilal, announce to the people that they must fast tomorrow}}
\hadithdefcmd{abudawud}{2341}{حَدَّثَنِي مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ عِكْرِمَةَ، أَنَّهُمْ شَكُّوا فِي هِلاَلِ رَمَضَانَ مَرَّةً فَأَرَادُوا أَنْ لاَ يَقُومُوا وَلاَ يَصُومُوا فَجَاءَ أَعْرَابِيٌّ مِنَ الْحَرَّةِ فَشَهِدَ أَنَّهُ رَأَى الْهِلاَلَ فَأُتِيَ بِهِ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَتَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَنِّي رَسُولُ اللَّهِ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ وَشَهِدَ أَنَّهُ رَأَى الْهِلاَلَ فَأَمَرَ بِلاَلاً فَنَادَى فِي النَّاسِ أَنْ يَقُومُوا وَأَنْ يَصُومُوا ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ جَمَاعَةٌ عَنْ سِمَاكٍ عَنْ عِكْرِمَةَ مُرْسَلاً وَلَمْ يَذْكُرِ الْقِيَامَ أَحَدٌ إِلاَّ حَمَّادُ بْنُ سَلَمَةَ ‏.‏\hadithno{2341}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ikrimah: Once the people doubted the appearance of the moon of Ramadan, and intended neither to offer the tarawih prayer nor to keep fast. A bedouin came from al-Harrah and testified that he had sighted the moon. He was brought to the Prophet (ﷺ). He asked: Do you testify that there is no god but Allah, and that I am the Messenger of Allah? He said: Yes; and he testified that he had sighted the moon. He commanded Bilal who announced to the people to offer the tarawih prayer and to keep fast}}
\hadithdefcmd{abudawud}{2342}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، وَعَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ السَّمَرْقَنْدِيُّ، - وَأَنَا لِحَدِيثِهِ، أَتْقَنُ - قَالاَ حَدَّثَنَا مَرْوَانُ، - هُوَ ابْنُ مُحَمَّدٍ - عَنْ عَبْدِ اللَّهِ بْنِ وَهْبٍ، عَنْ يَحْيَى بْنِ عَبْدِ اللَّهِ بْنِ سَالِمٍ، عَنْ أَبِي بَكْرِ بْنِ نَافِعٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عُمَرَ، قَالَ تَرَاءَى النَّاسُ الْهِلاَلَ فَأَخْبَرْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنِّي رَأَيْتُهُ فَصَامَهُ وَأَمَرَ النَّاسَ بِصِيَامِهِ ‏.‏\hadithno{2342}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Umar: The people looked for the moon, so I informed the Messenger of Allah (ﷺ) that I had sighted it. He fasted and commanded the people to fast}}
\hadithdefcmd{abudawud}{2343}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، عَنْ مُوسَى بْنِ عُلَىِّ بْنِ رَبَاحٍ، عَنْ أَبِيهِ، عَنْ أَبِي قَيْسٍ، مَوْلَى عَمْرِو بْنِ الْعَاصِ عَنْ عَمْرِو بْنِ الْعَاصِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ فَصْلَ مَا بَيْنَ صِيَامِنَا وَصِيَامِ أَهْلِ الْكِتَابِ أَكْلَةُ السَّحَرِ ‏"‏ ‏.‏\hadithno{2343}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (1096)}\hadithtrans{Narrated 'Amr b. al-'As:The Messenger of Allah (ﷺ) as saying: The difference between our fasting and that of the people of the Book is eating shortly before dawn}}
\hadithdefcmd{abudawud}{2344}{حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ النَّاقِدُ، حَدَّثَنَا حَمَّادُ بْنُ خَالِدٍ الْخَيَّاطُ، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ يُونُسَ بْنِ سَيْفٍ، عَنِ الْحَارِثِ بْنِ زِيَادٍ، عَنْ أَبِي رُهْمٍ، عَنِ الْعِرْبَاضِ بْنِ سَارِيَةَ، قَالَ دَعَانِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى السَّحُورِ فِي رَمَضَانَ فَقَالَ ‏ "‏ هَلُمَّ إِلَى الْغَدَاءِ الْمُبَارَكِ ‏"‏ ‏.‏\hadithno{2344}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Al-Irbad ibn Sariyyah: The Messenger of Allah (ﷺ) invited me to a meal shortly before dawn in Ramadan saying: Come to the blessed morning meal}}
\hadithdefcmd{abudawud}{2345}{حَدَّثَنَا عُمَرُ بْنُ الْحَسَنِ بْنِ إِبْرَاهِيمَ، حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي الْوَزِيرِ أَبُو الْمُطَرِّفِ، حَدَّثَنَا مُحَمَّدُ بْنُ مُوسَى، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ نِعْمَ سَحُورُ الْمُؤْمِنِ التَّمْرُ ‏"‏ ‏.‏\hadithno{2345}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah:The Prophet (ﷺ) as saying: How good is the believers meal of dates shortly before dawn}}
\hadithdefcmd{abudawud}{2346}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ سَوَادَةَ الْقُشَيْرِيِّ، عَنْ أَبِيهِ، قَالَ سَمِعْتُ سَمُرَةَ بْنَ جُنْدُبٍ، يَخْطُبُ وَهُوَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَمْنَعَنَّ مِنْ سَحُورِكُمْ أَذَانُ بِلاَلٍ وَلاَ بَيَاضُ الأُفُقِ الَّذِي هَكَذَا حَتَّى يَسْتَطِيرَ ‏"‏ ‏.‏\hadithno{2346}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1094)}\hadithtrans{Addressing (the people) Samurah b. Jundub reported the Messenger of Allah (ﷺ) as saying:The adhan (call to prayer) of Bilal should not prevent you from taking a meal shortly before dawn, not does the whiteness of horizon (before dawn) in this way (vertically) until it spreads out horizontally}}
\hadithdefcmd{abudawud}{2347}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ التَّيْمِيِّ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَمْنَعَنَّ أَحَدَكُمْ أَذَانُ بِلاَلٍ مِنْ سَحُورِهِ فَإِنَّهُ يُؤَذِّنُ - أَوْ قَالَ يُنَادِي - لِيَرْجِعَ قَائِمُكُمْ وَيَنْتَبِهَ نَائِمُكُمْ وَلَيْسَ الْفَجْرُ أَنْ يَقُولَ هَكَذَا ‏"‏ ‏.‏ قَالَ مُسَدَّدٌ وَجَمَعَ يَحْيَى كَفَّيْهِ حَتَّى يَقُولَ هَكَذَا وَمَدَّ يَحْيَى بِأُصْبَعَيْهِ السَّبَّابَتَيْنِ ‏.‏\hadithno{2347}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (621) Sahih Muslim (1093)}\hadithtrans{Narrated 'Abd Allah b. Mas'ud:The Messenger of Allah (ﷺ) as saying: The summons (adhan) of Bilal should not restrain one of you from taking a meal shortly before dawn, for he utters adhan or calls (for prayer) so that the man at prayer may return, and the man asleep may get up. Dawn is not (the whiteness) which indicates thus (in perpendicular) - the narrator Musaddad said: Yahya joined his palms (indicating the spread of whiteness vertically - until it indicates thus - and Yahya spread out two ring-fingers of his (demonstrating the spread of whiteness horizontally)l}}
\hadithdefcmd{abudawud}{2348}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا مُلاَزِمُ بْنُ عَمْرٍو، عَنْ عَبْدِ اللَّهِ بْنِ النُّعْمَانِ، حَدَّثَنِي قَيْسُ بْنُ طَلْقٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُلُوا وَاشْرَبُوا وَلاَ يَهِيدَنَّكُمُ السَّاطِعُ الْمُصْعِدُ فَكُلُوا وَاشْرَبُوا حَتَّى يَعْتَرِضَ لَكُمُ الأَحْمَرُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا مِمَّا تَفَرَّدَ بِهِ أَهْلُ الْيَمَامَةِ ‏.‏\hadithno{2348}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Talq ibn Ali al-Yamami: The Messenger of Allah (ﷺ) said: Eat and drink; let not the white and ascending light prevent you from (eating and drinking); so eat and drink until the red light spreads horizontally}}
\hadithdefcmd{abudawud}{2349}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا حُصَيْنُ بْنُ نُمَيْرٍ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ إِدْرِيسَ، - الْمَعْنَى - عَنْ حُصَيْنٍ، عَنِ الشَّعْبِيِّ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ لَمَّا نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ حَتَّى يَتَبَيَّنَ لَكُمُ الْخَيْطُ الأَبْيَضُ مِنَ الْخَيْطِ الأَسْوَدِ ‏\}‏ ‏.‏ قَالَ أَخَذْتُ عِقَالاً أَبْيَضَ وَعِقَالاً أَسْوَدَ فَوَضَعْتُهُمَا تَحْتَ وِسَادَتِي فَنَظَرْتُ فَلَمْ أَتَبَيَّنْ فَذَكَرْتُ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَضَحِكَ فَقَالَ ‏"‏ إِنَّ وِسَادَكَ لَعَرِيضٌ طَوِيلٌ إِنَّمَا هُوَ اللَّيْلُ وَالنَّهَارُ ‏"‏ ‏.‏ قَالَ عُثْمَانُ ‏"‏ إِنَّمَا هُوَ سَوَادُ اللَّيْلِ وَبَيَاضُ النَّهَارِ ‏"‏ ‏.‏\hadithno{2349}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1916) Sahih Muslim (1090)}\hadithtrans{Narrated 'Adi b. Hatim:When the verse "Until the white thread of dawn appear to you distinct from its black thread" was revealed, I took a white rope and a black rope, and placed them beneath my pillow ; and then I looked at them, byt they were not clear to me. So I mentioned it to the Messenger of Allah (ﷺ). He laughed and said: Your pillow is so broad and lengthy ; that is (i.e. means) night and day. The version of the narrator 'Uthman has: That is the blackness of night and whiteness of day}}
\hadithdefcmd{abudawud}{2350}{حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا سَمِعَ أَحَدُكُمُ النِّدَاءَ وَالإِنَاءُ عَلَى يَدِهِ فَلاَ يَضَعْهُ حَتَّى يَقْضِيَ حَاجَتَهُ مِنْهُ ‏"‏ ‏.‏\hadithno{2350}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: When any of you hears the summons to prayer while he has a vessel in his hand, he should not lay it down till he fulfils his need}}
\hadithdefcmd{abudawud}{2351}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامٌ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ دَاوُدَ، عَنْ هِشَامٍ، - الْمَعْنَى - قَالَ هِشَامُ بْنُ عُرْوَةَ عَنْ أَبِيهِ، عَنْ عَاصِمِ بْنِ عُمَرَ، عَنْ أَبِيهِ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِذَا جَاءَ اللَّيْلُ مِنْ هَا هُنَا وَذَهَبَ النَّهَارُ مِنْ هَا هُنَا ‏"‏ ‏.‏ زَادَ مُسَدَّدٌ ‏"‏ وَغَابَتِ الشَّمْسُ فَقَدْ أَفْطَرَ الصَّائِمُ ‏"‏ ‏.‏\hadithno{2351}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1954) Sahih Muslim (1100)}\hadithtrans{Narrated 'Umar:The Prophet (ﷺ) as saying: When the night approaches from this side and the day retreats on that side, and the sun sets - according to the version of Musaddad - he who fasts has reached the time to break it}}
\hadithdefcmd{abudawud}{2352}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ، حَدَّثَنَا سُلَيْمَانُ الشَّيْبَانِيُّ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى، يَقُولُ سِرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ صَائِمٌ فَلَمَّا غَرَبَتِ الشَّمْسُ قَالَ ‏"‏ يَا بِلاَلُ انْزِلْ فَاجْدَحْ لَنَا ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ لَوْ أَمْسَيْتَ ‏.‏ قَالَ ‏"‏ انْزِلْ فَاجْدَحْ لَنَا ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ إِنَّ عَلَيْكَ نَهَارًا ‏.‏ قَالَ ‏"‏ انْزِلْ فَاجْدَحْ لَنَا ‏"‏ ‏.‏ فَنَزَلَ فَجَدَحَ فَشَرِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ إِذَا رَأَيْتُمُ اللَّيْلَ قَدْ أَقْبَلَ مِنْ هَا هُنَا فَقَدْ أَفْطَرَ الصَّائِمُ ‏"‏ ‏.‏ وَأَشَارَ بِأُصْبُعِهِ قِبَلَ الْمَشْرِقِ ‏.‏\hadithno{2352}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1955) Sahih Muslim (1101)}\hadithtrans{Narrated 'Abd Allah b. Abi Awfa:We went along with the Messenger of Allah (ﷺ) while he was fasting. When the sun set, he said to Bilal: Bilal, come down and prepare barley beverage for us. He said: Messenger of Allah, would that you waited for the evening. He said: Come down and prepare barley beverage for us. He said: Messenger of Allah, the say still remains on you (i.e. there remains the brightness of the day). He said: Come down and prepare barley drink for us. So he came down and prepared barley drink. The Messenger of Allah (ﷺ) drank it and said: When you see that the night approaches from this side, he who fasts has reached the time to break it ; and he pointed to the east with his finger}}
\hadithdefcmd{abudawud}{2353}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، عَنْ مُحَمَّدٍ، - يَعْنِي ابْنَ عَمْرٍو - عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَزَالُ الدِّينُ ظَاهِرًا مَا عَجَّلَ النَّاسُ الْفِطْرَ لأَنَّ الْيَهُودَ وَالنَّصَارَى يُؤَخِّرُونَ ‏"‏ ‏.‏\hadithno{2353}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: Religion will continue to prevail as long as people hasten to break the fast, because the Jews and the Christians delay doing so}}
\hadithdefcmd{abudawud}{2354}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنْ أَبِي عَطِيَّةَ، قَالَ دَخَلْتُ عَلَى عَائِشَةَ - رضى الله عنها - أَنَا وَمَسْرُوقٌ فَقُلْنَا يَا أُمَّ الْمُؤْمِنِينَ رَجُلاَنِ مِنْ أَصْحَابِ مُحَمَّدٍ صلى الله عليه وسلم أَحَدُهُمَا يُعَجِّلُ الإِفْطَارَ وَيُعَجِّلُ الصَّلاَةَ وَالآخَرُ يُؤَخِّرُ الإِفْطَارَ وَيُؤَخِّرُ الصَّلاَةَ قَالَتْ أَيُّهُمَا يُعَجِّلُ الإِفْطَارَ وَيُعَجِّلُ الصَّلاَةَ قُلْنَا عَبْدُ اللَّهِ ‏.‏ قَالَتْ كَذَلِكَ كَانَ يَصْنَعُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2354}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1099)}\hadithtrans{Narrated Abu 'Atiyyah:I and Masruq entered upon 'Aishah and we said: Mother of believers, there are two persons from the Companions of the Muhammad (ﷺ). One of them hastens to break the fast and hastens to pray while the other delays to break the fast and delays praying. She asked: Which of them hastens to break the fast and hasten to pray ? We replied: 'Abd Allah (b. Mas'ud). She said: Thus did the Messenger of Allah (ﷺ) do}}
\hadithdefcmd{abudawud}{2355}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنِ الرَّبَابِ، عَنْ سَلْمَانَ بْنِ عَامِرٍ، عَمِّهَا قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ أَحَدُكُمْ صَائِمًا فَلْيُفْطِرْ عَلَى التَّمْرِ فَإِنْ لَمْ يَجِدِ التَّمْرَ فَعَلَى الْمَاءِ فَإِنَّ الْمَاءَ طَهُورٌ ‏"‏ ‏.‏\hadithno{2355}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Salman ibn Amir: The Prophet (ﷺ) said: When one of you is fasting, he should break his fast with dates; but if he cannot get any, then (he should break his fast) with water, for water is purifying}}
\hadithdefcmd{abudawud}{2356}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ، حَدَّثَنَا ثَابِتٌ الْبُنَانِيُّ، أَنَّهُ سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُفْطِرُ عَلَى رُطَبَاتٍ قَبْلَ أَنْ يُصَلِّيَ فَإِنْ لَمْ تَكُنْ رُطَبَاتٌ فَعَلَى تَمَرَاتٍ فَإِنْ لَمْ تَكُنْ حَسَا حَسَوَاتٍ مِنْ مَاءٍ ‏.‏\hadithno{2356}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Anas ibn Malik: The Messenger of Allah (ﷺ) used to break his fast before praying with some fresh dates; but if there were no fresh dates, he had a few dry dates, and if there were no dry dates, he took some mouthfuls of water}}
\hadithdefcmd{abudawud}{2357}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ يَحْيَى أَبُو مُحَمَّدٍ، حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ، أَخْبَرَنِي الْحُسَيْنُ بْنُ وَاقِدٍ، حَدَّثَنَا مَرْوَانُ، - يَعْنِي ابْنَ سَالِمٍ - الْمُقَفَّعُ - قَالَ رَأَيْتُ ابْنَ عُمَرَ يَقْبِضُ عَلَى لِحْيَتِهِ فَيَقْطَعُ مَا زَادَ عَلَى الْكَفِّ وَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَفْطَرَ قَالَ ‏ "‏ ذَهَبَ الظَّمَأُ وَابْتَلَّتِ الْعُرُوقُ وَثَبَتَ الأَجْرُ إِنْ شَاءَ اللَّهُ ‏"‏ ‏.‏\hadithno{2357}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Marwan ibn Salim al-Muqaffa' said: I saw Ibn Umar holding his beard with his hand and cutting what exceeded the handful of it. He (Ibn Umar) said that the Prophet (ﷺ) said when he broke his fast: Thirst has gone, the arteries are moist, and the reward is sure, if Allah wills}}
\hadithdefcmd{abudawud}{2358}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا هُشَيْمٌ، عَنْ حُصَيْنٍ، عَنْ مُعَاذِ بْنِ زُهْرَةَ، أَنَّهُ بَلَغَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا أَفْطَرَ قَالَ ‏ "‏ اللَّهُمَّ لَكَ صُمْتُ وَعَلَى رِزْقِكَ أَفْطَرْتُ ‏"‏ ‏.‏\hadithno{2358}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'adh ibn Zuhrah: The Prophet of Allah (ﷺ) used to say when he broke his fast: O Allah, for Thee I have fasted, and with Thy provision I have broken my fast}}
\hadithdefcmd{abudawud}{2359}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، - الْمَعْنَى - قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامُ بْنُ عُرْوَةَ، عَنْ فَاطِمَةَ بِنْتِ الْمُنْذِرِ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، قَالَتْ أَفْطَرْنَا يَوْمًا فِي رَمَضَانَ فِي غَيْمٍ فِي عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم ثُمَّ طَلَعَتِ الشَّمْسُ قَالَ أَبُو أُسَامَةَ قُلْتُ لِهِشَامٍ أُمِرُوا بِالْقَضَاءِ قَالَ وَبُدٌّ مِنْ ذَلِكَ\hadithno{2359}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1959)}\hadithtrans{Narrated Asma' daughter of Abu Bakr :We broke the fast one during Ramadan when it was cloudy in the lifetime of the Messenger of Allah (ﷺ) ; then the sun rose. Abu Usamah said: I said to Hisham: Were they commanded to atone for it ? He replied: That was inevitable}}
\hadithdefcmd{abudawud}{2360}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ نَهَى عَنِ الْوِصَالِ، قَالُوا فَإِنَّكَ تُوَاصِلُ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏ "‏ إِنِّي لَسْتُ كَهَيْئَتِكُمْ إِنِّي أُطْعَمُ وَأُسْقَى ‏"‏ ‏.‏\hadithno{2360}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1962) Sahih Muslim (1102)}\hadithtrans{Narrated Ibn 'Umar:The Messenger of Allah (ﷺ) prohibited perpetual fasting. They (the people) said: You keep perpetual fasting, Messenger of Allah. He said: My position is not like that you yours. I am provided with food and drink}}
\hadithdefcmd{abudawud}{2361}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، أَنَّ بَكْرَ بْنَ مُضَرَ، حَدَّثَهُمْ عَنِ ابْنِ الْهَادِ، عَنْ عَبْدِ اللَّهِ بْنِ خَبَّابٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ لاَ تُوَاصِلُوا فَأَيُّكُمْ أَرَادَ أَنْ يُوَاصِلَ فَلْيُوَاصِلْ حَتَّى السَّحَرِ ‏"‏ ‏.‏ قَالُوا فَإِنَّكَ تُوَاصِلُ ‏.‏ قَالَ ‏"‏ إِنِّي لَسْتُ كَهَيْئَتِكُمْ إِنَّ لِي مُطْعِمًا يُطْعِمُنِي وَسَاقِيًا يَسْقِينِي ‏"‏ ‏.‏\hadithno{2361}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1963)}\hadithtrans{Narrated Abu Sa'id al-Khudri:The Messenger of Allah (ﷺ) as saying: Do not observe perpetual fasting. If any of you wants to observe perpetual fast, he should observe it until the dawn. They (the people) asked: You observe perpetual fast ? He replied: My position is not like that of yours. There is One Who gives me to eat, and there is One who gives me to drink}}
\hadithdefcmd{abudawud}{2362}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنِ الْمَقْبُرِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لَمْ يَدَعْ قَوْلَ الزُّورِ وَالْعَمَلَ بِهِ فَلَيْسَ لِلَّهِ حَاجَةٌ أَنْ يَدَعَ طَعَامَهُ وَشَرَابَهُ ‏"‏ ‏.‏ قَالَ أَحْمَدُ فَهِمْتُ إِسْنَادَهُ مِنَ ابْنِ أَبِي ذِئْبٍ وَأَفْهَمَنِي الْحَدِيثَ رَجُلٌ إِلَى جَنْبِهِ أُرَاهُ ابْنَ أَخِيهِ ‏.‏\hadithno{2362}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1903)}\hadithtrans{Narrated Abu Hurairah: The Messenger of Allah (ﷺ) as saying: If anyone does not abandon falsehood and action is accordance with it, Allah has no need that he should abandon his food and drink. The narrator Ahmad (b. Yunus) said: I learnt the chain of narrators from Ibn Abi Dhi'b, and a man by his side made me understand the tradition. I think he was his cousin}}
\hadithdefcmd{abudawud}{2363}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الصِّيَامُ جُنَّةٌ إِذَا كَانَ أَحَدُكُمْ صَائِمًا فَلاَ يَرْفُثْ وَلاَ يَجْهَلْ فَإِنِ امْرُؤٌ قَاتَلَهُ أَوْ شَاتَمَهُ فَلْيَقُلْ إِنِّي صَائِمٌ إِنِّي صَائِمٌ ‏"‏ ‏.‏\hadithno{2363}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1894) Sahih Muslim (1151)}\hadithtrans{Narrated Abu Hurairah:The Prophet (ﷺ) as saying: Fast is a shield ; when one of you is fasting, he should neither behave in an obscene manner nor foolishly. If a man fights or abuses him, he should say: I am fasting, I am fasting}}
\hadithdefcmd{abudawud}{2364}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، حَدَّثَنَا شَرِيكٌ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَامِرِ بْنِ رَبِيعَةَ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَسْتَاكُ وَهُوَ صَائِمٌ ‏.‏ زَادَ مُسَدَّدٌ مَا لاَ أَعُدُّ وَلاَ أُحْصِي ‏.‏\hadithno{2364}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Amir ibn Rabi'ah: I have seen the Messenger of Allah (ﷺ) using a tooth-stick while he was fasting. Musaddad added in his version: "more often than I could count}}
\hadithdefcmd{abudawud}{2365}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ سُمَىٍّ، مَوْلَى أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ بَعْضِ، أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَ النَّاسَ فِي سَفَرِهِ عَامَ الْفَتْحِ بِالْفِطْرِ وَقَالَ ‏ "‏ تَقَوَّوْا لِعَدُوِّكُمْ ‏"‏ ‏.‏ وَصَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو بَكْرٍ قَالَ الَّذِي حَدَّثَنِي لَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم بِالْعَرْجِ يَصُبُّ عَلَى رَأْسِهِ الْمَاءَ وَهُوَ صَائِمٌ مِنَ الْعَطَشِ أَوْ مِنَ الْحَرِّ ‏.‏\hadithno{2365}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated A Companion of the Prophet: AbuBakr ibn AbdurRahman reported on the authority of a Companion of the Prophet (ﷺ): I saw the Prophet (ﷺ) commanding the people while he was travelling on the occasion of the conquest of Mecca not to observe fast. He said: Be strong for your enemy. The Messenger of Allah (ﷺ) fasted himself. Narrated AbuBakr: A man who narrated his tradition to me said: I have seen the Messenger of Allah (ﷺ) in al-Arj pouring water over his head while he was fasting, either because of thirst or because of heat}}
\hadithdefcmd{abudawud}{2366}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنِي يَحْيَى بْنُ سُلَيْمٍ، عَنْ إِسْمَاعِيلَ بْنِ كَثِيرٍ، عَنْ عَاصِمِ بْنِ لَقِيطِ بْنِ صَبِرَةَ، عَنْ أَبِيهِ، لَقِيطِ بْنِ صَبِرَةَ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بَالِغْ فِي الاِسْتِنْشَاقِ إِلاَّ أَنْ تَكُونَ صَائِمًا ‏"‏ ‏.‏\hadithno{2366}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Laqit ibn Saburah: The Prophet (ﷺ) said: Snuff up water freely unless you are fasting}}
\hadithdefcmd{abudawud}{2367}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، ح وَحَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا حَسَنُ بْنُ مُوسَى، حَدَّثَنَا شَيْبَانُ، - جَمِيعًا - عَنْ يَحْيَى، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ، - يَعْنِي الرَّحَبِيَّ - عَنْ ثَوْبَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَفْطَرَ الْحَاجِمُ وَالْمَحْجُومُ ‏"‏ ‏.‏ قَالَ شَيْبَانُ أَخْبَرَنِي أَبُو قِلاَبَةَ أَنَّ أَبَا أَسْمَاءَ الرَّحَبِيَّ حَدَّثَهُ أَنَّ ثَوْبَانَ مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَخْبَرَهُ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2367}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Thawban: The Prophet (ﷺ) said: A man who cupped and a man who has himself cupped broke their fast. The narrator Shayban said in his version: AbuQilabah told me that AbuAsma' ar-Rahbi told him that Thawban, the client of the Messenger of Allah (ﷺ), told him that he heard the Prophet (ﷺ) say this}}
\hadithdefcmd{abudawud}{2368}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا حَسَنُ بْنُ مُوسَى، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، قَالَ حَدَّثَنِي أَبُو قِلاَبَةَ الْجَرْمِيُّ، أَنَّهُ أَخْبَرَهُ أَنَّ شَدَّادَ بْنَ أَوْسٍ بَيْنَمَا هُوَ يَمْشِي مَعَ النَّبِيِّ صلى الله عليه وسلم فَذَكَرَ نَحْوَهُ ‏.‏\hadithno{2368}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Shaddad ibn Aws: The tradition mentioned above (No. 2361) has also been transmitted by Shaddad ibn Aws through a different chain of narrators. This version adds: While Shaddad ibn Aws was walking along with the Prophet (ﷺ)....The narrator then transmitted the rest of the tradition to the same effect}}
\hadithdefcmd{abudawud}{2369}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الأَشْعَثِ، عَنْ شَدَّادِ بْنِ أَوْسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَتَى عَلَى رَجُلٍ بِالْبَقِيعِ وَهُوَ يَحْتَجِمُ وَهُوَ آخِذٌ بِيَدِي لِثَمَانَ عَشْرَةَ خَلَتْ مِنْ رَمَضَانَ فَقَالَ ‏ "‏ أَفْطَرَ الْحَاجِمُ وَالْمَحْجُومُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَى خَالِدٌ الْحَذَّاءُ عَنْ أَبِي قِلاَبَةَ بِإِسْنَادِ أَيُّوبَ مِثْلَهُ ‏.‏\hadithno{2369}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Shaddad b. Aws: The Messenger of Allah (ﷺ) came to a man at al-Baqi' while he was cupping on the 18th of Ramadan ; he (the Prophet) was holding my hand. Thereupon he said: A man who cups and a man who gets himself cupped break their fast. Abu Dawud said: The narrator Khalid al-Hadhdha' transmitted a similar tradition from Abu Qilabah through a different chain of narrators mentioned by the narrator Ayyub}}
\hadithdefcmd{abudawud}{2370}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ، وَعَبْدُ الرَّزَّاقِ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنِي ابْنَ إِبْرَاهِيمَ - عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنِي مَكْحُولٌ، أَنَّ شَيْخًا، مِنَ الْحَىِّ - قَالَ عُثْمَانُ فِي حَدِيثِهِ مُصَدَّقٌ - أَخْبَرَهُ أَنَّ ثَوْبَانَ مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَخْبَرَهُ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَفْطَرَ الْحَاجِمُ وَالْمَحْجُومُ ‏"‏ ‏.‏\hadithno{2370}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Thawban, the client of the Prophet (ﷺ):The Prophet (ﷺ) as saying: A man who cups and a man who gets himself cupped break their fast}}
\hadithdefcmd{abudawud}{2371}{حَدَّثَنَا مَحْمُودُ بْنُ خَالِدٍ، حَدَّثَنَا مَرْوَانُ، حَدَّثَنَا الْهَيْثَمُ بْنُ حُمَيْدٍ، أَخْبَرَنَا الْعَلاَءُ بْنُ الْحَارِثِ، عَنْ مَكْحُولٍ، عَنْ أَبِي أَسْمَاءَ الرَّحَبِيِّ، عَنْ ثَوْبَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَفْطَرَ الْحَاجِمُ وَالْمَحْجُومُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ ابْنُ ثَوْبَانَ عَنْ أَبِيهِ عَنْ مَكْحُولٍ بِإِسْنَادِهِ مِثْلَهُ ‏.‏\hadithno{2371}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Thawban: The Prophet (ﷺ) as saying: A man who cups and a man who gets himself cupped break their fast. Abu Dawud said: Ibn Thawban transmitted a similar tradition from his father on the authority of Makhul through an chain of narrators mentioned by him}}
\hadithdefcmd{abudawud}{2372}{حَدَّثَنَا أَبُو مَعْمَرٍ عَبْدُ اللَّهِ بْنُ عَمْرٍو، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم احْتَجَمَ وَهُوَ صَائِمٌ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ وُهَيْبُ بْنُ خَالِدٍ عَنْ أَيُّوبَ بِإِسْنَادِهِ مِثْلَهُ ‏.‏ وَجَعْفَرُ بْنُ رَبِيعَةَ وَهِشَامُ بْنُ حَسَّانَ عَنْ عِكْرِمَةَ عَنِ ابْنِ عَبَّاسٍ مِثْلَهُ ‏.‏\hadithno{2372}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5694)}\hadithtrans{Narrated Ibn 'Abbas: The Messenger of Allah (ﷺ) had himself cupped when he was fasting. Abu Dawud said: Wuhaib b. Khalid narrated a similar tradition from Ayyub through a different chain of narrators. Ja'far b. Rabi'ah and Hisham, that is, Ibn Hassan, narrated a similar tradition from 'Ikrimah on the authority of Ibn 'Abbas}}
\hadithdefcmd{abudawud}{2373}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم احْتَجَمَ وَهُوَ صَائِمٌ مُحْرِمٌ ‏.‏\hadithno{2373}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Messenger of Allah (ﷺ) had himself cupped when he was fasting and wearing ihram (pilgrim garb)}}
\hadithdefcmd{abudawud}{2374}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَابِسٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي لَيْلَى، حَدَّثَنِي رَجُلٌ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الْحِجَامَةِ وَالْمُوَاصَلَةِ وَلَمْ يُحَرِّمْهُمَا إِبْقَاءً عَلَى أَصْحَابِهِ فَقِيلَ لَهُ يَا رَسُولَ اللَّهِ إِنَّكَ تُوَاصِلُ إِلَى السَّحَرِ ‏.‏ فَقَالَ ‏ "‏ إِنِّي أُوَاصِلُ إِلَى السَّحَرِ وَرَبِّي يُطْعِمُنِي وَيَسْقِينِي ‏"‏ ‏.‏\hadithno{2374}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Abd al-Rahman b. Abi Laila:A man from the Companions of the Prophet (ﷺ) told me that the Messenger of Allah (ﷺ) prohibited cupping and perpetual fasting, but he had not made them unlawful showing mercy on his Companions. Thereupon he was asked: Messenger of Allah, you observe perpetual fast till dawn. He replied: I observe perpetual fast till dawn (for) my Lord gives me food and drink}}
\hadithdefcmd{abudawud}{2375}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا سُلَيْمَانُ، - يَعْنِي ابْنَ الْمُغِيرَةِ - عَنْ ثَابِتٍ، قَالَ قَالَ أَنَسٌ مَا كُنَّا نَدَعُ الْحِجَامَةَ لِلصَّائِمِ إِلاَّ كَرَاهِيَةَ الْجَهْدِ ‏.‏\hadithno{2375}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas:We would not allow a man who was fasting to get himself cupped due to abomination of hardship}}
\hadithdefcmd{abudawud}{2376}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ رَجُلٍ، مِنْ أَصْحَابِهِ عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُفْطِرُ مَنْ قَاءَ وَلاَ مَنِ احْتَلَمَ وَلاَ مَنِ احْتَجَمَ ‏"‏ ‏.‏\hadithno{2376}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated A man from the Companions: The Messenger of Allah (ﷺ) said: Neither vomiting, nor emission, nor cupping breaks the fast of the one who is fasting}}
\hadithdefcmd{abudawud}{2377}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا عَلِيُّ بْنُ ثَابِتٍ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ النُّعْمَانِ بْنِ مَعْبَدِ بْنِ هَوْذَةَ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ أَمَرَ بِالإِثْمِدِ الْمُرَوَّحِ عِنْدَ النَّوْمِ وَقَالَ ‏ "‏ لِيَتَّقِهِ الصَّائِمُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ لِي يَحْيَى بْنُ مَعِينٍ هُوَ حَدِيثٌ مُنْكَرٌ يَعْنِي حَدِيثَ الْكَحْلِ ‏.‏\hadithno{2377}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ma'bad b. Hudhah: The Prophet (ﷺ) commanded to apply collyrium mixed with musk at the time of sleep. He said: A man who is fasting should abstain from it. Abu Dawud said: Yahya b. Ma'in said to me: This tradition about the use of collyrium is munkar (i.e. contradicts the sound traditions on the subject)}}
\hadithdefcmd{abudawud}{2378}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، أَخْبَرَنَا أَبُو مُعَاوِيَةَ، عَنْ عُتْبَةَ، عَنْ أَبِي مُعَاذٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ أَنَسٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ كَانَ يَكْتَحِلُ وَهُوَ صَائِمٌ ‏.‏\hadithno{2378}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Ubaid Allah b. Abu Bakr b. Anas reported on the authority of Anas b. Malik that he used to apply collyrium when he was fasting}}
\hadithdefcmd{abudawud}{2379}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ الْمُخَرِّمِيُّ، وَيَحْيَى بْنُ مُوسَى الْبَلْخِيُّ، قَالاَ حَدَّثَنَا يَحْيَى بْنُ عِيسَى، عَنِ الأَعْمَشِ، قَالَ مَا رَأَيْتُ أَحَدًا مِنْ أَصْحَابِنَا يَكْرَهُ الْكَحْلَ لِلصَّائِمِ وَكَانَ إِبْرَاهِيمُ يُرَخِّصُ أَنْ يَكْتَحِلَ الصَّائِمُ بِالصَّبِرِ ‏.‏\hadithno{2379}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Al-A'mash said:I did not see any of our companions who abominated the use of collyrium by a man who fasting. Ibrahim would permit the man who was fasting to apply collyrium with aloes}}
\hadithdefcmd{abudawud}{2380}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا هِشَامُ بْنُ حَسَّانَ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ ذَرَعَهُ قَىْءٌ وَهُوَ صَائِمٌ فَلَيْسَ عَلَيْهِ قَضَاءٌ وَإِنِ اسْتَقَاءَ فَلْيَقْضِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ أَيْضًا حَفْصُ بْنُ غِيَاثٍ عَنْ هِشَامٍ مِثْلَهُ ‏.‏\hadithno{2380}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: if one has a sudden attack of vomiting while one is fasting, no atonement is required of him, but if he vomits intentionally he must make atonement}}
\hadithdefcmd{abudawud}{2381}{حَدَّثَنَا أَبُو مَعْمَرٍ عَبْدُ اللَّهِ بْنُ عَمْرٍو، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا الْحُسَيْنُ، عَنْ يَحْيَى، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ عَمْرٍو الأَوْزَاعِيُّ، عَنْ يَعِيشَ بْنِ الْوَلِيدِ بْنِ هِشَامٍ، أَنَّ أَبَاهُ، حَدَّثَهُ حَدَّثَنِي مَعْدَانُ بْنُ طَلْحَةَ، أَنَّ أَبَا الدَّرْدَاءِ، حَدَّثَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَاءَ فَأَفْطَرَ فَلَقِيتُ ثَوْبَانَ مَوْلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فِي مَسْجِدِ دِمَشْقَ فَقُلْتُ إِنَّ أَبَا الدَّرْدَاءِ حَدَّثَنِي أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَاءَ فَأَفْطَرَ ‏.‏ قَالَ صَدَقَ وَأَنَا صَبَبْتُ لَهُ وَضُوءَهُ صلى الله عليه وسلم ‏.‏\hadithno{2381}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ma'dan b. Talhah:That Abu ad-Darda' narrated to him: The Messenger of Allah (ﷺ) vomited and broke his fast. Then I met Thawban, the client of the Messenger of Allah (ﷺ), in the mosque in Damascus, I said (to him): Abu al-Darda has told me that the Messenger of Allah (ﷺ) vomited and broke his fast. He said: He spoke the truth ; and I poured out water for his ablution (ﷺ)}}
\hadithdefcmd{abudawud}{2382}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، وَعَلْقَمَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَبِّلُ وَهُوَ صَائِمٌ وَيُبَاشِرُ وَهُوَ صَائِمٌ وَلَكِنَّهُ كَانَ أَمْلَكَ لإِرْبِهِ ‏.‏\hadithno{2382}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (1927) Sahih Muslim (1106)}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) used to kiss and embrace while he was fasting, but he was the one of you who had most control over his desire}}
\hadithdefcmd{abudawud}{2383}{حَدَّثَنَا أَبُو تَوْبَةَ الرَّبِيعُ بْنُ نَافِعٍ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ زِيَادِ بْنِ عِلاَقَةَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَبِّلُ فِي شَهْرِ الصَّوْمِ ‏.‏\hadithno{2383}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1106)}\hadithtrans{Narrated 'Aishah:The Prophet (ﷺ) used to kiss (me) during the month of fasting}}
\hadithdefcmd{abudawud}{2384}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ طَلْحَةَ بْنِ عَبْدِ اللَّهِ، - يَعْنِي ابْنَ عُثْمَانَ الْقُرَشِيَّ - عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُقَبِّلُنِي وَهُوَ صَائِمٌ وَأَنَا صَائِمَةٌ ‏.‏\hadithno{2384}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) used to kiss me when he was fasting and when I was fasting}}
\hadithdefcmd{abudawud}{2385}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا اللَّيْثُ، ح وَحَدَّثَنَا عِيسَى بْنُ حَمَّادٍ، أَخْبَرَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ، عَنْ عَبْدِ الْمَلِكِ بْنِ سَعِيدٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ عُمَرُ بْنُ الْخَطَّابِ هَشِشْتُ فَقَبَّلْتُ وَأَنَا صَائِمٌ، فَقُلْتُ يَا رَسُولَ اللَّهِ صَنَعْتُ الْيَوْمَ أَمْرًا عَظِيمًا قَبَّلْتُ وَأَنَا صَائِمٌ ‏.‏ قَالَ ‏"‏ أَرَأَيْتَ لَوْ مَضْمَضْتَ مِنَ الْمَاءِ وَأَنْتَ صَائِمٌ ‏"‏ ‏.‏ قَالَ عِيسَى بْنُ حَمَّادٍ فِي حَدِيثِهِ قُلْتُ لاَ بَأْسَ بِهِ ‏.‏ ثُمَّ اتَّفَقَا قَالَ ‏"‏ فَمَهْ ‏"‏ ‏.‏\hadithno{2385}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Umar ibn al-Khattab: I got excited, so I kissed while I was fasting, I then said: Messenger of Allah, I have done a big deed; I kissed while I was fasting. He said: What do you think if you rinse your mouth with water while you are fasting. The narrator Isa ibn Hammad said in his version: I said to him: There is no harm in it. Then both of them agreed on the version: He said: Then what?}}
\hadithdefcmd{abudawud}{2386}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا مُحَمَّدُ بْنُ دِينَارٍ، حَدَّثَنَا سَعْدُ بْنُ أَوْسٍ الْعَبْدِيُّ، عَنْ مِصْدَعٍ أَبِي يَحْيَى، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُقَبِّلُهَا وَهُوَ صَائِمٌ وَيَمُصُّ لِسَانَهَا ‏.‏\hadithno{2386}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) used to kiss her and suck her tongue when he was fasting}}
\hadithdefcmd{abudawud}{2387}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ، حَدَّثَنَا أَبُو أَحْمَدَ، - يَعْنِي الزُّبَيْرِيَّ - أَخْبَرَنَا إِسْرَائِيلُ، عَنْ أَبِي الْعَنْبَسِ، عَنِ الأَغَرِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، سَأَلَ النَّبِيَّ صلى الله عليه وسلم عَنِ الْمُبَاشَرَةِ لِلصَّائِمِ فَرَخَّصَ لَهُ وَأَتَاهُ آخَرُ فَسَأَلَهُ فَنَهَاهُ ‏.‏ فَإِذَا الَّذِي رَخَّصَ لَهُ شَيْخٌ وَالَّذِي نَهَاهُ شَابٌّ ‏.‏\hadithno{2387}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: A man asked the Prophet (ﷺ) whether one who was fasting could embrace (his wife) and he gave him permission; but when another man came to him, and asked him, he forbade him. The one to whom he gave permission was an old man and the one whom he forbade was a youth}}
\hadithdefcmd{abudawud}{2388}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدِ بْنِ إِسْحَاقَ الأَذْرَمِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مَالِكٍ، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ بْنِ هِشَامٍ، عَنْ عَائِشَةَ، وَأُمِّ سَلَمَةَ زَوْجَىِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُمَا قَالَتَا كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصْبِحُ جُنُبًا ‏.‏ قَالَ عَبْدُ اللَّهِ الأَذْرَمِيُّ فِي حَدِيثِهِ فِي رَمَضَانَ مِنْ جِمَاعٍ غَيْرِ احْتِلاَمٍ ثُمَّ يَصُومُ ‏.‏ قَالَ أَبُو دَاوُدَ وَمَا أَقَلَّ مَنْ يَقُولُ هَذِهِ الْكَلِمَةَ - يَعْنِي يُصْبِحُ جُنُبًا فِي رَمَضَانَ - وَإِنَّمَا الْحَدِيثُ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يُصْبِحُ جُنُبًا وَهُوَ صَائِمٌ ‏.‏\hadithno{2388}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1109)}\hadithtrans{Narrated 'Aishah and Umm Salamah, wives of the Prophet (ﷺ): The Messenger of Allah (ﷺ) would be overtaken by the dawn when he was in a state of sexual defilement. The narrator 'Abd Allah al-Adhrami said in his version: During Ramadan, due to sexual intercourse and no owing to a dream (i.e. nocturnal emission), and would fast. Abu Dawud said: How brief is this sentence uttered by the narrator, this is, "he was overtaken by daw when he was in the state of sexual defilement"? The tradition says: The Prophet (ﷺ) was overtaken by dawn in the state of sexual defilement when he was fasting}}
\hadithdefcmd{abudawud}{2389}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، - يَعْنِي الْقَعْنَبِيَّ - عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ مَعْمَرٍ الأَنْصَارِيِّ، عَنْ أَبِي يُونُسَ، مَوْلَى عَائِشَةَ عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَجُلاً قَالَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ وَاقِفٌ عَلَى الْبَابِ يَا رَسُولَ اللَّهِ إِنِّي أُصْبِحُ جُنُبًا وَأَنَا أُرِيدُ الصِّيَامَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَأَنَا أُصْبِحُ جُنُبًا وَأَنَا أُرِيدُ الصِّيَامَ فَأَغْتَسِلُ وَأَصُومُ ‏"‏ ‏.‏ فَقَالَ الرَّجُلُ يَا رَسُولَ اللَّهِ إِنَّكَ لَسْتَ مِثْلَنَا قَدْ غَفَرَ اللَّهُ لَكَ مَا تَقَدَّمَ مِنْ ذَنْبِكَ وَمَا تَأَخَّرَ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَالَ ‏"‏ وَاللَّهِ إِنِّي لأَرْجُو أَنْ أَكُونَ أَخْشَاكُمْ لِلَّهِ وَأَعْلَمَكُمْ بِمَا أَتَّبِعُ ‏"‏ ‏.‏\hadithno{2389}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Muslim (1110)}\hadithtrans{Narrated 'Aishah, wife of Prophet (ﷺ):A man said to Messenger of Allah (ﷺ): Messenger of Allah, I was overtaken by dawn while I was sexually defiled, and I want to keep fast. The Messenger of Allah (ﷺ) said: I am also overtaken by dawn while I am in the state of sexual defilement ; I also want to keep fast. I take a bath and I keep fast. The man said: Messenger of Allah, you are not like us ; Allah has forgiven you your past and future sins. The Messenger of Allah (ﷺ) became angry and said: I swear by Allah, I hope I shall be the most fearful of you of Allah, and most familiar of you with what I follow}}
\hadithdefcmd{abudawud}{2390}{حَدَّثَنَا مُسَدَّدٌ، وَمُحَمَّدُ بْنُ عِيسَى، - الْمَعْنَى - قَالاَ حَدَّثَنَا سُفْيَانُ، - قَالَ مُسَدَّدٌ - حَدَّثَنَا الزُّهْرِيُّ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ أَتَى رَجُلٌ النَّبِيَّ صلى الله عليه وسلم فَقَالَ هَلَكْتُ ‏.‏ فَقَالَ ‏"‏ مَا شَأْنُكَ ‏"‏ ‏.‏ قَالَ وَقَعْتُ عَلَى امْرَأَتِي فِي رَمَضَانَ ‏.‏ قَالَ ‏"‏ فَهَلْ تَجِدُ مَا تُعْتِقُ رَقَبَةً ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَهَلْ تَسْتَطِيعُ أَنْ تَصُومَ شَهْرَيْنِ مُتَتَابِعَيْنِ ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ فَهَلْ تَسْتَطِيعُ أَنْ تُطْعِمَ سِتِّينَ مِسْكِينًا ‏"‏ ‏.‏ قَالَ لاَ ‏.‏ قَالَ ‏"‏ اجْلِسْ ‏"‏ ‏.‏ فَأُتِيَ النَّبِيُّ صلى الله عليه وسلم بِعَرَقٍ فِيهِ تَمْرٌ فَقَالَ ‏"‏ تَصَدَّقْ بِهِ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ مَا بَيْنَ لاَبَتَيْهَا أَهْلُ بَيْتٍ أَفْقَرَ مِنَّا فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى بَدَتْ ثَنَايَاهُ قَالَ ‏"‏ فَأَطْعِمْهُ إِيَّاهُمْ ‏"‏ ‏.‏ وَقَالَ مُسَدَّدٌ فِي مَوْضِعٍ آخَرَ أَنْيَابُهُ ‏.‏\hadithno{2390}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6711) Sahih Muslim (1111)}\hadithtrans{Narrated Abu Hurairah:A man came to the Prophet (ﷺ) and said: I am undone. He asked him: What has happened to you ? He said: I had intercourse with my wife in Ramadan (while I was fasting). He asked: Can you set a slave free ? He said: No. He again asked: Can you fast for two consecutive months ? He said: No. He asked: Can you provide food for sixty poor people ? He said: No. He said: Sit down. Then a huge basket containing dates ('araq) was brought to the Prophet (ﷺ). He then said to him: Give it as sadaqah (i.e. alms). He said: Messenger of Allah, there is no poorer family than mine between the two lave plains of it (Medina). The Messenger of Allah (ﷺ) laughed so that his eye-teeth became visible, and said: Give it to your family to eat. Musaddad said in another place: "his canine teeth}}
\hadithdefcmd{abudawud}{2391}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، بِهَذَا الْحَدِيثِ بِمَعْنَاهُ ‏.‏ زَادَ الزُّهْرِيُّ وَإِنَّمَا كَانَ هَذَا رُخْصَةً لَهُ خَاصَّةً فَلَوْ أَنَّ رَجُلاً فَعَلَ ذَلِكَ الْيَوْمَ لَمْ يَكُنْ لَهُ بُدٌّ مِنَ التَّكْفِيرِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ اللَّيْثُ بْنُ سَعْدٍ وَالأَوْزَاعِيُّ وَمَنْصُورُ بْنُ الْمُعْتَمِرِ وَعِرَاكُ بْنُ مَالِكٍ عَلَى مَعْنَى ابْنِ عُيَيْنَةَ ‏.‏ زَادَ الأَوْزَاعِيُّ وَاسْتَغْفِرِ اللَّهَ ‏.‏\hadithno{2391}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6710) Sahih Muslim (1111)}\hadithtrans{This tradition has also been transmitted by al-Zuhri through a different chain of narrators to the same effect. Al-Zuhri added in his version:This was a special concession for him. If a man commits this act today, the expiation is necessary for him. Abu Dawud said: Al-Laith b. Sa'd, al-Awza'i, Mansur b. al-Mu'tamir and 'Irak b. Malik have narrated this tradition like the one narrated by Ibn 'Uyainah. Al-Awza'i narrated in his version the words: Beg pardon of Allah}}
\hadithdefcmd{abudawud}{2392}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَجُلاً، أَفْطَرَ فِي رَمَضَانَ فَأَمَرَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُعْتِقَ رَقَبَةً أَوْ يَصُومَ شَهْرَيْنِ مُتَتَابِعَيْنِ أَوْ يُطْعِمَ سِتِّينَ مِسْكِينًا ‏.‏ قَالَ لاَ أَجِدُ ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ اجْلِسْ ‏"‏ ‏.‏ فَأُتِيَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِعَرَقٍ فِيهِ تَمْرٌ فَقَالَ ‏"‏ خُذْ هَذَا فَتَصَدَّقْ بِهِ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ مَا أَحَدٌ أَحْوَجَ مِنِّي ‏.‏ فَضَحِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى بَدَتْ أَنْيَابُهُ وَقَالَ لَهُ ‏"‏ كُلْهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ابْنُ جُرَيْجٍ عَنِ الزُّهْرِيِّ عَلَى لَفْظِ مَالِكٍ أَنَّ رَجُلاً أَفْطَرَ وَقَالَ فِيهِ ‏"‏ أَوْ تُعْتِقَ رَقَبَةً أَوْ تَصُومَ شَهْرَيْنِ أَوْ تُطْعِمَ سِتِّينَ مِسْكِينًا ‏"‏ ‏.‏\hadithno{2392}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1111)}\hadithtrans{Narrated Abu Hurairah: (A man broke his fast intentionally) during Ramadan. The Messenger of Allah (ﷺ) commanded him to emancipate a slave, or fast for two months, or feed sixty poor men. He said: I cannot provide. The Messenger of Allah (ﷺ) said: Sit down. Thereafter a huge basket of dates ('araq) was brought to the Messenger of Allah (ﷺ). He said: Take this and give it as sadaqah (alms). He said: Messenger of Allah, there is no poorer than I. The Messenger of Allah (ﷺ) thereupon laughed so that his canine teeth became visible and said: Eat it yourself. Abu Dawud said: Ibn Juraij narrated it from al-Zuhri in the wordings of the narrator Malik that a man broke his fast. This version says: You should either free a slave, or fast for two months, or provide food for sixty poor men}}
\hadithdefcmd{abudawud}{2393}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم أَفْطَرَ فِي رَمَضَانَ بِهَذَا الْحَدِيثِ ‏.‏ قَالَ فَأُتِيَ بِعَرَقٍ فِيهِ تَمْرٌ قَدْرُ خَمْسَةَ عَشَرَ صَاعًا وَقَالَ فِيهِ ‏ "‏ كُلْهُ أَنْتَ وَأَهْلُ بَيْتِكَ وَصُمْ يَوْمًا وَاسْتَغْفِرِ اللَّهَ ‏"‏ ‏.‏\hadithno{2393}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Abu Hurairah said:A man came to the Prophet (ﷺ). He broke his fast during Ramadan. He then narrated the rest of this tradition adding: Then a huge basket containing fifteen sa's of dates was brought to him. He said: Eat it yourself and your family and keep one fast and beg pardon of Allah}}
\hadithdefcmd{abudawud}{2394}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، أَنَّ عَبْدَ الرَّحْمَنِ بْنَ الْقَاسِمِ، حَدَّثَهُ أَنَّ مُحَمَّدَ بْنَ جَعْفَرِ بْنِ الزُّبَيْرِ حَدَّثَهُ أَنَّ عَبَّادَ بْنَ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ حَدَّثَهُ أَنَّهُ، سَمِعَ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم تَقُولُ أَتَى رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فِي الْمَسْجِدِ فِي رَمَضَانَ فَقَالَ يَا رَسُولَ اللَّهِ احْتَرَقْتُ ‏.‏ فَسَأَلَهُ النَّبِيُّ صلى الله عليه وسلم مَا شَأْنُهُ قَالَ أَصَبْتُ أَهْلِي ‏.‏ قَالَ ‏"‏ تَصَدَّقْ ‏"‏ ‏.‏ قَالَ وَاللَّهِ مَا لِي شَىْءٌ وَلاَ أَقْدِرُ عَلَيْهِ ‏.‏ قَالَ ‏"‏ اجْلِسْ ‏"‏ ‏.‏ فَجَلَسَ فَبَيْنَمَا هُوَ عَلَى ذَلِكَ أَقْبَلَ رَجُلٌ يَسُوقُ حِمَارًا عَلَيْهِ طَعَامٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيْنَ الْمُحْتَرِقُ آنِفًا ‏"‏ ‏.‏ فَقَامَ الرَّجُلُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تَصَدَّقْ بِهَذَا ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ أَعَلَى غَيْرِنَا فَوَاللَّهِ إِنَّا لَجِيَاعٌ مَا لَنَا شَىْءٌ ‏.‏ قَالَ ‏"‏ كُلُوهُ ‏"‏ ‏.‏\hadithno{2394}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1112)}\hadithtrans{Narrated 'Aishah, wife of Prophet (ﷺ):A man came to the Prophet (ﷺ) during Ramadan in the mosque. He said: Messenger of Allah, I am burnt. The Prophet (ﷺ) asked him what happened to him. He said: I had sexual intercourse with my wife. He said: Give sadaqah (alms). He said: I swear by Allah, I possess nothing with me, and I cannot do this. He said: Sit down. He sat down. While he was waiting, a man came forward driving his donkey loaded with food. The Messenger of Allah (ﷺ) said: Where is the man who was burnt just now ? Thereupon the man stood up. The Messenger of Allah (ﷺ) said: Give it as sadaqah (alms). He asked: Messenger of Allah, to others than us ? By Allah. we are hungry, we have nothing (to eat). He said: Eat it yourselves}}
\hadithdefcmd{abudawud}{2395}{حَدَّثَنَا مُحَمَّدُ بْنُ عَوْفٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا ابْنُ أَبِي الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ، عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عَبَّادِ بْنِ عَبْدِ اللَّهِ، عَنْ عَائِشَةَ، بِهَذِهِ الْقِصَّةِ قَالَ فَأُتِيَ بِعَرَقٍ فِيهِ عِشْرُونَ صَاعًا ‏.‏\hadithno{2395}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{The tradition mentioned above has also been transmitted by 'Aishah through a different chain of narrators. This version adds:A huge basket containing twenty sa's (of dates) was brought}}
\hadithdefcmd{abudawud}{2396}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، قَالَ حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، قَالَ أَخْبَرَنَا شُعْبَةُ، عَنْ حَبِيبِ بْنِ أَبِي ثَابِتٍ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنِ ابْنِ مُطَوِّسٍ، عَنْ أَبِيهِ، - قَالَ ابْنُ كَثِيرٍ عَنْ أَبِي الْمُطَوِّسِ، عَنْ أَبِيهِ، - عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَفْطَرَ يَوْمًا مِنْ رَمَضَانَ مِنْ غَيْرِ رُخْصَةٍ رَخَّصَهَا اللَّهُ لَهُ لَمْ يَقْضِ عَنْهُ صِيَامُ الدَّهْرِ ‏"‏ ‏.‏\hadithno{2396}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: If anyone breaks his fast one day in Ramadan without a concession granted to him by Allah, a perpetual fast will not atone for it}}
\hadithdefcmd{abudawud}{2397}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ سُفْيَانَ، حَدَّثَنِي حَبِيبٌ، عَنْ عُمَارَةَ، عَنِ ابْنِ الْمُطَوِّسِ، - قَالَ فَلَقِيتُ ابْنَ الْمُطَوِّسِ فَحَدَّثَنِي - عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم مِثْلَ حَدِيثِ ابْنِ كَثِيرٍ وَسُلَيْمَانَ ‏.‏ قَالَ أَبُو دَاوُدَ وَاخْتُلِفَ عَلَى سُفْيَانَ وَشُعْبَةَ عَنْهُمَا ابْنُ الْمُطَوِّسِ وَأَبُو الْمُطَوِّسِ ‏.‏\hadithno{2397}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Hurairah through a different chain of narrators similar to the tradition narrated by Ibn Kathir and Sulaiman. Abu Dawud said:Sufyan and Shu'bah differed among themselves on the name of the narrator Ibn al-Mutawwas and Abu al-Mutawwas}}
\hadithdefcmd{abudawud}{2398}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، وَحَبِيبٌ، وَهِشَامٌ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَكَلْتُ وَشَرِبْتُ نَاسِيًا وَأَنَا صَائِمٌ ‏.‏ فَقَالَ ‏ "‏ أَطْعَمَكَ اللَّهُ وَسَقَاكَ ‏"‏ ‏.‏\hadithno{2398}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Bukhari (1933) Sahih Muslim (1155)}\hadithtrans{Narrated Abu Hurairah:A man came to the Prophet (ﷺ) and said: Messenger of Allah, I ate and drank in forgetfulness when I was fasting. Hie said: Allah had fed you and given you drink}}
\hadithdefcmd{abudawud}{2399}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، أَنَّهُ سَمِعَ عَائِشَةَ، - رضى الله عنها - تَقُولُ إِنْ كَانَ لَيَكُونُ عَلَىَّ الصَّوْمُ مِنْ رَمَضَانَ فَمَا أَسْتَطِيعُ أَنْ أَقْضِيَهُ حَتَّى يَأْتِيَ شَعْبَانُ ‏.‏\hadithno{2399}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (1950) Sahih Muslim (1146)}\hadithtrans{Narrated 'Aishah:If I had some part of the fast of Ramadan to make up, I would not be able to atone for it except in Sha'ban}}
\hadithdefcmd{abudawud}{2400}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي جَعْفَرٍ، عَنْ مُحَمَّدِ بْنِ جَعْفَرِ بْنِ الزُّبَيْرِ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ مَاتَ وَعَلَيْهِ صِيَامٌ صَامَ عَنْهُ وَلِيُّهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا فِي النَّذْرِ وَهُوَ قَوْلُ أَحْمَدَ بْنِ حَنْبَلٍ ‏.‏\hadithno{2400}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1952) Sahih Muslim (1147)}\hadithtrans{Narrated 'Aishah: The Prophet (ﷺ) as saying: If anyone dies when some fast is due from him (i.e. which he could not keep) his heir must fast on his behalf. Abu Dawud said: This applies to the fast which a man vows ; and this is the opinion of Ahmad b. Hanbal}}
\hadithdefcmd{abudawud}{2401}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي حَصِينٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِذَا مَرِضَ الرَّجُلُ فِي رَمَضَانَ ثُمَّ مَاتَ وَلَمْ يَصُمْ أُطْعِمَ عَنْهُ وَلَمْ يَكُنْ عَلَيْهِ قَضَاءٌ وَإِنْ كَانَ عَلَيْهِ نَذْرٌ قَضَى عَنْهُ وَلِيُّهُ ‏.‏\hadithno{2401}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Muquf; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Abbas:If a man falls ill during Ramadan and he dies, while he could not keep the fast, food will be provided (for the poor men) on his behalf ; there is no atonement (for his fasts) due from him. If there is some vow which he could not fulfill, his heir must atone on his behalf}}
\hadithdefcmd{abudawud}{2402}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا حَمَّادٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ حَمْزَةَ الأَسْلَمِيَّ، سَأَلَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي رَجُلٌ أَسْرُدُ الصَّوْمَ أَفَأَصُومُ فِي السَّفَرِ قَالَ ‏ "‏ صُمْ إِنْ شِئْتَ وَأَفْطِرْ إِنْ شِئْتَ ‏"‏ ‏.‏\hadithno{2402}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1121)}\hadithtrans{Narrated 'Aishah:Hamzat al-Aslami asked the Prophet (ﷺ): Messenger of Allah, I am a man who keeps perpetual fast, may I fast while on a journey? He replied: Fast if you like, or break your fast if you like}}
\hadithdefcmd{abudawud}{2403}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَجِيدِ الْمَدَنِيُّ، قَالَ سَمِعْتُ حَمْزَةَ بْنَ مُحَمَّدِ بْنِ حَمْزَةَ الأَسْلَمِيَّ، يَذْكُرُ أَنَّ أَبَاهُ، أَخْبَرَهُ عَنْ جَدِّهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي صَاحِبُ ظَهْرٍ أُعَالِجُهُ أُسَافِرُ عَلَيْهِ وَأَكْرِيهِ وَإِنَّهُ رُبَّمَا صَادَفَنِي هَذَا الشَّهْرُ - يَعْنِي رَمَضَانَ - وَأَنَا أَجِدُ الْقُوَّةَ وَأَنَا شَابٌّ وَأَجِدُ بِأَنْ أَصُومَ يَا رَسُولَ اللَّهِ أَهْوَنَ عَلَىَّ مِنْ أَنْ أُؤَخِّرَهُ فَيَكُونَ دَيْنًا أَفَأَصُومُ يَا رَسُولَ اللَّهِ أَعْظَمُ لأَجْرِي أَوْ أُفْطِرُ قَالَ ‏ "‏ أَىُّ ذَلِكَ شِئْتَ يَا حَمْزَةُ ‏"‏ ‏.‏\hadithno{2403}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Hamzat al-Aslami:I said: Messenger of Allah. I am a master of mounts and I use them ! I myself travel on them and I rent them. This month, that is, Ramadan, happend to come to me (while I am on a journey), and I find myself strong enough (to fast) as I am young, and I find that it is easier for me to fast than to postpone it, and i becomes debt due from me. Does it bring me more reward, Messenger of Allah, if I fast, or if I break ? He replied: Whichever you like, Hamzah}}
\hadithdefcmd{abudawud}{2404}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ مَنْصُورٍ، عَنْ مُجَاهِدٍ، عَنْ طَاوُسٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ خَرَجَ النَّبِيُّ صلى الله عليه وسلم مِنَ الْمَدِينَةِ إِلَى مَكَّةَ حَتَّى بَلَغَ عُسْفَانَ ثُمَّ دَعَا بِإِنَاءٍ فَرَفَعَهُ إِلَى فِيهِ لِيُرِيَهُ النَّاسَ وَذَلِكَ فِي رَمَضَانَ ‏.‏ فَكَانَ ابْنُ عَبَّاسٍ يَقُولُ قَدْ صَامَ النَّبِيُّ صلى الله عليه وسلم وَأَفْطَرَ فَمَنْ شَاءَ صَامَ وَمَنْ شَاءَ أَفْطَرَ ‏.‏\hadithno{2404}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1948) Sahih Muslim (1133)}\hadithtrans{Narrated Ibn 'Abbas:The Prophet (ﷺ) left Medina for Mecca till he reached 'Usfan, He then called for a vessel (of water). It was raised to his mouth to show it to the people, and that was in Ramadan. Ibn 'Abbas used to say: The Prophet (ﷺ) fasted and he broke his fast. He who likes may fast and he who likes may break}}
\hadithdefcmd{abudawud}{2405}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زَائِدَةُ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسٍ، قَالَ سَافَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي رَمَضَانَ فَصَامَ بَعْضُنَا وَأَفْطَرَ بَعْضُنَا فَلَمْ يَعِبِ الصَّائِمُ عَلَى الْمُفْطِرِ وَلاَ الْمُفْطِرُ عَلَى الصَّائِمِ ‏.‏\hadithno{2405}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1947) Sahih Muslim (1118)}\hadithtrans{Narrated Anas :We travelled along with the Prophet (ﷺ) during Ramadan. Some of us were fasting and other broke their fast. Those who fasted did not find fault with those who broke, and those who broke their fast did not find fault with those who fasted}}
\hadithdefcmd{abudawud}{2406}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، وَوَهْبُ بْنُ بَيَانٍ، - الْمَعْنَى - قَالاَ حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي مُعَاوِيَةُ، عَنْ رَبِيعَةَ بْنِ يَزِيدَ، أَنَّهُ حَدَّثَهُ عَنْ قَزَعَةَ، قَالَ أَتَيْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ وَهُوَ يُفْتِي النَّاسَ وَهُمْ مُكِبُّونَ عَلَيْهِ فَانْتَظَرْتُ خَلْوَتَهُ فَلَمَّا خَلاَ سَأَلْتُهُ عَنْ صِيَامِ رَمَضَانَ فِي السَّفَرِ فَقَالَ خَرَجْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي رَمَضَانَ عَامَ الْفَتْحِ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ وَنَصُومُ حَتَّى بَلَغَ مَنْزِلاً مِنَ الْمَنَازِلِ فَقَالَ ‏"‏ إِنَّكُمْ قَدْ دَنَوْتُمْ مِنْ عَدُوِّكُمْ وَالْفِطْرُ أَقْوَى لَكُمْ ‏"‏ ‏.‏ فَأَصْبَحْنَا مِنَّا الصَّائِمُ وَمِنَّا الْمُفْطِرُ - قَالَ - ثُمَّ سِرْنَا فَنَزَلْنَا مَنْزِلاً فَقَالَ ‏"‏ إِنَّكُمْ تُصَبِّحُونَ عَدُوَّكُمْ وَالْفِطْرُ أَقْوَى لَكُمْ فَأَفْطِرُوا ‏"‏ ‏.‏ فَكَانَتْ عَزِيمَةً مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو سَعِيدٍ ثُمَّ لَقَدْ رَأَيْتُنِي أَصُومُ مَعَ النَّبِيِّ صلى الله عليه وسلم قَبْلَ ذَلِكَ وَبَعْدَ ذَلِكَ ‏.‏\hadithno{2406}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (1120)}\hadithtrans{Narrated Qaza'ah: I came to Abu Sa'id al-Khudri while he was giving his legal opinion to the people who bent down on him. So I waited to see hi when he was alone. When he became alone, I asked him about keeping fast while travelling. He said: we went out along with the Prophet (ﷺ) in Ramadan in the year of conquest of Mecca. The Messenger of Allah (ﷺ) fasted and we fasted until he reached a certain stage. He said: You have come near your enemy; the breaking of fast will bring you more strength. Then morning came when some of us fasted and other broke their fast. He (Abu Sa'id al-Khudri) said: We then proceeded and alighted at a stage. He said: You are going to attack your enemy tomorrow morning ; breaking the fast will bring you more strength ; so break your fast (i.e. do not keep fast). This resolution (of breaking the fast) took place (due to the announcement) from the Messenger of Allah (ﷺ). Abu Sa'id said: Then I found myself keeping fast along with the Prophet (ﷺ) before and after that}}
\hadithdefcmd{abudawud}{2407}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، - يَعْنِي ابْنَ سَعْدِ بْنِ زُرَارَةَ - عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَسَنٍ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى رَجُلاً يُظَلَّلُ عَلَيْهِ وَالزِّحَامُ عَلَيْهِ فَقَالَ ‏ "‏ لَيْسَ مِنَ الْبِرِّ الصِّيَامُ فِي السَّفَرِ ‏"‏ ‏.‏\hadithno{2407}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1946) Sahih Muslim (1115)}\hadithtrans{Narrated Jabir b. 'Abd Allah :The Prophet (ﷺ) saw a man who had been put in the shade and saw a crowd of people around him (in the course of a journey). He said: Fasting while on journey is not part of righteousness}}
\hadithdefcmd{abudawud}{2408}{حَدَّثَنَا شَيْبَانُ بْنُ فَرُّوخَ، حَدَّثَنَا أَبُو هِلاَلٍ الرَّاسِبِيُّ، حَدَّثَنَا ابْنُ سَوَادَةَ الْقُشَيْرِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، - رَجُلٍ مِنْ بَنِي عَبْدِ اللَّهِ بْنِ كَعْبٍ إِخْوَةِ بَنِي قُشَيْرٍ - قَالَ أَغَارَتْ عَلَيْنَا خَيْلٌ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَانْتَهَيْتُ - أَوْ قَالَ فَانْطَلَقْتُ - إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يَأْكُلُ فَقَالَ ‏"‏ اجْلِسْ فَأَصِبْ مِنْ طَعَامِنَا هَذَا ‏"‏ ‏.‏ فَقُلْتُ إِنِّي صَائِمٌ ‏.‏ قَالَ ‏"‏ اجْلِسْ أُحَدِّثْكَ عَنِ الصَّلاَةِ وَعَنِ الصِّيَامِ إِنَّ اللَّهَ تَعَالَى وَضَعَ شَطْرَ الصَّلاَةِ أَوْ نِصْفَ الصَّلاَةِ وَالصَّوْمَ عَنِ الْمُسَافِرِ وَعَنِ الْمُرْضِعِ أَوِ الْحُبْلَى ‏"‏ ‏.‏ وَاللَّهِ لَقَدْ قَالَهُمَا جَمِيعًا أَوْ أَحَدَهُمَا قَالَ فَتَلَهَّفَتْ نَفْسِي أَنْ لاَ أَكُونَ أَكَلْتُ مِنْ طَعَامِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2408}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Anas ibn Malik: A man from Banu Abdullah ibn Ka'b brethren of Banu Qushayr (not Anas ibn Malik, the well-known Companion), said: A contingent from the cavalry of the Messenger of Allah (ﷺ) raided us. I reached (for he said went) to the Messenger of Allah (ﷺ) who was taking his meals. He said: Sit down, and take some from this meal of ours. I said: I am fasting, he said: Sit down, I shall tell you about prayer and fasting. Allah has remitted half the prayer to a traveller, and fasting to the traveller, the woman who is suckling an infant and the woman who is pregnant, I swear by Allah, he mentioned both (i.e. suckling and pregnant women) or one of them. I was grieved for not taking the food of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{2409}{حَدَّثَنَا مُؤَمَّلُ بْنُ الْفَضْلِ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الْعَزِيزِ، حَدَّثَنِي إِسْمَاعِيلُ بْنُ عُبَيْدِ اللَّهِ، حَدَّثَتْنِي أُمُّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، قَالَ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي بَعْضِ غَزَوَاتِهِ فِي حَرٍّ شَدِيدٍ حَتَّى إِنَّ أَحَدَنَا لَيَضَعُ يَدَهُ عَلَى رَأْسِهِ أَوْ كَفَّهُ عَلَى رَأْسِهِ مِنْ شِدَّةِ الْحَرِّ مَا فِينَا صَائِمٌ إِلاَّ رَسُولُ اللَّهِ صلى الله عليه وسلم وَعَبْدُ اللَّهِ بْنُ رَوَاحَةَ ‏.‏\hadithno{2409}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1945) Sahih Muslim (1122)}\hadithtrans{Narrated Abu al-Darda:We went out along with the Messenger of Allah (ﷺ) for some battle in intense heat, so much so that one of us placed his hand on his head, or placed his palm on his head, due to intense heat, No one of us fasted except the Messenger of Allah (ﷺ) and 'Abd Allah b. Rawahah}}
\hadithdefcmd{abudawud}{2410}{حَدَّثَنَا حَامِدُ بْنُ يَحْيَى، حَدَّثَنَا هَاشِمُ بْنُ الْقَاسِمِ، ح وَحَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ، حَدَّثَنَا أَبُو قُتَيْبَةَ، - الْمَعْنَى - قَالاَ حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ حَبِيبِ بْنِ عَبْدِ اللَّهِ الأَزْدِيُّ، حَدَّثَنِي حَبِيبُ بْنُ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ سِنَانَ بْنَ سَلَمَةَ بْنِ الْمُحَبَّقِ الْهُذَلِيَّ، يُحَدِّثُ عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَتْ لَهُ حَمُولَةٌ تَأْوِي إِلَى شِبَعٍ فَلْيَصُمْ رَمَضَانَ حَيْثُ أَدْرَكَهُ ‏"‏ ‏.‏\hadithno{2410}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salamah ibn al-Muhabbaq al-Hudhali: The Messenger of Allah (ﷺ) said: If anyone has a riding beast which carries him to where he can get sufficient food, he should keep the fast of Ramadan wherever he is when it comes}}
\hadithdefcmd{abudawud}{2411}{حَدَّثَنَا نَصْرُ بْنُ الْمُهَاجِرِ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ عَبْدِ الْوَارِثِ، حَدَّثَنَا عَبْدُ الصَّمَدِ بْنُ حَبِيبٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ سِنَانِ بْنِ سَلَمَةَ، عَنْ سَلَمَةَ بْنِ الْمُحَبَّقِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَدْرَكَهُ رَمَضَانُ فِي السَّفَرِ ‏"‏ ‏.‏ فَذَكَرَ مَعْنَاهُ ‏.‏\hadithno{2411}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Salamah b. al-Muhabbaq:The Messenger of Allah (ﷺ) as saying: If anyone is on a journey and Ramadan comes... He then narrated the rest of the tradition to the same effect}}
\hadithdefcmd{abudawud}{2412}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ يَزِيدَ، ح وَحَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَحْيَى، - الْمَعْنَى - حَدَّثَنِي سَعِيدُ بْنُ أَبِي أَيُّوبَ، وَزَادَ، جَعْفَرٌ وَاللَّيْثُ حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، أَنَّ كُلَيْبَ بْنَ ذُهْلٍ الْحَضْرَمِيَّ، أَخْبَرَهُ عَنْ عُبَيْدٍ، - قَالَ جَعْفَرٌ ابْنُ جَبْرٍ - قَالَ كُنْتُ مَعَ أَبِي بَصْرَةَ الْغِفَارِيِّ صَاحِبِ النَّبِيِّ صلى الله عليه وسلم فِي سَفِينَةٍ مِنَ الْفُسْطَاطِ فِي رَمَضَانَ فَرُفِعَ ثُمَّ قُرِّبَ غَدَاهُ - قَالَ جَعْفَرٌ فِي حَدِيثِهِ - فَلَمْ يُجَاوِزِ الْبُيُوتَ حَتَّى دَعَا بِالسُّفْرَةِ قَالَ اقْتَرِبْ ‏.‏ قُلْتُ أَلَسْتَ تَرَى الْبُيُوتَ قَالَ أَبُو بَصْرَةَ أَتَرْغَبُ عَنْ سُنَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ جَعْفَرٌ فِي حَدِيثِهِ فَأَكَلَ ‏.‏\hadithno{2412}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuBusrah al-Ghifari,: Ja'far ibn Jubayr said: I accompanied AbuBusrah al-Ghifari, a Companion of the Messenger of Allah (ﷺ), in a boat proceeding from al-Fustat (Cairo) during Ramadan. He was lifted (to the boat), then his meal was brought to him. The narrator Ja'far said in his version: He did not go beyond the houses (of the city) but he called for the dining sheet. He said (to me): Come near. I said: Do you not see the houses? AbuBusrah said: Do you detest the sunnah (practice) of the Messenger of Allah (ﷺ)? The narrator Ja'far said in his version: He then ate (it)}}
\hadithdefcmd{abudawud}{2413}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ، أَخْبَرَنَا اللَّيْثُ، - يَعْنِي ابْنَ سَعْدٍ - عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ مَنْصُورٍ الْكَلْبِيِّ، أَنَّ دِحْيَةَ بْنَ خَلِيفَةَ، خَرَجَ مِنْ قَرْيَةٍ مِنْ دِمَشْقَ مَرَّةً إِلَى قَدْرِ قَرْيَةِ عُقْبَةَ مِنَ الْفُسْطَاطِ وَذَلِكَ ثَلاَثَةُ أَمْيَالٍ فِي رَمَضَانَ ثُمَّ إِنَّهُ أَفْطَرَ وَأَفْطَرَ مَعَهُ نَاسٌ وَكَرِهَ آخَرُونَ أَنْ يُفْطِرُوا فَلَمَّا رَجَعَ إِلَى قَرْيَتِهِ قَالَ وَاللَّهِ لَقَدْ رَأَيْتُ الْيَوْمَ أَمْرًا مَا كُنْتُ أَظُنُّ أَنِّي أَرَاهُ إِنَّ قَوْمًا رَغِبُوا عَنْ هَدْىِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأَصْحَابِهِ ‏.‏ يَقُولُ ذَلِكَ لِلَّذِينَ صَامُوا ثُمَّ قَالَ عِنْدَ ذَلِكَ اللَّهُمَّ اقْبِضْنِي إِلَيْكَ ‏.‏\hadithno{2413}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Dihyah: Mansur al-Kalbi said: Dihyah ibn Khalifah once went out from a village of Damascus at as much distance as it measures between Aqabah and al-Fustat during Ramadan; and that is three miles. He then broke his fast and the people broke their fast along with him. But some of them disliked to break their fast. When he came back to his village, he said: I swear by Allah, today I witnessed a thing of which I could not even think to see. The people detested the way of the Messenger of Allah (ﷺ) and his Companions. He said this to those who fasted. At this moment he said: O Allah, make me die}}
\hadithdefcmd{abudawud}{2414}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا الْمُعْتَمِرُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، أَنَّ ابْنَ عُمَرَ، كَانَ يَخْرُجُ إِلَى الْغَابَةِ فَلاَ يُفْطِرُ وَلاَ يَقْصُرُ ‏.‏\hadithno{2414}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Nafi' said:Ibn 'Umar used to go out to al-Ghabah (jungle), but he neither broke his fast, nor shortened his prayer}}
\hadithdefcmd{abudawud}{2415}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ الْمُهَلَّبِ بْنِ أَبِي حَبِيبَةَ، حَدَّثَنَا الْحَسَنُ، عَنْ أَبِي بَكْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَقُولَنَّ أَحَدُكُمْ إِنِّي صُمْتُ رَمَضَانَ كُلَّهُ وَ قُمْتُهُ كُلَّهُ ‏"‏ ‏.‏ فَلاَ أَدْرِي أَكَرِهَ التَّزْكِيَةَ أَوْ قَالَ لاَ بُدَّ مِنْ نَوْمَةٍ أَوْ رَقْدَةٍ ‏.‏\hadithno{2415}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuBakrah: The Prophet (ﷺ) said: One of you should not say: I fasted the whole of Ramadan, and I prayed during the night in the whole of Ramadan. I do not know whether he disliked the purification; or he (the narrator) said: He must have slept a little and taken rest}}
\hadithdefcmd{abudawud}{2416}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَهَذَا حَدِيثُهُ - قَالَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ أَبِي عُبَيْدٍ، قَالَ شَهِدْتُ الْعِيدَ مَعَ عُمَرَ فَبَدَأَ بِالصَّلاَةِ قَبْلَ الْخُطْبَةِ ثُمَّ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ صِيَامِ هَذَيْنِ الْيَوْمَيْنِ أَمَّا يَوْمُ الأَضْحَى فَتَأْكُلُونَ مِنْ لَحْمِ نُسُكِكُمْ وَأَمَّا يَوْمُ الْفِطْرِ فَفِطْرُكُمْ مِنْ صِيَامِكُمْ ‏.‏\hadithno{2416}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1990) Sahih Muslim (1137)}\hadithtrans{Narrated Abu 'Ubaid:I attended the 'Id (prayer) along with 'Umar. He offered prayer before the sermon. He then said: The Messenger of Allah (ﷺ) prohibited fasting on these two days. As regards Id al-Adha, you eat the meat of your sacrificial animals. As for 'Id al-Fitr, you break (i.e. end) your fast}}
\hadithdefcmd{abudawud}{2417}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ صِيَامِ يَوْمَيْنِ يَوْمِ الْفِطْرِ وَيَوْمِ الأَضْحَى وَعَنْ لِبْسَتَيْنِ الصَّمَّاءِ وَأَنْ يَحْتَبِيَ الرَّجُلُ فِي الثَّوْبِ الْوَاحِدِ وَعَنِ الصَّلاَةِ فِي سَاعَتَيْنِ بَعْدَ الصُّبْحِ وَبَعْدَ الْعَصْرِ ‏.‏\hadithno{2417}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (1991، 1992) Sahih Muslim (827 After  1138)}\hadithtrans{Narrated Abu Sa’id Al Khudri :The Messenger of Allah (ﷺ) forbade fasting on two days, al-Fitr (breaking the fast of Ramadan) and al-Adha (the day of sacrifice), and wearing a tight single garment the raising of which discloses private parts, and sitting with one's legs drawn up and wrapped in one's garment, and forbade praying at two hours, after the Fajr prayer and after the Asr prayer}}
\hadithdefcmd{abudawud}{2418}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ يَزِيدَ بْنِ الْهَادِ، عَنْ أَبِي مُرَّةَ، مَوْلَى أُمِّ هَانِئٍ أَنَّهُ دَخَلَ مَعَ عَبْدِ اللَّهِ بْنِ عَمْرٍو عَلَى أَبِيهِ عَمْرِو بْنِ الْعَاصِ فَقَرَّبَ إِلَيْهِمَا طَعَامًا فَقَالَ كُلْ ‏.‏ فَقَالَ إِنِّي صَائِمٌ ‏.‏ فَقَالَ عَمْرٌو كُلْ فَهَذِهِ الأَيَّامُ الَّتِي كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُنَا بِإِفْطَارِهَا وَيَنْهَانَا عَنْ صِيَامِهَا ‏.‏ قَالَ مَالِكٌ وَهِيَ أَيَّامُ التَّشْرِيقِ ‏.‏\hadithno{2418}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Murrah, the client of Umm Hani, entered along with 'Abd Allah b. 'Amr upon his father 'Amr b. 'As and he brought food for him. He said:Eat. He said: I am fasting. 'Amr said: Eat, these are the days on which the Messenger of Allah (ﷺ) used to command us to break fast, and forbid us to keep fast. The narrator Malik said: These are the day of al-tashriq (i.e. 11th, 12th, and 13th of Dhu al-Hijjah)}}
\hadithdefcmd{abudawud}{2419}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا وَهْبٌ، حَدَّثَنَا مُوسَى بْنُ عُلَىٍّ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ مُوسَى بْنِ عُلَىٍّ، - وَالإِخْبَارُ فِي حَدِيثِ وَهْبٍ - قَالَ سَمِعْتُ أَبِي أَنَّهُ، سَمِعَ عُقْبَةَ بْنَ عَامِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَوْمُ عَرَفَةَ وَيَوْمُ النَّحْرِ وَأَيَّامُ التَّشْرِيقِ عِيدُنَا أَهْلَ الإِسْلاَمِ وَهِيَ أَيَّامُ أَكْلٍ وَشُرْبٍ ‏"‏ ‏.‏\hadithno{2419}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Uqbah ibn Amir: The Prophet (ﷺ) said: The day of Arafah, the day of sacrifice, the days of tashriq are (the days of) our festival, O people of Islam. These are the days of eating and drinking}}
\hadithdefcmd{abudawud}{2420}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَصُمْ أَحَدُكُمْ يَوْمَ الْجُمُعَةِ إِلاَّ أَنْ يَصُومَ قَبْلَهُ بِيَوْمٍ أَوْ بَعْدَهُ ‏"‏ ‏.‏\hadithno{2420}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1985) Sahih Muslim (1144)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: None of you must fast on Friday unless he fasts the day before or the day after}}
\hadithdefcmd{abudawud}{2421}{حَدَّثَنَا حُمَيْدُ بْنُ مَسْعَدَةَ، حَدَّثَنَا سُفْيَانُ بْنُ حَبِيبٍ، ح وَحَدَّثَنَا يَزِيدُ بْنُ قُبَيْسٍ، - مِنْ أَهْلِ جَبَلَةَ - حَدَّثَنَا الْوَلِيدُ، جَمِيعًا عَنْ ثَوْرِ بْنِ يَزِيدَ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ السُّلَمِيِّ، عَنْ أُخْتِهِ، - وَقَالَ يَزِيدُ الصَّمَّاءِ - أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَصُومُوا يَوْمَ السَّبْتِ إِلاَّ فِيمَا افْتُرِضَ عَلَيْكُمْ وَإِنْ لَمْ يَجِدْ أَحَدُكُمْ إِلاَّ لِحَاءَ عِنَبَةٍ أَوْ عُودَ شَجَرَةٍ فَلْيَمْضُغْهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَهَذَا حَدِيثٌ مَنْسُوخٌ ‏.‏\hadithno{2421}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated As-Samma' sister of Abdullah ibn Busr: The Prophet (ﷺ) said: Do not fast on Saturday except what has been made obligatory on you; and if one of you can get nothing but a grape skin or a piece of wood from a tree, he should chew it}}
\hadithdefcmd{abudawud}{2422}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، ح وَحَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَبِي أَيُّوبَ، - قَالَ حَفْصٌ الْعَتَكِيُّ - عَنْ جُوَيْرِيَةَ بِنْتِ الْحَارِثِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ عَلَيْهَا يَوْمَ الْجُمُعَةِ وَهِيَ صَائِمَةٌ فَقَالَ ‏"‏ أَصُمْتِ أَمْسِ ‏"‏ ‏.‏ قَالَتْ لاَ ‏.‏ قَالَ ‏"‏ تُرِيدِينَ أَنْ تَصُومِي غَدًا ‏"‏ ‏.‏ قَالَتْ لاَ ‏.‏ قَالَ ‏"‏ فَأَفْطِرِي ‏"‏ ‏.‏\hadithno{2422}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1986)}\hadithtrans{Narrated Juwairiyah, daughter of al-Harith:That the Prophet (ﷺ) entered upon her on Friday while she was fasting. He asked: Did you fast yesterday ? She said: No. He again asked: Do you intend to fast tomorrow ? She said: No. He said: So break your fast}}
\hadithdefcmd{abudawud}{2423}{حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ شُعَيْبٍ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ سَمِعْتُ اللَّيْثَ، يُحَدِّثُ عَنِ ابْنِ شِهَابٍ، أَنَّهُ كَانَ إِذَا ذُكِرَ لَهُ أَنَّهُ نُهِيَ عَنْ صِيَامِ يَوْمِ السَّبْتِ يَقُولُ ابْنُ شِهَابٍ هَذَا حَدِيثٌ حِمْصِيٌّ ‏.‏\hadithno{2423}\hadithgrade{Al-Albani: Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Maqtu; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Al-Laith:When it was mentioned to Ibn Shihab (al-Zuhri) that fasting on Saturday had been prohibited, he would say: This is a Himsi tradition}}
\hadithdefcmd{abudawud}{2424}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ بْنِ سُفْيَانَ، حَدَّثَنَا الْوَلِيدُ، عَنِ الأَوْزَاعِيِّ، قَالَ مَا زِلْتُ لَهُ كَاتِمًا حَتَّى رَأَيْتُهُ انْتَشَرَ ‏.‏ يَعْنِي حَدِيثَ عَبْدِ اللَّهِ بْنِ بُسْرٍ هَذَا فِي صَوْمِ يَوْمِ السَّبْتِ ‏.‏ قَالَ أَبُو دَاوُدَ قَالَ مَالِكٌ هَذَا كَذِبٌ ‏.‏\hadithno{2424}\hadithgrade{Al-Albani: Sahih Maqtu; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Maqtu; Zubair Ali Zai: Daif}\hadithtrans{Al-Auza'i said:I always concealed it, but I found that it became known widely, that is, the tradition on Ibn Busr about fasting on Saturday. Abu Dawud said: Malik said: This is a false (tradition)}}
\hadithdefcmd{abudawud}{2425}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْبَدٍ الزِّمَّانِيِّ، عَنْ أَبِي قَتَادَةَ، أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ تَصُومُ فَغَضِبَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ قَوْلِهِ فَلَمَّا رَأَى ذَلِكَ عُمَرُ قَالَ رَضِينَا بِاللَّهِ رَبًّا وَبِالإِسْلاَمِ دِينًا وَبِمُحَمَّدٍ نَبِيًّا نَعُوذُ بِاللَّهِ مِنْ غَضَبِ اللَّهِ وَمِنْ غَضَبِ رَسُولِهِ ‏.‏ فَلَمْ يَزَلْ عُمَرُ يُرَدِّدُهَا حَتَّى سَكَنَ غَضَبُ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ كَيْفَ بِمَنْ يَصُومُ الدَّهْرَ كُلَّهُ قَالَ ‏"‏ لاَ صَامَ وَلاَ أَفْطَرَ ‏"‏ ‏.‏ قَالَ مُسَدَّدٌ ‏"‏ لَمْ يَصُمْ وَلَمْ يُفْطِرْ أَوْ مَا صَامَ وَلاَ أَفْطَرَ ‏"‏ ‏.‏ شَكَّ غَيْلاَنُ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ كَيْفَ بِمَنْ يَصُومُ يَوْمَيْنِ وَيُفْطِرُ يَوْمًا قَالَ ‏"‏ أَوَيُطِيقُ ذَلِكَ أَحَدٌ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ فَكَيْفَ بِمَنْ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمًا قَالَ ‏"‏ ذَلِكَ صَوْمُ دَاوُدَ ‏"‏ ‏.‏ قَالَ يَا رَسُولَ اللَّهِ فَكَيْفَ بِمَنْ يَصُومُ يَوْمًا وَيُفْطِرُ يَوْمَيْنِ قَالَ ‏"‏ وَدِدْتُ أَنِّي طُوِّقْتُ ذَلِكَ ‏"‏ ‏.‏ ثُمَّ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ثَلاَثٌ مِنْ كُلِّ شَهْرٍ وَرَمَضَانُ إِلَى رَمَضَانَ فَهَذَا صِيَامُ الدَّهْرِ كُلِّهِ وَصِيَامُ عَرَفَةَ إِنِّي أَحْتَسِبُ عَلَى اللَّهِ أَنْ يُكَفِّرَ السَّنَةَ الَّتِي قَبْلَهُ وَالسَّنَةَ الَّتِي بَعْدَهُ وَصَوْمُ يَوْمِ عَاشُورَاءَ إِنِّي أَحْتَسِبُ عَلَى اللَّهِ أَنْ يُكَفِّرَ السَّنَةَ الَّتِي قَبْلَهُ ‏"‏ ‏.‏\hadithno{2425}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1162)}\hadithtrans{Narrated AbuQatadah: A man came to the Prophet (ﷺ) and said: How do you fast, Messenger of Allah? The Messenger of Allah (ﷺ) became angry at what he said. When Umar observed this (his anger), he said: We are satisfied with Allah as Lord, with Islam as religion, and with Muhammad as Prophet. We seek refuge in Allah from the anger of Allah, and from the anger of His Apostle. Umar continued to repeat these words till his anger cooled down. He then asked: Messenger of Allah, what is the position of one who observes a perpetual fast? He replied: May he not fast or break his fast. Musaddad said in his version: He has neither fasted nor broken his fast. The narrator, Ghaylan, doubted the actual wordings. He asked: What is the position of one who fasts two days and does not fast one day? He said: Is anyone able to do that? He asked: What is the position of one who fasts every second day (i.e. fasts one day and does not fasts the next day)? He (the Prophet) said: This is the fast that David observed. He asked: Messenger of Allah, what is the position of one who fasts one day and breaks it for two days? He replied: I wish I were given the power to observe that. Then the Messenger of Allah (ﷺ) said: The observance of three days' fast every month and of one Ramadan to the other (i.e. the fast of Ramadan every year) is (equivalent to) a perpetual fast. I seek from Allah that fasting on the day of Arafah may atone for the sins of the preceding and the coming year, and I seek from Allah that fasting on the day of Ashura' may atone for the sins of the preceding year}}
\hadithdefcmd{abudawud}{2426}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا مَهْدِيُّ، حَدَّثَنَا غَيْلاَنُ، عَنْ عَبْدِ اللَّهِ بْنِ مَعْبَدٍ الزِّمَّانِيِّ، عَنْ أَبِي قَتَادَةَ، بِهَذَا الْحَدِيثِ زَادَ قَالَ يَا رَسُولَ اللَّهِ أَرَأَيْتَ صَوْمَ يَوْمِ الاِثْنَيْنِ وَيَوْمِ الْخَمِيسِ قَالَ ‏ "‏ فِيهِ وُلِدْتُ وَفِيهِ أُنْزِلَ عَلَىَّ الْقُرْآنُ ‏"‏ ‏.‏\hadithno{2426}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The tradition mentioned above has also been transmitted by Abu Qatadah through a different chain of narrators. This version add:He said: Messenger of Allah, tell me about keeping fast on Monday and Thursday. He said: On it I was born, and on it the Qur'an was first revealed to me}}
\hadithdefcmd{abudawud}{2427}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، وَأَبِي، سَلَمَةَ عَنْ عَبْدِ اللَّهِ بْنِ عَمْرِو بْنِ الْعَاصِ، قَالَ لَقِيَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏"‏ أَلَمْ أُحَدَّثْ أَنَّكَ تَقُولُ لأَقُومَنَّ اللَّيْلَ وَلأَصُومَنَّ النَّهَارَ ‏"‏ ‏.‏ قَالَ - أَحْسِبُهُ قَالَ - نَعَمْ يَا رَسُولَ اللَّهِ قَدْ قُلْتُ ذَاكَ ‏.‏ قَالَ ‏"‏ قُمْ وَنَمْ وَصُمْ وَأَفْطِرْ وَصُمْ مِنْ كُلِّ شَهْرٍ ثَلاَثَةَ أَيَّامٍ وَذَاكَ مِثْلُ صِيَامِ الدَّهْرِ ‏"‏ ‏.‏ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ ‏.‏ قَالَ ‏"‏ فَصُمْ يَوْمًا وَأَفْطِرْ يَوْمَيْنِ ‏"‏ ‏.‏ قَالَ فَقُلْتُ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ قَالَ ‏"‏ فَصُمْ يَوْمًا وَأَفْطِرْ يَوْمًا وَهُوَ أَعْدَلُ الصِّيَامِ وَهُوَ صِيَامُ دَاوُدَ ‏"‏ ‏.‏ قُلْتُ إِنِّي أُطِيقُ أَفْضَلَ مِنْ ذَلِكَ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ أَفْضَلَ مِنْ ذَلِكَ ‏"‏ ‏.‏\hadithno{2427}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1976) Sahih Muslim (1159)}\hadithtrans{Narrated 'Abd Allah b. 'Amr b. al-'As:The Messenger of Allah (ﷺ) met me and said: Have I not been informed that you told: I shall stand at prayer all the night, and I shall fast during the day ? He said: I think so. Yes, Messenger of Allah, I have said this. He said: Get up and pray at night and sleep ; fast and break your fast ; fast three days every month: that is equivalent to keeping perpetual fast. I said: Messenger of Allah, I have more power than that. He said: Then fast one day and break your fast one day. That is the most moderate fast ; that is the fast of Dawud (David). He said: I have more power than that. The Messenger of Allah (ﷺ) said: There is no fast more excellent that it}}
\hadithdefcmd{abudawud}{2428}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، عَنْ أَبِي السَّلِيلِ، عَنْ مُجِيبَةَ الْبَاهِلِيَّةِ، عَنْ أَبِيهَا، أَوْ عَمِّهَا أَنَّهُ أَتَى رَسُولَ اللَّهِ صلى الله عليه وسلم ثُمَّ انْطَلَقَ فَأَتَاهُ بَعْدَ سَنَةٍ وَقَدْ تَغَيَّرَتْ حَالَتُهُ وَهَيْئَتُهُ فَقَالَ يَا رَسُولَ اللَّهِ أَمَا تَعْرِفُنِي قَالَ ‏"‏ وَمَنْ أَنْتَ ‏"‏ ‏.‏ قَالَ أَنَا الْبَاهِلِيُّ الَّذِي جِئْتُكَ عَامَ الأَوَّلِ ‏.‏ قَالَ ‏"‏ فَمَا غَيَّرَكَ وَقَدْ كُنْتَ حَسَنَ الْهَيْئَةِ ‏"‏ ‏.‏ قَالَ مَا أَكَلْتُ طَعَامًا إِلاَّ بِلَيْلٍ مُنْذُ فَارَقْتُكَ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لِمَ عَذَّبْتَ نَفْسَكَ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ صُمْ شَهْرَ الصَّبْرِ وَيَوْمًا مِنْ كُلِّ شَهْرٍ ‏"‏ ‏.‏ قَالَ زِدْنِي فَإِنَّ بِي قُوَّةً ‏.‏ قَالَ ‏"‏ صُمْ يَوْمَيْنِ ‏"‏ ‏.‏ قَالَ زِدْنِي ‏.‏ قَالَ ‏"‏ صُمْ ثَلاَثَةَ أَيَّامٍ ‏"‏ ‏.‏ قَالَ زِدْنِي ‏.‏ قَالَ ‏"‏ صُمْ مِنَ الْحُرُمِ وَاتْرُكْ صُمْ مِنَ الْحُرُمِ وَاتْرُكْ صُمْ مِنَ الْحُرُمِ وَاتْرُكْ ‏"‏ ‏.‏ وَقَالَ بِأَصَابِعِهِ الثَّلاَثَةِ فَضَمَّهَا ثُمَّ أَرْسَلَهَا ‏.‏\hadithno{2428}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn al-Harith ; or Uncle of Mujibah al-Bahiliyyah: The father or Uncle of Mujibah al-Bahiliyyah visited the Messenger of Allah (ﷺ). He then went away and came to him (again) after one year when his condition and appearance had changed. He said: Messenger of Allah, do you not recognize me? He asked: Who are you? He replied: I am al-Bahili who came to you last year. He said: What has changed you? You were looking well, then you were good in appearance? He said: I have only food at night since I departed from you. Thereupon the Messenger of Allah (ﷺ) said: Why did you torment yourself? Fast during Ramadan (the month of patience) and fast for one day every month. He said: Increase it for me, for I have (more) strength. He said: Fast two days. He again said: Increase it for me. He said: Fast three days. He again said: Increase it for me. He said: Fast during the inviolable months and then stop; fast during the inviolable months and then stop; fast during the inviolable months and then stop. He indicated by his three fingers, and joined them and then opened them}}
\hadithdefcmd{abudawud}{2429}{حَدَّثَنَا مُسَدَّدٌ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ أَبِي بِشْرٍ، عَنْ حُمَيْدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَفْضَلُ الصِّيَامِ بَعْدَ شَهْرِ رَمَضَانَ شَهْرُ اللَّهِ الْمُحَرَّمُ وَإِنَّ أَفْضَلَ الصَّلاَةِ بَعْدَ الْمَفْرُوضَةِ صَلاَةٌ مِنَ اللَّيْلِ ‏"‏ ‏.‏ لَمْ يَقُلْ قُتَيْبَةُ ‏"‏ شَهْرِ ‏"‏ ‏.‏ قَالَ ‏"‏ رَمَضَانَ ‏"‏ ‏.‏\hadithno{2429}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1163)}\hadithtrans{Narrated Abu Hurairah:The Messenger of Allah (ﷺ) as saying: The most excellent fast after Ramadan is Allah's month al-Muharram, and the most excellent prayer after the prescribed prayer is the prayer during night}}
\hadithdefcmd{abudawud}{2430}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُوسَى، حَدَّثَنَا عِيسَى، حَدَّثَنَا عُثْمَانُ، - يَعْنِي ابْنَ حَكِيمٍ - قَالَ سَأَلْتُ سَعِيدَ بْنَ جُبَيْرٍ عَنْ صِيَامِ رَجَبَ، فَقَالَ أَخْبَرَنِي ابْنُ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَصُومُ حَتَّى نَقُولَ لاَ يُفْطِرُ وَيُفْطِرُ حَتَّى نَقُولَ لاَ يَصُومُ ‏.‏\hadithno{2430}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1971 Mukhtasar) Sahih Muslim (1157)}\hadithtrans{Narrated 'Uthman b. Hakim:I asked Sa'id b. Jubair about fasting during Rajab. He said: Ibn 'Abbas told me that the Messenger of Allah (ﷺ) used to fast to such an extent that we thought that he would never break his fast; and he would go without fasting to such an extent that we thought he would never fast}}
\hadithdefcmd{abudawud}{2431}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَيْسٍ، سَمِعَ عَائِشَةَ، تَقُولُ كَانَ أَحَبَّ الشُّهُورِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم أَنْ يَصُومَهُ شَعْبَانُ ثُمَّ يَصِلُهُ بِرَمَضَانَ ‏.‏\hadithno{2431}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The month most liked by the Messenger of Allah (ﷺ) for fasting was Sha'ban. He then joined it with Ramadan}}
\hadithdefcmd{abudawud}{2432}{حَدَّثَنَا مُحَمَّدُ بْنُ عُثْمَانَ الْعِجْلِيُّ، حَدَّثَنَا عُبَيْدُ اللَّهِ، - يَعْنِي ابْنَ مُوسَى - عَنْ هَارُونَ بْنِ سَلْمَانَ، عَنْ عُبَيْدِ اللَّهِ بْنِ مُسْلِمٍ الْقُرَشِيِّ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ - أَوْ سُئِلَ النَّبِيُّ صلى الله عليه وسلم - عَنْ صِيَامِ الدَّهْرِ فَقَالَ ‏ "‏ إِنَّ لأَهْلِكَ عَلَيْكَ حَقًّا صُمْ رَمَضَانَ وَالَّذِي يَلِيهِ وَكُلَّ أَرْبِعَاءَ وَخَمِيسٍ فَإِذَا أَنْتَ قَدْ صُمْتَ الدَّهْرَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَافَقَهُ زَيْدٌ الْعُكْلِيُّ وَخَالَفَهُ أَبُو نُعَيْمٍ قَالَ مُسْلِمُ بْنُ عُبَيْدِ اللَّهِ ‏.‏\hadithno{2432}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Muslim al-Qurashi: I asked or someone asked the Prophet (ﷺ) about perpetual fasting. He replied: You have a duty to your family. Fast during Ramadan and the following month, and every Wednesday and Thursday. You will then have observed a perpetual fast}}
\hadithdefcmd{abudawud}{2433}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، وَسَعْدِ بْنِ سَعِيدٍ، عَنْ عُمَرَ بْنِ ثَابِتٍ الأَنْصَارِيِّ، عَنْ أَبِي أَيُّوبَ، صَاحِبِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَامَ رَمَضَانَ ثُمَّ أَتْبَعَهُ بِسِتٍّ مِنْ شَوَّالٍ فَكَأَنَّمَا صَامَ الدَّهْرَ ‏"‏ ‏.‏\hadithno{2433}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1164)}\hadithtrans{Narrated Abu Ayyub:The Prophet (ﷺ) as saying: If anyone fasts during Ramadan, then follows it with six days in Shawwal, it will be like a perpetual fast}}
\hadithdefcmd{abudawud}{2434}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، مَوْلَى عُمَرَ بْنِ عُبَيْدِ اللَّهِ عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّهَا قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ حَتَّى نَقُولَ لاَ يُفْطِرُ وَيُفْطِرُ حَتَّى نَقُولَ لاَ يَصُومُ وَمَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم اسْتَكْمَلَ صِيَامَ شَهْرٍ قَطُّ إِلاَّ رَمَضَانَ وَمَا رَأَيْتُهُ فِي شَهْرٍ أَكْثَرَ صِيَامًا مِنْهُ فِي شَعْبَانَ ‏.‏\hadithno{2434}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1969) Sahih Muslim (1156)}\hadithtrans{Narrated 'Aishah, wife of Prophet (ﷺ):The Messenger of Allah (ﷺ) used to fast to such an extent that we thought that he would never break his fast, and he would go without fasting to such an extent that we thought he would never fast. I never saw the Messenger of Allah (ﷺ) fast a complete month except in Ramadan, and I never saw his fast more in any month than in Sha'ban}}
\hadithdefcmd{abudawud}{2435}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏ زَادَ كَانَ يَصُومُهُ إِلاَّ قَلِيلاً بَلْ كَانَ يَصُومُهُ كُلَّهُ ‏.‏\hadithno{2435}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{The tradition mentioned above has alos been transmitted by Abu Hurairah through a different chain of narrators to the same effect. This version adds:He would fast all but a little of Sha'ban, rather he used to fast the whole of Sha'ban}}
\hadithdefcmd{abudawud}{2436}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، حَدَّثَنَا يَحْيَى، عَنْ عُمَرَ بْنِ أَبِي الْحَكَمِ بْنِ ثَوْبَانَ، عَنْ مَوْلَى، قُدَامَةَ بْنِ مَظْعُونٍ عَنْ مَوْلَى، أُسَامَةَ بْنِ زَيْدٍ أَنَّهُ انْطَلَقَ مَعَ أُسَامَةَ إِلَى وَادِي الْقُرَى فِي طَلَبِ مَالٍ لَهُ فَكَانَ يَصُومُ يَوْمَ الاِثْنَيْنِ وَيَوْمَ الْخَمِيسِ فَقَالَ لَهُ مَوْلاَهُ لِمَ تَصُومُ يَوْمَ الاِثْنَيْنِ وَيَوْمَ الْخَمِيسِ وَأَنْتَ شَيْخٌ كَبِيرٌ فَقَالَ إِنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَصُومُ يَوْمَ الاِثْنَيْنِ وَيَوْمَ الْخَمِيسِ وَسُئِلَ عَنْ ذَلِكَ فَقَالَ ‏ "‏ إِنَّ أَعْمَالَ الْعِبَادِ تُعْرَضُ يَوْمَ الاِثْنَيْنِ وَيَوْمَ الْخَمِيسِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ كَذَا قَالَ هِشَامٌ الدَّسْتَوَائِيُّ عَنْ يَحْيَى عَنْ عُمَرَ بْنِ أَبِي الْحَكَمِ ‏.‏\hadithno{2436}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Usamah ibn Zayd: The client of Usamah ibn Zayd said that he went along with Usamah to Wadi al-Qura in pursuit of his camels. He would fast on Monday and Thursday. His client said to him: Why do you fast on Monday and Thursday, while you are an old man? He said: The Prophet of Allah (ﷺ) used to fast on Monday and Thursday. When he was asked about it, he said: The works of the servants (of Allah) are presented (to Allah) on Monday and Thursday}}
\hadithdefcmd{abudawud}{2437}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الْحُرِّ بْنِ الصَّبَّاحِ، عَنْ هُنَيْدَةَ بْنِ خَالِدٍ، عَنِ امْرَأَتِهِ، عَنْ بَعْضِ، أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ تِسْعَ ذِي الْحِجَّةِ وَيَوْمَ عَاشُورَاءَ وَثَلاَثَةَ أَيَّامٍ مِنْ كُلِّ شَهْرٍ أَوَّلَ اثْنَيْنِ مِنَ الشَّهْرِ وَالْخَمِيسَ ‏.‏\hadithno{2437}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated One of the wives of the Prophet: Hunaydah ibn Khalid narrated from his wife on the authority of one of the wives of the Prophet (ﷺ) who said: The Messenger of Allah (ﷺ) used to fast the first nine days of Dhul-Hijjah, Ashura' and three days of every month, that is, the first Monday (of the month) and Thursday}}
\hadithdefcmd{abudawud}{2438}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، وَمُجَاهِدٍ، وَمُسْلِمٍ الْبَطِينِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا مِنْ أَيَّامٍ الْعَمَلُ الصَّالِحُ فِيهَا أَحَبُّ إِلَى اللَّهِ مِنْ هَذِهِ الأَيَّامِ ‏"‏ ‏.‏ يَعْنِي أَيَّامَ الْعَشْرِ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَلاَ الْجِهَادُ فِي سَبِيلِ اللَّهِ قَالَ ‏"‏ وَلاَ الْجِهَادُ فِي سَبِيلِ اللَّهِ إِلاَّ رَجُلٌ خَرَجَ بِنَفْسِهِ وَمَالِهِ فَلَمْ يَرْجِعْ مِنْ ذَلِكَ بِشَىْءٍ ‏"‏ ‏.‏\hadithno{2438}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (969)}\hadithtrans{Narrated Ibn 'Abbas:The Messenger of Allah (ﷺ) as saying: There is no virtue more to the liking of Allah in any day than in these days, that is, the first ten days of Dhu al-Hijjah. They (the Companions) asked: Messenger of Allah, not even the struggle in the path of Allah (Jihad) ? He said: (Yes), not even the struggle in the path of Allah, except a man who goes out (in the path of Allah) with his life and property, and does not return with any of them}}
\hadithdefcmd{abudawud}{2439}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ مَا رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم صَائِمًا الْعَشْرَ قَطُّ ‏.‏\hadithno{2439}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1176)}\hadithtrans{Aishah said:I never saw the Messenger of Allah (ﷺ) fasting during the first ten days of Dhu al-Hijjah}}
\hadithdefcmd{abudawud}{2440}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا حَوْشَبُ بْنُ عَقِيلٍ، عَنْ مَهْدِيٍّ الْهَجَرِيِّ، حَدَّثَنَا عِكْرِمَةُ، قَالَ كُنَّا عِنْدَ أَبِي هُرَيْرَةَ فِي بَيْتِهِ فَحَدَّثَنَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ صَوْمِ يَوْ��ِ عَرَفَةَ بِعَرَفَةَ ‏.‏\hadithno{2440}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: Ikrimah said: We were with AbuHurayrah in his house when he narrated to us: The Messenger of Allah (ﷺ) prohibited fasting on the day of Arafah at Arafah}}
\hadithdefcmd{abudawud}{2441}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ أَبِي النَّضْرِ، عَنْ عُمَيْرٍ، مَوْلَى عَبْدِ اللَّهِ بْنِ عَبَّاسٍ عَنْ أُمِّ الْفَضْلِ بِنْتِ الْحَارِثِ، أَنَّ نَاسًا، تَمَارَوْا عِنْدَهَا يَوْمَ عَرَفَةَ فِي صَوْمِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ بَعْضُهُمْ هُوَ صَائِمٌ ‏.‏ وَقَالَ بَعْضُهُمْ لَيْسَ بِصَائِمٍ ‏.‏ فَأَرْسَلَتْ إِلَيْهِ بِقَدَحِ لَبَنٍ وَهُوَ وَاقِفٌ عَلَى بَعِيرِهِ بِعَرَفَةَ فَشَرِبَ ‏.‏\hadithno{2441}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1988) Sahih Muslim (1123)}\hadithtrans{Umm al-Fadl, daughter of al-Harith, said:On the day of 'Arafah some people near her argued whether the Messenger of Allah (ﷺ) was fasting, some saying that he was, and others saying that he was not. I, therefore, sent him a cup of milk while he was observing the halt at 'Arafah on his camel, and he drank it}}
\hadithdefcmd{abudawud}{2442}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ يَوْمُ عَاشُورَاءَ يَوْمًا تَصُومُهُ قُرَيْشٌ فِي الْجَاهِلِيَّةِ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُهُ فِي الْجَاهِلِيَّةِ فَلَمَّا قَدِمَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْمَدِينَةَ صَامَهُ وَأَمَرَ بِصِيَامِهِ فَلَمَّا فُرِضَ رَمَضَانُ كَانَ هُوَ الْفَرِيضَةَ وَتُرِكَ عَاشُورَاءُ فَمَنْ شَاءَ صَامَهُ وَمَنْ شَاءَ تَرَكَهُ ‏.‏\hadithno{2442}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2002) Sahih Muslim (1125)}\hadithtrans{Aishah said:The Quraish used to fast on the day of 'Ashurah in pre Islamic days. The Messenger of Allah (ﷺ) would fast on it in pre-Islamic period. When the Messenger of Allah (ﷺ) came to Medina, he fasted on it and commanded to fast on it. When the fast of Ramadan was prescribed, that became obligatory, and (fasting on) 'Ashurah was abandoned. He who wishes may fast on it and he who wishes may leave it}}
\hadithdefcmd{abudawud}{2443}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ أَخْبَرَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ عَاشُورَاءُ يَوْمًا نَصُومُهُ فِي الْجَاهِلِيَّةِ فَلَمَّا نَزَلَ رَمَضَانُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ هَذَا يَوْمٌ مِنْ أَيَّامِ اللَّهِ فَمَنْ شَاءَ صَامَهُ وَمَنْ شَاءَ تَرَكَهُ ‏"‏ ‏.‏\hadithno{2443}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4501) Sahih Muslim (1126)}\hadithtrans{Ibn 'Umar said:'Ashurah was a day on which we used to fast in pre-Islamic days. When (fasting of) Ramadan was prescribed, the Messenger of Allah (ﷺ) said: This is one of the days of Allah ; he who wishes may fast on it}}
\hadithdefcmd{abudawud}{2444}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، حَدَّثَنَا هُشَيْمٌ، حَدَّثَنَا أَبُو بِشْرٍ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا قَدِمَ النَّبِيُّ صلى الله عليه وسلم الْمَدِينَةَ وَجَدَ الْيَهُودَ يَصُومُونَ عَاشُورَاءَ فَسُئِلُوا عَنْ ذَلِكَ فَقَالُوا هَذَا الْيَوْمُ الَّذِي أَظْهَرَ اللَّهُ فِيهِ مُوسَى عَلَى فِرْعَوْنَ وَنَحْنُ نَصُومُهُ تَعْظِيمًا لَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ نَحْنُ أَوْلَى بِمُوسَى مِنْكُمْ ‏"‏ ‏.‏ وَأَمَرَ بِصِيَامِهِ ‏.‏\hadithno{2444}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (3943) Sahih Muslim (1130)}\hadithtrans{Ibn 'Abbas said:When the Prophet (ﷺ) came to Medina, he found the Jews observing fast on the day of 'Ashurah; so they were asked about it (by the Prophet). They said: This is a day on which Allah gave Moses domination over Pharaoh. We fast on it out of reverence to him. The Messenger of Allah (ﷺ) said: We have a closer connection with Moses than you have. He then gave orders that it should be observed}}
\hadithdefcmd{abudawud}{2445}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يَحْيَى بْنُ أَيُّوبَ، أَنَّ إِسْمَاعِيلَ بْنَ أُمَيَّةَ الْقُرَشِيَّ، حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا غَطَفَانَ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَبَّاسٍ، يَقُولُ حِينَ صَامَ النَّبِيُّ صلى الله عليه وسلم يَوْمَ عَاشُورَاءَ وَأَمَرَنَا بِصِيَامِهِ قَالُوا يَا رَسُولَ اللَّهِ إِنَّهُ يَوْمٌ تُعَظِّمُهُ الْيَهُودُ وَالنَّصَارَى ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ فَإِذَا كَانَ الْعَامُ الْمُقْبِلُ صُمْنَا يَوْمَ التَّاسِعِ ‏"‏ ‏.‏ فَلَمْ يَأْتِ الْعَامُ الْمُقْبِلُ حَتَّى تُوُفِّيَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2445}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1134)}\hadithtrans{Ibn 'Abbas said:When the Prophet (ﷺ) on the day of 'Ashurah and commanded us to fast on it, they (i.e. Companions) said: Messenger of Allah, this is a day which is considered great by Jews and Christians ? The Messenger of Allah (ﷺ) said: When the next year comes, we shall fast on the 9th of Muharram. But the next year the Messenger of Allah (ﷺ) breathed his last}}
\hadithdefcmd{abudawud}{2446}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - عَنْ مُعَاوِيَةَ بْنِ غَلاَبٍ، ح وَحَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، أَخْبَرَنِي حَاجِبُ بْنُ عُمَرَ، - جَمِيعًا الْمَعْنَى - عَنِ الْحَكَمِ بْنِ الأَعْرَجِ، قَالَ أَتَيْتُ ابْنَ عَبَّاسٍ وَهُوَ مُتَوَسِّدٌ رِدَاءَهُ فِي الْمَسْجِدِ الْحَرَامِ فَسَأَلْتُهُ عَنْ صَوْمِ يَوْمِ عَاشُورَاءَ فَقَالَ إِذَا رَأَيْتَ هِلاَلَ الْمُحَرَّمِ فَاعْدُدْ فَإِذَا كَانَ يَوْمُ التَّاسِعِ فَأَصْبِحْ صَائِمًا ‏.‏ فَقُلْتُ كَذَا كَانَ مُحَمَّدٌ صلى الله عليه وسلم يَصُومُ فَقَالَ كَذَلِكَ كَانَ مُحَمَّدٌ صلى الله عليه وسلم يَصُومُ ‏.‏\hadithno{2446}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1133)}\hadithtrans{Al-Hakam b. al-A'raj said:I came to Ibn 'Abbas who was leaning against his sheet of cloth in the Sacred Mosque (al-Masjid al-Haram). I asked him about fasting on the day of 'Ashurah. He said: When you sight the moon of al-Muharram, count (the days). When the 9th of Muharram comes, fast from the morning. I said: Would Muhammad (ﷺ) observe this fast ? He replied: Thus Muhammad (ﷺ) used to fast}}
\hadithdefcmd{abudawud}{2447}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمِنْهَالِ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ مَسْلَمَةَ، عَنْ عَمِّهِ، أَنَّ أَسْلَمَ، أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏"‏ صُمْتُمْ يَوْمَكُمْ هَذَا ‏"‏ ‏.‏ قَالُوا لاَ ‏.‏ قَالَ ‏"‏ فَأَتِمُّوا بَقِيَّةَ يَوْمِكُمْ وَاقْضُوهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ يَعْنِي يَوْمَ عَاشُورَاءَ ‏.‏\hadithno{2447}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbdurRahman ibn Maslamah: AbdurRahman reported on the authority of his uncle that the people of the tribe Aslam came to the Prophet (ﷺ). He said (to them): Did you fast on this day? They replied: No. He said: Complete the rest of your day, and make atonement for it}}
\hadithdefcmd{abudawud}{2448}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَمُحَمَّدُ بْنُ عِيسَى، وَمُسَدَّدٌ، - وَالإِخْبَارُ فِي حَدِيثِ أَحْمَدَ - قَالُوا حَدَّثَنَا سُفْيَانُ قَالَ سَمِعْتُ عَمْرًا قَالَ أَخْبَرَنِي عَمْرُو بْنُ أَوْسٍ سَمِعَهُ مِنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَحَبُّ الصِّيَامِ إِلَى اللَّهِ تَعَالَى صِيَامُ دَاوُدَ وَأَحَبُّ الصَّلاَةِ إِلَى اللَّهِ صَلاَةُ دَاوُدَ كَانَ يَنَامُ نِصْفَهُ وَيَقُومُ ثُلُثَهُ وَيَنَامُ سُدُسَهُ وَكَانَ يُفْطِرُ يَوْمًا وَيَصُومُ يَوْمًا ‏"‏ ‏.‏\hadithno{2448}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1131) Sahih Muslim (1159)}\hadithtrans{Abd Allah b. 'And (b. al-'As) said:The Messenger of Allah (ﷺ) said to me: The fast most liked by Allah is the one observed by Dawud (David), and the prayer dearer to Allah is the one offered by Dawud (David): he would sleep half the night, and stand (in prayer) one-third of it, and sleep one-sixth of it. He would go without fasting one day, and fast the other day}}
\hadithdefcmd{abudawud}{2449}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا هَمَّامٌ، عَنْ أَنَسٍ، أَخِي مُحَمَّدٍ عَنِ ابْنِ مِلْحَانَ الْقَيْسِيِّ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُنَا أَنْ نَصُومَ الْبِيضَ ثَلاَثَ عَشْرَةَ وَأَرْبَعَ عَشْرَةَ وَخَمْسَ عَشْرَةَ ‏.‏ قَالَ وَقَالَ ‏ "‏ هُنَّ كَهَيْئَةِ الدَّهْرِ ‏"‏ ‏.‏\hadithno{2449}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Qatadah Ibn Malhan al-Qaysi: The Messenger of Allah (ﷺ) used to command us to fast the days of the white (nights): thirteenth, fourteenth and fifteenth of the month. He said: This is like keeping perpetual fast}}
\hadithdefcmd{abudawud}{2450}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا شَيْبَانُ، عَنْ عَاصِمٍ، عَنْ زِرٍّ، عَنْ عَبْدِ اللَّهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ - يَعْنِي مِنْ غُرَّةِ كُلِّ شَهْرٍ - ثَلاَثَةَ أَيَّامٍ ‏.‏\hadithno{2450}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Messenger of Allah (ﷺ) used to fast three days every month}}
\hadithdefcmd{abudawud}{2451}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ عَاصِمِ بْنِ بَهْدَلَةَ، عَنْ سَوَاءٍ الْخُزَاعِيِّ، عَنْ حَفْصَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ ثَلاَثَةَ أَيَّامٍ مِنَ الشَّهْرِ الاِثْنَيْنِ وَالْخَمِيسِ وَالاِثْنَيْنِ مِنَ الْجُمُعَةِ الأُخْرَى ‏.‏\hadithno{2451}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Hafsah, Ummul Mu'minin: The apostle of Allah (ﷺ) used to fast three days every month: Monday, Thursday and Monday in the next week}}
\hadithdefcmd{abudawud}{2452}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، حَدَّثَنَا الْحَسَنُ بْنُ عُبَيْدِ اللَّهِ، عَنْ هُنَيْدَةَ الْخُزَاعِيِّ، عَنْ أُمِّهِ، قَالَتْ دَخَلْتُ عَلَى أُمِّ سَلَمَةَ فَسَأَلْتُهَا عَنِ الصِّيَامِ فَقَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَأْمُرُنِي أَنْ أَصُومَ ثَلاَثَةَ أَيَّامٍ مِنْ كُلِّ شَهْرٍ أَوَّلُهَا الاِثْنَيْنِ وَالْخَمِيسِ ‏.‏\hadithno{2452}\hadithgrade{Al-Albani: Munkar; Muhammad Muhyi Al-Din Abdul Hamid: Munkar; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Umm Salamah, Ummul Mu'minin: Hunaydah al-Khuza'i reported on the authority of her mother who said: I entered upon Umm Salamah and asked her about fasting. She said: The Messenger of Allah (ﷺ) used to command me to fast three days every month beginning with Monday or Thursday}}
\hadithdefcmd{abudawud}{2453}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ يَزِيدَ الرِّشْكِ، عَنْ مُعَاذَةَ، قَالَتْ قُلْتُ لِعَائِشَةَ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَصُومُ مِنْ كُلِّ شَهْرٍ ثَلاَثَةَ أَيَّامٍ قَالَتْ نَعَمْ ‏.‏ قُلْتُ مِنْ أَىِّ شَهْرٍ كَانَ يَصُومُ قَالَتْ مَا كَانَ يُبَالِي مِنْ أَىِّ أَيَّامِ الشَّهْرِ كَانَ يَصُومُ ‏.‏\hadithno{2453}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1160)}\hadithtrans{Mu'adhah (al-'Adawiyyah) said:I asked 'Aishah: Would the Messenger of Allah (ﷺ) fast three days every month ? She replied: Yes. I asked: Which days in the month he used to fast ? She replied: He did not care which days of the month he fasted}}
\hadithdefcmd{abudawud}{2454}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي ابْنُ لَهِيعَةَ، وَيَحْيَى بْنُ أَيُّوبَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ حَزْمٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنْ حَفْصَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَمْ يُجْمِعِ الصِّيَامَ قَبْلَ الْفَجْرِ فَلاَ صِيَامَ لَهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ اللَّيْثُ وَإِسْحَاقُ بْنُ حَازِمٍ أَيْضًا جَمِيعًا عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ مِثْلَهُ وَوَقَفَهُ عَلَى حَفْصَةَ مَعْمَرٌ وَالزُّبَيْدِيُّ وَابْنُ عُيَيْنَةَ وَيُونُسُ الأَيْلِيُّ كُلُّهُمْ عَنِ الزُّهْرِيِّ ‏.‏\hadithno{2454}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Hafsah, Ummul Mu'minin: The Messenger of Allah (ﷺ) said: He who does not determine to fast before dawn does not fast}}
\hadithdefcmd{abudawud}{2455}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، حَدَّثَنَا سُفْيَانُ، ح وَحَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، جَمِيعًا عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ عَائِشَةَ بِنْتِ طَلْحَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا دَخَلَ عَلَىَّ قَالَ ‏"‏ هَلْ عِنْدَكُمْ طَعَامٌ ‏"‏ ‏.‏ فَإِذَا قُلْنَا لاَ قَالَ ‏"‏ إِنِّي صَائِمٌ ‏"‏ ‏.‏ زَادَ وَكِيعٌ فَدَخَلَ عَلَيْنَا يَوْمًا آخَرَ فَقُلْنَا يَا رَسُولَ اللَّهِ أُهْدِيَ لَنَا حَيْسٌ فَحَبَسْنَاهُ لَكَ ‏.‏ فَقَالَ ‏"‏ أَدْنِيهِ ‏"‏ ‏.‏ قَالَ طَلْحَةُ فَأَصْبَحَ صَائِمًا وَأَفْطَرَ ‏.‏\hadithno{2455}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1154)}\hadithtrans{Aishah said:When the Prophet (ﷺ) entered upon me, he would ask: Do you have food ? When we said: No, he would say: I am fasting. Waki' added in his version: Another day when he entered upon us, we said: Messenger of Allah, some pudding (hair) has been presented to us and we have retained it for you. He said: Bring it to me. Talhah said: He fasted in the morning, but broke his fast (that day)}}
\hadithdefcmd{abudawud}{2456}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرُ بْنُ عَبْدِ الْحَمِيدِ، عَنْ يَزِيدَ بْنِ أَبِي زِيَادٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ، عَنْ أُمِّ هَانِئٍ، قَالَتْ لَمَّا كَانَ يَوْمُ الْفَتْحِ فَتْحِ مَكَّةَ جَاءَتْ فَاطِمَةُ فَجَلَسَتْ عَنْ يَسَارِ رَسُولِ اللَّهِ صلى الله عليه وسلم وَأُمُّ هَانِئٍ عَنْ يَمِينِهِ قَالَتْ فَجَاءَتِ الْوَلِيدَةُ بِإِنَاءٍ فِيهِ شَرَابٌ فَنَاوَلَتْهُ فَشَرِبَ مِنْهُ ثُمَّ نَاوَلَهُ أُمَّ هَانِئٍ فَشَرِبَتْ مِنْهُ فَقَالَتْ يَا رَسُولَ اللَّهِ لَقَدْ أَفْطَرْتُ وَكُنْتُ صَائِمَةً ‏.‏ فَقَالَ لَهَا ‏"‏ أَكُنْتِ تَقْضِينَ شَيْئًا ‏"‏ ‏.‏ قَالَتْ لاَ ‏.‏ قَالَ ‏"‏ فَلاَ يَضُرُّكِ إِنْ كَانَ تَطَوُّعًا ‏"‏ ‏.‏\hadithno{2456}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Umm Hani: On the days of the conquest of Mecca, when Mecca was captured, Fatimah came and sat on the left side of the Messenger of Allah (ﷺ), and Umm Hani was on his right side. A slave-girl brought a vessel which contained some drink; she gave it to him and he drank of it. He then gave it to Umm Hani who drank of it. She said: Messenger of Allah, I have broken my fast; I was fasting. He said to her: Were you making atonement for something? She replied: No. He said: Then it does not harm you if it was voluntary (fast)}}
\hadithdefcmd{abudawud}{2457}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي حَيْوَةُ بْنُ شُرَيْحٍ، عَنِ ابْنِ الْهَادِ، عَنْ زُمَيْلٍ، مَوْلَى عُرْوَةَ عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ أُهْدِيَ لِي وَلِحَفْصَةَ طَعَامٌ وَكُنَّا صَائِمَتَيْنِ فَأَفْطَرْنَا ثُمَّ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقُلْنَا لَهُ يَا رَسُولَ اللَّهِ إِنَّا أُهْدِيَتْ لَنَا هَدِيَّةٌ فَاشْتَهَيْنَاهَا فَأَفْطَرْنَا فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ عَلَيْكُمَا صُومَا مَكَانَهُ يَوْمًا آخَرَ ‏"‏ ‏.‏\hadithno{2457}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Some food was presented to me and Hafsah. We were fasting, but broke our fast. Then the Messenger of Allah (ﷺ) entered upon us. We said to him: A gift was presented to us; we coveted it and we broke our fast. The Messenger of Allah (ﷺ) said: There is no harm to you; keep a fast another day in lieu of it}}
\hadithdefcmd{abudawud}{2458}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تَصُومُ الْمَرْأَةُ وَبَعْلُهَا شَاهِدٌ إِلاَّ بِإِذْنِهِ غَيْرَ رَمَضَانَ وَلاَ تَأْذَنُ فِي بَيْتِهِ وَهُوَ شَاهِدٌ إِلاَّ بِإِذْنِهِ ‏"‏ ‏.‏\hadithno{2458}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5192) Sahih Muslim (1026)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying:It is not allowable for a woman to keep (voluntary) fast when her husband is present without his permission, and she may not allow anyone to enter his house without his permission}}
\hadithdefcmd{abudawud}{2459}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ جَاءَتِ امْرَأَةٌ إِلَى النَّبِيِّ صلى الله عليه وسلم وَنَحْنُ عِنْدَهُ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّ زَوْجِي صَفْوَانَ بْنَ الْمُعَطَّلِ يَضْرِبُنِي إِذَا صَلَّيْتُ وَيُفَطِّرُنِي إِذَا صُمْتُ وَلاَ يُصَلِّي صَلاَةَ الْفَجْرِ حَتَّى تَطْلُعَ الشَّمْسُ ‏.‏ قَالَ وَصَفْوَانُ عِنْدَهُ ‏.‏ قَالَ فَسَأَلَهُ عَمَّا قَالَتْ فَقَالَ يَا رَسُولَ اللَّهِ أَمَّا قَوْلُهَا يَضْرِبُنِي إِذَا صَلَّيْتُ فَإِنَّهَا تَقْرَأُ بِسُورَتَيْنِ وَقَدْ نَهَيْتُهَا ‏.‏ قَالَ فَقَالَ ‏"‏ لَوْ كَانَتْ سُورَةً وَاحِدَةً لَكَفَتِ النَّاسَ ‏"‏ ‏.‏ وَأَمَّا قَوْلُهَا يُفَطِّرُنِي فَإِنَّهَا تَنْطَلِقُ فَتَصُومُ وَأَنَا رَجُلٌ شَابٌّ فَلاَ أَصْبِرُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَئِذٍ ‏"‏ لاَ تَصُومُ امْرَأَةٌ إِلاَّ بِإِذْنِ زَوْجِهَا ‏"‏ ‏.‏ وَأَمَّا قَوْلُهَا إِنِّي لاَ أُصَلِّي حَتَّى تَطْلُعَ الشَّمْسُ فَإِنَّا أَهْلُ بَيْتٍ قَدْ عُرِفَ لَنَا ذَاكَ لاَ نَكَادُ نَسْتَيْقِظُ حَتَّى تَطْلُعَ الشَّمْسُ ‏.‏ قَالَ ‏"‏ فَإِذَا اسْتَيْقَظْتَ فَصَلِّ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ حَمَّادٌ - يَعْنِي ابْنَ سَلَمَةَ - عَنْ حُمَيْدٍ أَوْ ثَابِتٍ عَنْ أَبِي الْمُتَوَكِّلِ ‏.‏\hadithno{2459}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: A woman came to the Prophet (ﷺ) while we were with him. She said: Messenger of Allah, my husband, Safwan ibn al-Mu'attal, beats me when I pray, and makes me break my fast when I keep a fast, and he does not offer the dawn prayer until the sun rises. He asked Safwan, who was present, about what she had said. He replied: Messenger of Allah, as for her statement "he beats me when I pray", she recites two surahs (during prayer) and I have prohibited her (to do so). He (the Prophet) said: If one surah is recited (during prayer), that is sufficient for the people. (Safwan continued:) As regards her saying "he makes me break my fast," she dotes on fasting; I am a young man, I cannot restrain myself. The Messenger of Allah (ﷺ) said on that day: A woman should not fast except with the permission of her husband. (Safwan said:) As for her statement that I do not pray until the sun rises, we are a people belonging to a class, and that (our profession of supplying water) is already known about us. We do not awake until the sun rises. He said: When you awake, offer your prayer}}
\hadithdefcmd{abudawud}{2460}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو خَالِدٍ، عَنْ هِشَامٍ، عَنِ ابْنِ سِيرِينَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دُعِيَ أَحَدُكُمْ فَلْيُجِبْ فَإِنْ كَانَ مُفْطِرًا فَلْيَطْعَمْ وَإِنْ كَانَ صَائِمًا فَلْيُصَلِّ ‏"‏ ‏.‏ قَالَ هِشَامٌ وَالصَّلاَةُ الدُّعَاءُ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ حَفْصُ بْنُ غِيَاثٍ أَيْضًا عَنْ هِشَامٍ ‏.‏\hadithno{2460}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1431)}\hadithtrans{Abu Hurairah reported the Messenger of Allah (ﷺ) as saying:When one of you receives an invitation (for a meal), he should accept it. If he isn to fasting, he should eat, and if he is fasten, he should pray. Hisham said: The word salat means to pray (for him to Allah). Abu Dawud said: This tradition has also been narrated by Hafs b. Ghiyath from Hisham}}
\hadithdefcmd{abudawud}{2461}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا دُعِيَ أَحَدُكُمْ إِلَى طَعَامٍ وَهُوَ صَائِمٌ فَلْيَقُلْ إِنِّي صَائِمٌ ‏"‏ ‏.‏\hadithno{2461}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1150)}\hadithtrans{Abu Hurairah reported Messenger of Allah (ﷺ) as saying:When one of you is invited (to a meal), and he is fasting, he should say that he is fasting}}
\hadithdefcmd{abudawud}{2462}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَعْتَكِفُ الْعَشْرَ الأَوَاخِرَ مِنْ رَمَضَانَ حَتَّى قَبَضَهُ اللَّهُ ثُمَّ اعْتَكَفَ أَزْوَاجُهُ مِنْ بَعْدِهِ ‏.‏\hadithno{2462}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2026) Sahih Muslim (1172)}\hadithtrans{Aishah said:The Prophet (ﷺ) used to observe retirement (i'tikaf) to the mosque during the last ten days of Ramadan till Allah took him, and then his wives observed retirement to the mosque after his death}}
\hadithdefcmd{abudawud}{2463}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا ثَابِتٌ، عَنْ أَبِي رَافِعٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَعْتَكِفُ الْعَشْرَ الأَوَاخِرَ مِنْ رَمَضَانَ فَلَمْ يَعْتَكِفْ عَامًا فَلَمَّا كَانَ الْعَامُ الْمُقْبِلُ اعْتَكَفَ عِشْرِينَ لَيْلَةً ‏.‏\hadithno{2463}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Ubayy ibn Ka'b: The Prophet (ﷺ) used to observe i'tikaf during the last ten days of Ramadan. One year he did not observe i'tikaf. When the next year came, he observed i'tikaf for twenty nights (i.e. days)}}
\hadithdefcmd{abudawud}{2464}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، وَيَعْلَى بْنُ عُبَيْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عَمْرَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَعْتَكِفَ صَلَّى الْفَجْرَ ثُمَّ دَخَلَ مُعْتَكَفَهُ ‏.‏ قَالَتْ وَإِنَّهُ أَرَادَ مَرَّةً أَنْ يَعْتَكِفَ فِي الْعَشْرِ الأَوَاخِرِ مِنْ رَمَضَانَ ‏.‏ قَالَتْ فَأَمَرَ بِبِنَائِهِ فَضُرِبَ فَلَمَّا رَأَيْتُ ذَلِكَ أَمَرْتُ بِبِنَائِي فَضُرِبَ ‏.‏ قَالَتْ وَأَمَرَ غَيْرِي مِنْ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم بِبِنَائِهِ فَضُرِبَ فَلَمَّا صَلَّى الْفَجْرَ نَظَرَ إِلَى الأَبْنِيَةِ فَقَالَ ‏ "‏ مَا هَذِهِ آلْبِرَّ تُرِدْنَ ‏"‏ ‏.‏ قَالَتْ فَأَمَرَ بِبِنَائِهِ فَقُوِّضَ وَأَمَرَ أَزْوَاجُهُ بِأَبْنِيَتِهِنَّ فَقُوِّضَتْ ثُمَّ أَخَّرَ الاِعْتِكَافَ إِلَى الْعَشْرِ الأُوَلِ يَعْنِي مِنْ شَوَّالٍ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ابْنُ إِسْحَاقَ وَالأَوْزَاعِيُّ عَنْ يَحْيَى بْنِ سَعِيدٍ نَحْوَهُ وَرَوَاهُ مَالِكٌ عَنْ يَحْيَى بْنِ سَعِيدٍ قَالَ اعْتَكَفَ عِشْرِينَ مِنْ شَوَّالٍ ‏.‏\hadithno{2464}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2033) Sahih Muslim (1173)}\hadithtrans{Aishah said:When the Messenger of Allah (ﷺ) intended to observe I'tikaf, he prayed the fajr prayer and then entered his place of seclusion. Once he intended to observe I'tikaf during the last ten days of Ramadan. She said: He ordered to pitch a tent for him, and it was pitched. She said: The other wives of the Prophet (ﷺ) also ordered to pitch tents for them and they were pitched. When he offered the fajr prayer, he saw the tents, and said: What is this ? Did you intend to do an act of virtue ? She said: He then ordered to demolish his tent, and it was demolished. Then his wives also ordered to demolish their tents and they were demolished. He then postponed I'tikaf till the first ten days, that is of Shawwal. Abu Dawud said: This tradition has been transmitted by Ibn Ishaq and al-Auza'i from Yahya b. Sa'id in a similar manner, and Malik narrated it from Yahya b. Sa'id, saying: He observed I'tikaf during twenty days of Shawwal}}
\hadithdefcmd{abudawud}{2465}{حَدَّثَنَا سُلَيْمَانُ بْنُ دَاوُدَ الْمَهْرِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، أَنَّ نَافِعًا، أَخْبَرَهُ عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَعْتَكِفُ الْعَشْرَ الأَوَاخِرَ مِنْ رَمَضَانَ ‏.‏ قَالَ نَافِعٌ وَقَدْ أَرَانِي عَبْدُ اللَّهِ الْمَكَانَ الَّذِي يَعْتَكِفُ فِيهِ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنَ الْمَسْجِدِ ‏.‏\hadithno{2465}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2025) Sahih Muslim (1171)}\hadithtrans{Ibn 'Umar said:The Prophet (ﷺ) used to observe I'tikaf during the last ten days of Ramadan. Nafi' said: 'Abd Allah (b. 'Umar) showed me the place in the mosque where Messenger of Allah (ﷺ) used to observe I'tikaf}}
\hadithdefcmd{abudawud}{2466}{حَدَّثَنَا هَنَّادٌ، عَنْ أَبِي بَكْرٍ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَعْتَكِفُ كُلَّ رَمَضَانَ عَشَرَةَ أَيَّامٍ فَلَمَّا كَانَ الْعَامُ الَّذِي قُبِضَ فِيهِ اعْتَكَفَ عِشْرِينَ يَوْمًا ‏.‏\hadithno{2466}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2044)}\hadithtrans{Abu Hurairah said:The Prophet (ﷺ) used to observe I'tikaf during ten days of Ramadan every year. But when the year in which he died, he observed I'tikaf for twenty days}}
\hadithdefcmd{abudawud}{2467}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا اعْتَكَفَ يُدْنِي إِلَىَّ رَأْسَهُ فَأُرَجِّلُهُ وَكَانَ لاَ يَدْخُلُ الْبَيْتَ إِلاَّ لِحَاجَةِ الإِنْسَانِ ‏.‏\hadithno{2467}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim (297)}\hadithtrans{Aishah said:When the Messenger of Allah (ﷺ) observed I'tikaf, he would put his head near me, and I would comb it. and he entered the house only to fulfill human needs (i.e. to urinate or to relieve himself)}}
\hadithdefcmd{abudawud}{2468}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَعَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، قَالاَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ يُونُسُ عَنِ الزُّهْرِيِّ وَلَمْ يُتَابِعْ أَحَدٌ مَالِكًا عَلَى عُرْوَةَ عَنْ عَمْرَةَ وَرَوَاهُ مَعْمَرٌ وَزِيَادُ بْنُ سَعْدٍ وَغَيْرُهُمَا عَنِ الزُّهْرِيِّ عَنْ عُرْوَةَ عَنْ عَائِشَةَ ‏.‏\hadithno{2468}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2029)}\hadithtrans{A similar tradition has been transmitted by 'Aishah from the Prophet (ﷺ) through a different chain of narrators. Abu Dawud said:And Yunus also narrated in a similar way from al-Zuhri, and no one supported Malik in his narration from 'Urwah from 'Umrah ; and Ma'mar, Ziyad b. Sad and others have also narrated it from al-Zuhri from 'Urwah on the authority of 'Aishah}}
\hadithdefcmd{abudawud}{2469}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَكُونُ مُعْتَكِفًا فِي الْمَسْجِدِ فَيُنَاوِلُنِي رَأْسَهُ مِنْ خَلَلِ الْحُجْرَةِ فَأَغْسِلُ رَأْسَهُ ‏.‏ وَقَالَ مُسَدَّدٌ فَأُرَجِّلُهُ وَأَنَا حَائِضٌ ‏.‏\hadithno{2469}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (295، 2030، 5925) Sahih Muslim (297)}\hadithtrans{Aishah said:The Messenger of Allah (ﷺ) used to observe I'tikaf in the mosque and put his head near me through the opening of the apartment, and I would wash his head. Musaddad said: "And I would comb it while I was menstruating}}
\hadithdefcmd{abudawud}{2470}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ شَبُّويَةَ الْمَرْوَزِيُّ، حَدَّثَنِي عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَلِيِّ بْنِ حُسَيْنٍ، عَنْ صَفِيَّةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم مُعْتَكِفًا فَأَتَيْتُهُ أَزُورُهُ لَيْلاً فَحَدَّثْتُهُ ثُمَّ قُمْتُ فَانْقَلَبْتُ فَقَامَ مَعِي لِيَقْلِبَنِي - وَكَانَ مَسْكَنُهَا فِي دَارِ أُسَامَةَ بْنِ زَيْدٍ - فَمَرَّ رَجُلاَنِ مِنَ الأَنْصَارِ فَلَمَّا رَأَيَا النَّبِيَّ صلى الله عليه وسلم أَسْرَعَا فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عَلَى رِسْلِكُمَا إِنَّهَا صَفِيَّةُ بِنْتُ حُيَىٍّ ‏"‏ ‏.‏ قَالاَ سُبْحَانَ اللَّهِ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ إِنَّ الشَّيْطَانَ يَجْرِي مِنَ الإِنْسَانِ مَجْرَى الدَّمِ فَخَشِيتُ أَنْ يَقْذِفَ فِي قُلُوبِكُمَا شَيْئًا ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ شَرًّا ‏"‏ ‏.‏\hadithno{2470}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (3281) Sahih Muslim (2175)}\hadithtrans{Safiyyah said:When the Messenger of Allah (ﷺ) was observing I'tikaf (in the mosque), I would come to him to visit him. I had a talk with him and then stood up. I then returned and he (the Prophet) also stood up to accompany me (to my house). Her dwelling place was in the house of Usamah b. Zaid. Two men from the Ansar (helpers) passed (by him at the moment). When they saw the Prophet (ﷺ), they walked quickly. The Prophet (ﷺ) said: Be at ease, she is Safiyyah daughter of Huyayy. They said: Be glory to Allah, Messenger of Allah! He said: Satan runs in man like blood. I feared he might inspire something in your mind, or he said: evil (the narrator doubted)}}
\hadithdefcmd{abudawud}{2471}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، بِإِسْنَادِهِ بِهَذَا قَالَتْ حَتَّى إِذَا كَانَ عِنْدَ بَابِ الْمَسْجِدِ الَّذِي عِنْدَ بَابِ أُمِّ سَلَمَةَ مَرَّ بِهِمَا رَجُلاَنِ ‏.‏ وَسَاقَ مَعْنَاهُ ‏.‏\hadithno{2471}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2035)}\hadithtrans{The tradition mentioned above has also been transmitted by Al Zuhri through a different chain of narrators. In this version she said “When he was at the gate of the mosque which was near the gate of Umm Salamah, two men passed them. The narrator then transmitted the tradition to the same effect}}
\hadithdefcmd{abudawud}{2472}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، وَمُحَمَّدُ بْنُ عِيسَى، قَالاَ حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ حَرْبٍ، أَخْبَرَنَا اللَّيْثُ بْنُ أَبِي سُلَيْمٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، - قَالَ النُّفَيْلِيُّ - قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَمُرُّ بِالْمَرِيضِ وَهُوَ مُعْتَكِفٌ فَيَمُرُّ كَمَا هُوَ وَلاَ يُعَرِّجُ يَسْأَلُ عَنْهُ ‏.‏ وَقَالَ ابْنُ عِيسَى قَالَتْ إِنْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَعُودُ الْمَرِيضَ وَهُوَ مُعْتَكِفٌ ‏.‏\hadithno{2472}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{According to the version of Al Nufaili, A’ishah said “The Prophet (ﷺ) used to pass by a patient while he was observing I’tikaf(in the mosque) but he passed as usual and did not stay asking about him.” According to the version of Ibn Isa she said “The Prophet (ﷺ) would visit a patient while he was observing I’tikaf.”}}
\hadithdefcmd{abudawud}{2473}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، أَخْبَرَنَا خَالِدٌ، عَنْ عَبْدِ الرَّحْمَنِ، - يَعْنِي ابْنَ إِسْحَاقَ - عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتِ السُّنَّةُ عَلَى الْمُعْتَكِفِ أَنْ لاَ يَعُودَ مَرِيضًا وَلاَ يَشْهَدَ جَنَازَةً وَلاَ يَمَسَّ امْرَأَةً وَلاَ يُبَاشِرَهَا وَلاَ يَخْرُجَ لِحَاجَةٍ إِلاَّ لِمَا لاَ بُدَّ مِنْهُ وَلاَ اعْتِكَافَ إِلاَّ بِصَوْمٍ وَلاَ اعْتِكَافَ إِلاَّ فِي مَسْجِدٍ جَامِعٍ ‏.‏ قَالَ أَبُو دَاوُدَ غَيْرُ عَبْدِ الرَّحْمَنِ بْنِ إِسْحَاقَ لاَ يَقُولُ فِيهِ قَالَتِ السُّنَّةُ ‏.‏ قَالَ أَبُو دَاوُدَ جَعَلَهُ قَوْلَ عَائِشَةَ ‏.‏\hadithno{2473}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The sunnah for one who is observing i'tikaf (in a mosque) is not to visit a patient, or to attend a funeral, or touch or embrace one's wife, or go out for anything but necessary purposes. There is no i'tikaf without fasting, and there is no i'tikaf except in a congregational mosque}}
\hadithdefcmd{abudawud}{2474}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُدَيْلٍ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ ابْنِ عُمَرَ، أَنَّ عُمَرَ، - رضى الله عنه - جَعَلَ عَلَيْهِ أَنْ يَعْتَكِفَ فِي الْجَاهِلِيَّةِ لَيْلَةً أَوْ يَوْمًا عِنْدَ الْكَعْبَةِ فَسَأَلَ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ اعْتَكِفْ وَصُمْ ‏"‏ ‏.‏\hadithno{2474}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: Umar (may Allah be pleased with him) took a vow in the pre-Islamic days to spend a night or a day in devotion near the Ka'bah (in the sacred mosque). He asked the Prophet (ﷺ) about it. He said: Observe i'tikaf (i.e. spend a night or a day near the Ka'bah) and fast}}
\hadithdefcmd{abudawud}{2475}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ بْنِ مُحَمَّدٍ، عَنْ أَبَانَ بْنِ صَالِحٍ الْقُرَشِيِّ، حَدَّثَنَا عَمْرُو بْنُ مُحَمَّدٍ، - يَعْنِي الْعَنْقَزِيَّ - عَنْ عَبْدِ اللَّهِ بْنِ بُدَيْلٍ، بِإِسْنَادِهِ نَحْوَهُ قَالَ فَبَيْنَمَا هُوَ مُعْتَكِفٌ إِذْ كَبَّرَ النَّاسُ فَقَالَ مَا هَذَا يَا عَبْدَ اللَّهِ قَالَ سَبْىُ هَوَازِنَ أَعْتَقَهُمُ النَّبِيُّ صلى الله عليه وسلم قَالَ وَتِلْكَ الْجَارِيَةُ ‏.‏ فَأَرْسَلَهَا مَعَهُمْ ‏.‏\hadithno{2475}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: The tradition mentioned above (No. 2468) has also been transmitted by Abdullah ibn Budayl through a different chain of narrators in a similar way. This version adds: While he (Umar) was observing i'tikaf (in the sacred mosque), the people uttered (loudly): "Allah is most great." He said: What is this, Abdullah? He said: These are the captives of the Hawazin whom the Messenger of Allah (ﷺ) has set free. He said: This slave-girl too? He sent her along with them}}
\hadithdefcmd{abudawud}{2476}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا يَزِيدُ، عَنْ خَالِدٍ، عَنْ عِكْرِمَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتِ اعْتَكَفَتْ مَعَ النَّبِيِّ صلى الله عليه وسلم امْرَأَةٌ مِنْ أَزْوَاجِهِ فَكَانَتْ تَرَى الصُّفْرَةَ وَالْحُمْرَةَ فَرُبَّمَا وَضَعْنَا الطَّسْتَ تَحْتَهَا وَهِيَ تُصَلِّي ‏.‏\hadithno{2476}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2037)}\hadithtrans{A’ishah(may Allaah be pleased with her) said “One of the wives of the Apostle of Allaah(ﷺ) observed I’tikaf along with him (in the mosque). She would see yellowness and redness. Sometimes we would place a washbasin while she prayed.”}}
