% Auto-generated chapter 81 for bukhari
% Hadiths in this chapter: 181

\hadithdefcmd{bukhari}{6412}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ ـ هُوَ ابْنُ أَبِي هِنْدٍ ـ عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ نِعْمَتَانِ مَغْبُونٌ فِيهِمَا كَثِيرٌ مِنَ النَّاسِ، الصِّحَّةُ وَالْفَرَاغُ ‏"‏‏.‏ قَالَ عَبَّاسٌ الْعَنْبَرِيُّ حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، عَنْ عَبْدِ اللَّهِ بْنِ سَعِيدِ بْنِ أَبِي هِنْدٍ، عَنْ أَبِيهِ، سَمِعْتُ ابْنَ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ‏.‏\hadithno{6412}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said: "There are two blessings that many people are deceived into losing: health and free time}}
\hadithdefcmd{bukhari}{6413}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اللَّهُمَّ لاَ عَيْشَ إِلاَّ عَيْشُ الآخِرَة، فَأَصْلِحِ الأَنْصَارَ وَالْمُهَاجِرَة ‏"‏‏.‏\hadithno{6413}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "O Allah! There is no life worth living except the life of the Hereafter, so (please) make righteous the Ansar and the Emigrants}}
\hadithdefcmd{bukhari}{6414}{حَدَّثَنِي أَحْمَدُ بْنُ الْمِقْدَامِ، حَدَّثَنَا الْفُضَيْلُ بْنُ سُلَيْمَانَ، حَدَّثَنَا أَبُو حَازِمٍ، حَدَّثَنَا سَهْلُ بْنُ سَعْدٍ السَّاعِدِيُّ، كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْخَنْدَقِ وَهْوَ يَحْفِرُ وَنَحْنُ نَنْقُلُ التُّرَابَ وَيَمُرُّ بِنَا فَقَالَ ‏ "‏ اللَّهُمَّ لاَ عَيْشَ إِلاَّ عَيْشُ الآخِرَهْ، فَاغْفِرْ لِلأَنْصَارِ وَالْمُهَاجِرَهْ ‏"‏‏.‏ تَابَعَهُ سَهْلُ بْنُ سَعْدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ‏.‏\hadithno{6414}\hadithtrans{Narrated Sahl bin Sa`d As-Sa`idi:We were in the company of Allah's Messenger (ﷺ) in (the battle of) Al-Khandaq, and he was digging the trench while we were carrying the earth away. He looked at us and said, "O Allah! There is no life worth living except the life of the Hereafter, so (please) forgive the Ansar and the Emigrants}}
\hadithdefcmd{bukhari}{6415}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَوْضِعُ سَوْطٍ فِي الْجَنَّةِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا، وَلَغَدْوَةٌ فِي سَبِيلِ اللَّهِ أَوْ رَوْحَةٌ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏‏.‏\hadithno{6415}\hadithtrans{Narrated Sahl:I heard the Prophet (ﷺ) saying, "A (small) place equal to an area occupied by a whip in Paradise is better than the (whole) world and whatever is in it; and an undertaking (journey) in the forenoon or in the afternoon for Allah's Cause, is better than the whole world and whatever is in it}}
\hadithdefcmd{bukhari}{6416}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ أَبُو الْمُنْذِرِ الطُّفَاوِيُّ، عَنْ سُلَيْمَانَ الأَعْمَشِ، قَالَ حَدَّثَنِي مُجَاهِدٌ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ أَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِمَنْكِبِي فَقَالَ ‏ "‏ كُنْ فِي الدُّنْيَا كَأَنَّكَ غَرِيبٌ، أَوْ عَابِرُ سَبِيلٍ ‏"‏‏.‏ وَكَانَ ابْنُ عُمَرَ يَقُولُ إِذَا أَمْسَيْتَ فَلاَ تَنْتَظِرِ الصَّبَاحَ، وَإِذَا أَصْبَحْتَ فَلاَ تَنْتَظِرِ الْمَسَاءَ، وَخُذْ مِنْ صِحَّتِكَ لِمَرَضِكَ، وَمِنْ حَيَاتِكَ لِمَوْتِكَ‏.‏\hadithno{6416}\hadithtrans{Narrated Mujahid:`Abdullah bin `Umar said, "Allah's Messenger (ﷺ) took hold of my shoulder and said, 'Be in this world as if you were a stranger or a traveler." The sub-narrator added: Ibn `Umar used to say, "If you survive till the evening, do not expect to be alive in the morning, and if you survive till the morning, do not expect to be alive in the evening, and take from your health for your sickness, and (take) from your life for your death}}
\hadithdefcmd{bukhari}{6417}{حَدَّثَنَا صَدَقَةُ بْنُ الْفَضْلِ، أَخْبَرَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي أَبِي، عَنْ مُنْذِرٍ، عَنْ رَبِيعِ بْنِ خُثَيْمٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ خَطَّ النَّبِيُّ صلى الله عليه وسلم خَطًّا مُرَبَّعًا، وَخَطَّ خَطًّا فِي الْوَسَطِ خَارِجًا مِنْهُ، وَخَطَّ خُطُطًا صِغَارًا إِلَى هَذَا الَّذِي فِي الْوَسَطِ، مِنْ جَانِبِهِ الَّذِي فِي الْوَسَطِ وَقَالَ ‏ "‏ هَذَا الإِنْسَانُ، وَهَذَا أَجَلُهُ مُحِيطٌ بِهِ ـ أَوْ قَدْ أَحَاطَ بِهِ ـ وَهَذَا الَّذِي هُوَ خَارِجٌ أَمَلُهُ، وَهَذِهِ الْخُطُطُ الصِّغَارُ الأَعْرَاضُ، فَإِنْ أَخْطَأَهُ هَذَا نَهَشَهُ هَذَا، وَإِنْ أَخْطَأَهُ هَذَا نَهَشَهُ هَذَا ‏"‏‏.‏\hadithno{6417}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) drew a square and then drew a line in the middle of it and let it extend outside the square and then drew several small lines attached to that central line, and said, "This is the human being, and this, (the square) in his lease of life, encircles him from all sides (or has encircled him), and this (line), which is outside (the square), is his hope, and these small lines are the calamities and troubles (which may befall him), and if one misses him, an-other will snap (i.e. overtake) him, and if the other misses him, a third will snap (i.e. overtake) him}}
\hadithdefcmd{bukhari}{6418}{حَدَّثَنَا مُسْلِمٌ، حَدَّثَنَا هَمَّامٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسٍ، قَالَ خَطَّ النَّبِيُّ صلى الله عليه وسلم خُطُوطًا فَقَالَ ‏ "‏ هَذَا الأَمَلُ وَهَذَا أَجَلُهُ، فَبَيْنَمَا هُوَ كَذَلِكَ إِذْ جَاءَهُ الْخَطُّ الأَقْرَبُ ‏"‏‏.‏\hadithno{6418}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) drew a few lines and said, "This is (man's) hope, and this is the instant of his death, and while he is in this state (of hope), the nearer line (death) comes to Him}}
\hadithdefcmd{bukhari}{6419}{حَدَّثَنِي عَبْدُ السَّلاَمِ بْنُ مُطَهَّرٍ، حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ، عَنْ مَعْنِ بْنِ مُحَمَّدٍ الْغِفَارِيِّ، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَعْذَرَ اللَّهُ إِلَى امْرِئٍ أَخَّرَ أَجَلَهُ حَتَّى بَلَّغَهُ سِتِّينَ سَنَةً ‏"‏‏.‏ تَابَعَهُ أَبُو حَازِمٍ وَابْنُ عَجْلاَنَ عَنِ الْمَقْبُرِيِّ‏.‏\hadithno{6419}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah will not accept the excuse of any person whose instant of death is delayed till he is sixty years of age}}
\hadithdefcmd{bukhari}{6420}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا أَبُو صَفْوَانَ عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ يَزَالُ قَلْبُ الْكَبِيرِ شَابًّا فِي اثْنَتَيْنِ فِي حُبِّ الدُّنْيَا، وَطُولِ الأَمَلِ ‏"‏‏.‏ قَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ وَابْنُ وَهْبٍ عَنْ يُونُسَ عَنِ ابْنِ شِهَابٍ قَالَ أَخْبَرَنِي سَعِيدٌ وَأَبُو سَلَمَةَ‏.‏\hadithno{6420}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "The heart of an old man remains young in two respects, i.e., his love for the world (its wealth, amusements and luxuries) and his incessant hope}}
\hadithdefcmd{bukhari}{6421}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَكْبَرُ ابْنُ آدَمَ وَيَكْبَرُ مَعَهُ اثْنَانِ حُبُّ الْمَالِ، وَطُولُ الْعُمُرِ ‏"‏‏.‏ رَوَاهُ شُعْبَةُ عَنْ قَتَادَةَ‏.‏\hadithno{6421}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "The son of Adam (i.e. man) grows old and so also two (desires) grow old with him, i.e., love for wealth and (a wish for) a long life}}
\hadithdefcmd{bukhari}{6422}{حَدَّثَنَا مُعَاذُ بْنُ أَسَدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي مَحْمُودُ بْنُ الرَّبِيعِ، وَزَعَمَ، مَحْمُودٌ أَنَّهُ عَقَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَقَالَ وَعَقَلَ مَجَّةً مَجَّهَا مِنْ دَلْوٍ كَانَتْ فِي دَارِهِمْ‏.‏\hadithno{6422}\hadithtrans{Narrated Mahmud bin Ar-Rabi'a:I remember that the Allah's Messenger (ﷺ) took water from a bucket (which was in our home used for getting water out of well) with his mouth (and threw it on my face)}}
\hadithdefcmd{bukhari}{6423}{قَالَ سَمِعْتُ عِتْبَانَ بْنَ مَالِكٍ الأَنْصَارِيَّ، ثُمَّ أَحَدَ بَنِي سَالِمٍ قَالَ غَدَا عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لَنْ يُوَافِيَ عَبْدٌ يَوْمَ الْقِيَامَةِ يَقُولُ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ يَبْتَغِي بِهِ وَجْهَ اللَّهِ، إِلاَّ حَرَّمَ اللَّهُ عَلَيْهِ النَّارَ ‏"‏‏.‏\hadithno{6423}\hadithtrans{Narrated `Utban bin Malik Al-Ansari:who was one of the men of the tribe of Bani Salim: Allah's Messenger (ﷺ) came to me and said, "If anybody comes on the Day of Resurrection who has said: La ilaha illal-lah, sincerely, with the intention to win Allah's Pleasure, Allah will make the Hell-Fire forbidden for him}}
\hadithdefcmd{bukhari}{6424}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَمْرٍو، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَقُولُ اللَّهُ تَعَالَى مَا لِعَبْدِي الْمُؤْمِنِ عِنْدِي جَزَاءٌ، إِذَا قَبَضْتُ صَفِيَّهُ مِنْ أَهْلِ الدُّنْيَا، ثُمَّ احْتَسَبَهُ إِلاَّ الْجَنَّةُ ‏"‏‏.‏\hadithno{6424}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah says, 'I have nothing to give but Paradise as a reward to my believer slave, who, if I cause his dear friend (or relative) to die, remains patient (and hopes for Allah's Reward)}}
\hadithdefcmd{bukhari}{6425}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ بْنِ عُقْبَةَ، عَنْ مُوسَى بْنِ عُقْبَةَ، قَالَ ابْنُ شِهَابٍ حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ، أَخْبَرَهُ أَنَّ عَمْرَو بْنَ عَوْفٍ وَهْوَ حَلِيفٌ لِبَنِي عَامِرِ بْنِ لُؤَىٍّ كَانَ شَهِدَ بَدْرًا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم أَخْبَرَهُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ أَبَا عُبَيْدَةَ بْنَ الْجَرَّاحِ إِلَى الْبَحْرَيْنِ يَأْتِي بِجِزْيَتِهَا، وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم هُوَ صَالَحَ أَهْلَ الْبَحْرَيْنِ، وَأَمَّرَ عَلَيْهِمُ الْعَلاَءَ بْنَ الْحَضْرَمِيِّ، فَقَدِمَ أَبُو عُبَيْدَةَ بِمَالٍ مِنَ الْبَحْرَيْنِ، فَسَمِعَتِ الأَنْصَارُ بِقُدُومِهِ فَوَافَتْهُ صَلاَةَ الصُّبْحِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا انْصَرَفَ تَعَرَّضُوا لَهُ فَتَبَسَّمَ حِينَ رَآهُمْ وَقَالَ ‏"‏ أَظُنُّكُمْ سَمِعْتُمْ بِقُدُومِ أَبِي عُبَيْدَةَ، وَأَنَّهُ جَاءَ بِشَىْءٍ ‏"‏‏.‏ قَالُوا أَجَلْ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَأَبْشِرُوا وَأَمِّلُوا مَا يَسُرُّكُمْ، فَوَاللَّهِ مَا الْفَقْرَ أَخْشَى عَلَيْكُمْ، وَلَكِنْ أَخْشَى عَلَيْكُمْ أَنْ تُبْسَطَ عَلَيْكُمُ الدُّنْيَا، كَمَا بُسِطَتْ عَلَى مَنْ كَانَ قَبْلَكُمْ، فَتَنَافَسُوهَا كَمَا تَنَافَسُوهَا وَتُلْهِيَكُمْ كَمَا أَلْهَتْهُمْ ‏"‏‏.‏\hadithno{6425}\hadithtrans{Narrated `Amr bin `Auf:(An ally of the tribe of Bani 'Amir bin Lu'ai and one of those who had witnessed the battle of Badr with Allah's Messenger (ﷺ)) Allah's Messenger (ﷺ) sent Abu 'Ubaida bin AlJarrah to Bahrain to collect the Jizya tax. Allah's Messenger (ﷺ) had concluded a peace treaty with the people of Bahrain and appointed Al 'Ala bin Al-Hadrami as their chief; Abu Ubaida arrived from Bahrain with the money. The Ansar heard of Abu 'Ubaida's arrival which coincided with the Fajr (morning) prayer led by Allah's Messenger (ﷺ). When the Prophet (ﷺ) finished the prayer, they came to him. Allah's Messenger (ﷺ) smiled when he saw them and said, "I think you have heard of the arrival of Abu 'Ubaida and that he has brought something." They replied, "Yes, O Allah's Messenger (ﷺ)! " He said, "Have the good news, and hope for what will please you. By Allah, I am not afraid that you will become poor, but I am afraid that worldly wealth will be given to you in abundance as it was given to those (nations) before you, and you will start competing each other for it as the previous nations competed for it, and then it will divert you (from good) as it diverted them}}
\hadithdefcmd{bukhari}{6426}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ يَوْمًا فَصَلَّى عَلَى أَهْلِ أُحُدٍ صَلاَتَهُ عَلَى الْمَيِّتِ، ثُمَّ انْصَرَفَ إِلَى الْمِنْبَرِ فَقَالَ ‏ "‏ إِنِّي فَرَطُكُمْ وَأَنَا شَهِيدٌ عَلَيْكُمْ، وَإِنِّي وَاللَّهِ لأَنْظُرُ إِلَى حَوْضِي الآنَ، وَإِنِّي قَدْ أُعْطِيتُ مَفَاتِيحَ خَزَائِنِ الأَرْضِ ـ أَوْ مَفَاتِيحَ الأَرْضِ ـ وَإِنِّي وَاللَّهِ مَا أَخَافُ عَلَيْكُمْ أَنْ تُشْرِكُوا بَعْدِي، وَلَكِنِّي أَخَافُ عَلَيْكُمْ أَنْ تَنَافَسُوا فِيهَا ‏"‏‏.‏\hadithno{6426}\hadithtrans{Narrated `Uqba bin 'Amir:The Prophet (ﷺ) went out and offered the funeral prayer for the martyrs of the (battle of) Uhud and then ascended the pulpit and said, "I am your predecessor and I am a witness against you. By Allah, I am now looking at my Tank-lake (Al-Kauthar) and I have been given the keys of the treasures of the earth (or the keys of the earth). By Allah! I am not afraid that after me you will worship others besides Allah, but I am afraid that you will start competing for (the pleasures of) this world}}
\hadithdefcmd{bukhari}{6427}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ أَكْثَرَ مَا أَخَافُ عَلَيْكُمْ مَا يُخْرِجُ اللَّهُ لَكُمْ مِنْ بَرَكَاتِ الأَرْضِ ‏"‏‏.‏ قِيلَ وَمَا بَرَكَاتُ الأَرْضِ قَالَ ‏"‏ زَهْرَةُ الدُّنْيَا ‏"‏‏.‏ فَقَالَ لَهُ رَجُلٌ هَلْ يَأْتِي الْخَيْرُ بِالشَّرِّ فَصَمَتَ النَّبِيُّ صلى الله عليه وسلم حَتَّى ظَنَنَّا أَنَّهُ يُنْزَلُ عَلَيْهِ، ثُمَّ جَعَلَ يَمْسَحُ عَنْ جَبِينِهِ فَقَالَ ‏"‏ أَيْنَ السَّائِلُ ‏"‏‏.‏ قَالَ أَنَا‏.‏ قَالَ أَبُو سَعِيدٍ لَقَدْ حَمِدْنَاهُ حِينَ طَلَعَ ذَلِكَ‏.‏ قَالَ ‏"‏ لاَ يَأْتِي الْخَيْرُ إِلاَّ بِالْخَيْرِ، إِنَّ هَذَا الْمَالَ خَضِرَةٌ حُلْوَةٌ، وَإِنَّ كُلَّ مَا أَنْبَتَ الرَّبِيعُ يَقْتُلُ حَبَطًا أَوْ يُلِمُّ، إِلاَّ آكِلَةَ الْخَضِرَةِ، أَكَلَتْ حَتَّى إِذَا امْتَدَّتْ خَاصِرَتَاهَا اسْتَقْبَلَتِ الشَّمْسَ، فَاجْتَرَّتْ وَثَلَطَتْ وَبَالَتْ، ثُمَّ عَادَتْ فَأَكَلَتْ، وَإِنَّ هَذَا الْمَالَ حُلْوَةٌ، مَنْ أَخَذَهُ بِحَقِّهِ وَوَضَعَهُ فِي حَقِّهِ، فَنِعْمَ الْمَعُونَةُ هُوَ، وَمَنْ أَخَذَهُ بِغَيْرِ حَقِّهِ، كَانَ الَّذِي يَأْكُلُ وَلاَ يَشْبَعُ ‏"‏‏.‏\hadithno{6427}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "The thing I am afraid of most for your sake, is the worldly blessings which Allah will bring forth to you." It was said, "What are the blessings of this world?" The Prophet (ﷺ) said, "The pleasures of the world." A man said, "Can the good bring forth evil?" The Prophet (ﷺ) kept quiet for a while till we thought that he was being inspired divinely. Then he started removing the sweat from his forehead and said," Where is the questioner?" That man said, "I (am present)." Abu Sa`id added: We thanked the man when the result (of his question) was such. The Prophet (ﷺ) said, "Good never brings forth but good. This wealth (of the world) is (like) green and sweet (fruit), and all the vegetation which grows on the bank of a stream either kills or nearly kills the animal that eats too much of it, except the animal that eats the Khadira (a kind of vegetation). Such an animal eats till its stomach is full and then it faces the sun and starts ruminating and then it passes out dung and urine and goes to eat again. This worldly wealth is (like) sweet (fruit), and if a person earns it (the wealth) in a legal way and spends it properly, then it is an excellent helper, and whoever earns it in an illegal way, he will be like the one who eats but is never satisfied}}
\hadithdefcmd{bukhari}{6428}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ أَبَا جَمْرَةَ، قَالَ حَدَّثَنِي زَهْدَمُ بْنُ مُضَرِّبٍ، قَالَ سَمِعْتُ عِمْرَانَ بْنَ حُصَيْنٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ خَيْرُكُمْ قَرْنِي، ثُمَّ الَّذِينَ يَلُونَهُمْ، ثُمَّ الَّذِينَ يَلُونَهُمْ ‏"‏‏.‏ قَالَ عِمْرَانُ فَمَا أَدْرِي قَالَ النَّبِيُّ صلى الله عليه وسلم بَعْدَ قَوْلِهِ مَرَّتَيْنِ أَوْ ثَلاَثًا ‏"‏ ثُمَّ يَكُونُ بَعْدَهُمْ قَوْمٌ يَشْهَدُونَ وَلاَ يُسْتَشْهَدُونَ، وَيَخُونُونَ وَلاَ يُؤْتَمَنُونَ، وَيَنْذِرُونَ وَلاَ يَفُونَ وَيَظْهَرُ فِيهِمُ السِّمَنُ ‏"‏‏.‏\hadithno{6428}\hadithtrans{Narrated Zahdam bin Mudarrib:`Imran bin Husain said: The Prophet (ﷺ) said, "The best people are my contemporaries (i.e., the present (my) generation) and then those who come after them (i.e., the next generation)." `Imran added: I am not sure whether the Prophet (ﷺ) repeated the statement twice after his first saying. The Prophet (ﷺ) added, "And after them there will come people who will bear witness, though they will not be asked to give their witness; and they will be treacherous and nobody will trust them, and they will make vows, but will not fulfill them, and fatness will appear among them}}
\hadithdefcmd{bukhari}{6429}{حَدَّثَنَا عَبْدَانُ، عَنْ أَبِي حَمْزَةَ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ النَّاسِ قَرْنِي، ثُمَّ الَّذِينَ يَلُونَهُمْ، ثُمَّ الَّذِينَ يَلُونَهُمْ، ثُمَّ يَجِيءُ مِنْ بَعْدِهِمْ قَوْمٌ تَسْبِقُ شَهَادَتُهُمْ أَيْمَانَهُمْ وَأَيْمَانُهُمْ شَهَادَتَهُمْ ‏"‏‏.‏\hadithno{6429}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "The best people are those of my generation, and then those who will come after them (the next generation), and then those who will come after them (i.e. the next generation), and then after them, there will come people whose witness will precede their oaths, and whose oaths will precede their witness}}
\hadithdefcmd{bukhari}{6430}{حَدَّثَنِي يَحْيَى بْنُ مُوسَى، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ قَيْسٍ، قَالَ سَمِعْتُ خَبَّابًا، وَقَدِ اكْتَوَى يَوْمَئِذٍ سَبْعًا فِي بَطْنِهِ وَقَالَ لَوْلاَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَانَا أَنْ نَدْعُوَ بِالْمَوْتِ لَدَعَوْتُ بِالْمَوْتِ، إِنَّ أَصْحَابَ مُحَمَّدٍ صلى الله عليه وسلم مَضَوْا وَلَمْ تَنْقُصْهُمُ الدُّنْيَا بِشَىْءٍ، وَإِنَّا أَصَبْنَا مِنَ الدُّنْيَا مَا لاَ نَجِدُ لَهُ مَوْضِعًا إِلاَّ التُّرَابَ‏.‏\hadithno{6430}\hadithtrans{Narrated Qais:I heard Khabbab, who had branded his `Abdomen with seven brands, saying, "Had Allah's Messenger (ﷺ) not forbidden us to invoke Allah for death, I would have invoked Allah for death. The companions of Muhammad have left this world without taking anything of their reward in it (i.e., they will have perfect reward in the Hereafter), but we have collected of the worldly wealth what we cannot spend but on earth (i.e. on building houses)}}
\hadithdefcmd{bukhari}{6431}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، قَالَ حَدَّثَنِي قَيْسٌ، قَالَ أَتَيْتُ خَبَّابًا وَهْوَ يَبْنِي حَائِطًا لَهُ فَقَالَ إِنَّ أَصْحَابَنَا الَّذِينَ مَضَوْا لَمْ تَنْقُصْهُمُ الدُّنْيَا شَيْئًا، وَإِنَّا أَصَبْنَا مِنْ بَعْدِهِمْ شَيْئًا، لاَ نَجِدُ لَهُ مَوْضِعًا إِلاَّ التُّرَابَ‏.‏\hadithno{6431}\hadithtrans{Narrated Qais:I came to Khabbab while he was building a wall, and he (Khabbab) said, "Our companions who have left this world, did not enjoy anything of their reward therein, while we have collected after them, much wealth that we cannot spend but on earth (i.e., on building)}}
\hadithdefcmd{bukhari}{6432}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، عَنْ سُفْيَانَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ خَبَّاب ٍ ـ رضى الله عنه ـ قَالَ هَاجَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{6432}\hadithtrans{Narrated Khabbab:We migrated with the Prophet..(This narration is related in the chapter of migration)}}
\hadithdefcmd{bukhari}{6433}{حَدَّثَنَا سَعْدُ بْنُ حَفْصٍ، حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ الْقُرَشِيِّ، قَالَ أَخْبَرَنِي مُعَاذُ بْنُ عَبْدِ الرَّحْمَنِ، أَنَّ ابْنَ أَبَانَ، أَخْبَرَهُ قَالَ أَتَيْتُ عُثْمَانَ بِطَهُورٍ وَهْوَ جَالِسٌ عَلَى الْمَقَاعِدِ، فَتَوَضَّأَ فَأَحْسَنَ الْوُضُوءَ ثُمَّ قَالَ رَأَيْتُ النَّبِيَّ صلى الله عليه وسلم تَوَضَّأَ وَهْوَ فِي هَذَا الْمَجْلِسِ، فَأَحْسَنَ الْوُضُوءَ ثُمَّ قَالَ ‏"‏ مَنْ تَوَضَّأَ مِثْلَ هَذَا الْوُضُوءِ، ثُمَّ أَتَى الْمَسْجِدَ فَرَكَعَ رَكْعَتَيْنِ، ثُمَّ جَلَسَ، غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ ‏"‏‏.‏ قَالَ وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ تَغْتَرُّوا ‏"‏‏.‏\hadithno{6433}\hadithtrans{Narrated Ibn `Abbas:I brought water to `Uthman bin `Affan to perform the ablution while he was sitting on his seat. He performed the ablution in a perfect way and said, "I saw the Prophet (ﷺ) performing the ablution in this place and he performed it in a perfect way and said, "Whoever performs the ablution as I have done this time and then proceeds to the mosque and offers a two-rak`at prayer and then sits there (waiting for the compulsory congregational prayers), then all his past sins will be forgiven." The Prophet (ﷺ) further added, "Do not be conceited (thinking that your sins will be forgiven because of your prayer)}}
\hadithdefcmd{bukhari}{6434}{حَدَّثَنِي يَحْيَى بْنُ حَمَّادٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ بَيَانٍ، عَنْ قَيْسِ بْنِ أَبِي حَازِمٍ، عَنْ مِرْدَاسٍ الأَسْلَمِيِّ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَذْهَبُ الصَّالِحُونَ الأَوَّلُ فَالأَوَّلُ، وَيَبْقَى حُفَالَةٌ كَحُفَالَةِ الشَّعِيرِ أَوِ التَّمْرِ، لاَ يُبَالِيهِمُ اللَّهُ بَالَةً ‏"‏‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ يُقَالُ حُفَالَةٌ وَحُثَالَةٌ‏.‏\hadithno{6434}\hadithtrans{Narrated Mirdas Al-Aslami:The Prophet (ﷺ) said, "The righteous (pious people will depart (die) in succession one after the other, and there will remain (on the earth) useless people like the useless husk of barley seeds or bad dates}}
\hadithdefcmd{bukhari}{6435}{حَدَّثَنِي يَحْيَى بْنُ يُوسُفَ، أَخْبَرَنَا أَبُو بَكْرٍ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تَعِسَ عَبْدُ الدِّينَارِ وَالدِّرْهَمِ وَالْقَطِيفَةِ وَالْخَمِيصَةِ، إِنْ أُعْطِيَ رَضِيَ، وَإِنْ لَمْ يُعْطَ لَمْ يَرْضَ ‏"‏‏.‏\hadithno{6435}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Perish the slave of Dinar, Dirham, Qatifa (thick soft cloth), and Khamisa (a garment), for if he is given, he is pleased; otherwise he is dissatisfied}}
\hadithdefcmd{bukhari}{6436}{حَدَّثَنَا أَبُو عَاصِمٍ، عَنِ ابْنِ جُرَيْجٍ، عَنْ عَطَاءٍ، قَالَ سَمِعْتُ ابْنَ عَبَّاسٍ ـ رضى الله عنهما ـ يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَوْ كَانَ لاِبْنِ آدَمَ وَادِيَانِ مِنْ مَالٍ لاَبْتَغَى ثَالِثًا، وَلاَ يَمْلأُ جَوْفَ ابْنِ آدَمَ إِلاَّ التُّرَابُ، وَيَتُوبُ اللَّهُ عَلَى مَنْ تَابَ ‏"‏‏.‏\hadithno{6436}\hadithtrans{Narrated Ibn `Abbas:I heard the Prophet (ﷺ) saying, "If the son of Adam (the human being) had two valleys of money, he would wish for a third, for nothing can fill the belly of Adam's son except dust, and Allah forgives him who repents to Him}}
\hadithdefcmd{bukhari}{6437}{حَدَّثَنِي مُحَمَّدٌ، أَخْبَرَنَا مَخْلَدٌ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، قَالَ سَمِعْتُ عَطَاءً، يَقُولُ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَوْ أَنَّ لاِبْنِ آدَمَ مِثْلَ وَادٍ مَالاً لأَحَبَّ أَنَّ لَهُ إِلَيْهِ مِثْلَهُ، وَلاَ يَمْلأُ عَيْنَ ابْنِ آدَمَ إِلاَّ التُّرَابُ، وَيَتُوبُ اللَّهُ عَلَى مَنْ تَابَ ‏"‏‏.‏ قَالَ ابْنُ عَبَّاسٍ فَلاَ أَدْرِي مِنَ الْقُرْآنِ هُوَ أَمْ لاَ‏.‏ قَالَ وَسَمِعْتُ ابْنَ الزُّبَيْرِ يَقُولُ ذَلِكَ عَلَى الْمِنْبَرِ‏.‏\hadithno{6437}\hadithtrans{Narrated Ibn `Abbas:I heard Allah's Messenger (ﷺ) saying, "If the son of Adam had money equal to a valley, then he will wish for another similar to it, for nothing can satisfy the eye of Adam's son except dust. And Allah forgives him who repents to Him." Ibn `Abbas said: I do not know whether this saying was quoted from the Qur'an or not. `Ata' said, "I heard Ibn Az-Zubair saying this narration while he was on the pulpit}}
\hadithdefcmd{bukhari}{6438}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ سُلَيْمَانَ بْنِ الْغَسِيلِ، عَنْ عَبَّاسِ بْنِ سَهْلِ بْنِ سَعْدٍ، قَالَ سَمِعْتُ ابْنَ الزُّبَيْرِ، عَلَى الْمِنْبَرِ بِمَكَّةَ فِي خُطْبَتِهِ يَقُولُ يَا أَيُّهَا النَّاسُ إِنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ لَوْ أَنَّ ابْنَ آدَمَ أُعْطِيَ وَادِيًا مَلأً مِنْ ذَهَبٍ أَحَبَّ إِلَيْهِ ثَانِيًا، وَلَوْ أُعْطِيَ ثَانِيًا أَحَبَّ إِلَيْهِ ثَالِثًا، وَلاَ يَسُدُّ جَوْفَ ابْنِ آدَمَ إِلاَّ التُّرَابُ، وَيَتُوبُ اللَّهُ عَلَى مَنْ تَابَ ‏"‏‏.‏\hadithno{6438}\hadithtrans{Narrated Sahl bin Sa`d:I heard Ibn Az-Zubair who was on the pulpit at Mecca, delivering a sermon, saying, "O men! The Prophet used to say, "If the son of Adam were given a valley full of gold, he would love to have a second one; and if he were given the second one, he would love to have a third, for nothing fills the belly of Adam's son except dust. And Allah forgives he who repents to Him." Ubai said, "We considered this as a saying from the Qur'an till the Sura (beginning with) 'The mutual rivalry for piling up of worldly things diverts you..' (102.1) was revealed}}
\hadithdefcmd{bukhari}{6439}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ أَنَّ لاِبْنِ آدَمَ وَادِيًا مِنْ ذَهَبٍ أَحَبَّ أَنْ يَكُونَ لَهُ وَادِيَانِ، وَلَنْ يَمْلأَ فَاهُ إِلاَّ التُّرَابُ، وَيَتُوبُ اللَّهُ عَلَى مَنْ تَابَ ‏"‏‏.‏\hadithno{6439}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "If Adam's son had a valley full of gold, he would like to have two valleys, for nothing fills his mouth except dust. And Allah forgives him who repents to Him}}
\hadithdefcmd{bukhari}{6440}{وَقَالَ لَنَا أَبُو الْوَلِيدِ حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ ثَابِتٍ، عَنْ أَنَسٍ، عَنْ أُبَىٍّ، قَالَ كُنَّا نَرَى هَذَا مِنَ الْقُرْآنِ حَتَّى نَزَلَتْ ‏\{‏أَلْهَاكُمُ التَّكَاثُرُ‏\}‏\hadithno{6440}\hadithtrans{Ubayy said (referring to the hadith above), "We considered this as a saying from the Qur'an till the Surah (beginning with):"The mutual rivalry (for piling up of worldly things) diverts you' (102:1) was revealed}}
\hadithdefcmd{bukhari}{6441}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُفْيَانُ، قَالَ سَمِعْتُ الزُّهْرِيَّ، يَقُولُ أَخْبَرَنِي عُرْوَةُ، وَسَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ حَكِيمِ بْنِ حِزَامٍ، قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم فَأَعْطَانِي، ثُمَّ سَأَلْتُهُ فَأَعْطَانِي، ثُمَّ سَأَلْتُهُ فَأَعْطَانِي، ثُمَّ قَالَ ‏ "‏ هَذَا الْمَالُ ـ وَرُبَّمَا قَالَ سُفْيَانُ قَالَ لِي يَا حَكِيمُ ـ إِنَّ هَذَا الْمَالَ خَضِرَةٌ حُلْوَةٌ، فَمَنْ أَخَذَهُ بِطِيبِ نَفْسٍ بُورِكَ لَهُ فِيهِ، وَمَنْ أَخَذَهُ بِإِشْرَافِ نَفْسٍ لَمْ يُبَارَكْ لَهُ فِيهِ، وَكَانَ كَالَّذِي يَأْكُلُ وَلاَ يَشْبَعُ، وَالْيَدُ الْعُلْيَا خَيْرٌ مِنَ الْيَدِ السُّفْلَى ‏"‏‏.‏\hadithno{6441}\hadithtrans{Narrated Hakim bin Hizam:I asked the Prophet (for some money) and he gave me, and then again I asked him and he gave me, and then again I asked him and he gave me and he then said, "This wealth is (like) green and sweet (fruit), and whoever takes it without greed, Allah will bless it for him, but whoever takes it with greed, Allah will not bless it for him, and he will be like the one who eats but is never satisfied. And the upper (giving) hand is better than the lower (taking) hand}}
\hadithdefcmd{bukhari}{6442}{حَدَّثَنِي عُمَرُ بْنُ حَفْصٍ، حَدَّثَنِي أَبِي، حَدَّثَنَا الأَعْمَشُ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ التَّيْمِيُّ، عَنِ الْحَارِثِ بْنِ سُوَيْدٍ، قَالَ عَبْدُ اللَّهِ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَيُّكُمْ مَالُ وَارِثِهِ أَحَبُّ إِلَيْهِ مِنْ مَالِهِ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ مَا مِنَّا أَحَدٌ إِلاَّ مَالُهُ أَحَبُّ إِلَيْهِ‏.‏ قَالَ ‏"‏ فَإِنَّ مَالَهُ مَا قَدَّمَ، وَمَالُ وَارِثِهِ مَا أَخَّرَ ‏"‏‏.‏\hadithno{6442}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "Who among you considers the wealth of his heirs dearer to him than his own wealth?" They replied, "O Allah's Messenger (ﷺ)! There is none among us but loves his own wealth more." The Prophet (ﷺ) said, "So his wealth is whatever he spends (in Allah's Cause) during his life (on good deeds) while the wealth of his heirs is whatever he leaves after his death}}
\hadithdefcmd{bukhari}{6443}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا جَرِيرٌ، عَنْ عَبْدِ الْعَزِيزِ بْنِ رُفَيْعٍ، عَنْ زَيْدِ بْنِ وَهْبٍ، عَنْ أَبِي ذَرٍّ ـ رضى الله عنه ـ قَالَ خَرَجْتُ لَيْلَةً مِنَ اللَّيَالِي فَإِذَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَمْشِي وَحْدَهُ، وَلَيْسَ مَعَهُ إِنْسَانٌ ـ قَالَ ـ فَظَنَنْتُ أَنَّهُ يَكْرَهُ أَنْ يَمْشِيَ مَعَهُ أَحَدٌ ـ قَالَ ـ فَجَعَلْتُ أَمْشِي فِي ظِلِّ الْقَمَرِ فَالْتَفَتَ فَرَآنِي فَقَالَ ‏"‏ مَنْ هَذَا ‏"‏‏.‏ قُلْتُ أَبُو ذَرٍّ جَعَلَنِي اللَّهُ فِدَاءَكَ‏.‏ قَالَ ‏"‏ يَا أَبَا ذَرٍّ تَعَالَهْ ‏"‏‏.‏ قَالَ فَمَشَيْتُ مَعَهُ سَاعَةً فَقَالَ ‏"‏ إِنَّ الْمُكْثِرِينَ هُمُ الْمُقِلُّونَ يَوْمَ الْقِيَامَةِ، إِلاَّ مَنْ أَعْطَاهُ اللَّهُ خَيْرًا، فَنَفَحَ فِيهِ يَمِينَهُ وَشِمَالَهُ وَبَيْنَ يَدَيْهِ وَوَرَاءَهُ، وَعَمِلَ فِيهِ خَيْرًا ‏"‏‏.‏ قَالَ فَمَشَيْتُ مَعَهُ سَاعَةً فَقَالَ لِي ‏"‏ اجْلِسْ هَا هُنَا ‏"‏‏.‏ قَالَ فَأَجْلَسَنِي فِي قَاعٍ حَوْلَهُ حِجَارَةٌ فَقَالَ لِي ‏"‏ اجْلِسْ هَا هُنَا حَتَّى أَرْجِعَ إِلَيْكَ ‏"‏‏.‏ قَالَ فَانْطَلَقَ فِي الْحَرَّةِ حَتَّى لاَ أَرَاهُ فَلَبِثَ عَنِّي فَأَطَالَ اللُّبْثَ، ثُمَّ إِنِّي سَمِعْتُهُ وَهْوَ مُقْبِلٌ وَهْوَ يَقُولُ ‏"‏ وَإِنْ سَرَقَ وَإِنْ زَنَى ‏"‏‏.‏ قَالَ فَلَمَّا جَاءَ لَمْ أَصْبِرْ حَتَّى قُلْتُ يَا نَبِيَّ اللَّهِ جَعَلَنِي اللَّهُ فِدَاءَكَ مَنْ تُكَلِّمُ فِي جَانِبِ الْحَرَّةِ مَا سَمِعْتُ أَحَدًا يَرْجِعُ إِلَيْكَ شَيْئًا‏.‏ قَالَ ‏"‏ ذَلِكَ جِبْرِيلُ ـ عَلَيْهِ السَّلاَمُ ـ عَرَضَ لِي فِي جَانِبِ الْحَرَّةِ، قَالَ بَشِّرْ أُمَّتَكَ أَنَّهُ مَنْ مَاتَ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا دَخَلَ الْجَنَّةَ، قُلْتُ يَا جِبْرِيلُ وَإِنْ سَرَقَ وَإِنْ زَنَى قَالَ نَعَمْ‏.‏ قَالَ قُلْتُ وَإِنْ سَرَقَ وَإِنْ زَنَى قَالَ نَعَمْ، وَإِنْ شَرِبَ الْخَمْرَ. قَالَ النَّضْرُ أَخْبَرَنَا شُعْبَةُ، وَحَدَّثَنَا حَبِيبُ بْنُ أَبِي ثَابِتٍ، وَالأَعْمَشُ، وَعَبْدُ الْعَزِيزِ بْنُ رُفَيْعٍ، حَدَّثَنَا زَيْدُ بْنُ وَهْبٍ، بِهَذَا‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ حَدِيثُ أَبِي صَالِحٍ عَنْ أَبِي الدَّرْدَاءِ، مُرْسَلٌ، لاَ يَصِحُّ، إِنَّمَا أَرَدْنَا لِلْمَعْرِفَةِ، وَالصَّحِيحُ حَدِيثُ أَبِي ذَرٍّ‏.‏ قِيلَ لأَبِي عَبْدِ اللَّهِ حَدِيثُ عَطَاءِ بْنِ يَسَارٍ عَنْ أَبِي الدَّرْدَاءِ قَالَ مُرْسَلٌ أَيْضًا لاَ يَصِحُّ، وَالصَّحِيحُ حَدِيثُ أَبِي ذَرٍّ‏.‏ وَقَالَ اضْرِبُوا عَلَى حَدِيثِ أَبِي الدَّرْدَاءِ هَذَا‏.‏ إِذَا مَاتَ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ عِنْدَ الْمَوْتِ‏.‏\hadithno{6443}\hadithtrans{Narrated Abu Dhar:Once I went out at night and found Allah's Messenger (ﷺ) walking all alone accompanied by nobody, and I thought that perhaps he disliked that someone should accompany him. So I walked in the shade, away from the moonlight, but the Prophet (ﷺ) looked behind and saw me and said, "Who is that?" I replied, "Abu Dhar, let Allah get me sacrificed for you!" He said, "O Abu Dhar, come here!" So I accompanied him for a while and then he said, "The rich are in fact the poor (little rewarded) on the Day of Resurrection except him whom Allah gives wealth which he gives (in charity) to his right, left, front and back, and does good deeds with it. I walked with him a little longer. Then he said to me, "Sit down here." So he made me sit in an open space surrounded by rocks, and said to me, "Sit here till I come back to you." He went towards Al-Harra till I could not see him, and he stayed away for a long period, and then I heard him saying, while he was coming, "Even if he had committed theft, and even if he had committed illegal sexual intercourse?" When he came, I could not remain patient and asked him, "O Allah's Prophet! Let Allah get me sacrificed for you! Whom were you speaking to by the side of Al-Harra? I did not hear anybody responding to your talk." He said, "It was Gabriel who appeared to me beside Al-Harra and said, 'Give the good news to your followers that whoever dies without having worshipped anything besides Allah, will enter Paradise.' I said, 'O Gabriel! Even if he had committed theft or committed illegal sexual intercourse?' He said, 'Yes.' I said, 'Even if he has committed theft or committed illegal sexual intercourse?' He said, 'Yes.' I said, 'Even if he has committed theft or committed illegal sexual intercourse?' He said, 'Yes}}
\hadithdefcmd{bukhari}{6444}{حَدَّثَنَا الْحَسَنُ بْنُ الرَّبِيعِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنِ الأَعْمَشِ، عَنْ زَيْدِ بْنِ وَهْبٍ، قَالَ قَالَ أَبُو ذَرٍّ كُنْتُ أَمْشِي مَعَ النَّبِيِّ صلى الله عليه وسلم فِي حَرَّةِ الْمَدِينَةِ فَاسْتَقْبَلَنَا أُحُدٌ فَقَالَ ‏"‏ يَا أَبَا ذَرٍّ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ مَا يَسُرُّنِي أَنَّ عِنْدِي مِثْلَ أُحُدٍ هَذَا ذَهَبًا، تَمْضِي عَلَىَّ ثَالِثَةٌ وَعِنْدِي مِنْهُ دِينَارٌ، إِلاَّ شَيْئًا أُرْصِدُهُ لِدَيْنٍ، إِلاَّ أَنْ أَقُولَ بِهِ فِي عِبَادِ اللَّهِ هَكَذَا وَهَكَذَا وَهَكَذَا ‏"‏‏.‏ عَنْ يَمِينِهِ وَعَنْ شِمَالِهِ وَمِنْ خَلْفِهِ‏.‏ ثُمَّ مَشَى فَقَالَ ‏"‏ إِنَّ الأَكْثَرِينَ هُمُ الأَقَلُّونَ يَوْمَ الْقِيَامَةِ إِلاَّ مَنْ قَالَ هَكَذَا وَهَكَذَا وَهَكَذَا ـ عَنْ يَمِينِهِ وَعَنْ شِمَالِهِ وَمِنْ خَلْفِهِ ـ وَقَلِيلٌ مَا هُمْ ‏"‏‏.‏ ثُمَّ قَالَ لِي ‏"‏ مَكَانَكَ لاَ تَبْرَحْ حَتَّى آتِيَكَ ‏"‏‏.‏ ثُمَّ انْطَلَقَ فِي سَوَادِ اللَّيْلِ حَتَّى تَوَارَى فَسَمِعْتُ صَوْتًا قَدِ ارْتَفَعَ، فَتَخَوَّفْتُ أَنْ يَكُونَ قَدْ عَرَضَ لِلنَّبِيِّ صلى الله عليه وسلم فَأَرَدْتُ أَنْ آتِيَهُ فَذَكَرْتُ قَوْلَهُ لِي ‏"‏ لاَ تَبْرَحْ حَتَّى آتِيَكَ ‏"‏ فَلَمْ أَبْرَحْ حَتَّى أَتَانِي، قُلْتُ يَا رَسُولَ اللَّهِ لَقَدْ سَمِعْتُ صَوْتًا تَخَوَّفْتُ، فَذَكَرْتُ لَهُ فَقَالَ ‏"‏ وَهَلْ سَمِعْتَهُ ‏"‏‏.‏ قُلْتُ نَعَمْ‏.‏ قَالَ ‏"‏ ذَاكَ جِبْرِيلُ أَتَانِي فَقَالَ مَنْ مَاتَ مِنْ أُمَّتِكَ لاَ يُشْرِكُ بِاللَّهِ شَيْئًا دَخَلَ الْجَنَّةَ ‏"‏‏.‏ قُلْتُ وَإِنْ زَنَى وَإِنْ سَرَقَ قَالَ ‏"‏ وَإِنْ زَنَى وَإِنْ سَرَقَ ‏"‏‏.‏\hadithno{6444}\hadithtrans{Narrated Abu Dhar:While I was walking with the Prophet (ﷺ) in the Harra of Medina, Uhud came in sight. The Prophet (ﷺ) said, "O Abu Dhar!" I said, "Labbaik, O Allah's Messenger (ﷺ)!" He said, "I would not like to have gold equal to this mountain of Uhud, unless nothing of it, not even a single Dinar of it remains with me for more than three days, except something which I will keep for repaying debts. I would have spent all of it (distributed it) amongst Allah's Slaves like this, and like this, and like this." The Prophet (ﷺ) pointed out with his hand towards his right, his left and his back (while illustrating it). He proceeded with his walk and said, "The rich are in fact the poor (little rewarded) on the Day of Resurrection except those who spend their wealth like this, and like this, and like this, to their right, left and back, but such people are few in number." Then he said to me, "Stay at your place and do not leave it till I come back." Then he proceeded in the darkness of the night till he went out of sight, and then I heard a loud voice, and was afraid that something might have happened to the Prophet (ﷺ) .1 intended to go to him, but I remembered what he had said to me, i.e. 'Don't leave your place till I come back to you,' so I remained at my place till he came back to me. I said, "O Allah's Messenger (ﷺ)! I heard a voice and I was afraid." So I mentioned the whole story to him. He said, "Did you hear it?" I replied, "Yes." He said, "It was Gabriel who came to me and said, 'Whoever died without joining others in worship with Allah, will enter Paradise.' I asked (Gabriel), 'Even if he had committed theft or committed illegal sexual intercourse? Gabriel said, 'Yes, even if he had committed theft or committed illegal sexual intercourse}}
\hadithdefcmd{bukhari}{6445}{حَدَّثَنِي أَحْمَدُ بْنُ شَبِيبٍ، حَدَّثَنَا أَبِي، عَنْ يُونُسَ،‏.‏ وَقَالَ اللَّيْثُ حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ عُتْبَةَ، قَالَ أَبُو هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ كَانَ لِي مِثْلُ أُحُدٍ ذَهَبًا لَسَرَّنِي أَنْ لاَ تَمُرَّ عَلَىَّ ثَلاَثُ لَيَالٍ وَعِنْدِي مِنْهُ شَىْءٌ، إِلاَّ شَيْئًا أُرْصِدُهُ لِدَيْنٍ ‏"‏‏.‏\hadithno{6445}\hadithtrans{Narrated Abu Huraira:Allah's Apostle said, "If I had gold equal to the mountain of Uhud, it would not please me that anything of it should remain with me after three nights (i.e., I would spend all of it in Allah's Cause) except what I would keep for repaying debts}}
\hadithdefcmd{bukhari}{6446}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا أَبُو بَكْرٍ، حَدَّثَنَا أَبُو حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ الْغِنَى عَنْ كَثْرَةِ الْعَرَضِ، وَلَكِنَّ الْغِنَى غِنَى النَّفْسِ ‏"‏‏.‏\hadithno{6446}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Wealth is not in having many possessions, but rather (true) wealth is feeling sufficiency in the soul}}
\hadithdefcmd{bukhari}{6447}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، أَنَّهُ قَالَ مَرَّ رَجُلٌ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ لِرَجُلٍ عِنْدَهُ جَالِسٍ ‏"‏ مَا رَأْيُكَ فِي هَذَا ‏"‏‏.‏ فَقَالَ رَجُلٌ مِنْ أَشْرَافِ النَّاسِ، هَذَا وَاللَّهِ حَرِيٌّ إِنْ خَطَبَ أَنْ يُنْكَحَ، وَإِنْ شَفَعَ أَنْ يُشَفَّعَ‏.‏ قَالَ فَسَكَتَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ مَرَّ رَجُلٌ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ مَا رَأْيُكَ فِي هَذَا ‏"‏‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ هَذَا رَجُلٌ مِنْ فُقَرَاءِ الْمُسْلِمِينَ، هَذَا حَرِيٌّ إِنْ خَطَبَ أَنْ لاَ يُنْكَحَ، وَإِنْ شَفَعَ أَنْ لاَ يُشَفَّعَ، وَإِنْ قَالَ أَنْ لاَ يُسْمَعَ لِقَوْلِهِ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَذَا خَيْرٌ مِنْ مِلْءِ الأَرْضِ مِثْلَ هَذَا ‏"‏‏.‏\hadithno{6447}\hadithtrans{Narrated Sahl bin Sa`d As-Sa`id:A man passed by Allah's Messenger (ﷺ) and the Prophet (ﷺ) asked a man sitting beside him, "What is your opinion about this (passer-by)?" He replied, "This (passer-by) is from the noble class of people. By Allah, if he should ask for a lady's hand in marriage, he ought to be given her in marriage, and if he intercedes for somebody, his intercession will be accepted. Allah's Messenger (ﷺ) kept quiet, and then another man passed by and Allah's Messenger (ﷺ) asked the same man (his companion) again, "What is your opinion about this (second) one?" He said, "O Allah's Messenger (ﷺ)! This person is one of the poor Muslims. If he should ask a lady's hand in marriage, no-one will accept him, and if he intercedes for somebody, no one will accept his intercession, and if he talks, no-one will listen to his talk." Then Allah's Messenger (ﷺ) said, "This (poor man) is better than such a large number of the first type (i.e. rich men) as to fill the earth}}
\hadithdefcmd{bukhari}{6448}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا الأَعْمَشُ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، قَالَ عُدْنَا خَبَّابًا فَقَالَ هَاجَرْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم نُرِيدُ وَجْهَ اللَّهِ، فَوَقَعَ أَجْرُنَا عَلَى اللَّهِ، فَمِنَّا مَنْ مَضَى لَمْ يَأْخُذْ مِنْ أَجْرِهِ، مِنْهُمْ مُصْعَبُ بْنُ عُمَيْرٍ قُتِلَ يَوْمَ أُحُدٍ، وَتَرَكَ نَمِرَةً فَإِذَا غَطَّيْنَا رَأْسَهُ بَدَتْ رِجْلاَهُ، وَإِذَا غَطَّيْنَا رِجْلَيْهِ بَدَا رَأْسُهُ، فَأَمَرَنَا النَّبِيُّ صلى الله عليه وسلم أَنْ نُغَطِّيَ رَأْسَهُ، وَنَجْعَلَ عَلَى رِجْلَيْهِ مِنَ الإِذْخِرِ، وَمِنَّا مَنْ أَيْنَعَتْ لَهُ ثَمَرَتُهُ فَهْوَ يَهْدُبُهَا‏.‏\hadithno{6448}\hadithtrans{Narrated Abu Wail:We paid a visit to Khabbab who was sick, and he said, "We migrated with the Prophet (ﷺ) for Allah's Sake and our wages became due on Allah. Some of us died without having received anything of the wages, and one of them was Mus`ab bin `Umair, who was martyred on the day of the battle of Uhud, leaving only one sheet (to shroud him in). If we covered his head with it, his feet became uncovered, and if we covered his feet with it, his head became uncovered. So the Prophet (ﷺ) ordered us to cover his head with it and put some Idhkhir (a kind of grass) over his feet. On the other hand, some of us have had the fruits (of our good deed) and are plucking them (in this world)}}
\hadithdefcmd{bukhari}{6449}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا سَلْمُ بْنُ زَرِيرٍ، حَدَّثَنَا أَبُو رَجَاءٍ، عَنْ عِمْرَانَ بْنِ حُصَيْنٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اطَّلَعْتُ فِي الْجَنَّةِ فَرَأَيْتُ أَكْثَرَ أَهْلِهَا الْفُقَرَاءَ، وَاطَّلَعْتُ فِي النَّارِ فَرَأَيْتُ أَكْثَرَ أَهْلِهَا النِّسَاءَ ‏"‏‏.‏ تَابَعَهُ أَيُّوبُ وَعَوْفٌ، وَقَالَ صَخْرٌ وَحَمَّادُ بْنُ نَجِيحٍ عَنْ أَبِي رَجَاءٍ عَنِ ابْنِ عَبَّاسٍ‏.‏\hadithno{6449}\hadithtrans{Narrated `Imran bin Husain:The Prophet (ﷺ) said, "I looked into Paradise and found that the majority of its dwellers were the poor people, and I looked into the (Hell) Fire and found that the majority of its dwellers were women}}
\hadithdefcmd{bukhari}{6450}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ لَمْ يَأْكُلِ النَّبِيُّ صلى الله عليه وسلم عَلَى خِوَانٍ حَتَّى مَاتَ، وَمَا أَكَلَ خُبْزًا مُرَقَّقًا حَتَّى مَاتَ‏.‏\hadithno{6450}\hadithtrans{Narrated Anas:The Prophet (ﷺ) did not eat at a table till he died, and he did not eat a thin nicely baked wheat bread till he died}}
\hadithdefcmd{bukhari}{6451}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ لَقَدْ تُوُفِّيَ النَّبِيُّ صلى الله عليه وسلم وَمَا فِي رَفِّي مِنْ شَىْءٍ يَأْكُلُهُ ذُو كَبِدٍ، إِلاَّ شَطْرُ شَعِيرٍ فِي رَفٍّ لِي، فَأَكَلْتُ مِنْهُ حَتَّى طَالَ عَلَىَّ، فَكِلْتُهُ، فَفَنِيَ‏.‏\hadithno{6451}\hadithtrans{Narrated `Aisha:When the Prophet (ﷺ) died, nothing which can be eaten by a living creature was left on my shelf except some barley grain. I ate of it for a period and when I measured it, it finished}}
\hadithdefcmd{bukhari}{6452}{حَدَّثَنِي أَبُو نُعَيْمٍ، بِنَحْوٍ مِنْ نِصْفِ هَذَا الْحَدِيثِ حَدَّثَنَا عُمَرُ بْنُ ذَرٍّ، حَدَّثَنَا مُجَاهِدٌ، أَنَّ أَبَا هُرَيْرَةَ، كَانَ يَقُولُ آللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ إِنْ كُنْتُ لأَعْتَمِدُ بِكَبِدِي عَلَى الأَرْضِ مِنَ الْجُوعِ، وَإِنْ كُنْتُ لأَشُدُّ الْحَجَرَ عَلَى بَطْنِي مِنَ الْجُوعِ، وَلَقَدْ قَعَدْتُ يَوْمًا عَلَى طَرِيقِهِمُ الَّذِي يَخْرُجُونَ مِنْهُ، فَمَرَّ أَبُو بَكْرٍ، فَسَأَلْتُهُ عَنْ آيَةٍ مِنْ كِتَابِ اللَّهِ، مَا سَأَلْتُهُ إِلاَّ لِيُشْبِعَنِي، فَمَرَّ وَلَمْ يَفْعَلْ، ثُمَّ مَرَّ بِي عُمَرُ فَسَأَلْتُهُ عَنْ آيَةٍ مِنْ كِتَابِ اللَّهِ، مَا سَأَلْتُهُ إِلاَّ لِيُشْبِعَنِي، فَمَرَّ فَلَمْ يَفْعَلْ، ثُمَّ مَرَّ بِي أَبُو الْقَاسِمِ صلى الله عليه وسلم فَتَبَسَّمَ حِينَ رَآنِي وَعَرَفَ، مَا فِي نَفْسِي وَمَا فِي وَجْهِي ثُمَّ قَالَ ‏"‏ أَبَا هِرٍّ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ الْحَقْ ‏"‏‏.‏ وَمَضَى فَتَبِعْتُهُ، فَدَخَلَ فَاسْتَأْذَنَ، فَأَذِنَ لِي، فَدَخَلَ فَوَجَدَ لَبَنًا فِي قَدَحٍ فَقَالَ ‏"‏ مِنْ أَيْنَ هَذَا اللَّبَنُ ‏"‏‏.‏ قَالُوا أَهْدَاهُ لَكَ فُلاَنٌ أَوْ فُلاَنَةُ‏.‏ قَالَ ‏"‏ أَبَا هِرٍّ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ الْحَقْ إِلَى أَهْلِ الصُّفَّةِ فَادْعُهُمْ لِي ‏"‏‏.‏ قَالَ وَأَهْلُ الصُّفَّةِ أَضْيَافُ الإِسْلاَمِ، لاَ يَأْوُونَ إِلَى أَهْلٍ وَلاَ مَالٍ، وَلاَ عَلَى أَحَدٍ، إِذَا أَتَتْهُ صَدَقَةٌ بَعَثَ بِهَا إِلَيْهِمْ، وَلَمْ يَتَنَاوَلْ مِنْهَا شَيْئًا، وَإِذَا أَتَتْهُ هَدِيَّةٌ أَرْسَلَ إِلَيْهِمْ، وَأَصَابَ مِنْهَا وَأَشْرَكَهُمْ فِيهَا، فَسَاءَنِي ذَلِكَ فَقُلْتُ وَمَا هَذَا اللَّبَنُ فِي أَهْلِ الصُّفَّةِ كُنْتُ أَحَقُّ أَنَا أَنْ أُصِيبَ مِنْ هَذَا اللَّبَنِ شَرْبَةً أَتَقَوَّى بِهَا، فَإِذَا جَاءَ أَمَرَنِي فَكُنْتُ أَنَا أُعْطِيهِمْ، وَمَا عَسَى أَنْ يَبْلُغَنِي مِنْ هَذَا اللَّبَنِ، وَلَمْ يَكُنْ مِنْ طَاعَةِ اللَّهِ وَطَاعَةِ رَسُولِهِ صلى الله عليه وسلم بُدٌّ، فَأَتَيْتُهُمْ فَدَعَوْتُهُمْ فَأَقْبَلُوا، فَاسْتَأْذَنُوا فَأَذِنَ لَهُمْ، وَأَخَذُوا مَجَالِسَهُمْ مِنَ الْبَيْتِ قَالَ ‏"‏ يَا أَبَا هِرٍّ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ خُذْ فَأَعْطِهِمْ ‏"‏‏.‏ قَالَ فَأَخَذْتُ الْقَدَحَ فَجَعَلْتُ أُعْطِيهِ الرَّجُلَ فَيَشْرَبُ حَتَّى يَرْوَى، ثُمَّ يَرُدُّ عَلَىَّ الْقَدَحَ، فَأُعْطِيهِ الرَّجُلَ فَيَشْرَبُ حَتَّى يَرْوَى، ثُمَّ يَرُدُّ عَلَىَّ الْقَدَحَ فَيَشْرَبُ حَتَّى يَرْوَى، ثُمَّ يَرُدُّ عَلَىَّ الْقَدَحَ، حَتَّى انْتَهَيْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم وَقَدْ رَوِيَ الْقَوْمُ كُلُّهُمْ، فَأَخَذَ الْقَدَحَ فَوَضَعَهُ عَلَى يَدِهِ فَنَظَرَ إِلَىَّ فَتَبَسَّمَ فَقَالَ ‏"‏ أَبَا هِرٍّ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ بَقِيتُ أَنَا وَأَنْتَ ‏"‏‏.‏ قُلْتُ صَدَقْتَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ اقْعُدْ فَاشْرَبْ ‏"‏‏.‏ فَقَعَدْتُ فَشَرِبْتُ‏.‏ فَقَالَ ‏"‏ اشْرَبْ ‏"‏‏.‏ فَشَرِبْتُ، فَمَا زَالَ يَقُولُ ‏"‏ اشْرَبْ ‏"‏‏.‏ حَتَّى قُلْتُ لاَ وَالَّذِي بَعَثَكَ بِالْحَقِّ، مَا أَجِدُ لَهُ مَسْلَكًا‏.‏ قَالَ ‏"‏ فَأَرِنِي ‏"‏‏.‏ فَأَعْطَيْتُهُ الْقَدَحَ فَحَمِدَ اللَّهَ وَسَمَّى، وَشَرِبَ الْفَضْلَةَ‏.‏\hadithno{6452}\hadithtrans{Narrated Abu Huraira:By Allah except Whom none has the right to- be worshipped, (sometimes) I used to lay (sleep) on the ground on my liver (abdomen) because of hunger, and (sometimes) I used to bind a stone over my belly because of hunger. One day I sat by the way from where they (the Prophet (ﷺ) and his companions) used to come out. When Abu Bakr passed by, I asked him about a Verse from Allah's Book and I asked him only that he might satisfy my hunger, but he passed by and did not do so. Then `Umar passed by me and I asked him about a Verse from Allah's Book, and I asked him only that he might satisfy my hunger, but he passed by without doing so. Finally Abu-l-Qasim (the Prophet (ﷺ) ) passed by me and he smiled when he saw me, for he knew what was in my heart and on my face. He said, "O Aba Hirr (Abu Huraira)!" I replied, "Labbaik, O Allah's Messenger (ﷺ)!" He said to me, "Follow me." He left and I followed him. Then he entered the house and I asked permission to enter and was admitted. He found milk in a bowl and said, "From where is this milk?" They said, "It has been presented to you by such-and-such man (or by such and such woman)." He said, "O Aba Hirr!" I said, "Labbaik, O Allah's Messenger (ﷺ)!" He said, "Go and call the people of Suffa to me." These people of Suffa were the guests of Islam who had no families, nor money, nor anybody to depend upon, and whenever an object of charity was brought to the Prophet, he would send it to them and would not take anything from it, and whenever any present was given to him, he used to send some for them and take some of it for himself. The order of the Prophet upset me, and I said to myself, "How will this little milk be enough for the people of As- Suffa? though I was more entitled to drink from that milk in order to strengthen myself", but behold! The Prophet (ﷺ) came to order me to give that milk to them. I wondered what will remain of that milk for me, but anyway, I could not but obey Allah and His Apostle so I went to the people of As-Suffa and called them, and they came and asked the Prophet's permission to enter. They were admitted and took their seats in the house. The Prophet (ﷺ) said, "O Aba-Hirr!" I said, "Labbaik, O Allah's Messenger (ﷺ)!" He said, "Take it and give it to them." So I took the bowl (of milk) and started giving it to one man who would drink his fill and return it to me, whereupon I would give it to another man who, in his turn, would drink his fill and return it to me, and I would then offer it to another man who would drink his fill and return it to me. Finally, after the whole group had drunk their fill, I reached the Prophet (ﷺ) who took the bowl and put it on his hand, looked at me and smiled and said. "O Aba Hirr!" I replied, "Labbaik, O Allah's Messenger (ﷺ)!" He said, "There remain you and I." I said, "You have said the truth, O Allah's Messenger (ﷺ)!" He said, "Sit down and drink." I sat down and drank. He said, "Drink," and I drank. He kept on telling me repeatedly to drink, till I said, "No. by Allah Who sent you with the Truth, I have no space for it (in my stomach)." He said, "Hand it over to me." When I gave him the bowl, he praised Allah and pronounced Allah's Name on it and drank the remaining milk}}
\hadithdefcmd{bukhari}{6453}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، حَدَّثَنَا قَيْسٌ، قَالَ سَمِعْتُ سَعْدًا، يَقُولُ إِنِّي لأَوَّلُ الْعَرَبِ رَمَى بِسَهْمٍ فِي سَبِيلِ اللَّهِ، وَرَأَيْتُنَا نَغْزُو، وَمَا لَنَا طَعَامٌ إِلاَّ وَرَقُ الْحُبْلَةِ وَهَذَا السَّمُرُ، وَإِنَّ أَحَدَنَا لَيَضَعُ كَمَا تَضَعُ الشَّاةُ، مَا لَهُ خِلْطٌ، ثُمَّ أَصْبَحَتْ بَنُو أَسَدٍ تُعَزِّرُنِي عَلَى الإِسْلاَمِ، خِبْتُ إِذًا وَضَلَّ سَعْيِي‏.‏\hadithno{6453}\hadithtrans{Narrated Sa`d:I was the first man among the Arabs to throw an arrow for Allah's Cause. We used to fight in Allah's Cause while we had nothing to eat except the leaves of the Hubla and the Sumur trees (desert trees) so that we discharged excrement like that of sheep (i.e. unmixed droppings). Today the (people of the) tribe of Bani Asad teach me the laws of Islam. If so, then I am lost, and all my efforts of that hard time had gone in vain}}
\hadithdefcmd{bukhari}{6454}{حَدَّثَنِي عُثْمَانُ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنِ الأَسْوَدِ، عَنْ عَائِشَةَ، قَالَتْ مَا شَبِعَ آلُ مُحَمَّدٍ صلى الله عليه وسلم مُنْذُ قَدِمَ الْمَدِينَةَ مِنْ طَعَامِ بُرٍّ ثَلاَثَ لَيَالٍ تِبَاعًا حَتَّى قُبِضَ‏.‏\hadithno{6454}\hadithtrans{Narrated `Aisha:The family of Muhammad had never eaten their fill of wheat bread for three successive days since they had migrated to Medina till the death of the Prophet}}
\hadithdefcmd{bukhari}{6455}{حَدَّثَنِي إِسْحَاقُ بْنُ إِبْرَاهِيمَ بْنِ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا إِسْحَاقُ ـ هُوَ الأَزْرَقُ ـ عَنْ مِسْعَرِ بْنِ كِدَامٍ، عَنْ هِلاَلٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ مَا أَكَلَ آلُ مُحَمَّدٍ صلى الله عليه وسلم أَكْلَتَيْنِ فِي يَوْمٍ، إِلاَّ إِحْدَاهُمَا تَمْرٌ‏.‏\hadithno{6455}\hadithtrans{Narrated `Aisha:The family of Muhammad did not eat two meals on one day, but one of the two was of dates}}
\hadithdefcmd{bukhari}{6456}{حَدَّثَنِي أَحْمَدُ بْنُ أَبِي رَجَاءٍ، حَدَّثَنَا النَّضْرُ، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ، قَالَتْ كَانَ فِرَاشُ رَسُولِ اللَّهِ صلى الله عليه وسلم مِنْ أَدَمٍ، وَحَشْوُهُ مِنْ لِيفٍ‏.‏\hadithno{6456}\hadithtrans{Narrated `Aisha:The bed mattress of the Prophet (ﷺ) was made of a leather case stuffed with palm fibres}}
\hadithdefcmd{bukhari}{6457}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامُ بْنُ يَحْيَى، حَدَّثَنَا قَتَادَةُ، قَالَ كُنَّا نَأْتِي أَنَسَ بْنَ مَالِكٍ وَخَبَّازُهُ قَائِمٌ وَقَالَ كُلُوا فَمَا أَعْلَمُ النَّبِيَّ صلى الله عليه وسلم رَأَى رَغِيفًا مُرَقَّقًا، حَتَّى لَحِقَ بِاللَّهِ، وَلاَ رَأَى شَاةً سَمِيطًا بِعَيْنِهِ قَطُّ‏.‏\hadithno{6457}\hadithtrans{Narrated Qatada:We used to go to Anas bin Malik and see his baker standing (preparing the bread). Anas said, "Eat. I have not known that the Prophet (ﷺ) ever saw a thin well-baked loaf of bread till he died, and he never saw a roasted sheep with his eyes}}
\hadithdefcmd{bukhari}{6458}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا يَحْيَى، حَدَّثَنَا هِشَامٌ، أَخْبَرَنِي أَبِي، عَنْ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ كَانَ يَأْتِي عَلَيْنَا الشَّهْرُ مَا نُوقِدُ فِيهِ نَارًا، إِنَّمَا هُوَ التَّمْرُ وَالْمَاءُ، إِلاَّ أَنْ نُؤْتَى بِاللُّحَيْمِ‏.‏\hadithno{6458}\hadithtrans{Narrated `Aisha:A complete month would pass by during which we would not make a fire (for cooking), and our food used to be only dates and water unless we were given a present of some meat}}
\hadithdefcmd{bukhari}{6459}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ الأُوَيْسِيُّ، حَدَّثَنِي ابْنُ أَبِي حَازِمٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ بْنِ رُومَانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ لِعُرْوَةَ ابْنَ أُخْتِي إِنْ كُنَّا لَنَنْظُرُ إِلَى الْهِلاَلِ ثَلاَثَةَ أَهِلَّةٍ فِي شَهْرَيْنِ، وَمَا أُوقِدَتْ فِي أَبْيَاتِ رَسُولِ اللَّهِ صلى الله عليه وسلم نَارٌ‏.‏ فَقُلْتُ مَا كَانَ يُعِيشُكُمْ قَالَتِ الأَسْوَدَانِ التَّمْرُ وَالْمَاءُ إِلاَّ أَنَّهُ قَدْ كَانَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم جِيرَانٌ مِنَ الأَنْصَارِ كَانَ لَهُمْ مَنَائِحُ، وَكَانُوا يَمْنَحُونَ رَسُولَ اللَّهِ صلى الله عليه وسلم مِنْ أَبْيَاتِهِمْ، فَيَسْقِينَاهُ‏.‏\hadithno{6459}\hadithtrans{Narrated `Aisha:that she said to `Urwa, "O, the son of my sister! We used to see three crescents in two months, and no fire used to be made in the houses of Allah's Messenger (ﷺ) (i.e. nothing used to be cooked)." `Urwa said, "What used to sustain you?" `Aisha said, "The two black things i.e. dates and water, except that Allah's Messenger (ﷺ) had neighbors from the Ansar who had some milch she-camels, and they used to give the Prophet (ﷺ) some milk from their house, and he used to make us drink it}}
\hadithdefcmd{bukhari}{6460}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ أَبِيهِ، عَنْ عُمَارَةَ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اللَّهُمَّ ارْزُقْ آلَ مُحَمَّدٍ قُوتًا ‏"‏‏.‏\hadithno{6460}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "O Allah! Give food to the family of Muhammad}}
\hadithdefcmd{bukhari}{6461}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنَا أَبِي، عَنْ شُعْبَةَ، عَنْ أَشْعَثَ، قَالَ سَمِعْتُ أَبِي قَالَ، سَمِعْتُ مَسْرُوقًا، قَالَ سَأَلْتُ عَائِشَةَ ـ رضى الله عنها ـ أَىُّ الْعَمَلِ كَانَ أَحَبَّ إِلَى النَّبِيِّ صلى الله عليه وسلم قَالَتِ الدَّائِمُ‏.‏ قَالَ قُلْتُ فَأَىَّ حِينٍ كَانَ يَقُومُ قَالَتْ كَانَ يَقُومُ إِذَا سَمِعَ الصَّارِخَ‏.‏\hadithno{6461}\hadithtrans{Narrated Masruq:I asked `Aisha "What deed was the most beloved to the Prophet?" She said, "The regular constant one." I said, "At what time did he use to get up at night (for the Tahajjud night prayer)?' She said, "He used to get up on hearing (the crowing of) the cock (the last third of the night)}}
\hadithdefcmd{bukhari}{6462}{حَدَّثَنَا قُتَيْبَةُ، عَنْ مَالِكٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كَانَ أَحَبُّ الْعَمَلِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم الَّذِي يَدُومُ عَلَيْهِ صَاحِبُهُ‏.‏\hadithno{6462}\hadithtrans{Narrated `Aisha:The most beloved action to Allah's Messenger (ﷺ) was that whose doer did it continuously and regularly}}
\hadithdefcmd{bukhari}{6463}{حَدَّثَنَا آدَمُ، حَدَّثَنَا ابْنُ أَبِي ذِئْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَنْ يُنَجِّيَ أَحَدًا مِنْكُمْ عَمَلُهُ ‏"‏‏.‏ قَالُوا وَلاَ أَنْتَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَلاَ أَنَا، إِلاَّ أَنْ يَتَغَمَّدَنِي اللَّهُ بِرَحْمَةٍ، سَدِّدُوا وَقَارِبُوا، وَاغْدُوا وَرُوحُوا، وَشَىْءٌ مِنَ الدُّلْجَةِ‏.‏ وَالْقَصْدَ الْقَصْدَ تَبْلُغُوا ‏"‏‏.‏\hadithno{6463}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The deeds of anyone of you will not save you (from the (Hell) Fire)." They said, "Even you (will not be saved by your deeds), O Allah's Messenger (ﷺ)?" He said, "No, even I (will not be saved) unless and until Allah bestows His Mercy on me. Therefore, do good deeds properly, sincerely and moderately, and worship Allah in the forenoon and in the afternoon and during a part of the night, and always adopt a middle, moderate, regular course whereby you will reach your target (Paradise)}}
\hadithdefcmd{bukhari}{6464}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا سُلَيْمَانُ، عَنْ مُوسَى بْنِ عُقْبَةَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ سَدِّدُوا وَقَارِبُوا، وَاعْلَمُوا أَنْ لَنْ يُدْخِلَ أَحَدَكُمْ عَمَلُهُ الْجَنَّةَ، وَأَنَّ أَحَبَّ الأَعْمَالِ أَدْوَمُهَا إِلَى اللَّهِ، وَإِنْ قَلَّ ‏"‏\hadithno{6464}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said, "Do good deeds properly, sincerely and moderately and know that your deeds will not make you enter Paradise, and that the most beloved deed to Allah is the most regular and constant even if it were little}}
\hadithdefcmd{bukhari}{6465}{حَدَّثَنِي مُحَمَّدُ بْنُ عَرْعَرَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، عَنْ عَائِشَةَ ـ رضى الله عنها ـ أَنَّهَا قَالَتْ سُئِلَ النَّبِيُّ صلى الله عليه وسلم أَىُّ الأَعْمَالِ أَحَبُّ إِلَى اللَّهِ قَالَ ‏"‏ أَدْوَمُهَا وَإِنْ قَلَّ ‏"‏‏.‏ وَقَالَ ‏"‏ اكْلَفُوا مِنَ الأَعْمَالِ مَا تُطِيقُونَ ‏"‏‏.‏\hadithno{6465}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) was asked, "What deeds are loved most by Allah?" He said, "The most regular constant deeds even though they may be few." He added, 'Don't take upon yourselves, except the deeds which are within your ability}}
\hadithdefcmd{bukhari}{6466}{حَدَّثَنِي عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ سَأَلْتُ أُمَّ الْمُؤْمِنِينَ عَائِشَةَ قُلْتُ يَا أُمَّ الْمُؤْمِنِينَ كَيْفَ كَانَ عَمَلُ النَّبِيِّ صلى الله عليه وسلم هَلْ كَانَ يَخُصُّ شَيْئًا مِنَ الأَيَّامِ قَالَتْ لاَ، كَانَ عَمَلُهُ دِيمَةً، وَأَيُّكُمْ يَسْتَطِيعُ مَا كَانَ النَّبِيُّ صلى الله عليه وسلم يَسْتَطِيعُ‏.‏\hadithno{6466}\hadithtrans{Narrated 'Alqama:I asked `Aisha, mother of the believers, "O mother of the believers! How were the deeds of the Prophet? Did he use to do extra deeds of worship on special days?" She said, "No, but his deeds were regular and constant, and who among you is able to do what the Prophet (ﷺ) was able to do (i.e. in worshipping Allah)?}}
\hadithdefcmd{bukhari}{6467}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُحَمَّدُ بْنُ الزِّبْرِقَانِ، حَدَّثَنَا مُوسَى بْنُ عُقْبَةَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ سَدِّدُوا وَقَارِبُوا، وَأَبْشِرُوا، فَإِنَّهُ لاَ يُدْخِلُ أَحَدًا الْجَنَّةَ عَمَلُهُ ‏"‏‏.‏ قَالُوا وَلاَ، أَنْتَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ وَلاَ أَنَا إِلاَّ أَنْ يَتَغَمَّدَنِي اللَّهُ بِمَغْفِرَةٍ وَرَحْمَةٍ ‏"‏‏.‏ قَالَ أَظُنُّهُ عَنْ أَبِي النَّضْرِ عَنْ أَبِي سَلَمَةَ عَنْ عَائِشَةَ‏.‏ وَقَالَ عَفَّانُ حَدَّثَنَا وُهَيْبٌ، عَنْ مُوسَى بْنِ عُقْبَةَ، قَالَ سَمِعْتُ أَبَا سَلَمَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ سَدِّدُوا وَأَبْشِرُوا ‏"‏‏.‏ وَقَالَ مُجَاهِدٌ ‏\{‏قَوْلاً سَدِيدًا‏\}‏ وَسَدَادًا صِدْقًا‏.‏\hadithno{6467}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "Do good deeds properly, sincerely and moderately, and receive good news because one's good deeds will not make him enter Paradise." They asked, "Even you, O Allah's Messenger (ﷺ)?" He said, "Even I, unless and until Allah bestows His pardon and Mercy on me}}
\hadithdefcmd{bukhari}{6468}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُلَيْحٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ هِلاَلِ بْنِ عَلِيٍّ، عَنْ أَنَسِ بْنِ مَالِكٍ ـ رضى الله عنه ـ قَالَ سَمِعْتُهُ يَقُولُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى لَنَا يَوْمًا الصَّلاَةَ، ثُمَّ رَقِيَ الْمِنْبَرَ فَأَشَارَ بِيَدِهِ قِبَلَ قِبْلَةِ الْمَسْجِدِ، فَقَالَ ‏ "‏ قَدْ أُرِيتُ الآنَ ـ مُنْذُ صَلَّيْتُ لَكُمُ الصَّلاَةَ ـ الْجَنَّةَ وَالنَّارَ مُمَثَّلَتَيْنِ فِي قُبُلِ هَذَا الْجِدَارِ، فَلَمْ أَرَ كَالْيَوْمِ فِي الْخَيْرِ وَالشَّرِّ، فَلَمْ أَرَ كَالْيَوْمِ فِي الْخَيْرِ وَالشَّرِّ ‏"‏‏.‏\hadithno{6468}\hadithtrans{Narrated Anas bin Malik:Once Allah's Messenger (ﷺ) led us in prayer and then (after finishing it) ascended the pulpit and pointed with his hand towards the Qibla of the mosque and said, "While I was leading you in prayer, both Paradise and Hell were displayed in front of me in the direction of this wall. I had never seen a better thing (than Paradise) and a worse thing (than Hell) as I have seen today, I had never seen a better thing and a worse thing as I have seen today}}
\hadithdefcmd{bukhari}{6469}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ اللَّهَ خَلَقَ الرَّحْمَةَ يَوْمَ خَلَقَهَا مِائَةَ رَحْمَةٍ، فَأَمْسَكَ عِنْدَهُ تِسْعًا وَتِسْعِينَ رَحْمَةً، وَأَرْسَلَ فِي خَلْقِهِ كُلِّهِمْ رَحْمَةً وَاحِدَةً، فَلَوْ يَعْلَمُ الْكَافِرُ بِكُلِّ الَّذِي عِنْدَ اللَّهِ مِنَ الرَّحْمَةِ لَمْ يَيْأَسْ مِنَ الْجَنَّةِ، وَلَوْ يَعْلَمُ الْمُؤْمِنُ بِكُلِّ الَّذِي عِنْدَ اللَّهِ مِنَ الْعَذَابِ لَمْ يَأْمَنْ مِنَ النَّارِ ‏"‏‏.‏\hadithno{6469}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, Verily Allah created Mercy. The day He created it, He made it into one hundred parts. He withheld with Him ninety-nine parts, and sent its one part to all His creatures. Had the non-believer known of all the Mercy which is in the Hands of Allah, he would not lose hope of entering Paradise, and had the believer known of all the punishment which is present with Allah, he would not consider himself safe from the Hell-Fire}}
\hadithdefcmd{bukhari}{6470}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي عَطَاءُ بْنُ يَزِيدَ، أَنَّ أَبَا سَعِيدٍ، أَخْبَرَهُ أَنَّ أُنَاسًا مِنَ الأَنْصَارِ سَأَلُوا رَسُولَ اللَّهِ صلى الله عليه وسلم فَلَمْ يَسْأَلْهُ أَحَدٌ مِنْهُمْ إِلاَّ أَعْطَاهُ حَتَّى نَفِدَ مَا عِنْدَهُ فَقَالَ لَهُمْ حِينَ نَفِدَ كُلُّ شَىْءٍ أَنْفَقَ بِيَدَيْهِ ‏ "‏ مَا يَكُنْ عِنْدِي مِنْ خَيْرٍ لاَ أَدَّخِرْهُ عَنْكُمْ، وَإِنَّهُ مَنْ يَسْتَعِفَّ يُعِفُّهُ اللَّهُ، وَمَنْ يَتَصَبَّرْ يُصَبِّرْهُ اللَّهُ، وَمَنْ يَسْتَغْنِ يُغْنِهِ اللَّهُ، وَلَنْ تُعْطَوْا عَطَاءً خَيْرًا وَأَوْسَعَ مِنَ الصَّبْرِ ‏"‏‏.‏\hadithno{6470}\hadithtrans{Narrated Abu Sa`id:Some people from the Ansar asked Allah's Messenger (ﷺ) (to give them something) and he gave to everyone of them, who asked him, until all that he had was finished. When everything was finished and he had spent all that was in his hand, he said to them, '"(Know) that if I have any wealth, I will not withhold it from you (to keep for somebody else); And (know) that he who refrains from begging others (or doing prohibited deeds), Allah will make him contented and not in need of others; and he who remains patient, Allah will bestow patience upon him, and he who is satisfied with what he has, Allah will make him self-sufficient. And there is no gift better and vast (you may be given) than patience}}
\hadithdefcmd{bukhari}{6471}{حَدَّثَنَا خَلاَّدُ بْنُ يَحْيَى، حَدَّثَنَا مِسْعَرٌ، حَدَّثَنَا زِيَادُ بْنُ عِلاَقَةَ، قَالَ سَمِعْتُ الْمُغِيرَةَ بْنَ شُعْبَةَ، يَقُولُ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي حَتَّى تَرِمَ ـ أَوْ تَنْتَفِخَ ـ قَدَمَاهُ فَيُقَالُ لَهُ، فَيَقُولُ ‏ "‏ أَفَلاَ أَكُونُ عَبْدًا شَكُورًا ‏"‏‏.‏\hadithno{6471}\hadithtrans{Narrated Al-Mughira bin Shu`ba:The Prophet (ﷺ) used to pray so much that his feet used to become edematous or swollen, and when he was asked as to why he prays so much, he would say, "Shall I not be a thankful slave (to Allah)?}}
\hadithdefcmd{bukhari}{6472}{حَدَّثَنِي إِسْحَاقُ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ حُصَيْنَ بْنَ عَبْدِ الرَّحْمَنِ، قَالَ كُنْتُ قَاعِدًا عِنْدَ سَعِيدِ بْنِ جُبَيْرٍ فَقَالَ عَنِ ابْنِ عَبَّاسٍ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَدْخُلُ الْجَنَّةَ مِنْ أُمَّتِي سَبْعُونَ أَلْفًا بِغَيْرِ حِسَابٍ، هُمُ الَّذِينَ لاَ يَسْتَرْقُونَ، وَلاَ يَتَطَيَّرُونَ، وَعَلَى رَبِّهِمْ يَتَوَكَّلُونَ ‏"‏‏.‏\hadithno{6472}\hadithtrans{Narrated Ibn `Abbas:Allah's Messenger (ﷺ) said, "Seventy thousand people of my followers will enter Paradise without accounts, and they are those who do not practice Ar-Ruqya and do not see an evil omen in things, and put their trust in their Lord}}
\hadithdefcmd{bukhari}{6473}{حَدَّثَنَا عَلِيُّ بْنُ مُسْلِمٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا غَيْرُ، وَاحِدٍ، مِنْهُمْ مُغِيرَةُ وَفُلاَنٌ وَرَجُلٌ ثَالِثٌ أَيْضًا عَنِ الشَّعْبِيِّ عَنْ وَرَّادٍ كَاتِبِ الْمُغِيرَةِ بْنِ شُعْبَةَ أَنَّ مُعَاوِيَةَ كَتَبَ إِلَى الْمُغِيرَةِ أَنِ اكْتُبْ إِلَىَّ بِحَدِيثٍ سَمِعْتَهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَكَتَبَ إِلَيْهِ الْمُغِيرَةُ أَنِّي سَمِعْتُهُ يَقُولُ عِنْدَ انْصِرَافِهِ مِنَ الصَّلاَةِ ‏ "‏ لاَ إِلَهَ إِلاَّ اللَّهُ، وَحْدَهُ لاَ شَرِيكَ لَهُ، لَهُ الْمُلْكُ، وَلَهُ الْحَمْدُ، وَهْوَ عَلَى كُلِّ شَىْءٍ قَدِيرٌ ‏"‏‏.‏ ثَلاَثَ مَرَّاتٍ قَالَ وَكَانَ يَنْهَى عَنْ قِيلَ وَقَالَ وَكَثْرَةِ السُّؤَالِ، وَإِضَاعَةِ الْمَالِ، وَمَنْعٍ وَهَاتِ، وَعُقُوقِ الأُمَّهَاتِ، وَوَأْدِ الْبَنَاتِ‏.‏ وَعَنْ هُشَيْمٍ أَخْبَرَنَا عَبْدُ الْمَلِكِ بْنُ عُمَيْرٍ قَالَ سَمِعْتُ وَرَّادًا يُحَدِّثُ هَذَا الْحَدِيثَ عَنِ الْمُغِيرَةِ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6473}\hadithtrans{Narrated Warrad:(the clerk of Al-Mughira bin Shu`ba) Muawiya wrote to Al-Mughira: "Write to me a narration you have heard from Allah's Messenger (ﷺ)." So Al-Mughira wrote to him, "I heard him saying the following after each prayer: 'La ilaha illal-lahu wahdahu la sharika lahu, lahu-l-mulk wa lahuI-hamd, wa huwa 'ala kulli Shai-in qadir.' He also used to forbid idle talk, asking too many questions (in religion), wasting money, preventing what should be given, and asking others for something (except in great need), being undutiful to mothers, and burying one's little daughters (alive)}}
\hadithdefcmd{bukhari}{6474}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا عُمَرُ بْنُ عَلِيٍّ، سَمِعَ أَبَا حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ يَضْمَنْ لِي مَا بَيْنَ لَحْيَيْهِ وَمَا بَيْنَ رِجْلَيْهِ أَضْمَنْ لَهُ الْجَنَّةَ ‏"‏‏.‏\hadithno{6474}\hadithtrans{Narrated Sahl bin Sa`d:Allah's Messenger (ﷺ) said, "Whoever can guarantee (the chastity of) what is between his two jaw-bones and what is between his two legs (i.e. his tongue and his private parts), I guarantee Paradise for him}}
\hadithdefcmd{bukhari}{6475}{حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيَقُلْ خَيْرًا، أَوْ لِيَصْمُتْ، وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلاَ يُؤْذِ جَارَهُ، وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيُكْرِمْ ضَيْفَهُ ‏"‏‏.‏\hadithno{6475}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Whoever believes in Allah and the Last Day should talk what is good or keep quiet, and whoever believes in Allah and the Last Day should not hurt (or insult) his neighbor; and whoever believes in Allah and the Last Day, should entertain his guest generously}}
\hadithdefcmd{bukhari}{6476}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا لَيْثٌ، حَدَّثَنَا سَعِيدٌ الْمَقْبُرِيُّ، عَنْ أَبِي شُرَيْحٍ الْخُزَاعِيِّ، قَالَ سَمِعَ أُذُنَاىَ، وَوَعَاهُ، قَلْبِي النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ الضِّيَافَةُ ثَلاَثَةُ أَيَّامٍ جَائِزَتُهُ ‏"‏‏.‏ قِيلَ مَا جَائِزَتُهُ قَالَ ‏"‏ يَوْمٌ وَلَيْلَةٌ، وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيُكْرِمْ ضَيْفَهُ، وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلْيَقُلْ خَيْرًا، أَوْ لِيَسْكُتْ ‏"‏‏.‏\hadithno{6476}\hadithtrans{Narrated Abu Shuraih Al-Khuza`i:My ears heard and my heart grasped (the statement which) the Prophet (ﷺ) said, "The period for keeping one's guest is three days (and don't forget) his reward." It was asked, "What is his reward?" He said, "In the first night and the day he should be given a high class quality of meals; and whoever believes in Allah and the Last Day, should entertain his guest generously; and whoever believes in Allah and the Last Day should talk what is good (sense) or keep quiet}}
\hadithdefcmd{bukhari}{6477}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنِي ابْنُ أَبِي حَازِمٍ، عَنْ يَزِيدَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عِيسَى بْنِ طَلْحَةَ التَّيْمِيِّ، عَنْ أَبِي هُرَيْرَةَ، سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ الْعَبْدَ لَيَتَكَلَّمُ بِالْكَلِمَةِ مَا يَتَبَيَّنُ فِيهَا، يَزِلُّ بِهَا فِي النَّارِ أَبْعَدَ مِمَّا بَيْنَ الْمَشْرِقِ ‏"‏‏.‏\hadithno{6477}\hadithtrans{Narrated Abu Huraira:That he heard Allah's Messenger (ﷺ) saying, "A slave of Allah may utter a word without thinking whether it is right or wrong, he may slip down in the Fire as far away a distance equal to that between the east}}
\hadithdefcmd{bukhari}{6478}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُنِيرٍ، سَمِعَ أَبَا النَّضْرِ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ ـ يَعْنِي ابْنَ دِينَارٍ ـ عَنْ أَبِيهِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ الْعَبْدَ لَيَتَكَلَّمُ بِالْكَلِمَةِ مِنْ رِضْوَانِ اللَّهِ لاَ يُلْقِي لَهَا بَالاً، يَرْفَعُ اللَّهُ بِهَا دَرَجَاتٍ، وَإِنَّ الْعَبْدَ لَيَتَكَلَّمُ بِالْكَلِمَةِ مِنْ سَخَطِ اللَّهِ لاَ يُلْقِي لَهَا بَالاً يَهْوِي بِهَا فِي جَهَنَّمَ ‏"‏‏.‏\hadithno{6478}\hadithtrans{Narrated Abu Huraira:The Prophet; said, "A slave (of Allah) may utter a word which pleases Allah without giving it much importance, and because of that Allah will raise him to degrees (of reward): a slave (of Allah) may utter a word (carelessly) which displeases Allah without thinking of its gravity and because of that he will be thrown into the Hell-Fire}}
\hadithdefcmd{bukhari}{6479}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، قَالَ حَدَّثَنِي خُبَيْبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ سَبْعَةٌ يُظِلُّهُمُ اللَّهُ، رَجُلٌ ذَكَرَ اللَّهَ فَفَاضَتْ عَيْنَاهُ ‏"‏‏.‏\hadithno{6479}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said Allah will give shade to seven (types of people) under His Shade (on the Day of Resurrection). (one of them will be) a person who remembers Allah and his eyes are then flooded with tears}}
\hadithdefcmd{bukhari}{6480}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ رِبْعِيٍّ، عَنْ حُذَيْفَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ كَانَ رَجُلٌ مِمَّنْ كَانَ قَبْلَكُمْ يُسِيءُ الظَّنَّ بِعَمَلِهِ، فَقَالَ لأَهْلِهِ إِذَا أَنَا مُتُّ فَخُذُونِي فَذَرُّونِي، فِي الْبَحْرِ فِي يَوْمٍ صَائِفٍ، فَفَعَلُوا بِهِ، فَجَمَعَهُ اللَّهُ ثُمَّ قَالَ مَا حَمَلَكَ عَلَى الَّذِي صَنَعْتَ قَالَ مَا حَمَلَنِي إِلاَّ مَخَافَتُكَ‏.‏ فَغَفَرَ لَهُ ‏"‏‏.‏\hadithno{6480}\hadithtrans{Narrated Hudhaifa:The Prophet (ﷺ) said, "There was a man amongst the people who had suspicion as to the righteousness of his deeds. Therefore he said to his family, 'If I die, take me and burn my corpse and throw my ashes into the sea on a hot (or windy) day.' They did so, but Allah, collected his particles and asked (him), What made you do what you did?' He replied, 'The only thing that made me do it, was that I was afraid of You.' So Allah forgave him}}
\hadithdefcmd{bukhari}{6481}{حَدَّثَنَا مُوسَى، حَدَّثَنَا مُعْتَمِرٌ، سَمِعْتُ أَبِي، حَدَّثَنَا قَتَادَةُ، عَنْ عُقْبَةَ بْنِ عَبْدِ الْغَافِرِ، عَنْ أَبِي سَعِيدٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ذَكَرَ رَجُلاً فِيمَنْ كَانَ سَلَفَ أَوْ قَبْلَكُمْ آتَاهُ اللَّهُ مَالاً وَوَلَدًا ـ يَعْنِي أَعْطَاهُ قَالَ ـ فَلَمَّا حُضِرَ قَالَ لِبَنِيهِ أَىَّ أَبٍ كُنْتُ قَالُوا خَيْرَ أَبٍ‏.‏ قَالَ فَإِنَّهُ لَمْ يَبْتَئِرْ عِنْدَ اللَّهِ خَيْرًا ـ فَسَّرَهَا قَتَادَةُ لَمْ يَدَّخِرْ ـ وَإِنْ يَقْدَمْ عَلَى اللَّهِ يُعَذِّبْهُ فَانْظُرُوا، فَإِذَا مُتُّ فَأَحْرِقُونِي، حَتَّى إِذَا صِرْتُ فَحْمًا فَاسْحَقُونِي ـ أَوْ قَالَ فَاسْهَكُونِي ـ ثُمَّ إِذَا كَانَ رِيحٌ عَاصِفٌ فَأَذْرُونِي فِيهَا‏.‏ فَأَخَذَ مَوَاثِيقَهُمْ عَلَى ذَلِكَ وَرَبِّي فَفَعَلُوا فَقَالَ اللَّهُ كُنْ‏.‏ فَإِذَا رَجُلٌ قَائِمٌ، ثُمَّ قَالَ أَىْ عَبْدِي مَا حَمَلَكَ عَلَى مَا فَعَلْتَ قَالَ مَخَافَتُكَ ـ أَوْ فَرَقٌ مِنْكَ ـ فَمَا تَلاَفَاهُ أَنْ رَحِمَهُ اللَّهُ ‏"‏‏.‏ فَحَدَّثْتُ أَبَا عُثْمَانَ فَقَالَ سَمِعْتُ سَلْمَانَ غَيْرَ أَنَّهُ زَادَ فَأَذْرُونِي فِي الْبَحْرِ‏.‏ أَوْ كَمَا حَدَّثَ‏.‏ وَقَالَ مُعَاذٌ حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، سَمِعْتُ عُقْبَةَ، سَمِعْتُ أَبَا سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6481}\hadithtrans{Narrated Abu Sa`id:The Prophet (ﷺ) mentioned a man from the previous generation or from the people preceding your age whom Allah had given both wealth and children. The Prophet (ﷺ) said, "When the time of his death approached, he asked his children, 'What type of father have I been to you?' They replied: You have been a good father. He said, 'But he (i.e. your father) has not stored any good deeds with Allah (for the Hereafter): if he should face Allah, Allah will punish him. So listen, (O my children), when I die, burn my body till I become mere coal and then grind it into powder, and when there is a stormy wind, throw me (my ashes) in it.' So he took a firm promise from his children (to follow his instructions). And by Allah they (his sons) did accordingly(fulfilled their promise.) Then Allah said, "Be"' and behold! That man was standing there! Allah then said. "O my slave! What made you do what you did?" That man said, "Fear of You." So Allah forgave him}}
\hadithdefcmd{bukhari}{6482}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي بُرْدَةَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَثَلِي وَمَثَلُ مَا بَعَثَنِي اللَّهُ كَمَثَلِ رَجُلٍ أَتَى قَوْمًا فَقَالَ رَأَيْتُ الْجَيْشَ بِعَيْنَىَّ، وَإِنِّي أَنَا النَّذِيرُ الْعُرْيَانُ فَالنَّجَا النَّجَاءَ‏.‏ فَأَطَاعَتْهُ طَائِفَةٌ فَأَدْلَجُوا عَلَى مَهْلِهِمْ فَنَجَوْا، وَكَذَّبَتْهُ طَائِفَةٌ فَصَبَّحَهُمُ الْجَيْشُ فَاجْتَاحَهُمْ ‏"‏‏.‏\hadithno{6482}\hadithtrans{Narrated Abu Musa:Allah's Messenger (ﷺ) said. "My example and the example of the message with which Allah has sent me is like that of a man who came to some people and said, "I have seen with my own eyes the enemy forces, and I am a naked warner (to you) so save yourself, save yourself! A group of them obeyed him and went out at night, slowly and stealthily and were safe, while another group did not believe him and thus the army took them in the morning and destroyed them}}
\hadithdefcmd{bukhari}{6483}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ، أَنَّهُ حَدَّثَهُ أَنَّهُ، سَمِعَ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّمَا مَثَلِي وَمَثَلُ النَّاسِ كَمَثَلِ رَجُلٍ اسْتَوْقَدَ نَارًا، فَلَمَّا أَضَاءَتْ مَا حَوْلَهُ جَعَلَ الْفَرَاشُ وَهَذِهِ الدَّوَابُّ الَّتِي تَقَعُ فِي النَّارِ يَقَعْنَ فِيهَا، فَجَعَلَ يَنْزِعُهُنَّ وَيَغْلِبْنَهُ فَيَقْتَحِمْنَ فِيهَا، فَأَنَا آخُذُ بِحُجَزِكُمْ عَنِ النَّارِ، وَأَنْتُمْ تَقْتَحِمُونَ فِيهَا ‏"‏‏.‏\hadithno{6483}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "My example and the example of the people is that of a man who made a fire, and when it lighted what was around it, Moths and other insects started falling into the fire. The man tried (his best) to prevent them, (from falling in the fire) but they overpowered him and rushed into the fire. The Prophet (ﷺ) added: Now, similarly, I take hold of the knots at your waist (belts) to prevent you from falling into the Fire, but you insist on falling into it}}
\hadithdefcmd{bukhari}{6484}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا زَكَرِيَّاءُ، عَنْ عَامِرٍ، قَالَ سَمِعْتُ عَبْدَ اللَّهِ بْنَ عَمْرٍو، يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْمُسْلِمُ مَنْ سَلِمَ الْمُسْلِمُونَ مِنْ لِسَانِهِ وَيَدِهِ، وَالْمُهَاجِرُ مَنْ هَجَرَ مَا نَهَى اللَّهُ عَنْهُ ‏"‏‏.‏\hadithno{6484}\hadithtrans{Narrated `Abdullah bin `Amr:The Prophet (ﷺ) said, "A Muslim is the one who avoids harming Muslims with his tongue or his hands. And a Muhajir (an emigrant) is the one who gives up (abandons) all what Allah has forbidden}}
\hadithdefcmd{bukhari}{6485}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ ـ رضى الله عنه ـ كَانَ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ تَعْلَمُونَ مَا أَعْلَمُ لَضَحِكْتُمْ قَلِيلاً، وَلَبَكَيْتُمْ كَثِيرًا ‏"‏‏.‏\hadithno{6485}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If you knew that which I know you would laugh little and weep much}}
\hadithdefcmd{bukhari}{6486}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ مُوسَى بْنِ أَنَسٍ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏لَوْ تَعْلَمُونَ مَا أَعْلَمُ لَضَحِكْتُمْ قَلِيلاً وَلَبَكَيْتُمْ كَثِيرًا‏"‏\hadithno{6486}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "If you knew that which I know, you would laugh little and weep much}}
\hadithdefcmd{bukhari}{6487}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ حُجِبَتِ النَّارُ بِالشَّهَوَاتِ، وَحُجِبَتِ الْجَنَّةُ بِالْمَكَارِهِ ‏"‏‏.‏\hadithno{6487}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The (Hell) Fire is surrounded by all kinds of desires and passions, while Paradise is surrounded by all kinds of disliked undesirable things}}
\hadithdefcmd{bukhari}{6488}{حَدَّثَنِي مُوسَى بْنُ مَسْعُودٍ، حَدَّثَنَا سُفْيَانُ، عَنْ مَنْصُورٍ، وَالأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ الْجَنَّةُ أَقْرَبُ إِلَى أَحَدِكُمْ مِنْ شِرَاكِ نَعْلِهِ، وَالنَّارُ مِثْلُ ذَلِكَ ‏"‏‏.‏\hadithno{6488}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "Paradise is nearer to any of you than the Shirak (leather strap) of his shoe, and so is the (Hell) Fire}}
\hadithdefcmd{bukhari}{6489}{حَدَّثَنِي مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَبْدِ الْمَلِكِ بْنِ عُمَيْرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَصْدَقُ بَيْتٍ قَالَهُ الشَّاعِرُ أَلاَ كُلُّ شَىْءٍ مَا خَلاَ اللَّهَ بَاطِلُ ‏"‏‏.‏\hadithno{6489}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The truest poetic verse ever said by a poet, is: Indeed! Everything except Allah, is perishable}}
\hadithdefcmd{bukhari}{6490}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نَظَرَ أَحَدُكُمْ إِلَى مَنْ فُضِّلَ عَلَيْهِ فِي الْمَالِ وَالْخَلْقِ، فَلْيَنْظُرْ إِلَى مَنْ هُوَ أَسْفَلَ مِنْهُ ‏"‏‏.‏\hadithno{6490}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If anyone of you looked at a person who was made superior to him in property and (in good) appearance, then he should also look at the one who is inferior to him}}
\hadithdefcmd{bukhari}{6491}{حَدَّثَنَا أَبُو مَعْمَرٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، حَدَّثَنَا جَعْدٌ أَبُو عُثْمَانَ، حَدَّثَنَا أَبُو رَجَاءٍ الْعُطَارِدِيُّ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم فِيمَا يَرْوِي عَنْ رَبِّهِ عَزَّ وَجَلَّ قَالَ قَالَ ‏ "‏ إِنَّ اللَّهَ كَتَبَ الْحَسَنَاتِ وَالسَّيِّئَاتِ، ثُمَّ بَيَّنَ ذَلِكَ فَمَنْ هَمَّ بِحَسَنَةٍ فَلَمْ يَعْمَلْهَا كَتَبَهَا اللَّهُ لَهُ عِنْدَهُ حَسَنَةً كَامِلَةً، فَإِنْ هُوَ هَمَّ بِهَا فَعَمِلَهَا كَتَبَهَا اللَّهُ لَهُ عِنْدَهُ عَشْرَ حَسَنَاتٍ إِلَى سَبْعِمِائَةِ ضِعْفٍ إِلَى أَضْعَافٍ كَثِيرَةٍ، وَمَنْ هَمَّ بِسَيِّئَةٍ فَلَمْ يَعْمَلْهَا كَتَبَهَا اللَّهُ لَهُ عِنْدَهُ حَسَنَةً كَامِلَةً، فَإِنْ هُوَ هَمَّ بِهَا فَعَمِلَهَا كَتَبَهَا اللَّهُ لَهُ سَيِّئَةً وَاحِدَةً ‏"‏‏.‏\hadithno{6491}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) narrating about his Lord I'm and said, "Allah ordered (the appointed angels over you) that the good and the bad deeds be written, and He then showed (the way) how (to write). If somebody intends to do a good deed and he does not do it, then Allah will write for him a full good deed (in his account with Him); and if he intends to do a good deed and actually did it, then Allah will write for him (in his account) with Him (its reward equal) from ten to seven hundred times to many more times: and if somebody intended to do a bad deed and he does not do it, then Allah will write a full good deed (in his account) with Him, and if he intended to do it (a bad deed) and actually did it, then Allah will write one bad deed (in his account)}}
\hadithdefcmd{bukhari}{6492}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا مَهْدِيٌّ، عَنْ غَيْلاَنَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ إِنَّكُمْ لَتَعْمَلُونَ أَعْمَالاً هِيَ أَدَقُّ فِي أَعْيُنِكُمْ مِنَ الشَّعَرِ، إِنْ كُنَّا نَعُدُّهَا عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم الْمُوبِقَاتِ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ يَعْنِي بِذَلِكَ الْمُهْلِكَاتِ‏.‏\hadithno{6492}\hadithtrans{Narrated Ghailan:Anas said "You people do (bad) deeds (commit sins) which seem in your eyes as tiny (minute) than hair while we used to consider those (very deeds) during the life-time of the Prophet (ﷺ) as destructive sins}}
\hadithdefcmd{bukhari}{6493}{حَدَّثَنَا عَلِيُّ بْنُ عَيَّاشٍ، حَدَّثَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ نَظَرَ النَّبِيُّ صلى الله عليه وسلم إِلَى رَجُلٍ يُقَاتِلُ الْمُشْرِكِينَ، وَكَانَ مِنْ أَعْظَمِ الْمُسْلِمِينَ غَنَاءً عَنْهُمْ فَقَالَ ‏"‏ مَنْ أَحَبَّ أَنْ يَنْظُرَ إِلَى رَجُلٍ مِنْ أَهْلِ النَّارِ فَلْيَنْظُرْ إِلَى هَذَا ‏"‏‏.‏ فَتَبِعَهُ رَجُلٌ فَلَمْ يَزَلْ عَلَى ذَلِكَ حَتَّى جُرِحَ، فَاسْتَعْجَلَ الْمَوْتَ‏.‏ فَقَالَ بِذُبَابَةِ سَيْفِهِ، فَوَضَعَهُ بَيْنَ ثَدْيَيْهِ، فَتَحَامَلَ عَلَيْهِ، حَتَّى خَرَجَ مِنْ بَيْنِ كَتِفَيْهِ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ الْعَبْدَ لَيَعْمَلُ فِيمَا يَرَى النَّاسُ عَمَلَ أَهْلِ الْجَنَّةِ، وَإِنَّهُ لَمِنْ أَهْلِ النَّارِ، وَيَعْمَلُ فِيمَا يَرَى النَّاسُ عَمَلَ أَهْلِ النَّارِ وَهْوَ مِنْ أَهْلِ الْجَنَّةِ، وَإِنَّمَا الأَعْمَالُ بِخَوَاتِيمِهَا ‏"‏‏.‏\hadithno{6493}\hadithtrans{Narrated Sa`d bin Sahl As-Sa`idi:The Prophet (ﷺ) looked at a man fighting against the pagans and he was one of the most competent persons fighting on behalf of the Muslims. The Prophet (ﷺ) said, "Let him who wants to look at a man from the dwellers of the (Hell) Fire, look at this (man)." Another man followed him and kept on following him till he (the fighter) was injured and, seeking to die quickly, he placed the blade tip of his sword between his breasts and leaned over it till it passed through his shoulders (i.e., committed suicide)." The Prophet (ﷺ) added, "A person may do deeds that seem to the people as the deeds of the people of Paradise while in fact, he is from the dwellers of the (Hell) Fire: and similarly a person may do deeds that seem to the people as the deeds of the people of the (Hell) Fire while in fact, he is from the dwellers of Paradise. Verily, the (results of) deeds done, depend upon the last actions}}
\hadithdefcmd{bukhari}{6494}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي عَطَاءُ بْنُ يَزِيدَ، أَنَّ أَبَا سَعِيدٍ، حَدَّثَهُ قَالَ قِيلَ يَا رَسُولَ اللَّهِ‏.‏ وَقَالَ مُحَمَّدُ بْنُ يُوسُفَ حَدَّثَنَا الأَوْزَاعِيُّ حَدَّثَنَا الزُّهْرِيُّ عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ قَالَ جَاءَ أَعْرَابِيٌّ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَىُّ النَّاسِ خَيْرٌ قَالَ ‏ "‏ رَجُلٌ جَاهَدَ بِنَفْسِهِ وَمَالِهِ، وَرَجُلٌ فِي شِعْبٍ مِنَ الشِّعَابِ يَعْبُدُ رَبَّهُ، وَيَدَعُ النَّاسَ مِنْ شَرِّهِ ‏"‏‏.‏ تَابَعَهُ الزُّبَيْدِيُّ وَسُلَيْمَانُ بْنُ كَثِيرٍ وَالنُّعْمَانُ عَنِ الزُّهْرِيِّ‏.‏ وَقَالَ مَعْمَرٌ عَنِ الزُّهْرِيِّ عَنْ عَطَاءٍ أَوْ عُبَيْدِ اللَّهِ عَنْ أَبِي سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَقَالَ يُونُسُ وَابْنُ مُسَافِرٍ وَيَحْيَى بْنُ سَعِيدٍ عَنِ ابْنِ شِهَابٍ عَنْ عَطَاءٍ عَنْ بَعْضِ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6494}\hadithtrans{Narrated Abu Sa`id Al-Khudri:A bedouin came to the Prophet (ﷺ) and said, "O Allah's Messenger (ﷺ)! Who is the best of mankind!" The Prophet said, "A man who strives for Allah's Cause with his life and property, and also a man who lives (all alone) in a mountain path among the mountain paths to worship his Lord and save the people from his evil}}
\hadithdefcmd{bukhari}{6495}{حَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا الْمَاجِشُونُ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي صَعْصَعَةَ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ، أَنَّهُ سَمِعَهُ يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ يَأْتِي عَلَى النَّاسِ زَمَانٌ خَيْرُ مَالِ الرَّجُلِ الْمُسْلِمِ الْغَنَمُ، يَتْبَعُ بِهَا شَعَفَ الْجِبَالِ وَمَوَاقِعَ الْقَطْرِ، يَفِرُّ بِدِينِهِ مِنَ الْفِتَنِ ‏"‏‏.‏\hadithno{6495}\hadithtrans{Narrated Abu Sa`id:I heard from the Prophet (ﷺ) saying, "There will come a time upon the people when the best property of a Muslim will be sheep which he will take to the tops of mountains and to the places of rainfall, run away with his religion (in order to save it) from afflictions}}
\hadithdefcmd{bukhari}{6496}{حَدَّثَنَا مُحَمَّدُ بْنُ سِنَانٍ، حَدَّثَنَا فُلَيْحُ بْنُ سُلَيْمَانَ، حَدَّثَنَا هِلاَلُ بْنُ عَلِيٍّ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا ضُيِّعَتِ الأَمَانَةُ فَانْتَظِرِ السَّاعَةَ ‏"‏‏.‏ قَالَ كَيْفَ إِضَاعَتُهَا يَا رَسُولَ اللَّهِ قَالَ ‏"‏ إِذَا أُسْنِدَ الأَمْرُ إِلَى غَيْرِ أَهْلِهِ، فَانْتَظِرِ السَّاعَةَ ‏"‏‏.‏\hadithno{6496}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "When honesty is lost, then wait for the Hour." It was asked, "How will honesty be lost, O Allah's Messenger (ﷺ)?" He said, "When authority is given to those who do not deserve it, then wait for the Hour}}
\hadithdefcmd{bukhari}{6497}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنَا الأَعْمَشُ، عَنْ زَيْدِ بْنِ وَهْبٍ، حَدَّثَنَا حُذَيْفَةُ، قَالَ حَدَّثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم حَدِيثَيْنِ رَأَيْتُ أَحَدَهُمَا وَأَنَا أَنْتَظِرُ الآخَرَ، حَدَّثَنَا ‏"‏ أَنَّ الأَمَانَةَ نَزَلَتْ فِي جَذْرِ قُلُوبِ الرِّجَالِ، ثُمَّ عَلِمُوا مِنَ الْقُرْآنِ، ثُمَّ عَلِمُوا مِنَ السُّنَّةِ ‏"‏‏.‏ وَحَدَّثَنَا عَنْ رَفْعِهَا قَالَ ‏"‏ يَنَامُ الرَّجُلُ النَّوْمَةَ فَتُقْبَضُ الأَمَانَةُ مِنْ قَلْبِهِ، فَيَظَلُّ أَثَرُهَا مِثْلَ أَثَرِ الْوَكْتِ، ثُمَّ يَنَامُ النَّوْمَةَ فَتُقْبَضُ فَيَبْقَى أَثَرُهَا مِثْلَ الْمَجْلِ، كَجَمْرٍ دَحْرَجْتَهُ عَلَى رِجْلِكَ فَنَفِطَ، فَتَرَاهُ مُنْتَبِرًا، وَلَيْسَ فِيهِ شَىْءٌ، فَيُصْبِحُ النَّاسُ يَتَبَايَعُونَ فَلاَ يَكَادُ أَحَدٌ يُؤَدِّي الأَمَانَةَ، فَيُقَالُ إِنَّ فِي بَنِي فُلاَنٍ رَجُلاً أَمِينًا‏.‏ وَيُقَالُ لِلرَّجُلِ مَا أَعْقَلَهُ وَمَا أَظْرَفَهُ وَمَا أَجْلَدَهُ‏.‏ وَمَا فِي قَلْبِهِ مِثْقَالُ حَبَّةِ خَرْدَلٍ مِنْ إِيمَانٍ، وَلَقَدْ أَتَى عَلَىَّ زَمَانٌ وَمَا أُبَالِي أَيَّكُمْ بَايَعْتُ لَئِنْ كَانَ مُسْلِمًا رَدَّهُ الإِسْلاَمُ، وَإِنْ كَانَ نَصْرَانِيًّا رَدَّهُ عَلَىَّ سَاعِيهِ، فَأَمَّا الْيَوْمَ فَمَا كُنْتُ أُبَايِعُ إِلاَّ فُلاَنًا وَفُلاَنًا ‏"‏‏.‏ قَالَ الْفِرَبْرِيُّ قَالَ أَبُو جَعْفَرٍ حَدَّثْتُ أَبَا عَبْدِ اللَّهِ فَقَالَ سَمِعْتُ أَحْمَدَ بْنَ عَاصِمٍ يَقُولُ سَمِعْتُ أَبَا عُبَيْدٍ يَقُولُ قَالَ الأَصْمَعِيُّ وَأَبُو عَمْرٍو وَغَيْرُهُمَا جَذْرُ قُلُوبِ الرِّجَالِ الْجَذْرُ الأَصْلُ مِنْ كُلِّ شَىْءٍ، وَالْوَكْتُ أَثَرُ الشَّىْءِ الْيَسِيرُ مِنْهُ، وَالْمَجْلُ أَثَرُ الْعَمَلِ فِي الْكَفِّ إِذَا غَلُظَ‏.‏\hadithno{6497}\hadithtrans{Narrated Hudhaifa:Allah's Messenger (ﷺ) narrated to us two narrations, one of which I have seen (happening) and I am waiting for the other. He narrated that honesty was preserved in the roots of the hearts of men (in the beginning) and then they learnt it (honesty) from the Qur'an, and then they learnt it from the (Prophet's) Sunna (tradition). He also told us about its disappearance, saying, "A man will go to sleep whereupon honesty will be taken away from his heart, and only its trace will remain, resembling the traces of fire. He then will sleep whereupon the remainder of the honesty will also be taken away (from his heart) and its trace will resemble a blister which is raised over the surface of skin, when an ember touches one's foot; and in fact, this blister does not contain anything. So there will come a day when people will deal in business with each other but there will hardly be any trustworthy persons among them. Then it will be said that in such-and-such a tribe there is such-and-such person who is honest, and a man will be admired for his intelligence, good manners and strength, though indeed he will not have belief equal to a mustard seed in his heart." The narrator added: There came upon me a time when I did not mind dealing with anyone of you, for if he was a Muslim, his religion would prevent him from cheating; and if he was a Christian, his Muslim ruler would prevent him from cheating; but today I cannot deal except with so-and-so and so-and-so. (See Hadith No. 208, Vol)}}
\hadithdefcmd{bukhari}{6498}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ، أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّمَا النَّاسُ كَالإِبِلِ الْمِائَةُ لاَ تَكَادُ تَجِدُ فِيهَا رَاحِلَةً ‏"‏‏.‏\hadithno{6498}\hadithtrans{Narrated `Abdullah bin `Umar:I heard Allah's Messenger (ﷺ) saying, "People are just like camels, out of one hundred, one can hardly find a single camel suitable to ride}}
\hadithdefcmd{bukhari}{6499}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، حَدَّثَنِي سَلَمَةُ بْنُ كُهَيْلٍ،‏.‏ وَحَدَّثَنَا أَبُو نُعَيْمٍ، حَدَّثَنَا سُفْيَانُ، عَنْ سَلَمَةَ، قَالَ سَمِعْتُ جُنْدَبًا، يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم وَلَمْ أَسْمَعْ أَحَدًا يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم غَيْرَهُ فَدَنَوْتُ مِنْهُ فَسَمِعْتُهُ يَقُولُ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَنْ سَمَّعَ سَمَّعَ اللَّهُ بِهِ، وَمَنْ يُرَائِي يُرَائِي اللَّهُ بِهِ ‏"‏‏.‏\hadithno{6499}\hadithtrans{Narrated Jundub:The Prophet (ﷺ) said, "He who lets the people hear of his good deeds intentionally, to win their praise, Allah will let the people know his real intention (on the Day of Resurrection), and he who does good things in public to show off and win the praise of the people, Allah will disclose his real intention (and humiliate him)}}
\hadithdefcmd{bukhari}{6500}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، عَنْ مُعَاذِ بْنِ جَبَلٍ ـ رضى الله عنه ـ قَالَ بَيْنَمَا أَنَا رَدِيفُ النَّبِيِّ، صلى الله عليه وسلم لَيْسَ بَيْنِي وَبَيْنَهُ إِلاَّ آخِرَةُ الرَّحْلِ فَقَالَ ‏"‏ يَا مُعَاذُ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ يَا رَسُولَ اللَّهِ وَسَعْدَيْكَ، ثُمَّ سَارَ سَاعَةً ثُمَّ قَالَ ‏"‏ يَا مُعَاذُ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ رَسُولَ اللَّهِ وَسَعْدَيْكَ، ثُمَّ سَارَ سَاعَةً ثُمَّ قَالَ ‏"‏ يَا مُعَاذُ بْنَ جَبَلٍ ‏"‏‏.‏ قُلْتُ‏:‏ لَبَّيْكَ رَسُولَ اللَّهِ وَسَعْدَيْكَ‏.‏ قَالَ ‏"‏ هَلْ تَدْرِي مَا حَقُّ اللَّهِ عَلَى عِبَادِهِ ‏"‏‏.‏ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ حَقُّ اللَّهِ عَلَى عِبَادِهِ أَنْ يَعْبُدُوهُ، وَلاَ يُشْرِكُوا بِهِ شَيْئًا ‏"‏‏.‏ ثُمَّ سَارَ سَاعَةً ثُمَّ قَالَ ‏"‏ يَا مُعَاذُ بْنَ جَبَلٍ ‏"‏‏.‏ قُلْتُ لَبَّيْكَ رَسُولَ اللَّهِ وَسَعْدَيْكَ‏.‏ قَالَ ‏"‏ هَلْ تَدْرِي مَا حَقُّ الْعِبَادِ عَلَى اللَّهِ إِذَا فَعَلُوهُ ‏"‏‏.‏ قُلْتُ اللَّهُ وَرَسُولُهُ أَعْلَمُ‏.‏ قَالَ ‏"‏ حَقُّ الْعِبَادِ عَلَى اللَّهِ أَنْ لاَ يُعَذِّبَهُمْ ‏"‏‏.‏\hadithno{6500}\hadithtrans{Narrated Mu`adh bin Jabal:While I was riding behind the Prophet (ﷺ) as a companion rider and there was nothing between me and him except the back of the saddle, he said, "O Mu`adh!" I replied, "Labbaik O Allah's Messenger (ﷺ)! And Sa`daik!" He proceeded for a while and then said, "O Mu`adh!" I said, "Labbaik and Sa`daik, O Allah's Messenger (ﷺ)!" He then proceeded for another while and said, "O Mu`adh bin Jabal!" I replied, "Labbaik, O Allah's Messenger (ﷺ), and Sa`daik!" He said, "Do you know what is Allah's right on His slaves?" I replied, "Allah and His Apostle know better." He said, "Allah's right on his slaves is that they should worship Him and not worship anything besides Him." He then proceeded for a while, and again said, "O Mu`adh bin Jabal!" I replied. "Labbaik, O Allah's Messenger (ﷺ), and Sa`daik." He said, "Do you know what is (Allah's) slaves' (people's) right on Allah if they did that?" I replied, "Allah and His Apostle know better." He said, "The right of (Allah's) slaves on Allah is that He should not punish them (if they did that)}}
\hadithdefcmd{bukhari}{6501}{حَدَّثَنَا مَالِكُ بْنُ إِسْمَاعِيلَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسٍ ـ رضى الله عنه ـ كَانَ لِلنَّبِيِّ صلى الله عليه وسلم نَاقَةٌ‏.‏ قَالَ وَحَدَّثَنِي مُحَمَّدٌ أَخْبَرَنَا الْفَزَارِيُّ وَأَبُو خَالِدٍ الأَحْمَرُ عَنْ حُمَيْدٍ الطَّوِيلِ عَنْ أَنَسٍ قَالَ كَانَتْ نَاقَةٌ لِرَسُولِ اللَّهِ صلى الله عليه وسلم تُسَمَّى الْعَضْبَاءَ، وَكَانَتْ لاَ تُسْبَقُ، فَجَاءَ أَعْرَابِيٌّ عَلَى قَعُودٍ لَهُ فَسَبَقَهَا، فَاشْتَدَّ ذَلِكَ عَلَى الْمُسْلِمِينَ وَقَالُوا سُبِقَتِ الْعَضْبَاءُ، فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ حَقًّا عَلَى اللَّهِ أَنْ لاَ يَرْفَعَ شَيْئًا مِنَ الدُّنْيَا إِلاَّ وَضَعَهُ ‏"‏‏.‏\hadithno{6501}\hadithtrans{Narrated Anas:The Prophet (ﷺ) had a she-camel called Al-`Adba' and it was too fast to surpass in speed. There came a bedouin riding a camel of his, and that camel outstripped it (i.e. Al-Aqba'). That result was hard on the Muslims who said sorrowfully, "Al- Adba has been outstripped." Allah's Messenger (ﷺ) said, "It is due from Allah that nothing would be raised high in this world except that He lowers or puts it down}}
\hadithdefcmd{bukhari}{6502}{حَدَّثَنِي مُحَمَّدُ بْنُ عُثْمَانَ، حَدَّثَنَا خَالِدُ بْنُ مَخْلَدٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ بِلاَلٍ، حَدَّثَنِي شَرِيكُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي نَمِرٍ، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ قَالَ مَنْ عَادَى لِي وَلِيًّا فَقَدْ آذَنْتُهُ بِالْحَرْبِ، وَمَا تَقَرَّبَ إِلَىَّ عَبْدِي بِشَىْءٍ أَحَبَّ إِلَىَّ مِمَّا افْتَرَضْتُ عَلَيْهِ، وَمَا يَزَالُ عَبْدِي يَتَقَرَّبُ إِلَىَّ بِالنَّوَافِلِ حَتَّى أُحِبَّهُ، فَإِذَا أَحْبَبْتُهُ كُنْتُ سَمْعَهُ الَّذِي يَسْمَعُ بِهِ، وَبَصَرَهُ الَّذِي يُبْصِرُ بِهِ، وَيَدَهُ الَّتِي يَبْطُشُ بِهَا وَرِجْلَهُ الَّتِي يَمْشِي بِهَا، وَإِنْ سَأَلَنِي لأُعْطِيَنَّهُ، وَلَئِنِ اسْتَعَاذَنِي لأُعِيذَنَّهُ، وَمَا تَرَدَّدْتُ عَنْ شَىْءٍ أَنَا فَاعِلُهُ تَرَدُّدِي عَنْ نَفْسِ الْمُؤْمِنِ، يَكْرَهُ الْمَوْتَ وَأَنَا أَكْرَهُ مَسَاءَتَهُ ‏"‏‏.‏\hadithno{6502}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Allah said, 'I will declare war against him who shows hostility to a pious worshipper of Mine. And the most beloved things with which My slave comes nearer to Me, is what I have enjoined upon him; and My slave keeps on coming closer to Me through performing Nawafil (praying or doing extra deeds besides what is obligatory) till I love him, so I become his sense of hearing with which he hears, and his sense of sight with which he sees, and his hand with which he grips, and his leg with which he walks; and if he asks Me, I will give him, and if he asks My protection (Refuge), I will protect him; (i.e. give him My Refuge) and I do not hesitate to do anything as I hesitate to take the soul of the believer, for he hates death, and I hate to disappoint him}}
\hadithdefcmd{bukhari}{6503}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، حَدَّثَنَا أَبُو حَازِمٍ، عَنْ سَهْلٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ بُعِثْتُ أَنَا وَالسَّاعَةَ هَكَذَا ‏"‏‏.‏ وَيُشِيرُ بِإِصْبَعَيْهِ فَيَمُدُّ بِهِمَا‏.‏\hadithno{6503}\hadithtrans{Narrated Sahl:Allah's Messenger (ﷺ) said, "I have been sent and the Hour (is at hand) as these two," showing his two fingers and sticking (separating) them out}}
\hadithdefcmd{bukhari}{6504}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ ـ هُوَ الْجُعْفِيُّ ـ حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، وَأَبِي التَّيَّاحِ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بُعِثْتُ أَنَا وَالسَّاعَةَ كَهَاتَيْنِ ‏"‏‏.‏\hadithno{6504}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) said, "I have been sent and the Hour (is at hand) as these two (fingers)}}
\hadithdefcmd{bukhari}{6505}{حَدَّثَنِي يَحْيَى بْنُ يُوسُفَ، أَخْبَرَنَا أَبُو بَكْرٍ، عَنْ أَبِي حَصِينٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بُعِثْتُ أَنَا وَالسَّاعَةَ كَهَاتَيْنِ ‏"‏‏.‏ يَعْنِي إِصْبَعَيْنِ‏.‏ تَابَعَهُ إِسْرَائِيلُ عَنْ أَبِي حَصِينٍ‏.‏\hadithno{6505}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "I have been sent and the Hour (is at hand) as these two (fingers)}}
\hadithdefcmd{bukhari}{6506}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنْ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، رضى الله عنه أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَقُومُ السَّاعَةُ حَتَّى تَطْلُعَ الشَّمْسُ مِنْ مَغْرِبِهَا، فَإِذَا طَلَعَتْ فَرَآهَا النَّاسُ آمَنُوا أَجْمَعُونَ، فَذَلِكَ حِينَ لاَ يَنْفَعُ نَفْسًا إِيمَانُهَا، لَمْ تَكُنْ آمَنَتْ مِنْ قَبْلُ، أَوْ كَسَبَتْ فِي إِيمَانِهَا خَيْرًا، وَلَتَقُومَنَّ السَّاعَةُ وَقَدْ نَشَرَ الرَّجُلاَنِ ثَوْبَهُمَا بَيْنَهُمَا فَلاَ يَتَبَايَعَانِهِ وَلاَ يَطْوِيَانِهِ، وَلَتَقُومَنَّ السَّاعَةُ وَقَدِ انْصَرَفَ الرَّجُلُ بِلَبَنِ لِقْحَتِهِ فَلاَ يَطْعَمُهُ، وَلَتَقُومَنَّ السَّاعَةُ وَهْوَ يَلِيطُ حَوْضَهُ فَلاَ يَسْقِي فِيهِ، وَلَتَقُومَنَّ السَّاعَةُ وَقَدْ رَفَعَ أُكْلَتَهُ إِلَى فِيهِ فَلاَ يَطْعَمُهَا ‏"‏‏.‏\hadithno{6506}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The Hour will not be established till the sun rises from the west, and when it rises (from the west) and the people see it, then all of them will believe (in Allah). But that will be the time when 'No good it will do to a soul to believe then. If it believed not before.."' (6.158) The Hour will be established (so suddenly) that two persons spreading a garment between them will not be able to finish their bargain, nor will they be able to fold it up. The Hour will be established while a man is carrying the milk of his she-camel, but cannot drink it; and the Hour will be established when someone is not able to prepare the tank to water his livestock from it; and the Hour will be established when some of you has raised his food to his mouth but cannot eat it}}
\hadithdefcmd{bukhari}{6507}{حَدَّثَنَا حَجَّاجٌ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ، وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏‏.‏ قَالَتْ عَائِشَةُ أَوْ بَعْضُ أَزْوَاجِهِ إِنَّا لَنَكْرَهُ الْمَوْتَ‏.‏ قَالَ ‏"‏ لَيْسَ ذَاكَ، وَلَكِنَّ الْمُؤْمِنَ إِذَا حَضَرَهُ الْمَوْتُ بُشِّرَ بِرِضْوَانِ اللَّهِ وَكَرَامَتِهِ، فَلَيْسَ شَىْءٌ أَحَبَّ إِلَيْهِ مِمَّا أَمَامَهُ، فَأَحَبَّ لِقَاءَ اللَّهِ وَأَحَبَّ اللَّهُ لِقَاءَهُ، وَإِنَّ الْكَافِرَ إِذَا حُضِرَ بُشِّرَ بِعَذَابِ اللَّهِ وَعُقُوبَتِهِ، فَلَيْسَ شَىْءٌ أَكْرَهَ إِلَيْهِ مِمَّا أَمَامَهُ، كَرِهَ لِقَاءَ اللَّهِ وَكَرِهَ اللَّهُ لِقَاءَهُ ‏"‏‏.‏ اخْتَصَرَهُ أَبُو دَاوُدَ وَعَمْرٌو عَنْ شُعْبَةَ‏.‏ وَقَالَ سَعِيدٌ عَنْ قَتَادَةَ عَنْ زُرَارَةَ عَنْ سَعْدٍ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6507}\hadithtrans{Narrated 'Ubada bin As-Samit:The Prophet (ﷺ) said, "Who-ever loves to meet Allah, Allah (too) loves to meet him and who-ever hates to meet Allah, Allah (too) hates to meet him". `Aisha, or some of the wives of the Prophet (ﷺ) said, "But we dislike death." He said: It is not like this, but it is meant that when the time of the death of a believer approaches, he receives the good news of Allah's pleasure with him and His blessings upon him, and so at that time nothing is dearer to him than what is in front of him. He therefore loves the meeting with Allah, and Allah (too) loves the meeting with him. But when the time of the death of a disbeliever approaches, he receives the evil news of Allah's torment and His Requital, whereupon nothing is more hateful to him than what is before him. Therefore, he hates the meeting with Allah, and Allah too, hates the meeting with him}}
\hadithdefcmd{bukhari}{6508}{حَدَّثَنِي مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَحَبَّ لِقَاءَ اللَّهِ أَحَبَّ اللَّهُ لِقَاءَهُ، وَمَنْ كَرِهَ لِقَاءَ اللَّهِ كَرِهَ اللَّهُ لِقَاءَهُ ‏"‏‏.‏\hadithno{6508}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said: "Whoever loves to meet Allah, Allah loves to meet him; and whoever hates to meet Allah, Allah hates to meet him}}
\hadithdefcmd{bukhari}{6509}{حَدَّثَنِي يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، وَعُرْوَةُ بْنُ الزُّبَيْرِ، فِي رِجَالٍ مِنْ أَهْلِ الْعِلْمِ أَنَّ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقُولُ وَهْوَ صَحِيحٌ ‏"‏ إِنَّهُ لَمْ يُقْبَضْ نَبِيٌّ قَطُّ حَتَّى يَرَى مَقْعَدَهُ مِنَ الْجَنَّةِ ثُمَّ يُخَيَّرُ ‏"‏‏.‏ فَلَمَّا نَزَلَ بِهِ، وَرَأْسُهُ عَلَى فَخِذِي، غُشِيَ عَلَيْهِ سَاعَةً، ثُمَّ أَفَاقَ، فَأَشْخَصَ بَصَرَهُ إِلَى السَّقْفِ ثُمَّ قَالَ ‏"‏ اللَّهُمَّ الرَّفِيقَ الأَعْلَى ‏"‏‏.‏ قُلْتُ إِذًا لاَ يَخْتَارُنَا، وَعَرَفْتُ أَنَّهُ الْحَدِيثُ الَّذِي كَانَ يُحَدِّثُنَا بِهِ ـ قَالَتْ ـ فَكَانَتْ تِلْكَ آخِرَ كَلِمَةٍ تَكَلَّمَ بِهَا النَّبِيُّ صلى الله عليه وسلم قَوْلُهُ ‏"‏ اللَّهُمَّ الرَّفِيقَ الأَعْلَى ‏"‏‏.‏\hadithno{6509}\hadithtrans{Narrated `Aisha:(the wife of the Prophet) When Allah's Messenger (ﷺ) was in good health, he used to say, "No prophet's soul is ever captured unless he is shown his place in Paradise and given the option (to die or survive)." So when the death of the Prophet (ﷺ) approached and his head was on my thigh, he became unconscious for a while and then he came to his senses and fixed his eyes on the ceiling and said, "O Allah (with) the highest companions." (See Qur'an 4:69). I said' "Hence he is not going to choose us." And I came to know that it was the application of the narration which he (the Prophet) used to narrate to us. And that was the last statement of the Prophet (before his death) i.e., "O Allah! With the highest companions." (See Qur'an 4:)}}
\hadithdefcmd{bukhari}{6510}{حَدَّثَنِي مُحَمَّدُ بْنُ عُبَيْدِ بْنِ مَيْمُونٍ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، عَنْ عُمَرَ بْنِ سَعِيدٍ، قَالَ أَخْبَرَنِي ابْنُ أَبِي مُلَيْكَةَ، أَنَّ أَبَا عَمْرٍو، ذَكْوَانَ مَوْلَى عَائِشَةَ أَخْبَرَهُ أَنَّ عَائِشَةَ ـ رضى الله عنها ـ كَانَتْ تَقُولُ إِنَّ رَسُولَ اللَّهَ صلى الله عليه وسلم كَانَ بَيْنَ يَدَيْهِ رَكْوَةٌ ـ أَوْ عُلْبَةٌ فِيهَا مَاءٌ، يَشُكُّ عُمَرُ ـ فَجَعَلَ يُدْخِلُ يَدَيْهِ فِي الْمَاءِ، فَيَمْسَحُ بِهِمَا وَجْهَهُ وَيَقُولُ ‏"‏ لاَ إِلَهَ إِلاَّ اللَّهُ، إِنَّ لِلْمَوْتِ سَكَرَاتٍ ‏"‏‏.‏ ثُمَّ نَصَبَ يَدَهُ فَجَعَلَ يَقُولُ ‏"‏ فِي الرَّفِيقِ الأَعْلَى ‏"‏‏.‏ حَتَّى قُبِضَ وَمَالَتْ يَدُهُ‏.‏ قَالَ أَبُو عَبْد اللَّهِ الْعُلْبَةُ مِنْ الْخَشَبِ وَالرَّكْوَةُ مِنْ الْأَدَمِ\hadithno{6510}\hadithtrans{Narrated `Aisha:There was a leather or wood container full of water in front of Allah's Messenger (ﷺ) (at the time of his death). He would put his hand into the water and rub his face with it, saying, "None has the right to be worshipped but Allah! No doubt, death has its stupors." Then he raised his hand and started saying, "(O Allah!) with the highest companions." (See Qur'an 4:69) (and kept on saying it) till he expired and his hand dropped}}
\hadithdefcmd{bukhari}{6511}{حَدَّثَنِي صَدَقَةُ، أَخْبَرَنَا عَبْدَةُ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رِجَالٌ مِنَ الأَعْرَابِ جُفَاةً يَأْتُونَ النَّبِيَّ صلى الله عليه وسلم فَيَسْأَلُونَهُ مَتَى السَّاعَةُ، فَكَانَ يَنْظُرُ إِلَى أَصْغَرِهِمْ فَيَقُولُ ‏ "‏ إِنْ يَعِشْ هَذَا لاَ يُدْرِكْهُ الْهَرَمُ حَتَّى تَقُومَ عَلَيْكُمْ سَاعَتُكُمْ ‏"‏‏.‏ قَالَ هِشَامٌ يَعْنِي مَوْتَهُمْ‏.‏\hadithno{6511}\hadithtrans{Narrated `Aisha:Some rough bedouins used to visit the Prophet (ﷺ) and ask him, "When will the Hour be?" He would look at the youngest of all of them and say, "If this should live till he is very old, your Hour (the death of the people addressed) will take place." Hisham said that he meant (by the Hour), their death}}
\hadithdefcmd{bukhari}{6512}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَلْحَلَةَ، عَنْ مَعْبَدِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِي قَتَادَةَ بْنِ رِبْعِيٍّ الأَنْصَارِيِّ، أَنَّهُ كَانَ يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم مُرَّ عَلَيْهِ بِجِنَازَةٍ فَقَالَ ‏"‏ مُسْتَرِيحٌ، وَمُسْتَرَاحٌ مِنْهُ ‏"‏‏.‏ قَالُوا يَا رَسُولَ اللَّهِ مَا الْمُسْتَرِيحُ وَالْمُسْتَرَاحُ مِنْهُ قَالَ ‏"‏ الْعَبْدُ الْمُؤْمِنُ يَسْتَرِيحُ مِنْ نَصَبِ الدُّنْيَا وَأَذَاهَا إِلَى رَحْمَةِ اللَّهِ، وَالْعَبْدُ الْفَاجِرُ يَسْتَرِيحُ مِنْهُ الْعِبَادُ وَالْبِلاَدُ وَالشَّجَرُ وَالدَّوَابُّ ‏"‏‏.‏\hadithno{6512}\hadithtrans{Narrated Abu Qatada bin Rib'i Al-Ansari:A funeral procession passed by Allah's Messenger (ﷺ) who said, "Relieved or relieving?" The people asked, "O Allah's Messenger (ﷺ)! What is relieved and relieving?" He said, "A believer is relieved (by death) from the troubles and hardships of the world and leaves for the Mercy of Allah, while (the death of) a wicked person relieves the people, the land, the trees, (and) the animals from him}}
\hadithdefcmd{bukhari}{6513}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عَبْدِ رَبِّهِ بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَلْحَلَةَ، حَدَّثَنِي ابْنُ كَعْبٍ، عَنْ أَبِي قَتَادَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مُسْتَرِيحٌ، وَمُسْتَرَاحٌ مِنْهُ، الْمُؤْمِنُ يَسْتَرِيحُ ‏"‏‏.‏\hadithno{6513}\hadithtrans{Narrated Abu Qatada:The Prophet (ﷺ) said, "Relieved or relieving. And a believer is relieved (by death)}}
\hadithdefcmd{bukhari}{6514}{حَدَّثَنَا الْحُمَيْدِيُّ، حَدَّثَنَا سُفْيَانُ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي بَكْرِ بْنِ عَمْرِو بْنِ حَزْمٍ، سَمِعَ أَنَسَ بْنَ مَالِكٍ، يَقُولُ قَالَ رَسُولُ اللَّهُ صلى الله عليه وسلم ‏ "‏ يَتْبَعُ الْمَيِّتَ ثَلاَثَةٌ، فَيَرْجِعُ اثْنَانِ وَيَبْقَى مَعَهُ وَاحِدٌ، يَتْبَعُهُ أَهْلُهُ وَمَالُهُ وَعَمَلُهُ، فَيَرْجِعُ أَهْلُهُ وَمَالُهُ، وَيَبْقَى عَمَلُهُ ‏"‏‏.‏\hadithno{6514}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "When carried to his grave, a dead person is followed by three, two of which return (after his burial) and one remains with him: his relative, his property, and his deeds follow him; relatives and his property go back while his deeds remain with him}}
\hadithdefcmd{bukhari}{6515}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا مَاتَ أَحَدُكُمْ عُرِضَ عَلَيْهِ مَقْعَدُهُ غُدْوَةً وَعَشِيًّا، إِمَّا النَّارُ وَإِمَّا الْجَنَّةُ، فَيُقَالُ هَذَا مَقْعَدُكَ حَتَّى تُبْعَثَ ‏إِلَيْهِ"‏‏.‏\hadithno{6515}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "When anyone of you dies, his destination is displayed before him in the forenoon and in the afternoon, either in the (Hell) Fire or in Paradise, and it is said to him, "That is your place till you are resurrected and sent to it}}
\hadithdefcmd{bukhari}{6516}{حَدَّثَنَا عَلِيُّ بْنُ الْجَعْدِ، أَخْبَرَنَا شُعْبَةُ، عَنِ الأَعْمَشِ، عَنْ مُجَاهِدٍ، عَنْ عَائِشَةَ، قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ تَسُبُّوا الأَمْوَاتَ، فَإِنَّهُمْ قَدْ أَفْضَوْا إِلَى مَا قَدَّمُوا ‏"‏‏.‏\hadithno{6516}\hadithtrans{Narrated `Aisha:The Prophet (ﷺ) said, "Do not abuse the dead, for they have reached the result of what they have done}}
\hadithdefcmd{bukhari}{6517}{حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، وَالأَعْرَجِ، أَنَّهُمَا حَدَّثَاهُ أَنَّ أَبَا هُرَيْرَةَ قَالَ اسْتَبَّ رَجُلاَنِ، رَجُلٌ مِنَ الْمُسْلِمِينَ وَرَجُلٌ مِنَ الْيَهُودِ فَقَالَ الْمُسْلِمُ وَالَّذِي اصْطَفَى مُحَمَّدًا عَلَى الْعَالَمِينَ‏.‏ فَقَالَ الْيَهُودِيُّ وَالَّذِي اصْطَفَى مُوسَى عَلَى الْعَالَمِينَ، قَالَ فَغَضِبَ الْمُسْلِمُ عِنْدَ ذَلِكَ، فَلَطَمَ وَجْهَ الْيَهُودِيِّ، فَذَهَبَ الْيَهُودِيُّ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَأَخْبَرَهُ بِمَا كَانَ مِنْ أَمْرِهِ وَأَمْرِ الْمُسْلِمِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُخَيِّرُونِي عَلَى مُوسَى، فَإِنَّ النَّاسَ يَصْعَقُونَ يَوْمَ الْقِيَامَةِ، فَأَكُونُ فِي أَوَّلِ مَنْ يُفِيقُ، فَإِذَا مُوسَى بَاطِشٌ بِجَانِبِ الْعَرْشِ، فَلاَ أَدْرِي أَكَانَ مُوسَى فِيمَنْ صَعِقَ فَأَفَاقَ قَبْلِي، أَوْ كَانَ مِمَّنِ اسْتَثْنَى اللَّهُ ‏"‏‏.‏\hadithno{6517}\hadithtrans{Narrated Abu Huraira:Two men, a Muslim and a Jew, abused each other. The Muslim said, "By Him Who gave superiority to Muhammad over all the people." On that, the Jew said, "By Him Who gave superiority to Moses over all the people." The Muslim became furious at that and slapped the Jew in the face. The Jew went to Allah's Messenger (ﷺ) and informed him of what had happened between him and the Muslim. Allah's Apostle said, "Don't give me superiority over Moses, for the people will fall unconscious on the Day of Resurrection and I will be the first to gain consciousness, and behold ! Moses will be there holding the side of Allah's Throne. I will not know whether Moses has been among those people who have become unconscious and then has regained consciousness before me, or has been among those exempted by Allah from falling unconscious}}
\hadithdefcmd{bukhari}{6518}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يَصْعَقُ النَّاسُ حِينَ يَصْعَقُونَ، فَأَكُونُ أَوَّلَ مَنْ قَامَ، فَإِذَا مُوسَى آخِذٌ بِالْعَرْشِ، فَمَا أَدْرِي أَكَانَ فِيمَنْ صَعِقَ ‏"‏‏.‏ رَوَاهُ أَبُو سَعِيدٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6518}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The people will fall down unconscious at the time when they should fall down (i.e., on the Day of Resurrection), and then I will be the first man to get up, and behold, Moses will be there holding (Allah's) Throne. I will not know whether he has been amongst those who have fallen unconscious}}
\hadithdefcmd{bukhari}{6519}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَقْبِضُ اللَّهُ الأَرْضَ، وَيَطْوِي السَّمَاءَ بِيَمِينِهِ، ثُمَّ يَقُولُ أَنَا الْمَلِكُ أَيْنَ مُلُوكُ الأَرْضِ ‏"‏‏.‏\hadithno{6519}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "Allah will take the whole earth (in His Hand) and will roll up the Heaven in His right Hand, and then He will say, "I am King! Where are the kings of the earth ?}}
\hadithdefcmd{bukhari}{6520}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، حَدَّثَنَا اللَّيْثُ، عَنْ خَالِدٍ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ تَكُونُ الأَرْضُ يَوْمَ الْقِيَامَةِ خُبْزَةً وَاحِدَةً، يَتَكَفَّؤُهَا الْجَبَّارُ بِيَدِهِ، كَمَا يَكْفَأُ أَحَدُكُمْ خُبْزَتَهُ فِي السَّفَرِ، نُزُلاً لأَهْلِ الْجَنَّةِ ‏"‏‏.‏ فَأَتَى رَجُلٌ مِنَ الْيَهُودِ فَقَالَ بَارَكَ الرَّحْمَنُ عَلَيْكَ يَا أَبَا الْقَاسِمِ، أَلاَ أُخْبِرُكَ بِنُزُلِ أَهْلِ الْجَنَّةِ يَوْمَ الْقِيَامَةِ قَالَ ‏"‏ بَلَى ‏"‏‏.‏ قَالَ تَكُونُ الأَرْضُ خُبْزَةً وَاحِدَةً كَمَا قَالَ النَّبِيُّ صلى الله عليه وسلم فَنَظَرَ النَّبِيُّ صلى الله عليه وسلم إِلَيْنَا، ثُمَّ ضَحِكَ حَتَّى بَدَتْ نَوَاجِذُهُ ثُمَّ قَالَ أَلاَ أُخْبِرُكَ بِإِدَامِهِمْ قَالَ إِدَامُهُمْ بَالاَمٌ وَنُونٌ‏.‏ قَالُوا وَمَا هَذَا قَالَ ثَوْرٌ وَنُونٌ يَأْكُلُ مِنْ زَائِدَةِ كَبِدِهِمَا سَبْعُونَ أَلْفًا‏.‏\hadithno{6520}\hadithtrans{Narrated Abu Sa`id Al-Khudri:The Prophet (ﷺ) said, "The (planet of) earth will be a bread on the Day of Resurrection, and The resistible (Allah) will topple turn it with His Hand like anyone of you topple turns a bread with his hands while (preparing the bread) for a journey, and that bread will be the entertainment for the people of Paradise." A man from the Jews came (to the Prophet) and said, "May The Beneficent (Allah) bless you, O Abul Qasim! Shall I tell you of the entertainment of the people of Paradise on the Day of Resurrection?" The Prophet (ﷺ) said, "Yes." The Jew said, "The earth will be a bread," as the Prophet (ﷺ) had said. Thereupon the Prophet (ﷺ) looked at us and smiled till his premolar tooth became visible. Then the Jew further said, "Shall I tell you of the udm (additional food taken with bread) they will have with the bread?" He added, "That will be Balam and Nun." The people asked, "What is that?" He said, "It is an ox and a fish, and seventy thousand people will eat of the caudate lobe (i.e. extra lobe) of their livers}}
\hadithdefcmd{bukhari}{6521}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، أَخْبَرَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، قَالَ سَمِعْتُ سَهْلَ بْنَ سَعْدٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ يُحْشَرُ النَّاسُ يَوْمَ الْقِيَامَةِ عَلَى أَرْضٍ بَيْضَاءَ عَفْرَاءَ كَقُرْصَةِ نَقِيٍّ ‏"‏‏.‏ قَالَ سَهْلٌ أَوْ غَيْرُهُ لَيْسَ فِيهَا مَعْلَمٌ لأَحَدٍ‏.‏\hadithno{6521}\hadithtrans{Narrated Sahl bin Sa`d:I heard the Prophet (ﷺ) saying, "The people will be gathered on the Day of Resurrection on reddish white land like a pure loaf of bread (made of pure fine flour)." Sahl added: That land will have no landmarks for anybody (to make use of)}}
\hadithdefcmd{bukhari}{6522}{حَدَّثَنَا مُعَلَّى بْنُ أَسَدٍ، حَدَّثَنَا وُهَيْبٌ، عَنِ ابْنِ طَاوُسٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يُحْشَرُ النَّاسُ عَلَى ثَلاَثِ طَرَائِقَ، رَاغِبِينَ رَاهِبِينَ وَاثْنَانِ عَلَى بَعِيرٍ، وَثَلاَثَةٌ عَلَى بَعِيرٍ، وَأَرْبَعَةٌ عَلَى بَ��ِيرٍ، وَعَشَرَةٌ عَلَى بَعِيرٍ وَيَحْشُرُ بَقِيَّتَهُمُ النَّارُ، تَقِيلُ مَعَهُمْ حَيْثُ قَالُوا، وَتَبِيتُ مَعَهُمْ حَيْثُ بَاتُوا، وَتُصْبِحُ مَعَهُمْ حَيْثُ أَصْبَحُوا، وَتُمْسِي مَعَهُمْ حَيْثُ أَمْسَوْا ‏"‏‏.‏\hadithno{6522}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The people will be gathered in three ways: (The first way will be of) those who will wish or have a hope (for Paradise) and will have a fear (of punishment), (The second batch will be those who will gather) riding two on a camel or three on a camel or ten on a camel. (The third batch) the rest of the people will be urged to gather by the Fire which will accompany them at the time of their afternoon nap and stay with them where they will spend the night, and will be with them in the morning wherever they may be then, and will be with them in the afternoon wherever they may be then}}
\hadithdefcmd{bukhari}{6523}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ الْبَغْدَادِيُّ، حَدَّثَنَا شَيْبَانُ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه أَنَّ رَجُلاً، قَالَ يَا نَبِيَّ اللَّهِ كَيْفَ يُحْشَرُ الْكَافِرُ عَلَى وَجْهِهِ قَالَ ‏ "‏ أَلَيْسَ الَّذِي أَمْشَاهُ عَلَى الرِّجْلَيْنِ فِي الدُّنْيَا قَادِرًا عَلَى أَنَّ يُمْشِيَهُ عَلَى وَجْهِهِ يَوْمَ الْقِيَامَةِ ‏"‏‏.‏ قَالَ قَتَادَةُ بَلَى وَعِزَّةِ رَبِّنَا‏.‏\hadithno{6523}\hadithtrans{Narrated Anas bin Malik:A man said, "O Allah's Prophet! Will a Kafir (disbeliever) be gathered (driven prone) on his face?" The Prophet (ﷺ) said, "Is not He Who made him walk with his legs in this world, able to make him walk on his face on the Day of Resurrection?" (Qatada, a sub-narrator said: Yes, (He can), by the Power of Our Lord}}
\hadithdefcmd{bukhari}{6524}{حَدَّثَنَا عَلِيٌّ، حَدَّثَنَا سُفْيَانُ، قَالَ عَمْرٌو سَمِعْتُ سَعِيدَ بْنَ جُبَيْرٍ، سَمِعْتُ ابْنَ عَبَّاسٍ، سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّكُمْ مُلاَقُو اللَّهِ حُفَاةً عُرَاةً مُشَاةً غُرْلاً ‏"‏‏.‏ قَالَ سُفْيَانُ هَذَا مِمَّا نَعُدُّ أَنَّ ابْنَ عَبَّاسٍ سَمِعَهُ مِنَ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6524}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "You will meet Allah barefooted, naked, walking on feet, and uncircumcised}}
\hadithdefcmd{bukhari}{6525}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا سُفْيَانُ، عَنْ عَمْرٍو، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنهما ـ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَخْطُبُ عَلَى الْمِنْبَرِ يَقُولُ ‏ "‏ إِنَّكُمْ مُلاَقُو اللَّهِ حُفَاةً عُرَاةً غُرْلاً ‏"‏‏.‏\hadithno{6525}\hadithtrans{Narrated Ibn `Abbas:I heard Allah's Messenger (ﷺ) while he was delivering a sermon on a pulpit, saying, "You will meet Allah barefooted, naked, and uncircumcised}}
\hadithdefcmd{bukhari}{6526}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنِ الْمُغِيرَةِ بْنِ النُّعْمَانِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَامَ فِينَا النَّبِيُّ صلى الله عليه وسلم يَخْطُبُ فَقَالَ ‏"‏ إِنَّكُمْ مَحْشُورُونَ حُفَاةً عُرَاةً ‏\{‏كَمَا بَدَأْنَا أَوَّلَ خَلْقٍ نُعِيدُهُ‏\}‏ الآيَةَ، وَإِنَّ أَوَّلَ الْخَلاَئِقِ يُكْسَى يَوْمَ الْقِيَامَةِ إِبْرَاهِيمُ، وَإِنَّهُ سَيُجَاءُ بِرِجَالٍ مِنْ أُمَّتِي، فَيُؤْخَذُ بِهِمْ ذَاتَ الشِّمَالِ‏.‏ فَأَقُولُ يَا رَبِّ أُصَيْحَابِي‏.‏ فَيَقُولُ إِنَّكَ لاَ تَدْرِي مَا أَحْدَثُوا بَعْدَكَ‏.‏ فَأَقُولُ كَمَا قَالَ الْعَبْدُ الصَّالِحُ ‏\{‏وَكُنْتُ عَلَيْهِمْ شَهِيدًا مَا دُمْتُ فِيهِمْ‏\}‏ إِلَى قَوْلِهِ ‏\{‏الْحَكِيمُ‏\}‏ قَالَ فَيُقَالُ إِنَّهُمْ لَمْ يَزَالُوا مُرْتَدِّينَ عَلَى أَعْقَابِهِمْ ‏"‏‏.‏\hadithno{6526}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) stood up among us and addressed (saying) "You will be gathered, barefooted, naked, and uncircumcised (as Allah says): 'As We began the first creation, We shall repeat it..' (21.104) And the first human being to be dressed on the Day of Resurrection will be (the Prophet) Abraham Al-Khalil. Then will be brought some men of my followers who will be taken towards the left (i.e., to the Fire), and I will say: 'O Lord! My companions whereupon Allah will say: You do not know what they did after you left them. I will then say as the pious slave, Jesus said, And I was witness over them while I dwelt amongst them..........(up to) ...the All-Wise.' (5.117-118). The narrator added: Then it will be said that those people (relegated from Islam, that is) kept on turning on their heels (deserted Islam)}}
\hadithdefcmd{bukhari}{6527}{حَدَّثَنَا قَيْسُ بْنُ حَفْصٍ، حَدَّثَنَا خَالِدُ بْنُ الْحَارِثِ، حَدَّثَنَا حَاتِمُ بْنُ أَبِي صَغِيرَةَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ، قَالَ حَدَّثَنِي الْقَاسِمُ بْنُ مُحَمَّدِ بْنِ أَبِي بَكْرٍ، أَنَّ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ تُحْشَرُونَ حُفَاةً عُرَاةً غُرْلاً ‏"‏ قَالَتْ عَائِشَةُ فَقُلْتُ يَا رَسُولَ اللَّهِ الرِّجَالُ وَالنِّسَاءُ يَنْظُرُ بَعْضُهُمْ إِلَى بَعْضٍ‏.‏ فَقَالَ ‏"‏ الأَمْرُ أَشَدُّ مِنْ أَنْ يُهِمَّهُمْ ذَاكِ ‏"‏‏.‏\hadithno{6527}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) said, "The people will be gathered barefooted, naked, and uncircumcised." I said, "O Allah's Messenger (ﷺ)! Will the men and the women look at each other?" He said, "The situation will be too hard for them to pay attention to that}}
\hadithdefcmd{bukhari}{6528}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَمْرِو بْنِ مَيْمُونٍ، عَنْ عَبْدِ اللَّهِ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي قُبَّةٍ فَقَالَ ‏"‏ أَتَرْضَوْنَ أَنْ تَكُونُوا رُبُعَ أَهْلِ الْجَنَّةِ ‏"‏‏.‏ قُلْنَا نَعَمْ‏.‏ قَالَ ‏"‏ تَرْضَوْنَ أَنْ تَكُونُوا ثُلُثَ أَهْلِ الْجَنَّةِ ‏"‏‏.‏ قُلْنَا نَعَمْ‏.‏ قَالَ ‏"‏ أَتَرْضَوْنَ أَنْ تَكُونُوا شَطْرَ أَهْلِ الْجَنَّةِ ‏"‏‏.‏ قُلْنَا نَعَمْ‏.‏ قَالَ ‏"‏ وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ إِنِّي لأَرْجُو أَنْ تَكُونُوا نِصْفَ أَهْلِ الْجَنَّةِ، وَذَلِكَ أَنَّ الْجَنَّةَ لاَ يَدْخُلُهَا إِلاَّ نَفْسٌ مُسْلِمَةٌ، وَمَا أَنْتُمْ فِي أَهْلِ الشِّرْكِ إِلاَّ كَالشَّعْرَةِ الْبَيْضَاءِ فِي جِلْدِ الثَّوْرِ الأَسْوَدِ أَوْ كَالشَّعْرَةِ السَّوْدَاءِ فِي جِلْدِ الثَّوْرِ الأَحْمَرِ ‏"‏‏.‏\hadithno{6528}\hadithtrans{Narrated `Abdullah:While we were in the company of the Prophet (ﷺ) in a tent he said, ''Would it please you to be one fourth of the people of Paradise?" We said, "Yes." He said, "Would It please you to be one-third of the people of Paradise?" We said, "Yes." He said, "Would it please you to be half of the people of Paradise?" We said, "Yes." Thereupon he said, "I hope that you will be one half of the people of Paradise, for none will enter Paradise but a Muslim soul, and you people, in comparison to the people who associate others in worship with Allah, are like a white hair on the skin of a black ox, or a black hair on the skin of a red ox}}
\hadithdefcmd{bukhari}{6529}{حَدَّثَنَا إِسْمَاعِيلُ، حَدَّثَنِي أَخِي، عَنْ سُلَيْمَانَ، عَنْ ثَوْرٍ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ أَوَّلُ مَنْ يُدْعَى يَوْمَ الْقِيَامَةِ آدَمُ، فَتَرَاءَى ذُرِّيَّتُهُ فَيُقَالُ هَذَا أَبُوكُمْ آدَمُ‏.‏ فَيَقُولُ لَبَّيْكَ وَسَعْدَيْكَ‏.‏ فَيَقُولُ أَخْرِجْ بَعْثَ جَهَنَّمَ مِنْ ذُرِّيَّتِكَ‏.‏ فَيَقُولُ يَا رَبِّ كَمْ أُخْرِجُ فَيَقُولُ أَخْرِجْ مِنْ كُلِّ مِائَةٍ تِسْعَةً وَتِسْعِينَ ‏"‏‏.‏ فَقَالُوا يَا رَسُولَ اللَّهِ إِذَا أُخِذَ مِنَّا مِنْ كُلِّ مِائَةٍ تِسْعَةٌ وَتِسْعُونَ، فَمَاذَا يَبْقَى مِنَّا قَالَ ‏"‏ إِنَّ أُمَّتِي فِي الأُمَمِ كَالشَّعَرَةِ الْبَيْضَاءِ فِي الثَّوْرِ الأَسْوَدِ ‏"‏‏.‏\hadithno{6529}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "The first man to be called on the Day of Resurrection will be Adam who will be shown his offspring, and it will be said to them, 'This is your father, Adam.' Adam will say (responding to the call), 'Labbaik and Sa`daik' Then Allah will say (to Adam), 'Take out of your offspring, the people of Hell.' Adam will say, 'O Lord, how many should I take out?' Allah will say, 'Take out ninety-nine out of every hundred." They (the Prophet's companions) said, "O Allah's Apostle! If ninety-nine out of every one hundred of us are taken away, what will remain out of us?" He said, "My followers in comparison to the other nations are like a white hair on a black ox}}
\hadithdefcmd{bukhari}{6530}{حَدَّثَنِي يُوسُفُ بْنُ مُوسَى، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَقُولُ اللَّهُ يَا آدَمُ‏.‏ فَيَقُولُ لَبَّيْكَ وَسَعْدَيْكَ وَالْخَيْرُ فِي يَدَيْكَ‏.‏ قَالَ يَقُولُ أَخْرِجْ بَعْثَ النَّارِ‏.‏ قَالَ وَمَا بَعْثُ النَّارِ قَالَ مِنْ كُلِّ أَلْفٍ تِسْعَمِائَةٍ وَتِسْعَةً وَتِسْعِينَ‏.‏ فَذَاكَ حِينَ يَشِيبُ الصَّغِيرُ، وَتَضَعُ كُلُّ ذَاتِ حَمْلٍ حَمْلَهَا، وَتَرَى النَّاسَ سَكْرَى وَمَا هُمْ بِسَكْرَى وَلَكِنَّ عَذَابَ اللَّهِ شَدِيدٌ ‏"‏‏.‏ فَاشْتَدَّ ذَلِكَ عَلَيْهِمْ فَقَالُوا يَا رَسُولُ اللَّهِ أَيُّنَا الرَّجُلُ قَالَ ‏"‏ أَبْشِرُوا، فَإِنَّ مِنْ يَأْجُوجَ وَمَأْجُوجَ أَلْفٌ وَمِنْكُمْ رَجُلٌ ـ ثُمَّ قَالَ ـ وَالَّذِي نَفْسِي فِي يَدِهِ إِنِّي لأَطْمَعُ أَنْ تَكُونُوا ثُلُثَ أَهْلِ الْجَنَّةِ ‏"‏‏.‏ قَالَ فَحَمِدْنَا اللَّهَ وَكَبَّرْنَا، ثُمَّ قَالَ ‏"‏ وَالَّذِي نَفْسِي فِي يَدِهِ إِنِّي لأَطْمَعُ أَنْ تَكُونُوا شَطْرَ أَهْلِ الْجَنَّةِ، إِنَّ مَثَلَكُمْ فِي الأُمَمِ كَمَثَلِ الشَّعَرَةِ الْبَيْضَاءِ فِي جِلْدِ الثَّوْرِ الأَسْوَدِ أَوِ الرَّقْمَةِ فِي ذِرَاعِ الْحِمَارِ ‏"‏‏.‏\hadithno{6530}\hadithtrans{Narrated Abu Sa`id:The Prophet (ﷺ) said, "Allah will say, 'O Adam!. Adam will reply, 'Labbaik and Sa`daik (I respond to Your Calls, I am obedient to Your orders), wal Khair fi Yadaik (and all the good is in Your Hands)!' Then Allah will say (to Adam), Bring out the people of the Fire.' Adam will say, 'What (how many) are the people of the Fire?' Allah will say, 'Out of every thousand (take out) nine hundred and ninety-nine (persons).' At that time children will become hoary-headed and every pregnant female will drop her load (have an abortion) and you will see the people as if they were drunk, yet not drunk; But Allah's punishment will be very severe." That news distressed the companions of the Prophet (ﷺ) too much, and they said, "O Allah's Messenger (ﷺ)! Who amongst us will be that man (the lucky one out of one-thousand who will be saved from the Fire)?" He said, "Have the good news that one-thousand will be from Gog and Magog, and the one (to be saved will be) from you." The Prophet (ﷺ) added, "By Him in Whose Hand my soul is, I Hope that you (Muslims) will be one third of the people of Paradise." On that, we glorified and praised Allah and said, "Allahu Akbar." The Prophet (ﷺ) then said, "By Him in Whose Hand my soul is, I hope that you will be one half of the people of Paradise, as your (Muslims) example in comparison to the other people (non-Muslims), is like that of a white hair on the skin of a black ox, or a round hairless spot on the foreleg of a donkey}}
\hadithdefcmd{bukhari}{6531}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبَانَ، حَدَّثَنَا عِيسَى بْنُ يُونُسَ، حَدَّثَنَا ابْنُ عَوْنٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ ‏\{‏يَوْمَ يَقُومُ النَّاسُ لِرَبِّ الْعَالَمِينَ‏\}‏ قَالَ ‏"‏ يَقُومُ أَحَدُهُمْ فِي رَشْحِهِ إِلَى أَنْصَافِ أُذُنَيْهِ ‏"‏‏.‏\hadithno{6531}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said (regarding the Verse), "A Day when all mankind will stand before the Lord of the Worlds,' (that day) they will stand, drowned in their sweat up to the middle of their ears}}
\hadithdefcmd{bukhari}{6532}{حَدَّثَنِي عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي سُلَيْمَانُ، عَنْ ثَوْرِ بْنِ زَيْدٍ، عَنْ أَبِي الْغَيْثِ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَعْرَقُ النَّاسُ يَوْمَ الْقِيَامَةِ حَتَّى يَذْهَبَ عَرَقُهُمْ فِي الأَرْضِ سَبْعِينَ ذِرَاعًا، وَيُلْجِمُهُمْ حَتَّى يَبْلُغَ آذَانَهُمْ ‏"‏‏.‏\hadithno{6532}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "The people will sweat so profusely on the Day of Resurrection that their sweat will sink seventy cubits deep into the earth, and it will rise up till it reaches the people's mouths and ears}}
\hadithdefcmd{bukhari}{6533}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنِي شَقِيقٌ، سَمِعْتُ عَبْدَ اللَّهِ ـ رضى الله عنه ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَوَّلُ مَا يُقْضَى بَيْنَ النَّاسِ بِالدِّمَاءِ ‏"‏‏.‏\hadithno{6533}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "The cases which will be decided first (on the Day of Resurrection) will be the cases of blood-shedding}}
\hadithdefcmd{bukhari}{6534}{حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنِي مَالِكٌ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَتْ عِنْدَهُ مَظْلَمَةٌ لأَخِيهِ فَلْيَتَحَلَّلْهُ مِنْهَا، فَإِنَّهُ لَيْسَ ثَمَّ دِينَارٌ وَلاَ دِرْهَمٌ مِنْ قَبْلِ أَنْ يُؤْخَذَ لأَخِيهِ مِنْ حَسَنَاتِهِ، فَإِنْ لَمْ يَكُنْ لَهُ حَسَنَاتٌ أُخِذَ مِنْ سَيِّئَاتِ أَخِيهِ، فَطُرِحَتْ عَلَيْهِ ‏"‏‏.‏\hadithno{6534}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Whoever has wronged his brother, should ask for his pardon (before his death), as (in the Hereafter) there will be neither a Dinar nor a Dirham. (He should secure pardon in this life) before some of his good deeds are taken and paid to his brother, or, if he has done no good deeds, some of the bad deeds of his brother are taken to be loaded on him (in the Hereafter)}}
\hadithdefcmd{bukhari}{6535}{حَدَّثَنِي الصَّلْتُ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، ‏\{‏وَنَزَعْنَا مَا فِي صُدُورِهِمْ مِنْ غِلٍّ‏\}‏ قَالَ حَدَّثَنَا سَعِيدٌ عَنْ قَتَادَةَ عَنْ أَبِي الْمُتَوَكِّلِ النَّاجِيِّ أَنَّ أَبَا سَعِيدٍ الْخُدْرِيَّ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَخْلُصُ الْمُؤْمِنُونَ مِنَ النَّارِ، فَيُحْبَسُونَ عَلَى قَنْطَرَةٍ بَيْنَ الْجَنَّةِ وَالنَّارِ، فَيُقَصُّ لِبَعْضِهِمْ مِنْ بَعْضٍ، مَظَالِمُ كَانَتْ بَيْنَهُمْ فِي الدُّنْيَا، حَتَّى إِذَا هُذِّبُوا وَنُقُّوا أُذِنَ لَهُمْ فِي دُخُولِ الْجَنَّةِ، فَوَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لأَحَدُهُمْ أَهْدَى بِمَنْزِلِهِ فِي الْجَنَّةِ مِنْهُ بِمَنْزِلِهِ كَانَ فِي الدُّنْيَا ‏"‏‏.‏\hadithno{6535}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "The believers, after being saved from the (Hell) Fire, will be stopped at a bridge between Paradise and Hell and mutual retaliation will be established among them regarding wrongs they have committed in the world against one another. After they are cleansed and purified (through the retaliation), they will be admitted into Paradise; and by Him in Whose Hand Muhammad's soul is, everyone of them will know his dwelling in Paradise better than he knew his dwelling in this world}}
\hadithdefcmd{bukhari}{6536}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ عُثْمَانَ بْنِ الأَسْوَدِ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ نُوقِشَ الْحِسَابَ عُذِّبَ ‏"‏‏.‏ قَالَتْ قُلْتُ أَلَيْسَ يَقُولُ اللَّهُ تَعَالَى ‏\{‏فَسَوْفَ يُحَاسَبُ حِسَابًا يَسِيرًا‏\}‏‏.‏ قَالَ ‏"‏ ذَلِكِ الْعَرْضُ ‏"‏‏.‏ حَدَّثَنِي عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا يَحْيَى، عَنْ عُثْمَانَ بْنِ الأَسْوَدِ، سَمِعْتُ ابْنَ أَبِي مُلَيْكَةَ، قَالَ سَمِعْتُ عَائِشَةَ ـ رضى الله عنها ـ قَالَتْ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم مِثْلَهُ‏.‏ وَتَابَعَهُ ابْنُ جُرَيْجٍ وَمُحَمَّدُ بْنُ سُلَيْمٍ وَأَيُّوبُ وَصَالِحُ بْنُ رُسْتُمٍ عَنِ ابْنِ أَبِي مُلَيْكَةَ عَنْ عَائِشَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6536}\hadithtrans{Narrated Ibn Abi Mulaika:`Aisha said, "The Prophet (ﷺ) said, 'Anybody whose account (record) is questioned will surely be punished.' I said, 'Doesn't Allah say: 'He surely will receive an easy reckoning?' (84.8) The Prophet (ﷺ) replied. 'This means only the presentation of the account."' Narrated `Aisha: The Prophet (ﷺ) said (as above)}}
\hadithdefcmd{bukhari}{6537}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا حَاتِمُ بْنُ أَبِي صَغِيرَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ أَبِي مُلَيْكَةَ، حَدَّثَنِي الْقَاسِمُ بْنُ مُحَمَّدٍ، حَدَّثَتْنِي عَائِشَةُ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ لَيْسَ أَحَدٌ يُحَاسَبُ يَوْمَ الْقِيَامَةِ إِلاَّ هَلَكَ ‏"‏‏.‏ فَقُلْتُ يَا رَسُولَ اللَّهِ أَلَيْسَ قَدْ قَالَ اللَّهُ تَعَالَى ‏\{‏فَأَمَّا مَنْ أُوتِيَ كِتَابَهُ بِيَمِينِهِ * فَسَوْفَ يُحَاسَبُ حِسَابًا يَسِيرًا‏\}‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّمَا ذَلِكِ الْعَرْضُ، وَلَيْسَ أَحَدٌ يُنَاقَشُ الْحِسَابَ يَوْمَ الْقِيَامَةِ إِلاَّ عُذِّبَ ‏"‏‏.‏\hadithno{6537}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ), said, "None will be called to account on the Day of Resurrection, but will be ruined." I said "O Allah's Messenger (ﷺ)! Hasn't Allah said: 'Then as for him who will be given his record in his right hand, he surely will receive an easy reckoning? (84.7-8) -- Allah's Messenger (ﷺ) said, "That (Verse) means only the presentation of the accounts, but anybody whose account (record) is questioned on the Day of Resurrection, will surely be punished}}
\hadithdefcmd{bukhari}{6538}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، قَالَ حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم وَحَدَّثَنِي مُحَمَّدُ بْنُ مَعْمَرٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم كَانَ يَقُولُ ‏ "‏ يُجَاءُ بِالْكَافِرِ يَوْمَ الْقِيَامَةِ فَيُقَالُ لَهُ أَرَأَيْتَ لَوْ كَانَ لَكَ مِلْءُ الأَرْضِ ذَهَبًا أَكُنْتَ تَفْتَدِي بِهِ فَيَقُولُ نَعَمْ‏.‏ فَيُقَالُ لَهُ قَدْ كُنْتَ سُئِلْتَ مَا هُوَ أَيْسَرُ مِنْ ذَلِكَ ‏"‏‏.‏\hadithno{6538}\hadithtrans{Narrated Anas bin Malik:Allah's Prophet used to say, "A disbeliever will be brought on the Day of Resurrection and will be asked. "Suppose you had as much gold as to fill the earth, would you offer it to ransom yourself?" He will reply, "Yes." Then it will be said to him, "You were asked for something easier than that (to join none in worship with Allah (i.e. to accept Islam, but you refused)}}
\hadithdefcmd{bukhari}{6539}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، حَدَّثَنَا أَبِي قَالَ، حَدَّثَنِي الأَعْمَشُ، قَالَ حَدَّثَنِي خَيْثَمَةُ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ مَا مِنْكُمْ مِنْ أَحَدٍ إِلاَّ وَسَيُكَلِّمُهُ اللَّهُ يَوْمَ الْقِيَامَةِ، لَيْسَ بَيْنَ اللَّهِ وَبَيْنَهُ تُرْجُمَانٌ، ثُمَّ يَنْظُرُ فَلاَ يَرَى شَيْئًا قُدَّامَهُ، ثُمَّ يَنْظُرُ بَيْنَ يَدَيْهِ فَتَسْتَقْبِلُهُ النَّارُ، فَمَنِ اسْتَطَاعَ مِنْكُمْ أَنْ يَتَّقِيَ النَّارَ وَلَوْ بِشِقِّ تَمْرَةٍ ‏"‏‏.‏\hadithno{6539}\hadithtrans{Narrated `Adi bin Hatim:The Prophet (ﷺ) said, "There will be none among you but will be talked to by Allah on the Day of Resurrection, without there being an interpreter between him and Him (Allah) . He will look and see nothing ahead of him, and then he will look (again for the second time) in front of him, and the (Hell) Fire will confront him. So, whoever among you can save himself from the Fire, should do so even with one half of a date (to give in charity)}}
\hadithdefcmd{bukhari}{6540}{قَالَ الأَعْمَشُ حَدَّثَنِي عَمْرٌو، عَنْ خَيْثَمَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ اتَّقُوا النَّارَ ‏"‏‏.‏ ثُمَّ أَعْرَضَ وَأَشَاحَ، ثُمَّ قَالَ ‏"‏ اتَّقُوا النَّارَ ‏"‏‏.‏ ثُمَّ أَعْرَضَ وَأَشَاحَ ثَلاَثًا، حَتَّى ظَنَنَّا أَنَّهُ يَنْظُرُ إِلَيْهَا، ثُمَّ قَالَ ‏"‏ اتَّقُوا النَّارَ وَلَوْ بِشِقِّ تَمْرَةٍ، فَمَنْ لَمْ يَجِدْ فَبِكَلِمَةٍ طَيِّبَةٍ ‏"‏‏.‏\hadithno{6540}\hadithtrans{Narrated `Adi bin Hatim:The Prophet (ﷺ) said, "Protect yourself from the Fire." He then turned his face aside (as if he were looking at it) and said again, "Protect yourself from the Fire," and then turned his face aside (as if he were looking at it), and he said so for the third time till we thought he was looking at it. He then said, "Protect yourselves from the Fire, even if with one half of a date and he who hasn't got even this, (should do so) by (saying) a good, pleasant word}}
\hadithdefcmd{bukhari}{6541}{حَدَّثَنَا عِمْرَانُ بْنُ مَيْسَرَةَ، حَدَّثَنَا ابْنُ فُضَيْلٍ، حَدَّثَنَا حُصَيْنٌ،‏.‏ وَحَدَّثَنِي أَسِيدُ بْنُ زَيْدٍ، حَدَّثَنَا هُشَيْمٌ، عَنْ حُصَيْنٍ، قَالَ كُنْتُ عِنْدَ سَعِيدِ بْنِ جُبَيْرٍ فَقَالَ حَدَّثَنِي ابْنُ عَبَّاسٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ عُرِضَتْ عَلَىَّ الأُمَمُ، فَأَخَذَ النَّبِيُّ يَمُرُّ مَعَهُ الأُمَّةُ، وَالنَّبِيُّ يَمُرُّ مَعَهُ النَّفَرُ، وَالنَّبِيُّ يَمُرُّ مَعَهُ الْعَشَرَةُ، وَالنَّبِيُّ يَمُرُّ مَعَهُ الْخَمْسَةُ، وَالنَّبِيُّ يَمُرُّ وَحْدَهُ، فَنَظَرْتُ فَإِذَا سَوَادٌ كَثِيرٌ قُلْتُ يَا جِبْرِيلُ هَؤُلاَءِ أُمَّتِي قَالَ لاَ وَلَكِنِ انْظُرْ إِلَى الأُفُقِ‏.‏ فَنَظَرْتُ فَإِذَا سَوَادٌ كَثِيرٌ‏.‏ قَالَ هَؤُلاَءِ أُمَّتُكَ، وَهَؤُلاَءِ سَبْعُونَ أَلْفًا قُدَّامَهُمْ، لاَ حِسَابَ عَلَيْهِمْ وَلاَ عَذَابَ‏.‏ قُلْتُ وَلِمَ قَالَ كَانُوا لاَ يَكْتَوُونَ، وَلاَ يَسْتَرْقُونَ، وَلاَ يَتَطَيَّرُونَ، وَعَلَى رَبِّهِمْ يَتَوَكَّلُونَ ‏"‏‏.‏ فَقَامَ إِلَيْهِ عُكَّاشَةُ بْنُ مِحْصَنٍ فَقَالَ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ قَالَ ‏"‏ اللَّهُمَّ اجْعَلْهُ مِنْهُمْ ‏"‏‏.‏ ثُمَّ قَامَ إِلَيْهِ رَجُلٌ آخَرُ قَالَ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ قَالَ ‏"‏ سَبَقَكَ بِهَا عُكَّاشَةُ ‏"‏‏.‏\hadithno{6541}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) said, "The people were displayed in front of me and I saw one prophet passing by with a large group of his followers, and another prophet passing by with only a small group of people, and another prophet passing by with only ten (persons), and another prophet passing by with only five (persons), and another prophet passed by alone. And then I looked and saw a large multitude of people, so I asked Gabriel, "Are these people my followers?' He said, 'No, but look towards the horizon.' I looked and saw a very large multitude of people. Gabriel said. 'Those are your followers, and those are seventy thousand (persons) in front of them who will neither have any reckoning of their accounts nor will receive any punishment.' I asked, 'Why?' He said, 'For they used not to treat themselves with branding (cauterization) nor with Ruqya (get oneself treated by the recitation of some Verses of the Qur'an) and not to see evil omen in things, and they used to put their trust (only) in their Lord." On hearing that, 'Ukasha bin Mihsan got up and said (to the Prophet), "Invoke Allah to make me one of them." The Prophet (ﷺ) said, "O Allah, make him one of them." Then another man got up and said (to the Prophet), "Invoke Allah to make me one of them." The Prophet (ﷺ) said, 'Ukasha has preceded you}}
\hadithdefcmd{bukhari}{6542}{حَدَّثَنَا مُعَاذُ بْنُ أَسَدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سَعِيدُ بْنُ الْمُسَيَّبِ، أَنَّ أَبَا هُرَيْرَةَ، حَدَّثَهُ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ يَدْخُلُ مِنْ أُمَّتِي زُمْرَةٌ هُمْ سَبْعُونَ أَلْفًا، تُضِيءُ وُجُوهُهُمْ إِضَاءَةَ الْقَمَرِ لَيْلَةَ الْبَدْرِ ‏"‏‏.‏ وَقَالَ أَبُو هُرَيْرَةَ فَقَامَ عُكَّاشَةُ بْنُ مِحْصَنٍ الأَسَدِيُّ يَرْفَعُ نَمِرَةً عَلَيْهِ فَقَالَ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ قَالَ ‏"‏ اللَّهُمَّ اجْعَلْهُ مِنْهُمْ ‏"‏‏.‏ ثُمَّ قَامَ رَجُلٌ مِنَ الأَنْصَارِ فَقَالَ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ‏.‏ فَقَالَ ‏"‏ سَبَقَكَ عُكَّاشَةُ ‏"‏‏.‏\hadithno{6542}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "From my followers there will enter Paradise a crowd, seventy thousand in number, whose faces will glitter as the moon does when it is full." On hearing that, 'Ukasha bin Mihsan Al-Asdi got up, lifting his covering sheet, and said, "O Allah's Messenger (ﷺ)! Invoke Allah that He may make me one of them." The Prophet (ﷺ) said, "O Allah, make him one of them." Another man from the Ansar got up and said, "O Allah's Messenger (ﷺ)! Invoke Allah to make me one of them. "The Prophet (ﷺ) said (to him), "'Ukasha has preceded you}}
\hadithdefcmd{bukhari}{6543}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، قَالَ حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَيَدْخُلَنَّ الْجَنَّةَ مِنْ أُمَّتِي سَبْعُونَ أَلْفًا أَوْ سَبْعُمِائَةِ أَلْفٍ ـ شَكَّ فِي أَحَدِهِمَا ـ مُتَمَاسِكِينَ، آخِذٌ بَعْضُهُمْ بِبَعْضٍ، حَتَّى يَدْخُلَ أَوَّلُهُمْ وَآخِرُهُمُ الْجَنَّةَ، وَوُجُوهُهُمْ عَلَى ضَوْءِ الْقَمَرِ لَيْلَةَ الْبَدْرِ ‏"‏‏.‏\hadithno{6543}\hadithtrans{Narrated Sahl bin Sa`d:The Prophet (ﷺ) said, "Seventy-thousand or seven-hundred thousand of my followers (the narrator is in doubt as to the correct number) will enter Paradise holding each other till the first and the last of them enter Paradise at the same time, and their faces will have a glitter like that of the moon at night when it is full}}
\hadithdefcmd{bukhari}{6544}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنْ صَالِحٍ، حَدَّثَنَا نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دَخَلَ أَهْلُ الْجَنَّةِ الْجَنَّةَ، وَأَهْلُ النَّارِ النَّارَ، ثُمَّ يَقُومُ مُؤَذِّنٌ بَيْنَهُمْ يَا أَهْلَ النَّارِ لاَ مَوْتَ، وَيَا أَهْلَ الْجَنَّةِ لاَ مَوْتَ، خُلُودٌ ‏"‏‏.‏\hadithno{6544}\hadithtrans{Narrated Ibn `Umar:The Prophet; said, "The people of Paradise will enter Paradise, and the people of the (Hell) Fire will enter the (Hell) Fire: then a call-maker will get up (and make an announcement) among them, 'O the people of the (Hell) Fire! No death anymore ! And O people of Paradise! No death (anymore) but Eternity}}
\hadithdefcmd{bukhari}{6545}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ يُقَالُ لأَهْلِ الْجَنَّةِ خُلُودٌ لاَ مَوْتَ‏.‏ وَلأَهْلِ النَّارِ يَا أَهْلَ النَّارِ خُلُودٌ لاَ مَوْتَ ‏"‏‏.‏\hadithno{6545}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, " It will be said to the people of Paradise, 'O people of Paradise! Eternity (for you) and no death,' and to the people of the Fire, 'O people of the Fire, eternity (for you) and no death}}
\hadithdefcmd{bukhari}{6546}{حَدَّثَنَا عُثْمَانُ بْنُ الْهَيْثَمِ، حَدَّثَنَا عَوْفٌ، عَنْ أَبِي رَجَاءٍ، عَنْ عِمْرَانَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اطَّلَعْتُ فِي الْجَنَّةِ فَرَأَيْتُ أَكْثَرَ أَهْلِهَا الْفُقَرَاءَ وَاطَّلَعْتُ فِي النَّارِ فَرَأَيْتُ أَكْثَرَ أَهْلِهَا النِّسَاءَ ‏"‏‏.‏\hadithno{6546}\hadithtrans{Narrated `Imran:The Prophet (ﷺ) said, "I looked into paradise and saw that the majority of its people were the poor, and I looked into the Fire and found that the majority of its people were women}}
\hadithdefcmd{bukhari}{6547}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا إِسْمَاعِيلُ، أَخْبَرَنَا سُلَيْمَانُ التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ، عَنْ أُسَامَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ قُمْتُ عَلَى باب الْجَنَّةِ فَكَانَ عَامَّةُ مَنْ دَخَلَهَا الْمَسَاكِينَ، وَأَصْحَابُ الْجَدِّ مَحْبُوسُونَ، غَيْرَ أَنَّ أَصْحَابَ النَّارِ قَدْ أُمِرَ بِهِمْ إِلَى النَّارِ، وَقُمْتُ عَلَى باب النَّارِ فَإِذَا عَامَّةُ مَنْ دَخَلَهَا النِّسَاءُ ‏"‏‏.‏\hadithno{6547}\hadithtrans{Narrated Usama:The Prophet (ﷺ) said, "I stood at the gate of Paradise and saw that the majority of the people who had entered it were poor people, while the rich were forbidden (to enter along with the poor, because they were waiting the reckoning of their accounts), but the people of the Fire had been ordered to be driven to the Fire. And I stood at the gate of the Fire and found that the majority of the people entering it were women}}
\hadithdefcmd{bukhari}{6548}{حَدَّثَنَا مُعَاذُ بْنُ أَسَدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا عُمَرُ بْنُ مُحَمَّدِ بْنِ زَيْدٍ، عَنْ أَبِيهِ، أَنَّهُ حَدَّثَهُ عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا صَارَ أَهْلُ الْجَنَّةِ إِلَى الْجَنَّةِ، وَأَهْلُ النَّارِ إِلَى النَّارِ، جِيءَ بِالْمَوْتِ حَتَّى يُجْعَلَ بَيْنَ الْجَنَّةِ وَالنَّارِ، ثُمَّ يُذْبَحُ، ثُمَّ يُنَادِي مُنَادٍ يَا أَهْلَ الْجَنَّةِ لاَ مَوْتَ، يَا أَهْلَ النَّارِ لاَ مَوْتَ، فَيَزْدَادُ أَهْلُ الْجَنَّةِ فَرَحًا إِلَى فَرَحِهِمْ‏.‏ وَيَزْدَادُ أَهْلُ النَّارِ حُزْنًا إِلَى حُزْنِهِمْ ‏"‏‏.‏\hadithno{6548}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "When the people of Paradise have entered Paradise and the people of the Fire have entered the Fire, death will be brought and will be placed between the Fire and Paradise, and then it will be slaughtered, and a call will be made (that), 'O people of Paradise, no more death ! O people of the Fire, no more death ! ' So the people of Paradise will have happiness added to their previous happiness, and the people of the Fire will have sorrow added to their previous sorrow}}
\hadithdefcmd{bukhari}{6549}{حَدَّثَنَا مُعَاذُ بْنُ أَسَدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ، أَخْبَرَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يَقُولُ لأَهْلِ الْجَنَّةِ يَا أَهْلَ الْجَنَّةِ‏.‏ يَقُولُونَ لَبَّيْكَ رَبَّنَا وَسَعْدَيْكَ‏.‏ فَيَقُولُ هَلْ رَضِيتُمْ فَيَقُولُونَ وَمَا لَنَا لاَ نَرْضَى وَقَدْ أَعْطَيْتَنَا مَا لَمْ تُعْطِ أَحَدًا مِنْ خَلْقِكَ‏.‏ فَيَقُولُ أَنَا أُعْطِيكُمْ أَفْضَلَ مِنْ ذَلِكَ‏.‏ قَالُوا يَا رَبِّ وَأَىُّ شَىْءٍ أَفْضَلُ مِنْ ذَلِكَ فَيَقُولُ أُحِلُّ عَلَيْكُمْ رِضْوَانِي فَلاَ أَسْخَطُ عَلَيْكُمْ بَعْدَهُ أَبَدًا ‏"‏‏.‏\hadithno{6549}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "Allah will say to the people of Paradise, 'O the people of Paradise!' They will say, 'Labbaik, O our Lord, and Sa`daik!' Allah will say, 'Are you pleased?" They will say, 'Why should we not be pleased since You have given us what You have not given to anyone of Your creation?' Allah will say, 'I will give you something better than that.' They will reply, 'O our Lord! And what is better than that?' Allah will say, 'I will bestow My pleasure and contentment upon you so that I will never be angry with you after for-ever}}
\hadithdefcmd{bukhari}{6550}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو إِسْحَاقَ، عَنْ حُمَيْدٍ، قَالَ سَمِعْتُ أَنَسًا، يَقُولُ أُصِيبَ حَارِثَةُ يَوْمَ بَدْرٍ وَهْوَ غُلاَمٌ، فَجَاءَتْ أُمُّهُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَتْ يَا رَسُولَ اللَّهِ قَدْ عَرَفْتَ مَنْزِلَةَ حَارِثَةَ مِنِّي، فَإِنْ يَكُ فِي الْجَنَّةِ أَصْبِرْ وَأَحْتَسِبْ، وَإِنْ تَكُنِ الأُخْرَى تَرَى مَا أَصْنَعُ‏.‏ فَقَالَ ‏ "‏ وَيْحَكِ ـ أَوَهَبِلْتِ ـ أَوَجَنَّةٌ وَاحِدَةٌ هِيَ جِنَانٌ كَثِيرَةٌ، وَإِنَّهُ لَفِي جَنَّةِ الْفِرْدَوْسِ ‏"‏‏.‏\hadithno{6550}\hadithtrans{Narrated Anas: Haritha was martyred on the day (of the battle) of Badr while he was young. His mother came to the Prophet (ﷺ) saying, "O Allah's Messenger (ﷺ)! You know the relation of Haritha to me (how fond of him I was); so, if he is in Paradise, I will remain patient and wish for Allah's reward, but if he is not there, then you will see what I will do." The Prophet (ﷺ) replied, "May Allah be merciful upon you! Have you gone mad? (Do you think) it is one Paradise? There are many Paradises and he is in the (most superior) Paradise of Al-Firdaus}}
\hadithdefcmd{bukhari}{6551}{حَدَّثَنَا مُعَاذُ بْنُ أَسَدٍ، أَخْبَرَنَا الْفَضْلُ بْنُ مُوسَى، أَخْبَرَنَا الْفُضَيْلُ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏مَا بَيْنَ مَنْكِبَىِ الْكَافِرِ مَسِيرَةُ ثَلاَثَةِ أَيَّامٍ لِلرَّاكِبِ الْمُسْرِعِ‏"‏.‏\hadithno{6551}\hadithtrans{Narrated Abu Huraira: The Prophet (ﷺ) said, "The width between the two shoulders of a Kafir (disbeliever) will be equal to the distance covered by a fast rider in three days}}
\hadithdefcmd{bukhari}{6552}{وَقَالَ إِسْحَاقُ بْنُ إِبْرَاهِيمَ أَخْبَرَنَا الْمُغِيرَةُ بْنُ سَلَمَةَ، حَدَّثَنَا وُهَيْبٌ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ فِي الْجَنَّةِ لَشَجَرَةً يَسِيرُ الرَّاكِبُ فِي ظِلِّهَا مِائَةَ عَامٍ، لاَ يَقْطَعُهَا ‏"‏‏.‏\hadithno{6552}\hadithtrans{Narrated Sahl bin Sa'd: Allah's Messenger (ﷺ) said, "In Paradise there is a tree so big that in its shade a rider may travel for one hundred years without being able to cross it}}
\hadithdefcmd{bukhari}{6553}{قَالَ أَبُو حَازِمٍ فَحَدَّثْتُ بِهِ النُّعْمَانَ بْنَ أَبِي عَيَّاشٍ، فَقَالَ حَدَّثَنِي أَبُو سَعِيدٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ فِي الْجَنَّةِ لَشَجَرَةً يَسِيرُ الرَّاكِبُ الْجَوَادَ الْمُضَمَّرَ السَّرِيعَ مِائَةَ عَامٍ، مَا يَقْطَعُهَا ‏"‏‏.‏\hadithno{6553}\hadithtrans{Narrated Abu Sa'id: The Prophet (ﷺ) said: There is a tree in Paradise (so huge) that a fast (or a trained) rider may travel: for one hundred years without being able to cross it}}
\hadithdefcmd{bukhari}{6554}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيَدْخُلَنَّ الْجَنَّةَ مِنْ أُمَّتِي سَبْعُونَ أَوْ سَبْعُمِائَةِ أَلْفٍ ـ لاَ يَدْرِي أَبُو حَازِمٍ أَيُّهُمَا قَالَ ـ مُتَمَاسِكُونَ، آخِذٌ بَعْضُهُمْ بَعْضًا، لاَ يَدْخُلُ أَوَّلُهُمْ حَتَّى يَدْخُلَ آخِرُهُمْ، وُجُوهُهُمْ عَلَى صُورَةِ الْقَمَرِ لَيْلَةَ الْبَدْرِ ‏"‏‏.‏\hadithno{6554}\hadithtrans{Narrated Sahl bin Sa`d:Allah's Messenger (ﷺ) said, "Seventy thousand or seven hundred thousand of my followers will enter Paradise. (Abu Hazim, the sub-narrator, is not sure as to which of the two numbers is correct.) They will be holding on to each other, the first will not entering the last one does, their faces like the moon on a full moon night}}
\hadithdefcmd{bukhari}{6555}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَبِيهِ، عَنْ سَهْلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏إِنَّ أَهْلَ الْجَنَّةِ لَيَتَرَاءَوْنَ الْغُرَفَ فِي الْجَنَّةِ كَمَا تَتَرَاءَوْنَ الْكَوْكَبَ فِي السَّمَاءِ‏"‏‏.‏\hadithno{6555}\hadithtrans{Narrated Sahl:The Prophet (ﷺ) said, "The people of Paradise will see the Ghuraf (special abodes) in Paradise as you see a star in the sky}}
\hadithdefcmd{bukhari}{6556}{قَالَ أَبِي فَحَدَّثْتُ النُّعْمَانَ بْنَ أَبِي عَيَّاشٍ، فَقَالَ أَشْهَدُ لَسَمِعْتُ أَبَا سَعِيدٍ يُحَدِّثُ وَيَزِيدُ فِيهِ ‏ "‏ كَمَا تَرَاءَوْنَ الْكَوْكَبَ الْغَارِبَ فِي الأُفُقِ الشَّرْقِيِّ وَالْغَرْبِيِّ ‏"‏‏.‏\hadithno{6556}\hadithtrans{Abu Sa`id added:"As you see a glittering star remaining in the eastern horizon and the western horizon}}
\hadithdefcmd{bukhari}{6557}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عِمْرَانَ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَقُولُ اللَّهُ تَعَالَى لأَهْوَنِ أَهْلِ النَّارِ عَذَابًا يَوْمَ الْقِيَامَةِ لَوْ أَنَّ لَكَ مَا فِي الأَرْضِ مِنْ شَىْءٍ أَكُنْتَ تَفْتَدِي بِهِ فَيَقُولُ نَعَمْ‏.‏ فَيَقُولُ أَرَدْتُ مِنْكَ أَهْوَنَ مِنْ هَذَا وَأَنْتَ فِي صُلْبِ آدَمَ أَنْ لاَ تُشْرِكَ بِي شَيْئًا فَأَبَيْتَ إِلاَّ أَنْ تُشْرِكَ بِي ‏"‏‏.‏\hadithno{6557}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "Allah will say to the person who will have the minimum punishment in the Fire on the Day of Resurrection, 'If you had things equal to whatever is on the earth, would you ransom yourself (from the punishment) with it?' He will reply, Yes. Allah will say, 'I asked you a much easier thing than this while you were in the backbone of Adam, that is, not to worship others besides Me, but you refused and insisted to worship others besides Me}}
\hadithdefcmd{bukhari}{6558}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادٌ، عَنْ عَمْرٍو، عَنْ جَابِرٍ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ يَخْرُجُ مِنَ النَّارِ بِالشَّفَاعَةِ كَأَنَّهُمُ الثَّعَارِيرُ ‏"‏‏.‏ قُلْتُ مَا الثَّعَارِيرُ قَالَ الضَّغَابِيسُ‏.‏ وَكَانَ قَدْ سَقَطَ فَمُهُ فَقُلْتُ لِعَمْرِو بْنِ دِينَارٍ أَبَا مُحَمَّدٍ سَمِعْتَ جَابِرَ بْنَ عَبْدِ اللَّهِ يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏"‏ يَخْرُجُ بِالشَّفَاعَةِ مِنَ النَّارِ ‏"‏‏.‏ قَالَ نَعَمْ‏.‏\hadithno{6558}\hadithtrans{Narrated Hammad from `Amr from Jabir:The Prophet (ﷺ) said, "Some people will come out of the Fire through intercession looking like The Thaarir." I asked `Amr, "What is the Thaarir?" He said, Ad Dagh`Abis, and at that time he was toothless. Hammad added: I said to `Amr bin Dinar, "O Abu Muhammad! Did you hear Jabir bin `Abdullah saying, 'I heard the Prophet (ﷺ) saying: 'Some people will come out of the Fire through intercession?" He said, "Yes}}
\hadithdefcmd{bukhari}{6559}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَخْرُجُ قَوْمٌ مِنَ النَّارِ بَعْدَ مَا مَسَّهُمْ مِنْهَا سَفْعٌ، فَيَدْخُلُونَ الْجَنَّةَ، فَيُسَمِّيهِمْ أَهْلُ الْجَنَّةِ الْجَهَنَّمِيِّينَ ‏"‏‏.‏\hadithno{6559}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said, "Some people will come out of the Fire after they have received a touch of the Fire, changing their color, and they will enter Paradise, and the people of Paradise will name them 'Al- Jahannamiyin' the (Hell) Fire people}}
\hadithdefcmd{bukhari}{6560}{حَدَّثَنَا مُوسَى، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَمْرُو بْنُ يَحْيَى، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا دَخَلَ أَهْلُ الْجَنَّةِ الْجَنَّةَ، وَأَهْلُ النَّارِ النَّارَ يَقُولُ اللَّهُ مَنْ كَانَ فِي قَلْبِهِ مِثْقَالُ حَبَّةٍ مِنْ خَرْدَلٍ مِنْ إِيمَانٍ فَأَخْرِجُوهُ‏.‏ فَيُخْرَجُونَ قَدِ امْتُحِشُوا وَعَادُوا حُمَمًا، فَيُلْقَوْنَ فِي نَهَرِ الْحَيَاةِ، فَيَنْبُتُونَ كَمَا تَنْبُتُ الْحِبَّةُ فِي حَمِيلِ السَّيْلِ ـ أَوْ قَالَ ـ حَمِيَّةِ السَّيْلِ ‏"‏‏.‏ وَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَلَمْ تَرَوْا أَنَّهَا تَنْبُتُ صَفْرَاءَ مُلْتَوِيَةً ‏"‏‏.‏\hadithno{6560}\hadithtrans{Narrated Abu Sa`id Al-Khudri:Allah's Messenger (ﷺ) said, "When the people of Paradise have entered Paradise, and the people of the Fire have entered the Fire, Allah will say. 'Take out (of the Fire) whoever has got faith equal to a mustard seed in his heart.' They will come out, and by that time they would have burnt and became like coal, and then they will be thrown into the river of Al-Hayyat (life) and they will spring up just as a seed grows on the bank of a rainwater stream." The Prophet (ﷺ) said, "Don't you see that the germinating seed comes out yellow and twisted?}}
\hadithdefcmd{bukhari}{6561}{حَدَّثَنِي مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا غُنْدَرٌ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ أَبَا إِسْحَاقَ، قَالَ سَمِعْتُ النُّعْمَانَ، سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏إِنَّ أَهْوَنَ أَهْلِ النَّارِ عَذَابًا يَوْمَ الْقِيَامَةِ لَرَجُلٌ تُوضَعُ فِي أَخْمَصِ قَدَمَيْهِ جَمْرَةٌ يَغْلِي مِنْهَا دِمَاغُهُ‏"‏.‏\hadithno{6561}\hadithtrans{Narrated An-Nu`man:I heard the Prophet (ﷺ) saying, "The person who will have the least punishment from amongst the Hell Fire people on the Day of Resurrection, will be a man under whose arch of the feet a smoldering ember will be placed so that his brain will boil because of it}}
\hadithdefcmd{bukhari}{6562}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ، حَدَّثَنَا إِسْرَائِيلُ، عَنْ أَبِي إِسْحَاقَ، عَنِ النُّعْمَانِ بْنِ بَشِيرٍ، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّ أَهْوَنَ أَهْلِ النَّارِ عَذَابًا يَوْمَ الْقِيَامَةِ رَجُلٌ عَلَى أَخْمَصِ قَدَمَيْهِ جَمْرَتَانِ يَغْلِي مِنْهُمَا دِمَاغُهُ، كَمَا يَغْلِي الْمِرْجَلُ وَالْقُمْقُمُ‏"‏‏.‏\hadithno{6562}\hadithtrans{Narrated An-Nu`man bin Bashir:I heard the Prophet (ﷺ) saying, "The least punished person of the (Hell) Fire people on the Day of Resurrection will be a man under whose arch of the feet two smoldering embers will be placed, because of which his brain will boil just like Al-Mirjal (copper vessel) or a Qum-qum (narrow-necked vessel) is boiling with water}}
\hadithdefcmd{bukhari}{6563}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرٍو، عَنْ خَيْثَمَةَ، عَنْ عَدِيِّ بْنِ حَاتِمٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم ذَكَرَ النَّارَ فَأَشَاحَ بِوَجْهِهِ فَتَعَوَّذَ مِنْهَا، ثُمَّ ذَكَرَ النَّارَ فَأَشَاحَ بِوَجْهِهِ فَتَعَوَّذَ مِنْهَا، ثُمَّ قَالَ ‏ "‏ اتَّقُوا النَّارَ وَلَوْ بِشِقِّ تَمْرَةٍ، فَمَنْ لَمْ يَجِدْ فَبِكَلِمَةٍ طَيِّبَةٍ ‏"‏‏.‏\hadithno{6563}\hadithtrans{Narrated `Adi bin Hatim:The Prophet (ﷺ) mentioned the Fire and turned his face aside and asked for Allah's protection from it, and then again he mentioned the Fire and turned his face aside and asked for Allah's protection from it and said, "Protect yourselves from the Hell-Fire, even if with one half of a date, and he who cannot afford that, then (let him do so) by (saying) a good, pleasant word}}
\hadithdefcmd{bukhari}{6564}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ، حَدَّثَنَا ابْنُ أَبِي حَازِمٍ، وَالدَّرَاوَرْدِيُّ، عَنْ يَزِيدَ، عَنْ عَبْدِ اللَّهِ بْنِ خَبَّابٍ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ ـ رضى الله عنه ـ أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم وَذُكِرَ عِنْدَهُ عَمُّهُ أَبُو طَالِبٍ فَقَالَ ‏ "‏ لَعَلَّهُ تَنْفَعُهُ شَفَاعَتِي يَوْمَ الْقِيَامَةِ فَيُجْعَلُ فِي ضَحْضَاحٍ مِنَ النَّارِ، يَبْلُغُ كَعْبَيْهِ، يَغْلِي مِنْهُ أُمُّ دِمَاغِهِ ‏"‏‏.‏\hadithno{6564}\hadithtrans{Narrated Abu Sa`id Al-Khudri:I heard Allah's Messenger (ﷺ) when his uncle, Abu Talib had been mentioned in his presence, saying, "May be my intercession will help him (Abu Talib) on the Day of Resurrection so that he may be put in a shallow place in the Fire, with fire reaching his ankles and causing his brain to boil}}
\hadithdefcmd{bukhari}{6565}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ ـ رضى الله عنه ـ قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يَجْمَعُ اللَّهُ النَّاسَ يَوْمَ الْقِيَامَةِ فَيَقُولُونَ لَوِ اسْتَشْفَعْنَا عَلَى رَبِّنَا حَتَّى يُرِيحَنَا مِنْ مَكَانِنَا‏.‏ فَيَأْتُونَ آدَمَ فَيَقُولُونَ أَنْتَ الَّذِي خَلَقَكَ اللَّهُ بِيَدِهِ، وَنَفَخَ فِيكَ مِنْ رُوحِهِ، وَأَمَرَ الْمَلاَئِكَةَ فَسَجَدُوا لَكَ، فَاشْفَعْ لَنَا عِنْدَ رَبِّنَا‏.‏ فَيَقُولُ لَسْتُ هُنَاكُمْ ـ وَيَذْكُرُ خَطِيئَتَهُ وَيَقُولُ ـ ائْتُوا نُوحًا أَوَّلَ رَسُولٍ بَعَثَهُ اللَّهُ‏.‏ فَيَأْتُونَهُ فَيَقُولُ لَسْتُ هُنَاكُمْ ـ وَيَذْكُرُ خَطِيئَتَهُ ـ ائْتُوا إِبْرَاهِيمَ الَّذِي اتَّخَذَهُ اللَّهُ خَلِيلاً‏.‏ فَيَأْتُونَهُ، فَيَقُولُ لَسْتُ هُنَاكُمْ ـ وَيَذْكُرُ خَطِيئَتَهُ ـ ائْتُوا مُوسَى الَّذِي كَلَّمَهُ اللَّهُ فَيَأْتُونَهُ فَيَقُولُ لَسْتُ هُنَاكُمْ، فَيَذْكُرُ خَطِيئَتَهُ ـ ائْتُوا عِيسَى فَيَأْتُونَهُ فَيَقُولُ لَسْتُ هُنَاكُمْ، ائْتُوا مُحَمَّدًا صلى الله عليه وسلم فَقَدْ غُفِرَ لَهُ مَا تَقَدَّمَ مِنْ ذَنْبِهِ وَمَا تَأَخَّرَ فَيَأْتُونِي فَأَسْتَأْذِنُ عَلَى رَبِّي، فَإِذَا رَأَيْتُهُ وَقَعْتُ سَاجِدًا، فَيَدَعُنِي مَا شَاءَ اللَّهُ، ثُمَّ يُقَالُ ارْفَعْ رَأْسَكَ، سَلْ تُعْطَهْ، وَقُلْ يُسْمَعْ، وَاشْفَعْ تُشَفَّعْ‏.‏ فَأَرْفَعُ رَأْسِي، فَأَحْمَدُ رَبِّي بِتَحْمِيدٍ يُعَلِّمُنِي، ثُمَّ أَشْفَعُ فَيَحُدُّ لِي حَدًّا، ثُمَّ أُخْرِجُهُمْ مِنَ النَّارِ، وَأُدْخِلُهُمُ الْجَنَّةَ، ثُمَّ أَعُودُ فَأَقَعُ سَاجِدًا مِثْلَهُ فِي الثَّالِثَةِ أَوِ الرَّابِعَةِ حَتَّى مَا بَقِيَ فِي النَّارِ إِلاَّ مَنْ حَبَسَهُ الْقُرْآنُ ‏"‏‏.‏ وَكَانَ قَتَادَةُ يَقُولُ عِنْدَ هَذَا أَىْ وَجَبَ عَلَيْهِ الْخُلُودُ‏.‏\hadithno{6565}\hadithtrans{Narrated Anas:Allah's Messenger (ﷺ) said, "Allah will gather all the people on the Day of Resurrection and they will say, 'Let us request someone to intercede for us with our Lord so that He may relieve us from this place of ours.' Then they will go to Adam and say, 'You are the one whom Allah created with His Own Hands, and breathed in you of His soul, and ordered the angels to prostrate to you; so please intercede for us with our Lord.' Adam will reply, 'I am not fit for this undertaking, and will remember his sin, and will say, 'Go to Noah, the first Apostle sent by Allah' They will go to him and he will say, 'I am not fit for this undertaking', and will remember his sin and say, 'Go to Abraham whom Allah took as a Khalil. They will go to him (and request similarly). He will reply, 'I am not fit for this undertaking,' and will remember his sin and say, 'Go to Moses to whom Allah spoke directly.' They will go to Moses and he will say, 'I am not fit for this undertaking,' and will remember his sin and say, 'Go to Jesus.' They will go to him, and he will say, 'I am not fit for this undertaking, go to Muhammad as Allah has forgiven his past and future sins.' They will come to me and I will ask my Lord's permission, and when I see Him, I will fall down in prostration to Him, and He will leave me in that state as long as (He) Allah will, and then I will be addressed. 'Raise up your head (O Muhammad)! Ask, and your request will be granted, and say, and your saying will be listened to; intercede, and your intercession will be accepted.' Then I will raise my head, and I will glorify and praise my Lord with a saying(i.e. invocation) He will teach me, and then I will intercede, Allah will fix a limit for me (i.e., certain type of people for whom I may intercede), and I will take them out of the (Hell) Fire and let them enter Paradise. Then I will come back (to Allah) and fall in prostration, and will do the same for the third and fourth times till no-one remains in the (Hell) Fire except those whom the Qur'an has imprisoned therein." (The sub-narrator, Qatada used to say at that point, "...those upon whom eternity (in Hell) has been imposed.") (See Hadith No. 3, Vol)}}
\hadithdefcmd{bukhari}{6566}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنِ الْحَسَنِ بْنِ ذَكْوَانَ، حَدَّثَنَا أَبُو رَجَاءٍ، حَدَّثَنَا عِمْرَانُ بْنُ حُصَيْن ٍ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَخْرُجُ قَوْمٌ مِنَ النَّارِ بِشَفَاعَةِ مُحَمَّدٍ صلى الله عليه وسلم فَيَدْخُلُونَ الْجَنَّةَ، يُسَمَّوْنَ الْجَهَنَّمِيِّينَ ‏"‏‏.‏\hadithno{6566}\hadithtrans{Narrated `Imran bin Husain:The Prophet (ﷺ) said, "Some people will be taken out of the Fire through the intercession of Muhammad they will enter Paradise and will be called Al-Jahannamiyin (the Hell Fire people)}}
\hadithdefcmd{bukhari}{6568}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ أُمَّ حَارِثَةَ، أَتَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم وَقَدْ هَلَكَ حَارِثَةُ يَوْمَ بَدْرٍ، أَصَابَهُ غَرْبُ سَهْمٍ‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ قَدْ عَلِمْتَ مَوْقِعَ حَارِثَةَ مِنْ قَلْبِي، فَإِنْ كَانَ فِي الْجَنَّةِ لَمْ أَبْكِ عَلَيْهِ، وَإِلاَّ سَوْفَ تَرَى مَا أَصْنَعُ‏.‏ فَقَالَ لَهَا ‏ "‏ هَبِلْتِ، أَجَنَّةٌ وَاحِدَةٌ هِيَ إِنَّهَا جِنَانٌ كَثِيرَةٌ، وَإِنَّهُ فِي الْفِرْدَوْسِ الأَعْلَى ‏"‏‏.‏ (وَقَالَ ‏:‏غَدْوَةٌ فِي سَبِيلِ اللَّهِ أَوْ رَوْحَةٌ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا، وَلَقَابُ قَوْسِ أَحَدِكُمْ أَوْ مَوْضِعُ قَدَمٍ مِنَ الْجَنَّةِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا، وَلَوْ أَنَّ امْرَأَةً مِنْ نِسَاءِ أَهْلِ الْجَنَّةِ اطَّلَعَتْ إِلَى الأَرْضِ، لأَضَاءَتْ مَا بَيْنَهُمَا، وَلَمَلأَتْ مَا بَيْنَهُمَا رِيحًا، وَلَنَصِيفُهَا ـ يَعْنِي الْخِمَارَ ـ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا‏)‏‏.‏\hadithno{6568}\hadithtrans{Narrated Anas:Um (the mother of) Haritha came to Allah's Messenger (ﷺ) after Haritha had been martyred on the Day (of the battle) of Badr by an arrow thrown by an unknown person. She said, "O Allah's Messenger (ﷺ)! You know the position of Haritha in my heart (i.e. how dear to me he was), so if he is in Paradise, I will not weep for him, or otherwise, you will see what I will do." The Prophet (ﷺ) said, "Are you mad? Is there only one Paradise? There are many Paradises, and he is in the highest Paradise of Firdaus." The Prophet added, "A forenoon journey or an after noon journey in Allah's Cause is better than the whole world and whatever is in it; and a place equal to an arrow bow of anyone of you, or a place equal to a foot in Paradise is better than the whole world and whatever is in it; and if one of the women of Paradise looked at the earth, she would fill the whole space between them (the earth and the heaven) with light, and would fill whatever is in between them, with perfume, and the veil of her face is better than the whole world and whatever is in it}}
\hadithdefcmd{bukhari}{6569}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، حَدَّثَنَا أَبُو الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لاَ يَدْخُلُ أَحَدٌ الْجَنَّةَ إِلاَّ أُرِيَ مَقْعَدَهُ مِنَ النَّارِ، لَوْ أَسَاءَ، لِيَزْدَادَ شُكْرًا، وَلاَ يَدْخُلُ النَّارَ أَحَدٌ إِلاَّ أُرِيَ مَقْعَدَهُ مِنَ الْجَنَّةِ، لَوْ أَحْسَنَ، لِيَكُونَ عَلَيْهِ حَسْرَةً ‏"‏‏.‏\hadithno{6569}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "None will enter Paradise but will be shown the place he would have occupied in the (Hell) Fire if he had rejected faith, so that he may be more thankful; and none will enter the (Hell) Fire but will be shown the place he would have occupied in Paradise if he had faith, so that may be a cause of sorrow for him}}
\hadithdefcmd{bukhari}{6570}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ عَمْرٍو، عَنْ سَعِيدِ بْنِ أَبِي سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّهُ قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَنْ أَسْعَدُ النَّاسِ بِشَفَاعَتِكَ يَوْمَ الْقِيَامَةِ فَقَالَ ‏ "‏ لَقَدْ ظَنَنْتُ يَا أَبَا هُرَيْرَةَ أَنْ لاَ يَسْأَلَنِي عَنْ هَذَا الْحَدِيثِ أَحَدٌ أَوَّلُ مِنْكَ، لِمَا رَأَيْتُ مِنْ حِرْصِكَ عَلَى الْحَدِيثِ، أَسْعَدُ النَّاسِ بِشَفَاعَتِي يَوْمَ الْقِيَامَةِ مَنْ قَالَ لاَ إِلَهَ إِلاَّ اللَّهُ‏.‏ خَالِصًا مِنْ قِبَلِ نَفْسِهِ ‏"‏‏.‏\hadithno{6570}\hadithtrans{Narrated Abu Huraira:I said, "O Allah's Messenger (ﷺ)! Who will be the luckiest person who will gain your intercession on the Day of Resurrection?" The Prophet (ﷺ) said, "O Abu Huraira! I have thought that none will ask me about this Hadith before you, as I know your longing for the (learning of) Hadiths. The luckiest person who will have my intercession on the Day of Resurrection will be the one who said, 'None has the right to be worshipped but Allah,' sincerely from the bottom of his heart}}
\hadithdefcmd{bukhari}{6571}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَبِيدَةَ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنِّي لأَعْلَمُ آخِرَ أَهْلِ النَّارِ خُرُوجًا مِنْهَا، وَآخِرَ أَهْلِ الْجَنَّةِ دُخُولاً رَجُلٌ يَخْرُجُ مِنَ النَّارِ كَبْوًا، فَيَقُولُ اللَّهُ اذْهَبْ فَادْخُلِ الْجَنَّةَ‏.‏ فَيَأْتِيهَا فَيُخَيَّلُ إِلَيْهِ أَنَّهَا مَلأَى، فَيَرْجِعُ فَيَقُولُ يَا رَبِّ وَجَدْتُهَا مَلأَى، فَيَقُولُ اذْهَبْ فَادْخُلِ الْجَنَّةَ‏.‏ فَيَأْتِيهَا فَيُخَيَّلُ إِلَيْهِ أَنَّهَا مَلأَى‏.‏ فَيَقُولُ يَا رَبِّ وَجَدْتُهَا مَلأَى، فَيَقُولُ اذْهَبْ فَادْخُلِ الْجَنَّةَ، فَإِنَّ لَكَ مِثْلَ الدُّنْيَا وَعَشَرَةَ أَمْثَالِهَا‏.‏ أَوْ إِنَّ لَكَ مِثْلَ عَشَرَةِ أَمْثَالِ الدُّنْيَا‏.‏ فَيَقُولُ تَسْخَرُ مِنِّي، أَوْ تَضْحَكُ مِنِّي وَأَنْتَ الْمَلِكُ ‏"‏‏.‏ فَلَقَدْ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم ضَحِكَ حَتَّى بَدَتْ نَوَاجِذُهُ، وَكَانَ يُقَالُ ذَلِكَ أَدْنَى أَهْلِ الْجَنَّةِ مَنْزِلَةً‏.‏\hadithno{6571}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "I know the person who will be the last to come out of the (Hell) Fire, and the last to enter Paradise. He will be a man who will come out of the (Hell) Fire crawling, and Allah will say to him, 'Go and enter Paradise.' He will go to it, but he will imagine that it had been filled, and then he will return and say, 'O Lord, I have found it full.' Allah will say, 'Go and enter Paradise, and you will have what equals the world and ten times as much (or, you will have as much as ten times the like of the world).' On that, the man will say, 'Do you mock at me (or laugh at me) though You are the King?" I saw Allah's Messenger (ﷺ) (while saying that) smiling that his premolar teeth became visible. It is said that will be the lowest in degree amongst the people of Paradise}}
\hadithdefcmd{bukhari}{6572}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ عَبْدِ الْمَلِكِ، عَنْ عَبْدِ اللَّهِ بْنِ الْحَارِثِ بْنِ نَوْفَلٍ، عَنِ الْعَبَّاسِ ـ رضى الله عنه ـ أَنَّهُ قَالَ لِلنَّبِيِّ صلى الله عليه وسلم هَلْ نَفَعْتَ أَبَا طَالِبٍ بِشَىْءٍ‏.‏\hadithno{6572}\hadithtrans{Narrated `Abbas:that he said to the Prophet (ﷺ) "Did you benefit Abu Talib with anything?}}
\hadithdefcmd{bukhari}{6573}{حَدَّثَنَا أَبُو الْيَمَانِ، أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، أَخْبَرَنِي سَعِيدٌ، وَعَطَاءُ بْنُ يَزِيدَ، أَنَّ أَبَا هُرَيْرَةَ، أَخْبَرَهُمَا عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَحَدَّثَنِي مَحْمُودٌ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ أُنَاسٌ يَا رَسُولَ اللَّهِ هَلْ نَرَى رَبَّنَا يَوْمَ الْقِيَامَةِ فَقَالَ ‏"‏ هَلْ تُضَارُّونَ فِي الشَّمْسِ، لَيْسَ دُونَهَا سَحَابٌ ‏"‏‏.‏ قَالُوا لاَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ هَلْ تُضَارُّونَ فِي الْقَمَرِ لَيْلَةَ الْبَدْرِ، لَيْسَ دُونَهُ سَحَابٌ ‏"‏‏.‏ قَالُوا لاَ يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَإِنَّكُمْ تَرَوْنَهُ يَوْمَ الْقِيَامَةِ كَذَلِكَ، يَجْمَعُ اللَّهُ النَّاسَ فَيَقُولُ مَنْ كَانَ يَعْبُدُ شَيْئًا فَلْيَتَّبِعْهُ، فَيَتْبَعُ مَنْ كَانَ يَعْبُدُ الشَّمْسَ، وَيَتْبَعُ مَنْ كَانَ يَعْبُدُ الْقَمَرَ، وَيَتْبَعُ مَنْ كَانَ يَعْبُدُ الطَّوَاغِيتَ، وَتَبْقَى هَذِهِ الأُمَّةُ فِيهَا مُنَافِقُوهَا، فَيَأْتِيهِمُ اللَّهُ فِي غَيْرِ الصُّورَةِ الَّتِي يَعْرِفُونَ فَيَقُولُ أَنَا رَبُّكُمْ‏.‏ فَيَقُولُونَ نَعُوذُ بِاللَّهِ مِنْكَ، هَذَا مَكَانُنَا حَتَّى يَأْتِيَنَا رَبُّنَا، فَإِذَا أَتَانَا رَبُّنَا عَرَفْنَاهُ فَيَأْتِيهِمُ اللَّهُ فِي الصُّورَةِ الَّتِي يَعْرِفُونَ فَيَقُولُ أَنَا رَبُّكُمْ‏.‏ فَيَقُولُونَ أَنْتَ رَبُّنَا، فَيَتْبَعُونَهُ وَيُضْرَبُ جِسْرُ جَهَنَّمَ ‏"‏‏.‏ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَأَكُونُ أَوَّلَ مَنْ يُجِيزُ، وَدُعَاءُ الرُّسُلِ يَوْمَئِذٍ اللَّهُمَّ سَلِّمْ سَلِّمْ، وَبِهِ كَلاَلِيبُ مِثْلُ شَوْكِ السَّعْدَانِ، أَمَا رَأَيْتُمْ شَوْكَ السَّعْدَانِ ‏"‏‏.‏ قَالُوا بَلَى يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ فَإِنَّهَا مِثْلُ شَوْكِ السَّعْدَانِ، غَيْرَ أَنَّهَا لاَ يَعْلَمُ قَدْرَ عِظَمِهَا إِلاَّ اللَّهُ، فَتَخْطَفُ النَّاسَ بِأَعْمَالِهِمْ، مِنْهُمُ الْمُوبَقُ، بِعَمَلِهِ وَمِنْهُمُ الْمُخَرْدَلُ، ثُمَّ يَنْجُو، حَتَّى إِذَا فَرَغَ اللَّهُ مِنَ الْقَضَاءِ بَيْنَ عِبَادِهِ، وَأَرَادَ أَنْ يُخْرِجَ مِنَ النَّارِ مَنْ أَرَادَ أَنْ يُخْرِجَ، مِمَّنْ كَانَ يَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، أَمَرَ الْمَلاَئِكَةَ أَنْ يُخْرِجُوهُمْ، فَيَعْرِفُونَهُمْ بِعَلاَمَةِ آثَارِ السُّجُودِ، وَحَرَّمَ اللَّهُ عَلَى النَّارِ أَنْ تَأْكُلَ مِنِ ابْنِ آدَمَ أَثَرَ السُّجُودِ، فَيُخْرِجُونَهُمْ قَدِ امْتُحِشُوا، فَيُصَبُّ عَلَيْهِمْ مَاءٌ يُقَالُ لَهُ مَاءُ الْحَيَاةِ، فَيَنْبُتُونَ نَبَاتَ الْحِبَّةِ فِي حَمِيلِ السَّيْلِ، وَيَبْقَى رَجُلٌ مُقْبِلٌ بِوَجْهِهِ عَلَى النَّارِ فَيَقُولُ يَا رَبِّ قَدْ قَشَبَنِي رِيحُهَا وَأَحْرَقَنِي ذَكَاؤُهَا، فَاصْرِفْ وَجْهِي عَنِ النَّارِ فَلاَ يَزَالُ يَدْعُو اللَّهَ‏.‏ فَيَقُولُ لَعَلَّكَ إِنْ أَعْطَيْتُكَ أَنْ تَسْأَلَنِي غَيْرَهُ‏.‏ فَيَقُولُ لاَ وَعِزَّتِكَ لاَ أَسْأَلُكَ غَيْرَهُ‏.‏ فَيَصْرِفُ وَجْهَهُ عَنِ النَّارِ، ثُمَّ يَقُولُ بَعْدَ ذَلِكَ يَا رَبِّ قَرِّبْنِي إِلَى باب الْجَنَّةِ‏.‏ فَيَقُولُ أَلَيْسَ قَدْ زَعَمْتَ أَنْ لاَ تَسْأَلْنِي غَيْرَهُ، وَيْلَكَ ابْنَ آدَمَ مَا أَغْدَرَكَ‏.‏ فَلاَ يَزَالُ يَدْعُو‏.‏ فَيَقُولُ لَعَلِّي إِنْ أَعْطَيْتُكَ ذَلِكَ تَسْأَلَنِي غَيْرَهُ‏.‏ فَيَقُولُ لاَ وَعِزَّتِكَ لاَ أَسْأَلُكَ غَيْرَهُ‏.‏ فَيُعْطِي اللَّهَ مِنْ عُهُودٍ وَمَوَاثِيقَ أَنْ لاَ يَسْأَلَهُ غَيْرَهُ، فَيُقَرِّبُهُ إِلَى باب الْجَنَّةِ، فَإِذَا رَأَى مَا فِيهَا سَكَتَ مَا شَاءَ اللَّهُ أَنْ يَسْكُتَ، ثُمَّ يَقُولُ رَبِّ أَدْخِلْنِي الْجَنَّةَ‏.‏ ثُمَّ يَقُولُ أَوَلَيْسَ قَدْ زَعَمْتَ أَنْ لاَ تَسْأَلَنِي غَيْرَهُ، وَيْلَكَ يَا ابْنَ آدَمَ مَا أَغْدَرَكَ فَيَقُولُ يَا رَبِّ لاَ تَجْعَلْنِي أَشْقَى خَلْقِكَ‏.‏ فَلاَ يَزَالُ يَدْعُو حَتَّى يَضْحَكَ، فَإِذَا ضَحِكَ مِنْهُ أَذِنَ لَهُ بِالدُّخُولِ فِيهَا، فَإِذَا دَخَلَ فِيهَا قِيلَ تَمَنَّ مِنْ كَذَا‏.‏ فَيَتَمَنَّى، ثُمَّ يُقَالُ لَهُ تَمَنَّ مِنْ كَذَا‏.‏ فَيَتَمَنَّى حَتَّى تَنْقَطِعَ بِهِ الأَمَانِيُّ فَيَقُولُ لَهُ هَذَا لَكَ وَمِثْلُهُ مَعَهُ ‏"‏‏.‏ قَالَ أَبُو هُرَيْرَةَ وَذَلِكَ الرَّجُلُ آخِرُ أَهْلِ الْجَنَّةِ دُخُولاً‏.‏\hadithno{6573}\hadithtrans{Narrated Abu Huraira:Some people said, "O Allah's Messenger (ﷺ)! Shall we see our Lord on the Day of Resurrection?" He said, "Do you crowd and squeeze each other on looking at the sun when it is not hidden by clouds?" They replied, "No, Allah's Messenger (ﷺ)." He said, "Do you crowd and squeeze each other on looking at the moon when it is full and not hidden by clouds?" They replied, No, O Allah's Messenger (ﷺ)!" He said, "So you will see Him (your Lord) on the Day of Resurrection similarly Allah will gather all the people and say, 'Whoever used to worship anything should follow that thing. 'So, he who used to worship the sun, will follow it, and he who used to worship the moon will follow it, and he who used to worship false deities will follow them; and then only this nation (i.e., Muslims) will remain, including their hypocrites. Allah will come to them in a shape other than they know and will say, 'I am your Lord.' They will say, 'We seek refuge with Allah from you. This is our place; (we will not follow you) till our Lord comes to us, and when our Lord comes to us, we will recognize Him. Then Allah will come to then in a shape they know and will say, "I am your Lord.' They will say, '(No doubt) You are our Lord,' and they will follow Him. Then a bridge will be laid over the (Hell) Fire." Allah's Messenger (ﷺ) added, "I will be the first to cross it. And the invocation of the Apostles on that Day, will be 'Allahumma Sallim, Sallim (O Allah, save us, save us!),' and over that bridge there will be hooks Similar to the thorns of As Sa'dan (a thorny tree). Didn't you see the thorns of As-Sa'dan?" The companions said, "Yes, O Allah's Messenger (ﷺ)." He added, "So the hooks over that bridge will be like the thorns of As-Sa-dan except that their greatness in size is only known to Allah. These hooks will snatch the people according to their deeds. Some people will be ruined because of their evil deeds, and some will be cut into pieces and fall down in Hell, but will be saved afterwards, when Allah has finished the judgments among His slaves, and intends to take out of the Fire whoever He wishes to take out from among those who used to testify that none had the right to be worshipped but Allah. We will order the angels to take them out and the angels will know them by the mark of the traces of prostration (on their foreheads) for Allah banned the f ire to consume the traces of prostration on the body of Adam's son. So they will take them out, and by then they would have burnt (as coal), and then water, called Ma'ul Hayat (water of life) will be poured on them, and they will spring out like a seed springs out on the bank of a rainwater stream, and there will remain one man who will be facing the (Hell) Fire and will say, 'O Lord! It's (Hell's) vapor has Poisoned and smoked me and its flame has burnt me; please turn my face away from the Fire.' He will keep on invoking Allah till Allah says, 'Perhaps, if I give you what you want), you will ask for another thing?' The man will say, 'No, by Your Power, I will not ask You for anything else.' Then Allah will turn his face away from the Fire. The man will say after that, 'O Lord, bring me near the gate of Paradise.' Allah will say (to him), 'Didn't you promise not to ask for anything else? Woe to you, O son of Adam ! How treacherous you are!' The man will keep on invoking Allah till Allah will say, 'But if I give you that, you may ask me for something else.' The man will say, 'No, by Your Power. I will not ask for anything else.' He will give Allah his covenant and promise not to ask for anything else after that. So Allah will bring him near to the gate of Paradise, and when he sees what is in it, he will remain silent as long as Allah will, and then he will say, 'O Lord! Let me enter Paradise.' Allah will say, 'Didn't you promise that you would not ask Me for anything other than that? Woe to you, O son of Adam ! How treacherous you are!' On that, the man will say, 'O Lord! Do not make me the most wretched of Your creation,' and will keep on invoking Allah till Allah will smile and when Allah will smile because of him, then He will allow him to enter Paradise, and when he will enter Paradise, he will be addressed, 'Wish from so-and-so.' He will wish till all his wishes will be fulfilled, then Allah will say, All this (i.e. what you have wished for) and as much again therewith are for you.' " Abu Huraira added: That man will be the last of the people of Paradise to enter (Paradise)}}
\hadithdefcmd{bukhari}{6574}{قَالَ عَطَاءٌ وَأَبُو سَعِيدٍ الْخُدْرِيُّ جَالِسٌ مَعَ أَبِي هُرَيْرَةَ، لاَ يُغَيِّرُ عَلَيْهِ شَيْئًا مِنْ حَدِيثِهِ حَتَّى انْتَهَى إِلَى قَوْلِهِ ‏"‏ هَذَا لَكَ وَمِثْلُهُ مَعَهُ ‏"‏‏.‏ قَالَ أَبُو سَعِيدٍ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ هَذَا لَكَ وَعَشَرَةُ أَمْثَالِهِ ‏"‏‏.‏ قَالَ أَبُو هُرَيْرَةَ حَفِظْتُ ‏"‏ مِثْلُهُ مَعَهُ ‏"‏‏.‏\hadithno{6574}\hadithtrans{Narrated 'Ata (while Abu Huraira was narrating (see previous hadith)):Abu Sa`id was sitting in the company of Abu Huraira and he did not deny anything of his narration till he reached his saying: "All this and as much again therewith are for you." Then Abu Sa`id said, "I heard Allah's Messenger (ﷺ) saying, 'This is for you and ten times as much.' " Abu Huraira said, "In my memory it is 'as much again therewith}}
\hadithdefcmd{bukhari}{6575}{حَدَّثَنِي يَحْيَى بْنُ حَمَّادٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سُلَيْمَانَ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ أَنَا فَرَطُكُمْ، عَلَى الْحَوْضِ ‏"‏‏.‏\hadithno{6575}\hadithtrans{Narrated `Abdullah:The Prophet (ﷺ) said, "I am your predecessor at the Lake-Fount}}
\hadithdefcmd{bukhari}{6576}{وَحَدَّثَنِي عَمْرُو بْنُ عَلِيٍّ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنِ الْمُغِيرَةِ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، عَنْ عَبْدِ اللَّهِ ـ رضى الله عنه ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏أَنَا فَرَطُكُمْ، عَلَى الْحَوْضِ، وَلَيُرْفَعَنَّ رِجَالٌ مِنْكُمْ ثُمَّ لَيُخْتَلَجُنَّ دُونِي فَأَقُولُ يَا رَبِّ أَصْحَابِي‏.‏ فَيُقَالُ إِنَّكَ لاَ تَدْرِي مَا أَحْدَثُوا بَعْدَكَ‏"‏.‏ تَابَعَهُ عَاصِمٌ عَنْ أَبِي وَائِلٍ‏.‏ وَقَالَ حُصَيْنٌ عَنْ أَبِي وَائِلٍ عَنْ حُذَيْفَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6576}\hadithtrans{Abdullah added:The Prophet (ﷺ) said, "I am your predecessor at the Lake-Fount, and some of you will be brought in front of me till I will see them and then they will be taken away from me and I will say, 'O Lord, my companions!' It will be said, 'You do not know what they did after you had left}}
\hadithdefcmd{bukhari}{6577}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، حَدَّثَنِي نَافِعٌ، عَنِ ابْنِ عُمَرَ ـ رضى الله عنهما ـ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَمَامَكُمْ حَوْضٌ كَمَا بَيْنَ جَرْبَاءَ وَأَذْرُحَ ‏"‏‏.‏\hadithno{6577}\hadithtrans{Narrated Ibn `Umar:The Prophet (ﷺ) said, "There will be a tank (Lake-Fount) in front of you as large as the distance between Jarba and Adhruh (two towns in Sham)}}
\hadithdefcmd{bukhari}{6578}{حَدَّثَنِي عَمْرُو بْنُ مُحَمَّدٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا أَبُو بِشْرٍ، وَعَطَاءُ بْنُ السَّائِبِ، عَنْ سَعِيدِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ ـ رضى الله عنه ـ قَالَ الْكَوْثَرُ الْخَيْرُ الْكَثِيرُ الَّذِي أَعْطَاهُ اللَّهُ إِيَّاهُ‏.‏ قَالَ أَبُو بِشْرٍ قُلْتُ لِسَعِيدٍ إِنَّ أُنَاسًا يَزْعُمُونَ أَنَّهُ نَهَرٌ فِي الْجَنَّةِ‏.‏ فَقَالَ سَعِيدٌ النَّهَرُ الَّذِي فِي الْجَنَّةِ مِنَ الْخَيْرِ الَّذِي أَعْطَاهُ اللَّهُ إِيَّاهُ‏.‏\hadithno{6578}\hadithtrans{Narrated Ibn `Abbas:The word 'Al-Kauthar' means the abundant good which Allah gave to him (the Prophet Muhammad (ﷺ)). Abu Bishr said: I said to Sa`id, "Some people claim that it (Al-Kauthar) is a river in Paradise." Sa`id replied, "The river which is in Paradise is one item of that good which Allah has bestowed upon him (Muhammad)}}
\hadithdefcmd{bukhari}{6579}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا نَافِعُ بْنُ عُمَرَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، قَالَ قَالَ عَبْدُ اللَّهِ بْنُ عَمْرٍو قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ حَوْضِي مَسِيرَةُ شَهْرٍ، مَاؤُهُ أَبْيَضُ مِنَ اللَّبَنِ، وَرِيحُهُ أَطْيَبُ مِنَ الْمِسْكِ، وَكِيزَانُهُ كَنُجُومِ السَّمَاءِ، مَنْ شَرِبَ مِنْهَا فَلاَ يَظْمَأُ أَبَدًا ‏"‏‏.‏\hadithno{6579}\hadithtrans{Narrated `Abdullah bin `Amr:The Prophet (ﷺ) said, "My Lake-Fount is (so large that it takes) a month's journey to cross it. Its water is whiter than milk, and its smell is nicer than musk (a kind of Perfume), and its drinking cups are (as numerous) as the (number of) stars of the sky; and whoever drinks from it, will never be thirsty}}
\hadithdefcmd{bukhari}{6580}{حَدَّثَنَا سَعِيدُ بْنُ عُفَيْرٍ، قَالَ حَدَّثَنِي ابْنُ وَهْبٍ، عَنْ يُونُسَ، قَالَ ابْنُ شِهَابٍ حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏(‏إِنَّ قَدْرَ حَوْضِي كَمَا بَيْنَ أَيْلَةَ وَصَنْعَاءَ مِنَ الْيَمَنِ، وَإِنَّ فِيهِ مِنَ الأَبَارِيقِ كَعَدَدِ نُجُومِ السَّمَاءِ‏)‏‏.‏\hadithno{6580}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) said, "The width of my Lake-Fount is equal to the distance between Aila (a town in Sham) and Sana' (the capital of Yemen) and it has as many (numerous) jugs as the number of stars of the sky}}
\hadithdefcmd{bukhari}{6581}{حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏ وَحَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَمَا أَنَا أَسِيرُ فِي الْجَنَّةِ إِذَا أَنَا بِنَهَرٍ حَافَتَاهُ قِبَابُ الدُّرِّ الْمُجَوَّفِ قُلْتُ مَا هَذَا يَا جِبْرِيلُ قَالَ هَذَا الْكَوْثَرُ الَّذِي أَعْطَاكَ رَبُّكَ‏.‏ فَإِذَا طِينُهُ ـ أَوْ طِيبُهُ ـ مِسْكٌ أَذْفَرُ ‏"‏‏.‏ شَكَّ هُدْبَةُ‏.‏\hadithno{6581}\hadithtrans{Narrated Anas bin Malik:The Prophet (ﷺ) said: "While I was walking in Paradise (on the night of Mi'raj), I saw a river, on the two banks of which there were tents made of hollow pearls. I asked, "What is this, O Gabriel?' He said, 'That is the Kauthar which Your Lord has given to you.' Behold! Its scent or its mud was sharp smelling musk!" (The sub-narrator, Hudba is in doubt as to the correct expression)}}
\hadithdefcmd{bukhari}{6582}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا وُهَيْبٌ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيَرِدَنَّ عَلَىَّ نَاسٌ مِنْ أَصْحَابِي الْحَوْضَ، حَتَّى عَرَفْتُهُمُ اخْتُلِجُوا دُونِي، فَأَقُولُ أَصْحَابِي‏.‏ فَيَقُولُ لاَ تَدْرِي مَا أَحْدَثُوا بَعْدَكَ ‏"‏‏.‏\hadithno{6582}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "Some of my companions will come to me at my Lake Fount, and after I recognize them, they will then be taken away from me, whereupon I will say, 'My companions!' Then it will be said, 'You do not know what they innovated (new things) in the religion after you}}
\hadithdefcmd{bukhari}{6583}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، حَدَّثَنَا مُحَمَّدُ بْنُ مُطَرِّفٍ، حَدَّثَنِي أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ إِنِّي فَرَطُكُمْ عَلَى الْحَوْضِ، مَنْ مَرَّ عَلَىَّ شَرِبَ، وَمَنْ شَرِبَ لَمْ يَظْمَأْ أَبَدًا، لَيَرِدَنَّ عَلَىَّ أَقْوَامٌ أَعْرِفُهُمْ وَيَعْرِفُونِي، ثُمَّ يُحَالُ بَيْنِي وَبَيْنَهُمْ ‏"‏‏.‏\hadithno{6583}\hadithtrans{Narrated Abu Hazim from Sahl bin Sa`d:The Prophet (ﷺ) said, "I am your predecessor (forerunner) at the Lake-Fount, and whoever will pass by there, he will drink from it and whoever will drink from it, he will never be thirsty. There will come to me some people whom I will recognize, and they will recognize me, but a barrier will be placed between me and them}}
\hadithdefcmd{bukhari}{6584}{قَالَ أَبُو حَازِمٍ فَسَمِعَنِي النُّعْمَانُ بْنُ أَبِي عَيَّاشٍ، فَقَالَ هَكَذَا سَمِعْتَ مِنْ، سَهْلٍ فَقُلْتُ نَعَمْ‏.‏ فَقَالَ أَشْهَدُ عَلَى أَبِي سَعِيدٍ الْخُدْرِيِّ لَسَمِعْتُهُ وَهْوَ يَزِيدُ فِيهَا ‏ "‏ فَأَقُولُ إِنَّهُمْ مِنِّي‏.‏ فَيُقَالُ إِنَّكَ لاَ تَدْرِي مَا أَحْدَثُوا بَعْدَكَ‏.‏ فَأَقُولُ سُحْقًا سُحْقًا لِمَنْ غَيَّرَ بَعْدِي ‏"‏‏.‏ وَقَالَ ابْنُ عَبَّاسٍ سُحْقًا بُعْدًا، يُقَالُ سَحِيقٌ بَعِيدٌ، وَأَسْحَقَهُ أَبْعَدَهُ‏.‏\hadithno{6584}\hadithtrans{Abu Hazim added:An-Nu`man bin Abi `Aiyash, on hearing me, said. "Did you hear this from Sahl?" I said, "Yes." He said, " I bear witness that I heard Abu Sa`id Al-Khudri saying the same, adding that the Prophet (ﷺ) said: 'I will say: They are of me (i.e. my followers). It will be said, 'You do not know what they innovated (new things) in the religion after you left'. I will say, 'Far removed, far removed (from mercy), those who changed (their religion) after me}}
\hadithdefcmd{bukhari}{6585}{وَقَالَ أَحْمَدُ بْنُ شَبِيبِ بْنِ سَعِيدٍ الْحَبَطِيُّ حَدَّثَنَا أَبِي، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ كَانَ يُحَدِّثُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَرِدُ عَلَىَّ يَوْمَ الْقِيَامَةِ رَهْطٌ مِنْ أَصْحَابِي فَيُحَلَّئُونَ عَنِ الْحَوْضِ فَأَقُولُ يَا رَبِّ أَصْحَابِي‏.‏ فَيَقُولُ إِنَّكَ لاَ عِلْمَ لَكَ بِمَا أَحْدَثُوا بَعْدَكَ، إِنَّهُمُ ارْتَدُّوا عَلَى أَدْبَارِهِمُ الْقَهْقَرَى ‏"‏‏.‏\hadithno{6585}\hadithtrans{Abu Huraira narrated that the Prophet (ﷺ) said:"On the Day of Resurrection a group of companions will come to me, but will be driven away from the Lake-Fount, and I will say, 'O Lord (those are) my companions!' It will be said, 'You have no knowledge as to what they innovated after you left; they turned apostate as renegades (reverted from Islam)}}
\hadithdefcmd{bukhari}{6586}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا ابْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، عَنِ ابْنِ الْمُسَيَّبِ، أَنَّهُ كَانَ يُحَدِّثُ عَنْ أَصْحَابِ النَّبِيِّ، صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ يَرِدُ عَلَى الْحَوْضِ رِجَالٌ مِنْ أَصْحَابِي فَيُحَلَّئُونَ عَنْهُ فَأَقُولُ يَا رَبِّ أَصْحَابِي‏.‏ فَيَقُولُ إِنَّكَ لاَ عِلْمَ لَكَ بِمَا أَحْدَثُوا بَعْدَكَ، إِنَّهُمُ ارْتَدُّوا عَلَى أَدْبَارِهِمُ الْقَهْقَرَى ‏"‏‏.‏ وَقَالَ شُعَيْبٌ عَنِ الزُّهْرِيِّ كَانَ أَبُو هُرَيْرَةَ يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم فَيُجْلَوْنَ‏.‏ وَقَالَ عُقَيْلٌ فَيُحَلَّئُونَ‏.‏ وَقَالَ الزُّبَيْدِيُّ عَنِ الزُّهْرِيِّ عَنْ مُحَمَّدِ بْنِ عَلِيٍّ عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{6586}\hadithtrans{Narrated Ibn Al-Musaiyab:The companions of the Prophet (ﷺ) said, "Some men from my companions will come to my Lake-Fount and they will be driven away from it, and I will say, 'O Lord, my companions!' It will be said, 'You have no knowledge of what they innovated after you left: they turned apostate as renegades (reverted from Islam)}}
\hadithdefcmd{bukhari}{6587}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا مُحَمَّدُ بْنُ فُلَيْحٍ، حَدَّثَنَا أَبِي قَالَ، حَدَّثَنِي هِلاَلٌ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ بَيْنَا أَنَا قَائِمٌ إِذَا زُمْرَةٌ، حَتَّى إِذَا عَرَفْتُهُمْ خَرَجَ رَجُلٌ مِنْ بَيْنِي وَبَيْنِهِمْ فَقَالَ هَلُمَّ‏.‏ فَقُلْتُ أَيْنَ قَالَ إِلَى النَّارِ وَاللَّهِ‏.‏ قُلْتُ وَمَا شَأْنُهُمْ قَالَ إِنَّهُمُ ارْتَدُّوا بَعْدَكَ عَلَى أَدْبَارِهِمُ الْقَهْقَرَى‏.‏ ثُمَّ إِذَا زُمْرَةٌ حَتَّى إِذَا عَرَفْتُهُمْ خَرَجَ رَجُلٌ مِنْ بَيْنِي وَبَيْنِهِمْ فَقَالَ هَلُمَّ‏.‏ قُلْتُ أَيْنَ قَالَ إِلَى النَّارِ وَاللَّهِ‏.‏ قُلْتُ مَا شَأْنُهُمْ قَالَ إِنَّهُمُ ارْتَدُّوا بَعْدَكَ عَلَى أَدْبَارِهِمُ الْقَهْقَرَى‏.‏ فَلاَ أُرَاهُ يَخْلُصُ مِنْهُمْ إِلاَّ مِثْلُ هَمَلِ النَّعَمِ ‏"‏‏.‏\hadithno{6587}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "While I was sleeping, a group (of my followers were brought close to me), and when I recognized them, a man (an angel) came out from amongst (us) me and them, he said (to them), 'Come along.' I asked, 'Where?' He said, 'To the (Hell) Fire, by Allah' I asked, 'what is wrong with them' He said, 'They turned apostate as renegades after you left.' Then behold! (Another) group (of my followers) were brought close to me, and when I recognized them, a man (an angel) came out from (me and them) he said (to them); Come along.' I asked, "Where?' He said, 'To the (Hell) Fire, by Allah.' I asked, What is wrong with them?' He said, 'They turned apostate as renegades after you left. So I did not see anyone of them escaping except a few who were like camels without a shepherd}}
\hadithdefcmd{bukhari}{6588}{حَدَّثَنِي إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ خُبَيْبٍ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ ـ رضى الله عنه ـ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَا بَيْنَ بَيْتِي وَمِنْبَرِي رَوْضَةٌ مِنْ رِيَاضِ الْجَنَّةِ، وَمِنْبَرِي عَلَى حَوْضِي ‏"‏‏.‏\hadithno{6588}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Between my house and my pulpit there is a garden from amongst the gardens of Paradise, and my pulpit is over my Lake-Fount}}
\hadithdefcmd{bukhari}{6589}{حَدَّثَنَا عَبْدَانُ، أَخْبَرَنِي أَبِي، عَنْ شُعْبَةَ، عَنْ عَبْدِ الْمَلِكَ، قَالَ سَمِعْتُ جُنْدَبًا، قَالَ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ أَنَا فَرَطُكُمْ، عَلَى الْحَوْضِ ‏"‏‏.‏\hadithno{6589}\hadithtrans{Narrated Jundab:I heard the Prophet, saying, "I am your predecessor at the Lake-Fount. (Al-Kauthar)}}
\hadithdefcmd{bukhari}{6590}{حَدَّثَنَا عَمْرُو بْنُ خَالِدٍ، حَدَّثَنَا اللَّيْثُ، عَنْ يَزِيدَ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ ـ رضى الله عنه ـ أَنَّ النَّبِيَّ صلى الله عليه وسلم خَرَجَ يَوْمًا فَصَلَّى عَلَى أَهْلِ أُحُدٍ صَلاَتَهُ عَلَى الْمَيِّتِ، ثُمَّ انْصَرَفَ عَلَى الْمِنْبَرِ فَقَالَ ‏ "‏ إِنِّي فَرَطٌ لَكُمْ، وَأَنَا شَهِيدٌ عَلَيْكُمْ، وَإِنِّي وَاللَّهِ لأَنْظُرُ إِلَى حَوْضِي الآنَ، وَإِنِّي أُعْطِيتُ مَفَاتِيحَ خَزَائِنِ الأَرْضِ ـ أَوْ مَفَاتِيحَ الأَرْضِ ـ وَإِنِّي وَاللَّهِ مَا أَخَافُ عَلَيْكُمْ أَنْ تُشْرِكُوا بَعْدِي، وَلَكِنْ أَخَافُ عَلَيْكُمْ أَنْ تَنَافَسُوا فِيهَا ‏"‏‏.‏\hadithno{6590}\hadithtrans{Narrated `Uqba bin 'Amir:Once the Prophet (ﷺ) went out and offered the funeral prayers for the martyrs of Uhud, and then went to the pulpit and said, "I am a predecessor for you and I am a witness for you: and by Allah, I am looking at my Fount just now, and the keys of the treasures of the earth (or the keys of the earth) have been given to me: and by Allah, I am not afraid that you will worship others besides Allah after me, but I am afraid that you will strive and struggle against each other over these treasures of the world}}
\hadithdefcmd{bukhari}{6591}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، حَدَّثَنَا حَرَمِيُّ بْنُ عُمَارَةَ، حَدَّثَنَا شُعْبَةُ، عَنْ مَعْبَدِ بْنِ خَالِدٍ، أَنَّهُ سَمِعَ حَارِثَةَ بْنَ وَهْبٍ، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم وَذَكَرَ الْحَوْضَ فَقَالَ ‏ "‏ كَمَا بَيْنَ الْمَدِينَةِ وَصَنْعَاءَ ‏"‏‏.‏\hadithno{6591}\hadithtrans{Narrated Haritha bin Wahb:I heard the Prophet (ﷺ) mentioning the Lake-Fount (Al-Kauthar), saying, "(The width of the Lake-Fount) is equal to the distance between Medina and Sana' (capital of Yemen)}}
\hadithdefcmd{bukhari}{6592}{وَزَادَ ابْنُ أَبِي عَدِيٍّ عَنْ شُعْبَةَ، عَنْ مَعْبَدِ بْنِ خَالِدٍ، عَنْ حَارِثَةَ، سَمِعَ النَّبِيَّ صلى الله عليه وسلم قَوْلَهُ حَوْضُهُ مَا بَيْنَ صَنْعَاءَ وَالْمَدِينَةِ‏.‏ فَقَالَ لَهُ الْمُسْتَوْرِدُ أَلَمْ تَسْمَعْهُ قَالَ الأَوَانِي‏.‏ قَالَ لاَ‏.‏ قَالَ الْمُسْتَوْرِدُ تُرَى فِيهِ الآنِيَةُ مِثْلَ الْكَوَاكِبِ‏.‏\hadithno{6592}\hadithtrans{Haritha said that he heard the Prophet saying that his Lake-Fount would be as large as the distance between Sana' and Medina. Al- Mustaurid said to Haritha, "Didn't you hear him talking about the vessels?" He said, "No." Al- Mustaurid said, "The vessels are seen in it as (numberless as) the stars}}
\hadithdefcmd{bukhari}{6593}{حَدَّثَنَا سَعِيدُ بْنُ أَبِي مَرْيَمَ، عَنْ نَافِعِ بْنِ عُمَرَ، قَالَ حَدَّثَنِي ابْنُ أَبِي مُلَيْكَةَ، عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ ـ رضى الله عنهما ـ قَالَتْ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنِّي عَلَى الْحَوْضِ حَتَّى أَنْظُرُ مَنْ يَرِدُ عَلَىَّ مِنْكُمْ، وَسَيُؤْخَذُ نَاسٌ دُونِي فَأَقُولُ يَا رَبِّ مِنِّي وَمِنْ أُمَّتِي‏.‏ فَيُقَالُ هَلْ شَعَرْتَ مَا عَمِلُوا بَعْدَكَ وَاللَّهِ مَا بَرِحُوا يَرْجِعُونَ عَلَى أَعْقَابِهِمْ ‏"‏‏.‏ فَكَانَ ابْنُ أَبِي مُلَيْكَةَ يَقُولُ اللَّهُمَّ إِنَّا نَعُوذُ بِكَ أَنْ نَرْجِعَ عَلَى أَعْقَابِنَا أَوْ نُفْتَنَ عَنْ دِينِنَا‏.‏ ‏\{‏أَعْقَابِكُمْ تَنْكِصُونَ‏\}‏ تَرْجِعُونَ عَلَى الْعَقِبِ‏.‏\hadithno{6593}\hadithtrans{Narrated Asma 'bint Abu Bakr:The Prophet (ﷺ) said, "I will be standing at the Lake-Fount so that I will see whom among you will come to me; and some people will be taken away from me, and I will say, 'O Lord, (they are) from me and from my followers.' Then it will be said, 'Did you notice what they did after you? By Allah, they kept on turning on their heels (turned as renegades).' " The sub-narrator, Ibn Abi Mulaika said, "O Allah, we seek refuge with You from turning on our heels, or being put to trial in our religion}}
